<?php
/**
 * Display Measures Engine Report Form
 * Copyright (C) 2015 - 2017      Suncoast Connection
 * 
 * LICENSE: This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0
 * See the Mozilla Public License for more details. 
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 * 
 * @author  Art Eaton <art@suncoastconnection.com>
 * @author  Bryan lee <leebc 11 at acm dot org>
 * @author  Sam Likins <sam.likins@wsi-services.com>
 * @package LibreHealthEHR 
 * @link    http://suncoastconnection.com
 * @link    http://librehealth.io
 *
 * Please support this product by sharing your changes with the LibreHealth.io community.
 */
// SANITIZE ALL ESCAPES
$sanitize_all_escapes = true;

// STOP FAKE REGISTER GLOBALS
$fake_register_globals = false;

require_once 'mips_headers.inc.php';


function existsDefault(&$array, $key, $default = '') {
  if(array_key_exists($key, $array)) {
    $default = trim($array[$key]);
  }

  return $default;
}

$page_titles = array(
  'pqrs'                  => xlt('Physician Quality Reporting System'),
  'pqrs_individual_2016'  => xlt('Physician Quality Reporting System -- Measures -- 2017'),
);

// See if showing an old report or creating a new report
$report_id = existsDefault($_GET, 'report_id');

// Collect the back variable, if pertinent
$back_link = existsDefault($_GET, 'back');

// If showing an old report, then collect information
if(!empty($report_id)) {
  $report_view = collectReportDatabase($report_id);

  //error_log("report_view is ".print_r($report_view,TRUE),0);

  $date_report = $report_view['date_report'];

  
  
  $type_report = (
    in_array(
      $report_view['type'],
      array(
        'pqrs', 'pqrs_individual_2016',
        
      )
    ) ?
    $report_view['type'] :
    'standard'
  );

  $rule_filter = $report_view['type'];

  if(in_array($type_report, array('pqrs', 'pqrs_individual_2016','mips_2017'))) {
    $begin_date = $report_view['date_begin'];
       if (isset($report_view['title'])) {

           $report_title=$report_view['title'];

            } else {

                $report_title="";

                }
  } 

  $target_date = $report_view['date_target'];
  $plan_filter = $report_view['plan'];
  $organize_method = $report_view['organize_mode'];
  $provider  = $report_view['provider'];
  $pat_prov_rel = $report_view['pat_prov_rel'];
  

  $dataSheet = json_decode($report_view['data'], true);
 
  $page_subtitle = ' - '.xlt('Date of Report').': '.text($date_report);
  $dis_text = ' disabled="disabled" ';

} else {
  // Collect report type parameter 
  $type_report = existsDefault($_GET, 'type', 'standard');
  $rule_filter = existsDefault($_POST, 'form_rule_filter', $type_report);

  if(in_array($type_report, array( 'pqrs_individual_2016'))) {
    $type_report = 'pqrs';
  } 

  // Collect form parameters (set defaults if empty)
  if($type_report == 'pqrs') {
    $begin_date = existsDefault($_POST, 'form_begin_date', '2017-01-01 00:00:00');  //change defaults in 2017
  }

  if($type_report == 'pqrs') {
    $target_date = existsDefault($_POST, 'form_target_date', '2017-12-31 23:59:59');  //change defaults in 2017
  } 
  $plan_filter = existsDefault($_POST, 'form_plan_filter', '');
  $organize_method = (empty($plan_filter)) ? 'default' : 'plans';
  $provider = trim(existsDefault($_POST, 'form_provider', ''));
  $pat_prov_rel = (empty($_POST['form_pat_prov_rel'])) ? 'encounter' : trim($_POST['form_pat_prov_rel']);
  $page_subtitle = '';
  $dis_text = '';
}
$DateFormat = DateFormatRead();
$DateLocale = getLocaleCodeForDisplayLanguage($GLOBALS['language_default']);

$widthDyn = '470px';  //determine what is needed for pqrs

?>
<html>
  <head>
<?php html_header_show();?>
    <link rel="stylesheet" href="<?php echo $css_header;?>" type="text/css">  <!--should include stylesheet in project-->
    <link rel="stylesheet" href="../../assets/css/jquery-datetimepicker/jquery.datetimepicker.css">
    <title><?php echo $page_titles[$type_report]; ?></title>
    <script type="text/javascript" src="../../library/overlib_mini.js"></script>
    <script type="text/javascript" src="../../library/textformat.js"></script>
    <script type="text/javascript" src="../../library/dialog.js"></script>
    <script type="text/javascript" src="../../assets/js/jquery-min-3-1-1/index.js"></script>
    <script language="JavaScript">
var mypcc = '<?php echo text($GLOBALS['phone_country_code']) ?>';

$(document).ready(function() {
  var win = top.printLogSetup ? top : openemr.top;
  win.printLogSetup(document.getElementById('printbutton'));
});

function runReport() {
  // Validate first
  if(!validateForm()) {
    alert("<?php echo xls('Rule Set and Plan Set selections are not consistent. Please fix and Submit again.'); ?>");
    return false;
  }

  // Showing processing wheel
  $("#processing").show();

  // hide Submit buttons
  $("#submit_button").hide();
  $("#xmla_button").hide();
  $("#xmlb_button").hide();
  $("#xmlc_button").hide();
  $("#print_button").hide();
  $("#genQRDA").hide();

  // hide instructions
  $("#instructions_text").hide();

  // Collect an id string via an ajax request
  top.restoreSession();
  $.get(
    "../../library/ajax/collect_new_report_id.php",
    function(data) {
      // Set the report id in page form
      $("#form_new_report_id").attr("value", data);

      // Start collection status checks
      collectStatus($("#form_new_report_id").val());

      // Run the report
      top.restoreSession();
      $.post(
        "../../library/ajax/execute_clinical_measures_report.php",
        {
          provider: $("#form_provider").val(),
          type: $("#form_rule_filter").val(),
          date_target: $("#form_target_date").val(),
          date_begin: $("#form_begin_date").val(),
          plan: $("#form_plan_filter").val(),
          labs: $("#labs_manual_entry").val(),
          pat_prov_rel: $("#form_pat_prov_rel").val(),
          execute_report_id: $("#form_new_report_id").val()
        }
      );
    }
  );
}

function collectStatus(report_id) {
  // Collect the status string via an ajax request and place in DOM at timed intervals
  top.restoreSession();

  // Do not send the skip_timeout_reset parameter, so don't close window before report is done.
  $.post(
    "../../library/ajax/status_report.php",
    { status_report_id: report_id },
    function(data) {
      if(data == "PENDING") {
        // Place the pending string in the DOM
        $('#status_span').replaceWith("<span id='status_span'><?php echo xlt('Preparing To Run Report'); ?></span>");
      } else if(data == "COMPLETE") {
        // Go into the results page
        top.restoreSession();
        link_report = "clinical_measures.php?report_id="+report_id;
        window.open(link_report, '_self', false);
        $("#processing").hide();
        $('#status_span').replaceWith("<a id='view_button' href='?report_id="+report_id+"' class='css_button' onclick='top.restoreSession()'><span><?php echo xlt('View Report'); ?></span></a>");
      } else {
        // Place the string in the DOM
        $('#status_span').replaceWith("<span id='status_span'>"+data+"</span>");
      }
    }
  );

  // run status check every 10 seconds
  var repeater = setTimeout("collectStatus("+report_id+")", 10000);
}

function GenXml(sNested) {

  top.restoreSession();

  if(sNested == "PQRS") {
    var form_rule_filter = theform.form_rule_filter.value;
    var sLoc = 'generate_pqrs_xml.php?target_date='+theform.form_target_date.value+'&form_provider='+theform.form_provider.value+"&report_id=<?php echo attr($report_id); ?>&xmloptimize="+document.getElementById("xmloptimize").checked;
  } else {
    var sLoc = '../../custom/export_registry_xml.php?&target_date='+theform.form_target_date.value+'&nested='+sNested;
  }
  dlgopen(sLoc, '_blank', 600, 500);

  return false;
}



function validateForm() {
  return true;
}

function Form_Validate() {
<?php if(empty($report_id) && in_array($type_report, array('pqrs', 'pqrs_individual_2016',))) { ?>
  var d = document.forms[0];

  FromDate = d.form_begin_date.value;
  ToDate = d.form_target_date.value;

  if(FromDate.length > 0 && ToDate.length > 0) {
    if(FromDate > ToDate) {
      alert("<?php echo xls('End date must be later than Begin date!'); ?>");
      return false;
    }
  }

<?php
    }

    if($report_id != '') {
?>
  // For Results are in Gray Background & disabling anchor links
  $("#report_results").css("opacity", '0.4');
  $("#report_results").css("filter", 'alpha(opacity=40)');
  $("a").removeAttr("href");

<?php } ?>
  $("#form_refresh").attr("value","true");

  runReport();

  return true;
}
    </script>
    <style type="text/css">
/* specifically include & exclude from printing */
@media print {
  #report_parameters {
    visibility: hidden;
    display: none;
  }
  #report_parameters_daterange {
    visibility: visible;
    display: inline;
  }
  #report_results table {
    margin-top: 0px;
  }
}

/* specifically exclude some from the screen */
@media screen {
  #report_parameters_daterange {
    visibility: hidden;
    display: none;
  }
}
    </style>
  </head>
  <body class="body_top">
    <!-- Required for the popup date selectors -->
    <div id="overDiv" style="position: absolute; visibility: hidden; z-index: 1000;"></div>

    <span class='title'><?php echo xlt('MIPS: ').' '.$page_titles[$rule_filter].$page_subtitle; ?></span>

    <form method='post' name='theform' id='theform' action='clinical_measures.php?type=<?php echo attr($type_report) ;?>' onsubmit='return validateForm()'>
      <div id="report_parameters">
        <table>
          <tr>
            <td scope="row" width='<?php echo $widthDyn; ?>'>
              <div style='float:left'>
                <table class='text'>
<?php if(in_array($type_report, array('pqrs', 'pqrs_individual_2016'))) { ?>

                    <td class='label'>
                      <?php echo htmlspecialchars(xl('Begin Date'), ENT_NOQUOTES); ?>:
                    </td>
                      <td>
                         <input type='text' name='form_begin_date' id='form_begin_date' size='20'
                                value='<?php echo htmlspecialchars( $_POST['form_begin_date'], ENT_QUOTES); ?>'
                                title='<?php echo htmlspecialchars( xl('yyyy-mm-dd hh:mm:ss'), ENT_QUOTES); ?>'>
                      </td>
                   </tr>

                <tr>
                        <td class='label'>
                              <?php echo htmlspecialchars( xl('End Date'), ENT_NOQUOTES); ?>:
                        </td>
                    <td>
                           <input type='text' name='form_end_date' id='form_end_date' size='20'
                                  value='<?php echo htmlspecialchars( $_POST['form_end_date'], ENT_QUOTES); ?>'
                                  title='<?php echo htmlspecialchars( xl('yyyy-mm-dd hh:mm:ss'), ENT_QUOTES); ?>'>
                        </td>
                </tr>
<!--                    <td>
                      <input <?php echo $dis_text; ?> type='text' name='form_begin_date' id="form_begin_date" size='20'
                        value='<?php echo htmlspecialchars($begin_date, ENT_QUOTES); ?>'
                        onkeyup='datekeyup(this,mypcc)' onblur='dateblur(this,mypcc)'
                        title='<?php echo htmlspecialchars(xl('yyyy-mm-dd hh:mm:ss'), ENT_QUOTES); ?>'>
<?php   if(empty($report_id)) { ?>
                      <img src='../../interface/pic/show_calendar.gif' align='absbottom' width='24' height='22'
                        id='img_begin_date' border='0' alt='[?]' style='cursor:pointer'
                        title='<?php echo htmlspecialchars(xl('Click here to choose a date'), ENT_QUOTES); ?>'>
<?php   } ?>
                    </td>
                  </tr>
<?php } ?>
                  <tr>
                    <td class='label'>
<?php if(in_array($type_report, array('pqrs', 'pqrs_individual_2016'))) { ?>
                      <?php echo htmlspecialchars(xl('End Date'), ENT_NOQUOTES); ?>:
<?php } else { ?>
                      <?php echo htmlspecialchars(xl('Target Date'), ENT_NOQUOTES); ?>:
<?php } ?>
                    </td>
                    <td>
                      <input <?php echo $dis_text; ?> type='text' name='form_target_date' id="form_target_date" size='20'
                        value='<?php echo htmlspecialchars($target_date, ENT_QUOTES); ?>'
                        onkeyup='datekeyup(this,mypcc)' onblur='dateblur(this,mypcc)'
                        title='<?php echo htmlspecialchars(xl('yyyy-mm-dd hh:mm:ss'), ENT_QUOTES); ?>'>
<?php if(empty($report_id)) { ?>
                      <img src='../../interface/pic/show_calendar.gif' align='absbottom' width='24' height='22'
                        id='img_target_date' border='0' alt='[?]' style='cursor:pointer'
                        title='<?php echo htmlspecialchars(xl('Click here to choose a date'), ENT_QUOTES); ?>'>
<?php } ?>
                    </td>
                  </tr>-->
<?php if(in_array($type_report, array('pqrs','pqrs_individual_2016'))) { ?>
                  <tr>
                    <td class='label'>
                      <?php echo xlt('Report Type'); ?>:
                    </td>
                    <td>
                      <select <?php echo $dis_text; ?> id='form_rule_filter' name='form_rule_filter'>
                        <option value='pqrs_individual_2016' <?php if ($rule_filter == "pqrs_individual_2016") {echo "selected";} ?>><?php echo xlt('Registry Measures'); ?></option>
                      </select>
                    </td>
                  </tr>
<?php }

    if(in_array($type_report, array('pqrs', 'pqrs_individual_2016'))) {

//  Nothing.  Do NOTHING!  --leebc
?>
        <input type='hidden' id='form_plan_filter' name='form_plan_filter' value=''>
<?php

 }  ?>
                  <tr>
                    <td class='label'>
                      <?php echo htmlspecialchars(xl('Provider'), ENT_NOQUOTES); ?>:
                    </td>
                    <td>
                      <select <?php echo $dis_text; ?> id='form_provider' name='form_provider'>
                        <option value=''>-- <?php echo htmlspecialchars(xl('All (Cumulative)'), ENT_NOQUOTES); ?> --</option>
<!-- TODO: Requires revision upon publishing of 2017 MIPS standard (not published yet: July 2017) -->
                        <option value='collate_outer' <?php if($provider == 'collate_outer') {echo 'selected';} ?>>-- <?php echo htmlspecialchars(xl('All (Collated Format A)'), ENT_NOQUOTES); ?> --</option>
                        <option value='collate_inner' <?php if($provider == 'collate_inner') {echo 'selected';} ?>>-- <?php echo htmlspecialchars(xl('All (Collated Format B)'), ENT_NOQUOTES); ?> --</option>
<?php
      // Build a drop-down list of providers.
      if(!isset($provider_facility_filter)) {
        $provider_facility_filter = '';
      }
      $providers = sqlStatement('SELECT `id`, `lname`, `fname` FROM `users` WHERE `authorized` = 1 '.$provider_facility_filter.' ORDER BY `lname`, `fname`;');
      // (CHEMED) facility filter
      while($providerRow = sqlFetchArray($providers)) {
?>
                        <option value='<?php echo htmlspecialchars($providerRow['id'], ENT_QUOTES); ?>' <?php if($providerRow['id'] == $provider) echo ' selected'; ?>><?php echo htmlspecialchars($providerRow['lname'].', '.$providerRow['fname'], ENT_NOQUOTES); ?></option>
<?php } ?>
                      </select>
                    </td>
                  </tr>
                  <tr>
                    <td class='label'>
                      <?php echo htmlspecialchars(xl('Provider Relationship'), ENT_NOQUOTES); ?>:
                    </td>
                    <td>
                      <select <?php echo $dis_text; ?> id='form_pat_prov_rel' name='form_pat_prov_rel' title='<?php echo xlt('Only applicable if a provider or collated list was chosen above. PRIMARY only selects patients that the provider is the primary provider. ENCOUNTER selects all patients that the provider has seen.'); ?>'>
                        <option value='primary'<?php if($pat_prov_rel == 'primary') {echo 'selected';} ?>><?php echo xlt('Primary'); ?></option>
                        <option value='encounter'<?php if($pat_prov_rel == 'encounter') {echo 'selected';} ?>><?php echo xlt('Encounter'); ?></option>
                      </select>
                    </td>
                  </tr>

                </table>
              </div>
            </td>
            <td align='left' valign='middle' height="100%">
              <table style='border-left:1px solid; width:100%; height:100%' >
                <tr>
                  <td scope="row">
                    <div style='margin-left:15px'>
                        <span>
<?php   if (isset($report_view['title'])) {
        $report_title=$report_view['title'];
        } else {
        $report_title="";
        }
    if ($report_title != "" ) {
        echo ("Report Title:  $report_title \n");
    }  ?>

                        </span>
                    </div>
          </td>
        </tr>
<?php if(empty($report_id)) { ?>
                      <a id='submit_button' href='#' class='css_button' onclick='runReport();'>
                        <span>
                          <?php echo htmlspecialchars(xl('Submit'), ENT_NOQUOTES); ?>
                        </span>
                      </a>
                      <span id='status_span'></span>
                      <div id='processing' style='margin:10px;display:none;'><img src='../../interface/pic/ajax-loader.gif'/></div>
<?php }

    if(!empty($report_id)) {
?>
                      <a href='#' class='css_button' id='printbutton'>
                        <span>
                          <?php echo htmlspecialchars(xl('Print'), ENT_NOQUOTES); ?>
                        </span>
                      </a>
<?php   if(in_array($type_report, array('pqrs_individual_2016'))) { ?>
                        Optimize XML report?
                        <input id="xmloptimize" type="checkbox" name="xmloptimize" value="1" />
                      <a href="#"  id="xml_pqrs" class='css_button' onclick='GenXml("PQRS");'>
                        <span>
                          <?php echo htmlspecialchars(xl('Generate XML for MIPS'), ENT_NOQUOTES); ?>
                        </span>
                      </a>
<?php   } 

      if($back_link == 'list') {
?>
                      <a href='report_results.php' class='css_button' onclick='top.restoreSession()'><span><?php echo xlt('Return To Report Results'); ?></span></a>
<?php   } else { ?>
                      <a href='#' class='css_button' onclick='top.restoreSession(); $("#theform").submit();'><span><?php echo xlt('Start Another Report'); ?></span></a>
<?php
      }
    }
?>
                    </div>
                  </td>
                </tr>
              </table>
            </td>
          </tr>
        </table>
      </div>  <!-- end of search parameters -->
      <br>
<?php if(!empty($report_id)) { ?>
      <div id="report_results">
        <table>
          <thead>
            <th><?php echo htmlspecialchars(xl('Title'), ENT_NOQUOTES); ?></th>
            <th><?php echo htmlspecialchars(xl('Total Patients'), ENT_NOQUOTES); ?></th>
            <th><?php if(in_array($type_report, array( 'pqrs', 'pqrs_individual_2016'))) { echo htmlspecialchars(xl('Denominator'), ENT_NOQUOTES); } else { echo htmlspecialchars(xl('something else'), ENT_NOQUOTES); }  ?></th>

            <th><?php echo htmlspecialchars(xl('Excluded Patients'), ENT_NOQUOTES); ?></th>

            <th><?php echo htmlspecialchars(xl('Passed Patients').' ('.xl('Numerator').')', ENT_NOQUOTES);  ?></th>
            <th><?php echo htmlspecialchars(xl('Failed Patients'), ENT_NOQUOTES);  ?></th>
            <th><?php echo htmlspecialchars(xl('Performance Percentage'), ENT_NOQUOTES); ?></th>
          </thead>
          <tbody>  <!-- added for better print-ability -->
<?php

      $firstProviderFlag = true;
      $firstPlanFlag = true;
      $existProvider = false;
//error_log("Datasheet is [".$dataSheet."]",0);
//error_log("Datasheet print_r is ".print_r($dataSheet,TRUE),0);
      foreach($dataSheet as $row) {
?>
            <tr bgcolor='<?php echo $bgcolor ?>'>
<?php
        if(isset($row['is_main']) || isset($row['is_sub'])) {
?>
              <td class='detail'>
<?php
          if(isset($row['is_main'])) {

            $main_pass_filter = $row['pass_filter'];

            echo '<b>'.generate_display_field(array('data_type' => '1', 'list_id' => 'clinical_rules'), $row['id']).'</b>';

            $tempMeasuresString = '';

            switch($type_report) {
                case 'pqrs':
              case 'pqrs_individual_2016':
                if(!empty($row['pqrs_code'])) {
                  $tempMeasuresString .= ' '.htmlspecialchars(xl('MIPS ').preg_replace('/PQRS_/', '',$row['pqrs_code']), ENT_NOQUOTES).' ';
                 
                }
                break;

            }

            if(!empty($tempMeasuresString)) {
                $patterns = array();
                $patterns[0] = '/PQRS_0/';
                $patterns[1] = '/pre_0/';

                $mipsnumber = preg_replace($patterns, '_', $row['pqrs_code']);
                $measureURL = 'http://suncoastconnection.com/standards/Registrymeasures/2017_Measure'. $mipsnumber.'_Registry.pdf';
                ?>
                <a href='<?php echo $measureURL;?>' target="_blank"><?php echo $tempMeasuresString;?></a>
                <?php
             
            }

            if(!(empty($row['concatenated_label']))) {
              echo ', '.htmlspecialchars(xl($row['concatenated_label']), ENT_NOQUOTES).' ';
            }
          } else {
            echo generate_display_field(array('data_type' => '1', 'list_id' => 'rule_action_category'), $row['action_category']);
            echo ': '.generate_display_field(array('data_type' => '1', 'list_id' => 'rule_action'), $row['action_item']);
          }
?>
              </td>
              <td align='center'><?php echo $row['total_patients']; ?></td>
<?php
          if(isset($row['itemized_test_id']) && $row['pass_filter'] > 0) {
            $query = http_build_query(array(
              'from_page' => 'pqrs_report',
              'pass_id' => 'all',
              'report_id' => attr($report_id),
              'itemized_test_id' => attr($row['itemized_test_id']),
              'numerator_label' => attr($row['numerator_label'])
            ));
?>
              <td align='center'><a href='../../interface/main/finder/patient_select.php?<?php echo $query; ?>' onclick='top.restoreSession()'><?php echo $row['pass_filter']; ?></a></td>
<?php
          } else {
?>
              <td align='center'><?php echo $row['pass_filter']; ?></td>
<?php
          }



            if(isset($row['itemized_test_id']) && $row['excluded'] > 0) {

              $query = http_build_query(array(
                'from_page' => 'pqrs_report',
                'pass_id' => 'exclude',
                'report_id' => attr($report_id),
                'itemized_test_id' => attr($row['itemized_test_id']),
                'numerator_label' => attr($row['numerator_label']),
              ));
?>
              <td align='center'><a href='../../interface/main/finder/patient_select.php?<?php echo $query; ?>' onclick='top.restoreSession()'><?php echo $row['excluded']; ?></a></td>
<?php
            } else {
?>
              <td align='center'><?php echo $row['excluded']; ?></td>
<?php
            }


// TODO: 
          if(isset($row['itemized_test_id']) && $row['pass_target'] > 0) {
            $query = http_build_query(array(
              'from_page' => 'pqrs_report',
              'pass_id' => 'pass',
              'report_id' => attr($report_id),
              'itemized_test_id' => attr($row['itemized_test_id']),
              'numerator_label' => attr($row['numerator_label']),
            ));
?>
              <td align='center'><a href='../../interface/main/finder/patient_select.php?<?php echo $query; ?>' onclick='top.restoreSession()'><?php echo $row['pass_target']; ?></a></td>
<?php
          } else {
?>
              <td align='center'><?php echo $row['pass_target']; ?></td>
<?php
          }

          $failed_items = 0;

          if(isset($row['is_main'])) {
              $failed_items = $row['pass_filter'] - $row['pass_target'] - $row['excluded'];

          } 

          if(isset($row['itemized_test_id']) && ($failed_items > 0) ) {
            $query = http_build_query(array(
              'from_page' => 'pqrs_report',
              'pass_id' => 'fail',
              'report_id' => attr($report_id),
              'itemized_test_id' => attr($row['itemized_test_id']),
              'numerator_label' => attr($row['numerator_label']),
            ));
?>
              <td align='center'><a href='../../interface/main/finder/patient_select.php?<?php echo $query; ?>' onclick='top.restoreSession()'><?php echo $failed_items; ?></a></td>
<?php
          } else {
?>
              <td align='center'><?php echo $failed_items; ?></td>
<?php
          }

?>
              <td align='center'><?php echo $row['percentage']; ?></td>
<?php
        } elseif(isset($row['is_provider'])) {
          // Display the provider information
          if(!$firstProviderFlag && $provider == 'collate_outer') {
?>
            <tr><td>&nbsp;</td></tr>
<?php
          }

          $contents = htmlspecialchars(xl('Provider').': '.$row['prov_lname'].','.$row['prov_fname'], ENT_NOQUOTES);

          if(!empty($row['npi']) || !empty($row['federaltaxid'])) {
            $contents .= ' (';
            if(!empty($row['npi'])) {
              $contents .= ' '.htmlspecialchars(xl('NPI').':'.$row['npi'], ENT_NOQUOTES).' ';
            }
            if(!empty($row['federaltaxid'])) {
              $contents .= ' '.htmlspecialchars(xl('TID').':'.$row['federaltaxid'], ENT_NOQUOTES).' ';
            }
            $contents .= ')';
          }
?>
              <td class='detail' align='center'><b><?php echo $contents; ?></b></td>
<?php
          $firstProviderFlag = false;
          $existProvider = true;
        } else {
          if(!$firstPlanFlag && $provider != 'collate_outer') {
?>
            <tr><td>&nbsp;</td></tr>
<?php
          }

          $contents = htmlspecialchars(xl('Plan'), ENT_NOQUOTES).': '.generate_display_field(array('data_type' => '1', 'list_id' => 'clinical_plans'), $row['id']);

?>
              <td class='detail' align='center'><b><?php echo $contents; ?></b></td>
<?php
          $firstPlanFlag = false;
        }
?>
            </tr>
<?php   } ?>
          </tbody>
        </table>
      </div>  <!-- end of search results -->
<?php } else { ?>
      <div id="instructions_text" class='text'><?php echo htmlspecialchars(xl('Please input search criteria above, and click Submit to start report.'), ENT_NOQUOTES); ?></div>
<?php } ?>
      <input type='hidden' name='form_new_report_id' id='form_new_report_id' value=''/>
    </form>
  </body>
  <script type="text/javascript" src="../../library/js/jquery.datetimepicker.full.min.js"></script>
<script>
    $(function() {
        $("#form_begin_date").datetimepicker({
            timepicker: false,
            format: "<?= $DateFormat; ?>"
        });
        $("#form_end_date").datetimepicker({
            timepicker: false,
            format: "<?= $DateFormat; ?>"
        });
        $.datetimepicker.setLocale('<?= $DateLocale;?>');
    });
</script>
  <!-- stuff for the popup calendar -->
  <style type="text/css">@import url(../../library/dynarch_calendar.css);</style>
  <script type="text/javascript" src="../../library/dynarch_calendar.js"></script>
<?php   include_once $GLOBALS['srcdir'].'/dynarch_calendar_en.inc.php'; ?>
  <script type="text/javascript" src="../../library/dynarch_calendar_setup.js"></script>
  <script language="Javascript">
<?php if(in_array($type_report, array('pqrs', 'pqrs_individual_2016'))) { ?>
  //  Calendar.setup({inputField:"form_begin_date", ifFormat:"%Y-%m-%d %H:%M:%S", button:"img_begin_date", showsTime:'true'});
<?php } ?>
  //  Calendar.setup({inputField:"form_target_date", ifFormat:"%Y-%m-%d %H:%M:%S", button:"img_target_date", showsTime:'true'});
  </script>
</html>
