
SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `libre200`
--

-- --------------------------------------------------------

--
-- Table structure for table `addresses`
--

CREATE TABLE `addresses` (
  `id` int(11) NOT NULL DEFAULT '0',
  `line1` varchar(255) DEFAULT NULL,
  `line2` varchar(255) DEFAULT NULL,
  `city` varchar(255) DEFAULT NULL,
  `state` varchar(35) DEFAULT NULL,
  `zip` varchar(10) DEFAULT NULL,
  `plus_four` varchar(4) DEFAULT NULL,
  `country` varchar(255) DEFAULT NULL,
  `foreign_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `foreign_id` (`foreign_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `amc_misc_data`
--

CREATE TABLE `amc_misc_data` (
  `amc_id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Unique and maps to list_options list clinical_rules',
  `pid` bigint(20) DEFAULT NULL,
  `map_category` varchar(255) NOT NULL DEFAULT '' COMMENT 'Maps to an object category (such as prescriptions etc.)',
  `map_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'Maps to an object id (such as prescription id etc.)',
  `date_created` datetime DEFAULT NULL,
  `date_completed` datetime DEFAULT NULL,
  KEY `amc_id` (`amc_id`,`pid`,`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `amendments`
--

CREATE TABLE `amendments` (
  `amendment_id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Amendment ID',
  `amendment_date` date NOT NULL COMMENT 'Amendement request date',
  `amendment_by` varchar(50) NOT NULL COMMENT 'Amendment requested from',
  `amendment_status` varchar(50) DEFAULT NULL COMMENT 'Amendment status accepted/rejected/null',
  `pid` int(11) NOT NULL COMMENT 'Patient ID from patient_data',
  `amendment_desc` text COMMENT 'Amendment Details',
  `created_by` int(11) NOT NULL COMMENT 'references users.id for session owner',
  `modified_by` int(11) DEFAULT NULL COMMENT 'references users.id for session owner',
  `created_time` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00' COMMENT 'created time',
  `modified_time` timestamp NULL DEFAULT NULL COMMENT 'modified time',
  PRIMARY KEY (`amendment_id`),
  KEY `amendment_pid` (`pid`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `amendments_history`
--

CREATE TABLE `amendments_history` (
  `amendment_id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Amendment ID',
  `amendment_note` text COMMENT 'Amendment requested from',
  `amendment_status` varchar(50) DEFAULT NULL COMMENT 'Amendment Request Status',
  `created_by` int(11) NOT NULL COMMENT 'references users.id for session owner',
  `created_time` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00' COMMENT 'created time',
  KEY `amendment_history_id` (`amendment_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `array`
--

CREATE TABLE `array` (
  `array_key` varchar(255) DEFAULT NULL,
  `array_value` longtext
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `ar_activity`
--

CREATE TABLE `ar_activity` (
  `pid` int(11) NOT NULL,
  `encounter` int(11) NOT NULL,
  `sequence_no` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `code_type` varchar(12) NOT NULL DEFAULT '',
  `code` varchar(20) NOT NULL COMMENT 'empty means claim level',
  `modifier` varchar(12) NOT NULL DEFAULT '',
  `payer_type` int(11) NOT NULL COMMENT '0=pt, 1=ins1, 2=ins2, etc',
  `post_time` datetime NOT NULL,
  `post_user` int(11) NOT NULL COMMENT 'references users.id',
  `session_id` int(10) unsigned NOT NULL COMMENT 'references ar_session.session_id',
  `memo` varchar(255) NOT NULL DEFAULT '' COMMENT 'adjustment reasons go here',
  `pay_amount` decimal(12,2) NOT NULL DEFAULT '0.00' COMMENT 'either pay or adj will always be 0',
  `adj_amount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `modified_time` datetime NOT NULL,
  `follow_up` char(1) NOT NULL,
  `follow_up_note` text,
  `account_code` varchar(15) NOT NULL,
  `reason_code` varchar(255) DEFAULT NULL COMMENT 'Use as needed to show the primary payer adjustment reason code',
  PRIMARY KEY (`sequence_no`,`pid`,`encounter`),
  KEY `session_id` (`session_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `ar_session`
--

CREATE TABLE `ar_session` (
  `session_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `payer_id` int(11) NOT NULL COMMENT '0=pt else references insurance_companies.id',
  `user_id` int(11) NOT NULL COMMENT 'references users.id for session owner',
  `closed` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=no, 1=yes',
  `reference` varchar(255) NOT NULL DEFAULT '' COMMENT 'check or EOB number',
  `check_date` date DEFAULT NULL,
  `deposit_date` date DEFAULT NULL,
  `pay_total` decimal(12,2) NOT NULL DEFAULT '0.00',
  `created_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `modified_time` datetime NOT NULL,
  `global_amount` decimal(12,2) NOT NULL,
  `payment_type` varchar(50) NOT NULL,
  `description` text,
  `adjustment_code` varchar(50) NOT NULL,
  `post_to_date` date NOT NULL,
  `patient_id` int(11) NOT NULL,
  `payment_method` varchar(25) NOT NULL,
  PRIMARY KEY (`session_id`),
  KEY `user_closed` (`user_id`,`closed`),
  KEY `deposit_date` (`deposit_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `audit_details`
--

CREATE TABLE `audit_details` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `table_name` varchar(100) NOT NULL COMMENT 'libreehr table name',
  `field_name` varchar(100) NOT NULL COMMENT 'libreehr table''s field name',
  `field_value` text COMMENT 'libreehr table''s field value',
  `audit_master_id` bigint(20) NOT NULL COMMENT 'Id of the audit_master table',
  `entry_identification` varchar(255) NOT NULL DEFAULT '1' COMMENT 'Used when multiple entry occurs from the same table.1 means no multiple entry',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `audit_master`
--

CREATE TABLE `audit_master` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `pid` bigint(20) NOT NULL,
  `user_id` bigint(20) NOT NULL COMMENT 'The Id of the user who approves or denies',
  `approval_status` tinyint(4) NOT NULL COMMENT '1-Pending,2-Approved,3-Denied,4-Appointment directly updated to calendar table,5-Cancelled appointment',
  `comments` text,
  `created_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `modified_time` datetime NOT NULL,
  `ip_address` varchar(100) NOT NULL,
  `type` tinyint(4) NOT NULL COMMENT '1-new patient,2-existing patient,3-change is only in the document,4-Patient upload,5-random key,10-Appointment',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `automatic_notification`
--

CREATE TABLE `automatic_notification` (
  `notification_id` int(5) NOT NULL AUTO_INCREMENT,
  `sms_gateway_type` varchar(255) NOT NULL,
  `next_app_date` date NOT NULL,
  `next_app_time` varchar(10) NOT NULL,
  `provider_name` varchar(100) NOT NULL,
  `message` text,
  `email_sender` varchar(100) NOT NULL,
  `email_subject` varchar(100) NOT NULL,
  `type` enum('SMS','Email') NOT NULL DEFAULT 'SMS',
  `notification_sent_date` datetime NOT NULL,
  PRIMARY KEY (`notification_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=3 ;

--
-- Dumping data for table `automatic_notification`
--

INSERT INTO `automatic_notification` VALUES
(1, 'CLICKATELL', '0000-00-00', ':', 'EMR GROUP 1 .. SMS', 'Welcome to EMR GROUP 1.. SMS', '', '', 'SMS', '0000-00-00 00:00:00'),
(2, '', '2007-10-02', '05:50', 'EMR GROUP', 'Welcome to EMR GROUP . Email', 'EMR Group', 'Welcome to EMR GROUP', 'Email', '2007-09-30 00:00:00');

-- --------------------------------------------------------

--
-- Table structure for table `background_services`
--

CREATE TABLE `background_services` (
  `name` varchar(31) NOT NULL,
  `title` varchar(127) NOT NULL COMMENT 'name for reports',
  `active` tinyint(1) NOT NULL DEFAULT '0',
  `running` tinyint(1) NOT NULL DEFAULT '-1',
  `next_run` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `execute_interval` int(11) NOT NULL DEFAULT '0' COMMENT 'minimum number of minutes between function calls,0=manual mode',
  `function` varchar(127) NOT NULL COMMENT 'name of background service function',
  `require_once` varchar(255) DEFAULT NULL COMMENT 'include file (if necessary)',
  `sort_order` int(11) NOT NULL DEFAULT '100' COMMENT 'lower numbers will be run first',
  PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `background_services`
--

INSERT INTO `background_services` VALUES
('phimail', 'phiMail Direct Messaging Service', 0, -1, '[[regtime]]', 5, 'phimail_check', '/library/direct_message_check.inc', 100);

-- --------------------------------------------------------

--
-- Table structure for table `batchcom`
--

CREATE TABLE `batchcom` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `patient_id` int(11) NOT NULL DEFAULT '0',
  `sent_by` bigint(20) NOT NULL DEFAULT '0',
  `msg_type` varchar(60) DEFAULT NULL,
  `msg_subject` varchar(255) DEFAULT NULL,
  `msg_text` mediumtext,
  `msg_date_sent` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `billing`
--

CREATE TABLE `billing` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `code_type` varchar(15) DEFAULT NULL,
  `code` varchar(20) DEFAULT NULL,
  `pid` int(11) DEFAULT NULL,
  `provider_id` int(11) DEFAULT NULL,
  `user` int(11) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(1) DEFAULT NULL,
  `encounter` bigint(20) DEFAULT NULL,
  `code_text` longtext,
  `billed` tinyint(1) DEFAULT NULL,
  `activity` tinyint(1) DEFAULT NULL,
  `payer_id` int(11) DEFAULT NULL,
  `bill_process` tinyint(2) NOT NULL DEFAULT '0',
  `bill_date` datetime DEFAULT NULL,
  `process_date` datetime DEFAULT NULL,
  `process_file` varchar(255) DEFAULT NULL,
  `modifier` varchar(12) DEFAULT NULL,
  `units` int(11) DEFAULT NULL,
  `fee` decimal(12,2) DEFAULT NULL,
  `justify` varchar(255) DEFAULT NULL,
  `target` varchar(30) DEFAULT NULL,
  `x12_partner_id` int(11) DEFAULT NULL,
  `ndc_info` varchar(255) DEFAULT NULL,
  `notecodes` varchar(80) NOT NULL DEFAULT '',
  `exclude_from_insurance_billing` tinyint(1) NOT NULL DEFAULT '0',
  `external_id` varchar(20) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `categories`
--

CREATE TABLE `categories` (
  `id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `value` varchar(255) DEFAULT NULL,
  `parent` int(11) NOT NULL DEFAULT '0',
  `lft` int(11) NOT NULL DEFAULT '0',
  `rght` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `parent` (`parent`),
  KEY `lft` (`lft`,`rght`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `categories`
--

INSERT INTO `categories` VALUES
(1, 'Categories', '', 0, 0, 25),
(2, 'Lab Report', '', 1, 1, 2),
(3, 'Medical Record', '', 1, 3, 4),
(4, 'Patient Information', '', 1, 5, 10),
(5, 'Patient ID card', '', 4, 6, 7),
(6, 'Advance Directive', '', 1, 11, 18),
(7, 'Do Not Resuscitate Order', '', 6, 12, 13),
(8, 'Durable Power of Attorney', '', 6, 14, 15),
(9, 'Living Will', '', 6, 16, 17),
(10, 'Patient Photograph', '', 4, 8, 9),
(11, 'CCR', '', 1, 19, 20),
(12, 'CCD', '', 1, 21, 22),
(13, 'CCDA', '', 1, 23, 24);

-- --------------------------------------------------------

--
-- Table structure for table `categories_seq`
--

CREATE TABLE `categories_seq` (
  `id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `categories_seq`
--

INSERT INTO `categories_seq` VALUES
(13);

-- --------------------------------------------------------

--
-- Table structure for table `categories_to_documents`
--

CREATE TABLE `categories_to_documents` (
  `category_id` int(11) NOT NULL DEFAULT '0',
  `document_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`category_id`,`document_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `ccda`
--

CREATE TABLE `ccda` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pid` bigint(20) DEFAULT NULL,
  `encounter` bigint(20) DEFAULT NULL,
  `ccda_data` mediumtext,
  `time` varchar(50) DEFAULT NULL,
  `status` smallint(6) DEFAULT NULL,
  `updated_date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `user_id` varchar(50) DEFAULT NULL,
  `couch_docid` varchar(100) DEFAULT NULL,
  `couch_revid` varchar(100) DEFAULT NULL,
  `view` tinyint(4) NOT NULL DEFAULT '0',
  `transfer` tinyint(4) NOT NULL DEFAULT '0',
  `emr_transfer` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_key` (`pid`,`encounter`,`time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `ccda_components`
--

CREATE TABLE `ccda_components` (
  `ccda_components_id` int(11) NOT NULL AUTO_INCREMENT,
  `ccda_components_field` varchar(100) DEFAULT NULL,
  `ccda_components_name` varchar(100) DEFAULT NULL,
  `ccda_type` int(11) NOT NULL COMMENT '0=>sections,1=>components',
  PRIMARY KEY (`ccda_components_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=23 ;

--
-- Dumping data for table `ccda_components`
--

INSERT INTO `ccda_components` VALUES
(1, 'progress_note', 'Progress Notes', 0),
(2, 'consultation_note', 'Consultation Note', 0),
(3, 'continuity_care_document', 'Continuity Care Document', 0),
(4, 'diagnostic_image_reporting', 'Diagnostic Image Reporting', 0),
(5, 'discharge_summary', 'Discharge Summary', 0),
(6, 'history_physical_note', 'History and Physical Note', 0),
(7, 'operative_note', 'Operative Note', 0),
(8, 'procedure_note', 'Procedure Note', 0),
(9, 'unstructured_document', 'Unstructured Document', 0),
(10, 'allergies', 'Allergies', 1),
(11, 'medications', 'Medications', 1),
(12, 'problems', 'Problems', 1),
(13, 'immunizations', 'Immunizations', 1),
(14, 'procedures', 'Procedures', 1),
(15, 'results', 'Results', 1),
(16, 'plan_of_care', 'Plan Of Care', 1),
(17, 'vitals', 'Vitals', 1),
(18, 'social_history', 'Social History', 1),
(19, 'encounters', 'Encounters', 1),
(20, 'functional_status', 'Functional Status', 1),
(21, 'referral', 'Reason for Referral', 1),
(22, 'instructions', 'Instructions', 1);

-- --------------------------------------------------------

--
-- Table structure for table `ccda_field_mapping`
--

CREATE TABLE `ccda_field_mapping` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `table_id` int(11) DEFAULT NULL,
  `ccda_field` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `ccda_sections`
--

CREATE TABLE `ccda_sections` (
  `ccda_sections_id` int(11) NOT NULL AUTO_INCREMENT,
  `ccda_components_id` int(11) DEFAULT NULL,
  `ccda_sections_field` varchar(100) DEFAULT NULL,
  `ccda_sections_name` varchar(100) DEFAULT NULL,
  `ccda_sections_req_mapping` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`ccda_sections_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=46 ;

--
-- Dumping data for table `ccda_sections`
--

INSERT INTO `ccda_sections` VALUES
(1, 1, 'assessment_plan', 'Assessment and Plan', 1),
(2, 2, 'assessment_plan', 'Assessment and Plan', 1),
(3, 2, 'history_of_present_illness', 'History of Present Illness', 1),
(4, 2, 'physical_exam', 'Physical Exam', 1),
(5, 2, 'reason_of_visit', 'Reason for Referral/Reason for Visit', 1),
(6, 3, 'allergies', 'Allergies', 0),
(7, 3, 'medications', 'Medications', 0),
(8, 3, 'problem_list', 'Problem List', 0),
(9, 3, 'procedures', 'Procedures', 0),
(10, 3, 'results', 'Results', 0),
(11, 4, 'report', 'Report', 0),
(12, 5, 'allergies', 'Allergies', 0),
(13, 5, 'hospital_course', 'Hospital Course', 0),
(14, 5, 'hospital_discharge_diagnosis', 'Hospital Discharge Diagnosis', 0),
(15, 5, 'hospital_discharge_medications', 'Hospital Discharge Medications', 0),
(16, 5, 'plan_of_care', 'Plan of Care', 1),
(17, 6, 'allergies', 'Allergies', 0),
(19, 6, 'chief_complaint', 'Chief Complaint / Reason for Visit', 1),
(21, 6, 'family_history', 'Family History', 1),
(22, 6, 'general_status', 'General Status', 1),
(23, 6, 'hpi_past_med', 'History of Past Illness (Past Medical History)', 1),
(24, 6, 'hpi', 'History of Present Illness', 1),
(25, 6, 'medications', 'Medications', 0),
(26, 6, 'physical_exam', 'Physical Exam', 1),
(28, 6, 'results', 'Results', 0),
(29, 6, 'review_of_systems', 'Review of Systems', 1),
(30, 6, 'social_history', 'Social History', 1),
(31, 6, 'vital_signs', 'Vital Signs', 0),
(32, 7, 'anesthesia', 'Anesthesia', 1),
(33, 7, 'complications', 'Complications', 1),
(34, 7, 'post_operative_diagnosis', 'Post Operative Diagnosis', 0),
(35, 7, 'pre_operative_diagnosis', 'Pre Operative Diagnosis', 0),
(36, 7, 'procedure_estimated_blood_loss', 'Procedure Estimated Blood Loss', 0),
(37, 7, 'procedure_findings', 'Procedure Findings', 0),
(38, 7, 'procedure_specimens_taken', 'Procedure Specimens Taken', 0),
(39, 7, 'procedure_description', 'Procedure Description', 1),
(40, 8, 'assessment_plan', 'Assessment and Plan', 1),
(41, 8, 'complications', 'Complications', 1),
(42, 8, 'postprocedure_diagnosis', 'Postprocedure Diagnosis', 0),
(43, 8, 'procedure_description', 'Procedure Description', 0),
(44, 8, 'procedure_indications', 'Procedure Indications', 0),
(45, 9, 'unstructured_doc', 'Document', 0);

-- --------------------------------------------------------

--
-- Table structure for table `ccda_table_mapping`
--

CREATE TABLE `ccda_table_mapping` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `ccda_component` varchar(100) DEFAULT NULL,
  `ccda_component_section` varchar(100) DEFAULT NULL,
  `form_dir` varchar(100) DEFAULT NULL,
  `form_type` smallint(6) DEFAULT NULL,
  `form_table` varchar(100) DEFAULT NULL,
  `user_id` int(11) DEFAULT NULL,
  `deleted` tinyint(4) NOT NULL DEFAULT '0',
  `timestamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `chart_tracker`
--

CREATE TABLE `chart_tracker` (
  `ct_pid` int(11) NOT NULL,
  `ct_when` datetime NOT NULL,
  `ct_userid` bigint(20) NOT NULL DEFAULT '0',
  `ct_location` varchar(31) NOT NULL DEFAULT '',
  PRIMARY KEY (`ct_pid`,`ct_when`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `claims`
--

CREATE TABLE `claims` (
  `patient_id` int(11) NOT NULL,
  `encounter_id` int(11) NOT NULL,
  `version` int(10) unsigned NOT NULL COMMENT 'Claim version, incremented in code',
  `payer_id` int(11) NOT NULL DEFAULT '0',
  `status` tinyint(2) NOT NULL DEFAULT '0',
  `payer_type` tinyint(4) NOT NULL DEFAULT '0',
  `bill_process` tinyint(2) NOT NULL DEFAULT '0',
  `bill_time` datetime DEFAULT NULL,
  `process_time` datetime DEFAULT NULL,
  `process_file` varchar(255) DEFAULT NULL,
  `target` varchar(30) DEFAULT NULL,
  `x12_partner_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`patient_id`,`encounter_id`,`version`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `clinical_plans`
--

CREATE TABLE `clinical_plans` (
  `id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Unique and maps to list_options list clinical_plans',
  `pid` bigint(20) NOT NULL DEFAULT '0' COMMENT '0 is default for all patients, while > 0 is id from patient_data table',
  `normal_flag` tinyint(1) DEFAULT NULL COMMENT 'Normal Activation Flag',
  `cqm_flag` tinyint(1) DEFAULT NULL COMMENT 'Clinical Quality Measure flag (unable to customize per patient)',
  `cqm_2011_flag` tinyint(1) DEFAULT NULL COMMENT '2011 Clinical Quality Measure flag (unable to customize per patient)',
  `cqm_2014_flag` tinyint(1) DEFAULT NULL COMMENT '2014 Clinical Quality Measure flag (unable to customize per patient)',
  `cqm_measure_group` varchar(10) NOT NULL DEFAULT '' COMMENT 'Clinical Quality Measure Group Identifier',
  PRIMARY KEY (`id`,`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `clinical_plans`
--

INSERT INTO `clinical_plans` VALUES
('back_pain_plan_cqm', 0, 0, 1, 1, NULL, 'G'),
('cabg_plan_cqm', 0, 0, 1, 1, NULL, 'H'),
('ckd_plan_cqm', 0, 0, 1, 1, NULL, 'C'),
('dm_plan', 0, 1, 0, NULL, NULL, ''),
('dm_plan_cqm', 0, 0, 1, 1, NULL, 'A'),
('periop_plan_cqm', 0, 0, 1, 1, NULL, 'E'),
('prevent_plan', 0, 1, 0, NULL, NULL, ''),
('prevent_plan_cqm', 0, 0, 1, 1, NULL, 'D'),
('rheum_arth_plan_cqm', 0, 0, 1, 1, NULL, 'F');

-- --------------------------------------------------------

--
-- Table structure for table `clinical_plans_rules`
--

CREATE TABLE `clinical_plans_rules` (
  `plan_id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Unique and maps to list_options list clinical_plans',
  `rule_id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Unique and maps to list_options list clinical_rules',
  PRIMARY KEY (`plan_id`,`rule_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `clinical_plans_rules`
--

INSERT INTO `clinical_plans_rules` VALUES
('dm_plan', 'rule_dm_eye'),
('dm_plan', 'rule_dm_foot'),
('dm_plan', 'rule_dm_hemo_a1c'),
('dm_plan', 'rule_dm_urine_alb'),
('dm_plan_cqm', 'rule_dm_a1c_cqm'),
('dm_plan_cqm', 'rule_dm_bp_control_cqm'),
('dm_plan_cqm', 'rule_dm_eye_cqm'),
('dm_plan_cqm', 'rule_dm_foot_cqm'),
('dm_plan_cqm', 'rule_dm_ldl_cqm'),
('prevent_plan', 'rule_adult_wt_screen_fu'),
('prevent_plan', 'rule_cs_colon'),
('prevent_plan', 'rule_cs_mammo'),
('prevent_plan', 'rule_cs_pap'),
('prevent_plan', 'rule_cs_prostate'),
('prevent_plan', 'rule_htn_bp_measure'),
('prevent_plan', 'rule_influenza_ge_50'),
('prevent_plan', 'rule_pneumovacc_ge_65'),
('prevent_plan', 'rule_tob_cess_inter'),
('prevent_plan', 'rule_tob_use_assess'),
('prevent_plan', 'rule_wt_assess_couns_child'),
('prevent_plan_cqm', 'rule_adult_wt_screen_fu_cqm'),
('prevent_plan_cqm', 'rule_influenza_ge_50_cqm'),
('prevent_plan_cqm', 'rule_pneumovacc_ge_65_cqm');

-- --------------------------------------------------------

--
-- Table structure for table `clinical_rules`
--

CREATE TABLE `clinical_rules` (
  `id` varchar(35) NOT NULL DEFAULT '',
  `pid` bigint(20) NOT NULL DEFAULT '0' COMMENT '0 is default for all patients, while > 0 is id from patient_data table',
  `active_alert_flag` tinyint(1) DEFAULT NULL COMMENT 'Active Alert Widget Module flag - note not yet utilized',
  `passive_alert_flag` tinyint(1) DEFAULT NULL COMMENT 'Passive Alert Widget Module flag',
  `patient_reminder_flag` tinyint(1) DEFAULT NULL COMMENT 'Clinical Reminder Module flag',
  `release_version` varchar(255) NOT NULL DEFAULT '' COMMENT 'Clinical Rule Release Version',
  `web_reference` varchar(255) NOT NULL DEFAULT '' COMMENT 'Clinical Rule Web Reference',
  `access_control` varchar(255) NOT NULL DEFAULT 'patients:med' COMMENT 'ACO link for access control',
  `pqrs_code` varchar(35) DEFAULT NULL COMMENT 'Measure number',
  `pqrs_individual_2016_flag` tinyint(4) DEFAULT NULL COMMENT 'Is MIPS flag',
  `pqrs_group_type` varchar(2) DEFAULT 'X' COMMENT 'XML output scheme type',
  `active` tinyint(4) DEFAULT NULL COMMENT 'Is this measure turned on?'
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `clinical_rules_log`
--

CREATE TABLE `clinical_rules_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `uid` bigint(20) NOT NULL DEFAULT '0',
  `category` varchar(255) NOT NULL DEFAULT '' COMMENT 'An example category is clinical_reminder_widget',
  `value` text NOT NULL,
  `new_value` text NOT NULL,
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`),
  KEY `uid` (`uid`),
  KEY `category` (`category`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `codes`
--

CREATE TABLE `codes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `code_text` varchar(255) NOT NULL DEFAULT '',
  `code_text_short` varchar(24) NOT NULL DEFAULT '',
  `code` varchar(25) NOT NULL DEFAULT '',
  `code_type` smallint(6) DEFAULT NULL,
  `modifier` varchar(12) NOT NULL DEFAULT '',
  `units` int(11) DEFAULT NULL,
  `fee` decimal(12,2) DEFAULT NULL,
  `superbill` varchar(31) NOT NULL DEFAULT '',
  `related_code` varchar(255) NOT NULL DEFAULT '',
  `taxrates` varchar(255) NOT NULL DEFAULT '',
  `cyp_factor` float NOT NULL DEFAULT '0' COMMENT 'quantity representing a years supply',
  `active` tinyint(1) DEFAULT '1' COMMENT '0 = inactive, 1 = active',
  `exclude_from_insurance_billing` tinyint(1) DEFAULT '0' COMMENT '0 = include, 1 = exclude',
  `reportable` tinyint(1) DEFAULT '0' COMMENT '0 = non-reportable, 1 = reportable',
  `financial_reporting` tinyint(1) DEFAULT '0' COMMENT '0 = negative, 1 = considered important code in financial reporting',
  PRIMARY KEY (`id`),
  KEY `code` (`code`),
  KEY `code_type` (`code_type`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=145 ;

--
-- Dumping data for table `codes`
--

INSERT INTO `codes` VALUES
(1, 'diphtheria, tetanus toxoids and pertussis vaccine', 'DTP', '1', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(2, 'poliovirus vaccine, live, oral', 'OPV', '2', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(3, 'measles, mumps and rubella virus vaccine', 'MMR', '3', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(4, 'measles and rubella virus vaccine', 'M/R', '4', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(5, 'measles virus vaccine', 'measles', '5', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(6, 'rubella virus vaccine', 'rubella', '6', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(7, 'mumps virus vaccine', 'mumps', '7', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(8, 'hepatitis B vaccine, pediatric or pediatric/adolescent dosage', 'Hep B, adolescent or ped', '8', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(9, 'tetanus and diphtheria toxoids, adsorbed, for adult use', 'Td (adult), adsorbed', '9', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(10, 'poliovirus vaccine, inactivated', 'IPV', '10', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(11, 'pertussis vaccine', 'pertussis', '11', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(12, 'diphtheria antitoxin', 'diphtheria antitoxin', '12', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(13, 'tetanus immune globulin', 'TIG', '13', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(14, 'immune globulin, unspecified formulation', 'IG, unspecified formulat', '14', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(15, 'influenza virus vaccine, split virus (incl. purified surface antigen)-retired CODE', 'influenza, split (incl. ', '15', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(16, 'influenza virus vaccine, whole virus', 'influenza, whole', '16', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(17, 'Haemophilus influenzae type b vaccine, conjugate unspecified formulation', 'Hib, unspecified formula', '17', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(18, 'rabies vaccine, for intramuscular injection', 'rabies, intramuscular in', '18', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(19, 'Bacillus Calmette-Guerin vaccine', 'BCG', '19', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(20, 'diphtheria, tetanus toxoids and acellular pertussis vaccine', 'DTaP', '20', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(21, 'varicella virus vaccine', 'varicella', '21', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(22, 'DTP-Haemophilus influenzae type b conjugate vaccine', 'DTP-Hib', '22', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(23, 'plague vaccine', 'plague', '23', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(24, 'anthrax vaccine', 'anthrax', '24', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(25, 'typhoid vaccine, live, oral', 'typhoid, oral', '25', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(26, 'cholera vaccine', 'cholera', '26', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(27, 'botulinum antitoxin', 'botulinum antitoxin', '27', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(28, 'diphtheria and tetanus toxoids, adsorbed for pediatric use', 'DT (pediatric)', '28', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(29, 'cytomegalovirus immune globulin, intravenous', 'CMVIG', '29', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(30, 'hepatitis B immune globulin', 'HBIG', '30', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(31, 'hepatitis A vaccine, pediatric dosage, unspecified formulation', 'Hep A, pediatric, unspec', '31', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(32, 'meningococcal polysaccharide vaccine (MPSV4)', 'meningococcal MPSV4', '32', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(33, 'pneumococcal polysaccharide vaccine, 23 valent', 'pneumococcal polysacchar', '33', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(34, 'rabies immune globulin', 'RIG', '34', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(35, 'tetanus toxoid, adsorbed', 'tetanus toxoid, adsorbed', '35', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(36, 'varicella zoster immune globulin', 'VZIG', '36', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(37, 'yellow fever vaccine', 'yellow fever', '37', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(38, 'rubella and mumps virus vaccine', 'rubella/mumps', '38', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(39, 'Japanese Encephalitis Vaccine SC', 'Japanese encephalitis SC', '39', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(40, 'rabies vaccine, for intradermal injection', 'rabies, intradermal inje', '40', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(41, 'typhoid vaccine, parenteral, other than acetone-killed, dried', 'typhoid, parenteral', '41', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(42, 'hepatitis B vaccine, adolescent/high risk infant dosage', 'Hep B, adolescent/high r', '42', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(43, 'hepatitis B vaccine, adult dosage', 'Hep B, adult', '43', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(44, 'hepatitis B vaccine, dialysis patient dosage', 'Hep B, dialysis', '44', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(45, 'hepatitis B vaccine, unspecified formulation', 'Hep B, unspecified formu', '45', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(46, 'Haemophilus influenzae type b vaccine, PRP-D conjugate', 'Hib (PRP-D)', '46', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(47, 'Haemophilus influenzae type b vaccine, HbOC conjugate', 'Hib (HbOC)', '47', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(48, 'Haemophilus influenzae type b vaccine, PRP-T conjugate', 'Hib (PRP-T)', '48', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(49, 'Haemophilus influenzae type b vaccine, PRP-OMP conjugate', 'Hib (PRP-OMP)', '49', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(50, 'DTaP-Haemophilus influenzae type b conjugate vaccine', 'DTaP-Hib', '50', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(51, 'Haemophilus influenzae type b conjugate and Hepatitis B vaccine', 'Hib-Hep B', '51', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(52, 'hepatitis A vaccine, adult dosage', 'Hep A, adult', '52', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(53, 'typhoid vaccine, parenteral, acetone-killed, dried (U.S. military)', 'typhoid, parenteral, AKD', '53', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(54, 'adenovirus vaccine, type 4, live, oral', 'adenovirus, type 4', '54', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(55, 'adenovirus vaccine, type 7, live, oral', 'adenovirus, type 7', '55', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(56, 'dengue fever vaccine', 'dengue fever', '56', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(57, 'hantavirus vaccine', 'hantavirus', '57', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(58, 'hepatitis C vaccine', 'Hep C', '58', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(59, 'hepatitis E vaccine', 'Hep E', '59', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(60, 'herpes simplex virus, type 2 vaccine', 'herpes simplex 2', '60', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(61, 'human immunodeficiency virus vaccine', 'HIV', '61', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(62, 'human papilloma virus vaccine, quadrivalent', 'HPV, quadrivalent', '62', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(63, 'Junin virus vaccine', 'Junin virus', '63', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(64, 'leishmaniasis vaccine', 'leishmaniasis', '64', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(65, 'leprosy vaccine', 'leprosy', '65', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(66, 'Lyme disease vaccine', 'Lyme disease', '66', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(67, 'malaria vaccine', 'malaria', '67', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(68, 'melanoma vaccine', 'melanoma', '68', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(69, 'parainfluenza-3 virus vaccine', 'parainfluenza-3', '69', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(70, 'Q fever vaccine', 'Q fever', '70', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(71, 'respiratory syncytial virus immune globulin, intravenous', 'RSV-IGIV', '71', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(72, 'rheumatic fever vaccine', 'rheumatic fever', '72', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(73, 'Rift Valley fever vaccine', 'Rift Valley fever', '73', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(74, 'rotavirus, live, tetravalent vaccine', 'rotavirus, tetravalent', '74', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(75, 'vaccinia (smallpox) vaccine', 'vaccinia (smallpox)', '75', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(76, 'Staphylococcus bacteriophage lysate', 'Staphylococcus bacterio ', '76', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(77, 'tick-borne encephalitis vaccine', 'tick-borne encephalitis', '77', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(78, 'tularemia vaccine', 'tularemia vaccine', '78', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(79, 'vaccinia immune globulin', 'vaccinia immune globulin', '79', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(80, 'Venezuelan equine encephalitis, live, attenuated', 'VEE, live', '80', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(81, 'Venezuelan equine encephalitis, inactivated', 'VEE, inactivated', '81', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(82, 'adenovirus vaccine, unspecified formulation', 'adenovirus, unspecified ', '82', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(83, 'hepatitis A vaccine, pediatric/adolescent dosage, 2 dose schedule', 'Hep A, ped/adol, 2 dose', '83', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(84, 'hepatitis A vaccine, pediatric/adolescent dosage, 3 dose schedule', 'Hep A, ped/adol, 3 dose', '84', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(85, 'hepatitis A vaccine, unspecified formulation', 'Hep A, unspecified formu', '85', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(86, 'immune globulin, intramuscular', 'IG', '86', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(87, 'immune globulin, intravenous', 'IGIV', '87', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(88, 'influenza virus vaccine, unspecified formulation', 'influenza, unspecified f', '88', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(89, 'poliovirus vaccine, unspecified formulation', 'polio, unspecified formu', '89', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(90, 'rabies vaccine, unspecified formulation', 'rabies, unspecified form', '90', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(91, 'typhoid vaccine, unspecified formulation', 'typhoid, unspecified for', '91', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(92, 'Venezuelan equine encephalitis vaccine, unspecified formulation', 'VEE, unspecified formula', '92', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(93, 'respiratory syncytial virus monoclonal antibody (palivizumab), intramuscular', 'RSV-MAb', '93', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(94, 'measles, mumps, rubella, and varicella virus vaccine', 'MMRV', '94', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(95, 'tuberculin skin test; old tuberculin, multipuncture device', 'TST-OT tine test', '95', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(96, 'tuberculin skin test; purified protein derivative solution, intradermal', 'TST-PPD intradermal', '96', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(97, 'tuberculin skin test; purified protein derivative, multipuncture device', 'TST-PPD tine test', '97', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(98, 'tuberculin skin test; unspecified formulation', 'TST, unspecified formula', '98', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(99, 'RESERVED - do not use', 'RESERVED - do not use', '99', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(100, 'pneumococcal conjugate vaccine, 7 valent', 'pneumococcal conjugate P', '100', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(101, 'typhoid Vi capsular polysaccharide vaccine', 'typhoid, ViCPs', '101', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(102, 'DTP- Haemophilus influenzae type b conjugate and hepatitis b vaccine', 'DTP-Hib-Hep B', '102', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(103, 'meningococcal C conjugate vaccine', 'meningococcal C conjugat', '103', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(104, 'hepatitis A and hepatitis B vaccine', 'Hep A-Hep B', '104', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(105, 'vaccinia (smallpox) vaccine, diluted', 'vaccinia (smallpox) dilu', '105', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(106, 'diphtheria, tetanus toxoids and acellular pertussis vaccine, 5 pertussis antigens', 'DTaP, 5 pertussis antige', '106', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(107, 'diphtheria, tetanus toxoids and acellular pertussis vaccine, unspecified formulation', 'DTaP, unspecified formul', '107', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(108, 'meningococcal vaccine, unspecified formulation', 'meningococcal, unspecifi', '108', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(109, 'pneumococcal vaccine, unspecified formulation', 'pneumococcal, unspecifie', '109', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(110, 'DTaP-hepatitis B and poliovirus vaccine', 'DTaP-Hep B-IPV', '110', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(111, 'influenza virus vaccine, live, attenuated, for intranasal use', 'influenza, live, intrana', '111', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(112, 'tetanus toxoid, unspecified formulation', 'tetanus toxoid, unspecif', '112', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(113, 'tetanus and diphtheria toxoids, adsorbed, preservative free, for adult use', 'Td (adult) preservative ', '113', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(114, 'meningococcal polysaccharide (groups A, C, Y and W-135) diphtheria toxoid conjugate vaccine (MCV4P)', 'meningococcal MCV4P', '114', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(115, 'tetanus toxoid, reduced diphtheria toxoid, and acellular pertussis vaccine, adsorbed', 'Tdap', '115', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(116, 'rotavirus, live, pentavalent vaccine', 'rotavirus, pentavalent', '116', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(117, 'varicella zoster immune globulin (Investigational New Drug)', 'VZIG (IND)', '117', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(118, 'human papilloma virus vaccine, bivalent', 'HPV, bivalent', '118', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(119, 'rotavirus, live, monovalent vaccine', 'rotavirus, monovalent', '119', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(120, 'diphtheria, tetanus toxoids and acellular pertussis vaccine, Haemophilus influenzae type b conjugate, and poliovirus vaccine, inactivated (DTaP-Hib-IPV)', 'DTaP-Hib-IPV', '120', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(121, 'zoster vaccine, live', 'zoster', '121', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(122, 'rotavirus vaccine, unspecified formulation', 'rotavirus, unspecified f', '122', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(123, 'influenza virus vaccine, H5N1, A/Vietnam/1203/2004 (national stockpile)', 'influenza, H5N1-1203', '123', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(124, 'Novel Influenza-H1N1-09, live virus for nasal administration', 'Novel Influenza-H1N1-09,', '125', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(125, 'Novel influenza-H1N1-09, preservative-free, injectable', 'Novel influenza-H1N1-09,', '126', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(126, 'Novel influenza-H1N1-09, injectable', 'Novel influenza-H1N1-09', '127', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(127, 'Novel influenza-H1N1-09, all formulations', 'Novel Influenza-H1N1-09,', '128', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(128, 'Japanese Encephalitis vaccine, unspecified formulation', 'Japanese Encephalitis, u', '129', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(129, 'Diphtheria, tetanus toxoids and acellular pertussis vaccine, and poliovirus vaccine, inactivated', 'DTaP-IPV', '130', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(130, 'Historical record of a typhus vaccination', 'typhus, historical', '131', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(131, 'Historical record of vaccine containing, diphtheria, tetanus toxoids and acellular pertussis, poliovirus, inactivated, Haemophilus influenzae type b conjugate, Hepatitis B (DTaP-Hib-IPV)', 'DTaP-IPV-HIB-HEP B, hist', '132', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(132, 'pneumococcal conjugate vaccine, 13 valent', 'Pneumococcal conjugate P', '133', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(133, 'Japanese Encephalitis vaccine for intramuscular administration', 'Japanese Encephalitis IM', '134', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(134, 'influenza, high dose seasonal, preservative-free', 'Influenza, high dose sea', '135', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(135, 'meningococcal oligosaccharide (groups A, C, Y and W-135) diphtheria toxoid conjugate vaccine (MCV4O)', 'Meningococcal MCV4O', '136', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(136, 'HPV, unspecified formulation', 'HPV, unspecified formula', '137', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(137, 'tetanus and diphtheria toxoids, not adsorbed, for adult use', 'Td (adult)', '138', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(138, 'Td(adult) unspecified formulation', 'Td(adult) unspecified fo', '139', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(139, 'Influenza, seasonal, injectable, preservative free', 'Influenza, seasonal, inj', '140', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(140, 'Influenza, seasonal, injectable', 'Influenza, seasonal, inj', '141', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(141, 'tetanus toxoid, not adsorbed', 'tetanus toxoid, not adso', '142', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(142, 'Adenovirus, type 4 and type 7, live, oral', 'Adenovirus types 4 and 7', '143', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(143, 'no vaccine administered', 'no vaccine administered', '998', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0),
(144, 'unknown vaccine or immune globulin', 'unknown', '999', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `code_types`
--

CREATE TABLE `code_types` (
  `ct_key` varchar(15) NOT NULL COMMENT 'short alphanumeric name',
  `ct_id` int(11) NOT NULL COMMENT 'numeric identifier',
  `ct_seq` int(11) NOT NULL DEFAULT '0' COMMENT 'sort order',
  `ct_mod` int(11) NOT NULL DEFAULT '0' COMMENT 'length of modifier field',
  `ct_just` varchar(15) NOT NULL DEFAULT '' COMMENT 'ct_key of justify type, if any',
  `ct_mask` varchar(9) NOT NULL DEFAULT '' COMMENT 'formatting mask for code values',
  `ct_fee` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if fees are used',
  `ct_rel` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if can relate to other code types',
  `ct_nofs` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if to be hidden in the fee sheet',
  `ct_diag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is a diagnosis type',
  `ct_active` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1 if this is active',
  `ct_label` varchar(31) NOT NULL DEFAULT '' COMMENT 'label of this code type',
  `ct_external` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 if stored codes in codes tables, 1 or greater if codes stored in external tables',
  `ct_claim` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is used in claims',
  `ct_proc` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is a procedure type',
  `ct_term` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is a clinical term',
  `ct_problem` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this code type is used as a medical problem',
  `ct_drug` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this code type is used as a medication',
  PRIMARY KEY (`ct_key`),
  UNIQUE KEY `ct_id` (`ct_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `code_types`
--

INSERT INTO `code_types` VALUES
('CPT4', 1, 2, 12, 'ICD9', '', 1, 0, 0, 0, 1, 'CPT4 Procedure/Service', 0, 1, 1, 0, 0, 0),
('CPTII', 104, 104, 0, 'ICD9', '', 0, 0, 0, 0, 0, 'CPTII Performance Measures', 0, 1, 0, 0, 0, 0),
('CVX', 100, 100, 0, '', '', 0, 0, 1, 0, 1, 'CVX Immunization', 0, 0, 0, 0, 0, 0),
('DSMIV', 101, 101, 0, '', '', 0, 0, 0, 1, 0, 'DSMIV Diagnosis', 0, 1, 0, 0, 1, 0),
('HCPCS', 3, 3, 12, 'ICD9', '', 1, 0, 0, 0, 1, 'HCPCS Procedure/Service', 0, 1, 1, 0, 0, 0),
('ICD10', 102, 102, 0, '', '', 0, 0, 0, 1, 1, 'ICD10 Diagnosis', 1, 1, 0, 0, 1, 0),
('ICD10-PCS', 106, 106, 12, 'ICD10', '', 1, 0, 0, 0, 0, 'ICD10 Procedure/Service', 6, 1, 1, 0, 0, 0),
('ICD9', 2, 1, 0, '', '', 0, 0, 0, 1, 1, 'ICD9 Diagnosis', 4, 1, 0, 0, 1, 0),
('ICD9-SG', 105, 105, 12, 'ICD9', '', 1, 0, 0, 0, 0, 'ICD9 Procedure/Service', 5, 1, 1, 0, 0, 0),
('LOINC', 110, 110, 0, '', '', 0, 0, 1, 0, 1, 'LOINC', 0, 0, 0, 0, 0, 0),
('PHIN Questions', 111, 111, 0, '', '', 0, 0, 1, 0, 1, 'PHIN Questions', 0, 0, 0, 0, 0, 0),
('RXCUI', 109, 109, 0, '', '', 0, 0, 1, 0, 0, 'RXCUI Medication', 0, 0, 0, 0, 0, 1),
('SNOMED', 103, 103, 0, '', '', 0, 0, 0, 1, 0, 'SNOMED Diagnosis', 2, 1, 0, 0, 1, 0),
('SNOMED-CT', 107, 107, 0, '', '', 0, 0, 1, 0, 0, 'SNOMED Clinical Term', 7, 0, 0, 1, 0, 0),
('SNOMED-PR', 108, 108, 0, 'SNOMED', '', 1, 0, 0, 0, 0, 'SNOMED Procedure', 9, 1, 1, 0, 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `config`
--

CREATE TABLE `config` (
  `id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `value` varchar(255) DEFAULT NULL,
  `parent` int(11) NOT NULL DEFAULT '0',
  `lft` int(11) NOT NULL DEFAULT '0',
  `rght` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `parent` (`parent`),
  KEY `lft` (`lft`,`rght`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `config_seq`
--

CREATE TABLE `config_seq` (
  `id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `config_seq`
--

INSERT INTO `config_seq` VALUES
(0);

-- --------------------------------------------------------

--
-- Table structure for table `dated_reminders`
--

CREATE TABLE `dated_reminders` (
  `dr_id` int(11) NOT NULL AUTO_INCREMENT,
  `dr_from_ID` int(11) NOT NULL,
  `dr_message_text` varchar(160) NOT NULL,
  `dr_message_sent_date` datetime NOT NULL,
  `dr_message_due_date` date NOT NULL,
  `pid` int(11) NOT NULL,
  `message_priority` tinyint(1) NOT NULL,
  `message_processed` tinyint(1) NOT NULL DEFAULT '0',
  `processed_date` timestamp NULL DEFAULT NULL,
  `dr_processed_by` int(11) NOT NULL,
  PRIMARY KEY (`dr_id`),
  KEY `dr_from_ID` (`dr_from_ID`,`dr_message_due_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `dated_reminders_link`
--

CREATE TABLE `dated_reminders_link` (
  `dr_link_id` int(11) NOT NULL AUTO_INCREMENT,
  `dr_id` int(11) NOT NULL,
  `to_id` int(11) NOT NULL,
  PRIMARY KEY (`dr_link_id`),
  KEY `to_id` (`to_id`),
  KEY `dr_id` (`dr_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `direct_message_log`
--

CREATE TABLE `direct_message_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `msg_type` char(1) NOT NULL COMMENT 'S=sent,R=received',
  `msg_id` varchar(127) NOT NULL,
  `sender` varchar(255) NOT NULL,
  `recipient` varchar(255) NOT NULL,
  `create_ts` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `status` char(1) NOT NULL COMMENT 'Q=queued,D=dispatched,R=received,F=failed',
  `status_info` varchar(511) DEFAULT NULL,
  `status_ts` timestamp NULL DEFAULT NULL,
  `patient_id` bigint(20) DEFAULT NULL,
  `user_id` bigint(20) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `msg_id` (`msg_id`),
  KEY `patient_id` (`patient_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `documents`
--

CREATE TABLE `documents` (
  `id` int(11) NOT NULL DEFAULT '0',
  `type` enum('file_url','blob','web_url') DEFAULT NULL,
  `size` int(11) DEFAULT NULL,
  `date` datetime DEFAULT NULL,
  `url` varchar(255) DEFAULT NULL,
  `mimetype` varchar(255) DEFAULT NULL,
  `pages` int(11) DEFAULT NULL,
  `owner` int(11) DEFAULT NULL,
  `revision` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `foreign_id` int(11) DEFAULT NULL,
  `docdate` date DEFAULT NULL,
  `hash` varchar(40) DEFAULT NULL COMMENT '40-character SHA-1 hash of document',
  `list_id` bigint(20) NOT NULL DEFAULT '0',
  `couch_docid` varchar(100) DEFAULT NULL,
  `couch_revid` varchar(100) DEFAULT NULL,
  `storagemethod` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0->Harddisk,1->CouchDB',
  `path_depth` tinyint(4) DEFAULT '1' COMMENT 'Depth of path to use in url to find document. Not applicable for CouchDB.',
  `imported` tinyint(4) DEFAULT '0' COMMENT 'Parsing status for CCR/CCD/CCDA importing',
  `encounter_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'Encounter id if tagged',
  `encounter_check` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'If encounter is created while tagging',
  `audit_master_approval_status` tinyint(4) NOT NULL DEFAULT '1' COMMENT 'approval_status from audit_master table',
  `audit_master_id` int(11) DEFAULT NULL,
  `documentationOf` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `revision` (`revision`),
  KEY `foreign_id` (`foreign_id`),
  KEY `owner` (`owner`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `documents_legal_categories`
--

CREATE TABLE `documents_legal_categories` (
  `dlc_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `dlc_category_type` int(10) unsigned NOT NULL COMMENT '1 category 2 subcategory',
  `dlc_category_name` varchar(45) NOT NULL,
  `dlc_category_parent` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`dlc_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=7 ;

--
-- Dumping data for table `documents_legal_categories`
--

INSERT INTO `documents_legal_categories` VALUES
(3, 1, 'Category', NULL),
(4, 2, 'Sub Category', 1),
(5, 1, 'Layout Form', 0),
(6, 2, 'Layout Signed', 5);

-- --------------------------------------------------------

--
-- Table structure for table `documents_legal_detail`
--

CREATE TABLE `documents_legal_detail` (
  `dld_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `dld_pid` int(10) unsigned DEFAULT NULL,
  `dld_facility` int(10) unsigned DEFAULT NULL,
  `dld_provider` int(10) unsigned DEFAULT NULL,
  `dld_encounter` int(10) unsigned DEFAULT NULL,
  `dld_master_docid` int(10) unsigned NOT NULL,
  `dld_signed` smallint(5) unsigned NOT NULL COMMENT '0-Not Signed or Cannot Sign(Layout),1-Signed,2-Ready to sign,3-Denied(Pat Regi),4-Patient Upload,10-Save(Layout)',
  `dld_signed_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `dld_filepath` varchar(75) DEFAULT NULL,
  `dld_filename` varchar(45) NOT NULL,
  `dld_signing_person` varchar(50) NOT NULL,
  `dld_sign_level` int(11) NOT NULL COMMENT 'Sign flow level',
  `dld_content` varchar(50) NOT NULL COMMENT 'Layout sign position',
  `dld_file_for_pdf_generation` blob NOT NULL COMMENT 'The filled details in the fdf file is stored here.Patient Registration Screen',
  `dld_denial_reason` longtext,
  `dld_moved` tinyint(4) NOT NULL DEFAULT '0',
  `dld_patient_comments` text COMMENT 'Patient comments stored here',
  PRIMARY KEY (`dld_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `documents_legal_master`
--

CREATE TABLE `documents_legal_master` (
  `dlm_category` int(10) unsigned DEFAULT NULL,
  `dlm_subcategory` int(10) unsigned DEFAULT NULL,
  `dlm_document_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `dlm_document_name` varchar(75) NOT NULL,
  `dlm_filepath` varchar(75) NOT NULL,
  `dlm_facility` int(10) unsigned DEFAULT NULL,
  `dlm_provider` int(10) unsigned DEFAULT NULL,
  `dlm_sign_height` double NOT NULL,
  `dlm_sign_width` double NOT NULL,
  `dlm_filename` varchar(45) NOT NULL,
  `dlm_effective_date` datetime NOT NULL,
  `dlm_version` int(10) unsigned NOT NULL,
  `content` varchar(255) NOT NULL,
  `dlm_savedsign` varchar(255) DEFAULT NULL COMMENT '0-Yes 1-No',
  `dlm_review` varchar(255) DEFAULT NULL COMMENT '0-Yes 1-No',
  `dlm_upload_type` tinyint(4) DEFAULT '0' COMMENT '0-Provider Uploaded,1-Patient Uploaded',
  PRIMARY KEY (`dlm_document_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='List of Master Docs to be signed' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `drugs`
--

CREATE TABLE `drugs` (
  `drug_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL DEFAULT '',
  `ndc_number` varchar(20) NOT NULL DEFAULT '',
  `on_order` int(11) NOT NULL DEFAULT '0',
  `reorder_point` float NOT NULL DEFAULT '0',
  `max_level` float NOT NULL DEFAULT '0',
  `last_notify` date NOT NULL DEFAULT '0000-00-00',
  `reactions` text,
  `form` int(3) NOT NULL DEFAULT '0',
  `size` float unsigned NOT NULL DEFAULT '0',
  `unit` int(11) NOT NULL DEFAULT '0',
  `route` int(11) NOT NULL DEFAULT '0',
  `substitute` int(11) NOT NULL DEFAULT '0',
  `related_code` varchar(255) NOT NULL DEFAULT '' COMMENT 'may reference a related codes.code',
  `cyp_factor` float NOT NULL DEFAULT '0' COMMENT 'quantity representing a years supply',
  `active` tinyint(1) DEFAULT '1' COMMENT '0 = inactive, 1 = active',
  `allow_combining` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 = allow filling an order from multiple lots',
  `allow_multiple` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1 = allow multiple lots at one warehouse',
  `drug_code` varchar(25) DEFAULT NULL,
  PRIMARY KEY (`drug_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `drug_inventory`
--

CREATE TABLE `drug_inventory` (
  `inventory_id` int(11) NOT NULL AUTO_INCREMENT,
  `drug_id` int(11) NOT NULL,
  `lot_number` varchar(20) DEFAULT NULL,
  `expiration` date DEFAULT NULL,
  `manufacturer` varchar(255) DEFAULT NULL,
  `on_hand` int(11) NOT NULL DEFAULT '0',
  `warehouse_id` varchar(31) NOT NULL DEFAULT '',
  `vendor_id` bigint(20) NOT NULL DEFAULT '0',
  `last_notify` date NOT NULL DEFAULT '0000-00-00',
  `destroy_date` date DEFAULT NULL,
  `destroy_method` varchar(255) DEFAULT NULL,
  `destroy_witness` varchar(255) DEFAULT NULL,
  `destroy_notes` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`inventory_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `drug_sales`
--

CREATE TABLE `drug_sales` (
  `sale_id` int(11) NOT NULL AUTO_INCREMENT,
  `drug_id` int(11) NOT NULL,
  `inventory_id` int(11) NOT NULL,
  `prescription_id` int(11) NOT NULL DEFAULT '0',
  `pid` int(11) NOT NULL DEFAULT '0',
  `encounter` int(11) NOT NULL DEFAULT '0',
  `user` varchar(255) DEFAULT NULL,
  `sale_date` date NOT NULL,
  `quantity` int(11) NOT NULL DEFAULT '0',
  `fee` decimal(12,2) NOT NULL DEFAULT '0.00',
  `billed` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'indicates if the sale is posted to accounting',
  `xfer_inventory_id` int(11) NOT NULL DEFAULT '0',
  `distributor_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references users.id',
  `notes` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`sale_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `drug_templates`
--

CREATE TABLE `drug_templates` (
  `drug_id` int(11) NOT NULL,
  `selector` varchar(255) NOT NULL DEFAULT '',
  `dosage` varchar(10) DEFAULT NULL,
  `period` int(11) NOT NULL DEFAULT '0',
  `quantity` int(11) NOT NULL DEFAULT '0',
  `refills` int(11) NOT NULL DEFAULT '0',
  `taxrates` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`drug_id`,`selector`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `eligibility_response`
--

CREATE TABLE `eligibility_response` (
  `response_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `response_description` varchar(255) DEFAULT NULL,
  `response_status` enum('A','D') NOT NULL DEFAULT 'A',
  `response_vendor_id` bigint(20) DEFAULT NULL,
  `response_create_date` date DEFAULT NULL,
  `response_modify_date` date DEFAULT NULL,
  PRIMARY KEY (`response_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `eligibility_verification`
--

CREATE TABLE `eligibility_verification` (
  `verification_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `response_id` bigint(20) DEFAULT NULL,
  `insurance_id` bigint(20) DEFAULT NULL,
  `eligibility_check_date` datetime DEFAULT NULL,
  `copay` int(11) DEFAULT NULL,
  `deductible` int(11) DEFAULT NULL,
  `deductiblemet` enum('Y','N') DEFAULT 'Y',
  `create_date` date DEFAULT NULL,
  PRIMARY KEY (`verification_id`),
  KEY `insurance_id` (`insurance_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `employer_data`
--

CREATE TABLE `employer_data` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) DEFAULT NULL,
  `street` varchar(255) DEFAULT NULL,
  `postal_code` varchar(255) DEFAULT NULL,
  `city` varchar(255) DEFAULT NULL,
  `state` varchar(255) DEFAULT NULL,
  `country` varchar(255) DEFAULT NULL,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `enc_category_map`
--

CREATE TABLE `enc_category_map` (
  `rule_enc_id` varchar(31) NOT NULL DEFAULT '' COMMENT 'encounter id from rule_enc_types list in list_options',
  `main_cat_id` int(11) NOT NULL DEFAULT '0' COMMENT 'category id from event category in libreehr_postcalendar_categories',
  KEY `rule_enc_id` (`rule_enc_id`,`main_cat_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `enc_category_map`
--

INSERT INTO `enc_category_map` VALUES
('enc_acute_inp_or_ed', 5),
('enc_acute_inp_or_ed', 9),
('enc_acute_inp_or_ed', 10),
('enc_hea_and_beh', 5),
('enc_hea_and_beh', 9),
('enc_hea_and_beh', 10),
('enc_influenza', 5),
('enc_influenza', 9),
('enc_influenza', 10),
('enc_nonac_inp_out_or_opth', 5),
('enc_nonac_inp_out_or_opth', 9),
('enc_nonac_inp_out_or_opth', 10),
('enc_nurs_discharge', 5),
('enc_nurs_discharge', 9),
('enc_nurs_discharge', 10),
('enc_nurs_fac', 5),
('enc_nurs_fac', 9),
('enc_nurs_fac', 10),
('enc_occ_ther', 5),
('enc_occ_ther', 9),
('enc_occ_ther', 10),
('enc_off_vis', 5),
('enc_off_vis', 9),
('enc_off_vis', 10),
('enc_ophthal_serv', 14),
('enc_outpatient', 5),
('enc_outpatient', 9),
('enc_outpatient', 10),
('enc_out_pcp_obgyn', 5),
('enc_out_pcp_obgyn', 9),
('enc_out_pcp_obgyn', 10),
('enc_pregnancy', 5),
('enc_pregnancy', 9),
('enc_pregnancy', 10),
('enc_pre_ind_counsel', 5),
('enc_pre_ind_counsel', 9),
('enc_pre_ind_counsel', 10),
('enc_pre_med_group_counsel', 5),
('enc_pre_med_group_counsel', 9),
('enc_pre_med_group_counsel', 10),
('enc_pre_med_other_serv', 5),
('enc_pre_med_other_serv', 9),
('enc_pre_med_other_serv', 10),
('enc_pre_med_ser_18_older', 5),
('enc_pre_med_ser_18_older', 9),
('enc_pre_med_ser_18_older', 10),
('enc_pre_med_ser_40_older', 5),
('enc_pre_med_ser_40_older', 9),
('enc_pre_med_ser_40_older', 10),
('enc_psych_and_psych', 5),
('enc_psych_and_psych', 9),
('enc_psych_and_psych', 10);

-- --------------------------------------------------------

--
-- Table structure for table `erx_ttl_touch`
--

CREATE TABLE `erx_ttl_touch` (
  `patient_id` bigint(20) unsigned NOT NULL COMMENT 'Patient record Id',
  `process` enum('allergies','medications') NOT NULL COMMENT 'NewCrop eRx SOAP process',
  `updated` datetime NOT NULL COMMENT 'Date and time of last process update for patient',
  PRIMARY KEY (`patient_id`,`process`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Store records last update per patient data process';

-- --------------------------------------------------------

--
-- Table structure for table `esign_signatures`
--

CREATE TABLE `esign_signatures` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `tid` int(11) NOT NULL COMMENT 'Table row ID for signature',
  `table` varchar(255) NOT NULL COMMENT 'table name for the signature',
  `uid` int(11) NOT NULL COMMENT 'user id for the signing user',
  `datetime` datetime NOT NULL COMMENT 'datetime of the signature action',
  `is_lock` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'sig, lock or amendment',
  `amendment` text COMMENT 'amendment text, if any',
  `hash` varchar(255) NOT NULL COMMENT 'hash of signed data',
  `signature_hash` varchar(255) NOT NULL COMMENT 'hash of signature itself',
  PRIMARY KEY (`id`),
  KEY `tid` (`tid`),
  KEY `table` (`table`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `extended_log`
--

CREATE TABLE `extended_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `event` varchar(255) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `recipient` varchar(255) DEFAULT NULL,
  `description` longtext,
  `patient_id` bigint(20) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `patient_id` (`patient_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `external_encounters`
--

CREATE TABLE `external_encounters` (
  `ee_id` int(11) NOT NULL AUTO_INCREMENT,
  `ee_date` date DEFAULT NULL,
  `ee_pid` int(11) DEFAULT NULL,
  `ee_provider_id` varchar(255) DEFAULT NULL,
  `ee_facility_id` varchar(255) DEFAULT NULL,
  `ee_encounter_diagnosis` varchar(255) DEFAULT NULL,
  `ee_external_id` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`ee_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `external_procedures`
--

CREATE TABLE `external_procedures` (
  `ep_id` int(11) NOT NULL AUTO_INCREMENT,
  `ep_date` date DEFAULT NULL,
  `ep_code_type` varchar(20) DEFAULT NULL,
  `ep_code` varchar(9) DEFAULT NULL,
  `ep_pid` int(11) DEFAULT NULL,
  `ep_encounter` int(11) DEFAULT NULL,
  `ep_code_text` longtext,
  `ep_facility_id` varchar(255) DEFAULT NULL,
  `ep_external_id` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`ep_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `facility`
--

CREATE TABLE `facility` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) DEFAULT NULL,
  `alias` varchar(60) DEFAULT NULL,
  `phone` varchar(30) DEFAULT NULL,
  `fax` varchar(30) DEFAULT NULL,
  `street` varchar(255) DEFAULT NULL,
  `city` varchar(255) DEFAULT NULL,
  `state` varchar(50) DEFAULT NULL,
  `postal_code` varchar(11) DEFAULT NULL,
  `country_code` varchar(10) DEFAULT NULL,
  `federal_ein` varchar(15) DEFAULT NULL,
  `website` varchar(255) DEFAULT NULL,
  `email` varchar(255) DEFAULT NULL,
  `service_location` tinyint(1) NOT NULL DEFAULT '1',
  `billing_location` tinyint(1) NOT NULL DEFAULT '0',
  `accepts_assignment` tinyint(1) NOT NULL DEFAULT '0',
  `pos_code` tinyint(4) DEFAULT NULL,
  `x12_sender_id` varchar(25) DEFAULT NULL,
  `attn` varchar(65) DEFAULT NULL,
  `domain_identifier` varchar(60) DEFAULT NULL,
  `facility_npi` varchar(15) DEFAULT NULL,
  `tax_id_type` varchar(31) NOT NULL DEFAULT '',
  `color` varchar(7) NOT NULL DEFAULT '',
  `primary_business_entity` int(10) NOT NULL DEFAULT '0' COMMENT '0-Not Set as business entity 1-Set as business entity',
  `facility_code` varchar(31) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `facility`
--

INSERT INTO `facility` VALUES
(3, 'Your Clinic Name Here', 'Your Clinic Name Here', '000-000-0000', '000-000-0000', '', '', '', '', '', '', NULL, NULL, 1, 1, 0, NULL, '', '', '', '', '', '#99FFFF', 0, '');

-- --------------------------------------------------------

--
-- Table structure for table `facility_user_ids`
--

CREATE TABLE `facility_user_ids` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `uid` bigint(20) DEFAULT NULL,
  `facility_id` bigint(20) DEFAULT NULL,
  `field_id` varchar(31) NOT NULL COMMENT 'references layout_options.field_id',
  `field_value` text,
  PRIMARY KEY (`id`),
  KEY `uid` (`uid`,`facility_id`,`field_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `fee_sheet_options`
--

CREATE TABLE `fee_sheet_options` (
  `fs_category` varchar(63) DEFAULT NULL,
  `fs_option` varchar(63) DEFAULT NULL,
  `fs_codes` varchar(255) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `fee_sheet_options`
--

INSERT INTO `fee_sheet_options` VALUES
('1New Patient', '1Brief', 'CPT4|99201|'),
('1New Patient', '2Limited', 'CPT4|99202|'),
('1New Patient', '3Detailed', 'CPT4|99203|'),
('1New Patient', '4Extended', 'CPT4|99204|'),
('1New Patient', '5Comprehensive', 'CPT4|99205|'),
('2Established Patient', '1Brief', 'CPT4|99211|'),
('2Established Patient', '2Limited', 'CPT4|99212|'),
('2Established Patient', '3Detailed', 'CPT4|99213|'),
('2Established Patient', '4Extended', 'CPT4|99214|'),
('2Established Patient', '5Comprehensive', 'CPT4|99215|');

-- --------------------------------------------------------

--
-- Table structure for table `forms`
--

CREATE TABLE `forms` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `encounter` bigint(20) DEFAULT NULL,
  `form_name` longtext,
  `form_id` bigint(20) DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `deleted` tinyint(4) NOT NULL DEFAULT '0' COMMENT 'flag indicates form has been deleted',
  `formdir` longtext,
  PRIMARY KEY (`id`),
  KEY `pid_encounter` (`pid`,`encounter`),
  KEY `form_id` (`form_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_annotate_diagram`
--

CREATE TABLE `form_annotate_diagram` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT '1',
  `data` text,
  `imagedata` varchar(255) DEFAULT 'NEW',
  `dyntitle` varchar(255) DEFAULT 'Annotated Diagram',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_care_plan`
--

CREATE TABLE `form_care_plan` (
  `id` bigint(20) NOT NULL,
  `date` date DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `encounter` varchar(255) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `code` varchar(255) DEFAULT NULL,
  `codetext` text,
  `description` text,
  `external_id` varchar(30) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `form_clinical_instructions`
--

CREATE TABLE `form_clinical_instructions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pid` bigint(20) DEFAULT NULL,
  `encounter` varchar(255) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `instruction` text,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `activity` tinyint(4) DEFAULT '1',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_dictation`
--

CREATE TABLE `form_dictation` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `dictation` longtext,
  `additional_notes` longtext,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_encounter`
--

CREATE TABLE `form_encounter` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `reason` longtext,
  `facility` longtext,
  `facility_id` int(11) NOT NULL DEFAULT '0',
  `pid` bigint(20) DEFAULT NULL,
  `encounter` bigint(20) DEFAULT NULL,
  `onset_date` datetime DEFAULT NULL,
  `sensitivity` varchar(30) DEFAULT NULL,
  `billing_note` text,
  `pc_catid` int(11) NOT NULL DEFAULT '5' COMMENT 'event category from libreehr_postcalendar_categories',
  `last_level_billed` int(11) NOT NULL DEFAULT '0' COMMENT '0=none, 1=ins1, 2=ins2, etc',
  `last_level_closed` int(11) NOT NULL DEFAULT '0' COMMENT '0=none, 1=ins1, 2=ins2, etc',
  `last_stmt_date` date DEFAULT NULL,
  `stmt_count` int(11) NOT NULL DEFAULT '0',
  `provider_id` int(11) DEFAULT '0' COMMENT 'default and main provider for this visit',
  `supervisor_id` int(11) DEFAULT '0' COMMENT 'supervising provider, if any, for this visit',
  `ordering_physician` int(11) DEFAULT '0' COMMENT 'ordering provider , if any, for this visit',
  `referring_physician` int(11) DEFAULT '0' COMMENT 'referring provider, if any, for this visit',
  `contract_physician` int(11) DEFAULT '0' COMMENT 'contract provider, if any, for this visit',
  `invoice_refno` varchar(31) NOT NULL DEFAULT '',
  `referral_source` varchar(31) NOT NULL DEFAULT '',
  `billing_facility` int(11) NOT NULL DEFAULT '0',
  `external_id` varchar(20) DEFAULT NULL,
  `eft_number` varchar(80) DEFAULT NULL,
  `claim_number` varchar(80) DEFAULT NULL,
  `document_image` varchar(80) DEFAULT NULL,
  `seq_number` varchar(80) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `pid_encounter` (`pid`,`encounter`),
  KEY `encounter_date` (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_functional_cognitive_status`
--

CREATE TABLE `form_functional_cognitive_status` (
  `id` bigint(20) NOT NULL,
  `date` date DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `encounter` varchar(255) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `code` varchar(255) DEFAULT NULL,
  `codetext` text,
  `description` text,
  `external_id` varchar(30) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `form_misc_billing_options`
--

CREATE TABLE `form_misc_billing_options` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `employment_related` tinyint(1) DEFAULT NULL,
  `auto_accident` tinyint(1) DEFAULT NULL,
  `accident_state` varchar(2) DEFAULT NULL,
  `other_accident` tinyint(1) DEFAULT NULL,
  `medicaid_referral_code` varchar(2) DEFAULT NULL,
  `epsdt_flag` tinyint(1) DEFAULT NULL,
  `provider_qualifier_code` varchar(2) DEFAULT NULL,
  `provider_id` int(11) DEFAULT NULL,
  `outside_lab` tinyint(1) DEFAULT NULL,
  `lab_amount` decimal(5,2) DEFAULT NULL,
  `is_unable_to_work` tinyint(1) DEFAULT NULL,
  `date_initial_treatment` date DEFAULT NULL,
  `off_work_from` date DEFAULT NULL,
  `off_work_to` date DEFAULT NULL,
  `is_hospitalized` tinyint(1) DEFAULT NULL,
  `hospitalization_date_from` date DEFAULT NULL,
  `hospitalization_date_to` date DEFAULT NULL,
  `medicaid_resubmission_code` varchar(10) DEFAULT NULL,
  `medicaid_original_reference` varchar(15) DEFAULT NULL,
  `prior_auth_number` varchar(20) DEFAULT NULL,
  `comments` varchar(255) DEFAULT NULL,
  `replacement_claim` tinyint(1) DEFAULT '0',
  `icn_resubmission_number` varchar(35) DEFAULT NULL,
  `box_14_date_qual` char(3) DEFAULT NULL,
  `box_15_date_qual` char(3) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_observation`
--

CREATE TABLE `form_observation` (
  `id` bigint(20) NOT NULL,
  `date` date DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `encounter` varchar(255) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `code` varchar(255) DEFAULT NULL,
  `observation` varchar(255) DEFAULT NULL,
  `ob_value` varchar(255) DEFAULT NULL,
  `ob_unit` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `code_type` varchar(255) DEFAULT NULL,
  `table_code` varchar(255) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `form_reviewofs`
--

CREATE TABLE `form_reviewofs` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `fever` varchar(5) DEFAULT NULL,
  `chills` varchar(5) DEFAULT NULL,
  `night_sweats` varchar(5) DEFAULT NULL,
  `weight_loss` varchar(5) DEFAULT NULL,
  `poor_appetite` varchar(5) DEFAULT NULL,
  `insomnia` varchar(5) DEFAULT NULL,
  `fatigued` varchar(5) DEFAULT NULL,
  `depressed` varchar(5) DEFAULT NULL,
  `hyperactive` varchar(5) DEFAULT NULL,
  `exposure_to_foreign_countries` varchar(5) DEFAULT NULL,
  `cataracts` varchar(5) DEFAULT NULL,
  `cataract_surgery` varchar(5) DEFAULT NULL,
  `glaucoma` varchar(5) DEFAULT NULL,
  `double_vision` varchar(5) DEFAULT NULL,
  `blurred_vision` varchar(5) DEFAULT NULL,
  `poor_hearing` varchar(5) DEFAULT NULL,
  `headaches` varchar(5) DEFAULT NULL,
  `ringing_in_ears` varchar(5) DEFAULT NULL,
  `bloody_nose` varchar(5) DEFAULT NULL,
  `sinusitis` varchar(5) DEFAULT NULL,
  `sinus_surgery` varchar(5) DEFAULT NULL,
  `dry_mouth` varchar(5) DEFAULT NULL,
  `strep_throat` varchar(5) DEFAULT NULL,
  `tonsillectomy` varchar(5) DEFAULT NULL,
  `swollen_lymph_nodes` varchar(5) DEFAULT NULL,
  `throat_cancer` varchar(5) DEFAULT NULL,
  `throat_cancer_surgery` varchar(5) DEFAULT NULL,
  `heart_attack` varchar(5) DEFAULT NULL,
  `irregular_heart_beat` varchar(5) DEFAULT NULL,
  `chest_pains` varchar(5) DEFAULT NULL,
  `shortness_of_breath` varchar(5) DEFAULT NULL,
  `high_blood_pressure` varchar(5) DEFAULT NULL,
  `heart_failure` varchar(5) DEFAULT NULL,
  `poor_circulation` varchar(5) DEFAULT NULL,
  `vascular_surgery` varchar(5) DEFAULT NULL,
  `cardiac_catheterization` varchar(5) DEFAULT NULL,
  `coronary_artery_bypass` varchar(5) DEFAULT NULL,
  `heart_transplant` varchar(5) DEFAULT NULL,
  `stress_test` varchar(5) DEFAULT NULL,
  `emphysema` varchar(5) DEFAULT NULL,
  `chronic_bronchitis` varchar(5) DEFAULT NULL,
  `interstitial_lung_disease` varchar(5) DEFAULT NULL,
  `shortness_of_breath_2` varchar(5) DEFAULT NULL,
  `lung_cancer` varchar(5) DEFAULT NULL,
  `lung_cancer_surgery` varchar(5) DEFAULT NULL,
  `pheumothorax` varchar(5) DEFAULT NULL,
  `stomach_pains` varchar(5) DEFAULT NULL,
  `peptic_ulcer_disease` varchar(5) DEFAULT NULL,
  `gastritis` varchar(5) DEFAULT NULL,
  `endoscopy` varchar(5) DEFAULT NULL,
  `polyps` varchar(5) DEFAULT NULL,
  `colonoscopy` varchar(5) DEFAULT NULL,
  `colon_cancer` varchar(5) DEFAULT NULL,
  `colon_cancer_surgery` varchar(5) DEFAULT NULL,
  `ulcerative_colitis` varchar(5) DEFAULT NULL,
  `crohns_disease` varchar(5) DEFAULT NULL,
  `appendectomy` varchar(5) DEFAULT NULL,
  `divirticulitis` varchar(5) DEFAULT NULL,
  `divirticulitis_surgery` varchar(5) DEFAULT NULL,
  `gall_stones` varchar(5) DEFAULT NULL,
  `cholecystectomy` varchar(5) DEFAULT NULL,
  `hepatitis` varchar(5) DEFAULT NULL,
  `cirrhosis_of_the_liver` varchar(5) DEFAULT NULL,
  `splenectomy` varchar(5) DEFAULT NULL,
  `kidney_failure` varchar(5) DEFAULT NULL,
  `kidney_stones` varchar(5) DEFAULT NULL,
  `kidney_cancer` varchar(5) DEFAULT NULL,
  `kidney_infections` varchar(5) DEFAULT NULL,
  `bladder_infections` varchar(5) DEFAULT NULL,
  `bladder_cancer` varchar(5) DEFAULT NULL,
  `prostate_problems` varchar(5) DEFAULT NULL,
  `prostate_cancer` varchar(5) DEFAULT NULL,
  `kidney_transplant` varchar(5) DEFAULT NULL,
  `sexually_transmitted_disease` varchar(5) DEFAULT NULL,
  `burning_with_urination` varchar(5) DEFAULT NULL,
  `discharge_from_urethra` varchar(5) DEFAULT NULL,
  `rashes` varchar(5) DEFAULT NULL,
  `infections` varchar(5) DEFAULT NULL,
  `ulcerations` varchar(5) DEFAULT NULL,
  `pemphigus` varchar(5) DEFAULT NULL,
  `herpes` varchar(5) DEFAULT NULL,
  `osetoarthritis` varchar(5) DEFAULT NULL,
  `rheumotoid_arthritis` varchar(5) DEFAULT NULL,
  `lupus` varchar(5) DEFAULT NULL,
  `ankylosing_sondlilitis` varchar(5) DEFAULT NULL,
  `swollen_joints` varchar(5) DEFAULT NULL,
  `stiff_joints` varchar(5) DEFAULT NULL,
  `broken_bones` varchar(5) DEFAULT NULL,
  `neck_problems` varchar(5) DEFAULT NULL,
  `back_problems` varchar(5) DEFAULT NULL,
  `back_surgery` varchar(5) DEFAULT NULL,
  `scoliosis` varchar(5) DEFAULT NULL,
  `herniated_disc` varchar(5) DEFAULT NULL,
  `shoulder_problems` varchar(5) DEFAULT NULL,
  `elbow_problems` varchar(5) DEFAULT NULL,
  `wrist_problems` varchar(5) DEFAULT NULL,
  `hand_problems` varchar(5) DEFAULT NULL,
  `hip_problems` varchar(5) DEFAULT NULL,
  `knee_problems` varchar(5) DEFAULT NULL,
  `ankle_problems` varchar(5) DEFAULT NULL,
  `foot_problems` varchar(5) DEFAULT NULL,
  `insulin_dependent_diabetes` varchar(5) DEFAULT NULL,
  `noninsulin_dependent_diabetes` varchar(5) DEFAULT NULL,
  `hypothyroidism` varchar(5) DEFAULT NULL,
  `hyperthyroidism` varchar(5) DEFAULT NULL,
  `cushing_syndrom` varchar(5) DEFAULT NULL,
  `addison_syndrom` varchar(5) DEFAULT NULL,
  `additional_notes` longtext,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_ros`
--

CREATE TABLE `form_ros` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pid` int(11) NOT NULL,
  `activity` int(11) NOT NULL DEFAULT '1',
  `date` datetime DEFAULT NULL,
  `weight_change` varchar(3) DEFAULT NULL,
  `weakness` varchar(3) DEFAULT NULL,
  `fatigue` varchar(3) DEFAULT NULL,
  `anorexia` varchar(3) DEFAULT NULL,
  `fever` varchar(3) DEFAULT NULL,
  `chills` varchar(3) DEFAULT NULL,
  `night_sweats` varchar(3) DEFAULT NULL,
  `insomnia` varchar(3) DEFAULT NULL,
  `irritability` varchar(3) DEFAULT NULL,
  `heat_or_cold` varchar(3) DEFAULT NULL,
  `intolerance` varchar(3) DEFAULT NULL,
  `change_in_vision` varchar(3) DEFAULT NULL,
  `glaucoma_history` varchar(3) DEFAULT NULL,
  `eye_pain` varchar(3) DEFAULT NULL,
  `irritation` varchar(3) DEFAULT NULL,
  `redness` varchar(3) DEFAULT NULL,
  `excessive_tearing` varchar(3) DEFAULT NULL,
  `double_vision` varchar(3) DEFAULT NULL,
  `blind_spots` varchar(3) DEFAULT NULL,
  `photophobia` varchar(3) DEFAULT NULL,
  `hearing_loss` varchar(3) DEFAULT NULL,
  `discharge` varchar(3) DEFAULT NULL,
  `pain` varchar(3) DEFAULT NULL,
  `vertigo` varchar(3) DEFAULT NULL,
  `tinnitus` varchar(3) DEFAULT NULL,
  `frequent_colds` varchar(3) DEFAULT NULL,
  `sore_throat` varchar(3) DEFAULT NULL,
  `sinus_problems` varchar(3) DEFAULT NULL,
  `post_nasal_drip` varchar(3) DEFAULT NULL,
  `nosebleed` varchar(3) DEFAULT NULL,
  `snoring` varchar(3) DEFAULT NULL,
  `apnea` varchar(3) DEFAULT NULL,
  `breast_mass` varchar(3) DEFAULT NULL,
  `breast_discharge` varchar(3) DEFAULT NULL,
  `biopsy` varchar(3) DEFAULT NULL,
  `abnormal_mammogram` varchar(3) DEFAULT NULL,
  `cough` varchar(3) DEFAULT NULL,
  `sputum` varchar(3) DEFAULT NULL,
  `shortness_of_breath` varchar(3) DEFAULT NULL,
  `wheezing` varchar(3) DEFAULT NULL,
  `hemoptsyis` varchar(3) DEFAULT NULL,
  `asthma` varchar(3) DEFAULT NULL,
  `copd` varchar(3) DEFAULT NULL,
  `chest_pain` varchar(3) DEFAULT NULL,
  `palpitation` varchar(3) DEFAULT NULL,
  `syncope` varchar(3) DEFAULT NULL,
  `pnd` varchar(3) DEFAULT NULL,
  `doe` varchar(3) DEFAULT NULL,
  `orthopnea` varchar(3) DEFAULT NULL,
  `peripheal` varchar(3) DEFAULT NULL,
  `edema` varchar(3) DEFAULT NULL,
  `legpain_cramping` varchar(3) DEFAULT NULL,
  `history_murmur` varchar(3) DEFAULT NULL,
  `arrythmia` varchar(3) DEFAULT NULL,
  `heart_problem` varchar(3) DEFAULT NULL,
  `dysphagia` varchar(3) DEFAULT NULL,
  `heartburn` varchar(3) DEFAULT NULL,
  `bloating` varchar(3) DEFAULT NULL,
  `belching` varchar(3) DEFAULT NULL,
  `flatulence` varchar(3) DEFAULT NULL,
  `nausea` varchar(3) DEFAULT NULL,
  `vomiting` varchar(3) DEFAULT NULL,
  `hematemesis` varchar(3) DEFAULT NULL,
  `gastro_pain` varchar(3) DEFAULT NULL,
  `food_intolerance` varchar(3) DEFAULT NULL,
  `hepatitis` varchar(3) DEFAULT NULL,
  `jaundice` varchar(3) DEFAULT NULL,
  `hematochezia` varchar(3) DEFAULT NULL,
  `changed_bowel` varchar(3) DEFAULT NULL,
  `diarrhea` varchar(3) DEFAULT NULL,
  `constipation` varchar(3) DEFAULT NULL,
  `polyuria` varchar(3) DEFAULT NULL,
  `polydypsia` varchar(3) DEFAULT NULL,
  `dysuria` varchar(3) DEFAULT NULL,
  `hematuria` varchar(3) DEFAULT NULL,
  `frequency` varchar(3) DEFAULT NULL,
  `urgency` varchar(3) DEFAULT NULL,
  `incontinence` varchar(3) DEFAULT NULL,
  `renal_stones` varchar(3) DEFAULT NULL,
  `utis` varchar(3) DEFAULT NULL,
  `hesitancy` varchar(3) DEFAULT NULL,
  `dribbling` varchar(3) DEFAULT NULL,
  `stream` varchar(3) DEFAULT NULL,
  `nocturia` varchar(3) DEFAULT NULL,
  `erections` varchar(3) DEFAULT NULL,
  `ejaculations` varchar(3) DEFAULT NULL,
  `g` varchar(3) DEFAULT NULL,
  `p` varchar(3) DEFAULT NULL,
  `ap` varchar(3) DEFAULT NULL,
  `lc` varchar(3) DEFAULT NULL,
  `mearche` varchar(3) DEFAULT NULL,
  `menopause` varchar(3) DEFAULT NULL,
  `lmp` varchar(3) DEFAULT NULL,
  `f_frequency` varchar(3) DEFAULT NULL,
  `f_flow` varchar(3) DEFAULT NULL,
  `f_symptoms` varchar(3) DEFAULT NULL,
  `abnormal_hair_growth` varchar(3) DEFAULT NULL,
  `f_hirsutism` varchar(3) DEFAULT NULL,
  `joint_pain` varchar(3) DEFAULT NULL,
  `swelling` varchar(3) DEFAULT NULL,
  `m_redness` varchar(3) DEFAULT NULL,
  `m_warm` varchar(3) DEFAULT NULL,
  `m_stiffness` varchar(3) DEFAULT NULL,
  `muscle` varchar(3) DEFAULT NULL,
  `m_aches` varchar(3) DEFAULT NULL,
  `fms` varchar(3) DEFAULT NULL,
  `arthritis` varchar(3) DEFAULT NULL,
  `loc` varchar(3) DEFAULT NULL,
  `seizures` varchar(3) DEFAULT NULL,
  `stroke` varchar(3) DEFAULT NULL,
  `tia` varchar(3) DEFAULT NULL,
  `n_numbness` varchar(3) DEFAULT NULL,
  `n_weakness` varchar(3) DEFAULT NULL,
  `paralysis` varchar(3) DEFAULT NULL,
  `intellectual_decline` varchar(3) DEFAULT NULL,
  `memory_problems` varchar(3) DEFAULT NULL,
  `dementia` varchar(3) DEFAULT NULL,
  `n_headache` varchar(3) DEFAULT NULL,
  `s_cancer` varchar(3) DEFAULT NULL,
  `psoriasis` varchar(3) DEFAULT NULL,
  `s_acne` varchar(3) DEFAULT NULL,
  `s_other` varchar(3) DEFAULT NULL,
  `s_disease` varchar(3) DEFAULT NULL,
  `p_diagnosis` varchar(3) DEFAULT NULL,
  `p_medication` varchar(3) DEFAULT NULL,
  `depression` varchar(3) DEFAULT NULL,
  `anxiety` varchar(3) DEFAULT NULL,
  `social_difficulties` varchar(3) DEFAULT NULL,
  `thyroid_problems` varchar(3) DEFAULT NULL,
  `diabetes` varchar(3) DEFAULT NULL,
  `abnormal_blood` varchar(3) DEFAULT NULL,
  `anemia` varchar(3) DEFAULT NULL,
  `fh_blood_problems` varchar(3) DEFAULT NULL,
  `bleeding_problems` varchar(3) DEFAULT NULL,
  `allergies` varchar(3) DEFAULT NULL,
  `frequent_illness` varchar(3) DEFAULT NULL,
  `hiv` varchar(3) DEFAULT NULL,
  `hai_status` varchar(3) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_soap`
--

CREATE TABLE `form_soap` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) DEFAULT '0',
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT '0',
  `activity` tinyint(4) DEFAULT '0',
  `subjective` text,
  `objective` text,
  `assessment` text,
  `plan` text,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `form_vitals`
--

CREATE TABLE `form_vitals` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) DEFAULT '0',
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT '0',
  `activity` tinyint(4) DEFAULT '0',
  `bps` varchar(40) DEFAULT NULL,
  `bpd` varchar(40) DEFAULT NULL,
  `weight` float(5,2) DEFAULT '0.00',
  `height` float(5,2) DEFAULT '0.00',
  `temperature` float(5,2) DEFAULT '0.00',
  `temp_method` varchar(255) DEFAULT NULL,
  `pulse` float(5,2) DEFAULT '0.00',
  `respiration` float(5,2) DEFAULT '0.00',
  `note` varchar(255) DEFAULT NULL,
  `BMI` float(4,1) DEFAULT '0.0',
  `BMI_status` varchar(255) DEFAULT NULL,
  `waist_circ` float(5,2) DEFAULT '0.00',
  `head_circ` float(4,2) DEFAULT '0.00',
  `oxygen_saturation` float(5,2) DEFAULT '0.00',
  `external_id` varchar(20) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_acl`
--

CREATE TABLE `gacl_acl` (
  `id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT 'system',
  `allow` int(11) NOT NULL DEFAULT '0',
  `enabled` int(11) NOT NULL DEFAULT '0',
  `return_value` text,
  `note` text,
  `updated_date` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `gacl_enabled_acl` (`enabled`),
  KEY `gacl_section_value_acl` (`section_value`),
  KEY `gacl_updated_date_acl` (`updated_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_acl`
--

INSERT INTO `gacl_acl` VALUES
(10, 'system', 1, 1, 'write', 'Administrators can do anything', [[timestamp]]),
(11, 'system', 1, 1, 'view', 'Things that physicians can only read', [[timestamp]]),
(12, 'system', 1, 1, 'addonly', 'Things that physicians can read and enter but not modify', [[timestamp]]),
(13, 'system', 1, 1, 'wsome', 'Things that physicians can read and partly modify', [[timestamp]]),
(14, 'system', 1, 1, 'write', 'Things that physicians can read and modify', [[timestamp]]),
(15, 'system', 1, 1, 'view', 'Things that clinicians can only read', [[timestamp]]),
(16, 'system', 1, 1, 'addonly', 'Things that clinicians can read and enter but not modify', [[timestamp]]),
(17, 'system', 1, 1, 'wsome', 'Things that clinicians can read and partly modify', [[timestamp]]),
(18, 'system', 1, 1, 'write', 'Things that clinicians can read and modify', [[timestamp]]),
(19, 'system', 1, 1, 'view', 'Things that front office can only read', [[timestamp]]),
(20, 'system', 1, 1, 'addonly', 'Things that front office can read and enter but not modify', [[timestamp]]),
(21, 'system', 1, 1, 'wsome', 'Things that front office can read and partly modify', [[timestamp]]),
(22, 'system', 1, 1, 'write', 'Things that front office can read and modify', [[timestamp]]),
(23, 'system', 1, 1, 'view', 'Things that back office can only read', [[timestamp]]),
(24, 'system', 1, 1, 'addonly', 'Things that back office can read and enter but not modify', [[timestamp]]),
(25, 'system', 1, 1, 'wsome', 'Things that back office can read and partly modify', [[timestamp]]),
(26, 'system', 1, 1, 'write', 'Things that back office can read and modify', [[timestamp]]),
(27, 'system', 1, 1, 'view', 'Things that PQRS reporters can only read', [[timestamp]]),
(28, 'system', 1, 1, 'addonly', 'Things that MIPS reporters can read and enter but not modify', [[timestamp]]),
(29, 'system', 1, 1, 'wsome', 'Things that MIPS reporters can read and partly modify', [[timestamp]]),
(30, 'system', 1, 1, 'write', 'Things that MIPS reporters can read and modify', [[timestamp]]),
(31, 'system', 1, 1, 'write', 'Emergency Login user can do anything', [[timestamp]]);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_acl_sections`
--

CREATE TABLE `gacl_acl_sections` (
  `id` int(11) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(230) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_value_acl_sections` (`value`),
  KEY `gacl_hidden_acl_sections` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_acl_sections`
--

INSERT INTO `gacl_acl_sections` VALUES
(1, 'system', 1, 'System', 0),
(2, 'user', 2, 'User', 0);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_acl_seq`
--

CREATE TABLE `gacl_acl_seq` (
  `id` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_acl_seq`
--

INSERT INTO `gacl_acl_seq` VALUES
(31);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aco`
--

CREATE TABLE `gacl_aco` (
  `id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_section_value_value_aco` (`section_value`,`value`),
  KEY `gacl_hidden_aco` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aco`
--

INSERT INTO `gacl_aco` VALUES
(10, 'acct', 'bill', 10, 'Billing (write optional)', 0),
(11, 'acct', 'disc', 10, 'Price Discounting', 0),
(12, 'acct', 'eob', 10, 'EOB Data Entry', 0),
(13, 'acct', 'rep', 10, 'Financial Reporting - my encounters', 0),
(14, 'acct', 'rep_a', 10, 'Financial Reporting - anything', 0),
(15, 'admin', 'super', 10, 'Superuser', 0),
(16, 'admin', 'calendar', 10, 'Calendar Settings', 0),
(17, 'admin', 'database', 10, 'Database Reporting', 0),
(18, 'admin', 'forms', 10, 'Forms Administration', 0),
(19, 'admin', 'practice', 10, 'Practice Settings', 0),
(20, 'admin', 'superbill', 10, 'Superbill Codes Administration', 0),
(21, 'admin', 'users', 10, 'Users/Groups/Logs Administration', 0),
(22, 'admin', 'batchcom', 10, 'Batch Communication Tool', 0),
(23, 'admin', 'language', 10, 'Language Interface Tool', 0),
(24, 'admin', 'drugs', 10, 'Pharmacy Dispensary', 0),
(25, 'admin', 'acl', 10, 'ACL Administration', 0),
(26, 'encounters', 'auth', 10, 'Authorize - my encounters', 0),
(27, 'encounters', 'auth_a', 10, 'Authorize - any encounters', 0),
(28, 'encounters', 'coding', 10, 'Coding - my encounters (write,wsome optional)', 0),
(29, 'encounters', 'coding_a', 10, 'Coding - any encounters (write,wsome optional)', 0),
(30, 'encounters', 'notes', 10, 'Notes - my encounters (write,addonly optional)', 0),
(31, 'encounters', 'notes_a', 10, 'Notes - any encounters (write,addonly optional)', 0),
(32, 'encounters', 'date_a', 10, 'Fix encounter dates - any encounters', 0),
(33, 'encounters', 'relaxed', 10, 'Less-private information (write,addonly optional)', 0),
(34, 'lists', 'default', 10, 'Default List (write,addonly optional)', 0),
(35, 'lists', 'state', 10, 'State List (write,addonly optional)', 0),
(36, 'lists', 'country', 10, 'Country List (write,addonly optional)', 0),
(37, 'lists', 'language', 10, 'Language List (write,addonly optional)', 0),
(38, 'lists', 'ethrace', 10, 'Ethnicity-Race List (write,addonly optional)', 0),
(39, 'patientportal', 'portal', 10, 'Patient Portal', 0),
(40, 'menus', 'modle', 10, 'Modules', 0),
(41, 'patients', 'appt', 10, 'Appointments (write,wsome optional)', 0),
(42, 'patients', 'demo', 10, 'Demographics (write,addonly optional)', 0),
(43, 'patients', 'med', 10, 'Medical/History (write,addonly optional)', 0),
(44, 'patients', 'trans', 10, 'Transactions (write optional)', 0),
(45, 'patients', 'docs', 10, 'Documents (write,addonly optional)', 0),
(46, 'patients', 'notes', 10, 'Patient Notes (write,addonly optional)', 0),
(47, 'patients', 'sign', 10, 'Sign Lab Results (write,addonly optional)', 0),
(48, 'sensitivities', 'normal', 10, 'Normal', 0),
(49, 'sensitivities', 'high', 20, 'High', 0),
(50, 'placeholder', 'filler', 10, 'Placeholder (Maintains empty ACLs)', 0);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aco_map`
--

CREATE TABLE `gacl_aco_map` (
  `acl_id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  PRIMARY KEY (`acl_id`,`section_value`,`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aco_map`
--

INSERT INTO `gacl_aco_map` VALUES
(10, 'acct', 'bill'),
(10, 'acct', 'disc'),
(10, 'acct', 'eob'),
(10, 'acct', 'rep'),
(10, 'acct', 'rep_a'),
(10, 'admin', 'acl'),
(10, 'admin', 'batchcom'),
(10, 'admin', 'calendar'),
(10, 'admin', 'database'),
(10, 'admin', 'drugs'),
(10, 'admin', 'forms'),
(10, 'admin', 'language'),
(10, 'admin', 'practice'),
(10, 'admin', 'super'),
(10, 'admin', 'superbill'),
(10, 'admin', 'users'),
(10, 'encounters', 'auth_a'),
(10, 'encounters', 'coding_a'),
(10, 'encounters', 'date_a'),
(10, 'encounters', 'notes_a'),
(10, 'lists', 'country'),
(10, 'lists', 'default'),
(10, 'lists', 'ethrace'),
(10, 'lists', 'language'),
(10, 'lists', 'state'),
(10, 'menus', 'modle'),
(10, 'patientportal', 'portal'),
(10, 'patients', 'appt'),
(10, 'patients', 'demo'),
(10, 'patients', 'docs'),
(10, 'patients', 'med'),
(10, 'patients', 'notes'),
(10, 'patients', 'trans'),
(10, 'sensitivities', 'high'),
(10, 'sensitivities', 'normal'),
(11, 'placeholder', 'filler'),
(12, 'placeholder', 'filler'),
(13, 'placeholder', 'filler'),
(14, 'acct', 'disc'),
(14, 'acct', 'rep'),
(14, 'admin', 'drugs'),
(14, 'encounters', 'auth_a'),
(14, 'encounters', 'coding_a'),
(14, 'encounters', 'date_a'),
(14, 'encounters', 'notes_a'),
(14, 'patients', 'appt'),
(14, 'patients', 'demo'),
(14, 'patients', 'docs'),
(14, 'patients', 'med'),
(14, 'patients', 'notes'),
(14, 'patients', 'sign'),
(14, 'patients', 'trans'),
(14, 'sensitivities', 'high'),
(14, 'sensitivities', 'normal'),
(15, 'placeholder', 'filler'),
(16, 'encounters', 'notes'),
(16, 'encounters', 'relaxed'),
(16, 'patients', 'demo'),
(16, 'patients', 'docs'),
(16, 'patients', 'med'),
(16, 'patients', 'notes'),
(16, 'sensitivities', 'normal'),
(17, 'placeholder', 'filler'),
(18, 'admin', 'drugs'),
(18, 'encounters', 'coding'),
(18, 'patients', 'appt'),
(19, 'placeholder', 'filler'),
(20, 'placeholder', 'filler'),
(21, 'placeholder', 'filler'),
(22, 'patients', 'appt'),
(22, 'patients', 'demo'),
(22, 'patients', 'notes'),
(22, 'patients', 'trans'),
(23, 'placeholder', 'filler'),
(24, 'placeholder', 'filler'),
(25, 'placeholder', 'filler'),
(26, 'acct', 'bill'),
(26, 'acct', 'disc'),
(26, 'acct', 'eob'),
(26, 'acct', 'rep'),
(26, 'acct', 'rep_a'),
(26, 'admin', 'practice'),
(26, 'admin', 'superbill'),
(26, 'encounters', 'auth_a'),
(26, 'encounters', 'coding_a'),
(26, 'encounters', 'date_a'),
(26, 'patients', 'appt'),
(26, 'patients', 'demo'),
(27, 'placeholder', 'filler'),
(28, 'placeholder', 'filler'),
(29, 'placeholder', 'filler'),
(30, 'acct', 'disc'),
(30, 'acct', 'rep'),
(30, 'admin', 'drugs'),
(30, 'encounters', 'auth_a'),
(30, 'encounters', 'coding_a'),
(30, 'encounters', 'date_a'),
(30, 'encounters', 'notes_a'),
(30, 'patients', 'appt'),
(30, 'patients', 'demo'),
(30, 'patients', 'docs'),
(30, 'patients', 'med'),
(30, 'patients', 'notes'),
(30, 'patients', 'sign'),
(30, 'patients', 'trans'),
(30, 'sensitivities', 'high'),
(30, 'sensitivities', 'normal'),
(31, 'acct', 'bill'),
(31, 'acct', 'disc'),
(31, 'acct', 'eob'),
(31, 'acct', 'rep'),
(31, 'acct', 'rep_a'),
(31, 'admin', 'acl'),
(31, 'admin', 'batchcom'),
(31, 'admin', 'calendar'),
(31, 'admin', 'database'),
(31, 'admin', 'drugs'),
(31, 'admin', 'forms'),
(31, 'admin', 'language'),
(31, 'admin', 'practice'),
(31, 'admin', 'super'),
(31, 'admin', 'superbill'),
(31, 'admin', 'users'),
(31, 'encounters', 'auth_a'),
(31, 'encounters', 'coding_a'),
(31, 'encounters', 'date_a'),
(31, 'encounters', 'notes_a'),
(31, 'lists', 'country'),
(31, 'lists', 'default'),
(31, 'lists', 'ethrace'),
(31, 'lists', 'language'),
(31, 'lists', 'state'),
(31, 'menus', 'modle'),
(31, 'patientportal', 'portal'),
(31, 'patients', 'appt'),
(31, 'patients', 'demo'),
(31, 'patients', 'docs'),
(31, 'patients', 'med'),
(31, 'patients', 'notes'),
(31, 'patients', 'trans'),
(31, 'sensitivities', 'high'),
(31, 'sensitivities', 'normal');

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aco_sections`
--

CREATE TABLE `gacl_aco_sections` (
  `id` int(11) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(230) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_value_aco_sections` (`value`),
  KEY `gacl_hidden_aco_sections` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aco_sections`
--

INSERT INTO `gacl_aco_sections` VALUES
(10, 'acct', 10, 'Accounting', 0),
(11, 'admin', 10, 'Administration', 0),
(12, 'encounters', 10, 'Encounters', 0),
(13, 'lists', 10, 'Lists', 0),
(14, 'patients', 10, 'Patients', 0),
(15, 'squads', 10, 'Squads', 0),
(16, 'sensitivities', 10, 'Sensitivities', 0),
(17, 'placeholder', 10, 'Placeholder', 0),
(18, 'patientportal', 10, 'Patient Portal', 0),
(19, 'menus', 10, 'Menus', 0);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aco_sections_seq`
--

CREATE TABLE `gacl_aco_sections_seq` (
  `id` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aco_sections_seq`
--

INSERT INTO `gacl_aco_sections_seq` VALUES
(19);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aco_seq`
--

CREATE TABLE `gacl_aco_seq` (
  `id` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aco_seq`
--

INSERT INTO `gacl_aco_seq` VALUES
(50);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro`
--

CREATE TABLE `gacl_aro` (
  `id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_section_value_value_aro` (`section_value`,`value`),
  KEY `gacl_hidden_aro` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro`
--

INSERT INTO `gacl_aro` VALUES
(10, 'users', '[[admin_username]]', 10, '[[admin_lname]]', 0);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_groups`
--

CREATE TABLE `gacl_aro_groups` (
  `id` int(11) NOT NULL DEFAULT '0',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `lft` int(11) NOT NULL DEFAULT '0',
  `rgt` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL,
  `value` varchar(150) NOT NULL,
  PRIMARY KEY (`id`,`value`),
  UNIQUE KEY `gacl_value_aro_groups` (`value`),
  KEY `gacl_parent_id_aro_groups` (`parent_id`),
  KEY `gacl_lft_rgt_aro_groups` (`lft`,`rgt`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro_groups`
--

INSERT INTO `gacl_aro_groups` VALUES
(10, 0, 1, 16, 'LibreEHR Users', 'users'),
(11, 10, 2, 3, 'Administrators', 'admin'),
(12, 10, 4, 5, 'Clinicians', 'clin'),
(13, 10, 6, 7, 'Physicians', 'doc'),
(14, 10, 8, 9, 'Front Office', 'front'),
(15, 10, 10, 11, 'Accounting', 'back'),
(16, 10, 12, 13, 'Emergency Login', 'breakglass'),
(17, 10, 14, 15, 'MIPS Reporter', 'pqrsreporter');

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_groups_id_seq`
--

CREATE TABLE `gacl_aro_groups_id_seq` (
  `id` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro_groups_id_seq`
--

INSERT INTO `gacl_aro_groups_id_seq` VALUES
(17);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_groups_map`
--

CREATE TABLE `gacl_aro_groups_map` (
  `acl_id` int(11) NOT NULL DEFAULT '0',
  `group_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`acl_id`,`group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro_groups_map`
--

INSERT INTO `gacl_aro_groups_map` VALUES
(10, 11),
(11, 13),
(12, 13),
(13, 13),
(14, 13),
(15, 12),
(16, 12),
(17, 12),
(18, 12),
(19, 14),
(20, 14),
(21, 14),
(22, 14),
(23, 15),
(24, 15),
(25, 15),
(26, 15),
(27, 17),
(28, 17),
(29, 17),
(30, 17),
(31, 16);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_map`
--

CREATE TABLE `gacl_aro_map` (
  `acl_id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  PRIMARY KEY (`acl_id`,`section_value`,`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_sections`
--

CREATE TABLE `gacl_aro_sections` (
  `id` int(11) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(230) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_value_aro_sections` (`value`),
  KEY `gacl_hidden_aro_sections` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro_sections`
--

INSERT INTO `gacl_aro_sections` VALUES
(10, 'users', 10, 'Users', 0);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_sections_seq`
--

CREATE TABLE `gacl_aro_sections_seq` (
  `id` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro_sections_seq`
--

INSERT INTO `gacl_aro_sections_seq` VALUES
(10);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_aro_seq`
--

CREATE TABLE `gacl_aro_seq` (
  `id` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_aro_seq`
--

INSERT INTO `gacl_aro_seq` VALUES
(10);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_axo`
--

CREATE TABLE `gacl_axo` (
  `id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_section_value_value_axo` (`section_value`,`value`),
  KEY `gacl_hidden_axo` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_axo_groups`
--

CREATE TABLE `gacl_axo_groups` (
  `id` int(11) NOT NULL DEFAULT '0',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `lft` int(11) NOT NULL DEFAULT '0',
  `rgt` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL,
  `value` varchar(150) NOT NULL,
  PRIMARY KEY (`id`,`value`),
  UNIQUE KEY `gacl_value_axo_groups` (`value`),
  KEY `gacl_parent_id_axo_groups` (`parent_id`),
  KEY `gacl_lft_rgt_axo_groups` (`lft`,`rgt`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_axo_groups_map`
--

CREATE TABLE `gacl_axo_groups_map` (
  `acl_id` int(11) NOT NULL DEFAULT '0',
  `group_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`acl_id`,`group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_axo_map`
--

CREATE TABLE `gacl_axo_map` (
  `acl_id` int(11) NOT NULL DEFAULT '0',
  `section_value` varchar(150) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  PRIMARY KEY (`acl_id`,`section_value`,`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_axo_sections`
--

CREATE TABLE `gacl_axo_sections` (
  `id` int(11) NOT NULL DEFAULT '0',
  `value` varchar(150) NOT NULL,
  `order_value` int(11) NOT NULL DEFAULT '0',
  `name` varchar(230) NOT NULL,
  `hidden` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `gacl_value_axo_sections` (`value`),
  KEY `gacl_hidden_axo_sections` (`hidden`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_groups_aro_map`
--

CREATE TABLE `gacl_groups_aro_map` (
  `group_id` int(11) NOT NULL DEFAULT '0',
  `aro_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`group_id`,`aro_id`),
  KEY `gacl_aro_id` (`aro_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_groups_aro_map`
--

INSERT INTO `gacl_groups_aro_map` VALUES
(11, 10);

-- --------------------------------------------------------

--
-- Table structure for table `gacl_groups_axo_map`
--

CREATE TABLE `gacl_groups_axo_map` (
  `group_id` int(11) NOT NULL DEFAULT '0',
  `axo_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`group_id`,`axo_id`),
  KEY `gacl_axo_id` (`axo_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `gacl_phpgacl`
--

CREATE TABLE `gacl_phpgacl` (
  `name` varchar(230) NOT NULL,
  `value` varchar(150) NOT NULL,
  PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `gacl_phpgacl`
--

INSERT INTO `gacl_phpgacl` VALUES
('schema_version', '2.1'),
('version', '3.3.7');

-- --------------------------------------------------------

--
-- Table structure for table `geo_country_reference`
--

CREATE TABLE `geo_country_reference` (
  `countries_id` int(5) NOT NULL AUTO_INCREMENT,
  `countries_name` varchar(64) DEFAULT NULL,
  `countries_iso_code_2` char(2) NOT NULL DEFAULT '',
  `countries_iso_code_3` char(3) NOT NULL DEFAULT '',
  PRIMARY KEY (`countries_id`),
  KEY `IDX_COUNTRIES_NAME` (`countries_name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=240 ;

--
-- Dumping data for table `geo_country_reference`
--

INSERT INTO `geo_country_reference` VALUES
(1, 'Afghanistan', 'AF', 'AFG'),
(2, 'Albania', 'AL', 'ALB'),
(3, 'Algeria', 'DZ', 'DZA'),
(4, 'American Samoa', 'AS', 'ASM'),
(5, 'Andorra', 'AD', 'AND'),
(6, 'Angola', 'AO', 'AGO'),
(7, 'Anguilla', 'AI', 'AIA'),
(8, 'Antarctica', 'AQ', 'ATA'),
(9, 'Antigua and Barbuda', 'AG', 'ATG'),
(10, 'Argentina', 'AR', 'ARG'),
(11, 'Armenia', 'AM', 'ARM'),
(12, 'Aruba', 'AW', 'ABW'),
(13, 'Australia', 'AU', 'AUS'),
(14, 'Austria', 'AT', 'AUT'),
(15, 'Azerbaijan', 'AZ', 'AZE'),
(16, 'Bahamas', 'BS', 'BHS'),
(17, 'Bahrain', 'BH', 'BHR'),
(18, 'Bangladesh', 'BD', 'BGD'),
(19, 'Barbados', 'BB', 'BRB'),
(20, 'Belarus', 'BY', 'BLR'),
(21, 'Belgium', 'BE', 'BEL'),
(22, 'Belize', 'BZ', 'BLZ'),
(23, 'Benin', 'BJ', 'BEN'),
(24, 'Bermuda', 'BM', 'BMU'),
(25, 'Bhutan', 'BT', 'BTN'),
(26, 'Bolivia', 'BO', 'BOL'),
(27, 'Bosnia and Herzegowina', 'BA', 'BIH'),
(28, 'Botswana', 'BW', 'BWA'),
(29, 'Bouvet Island', 'BV', 'BVT'),
(30, 'Brazil', 'BR', 'BRA'),
(31, 'British Indian Ocean Territory', 'IO', 'IOT'),
(32, 'Brunei Darussalam', 'BN', 'BRN'),
(33, 'Bulgaria', 'BG', 'BGR'),
(34, 'Burkina Faso', 'BF', 'BFA'),
(35, 'Burundi', 'BI', 'BDI'),
(36, 'Cambodia', 'KH', 'KHM'),
(37, 'Cameroon', 'CM', 'CMR'),
(38, 'Canada', 'CA', 'CAN'),
(39, 'Cape Verde', 'CV', 'CPV'),
(40, 'Cayman Islands', 'KY', 'CYM'),
(41, 'Central African Republic', 'CF', 'CAF'),
(42, 'Chad', 'TD', 'TCD'),
(43, 'Chile', 'CL', 'CHL'),
(44, 'China', 'CN', 'CHN'),
(45, 'Christmas Island', 'CX', 'CXR'),
(46, 'Cocos (Keeling) Islands', 'CC', 'CCK'),
(47, 'Colombia', 'CO', 'COL'),
(48, 'Comoros', 'KM', 'COM'),
(49, 'Congo', 'CG', 'COG'),
(50, 'Cook Islands', 'CK', 'COK'),
(51, 'Costa Rica', 'CR', 'CRI'),
(52, 'Cote D Ivoire', 'CI', 'CIV'),
(53, 'Croatia', 'HR', 'HRV'),
(54, 'Cuba', 'CU', 'CUB'),
(55, 'Cyprus', 'CY', 'CYP'),
(56, 'Czech Republic', 'CZ', 'CZE'),
(57, 'Denmark', 'DK', 'DNK'),
(58, 'Djibouti', 'DJ', 'DJI'),
(59, 'Dominica', 'DM', 'DMA'),
(60, 'Dominican Republic', 'DO', 'DOM'),
(61, 'East Timor', 'TP', 'TMP'),
(62, 'Ecuador', 'EC', 'ECU'),
(63, 'Egypt', 'EG', 'EGY'),
(64, 'El Salvador', 'SV', 'SLV'),
(65, 'Equatorial Guinea', 'GQ', 'GNQ'),
(66, 'Eritrea', 'ER', 'ERI'),
(67, 'Estonia', 'EE', 'EST'),
(68, 'Ethiopia', 'ET', 'ETH'),
(69, 'Falkland Islands (Malvinas)', 'FK', 'FLK'),
(70, 'Faroe Islands', 'FO', 'FRO'),
(71, 'Fiji', 'FJ', 'FJI'),
(72, 'Finland', 'FI', 'FIN'),
(73, 'France', 'FR', 'FRA'),
(74, 'France, MEtropolitan', 'FX', 'FXX'),
(75, 'French Guiana', 'GF', 'GUF'),
(76, 'French Polynesia', 'PF', 'PYF'),
(77, 'French Southern Territories', 'TF', 'ATF'),
(78, 'Gabon', 'GA', 'GAB'),
(79, 'Gambia', 'GM', 'GMB'),
(80, 'Georgia', 'GE', 'GEO'),
(81, 'Germany', 'DE', 'DEU'),
(82, 'Ghana', 'GH', 'GHA'),
(83, 'Gibraltar', 'GI', 'GIB'),
(84, 'Greece', 'GR', 'GRC'),
(85, 'Greenland', 'GL', 'GRL'),
(86, 'Grenada', 'GD', 'GRD'),
(87, 'Guadeloupe', 'GP', 'GLP'),
(88, 'Guam', 'GU', 'GUM'),
(89, 'Guatemala', 'GT', 'GTM'),
(90, 'Guinea', 'GN', 'GIN'),
(91, 'Guinea-bissau', 'GW', 'GNB'),
(92, 'Guyana', 'GY', 'GUY'),
(93, 'Haiti', 'HT', 'HTI'),
(94, 'Heard and Mc Donald Islands', 'HM', 'HMD'),
(95, 'Honduras', 'HN', 'HND'),
(96, 'Hong Kong', 'HK', 'HKG'),
(97, 'Hungary', 'HU', 'HUN'),
(98, 'Iceland', 'IS', 'ISL'),
(99, 'India', 'IN', 'IND'),
(100, 'Indonesia', 'ID', 'IDN'),
(101, 'Iran (Islamic Republic of)', 'IR', 'IRN'),
(102, 'Iraq', 'IQ', 'IRQ'),
(103, 'Ireland', 'IE', 'IRL'),
(104, 'Israel', 'IL', 'ISR'),
(105, 'Italy', 'IT', 'ITA'),
(106, 'Jamaica', 'JM', 'JAM'),
(107, 'Japan', 'JP', 'JPN'),
(108, 'Jordan', 'JO', 'JOR'),
(109, 'Kazakhstan', 'KZ', 'KAZ'),
(110, 'Kenya', 'KE', 'KEN'),
(111, 'Kiribati', 'KI', 'KIR'),
(112, 'Korea, Democratic Peoples Republic of', 'KP', 'PRK'),
(113, 'Korea, Republic of', 'KR', 'KOR'),
(114, 'Kuwait', 'KW', 'KWT'),
(115, 'Kyrgyzstan', 'KG', 'KGZ'),
(116, 'Lao Peoples Democratic Republic', 'LA', 'LAO'),
(117, 'Latvia', 'LV', 'LVA'),
(118, 'Lebanon', 'LB', 'LBN'),
(119, 'Lesotho', 'LS', 'LSO'),
(120, 'Liberia', 'LR', 'LBR'),
(121, 'Libyan Arab Jamahiriya', 'LY', 'LBY'),
(122, 'Liechtenstein', 'LI', 'LIE'),
(123, 'Lithuania', 'LT', 'LTU'),
(124, 'Luxembourg', 'LU', 'LUX'),
(125, 'Macau', 'MO', 'MAC'),
(126, 'Macedonia, The Former Yugoslav Republic of', 'MK', 'MKD'),
(127, 'Madagascar', 'MG', 'MDG'),
(128, 'Malawi', 'MW', 'MWI'),
(129, 'Malaysia', 'MY', 'MYS'),
(130, 'Maldives', 'MV', 'MDV'),
(131, 'Mali', 'ML', 'MLI'),
(132, 'Malta', 'MT', 'MLT'),
(133, 'Marshall Islands', 'MH', 'MHL'),
(134, 'Martinique', 'MQ', 'MTQ'),
(135, 'Mauritania', 'MR', 'MRT'),
(136, 'Mauritius', 'MU', 'MUS'),
(137, 'Mayotte', 'YT', 'MYT'),
(138, 'Mexico', 'MX', 'MEX'),
(139, 'Micronesia, Federated States of', 'FM', 'FSM'),
(140, 'Moldova, Republic of', 'MD', 'MDA'),
(141, 'Monaco', 'MC', 'MCO'),
(142, 'Mongolia', 'MN', 'MNG'),
(143, 'Montserrat', 'MS', 'MSR'),
(144, 'Morocco', 'MA', 'MAR'),
(145, 'Mozambique', 'MZ', 'MOZ'),
(146, 'Myanmar', 'MM', 'MMR'),
(147, 'Namibia', 'NA', 'NAM'),
(148, 'Nauru', 'NR', 'NRU'),
(149, 'Nepal', 'NP', 'NPL'),
(150, 'Netherlands', 'NL', 'NLD'),
(151, 'Netherlands Antilles', 'AN', 'ANT'),
(152, 'New Caledonia', 'NC', 'NCL'),
(153, 'New Zealand', 'NZ', 'NZL'),
(154, 'Nicaragua', 'NI', 'NIC'),
(155, 'Niger', 'NE', 'NER'),
(156, 'Nigeria', 'NG', 'NGA'),
(157, 'Niue', 'NU', 'NIU'),
(158, 'Norfolk Island', 'NF', 'NFK'),
(159, 'Northern Mariana Islands', 'MP', 'MNP'),
(160, 'Norway', 'NO', 'NOR'),
(161, 'Oman', 'OM', 'OMN'),
(162, 'Pakistan', 'PK', 'PAK'),
(163, 'Palau', 'PW', 'PLW'),
(164, 'Panama', 'PA', 'PAN'),
(165, 'Papua New Guinea', 'PG', 'PNG'),
(166, 'Paraguay', 'PY', 'PRY'),
(167, 'Peru', 'PE', 'PER'),
(168, 'Philippines', 'PH', 'PHL'),
(169, 'Pitcairn', 'PN', 'PCN'),
(170, 'Poland', 'PL', 'POL'),
(171, 'Portugal', 'PT', 'PRT'),
(172, 'Puerto Rico', 'PR', 'PRI'),
(173, 'Qatar', 'QA', 'QAT'),
(174, 'Reunion', 'RE', 'REU'),
(175, 'Romania', 'RO', 'ROM'),
(176, 'Russian Federation', 'RU', 'RUS'),
(177, 'Rwanda', 'RW', 'RWA'),
(178, 'Saint Kitts and Nevis', 'KN', 'KNA'),
(179, 'Saint Lucia', 'LC', 'LCA'),
(180, 'Saint Vincent and the Grenadines', 'VC', 'VCT'),
(181, 'Samoa', 'WS', 'WSM'),
(182, 'San Marino', 'SM', 'SMR'),
(183, 'Sao Tome and Principe', 'ST', 'STP'),
(184, 'Saudi Arabia', 'SA', 'SAU'),
(185, 'Senegal', 'SN', 'SEN'),
(186, 'Seychelles', 'SC', 'SYC'),
(187, 'Sierra Leone', 'SL', 'SLE'),
(188, 'Singapore', 'SG', 'SGP'),
(189, 'Slovakia (Slovak Republic)', 'SK', 'SVK'),
(190, 'Slovenia', 'SI', 'SVN'),
(191, 'Solomon Islands', 'SB', 'SLB'),
(192, 'Somalia', 'SO', 'SOM'),
(193, 'south Africa', 'ZA', 'ZAF'),
(194, 'South Georgia and the South Sandwich Islands', 'GS', 'SGS'),
(195, 'Spain', 'ES', 'ESP'),
(196, 'Sri Lanka', 'LK', 'LKA'),
(197, 'St. Helena', 'SH', 'SHN'),
(198, 'St. Pierre and Miquelon', 'PM', 'SPM'),
(199, 'Sudan', 'SD', 'SDN'),
(200, 'Suriname', 'SR', 'SUR'),
(201, 'Svalbard and Jan Mayen Islands', 'SJ', 'SJM'),
(202, 'Swaziland', 'SZ', 'SWZ'),
(203, 'Sweden', 'SE', 'SWE'),
(204, 'Switzerland', 'CH', 'CHE'),
(205, 'Syrian Arab Republic', 'SY', 'SYR'),
(206, 'Taiwan, Province of China', 'TW', 'TWN'),
(207, 'Tajikistan', 'TJ', 'TJK'),
(208, 'Tanzania, United Republic of', 'TZ', 'TZA'),
(209, 'Thailand', 'TH', 'THA'),
(210, 'Togo', 'TG', 'TGO'),
(211, 'Tokelau', 'TK', 'TKL'),
(212, 'Tonga', 'TO', 'TON'),
(213, 'Trinidad and Tobago', 'TT', 'TTO'),
(214, 'Tunisia', 'TN', 'TUN'),
(215, 'Turkey', 'TR', 'TUR'),
(216, 'Turkmenistan', 'TM', 'TKM'),
(217, 'Turks and Caicos Islands', 'TC', 'TCA'),
(218, 'Tuvalu', 'TV', 'TUV'),
(219, 'Uganda', 'UG', 'UGA'),
(220, 'Ukraine', 'UA', 'UKR'),
(221, 'United Arab Emirates', 'AE', 'ARE'),
(222, 'United Kingdom', 'GB', 'GBR'),
(223, 'United States', 'US', 'USA'),
(224, 'United States Minor Outlying Islands', 'UM', 'UMI'),
(225, 'Uruguay', 'UY', 'URY'),
(226, 'Uzbekistan', 'UZ', 'UZB'),
(227, 'Vanuatu', 'VU', 'VUT'),
(228, 'Vatican City State (Holy See)', 'VA', 'VAT'),
(229, 'Venezuela', 'VE', 'VEN'),
(230, 'Viet Nam', 'VN', 'VNM'),
(231, 'Virgin Islands (British)', 'VG', 'VGB'),
(232, 'Virgin Islands (U.S.)', 'VI', 'VIR'),
(233, 'Wallis and Futuna Islands', 'WF', 'WLF'),
(234, 'Western Sahara', 'EH', 'ESH'),
(235, 'Yemen', 'YE', 'YEM'),
(236, 'Yugoslavia', 'YU', 'YUG'),
(237, 'Zaire', 'ZR', 'ZAR'),
(238, 'Zambia', 'ZM', 'ZMB'),
(239, 'Zimbabwe', 'ZW', 'ZWE');

-- --------------------------------------------------------

--
-- Table structure for table `geo_zone_reference`
--

CREATE TABLE `geo_zone_reference` (
  `zone_id` int(5) NOT NULL AUTO_INCREMENT,
  `zone_country_id` int(5) NOT NULL DEFAULT '0',
  `zone_code` varchar(5) DEFAULT NULL,
  `zone_name` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`zone_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=83 ;

--
-- Dumping data for table `geo_zone_reference`
--

INSERT INTO `geo_zone_reference` VALUES
(1, 223, 'AL', 'Alabama'),
(2, 223, 'AK', 'Alaska'),
(3, 223, 'AS', 'American Samoa'),
(4, 223, 'AZ', 'Arizona'),
(5, 223, 'AR', 'Arkansas'),
(6, 223, 'AF', 'Armed Forces Africa'),
(7, 223, 'AA', 'Armed Forces Americas'),
(8, 223, 'AC', 'Armed Forces Canada'),
(9, 223, 'AE', 'Armed Forces Europe'),
(10, 223, 'AM', 'Armed Forces Middle East'),
(11, 223, 'AP', 'Armed Forces Pacific'),
(12, 223, 'CA', 'California'),
(13, 223, 'CO', 'Colorado'),
(14, 223, 'CT', 'Connecticut'),
(15, 223, 'DE', 'Delaware'),
(16, 223, 'DC', 'District of Columbia'),
(17, 223, 'FM', 'Federated States Of Micronesia'),
(18, 223, 'FL', 'Florida'),
(19, 223, 'GA', 'Georgia'),
(20, 223, 'GU', 'Guam'),
(21, 223, 'HI', 'Hawaii'),
(22, 223, 'ID', 'Idaho'),
(23, 223, 'IL', 'Illinois'),
(24, 223, 'IN', 'Indiana'),
(25, 223, 'IA', 'Iowa'),
(26, 223, 'KS', 'Kansas'),
(27, 223, 'KY', 'Kentucky'),
(28, 223, 'LA', 'Louisiana'),
(29, 223, 'ME', 'Maine'),
(30, 223, 'MH', 'Marshall Islands'),
(31, 223, 'MD', 'Maryland'),
(32, 223, 'MA', 'Massachusetts'),
(33, 223, 'MI', 'Michigan'),
(34, 223, 'MN', 'Minnesota'),
(35, 223, 'MS', 'Mississippi'),
(36, 223, 'MO', 'Missouri'),
(37, 223, 'MT', 'Montana'),
(38, 223, 'NE', 'Nebraska'),
(39, 223, 'NV', 'Nevada'),
(40, 223, 'NH', 'New Hampshire'),
(41, 223, 'NJ', 'New Jersey'),
(42, 223, 'NM', 'New Mexico'),
(43, 223, 'NY', 'New York'),
(44, 223, 'NC', 'North Carolina'),
(45, 223, 'ND', 'North Dakota'),
(46, 223, 'MP', 'Northern Mariana Islands'),
(47, 223, 'OH', 'Ohio'),
(48, 223, 'OK', 'Oklahoma'),
(49, 223, 'OR', 'Oregon'),
(50, 223, 'PW', 'Palau'),
(51, 223, 'PA', 'Pennsylvania'),
(52, 223, 'PR', 'Puerto Rico'),
(53, 223, 'RI', 'Rhode Island'),
(54, 223, 'SC', 'South Carolina'),
(55, 223, 'SD', 'South Dakota'),
(56, 223, 'TN', 'Tenessee'),
(57, 223, 'TX', 'Texas'),
(58, 223, 'UT', 'Utah'),
(59, 223, 'VT', 'Vermont'),
(60, 223, 'VI', 'Virgin Islands'),
(61, 223, 'VA', 'Virginia'),
(62, 223, 'WA', 'Washington'),
(63, 223, 'WV', 'West Virginia'),
(64, 223, 'WI', 'Wisconsin'),
(65, 223, 'WY', 'Wyoming'),
(66, 38, 'AB', 'Alberta'),
(67, 38, 'BC', 'British Columbia'),
(68, 38, 'MB', 'Manitoba'),
(69, 38, 'NF', 'Newfoundland'),
(70, 38, 'NB', 'New Brunswick'),
(71, 38, 'NS', 'Nova Scotia'),
(72, 38, 'NT', 'Northwest Territories'),
(73, 38, 'NU', 'Nunavut'),
(74, 38, 'ON', 'Ontario'),
(75, 38, 'PE', 'Prince Edward Island'),
(76, 38, 'QC', 'Quebec'),
(77, 38, 'SK', 'Saskatchewan'),
(78, 38, 'YT', 'Yukon Territory'),
(79, 61, 'QLD', 'Queensland'),
(80, 61, 'SA', 'South Australia'),
(81, 61, 'ACT', 'Australian Capital Territory'),
(82, 61, 'VIC', 'Victoria');

-- --------------------------------------------------------

--
-- Table structure for table `globals`
--

CREATE TABLE `globals` (
  `gl_name` varchar(63) NOT NULL,
  `gl_index` int(11) NOT NULL DEFAULT '0',
  `gl_value` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`gl_name`,`gl_index`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `globals`
--

INSERT INTO `globals` VALUES
('activate_ccr_ccd_report', 0, '1'),
('addr_label_type', 0, '1'),
('admit_default_source', 0, ''),
('admit_default_type', 0, ''),
('advance_directives_warning', 0, '0'),
('age_display_format', 0, '0'),
('age_display_limit', 0, '3'),
('allow_appointments_in_feesheet', 0, '0'),
('allow_debug_language', 0, '1'),
('allow_pat_delete', 0, '1'),
('amendments', 0, '1'),
('appt_display_sets_color_1', 0, '#FFFFFF'),
('appt_display_sets_color_2', 0, '#E6E6FF'),
('appt_display_sets_color_3', 0, '#E6FFE6'),
('appt_display_sets_color_4', 0, '#FFE6FF'),
('appt_display_sets_option', 0, '1'),
('appt_overbook_statuses', 0, 'x, ?, %, ^, =, &'),
('atna_audit_cacert', 0, ''),
('atna_audit_host', 0, ''),
('atna_audit_localcert', 0, ''),
('atna_audit_port', 0, '6514'),
('attending_id', 0, ''),
('audit_events_backup', 0, '1'),
('audit_events_cdr', 0, '0'),
('audit_events_order', 0, '1'),
('audit_events_other', 0, '1'),
('audit_events_patient-record', 0, '1'),
('audit_events_query', 0, '0'),
('audit_events_scheduling', 0, '1'),
('audit_events_security-administration', 0, '1'),
('auto_create_new_encounters', 0, '1'),
('auto_writeoff_y_n', 0, '1'),
('backup_log_dir', 0, '/tmp'),
('barcode_label_type', 0, '9'),
('billing_log_option', 0, '1'),
('billing_phone_number', 0, ''),
('bill_to_patient', 0, '0'),
('calendar_appt_style', 0, '2'),
('calendar_interval', 0, '15'),
('calendar_refresh_freq', 0, '360000'),
('calendar_view_type', 0, 'providerAgenda'),
('cash_receipts_report_invoice', 0, '0'),
('certificate_authority_crt', 0, ''),
('certificate_authority_key', 0, ''),
('chart_label_type', 0, '1'),
('checkout_roll_off', 0, '0'),
('claim_type', 0, '0'),
('client_certificate_valid_in_days', 0, '365'),
('cms_1500', 0, '1'),
('cms_1500_box_31_date', 0, '0'),
('cms_1500_box_31_format', 0, '0'),
('cms_left_margin_default', 0, '20'),
('cms_top_margin_default', 0, '24'),
('configuration_import_export', 0, '0'),
('contract_physician_in_feesheet', 0, '0'),
('contract_physician_in_feesheet_name', 0, 'Contractor'),
('couchdb_dbase', 0, ''),
('couchdb_host', 0, 'localhost'),
('couchdb_log', 0, '0'),
('couchdb_pass', 0, ''),
('couchdb_port', 0, '5984'),
('couchdb_user', 0, ''),
('country_data_type', 0, '26'),
('country_list', 0, 'country'),
('css_header', 0, 'style_light.css'),
('currency_decimals', 0, '2'),
('currency_dec_point', 0, '.'),
('currency_thousands_sep', 0, ','),
('date_display_format', 0, '0'),
('daysheet_provider_totals', 0, '1'),
('default_bill_type', 0, '0111'),
('default_chief_complaint', 0, ''),
('default_encounter_view', 0, '0'),
('default_fee_sheet_line_item_provider', 0, '0'),
('default_new_encounter_form', 0, ''),
('default_search_code_type', 0, 'ICD10'),
('default_tab_1', 0, '/interface/main/main_info.php'),
('default_tab_2', 0, '/interface/main/messages/messages.php?form_active=1'),
('disable_calendar', 0, '0'),
('disable_chart_tracker', 0, '0'),
('disable_deprecated_metrics_form', 0, '1'),
('disable_immunizations', 0, '0'),
('disable_non_default_groups', 0, '1'),
('disable_pat_trkr', 0, '0'),
('disable_prescriptions', 0, '0'),
('disable_sql_admin_link', 0, '0'),
('disallow_print_deceased', 0, '0'),
('discharge_status_default', 0, ''),
('discount_by_money', 0, '1'),
('display_canceled_appointments', 0, '1'),
('display_units_in_billing', 0, '0'),
('docs_see_entire_calendar', 0, '0'),
('document_storage_method', 0, '0'),
('drug_screen', 0, '0'),
('drug_testing_percentage', 0, '33'),
('EMAIL_METHOD', 0, 'SMTP'),
('EMAIL_NOTIFICATION_HOUR', 0, '50'),
('Emergency_Login_email_id', 0, ''),
('enable_alert_log', 0, '1'),
('enable_allergy_check', 0, '1'),
('enable_atna_audit', 0, '0'),
('enable_auditlog', 0, '1'),
('enable_auditlog_encryption', 0, '0'),
('enable_cdr', 0, '1'),
('enable_cdr_crp', 0, '1'),
('enable_cdr_crw', 0, '1'),
('enable_cdr_new_crp', 0, '1'),
('enable_cdr_prw', 0, '1'),
('enable_edihistory_in_menu', 0, '1'),
('enable_fees_in_menu', 0, '1'),
('enable_hylafax', 0, '0'),
('enable_pqrs', 0, '1'),
('enable_scanner', 0, '0'),
('encounter_page_size', 0, '20'),
('env_font_size', 0, '14'),
('env_x_dist', 0, '65'),
('env_x_width', 0, '104.775'),
('env_y_dist', 0, '220'),
('env_y_height', 0, '241.3'),
('erx_account_id', 0, '1'),
('erx_account_name', 0, ''),
('erx_account_partner_name', 0, ''),
('erx_account_password', 0, ''),
('erx_allergy_display', 0, '0'),
('erx_debug_setting', 0, '0'),
('erx_default_patient_country', 0, ''),
('erx_enable', 0, '0'),
('erx_import_status_message', 0, '0'),
('erx_medication_display', 0, '0'),
('erx_newcrop_path', 0, 'https://secure.newcropaccounts.com/InterfaceV7/RxEntry.aspx'),
('erx_newcrop_path_soap', 0, 'https://secure.newcropaccounts.com/v7/WebServices/Update1.asmx?WSDL;https://secure.newcropaccounts.com/v7/WebServices/Patient.asmx?WSDL'),
('erx_soap_ttl_allergies', 0, '21600'),
('erx_soap_ttl_medications', 0, '21600'),
('erx_upload_active', 0, '0'),
('esign_all', 0, '0'),
('esign_individual', 0, '1'),
('esign_lock_toggle', 0, '0'),
('esign_report_hide_empty_sig', 0, '1'),
('event_color', 0, '1'),
('expand_document_tree', 0, '0'),
('fifth_dun_msg_set', 0, '150'),
('fifth_dun_msg_text', 0, ''),
('first_dun_msg_set', 0, '30'),
('first_dun_msg_text', 0, ''),
('floating_message_alerts', 0, '0'),
('floating_message_alerts_allergies', 0, '0'),
('floating_message_alerts_timer', 0, '0:20'),
('force_billing_widget_open', 0, '0'),
('fourth_dun_msg_set', 0, '120'),
('fourth_dun_msg_text', 0, ''),
('full_new_patient_form', 0, '1'),
('gbl_currency_symbol', 0, '$'),
('gbl_mask_invoice_number', 0, ''),
('gbl_mask_patient_id', 0, ''),
('gbl_mask_product_id', 0, ''),
('gbl_mdm_category_name', 0, 'Lab Report'),
('gbl_print_log_option', 0, '0'),
('gbl_pt_list_new_window', 0, '0'),
('gbl_pt_list_page_size', 0, '10'),
('gbl_visit_referral_source', 0, '0'),
('gbl_vitals_options', 0, '0'),
('gb_how_sort_categories', 0, '1'),
('gb_how_sort_list', 0, '0'),
('hide_billing_widget', 0, '0'),
('hide_document_encryption', 0, '1'),
('hylafax_basedir', 0, '/var/spool/fax'),
('hylafax_enscript', 0, 'enscript -M Letter -B -e^ --margins=36:36:36:36'),
('hylafax_server', 0, 'localhost'),
('ignore_pnotes_authorization', 0, '1'),
('inactivate_insurance_companies', 0, '0'),
('inhouse_pharmacy', 0, '0'),
('insurance_information', 0, '4'),
('is_client_ssl_enabled', 0, '0'),
('lab_results_category_name', 0, 'Lab Report'),
('language_default', 0, 'English (Standard)'),
('language_menu_showall', 0, '1'),
('ledger_begin_date', 0, 'Y1'),
('libreehr_name', 0, 'LibreHealth EHR'),
('lock_esign_all', 0, '0'),
('lock_esign_individual', 0, '1'),
('maximum_drug_test_yearly', 0, '0'),
('MedicareReferrerIsRenderer', 0, '0'),
('menu_styling_tabs', 0, 'Administrator'),
('minimum_amount_to_print', 0, '1.00'),
('mysql_bin_dir', 0, '/usr/bin'),
('notes_to_display_in_Billing', 0, '3'),
('number_appointments_on_statement', 0, '2'),
('number_of_appts_to_show', 0, '10'),
('num_past_appointments_to_show', 0, '0'),
('omit_employers', 0, '0'),
('online_support_link', 0, 'https://forums.librehealth.io/c/7-support'),
('operating_id', 0, ''),
('ordering_physician_in_feesheet', 0, '0'),
('other1_id', 0, ''),
('other2_id', 0, ''),
('password_compatibility', 0, '1'),
('password_expiration_days', 0, '0'),
('password_grace_time', 0, '0'),
('password_history', 0, '0'),
('patient_id_category_name', 0, 'Patient ID card'),
('patient_photo_category_name', 0, 'Patient Photograph'),
('patient_portal_appt_display_num', 0, '20'),
('patient_reminder_sender_email', 0, ''),
('patient_reminder_sender_name', 0, ''),
('patient_search_results_style', 0, '0'),
('pat_rem_clin_nice', 0, ''),
('pat_trkr_timer', 0, '0:20'),
('payment_delete_begin_date', 0, 'N0'),
('pdf_bottom_margin', 0, '8'),
('pdf_language', 0, 'en'),
('pdf_layout', 0, 'P'),
('pdf_left_margin', 0, '5'),
('pdf_output', 0, 'D'),
('pdf_right_margin', 0, '5'),
('pdf_size', 0, 'LETTER'),
('pdf_top_margin', 0, '5'),
('perl_bin_dir', 0, '/usr/bin'),
('phimail_ccd_enable', 0, '0'),
('phimail_ccr_enable', 0, '0'),
('phimail_enable', 0, '0'),
('phimail_interval', 0, '5'),
('phimail_notify', 0, 'admin'),
('phimail_password', 0, ''),
('phimail_server_address', 0, 'https://phimail.example.com:32541'),
('phimail_username', 0, ''),
('phone_country_code', 0, '1'),
('phone_number_format', 0, '($1) $2-$3'),
('portal_default_status', 0, '- None'),
('portal_onsite_address', 0, 'https://your_web_site.com/libreehr/patients'),
('portal_onsite_appt_modify', 0, '0'),
('portal_onsite_document_download', 0, '1'),
('portal_onsite_enable', 0, '0'),
('portal_search_days', 0, '7'),
('portal_start_days', 0, '14'),
('post_to_date_benchmark', 0, '2017-10-24'),
('pqrs_creator', 0, 'FIXME creator FIXME!!!'),
('pqrs_demosystem', 0, '0'),
('pqrs_registry_id', 0, 'FIXME registry id FIXME!!!'),
('pqrs_registry_name', 0, 'FIXME registry name FIXME!!!'),
('pqrs_vendor_unique_id', 0, 'FIXME vendor unique id FIXME!!!'),
('practice_return_email_path', 0, ''),
('preprinted_cms_1500', 0, '0'),
('print_command', 0, 'lpr -P HPLaserjet6P -o cpi=10 -o lpi=6 -o page-left=72 -o page-top=72'),
('print_next_appointment_on_ledger', 0, '1'),
('ptkr_date_range', 0, '0'),
('ptkr_end_date', 0, 'Y1'),
('ptkr_flag_dblbook', 0, '1'),
('ptkr_pt_list_new_window', 0, '0'),
('ptkr_show_encounter', 0, '1'),
('ptkr_show_pid', 0, '1'),
('ptkr_show_room', 0, '1'),
('ptkr_show_visit_type', 0, '1'),
('ptkr_visit_reason', 0, '0'),
('receipts_by_provider', 0, '0'),
('referring_physician_in_feesheet', 0, '0'),
('replicate_justification', 0, '0'),
('report_itemizing_pqrs', 0, '1'),
('restrict_user_facility', 0, '0'),
('rx_bottom_margin', 0, '30'),
('rx_enable_DEA', 0, '1'),
('rx_enable_NPI', 0, '0'),
('rx_enable_SLN', 0, '0'),
('rx_left_margin', 0, '30'),
('rx_paper_size', 0, 'LETTER'),
('rx_right_margin', 0, '30'),
('rx_show_DEA', 0, '0'),
('rx_show_NPI', 0, '0'),
('rx_show_SLN', 0, '0'),
('rx_top_margin', 0, '72'),
('sales_report_invoice', 0, '2'),
('scanner_output_directory', 0, '/mnt/scan_docs'),
('schedule_end', 0, '17'),
('schedule_start', 0, '8'),
('second_dun_msg_set', 0, '60'),
('second_dun_msg_text', 0, ''),
('secure_password', 0, '0'),
('select_multi_providers', 0, '0'),
('set_facility_cookie', 0, '0'),
('show_aging_on_custom_statement', 0, '0'),
('simplified_copay', 0, '0'),
('simplified_demographics', 0, '0'),
('simplified_prescriptions', 0, '0'),
('SMTP_HOST', 0, 'localhost'),
('SMTP_PASS', 0, ''),
('SMTP_PORT', 0, '25'),
('SMTP_SECURE', 0, ''),
('SMTP_USER', 0, ''),
('specific_application', 0, '0'),
('statement_appearance', 0, '1'),
('statement_bill_note_print', 0, '0'),
('statement_message_to_patient', 0, '0'),
('statement_msg_text', 0, ''),
('state_custom_addlist_widget', 0, '1'),
('state_data_type', 0, '26'),
('state_list', 0, 'state'),
('status_default', 0, ''),
('supervising_physician_in_feesheet', 0, '0'),
('support_encounter_claims', 0, '0'),
('support_fee_sheet_line_item_provider', 0, '0'),
('support_phone_number', 0, ''),
('temporary_files_dir', 0, '/tmp'),
('theme_tabs_layout', 0, 'tabs_style_full.css'),
('third_dun_msg_set', 0, '90'),
('third_dun_msg_text', 0, ''),
('timeout', 0, '7200'),
('time_display_format', 0, '0'),
('translate_appt_categories', 0, '1'),
('translate_document_categories', 0, '1'),
('translate_form_titles', 0, '1'),
('translate_gacl_groups', 0, '1'),
('translate_layout', 0, '1'),
('translate_lists', 0, '1'),
('ubleft_margin_default', 0, '14'),
('ubtop_margin_default', 0, '07'),
('units_of_measurement', 0, '1'),
('use_custom_daysheet', 0, '1'),
('use_custom_immun_list', 0, '0'),
('use_custom_statement', 0, '0'),
('use_dunning_message', 0, '0'),
('use_statement_print_exclusion', 0, '0'),
('us_weight_format', 0, '1');

-- --------------------------------------------------------

--
-- Table structure for table `gprelations`
--

CREATE TABLE `gprelations` (
  `type1` int(2) NOT NULL,
  `id1` bigint(20) NOT NULL,
  `type2` int(2) NOT NULL,
  `id2` bigint(20) NOT NULL,
  PRIMARY KEY (`type1`,`id1`,`type2`,`id2`),
  KEY `key2` (`type2`,`id2`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='general purpose relations';

-- --------------------------------------------------------

--
-- Table structure for table `groups`
--

CREATE TABLE `groups` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `name` longtext,
  `user` longtext,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `groups`
--

INSERT INTO `groups` VALUES
(1, '[[init_group]]', '[[admin_username]]');

-- --------------------------------------------------------

--
-- Table structure for table `history_data`
--

CREATE TABLE `history_data` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `coffee` longtext,
  `tobacco` longtext,
  `alcohol` longtext,
  `sleep_patterns` longtext,
  `exercise_patterns` longtext,
  `seatbelt_use` longtext,
  `counseling` longtext,
  `hazardous_activities` longtext,
  `recreational_drugs` longtext,
  `last_breast_exam` varchar(255) DEFAULT NULL,
  `last_mammogram` varchar(255) DEFAULT NULL,
  `last_gynocological_exam` varchar(255) DEFAULT NULL,
  `last_rectal_exam` varchar(255) DEFAULT NULL,
  `last_prostate_exam` varchar(255) DEFAULT NULL,
  `last_physical_exam` varchar(255) DEFAULT NULL,
  `last_sigmoidoscopy_colonoscopy` varchar(255) DEFAULT NULL,
  `last_ecg` varchar(255) DEFAULT NULL,
  `last_cardiac_echo` varchar(255) DEFAULT NULL,
  `last_retinal` varchar(255) DEFAULT NULL,
  `last_fluvax` varchar(255) DEFAULT NULL,
  `last_pneuvax` varchar(255) DEFAULT NULL,
  `last_ldl` varchar(255) DEFAULT NULL,
  `last_hemoglobin` varchar(255) DEFAULT NULL,
  `last_psa` varchar(255) DEFAULT NULL,
  `last_exam_results` varchar(255) DEFAULT NULL,
  `history_mother` longtext,
  `dc_mother` text,
  `history_father` longtext,
  `dc_father` text,
  `history_siblings` longtext,
  `dc_siblings` text,
  `history_offspring` longtext,
  `dc_offspring` text,
  `history_spouse` longtext,
  `dc_spouse` text,
  `relatives_cancer` longtext,
  `relatives_tuberculosis` longtext,
  `relatives_diabetes` longtext,
  `relatives_high_blood_pressure` longtext,
  `relatives_heart_problems` longtext,
  `relatives_stroke` longtext,
  `relatives_epilepsy` longtext,
  `relatives_mental_illness` longtext,
  `relatives_suicide` longtext,
  `cataract_surgery` datetime DEFAULT NULL,
  `tonsillectomy` datetime DEFAULT NULL,
  `cholecystestomy` datetime DEFAULT NULL,
  `heart_surgery` datetime DEFAULT NULL,
  `hysterectomy` datetime DEFAULT NULL,
  `hernia_repair` datetime DEFAULT NULL,
  `hip_replacement` datetime DEFAULT NULL,
  `knee_replacement` datetime DEFAULT NULL,
  `appendectomy` datetime DEFAULT NULL,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `name_1` varchar(255) DEFAULT NULL,
  `value_1` varchar(255) DEFAULT NULL,
  `name_2` varchar(255) DEFAULT NULL,
  `value_2` varchar(255) DEFAULT NULL,
  `additional_history` text,
  `exams` text,
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_dx_order_code`
--

CREATE TABLE `icd10_dx_order_code` (
  `dx_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `dx_code` varchar(7) DEFAULT NULL,
  `formatted_dx_code` varchar(10) DEFAULT NULL,
  `valid_for_coding` char(1) DEFAULT NULL,
  `short_desc` varchar(60) DEFAULT NULL,
  `long_desc` varchar(300) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `dx_id` (`dx_id`),
  KEY `formatted_dx_code` (`formatted_dx_code`),
  KEY `active` (`active`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_gem_dx_9_10`
--

CREATE TABLE `icd10_gem_dx_9_10` (
  `map_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `dx_icd9_source` varchar(5) DEFAULT NULL,
  `dx_icd10_target` varchar(7) DEFAULT NULL,
  `flags` varchar(5) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `map_id` (`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_gem_dx_10_9`
--

CREATE TABLE `icd10_gem_dx_10_9` (
  `map_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `dx_icd10_source` varchar(7) DEFAULT NULL,
  `dx_icd9_target` varchar(5) DEFAULT NULL,
  `flags` varchar(5) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `map_id` (`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_gem_pcs_9_10`
--

CREATE TABLE `icd10_gem_pcs_9_10` (
  `map_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pcs_icd9_source` varchar(5) DEFAULT NULL,
  `pcs_icd10_target` varchar(7) DEFAULT NULL,
  `flags` varchar(5) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `map_id` (`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_gem_pcs_10_9`
--

CREATE TABLE `icd10_gem_pcs_10_9` (
  `map_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pcs_icd10_source` varchar(7) DEFAULT NULL,
  `pcs_icd9_target` varchar(5) DEFAULT NULL,
  `flags` varchar(5) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `map_id` (`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_pcs_order_code`
--

CREATE TABLE `icd10_pcs_order_code` (
  `pcs_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `pcs_code` varchar(7) DEFAULT NULL,
  `valid_for_coding` char(1) DEFAULT NULL,
  `short_desc` varchar(60) DEFAULT NULL,
  `long_desc` varchar(300) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `pcs_id` (`pcs_id`),
  KEY `pcs_code` (`pcs_code`),
  KEY `active` (`active`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_reimbr_dx_9_10`
--

CREATE TABLE `icd10_reimbr_dx_9_10` (
  `map_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(8) DEFAULT NULL,
  `code_cnt` tinyint(4) DEFAULT NULL,
  `ICD9_01` varchar(5) DEFAULT NULL,
  `ICD9_02` varchar(5) DEFAULT NULL,
  `ICD9_03` varchar(5) DEFAULT NULL,
  `ICD9_04` varchar(5) DEFAULT NULL,
  `ICD9_05` varchar(5) DEFAULT NULL,
  `ICD9_06` varchar(5) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `map_id` (`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `icd10_reimbr_pcs_9_10`
--

CREATE TABLE `icd10_reimbr_pcs_9_10` (
  `map_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(8) DEFAULT NULL,
  `code_cnt` tinyint(4) DEFAULT NULL,
  `ICD9_01` varchar(5) DEFAULT NULL,
  `ICD9_02` varchar(5) DEFAULT NULL,
  `ICD9_03` varchar(5) DEFAULT NULL,
  `ICD9_04` varchar(5) DEFAULT NULL,
  `ICD9_05` varchar(5) DEFAULT NULL,
  `ICD9_06` varchar(5) DEFAULT NULL,
  `active` tinyint(4) DEFAULT '0',
  `revision` int(11) DEFAULT '0',
  UNIQUE KEY `map_id` (`map_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `immunizations`
--

CREATE TABLE `immunizations` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `patient_id` int(11) DEFAULT NULL,
  `administered_date` datetime DEFAULT NULL,
  `immunization_id` int(11) DEFAULT NULL,
  `cvx_code` varchar(10) DEFAULT NULL,
  `manufacturer` varchar(100) DEFAULT NULL,
  `lot_number` varchar(50) DEFAULT NULL,
  `administered_by_id` bigint(20) DEFAULT NULL,
  `administered_by` varchar(255) DEFAULT NULL COMMENT 'Alternative to administered_by_id',
  `education_date` date DEFAULT NULL,
  `vis_date` date DEFAULT NULL COMMENT 'Date of VIS Statement',
  `note` text,
  `create_date` datetime DEFAULT NULL,
  `update_date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `created_by` bigint(20) DEFAULT NULL,
  `updated_by` bigint(20) DEFAULT NULL,
  `amount_administered` float DEFAULT NULL,
  `amount_administered_unit` varchar(50) DEFAULT NULL,
  `expiration_date` date DEFAULT NULL,
  `route` varchar(100) DEFAULT NULL,
  `administration_site` varchar(100) DEFAULT NULL,
  `added_erroneously` tinyint(1) NOT NULL DEFAULT '0',
  `external_id` varchar(20) DEFAULT NULL,
  `completion_status` varchar(50) DEFAULT NULL,
  `information_source` varchar(31) DEFAULT NULL,
  `refusal_reason` varchar(31) DEFAULT NULL,
  `ordering_provider` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `patient_id` (`patient_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `insurance_companies`
--

CREATE TABLE `insurance_companies` (
  `id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `attn` varchar(255) DEFAULT NULL,
  `cms_id` varchar(15) DEFAULT NULL,
  `ins_type_code` tinyint(2) DEFAULT NULL,
  `x12_receiver_id` varchar(25) DEFAULT NULL,
  `x12_default_partner_id` int(11) DEFAULT NULL,
  `alt_cms_id` varchar(15) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `insurance_data`
--

CREATE TABLE `insurance_data` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `type` enum('primary','secondary','tertiary') DEFAULT NULL,
  `provider` varchar(255) DEFAULT NULL,
  `plan_name` varchar(255) DEFAULT NULL,
  `policy_number` varchar(255) DEFAULT NULL,
  `group_number` varchar(255) DEFAULT NULL,
  `subscriber_lname` varchar(255) DEFAULT NULL,
  `subscriber_mname` varchar(255) DEFAULT NULL,
  `subscriber_fname` varchar(255) DEFAULT NULL,
  `subscriber_relationship` varchar(255) DEFAULT NULL,
  `subscriber_ss` varchar(255) DEFAULT NULL,
  `subscriber_DOB` date DEFAULT NULL,
  `subscriber_street` varchar(255) DEFAULT NULL,
  `subscriber_postal_code` varchar(255) DEFAULT NULL,
  `subscriber_city` varchar(255) DEFAULT NULL,
  `subscriber_state` varchar(255) DEFAULT NULL,
  `subscriber_country` varchar(255) DEFAULT NULL,
  `subscriber_phone` varchar(255) DEFAULT NULL,
  `subscriber_employer` varchar(255) DEFAULT NULL,
  `subscriber_employer_street` varchar(255) DEFAULT NULL,
  `subscriber_employer_postal_code` varchar(255) DEFAULT NULL,
  `subscriber_employer_state` varchar(255) DEFAULT NULL,
  `subscriber_employer_country` varchar(255) DEFAULT NULL,
  `subscriber_employer_city` varchar(255) DEFAULT NULL,
  `copay` varchar(255) DEFAULT NULL,
  `date` date NOT NULL DEFAULT '0000-00-00',
  `eDate` date NOT NULL DEFAULT '0000-00-00',
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `subscriber_sex` varchar(25) DEFAULT NULL,
  `accept_assignment` varchar(5) NOT NULL DEFAULT 'TRUE',
  `policy_type` varchar(25) NOT NULL DEFAULT '',
  `inactive` tinyint(1) DEFAULT '0',
  `inactive_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `pid_type_date_inactivetime` (`pid`,`type`,`date`,`inactive_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `insurance_numbers`
--

CREATE TABLE `insurance_numbers` (
  `id` int(11) NOT NULL DEFAULT '0',
  `provider_id` int(11) NOT NULL DEFAULT '0',
  `insurance_company_id` int(11) DEFAULT NULL,
  `provider_number` varchar(20) DEFAULT NULL,
  `rendering_provider_number` varchar(20) DEFAULT NULL,
  `group_number` varchar(20) DEFAULT NULL,
  `provider_number_type` varchar(4) DEFAULT NULL,
  `rendering_provider_number_type` varchar(4) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `issue_encounter`
--

CREATE TABLE `issue_encounter` (
  `pid` int(11) NOT NULL,
  `list_id` int(11) NOT NULL,
  `encounter` int(11) NOT NULL,
  `resolved` tinyint(1) NOT NULL,
  PRIMARY KEY (`pid`,`list_id`,`encounter`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `issue_types`
--

CREATE TABLE `issue_types` (
  `active` tinyint(1) NOT NULL DEFAULT '1',
  `category` varchar(75) NOT NULL DEFAULT '',
  `type` varchar(75) NOT NULL DEFAULT '',
  `plural` varchar(75) NOT NULL DEFAULT '',
  `singular` varchar(75) NOT NULL DEFAULT '',
  `abbreviation` varchar(75) NOT NULL DEFAULT '',
  `style` smallint(6) NOT NULL DEFAULT '0',
  `force_show` smallint(6) NOT NULL DEFAULT '0',
  `ordering` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`category`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `issue_types`
--

INSERT INTO `issue_types` VALUES
(1, 'default', 'allergy', 'Allergies', 'Allergy', 'A', 0, 1, 20),
(1, 'default', 'dental', 'Dental Issues', 'Dental', 'D', 0, 0, 50),
(1, 'default', 'medical_problem', 'Medical Problems', 'Problem', 'P', 0, 1, 10),
(1, 'default', 'medication', 'Medications', 'Medication', 'M', 0, 1, 30),
(1, 'default', 'surgery', 'Surgeries', 'Surgery', 'S', 0, 0, 40),
(1, 'ippf_specific', 'allergy', 'Allergies', 'Allergy', 'Y', 0, 1, 20),
(1, 'ippf_specific', 'contraceptive', 'Contraception', 'Contraception', 'C', 4, 0, 60),
(1, 'ippf_specific', 'ippf_gcac', 'Abortions', 'Abortion', 'A', 3, 0, 50),
(1, 'ippf_specific', 'medical_problem', 'Medical Problems', 'Problem', 'P', 0, 1, 10),
(1, 'ippf_specific', 'medication', 'Medications', 'Medication', 'M', 0, 1, 30),
(1, 'ippf_specific', 'surgery', 'Surgeries', 'Surgery', 'S', 0, 0, 40);

-- --------------------------------------------------------

--
-- Table structure for table `lang_constants`
--

CREATE TABLE `lang_constants` (
  `cons_id` int(11) NOT NULL AUTO_INCREMENT,
  `constant_name` mediumtext CHARACTER SET utf8 COLLATE utf8_bin,
  UNIQUE KEY `cons_id` (`cons_id`),
  KEY `constant_name` (`constant_name`(100))
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=7550 ;

--
-- Dumping data for table `lang_constants`
--

INSERT INTO `lang_constants` VALUES
(1, 'A'),
(2, 'A check number or claim number to identify the payment'),
(3, 'A client certificate for the admin user'),
(4, 'A clinical document is attached'),
(5, 'A clinical document is attached.'),
(6, 'A code of this type is already selected. Erase the field first if you need to replace it.'),
(7, 'A distributor is required'),
(8, 'A GCAC visit form should be added to this visit.'),
(9, 'A lot number is required'),
(10, 'A lot number is required!'),
(11, 'A lowercase letter'),
(12, 'A number'),
(13, 'A Patient Must Be Selected to Generate This Report'),
(14, 'A patient with this ID already exists.'),
(15, 'A patient with this name already exists.'),
(16, 'A patient with this SS already exists.'),
(17, 'A positive number will show that many past appointments on a Widget in the Patient Summary screen (a negative number will show the past appointments in descending order)'),
(18, 'A positive number will show that many past appointments on a Widget in the Patient Summary screen.'),
(19, 'A referral source may be specified for each visit.'),
(20, 'A related IPPF code is required!'),
(21, 'A special character'),
(22, 'A unique value to identify this field, not visible to the user'),
(23, 'A visit already exists for this patient today. Click Cancel to open it, or OK to proceed with creating a new one.'),
(24, 'a.c.'),
(25, 'a.m.'),
(26, 'A/F Level Right:'),
(27, 'AB'),
(28, 'Abbreviation'),
(29, 'Abcess:'),
(30, 'Abdominal'),
(31, 'Able to Bear Weight four (4) steps:'),
(32, 'Abn'),
(33, 'ABN1'),
(34, 'Abnormal'),
(35, 'Abnormal Blood Test'),
(36, 'Abnormal Hair Growth'),
(37, 'Abnormal Mammogram'),
(38, 'Abort'),
(39, 'Abortion'),
(40, 'Abortion Issues'),
(41, 'Abortion Method'),
(42, 'Abortion-Related Categories'),
(43, 'Abortions'),
(44, 'About the calendar'),
(45, 'Above upper panic limits'),
(46, 'Absences by Diagnosis'),
(47, 'Accept Assignment'),
(48, 'Accept Payment for'),
(49, 'Accept Payment for '),
(50, 'Accepts Assignment'),
(51, 'Access Control'),
(52, 'Access Control List Administration'),
(53, 'Access date'),
(54, 'Access not allowed'),
(55, 'Access Not Authorized'),
(56, 'Access Your Patient Portal'),
(57, 'Accident'),
(58, 'Account Id issued for NewCrop eRx service, used to separate multi-facility accounts.'),
(59, 'Account Name'),
(60, 'Account Name issued for NewCrop eRx service.'),
(61, 'Account Password issued for NewCrop eRx service.'),
(62, 'Accounting'),
(63, 'Acct'),
(64, 'Aches'),
(65, 'Acknowledgment Requested (ISA14)'),
(66, 'Acknowledgments, Licensing and Certification'),
(67, 'ACL'),
(68, 'ACL Administration'),
(69, 'ACL Administration Not Authorized'),
(70, 'ACL Updated Successfully'),
(71, 'Acne'),
(72, 'Act'),
(73, 'Act Date'),
(74, 'Action'),
(75, 'Actions'),
(76, 'Activate'),
(77, 'Activate CCR/CCD Reporting'),
(78, 'Active'),
(79, 'Active Alert'),
(80, 'Active Alert Rules'),
(81, 'Active Alerts/Reminders'),
(82, 'Active Encounter'),
(83, 'Active Issue Codes'),
(84, 'Active lists'),
(85, 'Active Patient'),
(86, 'Active Plans'),
(87, 'Activity'),
(88, 'Activity Type'),
(89, 'Actual Receipts'),
(90, 'Acute Intoxication/Withdrawal'),
(91, 'Acute Manifestation of a Chronic Condition'),
(92, 'Acute on Chronic'),
(93, 'add'),
(94, 'Add'),
(95, 'ADD'),
(96, 'Add a Company'),
(97, 'Add a condition'),
(98, 'Add a Pharmacy'),
(99, 'Add all rules to plan'),
(100, 'add an event for '),
(101, 'Add as a new note'),
(102, 'Add as New'),
(103, 'Add as new patient'),
(104, 'Add Buttons'),
(105, 'Add Buttons for Special Chars,Texts to be Displayed on Top of the Editor for inclusion to the text on a Click'),
(106, 'Add Category'),
(107, 'Add Constant'),
(108, 'Add Context'),
(109, 'Add Copay'),
(110, 'Add criteria'),
(111, 'Add Custom Button'),
(112, 'Add Diagnosis'),
(113, 'Add Drug'),
(114, 'Add Encounter'),
(115, 'Add encounter/notes'),
(116, 'Add Facility'),
(117, 'Add Field'),
(118, 'Add following lines to the Apache configuration file'),
(119, 'Add Group'),
(120, 'Add ICD Code'),
(121, 'Add Immunization'),
(122, 'Add is not authorized!'),
(123, 'Add Issue'),
(124, 'Add item to track'),
(125, 'Add Language'),
(126, 'Add New'),
(127, 'Add new'),
(128, 'Add new category : '),
(129, 'Add new certificates to the Apache configuration file'),
(130, 'Add New Component'),
(131, 'Add New Components'),
(132, 'Add New Group'),
(133, 'Add New Issue'),
(134, 'Add new lot and transaction'),
(135, 'Add New Note'),
(136, 'Add new note'),
(137, 'Add New Partner'),
(138, 'Add New Patient'),
(139, 'ADD NEW PLAN'),
(140, 'Add Note'),
(141, 'Add Patient Record'),
(142, 'Add Prescription'),
(143, 'Add Procedure'),
(144, 'Add Provider Number'),
(145, 'Add Rehab'),
(146, 'Add Rule'),
(147, 'Add to'),
(148, 'Add to Medication List'),
(149, 'Add Top Level'),
(150, 'Add Transaction'),
(151, 'Add User'),
(152, 'Add User To Group'),
(153, 'Add/Edit eRx'),
(154, 'Add/Edit Patient Transaction'),
(155, 'added'),
(156, 'Adding demographics is not authorized.'),
(157, 'Adding item to track failed'),
(158, 'Addison Syndrom'),
(159, 'Addison Syndrome'),
(160, 'Additional Attributes'),
(161, 'Additional Diagnosis:'),
(162, 'Additional History'),
(163, 'Additional history notes'),
(164, 'Additional Info'),
(165, 'Additional Labs'),
(166, 'Additional Notes'),
(167, 'Additional notes for this result or recommendation'),
(168, 'Additional Notes:'),
(169, 'Additional Notes: '),
(170, 'Additional X-RAY Notes:'),
(171, 'Additionally, the corresponding US Snomed Extension Package can be imported separately after installing the International (English version) Snomed Release'),
(172, 'addonly'),
(173, 'Addr Bk'),
(174, 'Addr Book'),
(175, 'Address'),
(176, 'Address and Postal Code'),
(177, 'Address and State'),
(178, 'Address Book'),
(179, 'Address book entry for the company performing this procedure'),
(180, 'Address book entry for the distributor'),
(181, 'Address book entry for the vendor'),
(182, 'Address Book Types'),
(183, 'Address Label'),
(184, 'Address Labels'),
(185, 'Address Only'),
(186, 'Address, State and Postal Code'),
(187, 'Address1'),
(188, 'Address2'),
(189, 'ADDRESSEE'),
(190, 'Adj'),
(191, 'Adj Amount'),
(192, 'Adjust'),
(193, 'Adjustment'),
(194, 'Adjustment Amt'),
(195, 'Adjustment Reasons'),
(196, 'Adjustment value for code '),
(197, 'Adjustments'),
(198, 'Adm adjust'),
(199, 'Admin'),
(200, 'Admin Email Address'),
(201, 'Administer Via'),
(202, 'Administered'),
(203, 'Administered By'),
(204, 'Administered Date'),
(205, 'Administered Site'),
(206, 'Administration'),
(207, 'Administration Site'),
(208, 'Administrators'),
(209, 'Administrators can do anything'),
(210, 'Admit Date'),
(211, 'Adopted Child'),
(212, 'Adult Weight Screening and Follow-Up'),
(213, 'Adult Weight Screening and Follow-Up (CQM)'),
(214, 'Advance Directive'),
(215, 'Advance Directives'),
(216, 'Advance Directives Warning'),
(217, 'Advance Options'),
(218, 'Advanced'),
(219, 'Advice'),
(220, 'Afar'),
(221, 'Affect normal'),
(222, 'Afrikaans'),
(223, 'After hrs calls'),
(224, 'After migration from the old password mechanisms where passwords are stored in the users table without salt is complete, this flag should be set to false so that only authentication by the new method is possible'),
(225, 'After performing above configurations, import the admin client certificate to the browser and restart Apache server (empty password).'),
(226, 'After saving the PDF, click [View Log] to check for errors.'),
(227, 'After saving the TEXT file(s), click [View Log] to check for errors.'),
(228, 'After saving your batch, click [View Log] to check for errors.'),
(229, 'After that the Match column will show the selected patient ID, or 0 to create.'),
(230, 'After the information is correctly entered, click the Save button.'),
(231, 'After Uploading click the button "Import"'),
(232, 'AfterCare Planning'),
(233, 'Again'),
(234, 'Age'),
(235, 'Age By'),
(236, 'Age Category'),
(237, 'Age data is out of range.'),
(238, 'Age Display Format'),
(239, 'Age format for "age from" is not valid'),
(240, 'Age format for "age up to" is not valid'),
(241, 'Age From'),
(242, 'Age in Years for Display Format Change'),
(243, 'Age max'),
(244, 'Age min'),
(245, 'Age Range'),
(246, 'Aging Columns'),
(247, 'Aging Columns:'),
(248, 'Akan'),
(249, 'Albanian'),
(250, 'Alcohol'),
(251, 'Alcohol consumption'),
(252, 'Alcohol Use'),
(253, 'Alert Count'),
(254, 'Alert Time'),
(255, 'Alerts'),
(256, 'Alerts Log'),
(257, 'Alerts/Reminders'),
(258, 'ALEUT'),
(259, 'All'),
(260, 'ALL'),
(261, 'All (Collated Format A)'),
(262, 'All (Collated Format B)'),
(263, 'All (Cumulative)'),
(264, 'All Alerts'),
(265, 'All Automated Measure Calculations (AMC)'),
(266, 'All Categories'),
(267, 'All Clinical Quality Measures (CQM)'),
(268, 'All Codes'),
(269, 'All Day'),
(270, 'All day event'),
(271, 'All demographics fields, with search and duplication check'),
(272, 'All Facilities'),
(273, 'All Injuries/Problems/Issues'),
(274, 'All Languages Allowed'),
(275, 'All Official Clinical Quality Measures (CQM) Measure Groups'),
(276, 'All or part of the first name'),
(277, 'All or part of the last name'),
(278, 'All or part of the organization'),
(279, 'All Patients'),
(280, 'All Products'),
(281, 'All Providers'),
(282, 'All Reviewed and Negative:'),
(283, 'All Topics'),
(284, 'All Users'),
(285, 'Allergic'),
(286, 'Allergies'),
(287, 'Allergies:'),
(288, 'Allergy'),
(289, 'Allergy import successfully completed'),
(290, 'Allergy Issue List'),
(291, 'Allergy Reaction'),
(292, 'ALLERGY WARNING'),
(293, 'Allergy Warning'),
(294, 'Allocate'),
(295, 'Allow'),
(296, 'Allow all available languages as choices on menu at login.'),
(297, 'Allow creation of claims containing diagnoses but not procedures or charges. Most clinics do not want this.'),
(298, 'Allow Debugging Language'),
(299, 'Allow Email'),
(300, 'Allow email messages?'),
(301, 'Allow Email?'),
(302, 'Allow Encounter Claims'),
(303, 'Allow Health Information Exchange'),
(304, 'Allow Immunization Info Sharing'),
(305, 'Allow Immunization Registry Use'),
(306, 'Allow Mail Message'),
(307, 'Allow Patient Flow Board to Select Patients for Drug Testing.'),
(308, 'Allow Patient Portal'),
(309, 'Allow SMS'),
(310, 'Allow SMS (text messages)?'),
(311, 'Allow submitted events to be made active instantly?'),
(312, 'Allow telephone messages?'),
(313, 'Allow users to publish Global Events'),
(314, 'Allow users to publish Personal Calendars'),
(315, 'Allow Voice Message'),
(316, 'Allowed'),
(317, 'Allowed Languages'),
(318, 'Allowed(c)'),
(319, 'Allows E-Sign on the entire encounter'),
(320, 'Allows E-Signing Individual Forms'),
(321, 'Allows Mail'),
(322, 'Allows Voice msgs'),
(323, 'already exists'),
(324, 'already exists.'),
(325, 'Already used, choose another identifier'),
(326, 'Already used, choose another title'),
(327, 'Alt Address'),
(328, 'alter'),
(329, 'Alternatively, you may use the search page to upload an electronic remittance (X12 835) file that you have obtained from your payer or clearinghouse.  You can do this by clicking the Browse button and selecting the file to upload, and then clicking Search to perform the upload and display the corresponding invoices.  In this case the other parameters mentioned above do not apply and will be ignored.  Uploading saves the file but does not yet process its contents -- that is done separately as described below.'),
(330, 'AM'),
(331, 'AM Program'),
(332, 'AMC'),
(333, 'AMC Tracking'),
(334, 'AMC-2011'),
(335, 'AMC-2014'),
(336, 'AMC-2014 Stage I'),
(337, 'AMC-2014 Stage II'),
(338, 'Amend Existing Note'),
(339, 'Amendment From'),
(340, 'Amendment Status'),
(341, 'Amendments'),
(342, 'Amendments for'),
(343, 'American Indian'),
(344, 'American Indian or Alaska Native'),
(345, 'AMEX'),
(346, 'Amharic'),
(347, 'Amount'),
(348, 'Amount Administered'),
(349, 'Amount Charges'),
(350, 'Amount for Past Balance'),
(351, 'Amount for This Visit'),
(352, 'Amount Paid'),
(353, 'Amount:'),
(354, 'Amt Billed'),
(355, 'An end date later than the start date is required for repeated events!'),
(356, 'An error occured signing the form'),
(357, 'An error occurred while dumping LibreEHR web directory tree'),
(358, 'An error occurred while dumping phpGACL web directory tree'),
(359, 'An error occurred while dumping SQL-Ledger web directory tree'),
(360, 'An incomplete GCAC issue has been created and linked. Someone will need to complete it later.'),
(361, 'An undefined error occurred, please contact your systems administrator.'),
(362, 'An unexpected error has occurred.'),
(363, 'An uppercase letter'),
(364, 'Analyzed'),
(365, 'And'),
(366, 'AND'),
(367, 'and'),
(368, 'and '),
(369, 'and all subordinate data? This action will be logged'),
(370, 'and modifier'),
(371, 'and processed.'),
(372, 'and restart Apache server.'),
(373, 'and the Reason is'),
(374, 'Anemia'),
(375, 'Ankle'),
(376, 'Ankle + heel'),
(377, 'Ankle Evaluation Form'),
(378, 'Ankle Problems'),
(379, 'Ankylosing Sondlilitis'),
(380, 'Ankylosing Spondlilitis'),
(381, 'Anorexia'),
(382, 'Another thing you can do in the posting window is request secondary billing. If you select this checkbox before saving, then the original claim will be re-opened and queued on the Billing page, and will be processed during the next billing run.'),
(383, 'ante'),
(384, 'Anus nl, no rectal tenderness/mass'),
(385, 'Anxiety'),
(386, 'Any'),
(387, 'Any Category'),
(388, 'Any part of the desired code or its description'),
(389, 'Any part of the desired specialty'),
(390, 'Any part of the drug id or drug name'),
(391, 'Any part of the immunization id or immunization name'),
(392, 'Any part of the patient name, or "last,first", or "X-Y"'),
(393, 'Anyother Relevant Information'),
(394, 'API key for SMS Gateway.'),
(395, 'Apnea'),
(396, 'Appearance'),
(397, 'Appearance:'),
(398, 'Append this note'),
(399, 'Append to the existing note'),
(400, 'Append to this note'),
(401, 'Append to This Note'),
(402, 'Appendectomy'),
(403, 'appendectomy'),
(404, 'Applicable Patients'),
(405, 'Application'),
(406, 'Application name for login page and main window title.'),
(407, 'Application Receiver Code (GS03 - If blank ISA08 will be used)'),
(408, 'Application Sender Code (GS02)'),
(409, 'Application Title'),
(410, 'Applies to the Vitals form and Growth Chart'),
(411, 'Applies to Vitals form'),
(412, 'Apply the changes to the Current event only, to this and all Future occurrences, or to All occurrences?'),
(413, 'apply to affected area'),
(414, 'apply to skin'),
(415, 'Applying'),
(416, 'Applying Patch to site'),
(417, 'Appointment'),
(418, 'Appointment Date'),
(419, 'Appointment Display Style'),
(420, 'Appointment Reminder Rule'),
(421, 'Appointment status'),
(422, 'Appointment Statuses'),
(423, 'Appointment within'),
(424, 'Appointment/Event Color'),
(425, 'Appointments'),
(426, 'Appointments (write optional)'),
(427, 'Appointments (write,wsome optional)'),
(428, 'Appointments - Onsite Patient Portal - Number to Display'),
(429, 'Appointments - Patient Summary - Number to Display'),
(430, 'Appointments and Encounters'),
(431, 'Appointments Report'),
(432, 'Appointments-Encounters Report'),
(433, 'Appropriate Testing for Children with Pharyngitis (CQM)'),
(434, 'Approve'),
(435, 'Approve the patient from Patient/Client->Import->Pending Approval'),
(436, 'Approved'),
(437, 'Approved Events Administration'),
(438, 'Approved Successfully'),
(439, 'Appt Time'),
(440, 'Appt-Enc'),
(441, 'Appts'),
(442, 'Apr'),
(443, 'April'),
(444, 'Arabic'),
(445, 'Aragonese'),
(446, 'Archive'),
(447, 'Are access control group names to be translated?'),
(448, 'Are appointment category names to be translated?'),
(449, 'Are document category names to be translated?'),
(450, 'Are fees charged for this type?'),
(451, 'Are patient note titles to be translated?'),
(452, 'Are the codes stored in external sql tables (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(453, 'Are you prepared to complete a new GCAC issue for this visit?'),
(454, 'Are you sure to post for today?'),
(455, 'Are you sure you want to approve these events?'),
(456, 'Are you sure you want to cancel your changes?'),
(457, 'Are you sure you want to completely remove this form?'),
(458, 'Are you sure you want to delete'),
(459, 'Are you sure you want to delete this disclosure?'),
(460, 'Are you sure you want to delete this event?'),
(461, 'Are you sure you want to delete this item from the database?'),
(462, 'Are you sure you want to delete this note?'),
(463, 'Are you sure you want to delete this plan?'),
(464, 'Are you sure you want to edit these events?'),
(465, 'Are you sure you want to hide these events?'),
(466, 'Are you sure you want to transmit it again?'),
(467, 'Are you sure you want to view these events?'),
(468, 'Are you sure you wish to delete the entire group named'),
(469, 'Are you sure you wish to delete the entire list'),
(470, 'Are you sure you wish to delete the field in'),
(471, 'Are you sure you wish to delete the selected fields?'),
(472, 'Are you sure you''d like to continue with these actions?'),
(473, 'Area not specified'),
(474, 'Arm'),
(475, 'Armenian'),
(476, 'Arrive Time'),
(477, 'Arrythmia'),
(478, 'Arthritis'),
(479, 'Arthritis / degen joint diseas'),
(480, 'Arthritis / degen joint disease'),
(481, 'as'),
(482, 'As Of'),
(483, 'ASC'),
(484, 'Asian'),
(485, 'Assamese'),
(486, 'Assess Penicillin Allergy'),
(487, 'Assessment'),
(488, 'Assigned To'),
(489, 'Assistant'),
(490, 'Asthma'),
(491, 'at'),
(492, 'At least one search parameter is required if you select All.'),
(493, 'At the Navicular'),
(494, 'At the Navicular:'),
(495, 'Athletic team'),
(496, 'Athletic Team'),
(497, 'Athletic/Injury'),
(498, 'ATNA audit CA certificate'),
(499, 'ATNA audit host'),
(500, 'ATNA audit local certificate'),
(501, 'ATNA audit port'),
(502, 'Attending physician'),
(503, 'Attention'),
(504, 'Attn'),
(505, 'Audiological physician'),
(506, 'Audit CDR Engine Queries'),
(507, 'Audit Log Tamper'),
(508, 'Audit Log Tamper Report'),
(509, 'Audit Logging Backups'),
(510, 'Audit Logging Miscellaneous'),
(511, 'Audit Logging Order'),
(512, 'Audit Logging Patient Record'),
(513, 'Audit Logging Scheduling'),
(514, 'Audit Logging Security Administration'),
(515, 'Audit Logging SELECT Query'),
(516, 'Aug'),
(517, 'August'),
(518, 'Aunt'),
(519, 'Auth'),
(520, 'Auth/notes'),
(521, 'Authenticator'),
(522, 'Author'),
(523, 'Authorization group'),
(524, 'Authorization Status'),
(525, 'Authorizations'),
(526, 'Authorize'),
(527, 'Authorize - any encounters'),
(528, 'Authorize - my encounters'),
(529, 'Authorize.net'),
(530, 'Authorized'),
(531, 'Authorized Only'),
(532, 'Auto Send'),
(533, 'Auto Sign-Off [days]'),
(534, 'Auto Transfer'),
(535, 'Auto-Create New Encounters'),
(536, 'Auto-generated'),
(537, 'Automated Measure Calculations (AMC)'),
(538, 'Automated Measure Calculations (AMC) - 2011'),
(539, 'Automated Measure Calculations (AMC) - 2014'),
(540, 'Automated Measure Calculations (AMC) - 2014 Stage I'),
(541, 'Automated Measure Calculations (AMC) - 2014 Stage II'),
(542, 'Automated Measure Calculations (AMC) Tracking'),
(543, 'Automated Measures (AMC)'),
(544, 'Automatic'),
(545, 'Automatically create a new encounter when an appointment check in status is selected.'),
(546, 'Automatically create a new encounter when appointment status is set to "@" (arrived).'),
(547, 'Automatically replicate justification codes in Fee Sheet'),
(548, 'Automatically replicate justification codes in Fee Sheet (basically fills in the blanks with the justification code above it).'),
(549, 'Automobile Medical'),
(550, 'autosaved'),
(551, 'Available categories'),
(552, 'Available Times'),
(553, 'Available Tracks'),
(554, 'Avaric'),
(555, 'Avery Label type for printing patient labels from popups in left nav screen'),
(556, 'Avestan'),
(557, 'Avg Monthly'),
(558, 'Avulsion / avulsion fracture'),
(559, 'Avulsion lateral malleolus'),
(560, 'Avulsion medial malleolus '),
(561, 'Awareness-Based'),
(562, 'Axillary'),
(563, 'Aymara'),
(564, 'Azerbaijani'),
(565, 'b.i.d.'),
(566, 'Back'),
(567, 'back'),
(568, 'Back eight visits'),
(569, 'Back eleven visits'),
(570, 'Back five visits'),
(571, 'Back four visits'),
(572, 'Back nine visits'),
(573, 'Back one visit'),
(574, 'Back Pain'),
(575, 'Back Problems'),
(576, 'Back seven visits'),
(577, 'Back six visits'),
(578, 'Back Surgery'),
(579, 'Back ten visits'),
(580, 'Back three visits'),
(581, 'Back to Admin Page'),
(582, 'Back to encounter'),
(583, 'Back to Patient'),
(584, 'Back To Patient'),
(585, 'Back to Users'),
(586, 'Back To View'),
(587, 'Back twelve visits'),
(588, 'Back two visits'),
(589, 'Background Services'),
(590, 'Backup'),
(591, 'Backup file has been created. Will now send download.'),
(592, 'Backup List'),
(593, 'Backup Successfully taken in'),
(594, 'Bad check'),
(595, 'Bad debt'),
(596, 'Bahasa Indonesia'),
(597, 'Bal'),
(598, 'Balance'),
(599, 'balance'),
(600, 'Balance Amt'),
(601, 'Balance Due'),
(602, 'Bambara'),
(603, 'Bank Draft'),
(604, 'Barcode Label'),
(605, 'Barcode Label Type'),
(606, 'Barcode type for printing barcode labels from popups in left nav screen.'),
(607, 'Base of fifth (5th) Metarsal'),
(608, 'Base of fifth (5th) Metarsal:'),
(609, 'Bashkir'),
(610, 'Basque'),
(611, 'Batch Claim'),
(612, 'Batch Communication Tool'),
(613, 'Batch Payment Entry'),
(614, 'Batch Payments'),
(615, 'Batch processing initiated; this may take a while.'),
(616, 'Batch Results'),
(617, 'BatchCom'),
(618, 'Be patient, some files can take several minutes to process!'),
(619, 'because that id does not exist.'),
(620, 'Begin'),
(621, 'Begin Date'),
(622, 'Beginning Date for Ledger Report'),
(623, 'Beginning date of service yyyy-mm-dd'),
(624, 'Beginning hour of day for calendar events.'),
(625, 'Belarusian'),
(626, 'Belching'),
(627, 'Below lower panic limits'),
(628, 'Bengali'),
(629, 'Bengali- Bangla'),
(630, 'between'),
(631, 'Bidirectional'),
(632, 'Bihari'),
(633, 'Bilateral'),
(634, 'Bilateral:'),
(635, 'Bill Date'),
(636, 'Bill Date:'),
(637, 'Bill/Collect'),
(638, 'Billed'),
(639, 'Billed Date'),
(640, 'Billing'),
(641, 'Billing (write optional)'),
(642, 'Billing Attn'),
(643, 'Billing Code Descriptions'),
(644, 'Billing Code for Requested Service'),
(645, 'Billing codes'),
(646, 'Billing Data'),
(647, 'Billing Department'),
(648, 'Billing Facility'),
(649, 'Billing Information'),
(650, 'Billing Location'),
(651, 'Billing Log Append'),
(652, 'Billing Log Option'),
(653, 'Billing Log Overwrite'),
(654, 'Billing log setting to append or overwrite the log file.'),
(655, 'Billing Manager'),
(656, 'Billing Note'),
(657, 'Billing Note for '),
(658, 'Billing Note:'),
(659, 'Billing queue results:'),
(660, 'Billing Report'),
(661, 'Billing Status'),
(662, 'Billing Status = Unbilled'),
(663, 'billing to '),
(664, 'Billing View'),
(665, 'Biopsy'),
(666, 'Birth Date'),
(667, 'Birth-24 months'),
(668, 'Bislama'),
(669, 'Black'),
(670, 'Black Lung'),
(671, 'Black or African American'),
(672, 'Bladder Cancer'),
(673, 'Bladder Infections'),
(674, 'Blank Forms'),
(675, 'Bleeding Problems'),
(676, 'Blind Spots'),
(677, 'Bloating'),
(678, 'Blocked'),
(679, 'Blood'),
(680, 'Blood Pressure'),
(681, 'Blood pressure'),
(682, 'Bloody Nose'),
(683, 'Blue Cross Blue Shield'),
(684, 'Blue lines in this report are informational. Black lines show previously existing information.  Green lines show changes that were successfully applied.  Red lines indicate errors, or changes that were not applied; these must be processed manually.  Currently denied claims and payment reversals are not handled automatically and so will appear in red.'),
(685, 'Blurred Vision'),
(686, 'BMI'),
(687, 'BMI Status'),
(688, 'Body'),
(689, 'Body Region'),
(690, 'Body Site'),
(691, 'Body site, if applicable'),
(692, 'Bone Tenderness:'),
(693, 'Bone Tenderness: Medial Malleolus'),
(694, 'Boolean'),
(695, 'Bosnian'),
(696, 'Bot'),
(697, 'Both Ears'),
(698, 'both ears'),
(699, 'Bottom'),
(700, 'Bottom Margin (px)'),
(701, 'BOX 10 A. Employment related '),
(702, 'BOX 10 B. Auto Accident '),
(703, 'BOX 10 C. Other Accident '),
(704, 'BOX 14 Date Qualifier'),
(705, 'BOX 15 Other Date Qualifier'),
(706, 'BOX 15. Date of same or similar illness (yyyy-mm-dd):'),
(707, 'BOX 15. Date of same or similar illness/Other Date (yyyy-mm-dd):'),
(708, 'BOX 16. Date unable to work from (yyyy-mm-dd):'),
(709, 'BOX 16. Date unable to work to (yyyy-mm-dd):'),
(710, 'BOX 18. Hospitalization date from (yyyy-mm-dd): '),
(711, 'BOX 18. Hospitalization date to (yyyy-mm-dd): '),
(712, 'BOX 20. Is Outside Lab used?'),
(713, 'BOX 22. Medicaid Resubmission Code (ICD-9) '),
(714, 'BOX 23. Prior Authorization No. '),
(715, 'BP'),
(716, 'BP Diastolic'),
(717, 'BP Systolic'),
(718, 'BPD'),
(719, 'Bpd'),
(720, 'BPS'),
(721, 'Bps'),
(722, 'Brazilian Portuguese'),
(723, 'Breast'),
(724, 'Breast Biopsy'),
(725, 'Breast Discharge'),
(726, 'Breast Disease'),
(727, 'Breast Exam'),
(728, 'Breast Mass'),
(729, 'Breath'),
(730, 'Breath Sounds:'),
(731, 'Breton'),
(732, 'Broken Bones'),
(733, 'broken form'),
(734, 'Bronchitis Form'),
(735, 'Browse'),
(736, 'Browse for Record'),
(737, 'Bruising/haematoma'),
(738, 'Bulgarian'),
(739, 'Bulging Right:'),
(740, 'Burmese'),
(741, 'Burning with Urination'),
(742, 'Burning With Urination'),
(743, 'Business Phone'),
(744, 'Busy'),
(745, 'but not yet processed.'),
(746, 'Buttock'),
(747, 'Buttock + S.I.'),
(748, 'by'),
(749, 'By'),
(750, 'by mouth'),
(751, 'By/Source'),
(752, 'By:'),
(753, 'C'),
(754, 'CA Certificate for verifying the RFC 5425 TLS syslog server.'),
(755, 'Cache Lifetime (in seconds)'),
(756, 'Cache template output?'),
(757, 'Caffeine consumption'),
(758, 'Calendar'),
(759, 'Calendar Ending Hour'),
(760, 'Calendar Interval'),
(761, 'Calendar Screen'),
(762, 'Calendar Settings'),
(763, 'Calendar Starting Hour'),
(764, 'Calendar UI'),
(765, 'Calendar View'),
(766, 'Call to addForm() goes here.<br>'),
(767, 'Calories'),
(768, 'Cambodian'),
(770, 'Can not set this unless the Summary of Care Sent toggle is set.'),
(771, 'Can''t find file!'),
(772, 'Can''t upload'),
(773, 'Canada'),
(774, 'Cancel'),
(775, 'Cancel Changes'),
(776, 'Canceled'),
(777, 'Cancer'),
(778, 'Cancer Screening: Colon Cancer Screening'),
(779, 'Cancer Screening: Mammogram'),
(780, 'Cancer Screening: Pap Smear'),
(781, 'Cancer Screening: Prostate Cancer Screening'),
(782, 'Cannot add this entry because it already exists!'),
(783, 'Cannot add/update this entry because a duplicate already exists!'),
(784, 'cannot be archived, ignored'),
(785, 'cannot be converted to JPEG. Perhaps ImageMagick is not installed?'),
(786, 'cannot be deleted, ignored'),
(787, 'cannot be displayed inline because its type is not supported by the browser.'),
(788, 'cannot be displayed inline becuase its type is not supported by the browser'),
(789, 'cannot be displayed inline becuase its type is not supported by the browser.'),
(790, 'Cannot create'),
(791, 'Cannot create file'),
(792, 'Cannot delete (from SFTP server) file'),
(793, 'Cannot delete file'),
(794, 'Cannot determine a destination filename'),
(795, 'Cannot find '),
(796, 'Cannot find a destination filename'),
(797, 'Cannot find a skip source field for'),
(798, 'Cannot find a skip target field for'),
(799, 'Cannot find patient from SQL-Ledger customer id'),
(800, 'Cannot find postscript document reference in '),
(801, 'Cannot find provider from SQL-Ledger employee = '),
(802, 'Cannot Modify Payments.Undistributed is Negative.'),
(803, 'Cannot open '),
(804, 'Cannot Post for Insurance.The Paying Entity selected is Patient.'),
(805, 'Cannot Post for Patient.The Paying Entity selected is Insurance.'),
(806, 'Cannot Post Payments.Undistributed is Negative.'),
(807, 'Cannot read'),
(808, 'Cannot read directory'),
(809, 'Cannot update because you are not editing an existing entry!'),
(810, 'Capitalize'),
(811, 'Capitalize all'),
(812, 'capsule'),
(813, 'Card'),
(814, 'Cardiac Catheterization'),
(815, 'Cardiac Echo'),
(816, 'Cardiovascular'),
(817, 'Care Coordination'),
(818, 'Care Plan'),
(819, 'Care Plan Form'),
(820, 'Care Team'),
(821, 'Cartilage / chondral / disc damage'),
(822, 'Cartilage injury'),
(823, 'Cartoid pulsations nl, pedal pulses nl'),
(824, 'cash'),
(825, 'Cash'),
(826, 'Cash Rec'),
(827, 'Cash Receipts by Provider'),
(828, 'Catalan- Valencian'),
(829, 'Cataract Surgery'),
(830, 'Cataracts'),
(831, 'Categories'),
(832, 'Categories for'),
(833, 'Category'),
(834, 'category'),
(835, 'Category '),
(836, 'Category Details'),
(837, 'Category Limits'),
(838, 'Category Name'),
(839, 'Category name is empty'),
(840, 'Category/Title'),
(841, 'Caucasian'),
(842, 'Causes Receipts to Print Encounter/Primary Provider Info'),
(843, 'CCD'),
(844, 'CCDA'),
(845, 'CCR'),
(846, 'CCR Approve'),
(847, 'CCR Patient Review'),
(848, 'CCR Review and Approve'),
(849, 'CDC Code'),
(850, 'CDR'),
(851, 'CDR Reports Processing Priority'),
(852, 'Cell'),
(853, 'Cell Phone'),
(854, 'Cell phone number'),
(855, 'Cell Phone Number'),
(856, 'Central Certification'),
(857, 'Central/South American'),
(858, 'Certificate Authority crt file location cannot be empty'),
(859, 'Certificate Authority key file location cannot be empty'),
(860, 'Certificate to send to RFC 5425 TLS syslog server.'),
(861, 'Certificate User'),
(862, 'Certificates'),
(863, 'Chamorro'),
(864, 'ChampUS'),
(865, 'ChampUSVA'),
(866, 'change'),
(867, 'Change'),
(868, 'Change Activity'),
(869, 'Change failed! CouchDB connect error?'),
(870, 'Change in Vision'),
(871, 'Change In Vision'),
(872, 'Change Password'),
(873, 'Change Status for'),
(874, 'Changed'),
(875, 'Changed Bowel'),
(876, 'Changing patient ID for document'),
(877, 'Characteristics'),
(878, 'Characters Remaining'),
(879, 'Charge'),
(880, 'Charge adjustment'),
(881, 'Charge Coded'),
(882, 'Charges'),
(883, 'Chart'),
(884, 'Chart Activity'),
(885, 'Chart Check-in/out Activity Report'),
(886, 'Chart ID'),
(887, 'Chart ID:'),
(888, 'Chart Label'),
(889, 'Chart Location Activity'),
(890, 'Chart Note'),
(891, 'Chart Number'),
(892, 'Chart Storage Locations'),
(893, 'Chart Tracker'),
(894, 'Chart Trk'),
(895, 'Charts Checked Out'),
(896, 'Charts Out'),
(897, 'Chechen'),
(898, 'Check'),
(899, 'check'),
(900, 'Check All'),
(901, 'Check All - Components'),
(902, 'Check Amount'),
(903, 'Check Date'),
(904, 'Check for differences of translations with custom language table.'),
(905, 'Check In'),
(906, 'Check In To'),
(907, 'Check Input Data'),
(908, 'Check items to graph'),
(909, 'Check Lab Results'),
(910, 'Check mark indicates reviewed'),
(911, 'Check No'),
(912, 'Check Number'),
(913, 'Check Out'),
(914, 'Check Out Time'),
(915, 'Check Payment'),
(916, 'Check the box if this is an encrypted file'),
(917, 'Check this if you want providers to see all appointments by default and not just their own.'),
(918, 'Check to create problem from this diagnosis'),
(919, 'Check/EOB Date:'),
(920, 'Check/EOB No.:'),
(921, 'Check/Ref Number'),
(922, 'Check/Reference Number'),
(923, 'Checkbox list'),
(924, 'checkbox list'),
(925, 'checkbox w/ text'),
(926, 'Checkbox w/text'),
(927, 'Checkboxes above indicate if you want to reject and delete the HL7 file.'),
(928, 'Checked'),
(929, 'Checked box = yes ,  empty = no'),
(930, 'Checked Drug Formulary?'),
(931, 'Checking the lock checkbox will prevent any futher edits on any forms in this encounter.'),
(932, 'Checkout'),
(933, 'Checksum'),
(934, 'Chest'),
(935, 'Chest CTAB'),
(936, 'Chest Pain'),
(937, 'Chest Pain:'),
(938, 'Chest Pains'),
(939, 'Chest physician'),
(940, 'Chg'),
(941, 'Chichewa- Chewa- Nyanja'),
(942, 'Chief Complaint'),
(943, 'Child'),
(944, 'Child in-law'),
(945, 'Childhood immunization Status (CQM)'),
(946, 'Chills'),
(947, 'Chinese'),
(948, 'Chinese (Simplified)'),
(949, 'Chinese (Traditional)'),
(950, 'Chiropractic'),
(951, 'Choices'),
(952, 'Cholecystectomy'),
(953, 'cholecystectomy'),
(954, 'Cholecystestomy'),
(955, 'Choose'),
(956, 'Choose a section and click an item within it; then in the other section you will see the related items highlighted, and you can click in that section to add and delete relationships.'),
(957, 'Choose Criteria'),
(958, 'Choose Download or Display Inline'),
(959, 'Choose File'),
(960, 'Choose from list'),
(961, 'Choose Layout Direction'),
(962, 'Choose list'),
(963, 'Choose Paper Size'),
(964, 'Choose PDF languange Preference'),
(965, 'Choose print format for this encounter report.'),
(966, 'Choose your default encounter view'),
(967, 'Chronic Bronchitis'),
(968, 'Chronic Joint Pain'),
(969, 'Chronic Kidney Disease (CKD)'),
(970, 'Chronic synovitis / effusion / joint pain / gout'),
(971, 'Chronic/Recurrent'),
(972, 'Chuvash'),
(973, 'Cirrhosis of the Liver'),
(974, 'Cirrhosis Of The Liver'),
(975, 'City'),
(976, 'City Name'),
(977, 'City, State'),
(978, 'City, State Zip'),
(979, 'City/State'),
(980, 'Claim'),
(981, 'Claim '),
(982, 'Claim Status'),
(983, 'Claim test has completed running'),
(984, 'Claim Type'),
(985, 'Claim was generated to file'),
(986, 'Claim was generated to file '),
(987, 'Claims'),
(988, 'Classification'),
(989, 'Clear'),
(990, 'CLEAR ACTIVE PATIENT'),
(991, 'Clear All'),
(992, 'Clear HL7 Data'),
(993, 'Clear Justification'),
(994, 'Clear Smarty Cache'),
(995, 'Clearing house info required for EDI 270 batch creation.'),
(996, 'CLIA Number'),
(997, 'Click'),
(998, 'Click ''export'' to export your Category, Subcategory, Item, Content data to a text file. Any resemblance of this file to an XML file is purely coincidental. The opening and closing tags must be on the same line, they must be lowercase with no spaces. To import, browse for a file and click ''import''. If the data is completely different, it will merge with your existing data. If there are similar item names, The old one will be kept and the new one saved with a number added to the end.'),
(999, 'Click a spot on the graphic to add a new annotation, click it again to remove it'),
(1000, 'Click Download Certificate to download the certificates in the file ssl.zip'),
(1001, 'click for more'),
(1002, 'Click for more details'),
(1003, 'Click for order summary'),
(1004, 'Click for results'),
(1005, 'Click here'),
(1006, 'Click Here to add a new patient.'),
(1007, 'Click here to add new injury change status and edit daily activity'),
(1008, 'Click here to choose a date'),
(1009, 'Click here to choose a date and time'),
(1010, 'Click here to choose a start date'),
(1011, 'Click here to choose date time'),
(1012, 'Click here to choose date time from'),
(1013, 'Click here to choose date time to'),
(1014, 'Click Here to Configure This module'),
(1015, 'Click here to delete the row'),
(1016, 'Click Here to Disable This module'),
(1017, 'Click here to duplicate the row'),
(1018, 'Click Here to Enable This module'),
(1019, 'Click Here to Install This module'),
(1020, 'click here to search'),
(1021, 'click here to update priority, category and nickname settings'),
(1022, 'Click here to view all.'),
(1023, 'Click here to view and graph'),
(1024, 'Click here to view and graph all labdata.'),
(1025, 'Click here to view and graph all vitals.'),
(1026, 'Click here to view patient details'),
(1027, 'Click here to view them all.'),
(1028, 'Click here to view/edit more details'),
(1029, 'Click Install button to install database release from the following date'),
(1030, 'Click on any of the time parts to increase it'),
(1031, 'Click Patient Name to Open Patient File'),
(1032, 'Click Refresh to view all results, or please input search criteria above to view specific results.'),
(1033, 'Click to add a diagnosis'),
(1034, 'Click to add new components'),
(1035, 'Click to add new consultation'),
(1036, 'Click to choose diagnoses to justify.'),
(1037, 'Click to download'),
(1038, 'Click to edit'),
(1039, 'Click to edit description'),
(1040, 'Click to edit this event'),
(1041, 'Click to generate the report'),
(1042, 'Click to match patient'),
(1043, 'Click to print'),
(1044, 'Click to receive (add) new lot'),
(1045, 'Click to select'),
(1046, 'Click To Select'),
(1047, 'Click to select an industry-standard code for this procedure'),
(1048, 'Click to select optional procedure code'),
(1049, 'Click to select or change coding'),
(1050, 'Click to select or change CVX code'),
(1051, 'Click to select or change diagnoses'),
(1052, 'Click to select or change service codes'),
(1053, 'Click to select patient'),
(1054, 'Click to select related code'),
(1055, 'Click to select services to perform if this result is abnormal'),
(1056, 'Click to select the desired procedure'),
(1057, 'Click to sort'),
(1058, 'Click to view'),
(1059, 'Click to view or edit'),
(1060, 'Click to view/edit'),
(1061, 'Click Upgrade button to upgrade database release from the following date'),
(1062, 'Click where indicated above to match the patient.'),
(1063, 'Click:'),
(1064, 'Client Certificate Expiration Days'),
(1065, 'Client certificate validation period'),
(1066, 'Client certificate validity should be a valid number.'),
(1067, 'Client Copy'),
(1068, 'Client ID'),
(1069, 'Client medical history summary'),
(1070, 'Client Name'),
(1071, 'Client Number'),
(1072, 'Client Profile - New Clients'),
(1073, 'Client Profile - Unique Clients'),
(1074, 'Clients'),
(1075, 'Clinic'),
(1076, 'Clinic Copy'),
(1077, 'Clinic Daily Record'),
(1078, 'Clinic ID'),
(1079, 'Clinical'),
(1080, 'Clinical Decision Rules Alert Manager'),
(1081, 'Clinical History'),
(1082, 'Clinical Instructions Form'),
(1083, 'Clinical Plans'),
(1084, 'Clinical Quality Measures (CQM)'),
(1085, 'Clinical Quality Measures (CQM) - 2011'),
(1086, 'Clinical Quality Measures (CQM) - 2014'),
(1087, 'Clinical Reminders'),
(1088, 'Clinical Reports'),
(1089, 'Clinical Rule Action Category'),
(1090, 'Clinical Rule Action Item'),
(1091, 'Clinical Rule Filter Methods'),
(1092, 'Clinical Rule Target Methods'),
(1093, 'Clinical Rules'),
(1094, 'Clinical Rules Age Intervals'),
(1095, 'Clinical Rules Comparisons'),
(1096, 'Clinical Rules Encounter Types'),
(1097, 'Clinical Rules Reminder Due Options'),
(1098, 'Clinical Rules Reminder Inactivation Options'),
(1099, 'Clinical Rules Reminder Intervals'),
(1100, 'Clinical Rules Reminder Methods'),
(1101, 'Clinical Rules Target Intervals'),
(1102, 'Clinical targets'),
(1103, 'Clinical Term'),
(1104, 'Clinical Term Code(s)'),
(1105, 'Clinical View'),
(1106, 'Clinicians'),
(1107, 'Clone'),
(1108, 'Clone Past Visit'),
(1109, 'Close'),
(1110, 'Close Window'),
(1111, 'close window'),
(1112, 'Closed'),
(1113, 'cm'),
(1114, 'CMS 1500 Margins'),
(1115, 'CMS 1500 Paper Form Format'),
(1116, 'CMS 1500: Box 31 Format'),
(1117, 'CMS 1500: Date in Box 31 (Signature)'),
(1118, 'CMS ID'),
(1119, 'CMS Portal'),
(1120, 'CMS Portal Login'),
(1121, 'CMS Portal Login ID'),
(1122, 'CMS Portal not enabled!'),
(1123, 'CMS Portal Password'),
(1124, 'CMS Portal Request'),
(1125, 'CMS Portal Site Address'),
(1126, 'CMS Portal Username'),
(1127, 'CN2-12 intact'),
(1128, 'Co Pay'),
(1129, 'Co Pay Paid'),
(1130, 'CO-PAY'),
(1131, 'Code'),
(1132, 'code'),
(1133, 'Code Finder'),
(1134, 'Code must be two letter lowercase'),
(1135, 'Code or symbol to indicate currency'),
(1136, 'Code Text'),
(1137, 'Code Type'),
(1138, 'code type'),
(1139, 'Code type not recognized'),
(1140, 'Code type not yet defined'),
(1141, 'Code Types'),
(1142, 'Code(s)'),
(1143, 'Coded'),
(1144, 'Codes'),
(1145, 'Coding'),
(1146, 'Coding (click for education)'),
(1147, 'Coding - any encounters (write,wsome optional)'),
(1148, 'Coding - my encounters (write,wsome optional)'),
(1149, 'Coding not authorized'),
(1150, 'Coffee'),
(1151, 'Coffee Use'),
(1152, 'Coinsurance'),
(1153, 'Coll w/o'),
(1154, 'Collapse'),
(1155, 'collapse'),
(1156, 'Collapse All'),
(1157, 'Collapse all'),
(1158, 'collapse all'),
(1159, 'Collected'),
(1160, 'Collection Date'),
(1161, 'Collections'),
(1162, 'Collections Report'),
(1163, 'Colon Cancer'),
(1164, 'Colon Cancer Screening'),
(1165, 'Colon Cancer Surgery'),
(1166, 'Colonoscopy'),
(1167, 'colonoscopy'),
(1168, 'Color'),
(1169, 'Color:Abbr'),
(1170, 'Column'),
(1171, 'Columns'),
(1172, 'Combining Lots'),
(1173, 'Comma'),
(1174, 'Comment'),
(1175, 'Comments'),
(1176, 'Comments for this result or recommendation'),
(1177, 'Commercial Insurance Co.'),
(1178, 'Commit Changes'),
(1179, 'Communication'),
(1180, 'Communications'),
(1181, 'Community health physician'),
(1182, 'Company'),
(1183, 'Company Name'),
(1184, 'Complete'),
(1185, 'Complete Visit Time'),
(1186, 'Completed'),
(1187, 'completed'),
(1188, 'Completed?'),
(1189, 'Completion Status'),
(1190, 'Complications by Service Provider'),
(1191, 'Complications of Abortion'),
(1192, 'Components'),
(1193, 'Computer Aided Medical Ordering System'),
(1194, 'Conclusions'),
(1195, 'Condition'),
(1196, 'Condition field not found'),
(1197, 'Condition Status'),
(1198, 'Config'),
(1199, 'Configuration'),
(1200, 'Configuration Export/Import'),
(1201, 'Configuration saved successfully'),
(1202, 'Configure Apache and LibreEHR to use Client side SSL certificates.'),
(1203, 'Configure Apache to use Client side SSL certificates'),
(1204, 'Configure Apache to use HTTPS.'),
(1205, 'Configure LIBREEHR to use Client side SSL certificates'),
(1206, 'Configure tracks'),
(1207, 'Configure Tracks'),
(1208, 'Confirm Create New Patient'),
(1209, 'Confirm New Password'),
(1210, 'Confirm Payment'),
(1211, 'Conflicted Allergies'),
(1212, 'Conflicted Medications'),
(1213, 'Conflicted Problems'),
(1214, 'Congenital'),
(1215, 'Conjuntiva, pupils'),
(1216, 'Connection error'),
(1217, 'Connectors'),
(1218, 'Constant'),
(1219, 'constant name'),
(1220, 'Constant name is blank'),
(1221, 'constants'),
(1222, 'Constipation'),
(1223, 'Constitutional'),
(1224, 'Construction Firm'),
(1225, 'Consultant physician'),
(1226, 'Consultation Brief Description'),
(1227, 'Contact'),
(1228, 'Contact Email'),
(1229, 'Contact Email Address'),
(1230, 'Contact EMR Direct to subscribe to the phiMail Direct messaging service'),
(1231, 'contact info'),
(1232, 'Contact Lenses'),
(1233, 'Contact Medical Information Integration, LLC at http://mi-squared.com for Lab Exchange Service.'),
(1234, 'Contact Medical Information Integration, LLC at http://mi-squared.com or ZH Healthcare at http://zhservices.com for subscribing the eRx service'),
(1235, 'Contact Medical Information Integration, LLC at http://mi-squared.com or ZH Healthcare at http://zhservices.com for subscribing to the NewCrop eRx service.'),
(1236, 'Contact name'),
(1237, 'Contact Person'),
(1238, 'Contact Phone'),
(1239, 'Contact Phone Number'),
(1240, 'Contact ZMG, LLC (zmghealth@gmail.com) for subscribing the eRx service'),
(1241, 'contain at least three of the four following items:'),
(1242, 'Container Group Name'),
(1243, 'Content'),
(1244, 'content'),
(1245, 'Context'),
(1246, 'Context name can''t be empty'),
(1247, 'Continue'),
(1248, 'Continuity of Care Document (CCD)'),
(1249, 'Continuity of Care Record (CCR)'),
(1250, 'Contra Clients'),
(1251, 'Contraception'),
(1252, 'Contraception Issues'),
(1253, 'Contraceptive Complication (specify)'),
(1254, 'Contraceptive Method'),
(1255, 'Contraceptive Products'),
(1256, 'Contraceptive services previously started'),
(1257, 'Contraceptives Start'),
(1258, 'Control ID'),
(1259, 'Control No.'),
(1260, 'Controlled Substance?'),
(1261, 'COPAY'),
(1262, 'Copay'),
(1263, 'CoPay'),
(1264, 'Copay not positive'),
(1265, 'Copay Paid'),
(1266, 'Copays'),
(1267, 'COPD'),
(1268, 'Copy Pages to Patient Chart'),
(1269, 'Copy Values'),
(1270, 'Copying the database file. This will take some time...'),
(1271, 'Copyright Notice'),
(1272, 'Cornish'),
(1273, 'Coronary Artery Bypass'),
(1274, 'Coronary Artery Bypass Graft (CABG)'),
(1275, 'Corrected'),
(1276, 'Corsican'),
(1277, 'CouchDB'),
(1278, 'CouchDB Connection Failed.'),
(1279, 'CouchDB Database'),
(1280, 'CouchDB database name'),
(1281, 'CouchDB host'),
(1282, 'CouchDB HostName'),
(1283, 'CouchDB Log Enable'),
(1284, 'CouchDB Password'),
(1285, 'CouchDB Port'),
(1286, 'CouchDB port'),
(1287, 'CouchDB save failed'),
(1288, 'CouchDB UserName'),
(1289, 'Cough'),
(1290, 'Cough:'),
(1291, 'could not connect to server'),
(1292, 'Could not import the document. Please contact the EMR vendor.'),
(1293, 'could not open table'),
(1294, 'Could not read file'),
(1295, 'Could not read the file'),
(1296, 'Could not send email due to a server problem, '),
(1297, 'Could not send email due to a server problem. '),
(1298, 'Couldn''t create backup dir:'),
(1299, 'Couldn''t remove dir:'),
(1300, 'Couldn''t remove old backup file:'),
(1301, 'Couldn''t remove old export file: '),
(1302, 'Coumadin Management - INR Monitoring'),
(1303, 'Couns by Method'),
(1304, 'Counseling'),
(1305, 'Counseling activities'),
(1306, 'COUNTER REFERRAL FORM'),
(1307, 'Counter-Referral'),
(1308, 'Country'),
(1309, 'Country Data Type'),
(1310, 'Country list'),
(1311, 'Country List (write,addonly optional)'),
(1312, 'Country Name should be represent in two letters. (Example: United States is US)'),
(1313, 'county'),
(1314, 'County'),
(1315, 'Coupon'),
(1316, 'Cousin'),
(1317, 'CPOE'),
(1318, 'CPT'),
(1319, 'CPT Code'),
(1320, 'CPT Codes'),
(1321, 'CPT4 Procedure/Service'),
(1322, 'CPTII Performance Measures'),
(1323, 'CQM'),
(1324, 'Crackles:'),
(1325, 'cream'),
(1326, 'Create a Client side SSL certificate for each user or client machine.'),
(1327, 'Create a client side SSL certificate for either a user or a client hostname.'),
(1328, 'Create a new track'),
(1329, 'Create an Event'),
(1330, 'Create and download a full backup'),
(1331, 'Create and modify tracks'),
(1332, 'Create Backup'),
(1333, 'Create batch'),
(1334, 'Create Client Certificate'),
(1335, 'Create Client side SSL certificates'),
(1336, 'Create Duplicate'),
(1337, 'Create Encounter'),
(1338, 'Create Eventlog Backup'),
(1339, 'Create new issue'),
(1340, 'Create New Patient'),
(1341, 'Create new Track'),
(1342, 'Create Offsite Portal Credentials'),
(1343, 'Create Onsite Portal Credentials'),
(1344, 'Create Patient Note'),
(1345, 'Create the SSL Certificate Authority and Server certificates.'),
(1346, 'Create Visit'),
(1347, 'Created'),
(1348, 'Creating export file'),
(1349, 'Creating new track failed'),
(1350, 'Creating this file on remote host failed'),
(1351, 'Creator'),
(1352, 'credit'),
(1353, 'Credit Card'),
(1354, 'Credits'),
(1355, 'Cree'),
(1356, 'Criteria'),
(1357, 'Croatian'),
(1358, 'Crohn''s Disease'),
(1359, 'Crohns Disease'),
(1360, 'CSV Export'),
(1361, 'CSV File'),
(1362, 'CSV Tables'),
(1363, 'CU.MM'),
(1364, 'Cuban'),
(1365, 'Currency Decimal Places'),
(1366, 'Currency Decimal Point Symbol'),
(1367, 'Currency Designator'),
(1368, 'Currency Thousands Separator'),
(1369, 'Current'),
(1370, 'Current Alcohol'),
(1371, 'Current Consultation'),
(1372, 'Current Criteria'),
(1373, 'Current day highlight color'),
(1374, 'Current every day smoker'),
(1375, 'Current file name was changed to'),
(1376, 'Current Hash'),
(1377, 'Current Location'),
(1378, 'Current Medications'),
(1379, 'Current Password'),
(1380, 'Current Patient'),
(1381, 'Current Pt Only'),
(1382, 'Current Recreational Drugs'),
(1383, 'Current some day smoker'),
(1384, 'Current Status Time'),
(1385, 'Current Value'),
(1386, 'Currently Active'),
(1387, 'Currently Running'),
(1388, 'Currently there are no facilities.'),
(1389, 'Cushing Syndrom'),
(1390, 'Cushing Syndrome'),
(1391, 'Custodian'),
(1392, 'Custom'),
(1393, 'Custom input?'),
(1394, 'Custom Table'),
(1395, 'Cvx Code'),
(1396, 'CVX Code'),
(1397, 'CVX Code Mapping'),
(1398, 'CVX Immunization'),
(1399, 'Cycle'),
(1400, 'CYP'),
(1401, 'CYP Factor'),
(1402, 'CYP Report'),
(1403, 'Czech'),
(1404, 'D'),
(1405, 'D&C'),
(1406, 'D&E'),
(1407, 'D.O.B.'),
(1408, 'daily'),
(1409, 'Daily Record'),
(1410, 'Danish'),
(1411, 'Data Alike is already in database, please change code and/or description'),
(1412, 'Data Alike is already in database, please change constant name'),
(1413, 'Data Cols'),
(1414, 'Data Enterer'),
(1415, 'Data Entry - Social Security Number'),
(1416, 'Data Error'),
(1417, 'Data from'),
(1418, 'Data integrity has been compromised'),
(1419, 'data of all encounters so far'),
(1420, 'Data Type'),
(1421, 'Database'),
(1422, 'Database is not installed.'),
(1423, 'Database Patch'),
(1424, 'Database Reporting'),
(1425, 'Database upgrade finished.'),
(1426, 'DataCols must be a number between 1 and 999'),
(1427, 'Date'),
(1428, 'DATE'),
(1429, 'Date & Time Administered'),
(1430, 'Date / Time'),
(1431, 'Date Administered'),
(1432, 'Date and time of sample collection'),
(1433, 'Date and time of this observation'),
(1434, 'Date and time of this report'),
(1435, 'Date and time that the sample was collected'),
(1436, 'Date Cannot be greater than Today'),
(1437, 'Date contraceptive services initially provided'),
(1438, 'Date Created'),
(1439, 'Date Deceased'),
(1440, 'Date Destroyed'),
(1441, 'Date Display Format'),
(1442, 'Date format for "appointment end" is not valid'),
(1443, 'Date format for "appointment start" is not valid'),
(1444, 'Date format for "Next Appointment" is not valid'),
(1445, 'Date format for "not seen since" is not valid'),
(1446, 'Date format for "seen since" is not valid'),
(1447, 'Date Immunization Information Statements Given'),
(1448, 'Date is missing for code '),
(1449, 'Date Master Criteria'),
(1450, 'Date of bank deposit yyyy-mm-dd'),
(1451, 'Date of Billing'),
(1452, 'Date of Birth'),
(1453, 'Date of birth'),
(1454, 'Date Of Birth'),
(1455, 'Date of Entry'),
(1456, 'Date of Injury'),
(1457, 'Date of Onset'),
(1458, 'Date of payment yyyy-mm-dd'),
(1459, 'Date of referral'),
(1460, 'Date of reply'),
(1461, 'Date of Report'),
(1462, 'Date of Service'),
(1463, 'Date Of Service'),
(1464, 'Date of Service = Today'),
(1465, 'Date of service mm/dd/yyyy'),
(1466, 'Date of Service:'),
(1467, 'Date Of Signature'),
(1468, 'Date of Status Change'),
(1469, 'Date of this order'),
(1470, 'Date of this report'),
(1471, 'Date of VIS Statement'),
(1472, 'Date Ordered'),
(1473, 'Date Range'),
(1474, 'Date Selector'),
(1475, 'Date selector'),
(1476, 'Date Sent'),
(1477, 'Date The Message Was Sent'),
(1478, 'Date Time'),
(1479, 'Date values Cannot be Blank.'),
(1480, 'Date/Appt'),
(1481, 'Date/Notes'),
(1482, 'Date/Notes of Last'),
(1483, 'Date/Time'),
(1484, 'Date:'),
(1485, 'Dated Message Log'),
(1486, 'Day'),
(1487, 'day'),
(1488, 'Day Sheet Report'),
(1489, 'Day View'),
(1490, 'Day(s)'),
(1491, 'Day(s) M-F'),
(1492, 'days'),
(1493, 'Days'),
(1494, 'days ago'),
(1495, 'Days and Games Missed'),
(1496, 'Days From Last Encounter'),
(1497, 'Days Missed'),
(1498, 'Days per Column:'),
(1499, 'Days/Col'),
(1500, 'Days/Col:'),
(1501, 'DB installed'),
(1502, 'DD/MM/YYYY'),
(1503, 'De Identification'),
(1504, 'De Identification Process is completed'),
(1505, 'De Identification Process is ongoing'),
(1506, 'De Identification process is started and running in background'),
(1507, 'De Identified data may not be complete'),
(1508, 'De-identification files will be saved in'),
(1509, 'DEA'),
(1510, 'Deactivate'),
(1511, 'Deaf'),
(1512, 'Debug Information'),
(1513, 'DEBUG OUTPUT'),
(1514, 'Debugging'),
(1515, 'Dec'),
(1516, 'DECEASED'),
(1517, 'December'),
(1518, 'Decimal pounds or pounds and ounces separated by #(e.g. 5#4)'),
(1519, 'Declined To Specify'),
(1520, 'Deductible'),
(1521, 'Deductible Met'),
(1522, 'Default'),
(1523, 'Default Calendar View'),
(1524, 'Default Encounter Form ID'),
(1525, 'Default Encounter View'),
(1526, 'Default Facility'),
(1527, 'Default Language'),
(1528, 'Default language if no other is allowed or chosen.'),
(1529, 'Default List (write,addonly optional)'),
(1530, 'Default Method'),
(1531, 'Default Password Expiration Days'),
(1532, 'Default password expiration period in days. 0 means this feature is disabled.'),
(1533, 'Default Patient Country'),
(1534, 'Default Patient Country sent to NewCrop eRx, only if patient country is not set.'),
(1535, 'Default Priority'),
(1536, 'Default Provider'),
(1537, 'Default Range'),
(1538, 'Default Reason for Visit'),
(1539, 'Default Search Code Type'),
(1540, 'Default Setting'),
(1541, 'Default state of New Window checkbox in the patient list.'),
(1542, 'Default Template'),
(1543, 'Default to a provider for line item in the fee sheet'),
(1544, 'Default to a provider for line item in the fee sheet.(only applicable if Support line item billing in option above)'),
(1545, 'Default to previous value'),
(1546, 'Default Units'),
(1547, 'Default Value'),
(1548, 'Default Warehouse'),
(1549, 'Default X12 Partner'),
(1550, 'Default/Global'),
(1551, 'Del'),
(1552, 'del'),
(1553, 'Delayed Recurrence (> 12 Mo)'),
(1554, 'Delete'),
(1555, 'delete'),
(1556, 'Delete Categories with ID(s) : '),
(1557, 'Delete Category'),
(1558, 'Delete Encounter Form'),
(1559, 'Delete failed!'),
(1560, 'Delete Group'),
(1561, 'Delete List'),
(1562, 'Delete Pages'),
(1563, 'Delete Patient, Encounter, Form, Issue, Document, Payment, Billing or Transaction'),
(1564, 'Delete Plan'),
(1565, 'Delete Row'),
(1566, 'Delete Selected Items'),
(1567, 'Delete Selected Requests'),
(1568, 'Delete successful.'),
(1569, 'Delete this document'),
(1570, 'Delete this form'),
(1571, 'Delete this note'),
(1572, 'Deleted Successfully'),
(1573, 'Deleted Successfully.'),
(1574, 'Deleting');
INSERT INTO `lang_constants` VALUES
(1575, 'Deleting this event cannot be undone. It cannot be recovered once it is gone. Are you sure you wish to delete this event?'),
(1576, 'Delivery Confirmed'),
(1577, 'Delivery is not allowed to the specified Direct Address.'),
(1578, 'Delivery is not currently permitted to the specified Direct Address.'),
(1579, 'Delivery of the attached clinical document was requested by the patient'),
(1580, 'Delivery of the attached clinical document was requested by the patient.'),
(1581, 'Dementia'),
(1582, 'Demographics'),
(1583, 'Demographics (write,addonly optional)'),
(1584, 'Demographics Fields'),
(1585, 'Demographics filter criteria'),
(1586, 'Demographics not authorized'),
(1587, 'Demographics not authorized.'),
(1588, 'Denied'),
(1589, 'Denominator'),
(1590, 'Dental'),
(1591, 'Dental Issue List'),
(1592, 'Dental Issues'),
(1593, 'Dependency Modules'),
(1594, 'Dependency Problem'),
(1595, 'Depending on the type of bill you are testing you will see HCFA like output on a blank page for HCFA bills, you will see many lines of somewhat garbled text  and information if you are testing an X12 claim. That garbled text is the X12 EDI 4010A format. Occasionally you will see odd characters that look like dominoes or  squiglies, these are control characters such as page feeds and are normal.'),
(1596, 'Deposit Date'),
(1597, 'Deposit Date Cannot be greater than Today'),
(1598, 'Deposit Date:'),
(1599, 'Depressed'),
(1600, 'Depression'),
(1601, 'DESC'),
(1602, 'Description'),
(1603, 'description'),
(1604, 'Description is default text'),
(1605, 'Description of the Disclosure'),
(1606, 'Description of this procedure or result code'),
(1607, 'Description Translation'),
(1608, 'Desired Filename'),
(1609, 'Destination'),
(1610, 'Destination Filename'),
(1611, 'Destroy Lot'),
(1612, 'Destroy...'),
(1613, 'Destroyed'),
(1614, 'Destroyed Drugs'),
(1615, 'Destroyed Drugs Report'),
(1616, 'Detail'),
(1617, 'Details'),
(1618, 'Developer'),
(1619, 'Developmental abnormality'),
(1620, 'Diabetes'),
(1621, 'Diabetes Mellitus'),
(1622, 'Diabetes: Blood Pressure Management (CQM)'),
(1623, 'Diabetes: Eye Exam'),
(1624, 'Diabetes: Eye Exam (CQM)'),
(1625, 'Diabetes: Foot Exam'),
(1626, 'Diabetes: Foot Exam (CQM)'),
(1627, 'Diabetes: HbA1c Poor Control (CQM)'),
(1628, 'Diabetes: Hemoglobin A1C'),
(1629, 'Diabetes: LDL Management & Control (CQM)'),
(1630, 'Diabetes: Urine Microalbumin'),
(1631, 'Diag'),
(1632, 'Diagnoses'),
(1633, 'Diagnosis'),
(1634, 'Diagnosis Code'),
(1635, 'Diagnosis Codes'),
(1636, 'Diagnosis Date'),
(1637, 'Diagnosis must be coded into a linked encounter'),
(1638, 'Diagnosis Name'),
(1639, 'Diagnosis Report'),
(1640, 'Diagnosis Reporting'),
(1641, 'Diagnosis Reporting Only'),
(1642, 'Diagnosis Title'),
(1643, 'Diagnosis:'),
(1644, 'Diagnosis: '),
(1645, 'Diagnostic Tests:'),
(1646, 'Dials'),
(1647, 'Diaphragms/Caps'),
(1648, 'Diarrhea'),
(1649, 'Diastolic'),
(1650, 'Dictation'),
(1651, 'Dictation: '),
(1652, 'Did you receive a copy of the HIPAA Notice?'),
(1653, 'Diffuse:'),
(1654, 'Digitally Signed'),
(1655, 'DIRECT ADDRESS'),
(1656, 'Direct Address'),
(1657, 'Direct Mail'),
(1658, 'Direct Message Log'),
(1659, 'Direct Message Received.'),
(1660, 'Direct messaging is currently unavailable.'),
(1661, 'Direct Messaging Send Failure.'),
(1662, 'Directions'),
(1663, 'Director Name'),
(1664, 'Directory delete failed; continuing.'),
(1665, 'Disability'),
(1666, 'Disable'),
(1667, 'Disable Calendar'),
(1668, 'Disable Chart Tracker'),
(1669, 'Disable Immunizations'),
(1670, 'Disable Old Metric Vitals Form'),
(1671, 'Disable Patient Flow Board'),
(1672, 'Disable phpMyAdmin'),
(1673, 'Disable Prescriptions'),
(1674, 'Disable User Groups'),
(1675, 'disabled'),
(1676, 'Disabled'),
(1677, 'Disabled Beneficiary Under Age 65 with Large Group Health Plan (LGHP)'),
(1678, 'DISC'),
(1679, 'Discard'),
(1680, 'Discarded'),
(1681, 'Discharge'),
(1682, 'Discharge From Urethra'),
(1683, 'Discharge Medications'),
(1684, 'Discharge Right'),
(1685, 'Discharge Right:'),
(1686, 'Discharge Summary'),
(1687, 'Discharge Time'),
(1688, 'Discharged'),
(1689, 'Disclosure Info'),
(1690, 'Disclosure Type'),
(1691, 'Disclosure Types'),
(1692, 'Disclosures'),
(1693, 'Discontinue'),
(1694, 'Discount'),
(1695, 'Discount Amount'),
(1696, 'Discount Level'),
(1697, 'Discount Percentage'),
(1698, 'Discounts as Monetary Amounts'),
(1699, 'Discounts at checkout time are entered as money amounts, as opposed to percentage.'),
(1700, 'Discrete Result'),
(1701, 'Disease'),
(1702, 'Dislocation'),
(1703, 'Disp #'),
(1704, 'Dispatch'),
(1705, 'Dispatch Received Document'),
(1706, 'Dispensed'),
(1707, 'Display advance directives in the demographics page.'),
(1708, 'Display Documents'),
(1709, 'Display event dates in block?'),
(1710, 'Display Format for US Weights'),
(1711, 'Display how many events?'),
(1712, 'Display Invoice Number or Patient Name or Both in the Sales Report'),
(1713, 'Display location in block?'),
(1714, 'Display Name'),
(1715, 'Display the calendar?'),
(1716, 'Display the Encounter Billing Note or Patient Billing Note or Both in the Billing Screen.'),
(1717, 'Display the Units Column on the Billing Screen'),
(1718, 'Display today''s events in the block?'),
(1719, 'Display topic in block?'),
(1720, 'Display upcoming events in block?'),
(1721, 'Displayed Columns'),
(1722, 'Displaying the following number of most recent disclosures:'),
(1723, 'Displaying the following number of most recent notes'),
(1724, 'Displaying the following number of most recent notes:'),
(1725, 'Distribution'),
(1726, 'Distributions'),
(1727, 'Distributor'),
(1728, 'Divehi- Dhivehi- Maldivian-'),
(1729, 'Diverticulitis'),
(1730, 'Diverticulitis Surgery'),
(1731, 'Divirticulitis'),
(1732, 'Divirticulitis Surgery'),
(1733, 'Divorced'),
(1734, 'Dizziness:'),
(1735, 'Do not change'),
(1736, 'Do not display Allergies uploaded after visiting NewCrop eRx.'),
(1737, 'Do not display Allergy uploaded to NewCrop'),
(1738, 'Do not display Medications uploaded after visiting NewCrop eRx.'),
(1739, 'Do not display Medications uploaded to NewCrop'),
(1740, 'Do not display NewCrop eRx Allergy uploaded'),
(1741, 'Do not display NewCrop eRx Medications uploaded'),
(1742, 'Do not display the calendar.'),
(1743, 'Do not display the patient flow board.'),
(1744, 'Do not inventory and sell any products'),
(1745, 'Do not require patient notes to be authorized'),
(1746, 'Do Not Resuscitate Order'),
(1747, 'do not save'),
(1748, 'do not substitute'),
(1749, 'do nothing'),
(1750, 'Do You Really Want to Continue'),
(1751, 'Do you really want to delete'),
(1752, 'Do you really want to delete the selection?'),
(1753, 'Do you really want to delete this group'),
(1754, 'Do you really want to delete?'),
(1755, 'Do you want to continue?'),
(1756, 'Do you want to delete this?'),
(1757, 'Do you want to delete?'),
(1758, 'Do you want to remove this record?'),
(1759, 'Do you wish to continue adding this new patient?'),
(1760, 'Do you wish to continue with the new name?'),
(1761, 'Do you wish to PERMANENTLY delete this immunization record?'),
(1762, 'DOB'),
(1763, 'DOB is missing, please enter if possible'),
(1764, 'Docs'),
(1765, 'Doctor'),
(1766, 'Doctor:'),
(1767, 'Doctor''s name and signature'),
(1768, 'Document'),
(1769, 'document'),
(1770, 'Document Categories'),
(1771, 'Document category for lab results does not exist'),
(1772, 'Document category name for storage of electronically received lab results.'),
(1773, 'Document category name for storage of electronically received MDM documents.'),
(1774, 'Document Category or Discard'),
(1775, 'Document could not be moved to patient id'),
(1776, 'Document created'),
(1777, 'Document Date'),
(1778, 'Document date and issue updated successfully'),
(1779, 'Document ID'),
(1780, 'Document moved to new category'),
(1781, 'Document moved to patient id'),
(1782, 'Document passed integrity check'),
(1783, 'Document passed integrity check.'),
(1784, 'Document Storage Method'),
(1785, 'Document successfully renamed.'),
(1786, 'Document tagged to Encounter successfully'),
(1787, 'Document Template Management'),
(1788, 'Document Templates'),
(1789, 'Document(s)'),
(1790, 'Document/Imaging Store'),
(1791, 'Documents'),
(1792, 'Documents (write,addonly optional)'),
(1793, 'DOC{{document format}}'),
(1794, 'DOE'),
(1795, 'Does not equal'),
(1796, 'does not match the PV1 encounter number'),
(1797, 'does not seem valid'),
(1798, 'Does this type allow related codes?'),
(1799, 'Domestic Partner'),
(1800, 'Don''t Save'),
(1801, 'Don''t Save'),
(1802, 'Don''t Save Changes'),
(1803, 'Done'),
(1804, 'Done with:'),
(1805, 'Done.  Will now send download.'),
(1806, 'DOS'),
(1807, 'Dosage'),
(1808, 'Dose'),
(1809, 'double click to edit'),
(1810, 'Double Vision'),
(1811, 'Download'),
(1812, 'DOWNLOAD'),
(1813, 'Download all patient documents'),
(1814, 'Download Anyway'),
(1815, 'Download billing file, post to accounting and mark as billed'),
(1816, 'Download CCDA file'),
(1817, 'Download Certificates'),
(1818, 'Download configuration data'),
(1819, 'Download document template for this patient and visit'),
(1820, 'download encrypted file'),
(1821, 'Download Fax'),
(1822, 'Download HL7 file'),
(1823, 'Download Offsite Portal Connection Files'),
(1824, 'Download or Delete a Template'),
(1825, 'Download PDF'),
(1826, 'Download QRDA Category III File'),
(1827, 'Download Selected Statements'),
(1828, 'Dr Check'),
(1829, 'Dr Visit'),
(1830, 'Dr.'),
(1831, 'Drag to move'),
(1832, 'Dribbling'),
(1833, 'Drivers License or State ID'),
(1834, 'Drug'),
(1835, 'Drug Finder'),
(1836, 'Drug Forms'),
(1837, 'Drug ID missing!'),
(1838, 'Drug Intervals'),
(1839, 'Drug Inventory'),
(1840, 'Drug Name'),
(1841, 'Drug Routes'),
(1842, 'Drug Screen'),
(1843, 'Drug Screen Completed'),
(1844, 'Drug Screen Report'),
(1845, 'Drug Units'),
(1846, 'Drugs'),
(1847, 'Drugs and Products'),
(1848, 'Dry Mouth'),
(1849, 'DSMIV Diagnosis'),
(1850, 'DT 1'),
(1851, 'DT 2'),
(1852, 'DT 3'),
(1853, 'DT 4'),
(1854, 'DT 5'),
(1855, 'DTaP 1'),
(1856, 'DTaP 2'),
(1857, 'DTaP 3'),
(1858, 'DTaP 4'),
(1859, 'DTaP 5'),
(1860, 'Due'),
(1861, 'Due Date'),
(1862, 'Due date mm/dd/yyyy or yyyy-mm-dd'),
(1863, 'Due Date:'),
(1864, 'Due Ins'),
(1865, 'Due Pt'),
(1866, 'Due Soon'),
(1867, 'Due Status'),
(1868, 'Due Status Update'),
(1869, 'Dumping LibreEHR database'),
(1870, 'Dumping LibreEHR web directory tree'),
(1871, 'Dumping phpGACL database'),
(1872, 'Dumping phpGACL web directory tree'),
(1873, 'Dumping SQL-Ledger database'),
(1874, 'Dumping SQL-Ledger web directory tree'),
(1875, 'Dup Check'),
(1876, 'Duplicated ID on line'),
(1877, 'Duplicated name on line'),
(1878, 'DUPLICATION WARNING'),
(1879, 'Durable Power of Attorney'),
(1880, 'duration'),
(1881, 'Duration'),
(1882, 'Dutch'),
(1883, 'Dx Rep'),
(1884, 'Dysphagia'),
(1885, 'Dyspnea:'),
(1886, 'Dysuria'),
(1887, 'Dzongkha'),
(1888, 'E-Prescription?'),
(1889, 'E-Reports'),
(1890, 'e-Rx'),
(1891, 'e-Rx EPCS'),
(1892, 'e-Rx Renewal'),
(1893, 'Each recipient must set their own messages as completed.'),
(1894, 'Early Recurrence (<2 Mo)'),
(1895, 'Ears'),
(1896, 'ECG'),
(1897, 'eClaims'),
(1898, 'Edema'),
(1899, 'edi history'),
(1900, 'EDI History'),
(1901, 'EDI History (under Fees) for storing and interpreting EDI claim response files'),
(1902, 'EDI-271 File Upload'),
(1903, 'EDI-271 Response File Upload'),
(1904, 'Edit'),
(1905, 'edit'),
(1906, 'Edit Allergies'),
(1907, 'Edit Categories'),
(1908, 'Edit Definitions'),
(1909, 'Edit definitions'),
(1910, 'Edit Diagnoses for'),
(1911, 'Edit Disclosure'),
(1912, 'Edit Facilities'),
(1913, 'Edit Facility'),
(1914, 'Edit Facility Information'),
(1915, 'Edit Facility Specific User Information'),
(1916, 'Edit File in'),
(1917, 'Edit form'),
(1918, 'Edit Global Settings'),
(1919, 'Edit is not authorized!'),
(1920, 'Edit layout'),
(1921, 'Edit list'),
(1922, 'Edit Payment'),
(1923, 'Edit Structure'),
(1924, 'Edit User'),
(1925, 'Edit User Settings'),
(1926, 'Edit your entered data'),
(1927, 'Editing failed'),
(1928, 'Education'),
(1929, 'Education Date'),
(1930, 'Educational materials for'),
(1931, 'ee the  * GNU General Public License for more details.  *   * You should have received a copy of the GNU General Public License  * along with this program; if not, write to the Free '),
(1932, 'Effective Date'),
(1933, 'Effective Dates'),
(1934, 'Effectiveness'),
(1935, 'EIN'),
(1936, 'Ejaculations'),
(1937, 'Elbow'),
(1938, 'Elbow Problems'),
(1939, 'Electronic'),
(1940, 'Electronic document received'),
(1941, 'Electronic Notes'),
(1942, 'Electronic Remits'),
(1943, 'Electronic Reports'),
(1944, 'Eligibility'),
(1945, 'Eligibility 270 Inquiry Batch'),
(1946, 'Eligibility Response'),
(1947, 'Eligibility status for Vaccine for Children supplied vaccine'),
(1948, 'Eligible'),
(1949, 'Email'),
(1950, 'email'),
(1951, 'Email Address'),
(1952, 'Email address is missing'),
(1953, 'Email address of the sender for patient reminders. Replies to patient reminders will be directed to this address. It is important to use an address from your clinic''s domain to avoid help prevent patient reminders from going to junk mail folders.'),
(1954, 'Email address, if any, to receive administrative notifications.'),
(1955, 'Email address, if any, to receive emergency login user activation messages.'),
(1956, 'Email Auth'),
(1957, 'Email from Batchcom'),
(1958, 'Email Notification'),
(1959, 'Email Notification Hours'),
(1960, 'Email Notification Report'),
(1961, 'Email send before'),
(1962, 'Email Sender'),
(1963, 'Email Sent'),
(1964, 'Email sent to'),
(1965, 'Email Subject'),
(1966, 'Email Text, Usable Tag: ***NAME*** , i.e. Dear ***NAME***'),
(1967, 'Email Text, Usable Tag: ***NAME*** , i.e. Dear ***NAME***{{Do Not translate the ***NAME*** elements of this constant.}}'),
(1968, 'Email Transport Method'),
(1969, 'Email was sent to following address'),
(1970, 'Emergency Care'),
(1971, 'Emergency Contact'),
(1972, 'Emergency Contact Person'),
(1973, 'Emergency Contact Phone Number'),
(1974, 'Emergency Contraception'),
(1975, 'Emergency Login'),
(1976, 'Emergency Login ACL is chosen. The user is still in active state, please de-activate the user and activate the same when required during emergency situations. Visit Administration->Users for activation or de-activation.'),
(1977, 'Emergency Login activation email will be circulated only if following settings in the interface/globals.php file are configured:'),
(1978, 'Emergency Login Email Address'),
(1979, 'Emergency Login user can do anything'),
(1980, 'Emergency Phone'),
(1981, 'Emotional / Behavioral Conditions & Complications'),
(1982, 'Emphysema'),
(1983, 'Employee'),
(1984, 'Employer'),
(1985, 'Employer Address'),
(1986, 'Employer Data'),
(1987, 'Employer Name'),
(1988, 'EMPTY'),
(1989, 'Empty'),
(1990, 'Empty Password Not Allowed'),
(1991, 'Empty value in "Email Hours"'),
(1992, 'Empty value in "Email Sender"'),
(1993, 'Empty value in "Email Subject"'),
(1994, 'Empty value in "Email Text"'),
(1995, 'Empty value in "Name of Provider"'),
(1996, 'Empty value in "Password"'),
(1997, 'Empty value in "SMS Hours"'),
(1998, 'Empty value in "SMS Text"'),
(1999, 'Empty value in "Username"'),
(2000, 'EMR Direct'),
(2001, 'Enable'),
(2002, 'Enable Alert Log'),
(2003, 'Enable Alert Logging'),
(2004, 'Enable Allergy Check'),
(2005, 'Enable Allergy Check Against Medications and Prescriptions'),
(2006, 'Enable AMC Prompting'),
(2007, 'Enable AMC Report Itemization'),
(2008, 'Enable AMC Reporting'),
(2009, 'Enable AMC Tracking'),
(2010, 'Enable amendments feature'),
(2011, 'Enable ATNA Auditing'),
(2012, 'Enable Audit Log Encryption'),
(2013, 'Enable Audit Logging'),
(2014, 'Enable Audit Trail and Node Authentication (ATNA).'),
(2015, 'Enable Automated Measure Calculations (AMC) Reporting'),
(2016, 'Enable Client SSL'),
(2017, 'Enable client SSL certificate authentication.'),
(2018, 'Enable Clinical Active Reminder Popup'),
(2019, 'Enable Clinical Decisions Rules (CDR)'),
(2020, 'Enable Clinical Passive New Reminder(s) Popup'),
(2021, 'Enable Clinical Passive Reminder Widget'),
(2022, 'Enable Clinical Quality Measure (CQM) Reporting'),
(2023, 'Enable Clinical Reminder Popup'),
(2024, 'Enable Clinical Reminder Widget'),
(2025, 'Enable CMS Portal'),
(2026, 'Enable CQM Report Itemization'),
(2027, 'Enable CQM Reporting'),
(2028, 'Enable EDI History In Left Menu'),
(2029, 'Enable Extension'),
(2030, 'Enable Fees In Left Menu'),
(2031, 'Enable Hylafax Support'),
(2032, 'Enable import status message after visiting NewCrop eRx.'),
(2033, 'Enable import status message for NewCrop erx'),
(2034, 'Enable Itemization of AMC Reports'),
(2035, 'Enable Itemization of CQM Reports'),
(2036, 'Enable Itemization of Standard Clinical Rules Reports'),
(2037, 'Enable Lab Exchange'),
(2038, 'Enable lock toggle'),
(2039, 'Enable log for document uploads/downloads to CouchDB'),
(2040, 'Enable logging of all SQL SELECT queries.'),
(2041, 'Enable logging of backup related activities.'),
(2042, 'Enable logging of CDR Engine Queries.'),
(2043, 'Enable logging of miscellaneous activities.'),
(2044, 'Enable logging of ordering activities.'),
(2045, 'Enable logging of patient record modifications.'),
(2046, 'Enable logging of scheduling activities.'),
(2047, 'Enable logging of security and administration activities.'),
(2048, 'Enable NewCrop eRx import status message'),
(2049, 'Enable NewCrop eRx Service'),
(2050, 'Enable NewCrop eRx Service.'),
(2051, 'Enable Offsite Patient Portal'),
(2052, 'Enable Offsite Patient Portal.'),
(2053, 'Enable Onsite Patient Portal'),
(2054, 'Enable Onsite Patient Portal Document Download'),
(2055, 'Enable Onsite Patient Portal.'),
(2056, 'Enable Patient Reminder Widget'),
(2057, 'Enable phiMail Direct Messaging Service'),
(2058, 'Enable Prompting For Automated Measure Calculations (AMC) Required Data'),
(2059, 'Enable Random Drug Testing'),
(2060, 'Enable Reporting of Tracking Date For Automated Measure Calculations (AMC)'),
(2061, 'Enable Scanner Support'),
(2062, 'Enable Standard Report Itemization'),
(2063, 'Enable support for the open source WordPress Portal by Sunset Systems'),
(2064, 'Enable the Medical Information Integration, LLC Lab Exchange Service.'),
(2065, 'Enable the LibreEHR Support LLC Lab Exchange Service.'),
(2066, 'Enable User Certificate Authentication'),
(2067, 'Enable ZMG, LLC eRx service'),
(2068, 'enabled'),
(2069, 'Enables the ability to download documents in the Onsite Patient Portal by the user.'),
(2070, 'Enables the old Charges panel for entering billing codes and payments. Not recommended, use the Fee Sheet instead.'),
(2071, 'Enc'),
(2072, 'Encnter'),
(2073, 'Encounter'),
(2074, 'encounter'),
(2075, 'Encounter '),
(2076, 'encounter acute inpatient or ED'),
(2077, 'Encounter Balance'),
(2078, 'Encounter Billing Note'),
(2079, 'Encounter Count'),
(2080, 'encounter data'),
(2081, 'Encounter Date'),
(2082, 'Encounter Diagnosis'),
(2083, 'Encounter Dt / Rsn'),
(2084, 'Encounter EDI Record'),
(2085, 'Encounter Esigned'),
(2086, 'Encounter Forms'),
(2087, 'encounter health and behavior assessment'),
(2088, 'Encounter History'),
(2089, 'Encounter ID'),
(2090, 'encounter influenza'),
(2091, 'Encounter number'),
(2092, 'Encounter Number'),
(2093, 'encounter nursing discharge'),
(2094, 'encounter nursing facility'),
(2095, 'encounter occupational therapy'),
(2096, 'encounter office visit'),
(2097, 'encounter outpatient'),
(2098, 'encounter outpatient w/PCP & obgyn'),
(2099, 'Encounter Page Size'),
(2100, 'Encounter Payment'),
(2101, 'encounter pregnancy'),
(2102, 'encounter preventive medicine - individual counseling'),
(2103, 'encounter preventive medicine 40 and older'),
(2104, 'encounter preventive medicine group counseling'),
(2105, 'encounter preventive medicine other services'),
(2106, 'encounter preventive medicine services 18 and older'),
(2107, 'encounter psychiatric & psychologic'),
(2108, 'Encounter statistics'),
(2109, 'Encounter Summary'),
(2110, 'Encounter was coded'),
(2111, 'Encounter:'),
(2112, 'Encounter: encounter non-acute inpt, outpatient, or ophthalmology'),
(2113, 'Encounters'),
(2114, 'Encounters & Forms'),
(2115, 'Encounters &amp; Forms'),
(2116, 'Encounters not authorized'),
(2117, 'Encounters Report'),
(2118, 'Encounters Section'),
(2119, 'Encrypted File'),
(2120, 'Encryption'),
(2121, 'End'),
(2122, 'End (yyyy-mm-dd): '),
(2123, 'End Date'),
(2124, 'End date'),
(2125, 'End date must be later than Begin date!'),
(2126, 'End date should be greater than Begin date'),
(2127, 'End Date:'),
(2128, 'End of Day by Provider or allow Totals Only'),
(2129, 'End Of Day Report'),
(2130, 'End of report'),
(2131, 'End Time'),
(2132, 'End-Stage Renal Disease Beneficiary in MCP with Employer`s Group Plan'),
(2133, 'Ending date of service yyyy-mm-dd'),
(2134, 'Ending DOS mm/dd/yyyy if you wish to enter a range'),
(2135, 'Ending hour of day for calendar events.'),
(2136, 'Endo Abnormal Blood'),
(2137, 'Endocrine'),
(2138, 'Endoscopy'),
(2139, 'Engineer'),
(2140, 'Engineering Firm'),
(2141, 'English'),
(2142, 'English '),
(2143, 'English (Indian)'),
(2144, 'English (Standard)'),
(2145, 'Enscript command used by Hylafax.'),
(2146, 'Ensure LibreEHR has write privileges to directory'),
(2147, 'ENT Discharge'),
(2148, 'ENT Pain'),
(2149, 'Enter a diagnosis code to exclude all invoices not containing it'),
(2150, 'Enter an amendment...'),
(2151, 'Enter body of letter here'),
(2152, 'Enter Database root Password'),
(2153, 'Enter Database root Username'),
(2154, 'Enter Diagnosis'),
(2155, 'Enter Drugs'),
(2156, 'Enter Encounter'),
(2157, 'Enter Encounter Number'),
(2158, 'Enter Immunizations'),
(2159, 'Enter Key'),
(2160, 'Enter new data'),
(2161, 'Enter new State'),
(2162, 'Enter Recipient''s Direct Address'),
(2163, 'Enter the LOINC code for this procedure'),
(2164, 'Enter the Re Identification code'),
(2165, 'Enter your search criteria above'),
(2166, 'Entered in Error'),
(2167, 'entries'),
(2168, 'Environmental'),
(2169, 'EOB Data Entry'),
(2170, 'EOB Posting - Electronic Remittances'),
(2171, 'EOB Posting - Instructions'),
(2172, 'EOB Posting - Invoice'),
(2173, 'EOB Posting - Patient Note'),
(2174, 'EOB Posting - Search'),
(2175, 'EOBs'),
(2176, 'Epilepsy'),
(2177, 'Equals'),
(2178, 'ERA'),
(2179, 'ERA Files'),
(2180, 'ERA Posting'),
(2181, 'Erase'),
(2182, 'Erections'),
(2183, 'Error'),
(2184, 'ERROR'),
(2185, 'Error confirming receipt of lab results'),
(2186, 'Error creating directory!'),
(2187, 'Error getting lab results from Lab Exchange Network'),
(2188, 'Error in "Gender" selection'),
(2189, 'Error in "HIPAA" selection'),
(2190, 'Error in "Process" selection'),
(2191, 'Error in "SMS Gateway" selection'),
(2192, 'Error in "Sort By" selection'),
(2193, 'Error in gzip compression of file: '),
(2194, 'Error in YES or NO option'),
(2195, 'Error opening uploaded file for reading'),
(2196, 'Error processing file'),
(2197, 'Error processing upload'),
(2198, 'Error Removing Message'),
(2199, 'Error retrieving results from Lab Exchange Network'),
(2200, 'Error retrieving values.'),
(2201, 'Error saving document'),
(2202, 'Error when granting file privilege to the LibreEHR user.'),
(2203, 'Error while adding new plan'),
(2204, 'Error while deleting the plan'),
(2205, 'error while registering form!'),
(2206, 'Error while saving to the file'),
(2207, 'Error while updating the plan'),
(2208, 'Error while writing to file'),
(2209, 'error(s) encountered from new results'),
(2210, 'Error, the file does not exist'),
(2211, 'ERROR, unable to collect data from server'),
(2212, 'Error, unable to create client certificate.'),
(2213, 'Error, unable to create the admin.p12 certificate.'),
(2214, 'Error, unable to create the Certificate Authority certificate.'),
(2215, 'Error, unable to create the Server certificate.'),
(2216, 'Error, unable to open file'),
(2217, 'Error, User Certificate Authentication is not enabled in LibreEHR'),
(2218, 'Error. You need to install the Archive/Tar.php php module.'),
(2219, 'ERROR: could not open table.sql, broken form?'),
(2220, 'Error: duplicated ID on line'),
(2221, 'Error: duplicated name on line'),
(2222, 'ERROR: Field'),
(2223, 'ERROR: Missing ZipArchive PHP Module'),
(2224, 'ERROR: No ICD import directory.'),
(2225, 'Error: passwords don''t match. Please check your typing.'),
(2226, 'Error: passwords don''t match. Please check your typing.'),
(2227, 'Error: the file does not exist'),
(2228, 'ERROR: The following variable contains invalid characters'),
(2229, 'ERROR: Unable to copy the file.'),
(2230, 'Error: Unable to create downloadable archive'),
(2231, 'ERROR: Unable to Create Zip Archive.'),
(2232, 'ERROR: Unable to extract the file.'),
(2233, 'ERROR: Unable to load the file into the database.'),
(2234, 'ERROR: Unable to set the version number.'),
(2235, 'Errors'),
(2236, 'eRx Account Status'),
(2237, 'eRx Logs'),
(2238, 'ERX Name'),
(2239, 'ERX Password'),
(2240, 'ERX Role'),
(2241, 'ERX User'),
(2242, 'Erythema:'),
(2243, 'eSign'),
(2244, 'eSign Log'),
(2245, 'Eskimo'),
(2246, 'Esperanto'),
(2247, 'Established Patient'),
(2248, 'Estonian'),
(2249, 'Ethnicity'),
(2250, 'Ethnicity or Race'),
(2251, 'Ethnicity-Race List (write,addonly optional)'),
(2252, 'ETIN'),
(2253, 'Event'),
(2254, 'Event Begins'),
(2255, 'Event Category'),
(2256, 'Event Date'),
(2257, 'Event Description'),
(2258, 'Event Details'),
(2259, 'Event does not repeat'),
(2260, 'Event Duration'),
(2261, 'Event duration in minutes'),
(2262, 'Event Fee'),
(2263, 'Event Location'),
(2264, 'Event repeats every'),
(2265, 'Event repeats on'),
(2266, 'Event start time'),
(2267, 'Event title'),
(2268, 'Event Title'),
(2269, 'Event Website'),
(2270, 'Events'),
(2271, 'Events for'),
(2272, 'Events open in new window'),
(2273, 'every'),
(2274, 'Every'),
(2275, 'every 3 hours'),
(2276, 'every 4 hours'),
(2277, 'every 5 hours'),
(2278, 'every 6 hours'),
(2279, 'every 8 hours'),
(2280, 'Every Fourth'),
(2281, 'Every Other'),
(2282, 'Every Third'),
(2283, 'Every, every other, every 3rd, etc.'),
(2284, 'Ewe'),
(2285, 'Exam and test results'),
(2286, 'Exam results'),
(2287, 'Exam Room #'),
(2288, 'Exam Room Number'),
(2289, 'Examination'),
(2290, 'Examination Date'),
(2291, 'Example'),
(2292, 'Examples'),
(2293, 'Exams/Tests'),
(2294, 'Except'),
(2295, 'Excessive Tearing'),
(2296, 'Excluded Patients'),
(2297, 'Exclusion'),
(2298, 'Exclusive Provider Organization (EPO)'),
(2299, 'Executive Paper Size'),
(2300, 'Exercise'),
(2301, 'Exercise Patterns'),
(2302, 'Exercise patterns'),
(2303, 'Exist'),
(2304, 'Exit from Administration'),
(2305, 'Exp'),
(2306, 'Expand'),
(2307, 'expand'),
(2308, 'Expand All'),
(2309, 'Expand All Document Categories'),
(2310, 'Expand All Document Categories by Default'),
(2311, 'Expanded View'),
(2312, 'Expected form_encounter.pid to be '),
(2313, 'Expiration'),
(2314, 'Expiration Date'),
(2315, 'Expires'),
(2316, 'expires in'),
(2317, 'Export'),
(2318, 'Export as CSV'),
(2319, 'Export Configuration'),
(2320, 'Export Individual Invoices'),
(2321, 'Export OFX'),
(2322, 'Export Patient Demographics'),
(2323, 'Export PQRI Report'),
(2324, 'Export QRDA Report'),
(2325, 'Export Selected as CSV'),
(2326, 'Export Selected to Collections'),
(2327, 'Export to CSV'),
(2328, 'Export to external billing system'),
(2329, 'Exposure to Foreign Countries'),
(2330, 'Exposure To Foreign Countries'),
(2331, 'Ext Time Collected'),
(2332, 'External'),
(2333, 'External Data'),
(2334, 'External Data Loads'),
(2335, 'External Database Import Utility'),
(2336, 'External ID'),
(2337, 'External Id'),
(2338, 'External identifier'),
(2339, 'External Only'),
(2340, 'External Organization'),
(2341, 'External Provider'),
(2342, 'External Referral'),
(2343, 'External Referral Followups'),
(2344, 'External referral?'),
(2345, 'External Referrals'),
(2346, 'Extract the zip file'),
(2347, 'Extracting the file. This will take some time...'),
(2348, 'Exudate:'),
(2349, 'Eye Irritation'),
(2350, 'Eye Pain'),
(2351, 'Eye Redness'),
(2352, 'Eyes'),
(2353, 'F'),
(2354, 'F/H Blood Problems'),
(2355, 'F/H Female Hirsutism/Striae'),
(2356, 'Facilities'),
(2357, 'Facility'),
(2358, 'facility'),
(2359, 'Facility Administration'),
(2360, 'Facility City'),
(2361, 'Facility Code'),
(2362, 'Facility Country code'),
(2363, 'Facility Fax'),
(2364, 'Facility Name'),
(2365, 'Facility NPI'),
(2366, 'Facility Phone'),
(2367, 'Facility Specific User Information'),
(2368, 'Facility State'),
(2369, 'Facility Street'),
(2370, 'Facility Zip'),
(2371, 'Facility Zip Code'),
(2372, 'Facility:'),
(2373, 'FAIL'),
(2374, 'failed'),
(2375, 'Failed'),
(2376, 'Failed Patients'),
(2377, 'Failed to add patient to portal'),
(2378, 'Failed to compute a unique filename'),
(2379, 'Failed to create'),
(2380, 'Failed to create temporary folder. CouchDB will not work.'),
(2381, 'Failed to send'),
(2382, 'Failed.'),
(2383, 'failure'),
(2384, 'Failure'),
(2385, 'FAILURE NOTICE: Direct Message Send Failed.'),
(2386, 'FAILURE: Couldn''t create the zip'),
(2387, 'FAILURE: No patients for measure'),
(2388, 'Falls: Screening, Risk-Assessment, and Plan of Care to Prevent Future Falls (CQM)'),
(2389, 'Family Health History'),
(2390, 'Family History'),
(2391, 'Family History of Glaucoma'),
(2392, 'Family History:'),
(2393, 'Family Member'),
(2394, 'Family Payment'),
(2395, 'Family Size'),
(2396, 'Fancy'),
(2397, 'Faroese'),
(2398, 'Farsi'),
(2399, 'Fatal'),
(2400, 'Father'),
(2401, 'Fathers History'),
(2402, 'Fatigue'),
(2403, 'Fatigued'),
(2404, 'Fax'),
(2405, 'Fax Count'),
(2406, 'Fax number'),
(2407, 'Fax sending failed'),
(2408, 'Fax/Scan'),
(2409, 'Faxes In'),
(2410, 'Faxes Out'),
(2411, 'Features'),
(2412, 'Feb'),
(2413, 'February'),
(2414, 'FECA'),
(2415, 'Federal Drug ID'),
(2416, 'Federal EIN'),
(2417, 'Federal Tax ID'),
(2418, 'Fee'),
(2419, 'fee'),
(2420, 'Fee is not allowed'),
(2421, 'Fee Sheet'),
(2422, 'Fee Sheet Options'),
(2423, 'Fees'),
(2424, 'Female'),
(2425, 'Female AP'),
(2426, 'Female Condoms'),
(2427, 'Female G'),
(2428, 'Female LC'),
(2429, 'Female P'),
(2430, 'Female Symptoms'),
(2431, 'Female VSC'),
(2432, 'Fetch'),
(2433, 'Fetching following file from portal'),
(2434, 'Fever'),
(2435, 'Fever:'),
(2436, 'FH Blood Problems'),
(2437, 'Fibroids'),
(2438, 'Field'),
(2439, 'Field ''name'' cannot be NULL'),
(2440, 'Field ID'),
(2441, 'Field type to use for employer or subscriber country in demographics.'),
(2442, 'Field type to use for employer or subscriber state in demographics.'),
(2443, 'Field(s) are missing!'),
(2444, 'Fields in This Form'),
(2445, 'Fifth account message'),
(2446, 'Fijian'),
(2447, 'File'),
(2448, 'file in the Documentation directory to learn how to automate the process of creating log backups'),
(2449, 'file location'),
(2450, 'File management'),
(2451, 'File Name'),
(2452, 'File path not found.'),
(2453, 'File privilege granted to LibreEHR user.'),
(2454, 'File retrieval from CouchDB failed'),
(2455, 'File Room'),
(2456, 'File to upload'),
(2457, 'File to Upload'),
(2458, 'File with same name already exists at location:'),
(2459, 'Filename'),
(2460, 'Filename must end with ".pdf"'),
(2461, 'Files'),
(2462, 'Filipino'),
(2463, 'Fill any of the Below Row.'),
(2464, 'Fill here only if sending email notification to patients'),
(2465, 'Fill in the values below'),
(2466, 'Fill Instructions'),
(2467, 'Fill the Row.'),
(2468, 'Filter'),
(2469, 'Filter for Constants'),
(2470, 'Filter for Definitions'),
(2471, 'filtered from'),
(2472, 'filters'),
(2473, 'Filters'),
(2474, 'Final'),
(2475, 'Final Diagnosis'),
(2476, 'Final diagnosis by specialist'),
(2477, 'Final Status'),
(2478, 'Financial'),
(2479, 'Financial Close Date (yyyy-mm-dd)'),
(2480, 'Financial Reporting - anything'),
(2481, 'Financial Reporting - my encounters'),
(2482, 'Financial Review Date'),
(2483, 'Financial Summary by Service Code'),
(2484, 'Find'),
(2485, 'Find Available'),
(2486, 'Find Available Appointments'),
(2487, 'Find Patient'),
(2488, 'Find Patient Education Materials'),
(2489, 'Findings'),
(2490, 'Findings by specialist'),
(2491, 'Fine'),
(2492, 'Finish Payments'),
(2493, 'finished'),
(2494, 'Finnish'),
(2495, 'First'),
(2496, 'First account message'),
(2497, 'First day of the week'),
(2498, 'First Name'),
(2499, 'First name'),
(2500, 'First Name:'),
(2501, 'First Visit or Consultation'),
(2502, 'Firstname Lastname'),
(2503, 'Fitness'),
(2504, 'Fitness Level'),
(2505, 'Fitness level for this player on this day'),
(2506, 'Fitness Testing'),
(2507, 'Fitness to Play'),
(2508, 'Fix encounter dates - any encounters'),
(2509, 'Fix this'),
(2510, 'FL'),
(2511, 'Flatulence'),
(2512, 'Flow'),
(2513, 'Flow Board'),
(2514, 'Flu season'),
(2515, 'Flu Season'),
(2516, 'Flu Vaccination'),
(2517, 'Fluid and electrolyte problem'),
(2518, 'FMS'),
(2519, 'Folio Paper Size'),
(2520, 'Follow manually'),
(2521, 'Follow these instructions for installing or upgrading the following database'),
(2522, 'Follow Up'),
(2523, 'Follow Up Note'),
(2524, 'Follow Up Reason'),
(2525, 'Following is a new custom constant:'),
(2526, 'Following is a new custom language:'),
(2527, 'Following is a new definition (Language, Constant, Definition):'),
(2528, 'Following rows in the audit log have been tampered'),
(2529, 'Followup Services'),
(2530, 'Followups Indicated'),
(2531, 'Food Intolerance'),
(2532, 'Foot'),
(2533, 'Foot Problems'),
(2534, 'Foot:'),
(2535, 'Football Injuries'),
(2536, 'Football Injury'),
(2537, 'Football Injury Report'),
(2538, 'Footwear Type'),
(2539, 'for'),
(2540, 'For'),
(2541, 'For code'),
(2542, 'For Dates'),
(2543, 'For Encounter Claims'),
(2544, 'For example:'),
(2545, 'For HCFA 02/12 Box 15 is Other Date with a qualifier to specify what the date indicates'),
(2546, 'For HCFA 02/12 Onset date specified on the Encounter Form needs a qualifier'),
(2547, 'for Invoice'),
(2548, 'For Medicare only, forces the referring provider to be the same as the rendering provider.'),
(2549, 'for OBR placer order number'),
(2550, 'for patient'),
(2551, 'For Provider'),
(2552, 'For Referred Organization/Practitioner'),
(2553, 'For the past'),
(2554, 'for variable'),
(2555, 'for:'),
(2556, 'Force Billing Widget Open'),
(2557, 'Force Create New Patient'),
(2558, 'Force Show'),
(2559, 'Forearm'),
(2560, 'Form'),
(2561, 'form'),
(2562, 'Form element not found'),
(2563, 'Form signed successfully'),
(2564, 'Format'),
(2565, 'format'),
(2566, 'Format for age display'),
(2567, 'Format incorrect for NDC'),
(2568, 'Format used to display most dates.'),
(2569, 'Format used to display most times.'),
(2570, 'Formatted Report'),
(2571, 'Former smoker'),
(2572, 'Forms'),
(2573, 'Forms Administration'),
(2574, 'Forms Esigned'),
(2575, 'Forward'),
(2576, 'Forward Pages via Fax'),
(2577, 'Forwarded'),
(2578, 'Foster Child'),
(2579, 'Fourth'),
(2580, 'Fourth account message'),
(2581, 'Fracture'),
(2582, 'Fracture at the Navicula'),
(2583, 'Fracture lateral malleolus'),
(2584, 'Fracture medial malleolus'),
(2585, 'Fracture, Base of fifth (5th) Metatarsal'),
(2586, 'Frame support required'),
(2587, 'French'),
(2588, 'French (Canadian)'),
(2589, 'French (Standard)'),
(2590, 'Frequency'),
(2591, 'Frequent Colds'),
(2592, 'Frequent Illness'),
(2593, 'Fri'),
(2594, 'Friday'),
(2595, 'From'),
(2596, 'FROM'),
(2597, 'from'),
(2598, 'From Date Cannot be Greater than To Date.'),
(2599, 'From:'),
(2600, 'From: '),
(2601, 'FROM_CITY'),
(2602, 'FROM_EMAIL'),
(2603, 'FROM_FNAME'),
(2604, 'FROM_LNAME'),
(2605, 'FROM_MNAME'),
(2606, 'FROM_PHONE'),
(2607, 'FROM_PHONECELL'),
(2608, 'FROM_POSTAL'),
(2609, 'FROM_STATE'),
(2610, 'FROM_STREET'),
(2611, 'FROM_TITLE'),
(2612, 'FROM_VALEDICTORY'),
(2613, 'Front Office'),
(2614, 'Front Office Receipts'),
(2615, 'Front Office Receipts Report'),
(2616, 'Front Rec'),
(2617, 'Frontal Right:'),
(2618, 'Fula- Fulah- Pulaar- Pular'),
(2619, 'Full Name'),
(2620, 'Full path to directory containing MySQL executables.'),
(2621, 'Full path to directory containing Perl executables.'),
(2622, 'Full path to directory for event log backup.'),
(2623, 'Full path to directory used for temporary files.'),
(2624, 'Full Play'),
(2625, 'Full Training'),
(2626, 'Fully Paid'),
(2627, 'Functional and Cognitive Status Form'),
(2628, 'Functional Cognitive Status'),
(2629, 'Functional Condition'),
(2630, 'Funding Source'),
(2631, 'Future'),
(2632, 'F{{Friday}}'),
(2633, 'G'),
(2634, 'G/DL'),
(2635, 'Galician'),
(2636, 'Gall Bladder Condition'),
(2637, 'Gall Stones'),
(2638, 'Game Period'),
(2639, 'Games'),
(2640, 'Games Missed'),
(2641, 'games/events'),
(2642, 'Games/Events Missed'),
(2643, 'Ganda'),
(2644, 'Gastritis'),
(2645, 'Gastro Pain'),
(2646, 'Gastrointestinal'),
(2647, 'GCAC Statistics Report'),
(2648, 'GCAC Stats'),
(2649, 'GCAC visit form is missing'),
(2650, 'Gender'),
(2651, 'Gender '),
(2652, 'General'),
(2653, 'General Issue List'),
(2654, 'General physician'),
(2655, 'General Service Category'),
(2656, 'Generate'),
(2657, 'Generate and download CMS 1500 paper claims'),
(2658, 'Generate and download HCFA 1500 paper claims'),
(2659, 'Generate and download X12 batch'),
(2660, 'Generate and download X12 encounter claim batch'),
(2661, 'Generate and transmit permissible prescriptions electronically (All Prescriptions).'),
(2662, 'Generate and transmit permissible prescriptions electronically (Not including controlled substances).'),
(2663, 'Generate and transmit permissible prescriptions electronically.'),
(2664, 'Generate CMS 1500'),
(2665, 'Generate CMS 1500 PDF'),
(2666, 'Generate CMS 1500 TEXT'),
(2667, 'Generate HCFA'),
(2668, 'Generate Invoice'),
(2669, 'Generate Letter'),
(2670, 'Generate Letter regarding '),
(2671, 'Generate PQRI report (Method A)'),
(2672, 'Generate PQRI report (Method A) - 2011'),
(2673, 'Generate PQRI report (Method E)'),
(2674, 'Generate PQRI report (Method E) - 2011'),
(2675, 'Generate QRDA I – 2014'),
(2676, 'Generate QRDA III - 2014'),
(2677, 'Generate Report'),
(2678, 'Generate Username And Password For'),
(2679, 'Generate X12'),
(2680, 'Generate X12 Encounter'),
(2681, 'Generate/Download QRDA I - 2014'),
(2682, 'Generated on'),
(2683, 'Generates'),
(2684, 'Genitourinary'),
(2685, 'Genitourinary medicine physician'),
(2686, 'Georgian'),
(2687, 'German'),
(2688, 'Gest age'),
(2689, 'Gestational Age'),
(2690, 'GET HL7'),
(2691, 'Get HL7'),
(2692, 'Glaucoma'),
(2693, 'Glaucoma Family History'),
(2694, 'Global'),
(2695, 'Global Default Patient Country'),
(2696, 'Global ID'),
(2697, 'Global Settings'),
(2698, 'Globals'),
(2699, 'GM/DL'),
(2700, 'go'),
(2701, 'Go'),
(2702, 'GO'),
(2703, 'Go Back'),
(2704, 'Go to'),
(2705, 'Go to week of'),
(2706, 'Go Today'),
(2707, 'Goal A'),
(2708, 'Goal and Methods'),
(2709, 'Goal B'),
(2710, 'Goal C'),
(2711, 'Grade of Injury'),
(2712, 'Grade:'),
(2713, 'grams'),
(2714, 'Grand Total'),
(2715, 'Grand Totals'),
(2716, 'Grandchild'),
(2717, 'Grandparent'),
(2718, 'Graphable'),
(2719, 'Great Grandparent'),
(2720, 'Greater Than'),
(2721, 'Greater Than or Equal To'),
(2722, 'Greek'),
(2723, 'Greek, Modern'),
(2724, 'Group'),
(2725, 'Group Name'),
(2726, 'Group names cannot be blank'),
(2727, 'Group names cannot start with numbers or spaces.'),
(2728, 'Group names cannot start with numbers.'),
(2729, 'Group Number'),
(2730, 'Group Payment'),
(2731, 'Group:'),
(2732, 'Groupname'),
(2733, 'Groups and Access Controls'),
(2734, 'Growth Chart'),
(2735, 'Growth-Chart'),
(2736, 'gtts(drops)'),
(2737, 'Guamanian'),
(2738, 'Guaraní'),
(2739, 'Guardian''s Name'),
(2740, 'Gujarati'),
(2741, 'Gynecological Exam'),
(2742, 'h'),
(2743, 'h.s.'),
(2744, 'H/O Hepatitis'),
(2745, 'had been successfully deleted. Any sub-categories if present were moved below'),
(2746, 'Haematoma / bruising'),
(2747, 'HAI Status'),
(2748, 'Haitian- Haitian Creole'),
(2749, 'Half-Sibling'),
(2750, 'Hand + fingers'),
(2751, 'Hand Problems'),
(2752, 'Hard Disk'),
(2753, 'Hardship w/o'),
(2754, 'has been linked to visit'),
(2755, 'has expired'),
(2756, 'Hash'),
(2757, 'Hash did not exist for this file. A new hash was generated.'),
(2758, 'Hash does not match. Data integrity has been compromised.'),
(2759, 'Hausa'),
(2760, 'Hawaiian'),
(2761, 'Hazardous Activities'),
(2762, 'Hazardous activities'),
(2763, 'HCFA left margin in points'),
(2764, 'HCFA Margins'),
(2765, 'HCFA top margin in points'),
(2766, 'HCPCS Procedure/Service'),
(2767, 'he PostCalendar '),
(2768, 'Head'),
(2769, 'Head Circ'),
(2770, 'Head Circumference'),
(2771, 'Headache'),
(2772, 'Headaches'),
(2773, 'health care operations'),
(2774, 'Health Care Operations'),
(2775, 'Health centre/clinic'),
(2776, 'Health Maintenance Organization'),
(2777, 'Health Maintenance Organization (HMO) Medicare Risk'),
(2778, 'Hearing Loss'),
(2779, 'Heart Attack'),
(2780, 'Heart Disease'),
(2781, 'Heart Failure'),
(2782, 'Heart Problem'),
(2783, 'Heart Problems'),
(2784, 'Heart Surgery'),
(2785, 'Heart Transplant'),
(2786, 'HEART:'),
(2787, 'Heartburn'),
(2788, 'Heat or Cold'),
(2789, 'Heat Or Cold'),
(2790, 'Heavy tobacco smoker'),
(2791, 'Hebrew'),
(2792, 'Hebrew (modern)'),
(2793, 'HEENT'),
(2794, 'Height'),
(2795, 'Height/Length'),
(2796, 'Help'),
(2797, 'help'),
(2798, 'Hematemesis'),
(2799, 'Hematochezia'),
(2800, 'Hematologic'),
(2801, 'Hematuria'),
(2802, 'Hemoglobin'),
(2803, 'Hemoglobin A1C'),
(2804, 'Hemoptysis'),
(2805, 'Hepatitis'),
(2806, 'Hepatitis A 1'),
(2807, 'Hepatitis A 2'),
(2808, 'Hepatitis B 1'),
(2809, 'Hepatitis B 2'),
(2810, 'Hepatitis B 3'),
(2811, 'here'),
(2812, 'Herero'),
(2813, 'Hernia Repair'),
(2814, 'Herniated Disc'),
(2815, 'Herpes'),
(2816, 'Hesitancy'),
(2817, 'heyyo. you have been here for '),
(2818, 'Hib 1'),
(2819, 'Hib 2'),
(2820, 'Hib 3'),
(2821, 'Hib 4'),
(2822, 'Hidden'),
(2823, 'Hidden Events Administration'),
(2824, 'Hide'),
(2825, 'Hide Details'),
(2826, 'Hide Empty E-Sign Logs On Report'),
(2827, 'Hide Encryption/Decryption Options In Document Management'),
(2828, 'Hide Menu'),
(2829, 'Hide print feature'),
(2830, 'Hide Reminders'),
(2831, 'Hide/Show Columns'),
(2832, 'HIE'),
(2833, 'High'),
(2834, 'High Blood Pressure'),
(2835, 'Hindi'),
(2836, 'Hip + groin'),
(2837, 'Hip and groin'),
(2838, 'Hip Problems'),
(2839, 'Hip Replacement'),
(2840, 'HIPAA Notice Received'),
(2841, 'Hiri Motu'),
(2842, 'Hirsutism/Striae'),
(2843, 'Hispanic'),
(2844, 'Hispanic - Other (Born in US)'),
(2845, 'Hispanic - Other (Born outside US)'),
(2846, 'Hispanic or Latino'),
(2847, 'History'),
(2848, 'History Data'),
(2849, 'History Date'),
(2850, 'History Fields'),
(2851, 'History Murmur'),
(2852, 'History not authorized'),
(2853, 'History of Heart Murmur'),
(2854, 'Hits'),
(2855, 'HIV'),
(2856, 'Hives'),
(2857, 'HL7'),
(2858, 'HL7 Viewer'),
(2859, 'HL7-V3 Concept Code'),
(2860, 'HMOL/L'),
(2861, 'Hmong'),
(2862, 'Hold down [Ctrl] for multiple selections or to unselect'),
(2863, 'Hold down Ctrl to select multiple items'),
(2864, 'Hold down Ctrl to select multiple squads'),
(2865, 'Home'),
(2866, 'Home Phone'),
(2867, 'Home Phone Number'),
(2868, 'Homeless or similar?'),
(2869, 'Homeless, etc'),
(2870, 'Homeless, etc.'),
(2871, 'Hooks'),
(2872, 'Host Name'),
(2873, 'Host Name cannot be empty'),
(2874, 'hour'),
(2875, 'Hour'),
(2876, 'Hours'),
(2877, 'hours'),
(2878, 'How did Injury Occur?'),
(2879, 'How did Injury Occur?:'),
(2880, 'How did they hear about us'),
(2881, 'How many months ahead to query for upcoming events?'),
(2882, 'HPI:'),
(2883, 'HT'),
(2884, 'HTML'),
(2885, 'HTML Output?'),
(2886, 'Https link for the LibreEHR Support LLC Lab Exchange Service.'),
(2887, 'Hungarian'),
(2888, 'Hylafax Directory'),
(2889, 'Hylafax Enscript Command'),
(2890, 'Hylafax Server'),
(2891, 'Hylafax server hostname.'),
(2892, 'Hyperactive'),
(2893, 'Hypertension'),
(2894, 'Hypertension: Blood Pressure Measurement'),
(2895, 'Hypertension: Blood Pressure Measurement (CQM)'),
(2896, 'Hyperthyroidism'),
(2897, 'Hypothyroidism'),
(2898, 'Hysterectomy'),
(2899, 'I'),
(2900, 'I am busy during this time.'),
(2901, 'I do not have permission to read '),
(2902, 'ICD'),
(2903, 'ICD10 Diagnosis'),
(2904, 'ICD10 Procedure/Service'),
(2905, 'ICD9'),
(2906, 'ICD9 Diagnosis'),
(2907, 'ICD9 Procedure/Service'),
(2908, 'Icelandic'),
(2909, 'ID'),
(2910, 'Id'),
(2911, 'ID cannot be blank'),
(2912, 'ID Card'),
(2913, 'IDays'),
(2914, 'identified as'),
(2915, 'Identifier(one word)'),
(2916, 'Identifying Code'),
(2917, 'Idle Session Timeout Seconds'),
(2918, 'Ido'),
(2919, 'If all data for all columns are complete for this form'),
(2920, 'If billing justification is used enter the name of the diagnosis code type.'),
(2921, 'if entered, select only those who have had this service'),
(2922, 'If name, any part of lastname or lastname,firstname'),
(2923, 'If paying by'),
(2924, 'If person is deceased, then enter date of death.'),
(2925, 'If SMTP is used, the server`s hostname or IP address.'),
(2926, 'If SMTP is used, the server`s TCP port number (usually 25).'),
(2927, 'if unemployed enter Student'),
(2928, 'If YMD is selected for age display, switch to just Years when patients older than this value in years'),
(2929, 'If you change e-RX Role for ePrescription, it may affect the ePrescription workflow. If you face any difficulty, contact your ePrescription vendor.'),
(2930, 'If you do not select a match the patient will be created.'),
(2931, 'If you have chosen to upload electronic remittances, then the search window redisplays itself with the matching invoices from the X12 file.  You may click on any of these invoice numbers (as described below) if you wish to make any corrections before the remittance information is applied. To apply the changes, click the Process ERA File button at the bottom of the page.  This will produce a new window with a detailed report.'),
(2932, 'If you have entered a Pay Date in the search page, this will override the posting date of payments and adjustments that are otherwise taken from the X12 file.  This may be useful for reporting purposes, if you want your receipts reporting to use your posting date rather than the insurance company''s processing date.  Note that this will also affect dates of prior payments and adjustments that are put into secondary claims.'),
(2933, 'If you want to change data types, or add rows or columns'),
(2934, 'If you want to upgrade the database, then place the database zip file in the following directory'),
(2935, 'Igbo'),
(2936, 'Ignore'),
(2937, 'Illness'),
(2938, 'IM'),
(2939, 'Image Results'),
(2940, 'Imaging'),
(2941, 'Imaging Service'),
(2942, 'Immunization'),
(2943, 'Immunization Code'),
(2944, 'Immunization Completion Status'),
(2945, 'Immunization Date'),
(2946, 'Immunization Expiration Date'),
(2947, 'Immunization Lot Number'),
(2948, 'Immunization Manufacturer'),
(2949, 'Immunization Registry'),
(2950, 'Immunization Report'),
(2951, 'Immunization Service'),
(2952, 'Immunization Title'),
(2953, 'Immunizations'),
(2954, 'Immunize'),
(2955, 'Immunologic'),
(2956, 'Implants'),
(2957, 'Import'),
(2958, 'Import All'),
(2959, 'Import CCDA'),
(2960, 'Import CCR'),
(2961, 'Import certificate to the browser.'),
(2962, 'Import Configuration'),
(2963, 'Import deferred for time-to-live'),
(2964, 'Import Patient'),
(2965, 'Import Patient Demographics'),
(2966, 'Important Codes'),
(2967, 'IMPORTANT: This upload tool is only for uploading documents on patients that are not yet entered into the system. To upload files for patients whom already have been entered into the system, please use the upload tool linked within the Patient Summary screen.'),
(2968, 'Imported Allergies'),
(2969, 'Imported from Accounting'),
(2970, 'Imported Medications'),
(2971, 'Imported Problems'),
(2972, 'Improved'),
(2973, 'in'),
(2974, 'IN'),
(2975, 'in each eye'),
(2976, 'in left eye'),
(2977, 'in nostril'),
(2978, 'In Office'),
(2979, 'in right eye'),
(2980, 'in-house'),
(2981, 'Inactive'),
(2982, 'Inactive Days'),
(2983, 'Inbox'),
(2984, 'INCITS Code'),
(2985, 'Include all values reported for each result code'),
(2986, 'Include Checksum'),
(2987, 'Include Completed'),
(2988, 'Include inactive users'),
(2989, 'Include Uncategorized'),
(2990, 'Include Unstructured data'),
(2991, 'Include Vitals'),
(2992, 'Include vitals data?'),
(2993, 'Inclusion'),
(2994, 'Income'),
(2995, 'Incoming results requiring attention:'),
(2996, 'Incomplete'),
(2997, 'Incomplete Abortion Treatment'),
(2998, 'Incontinence'),
(2999, 'Incorporate clinical lab-test results into certified EHR technology as structured data.'),
(3000, 'Incorrect password!'),
(3001, 'increased:'),
(3002, 'Indemnity Insurance'),
(3003, 'Indeterminate'),
(3004, 'Indian'),
(3005, 'Indicates abnormality'),
(3006, 'Indicates if this issue is currently active'),
(3007, 'Indications'),
(3008, 'Indicator for specialized usage'),
(3009, 'Indigent Patients'),
(3010, 'Indigent Patients Report'),
(3011, 'Indigents'),
(3012, 'Individual pages can override 2nd and 3rd options by implementing a log message.'),
(3013, 'Indonesian'),
(3014, 'Induced Abortion'),
(3015, 'Industry'),
(3016, 'Ineligible'),
(3017, 'Infection / Abscess'),
(3018, 'Infections'),
(3019, 'Infert Couns'),
(3020, 'Infertility'),
(3021, 'Influenza 1'),
(3022, 'Influenza 2'),
(3023, 'Influenza Immunization for Patients >= 50 Years Old'),
(3024, 'Influenza Immunization for Patients >= 50 Years Old (CQM)'),
(3025, 'Influenza Vaccine'),
(3026, 'Info'),
(3027, 'Info test 1'),
(3028, 'Info test 2'),
(3029, 'Info test 3'),
(3030, 'Info test 4'),
(3031, 'Info test 5'),
(3032, 'Info test 6'),
(3033, 'Informant'),
(3034, 'inhalations'),
(3035, 'inhilations'),
(3036, 'Initial Treatment'),
(3037, 'Initial User'),
(3038, 'Inj/Rehab'),
(3039, 'Injectables'),
(3040, 'Injection'),
(3041, 'Injured Body Part'),
(3042, 'Injured Out'),
(3043, 'Injury'),
(3044, 'Injury Mechanism'),
(3045, 'Injury Overview Report'),
(3046, 'Injury Surveillance'),
(3047, 'Injury Type'),
(3048, 'Injury/illness-related'),
(3049, 'Inline'),
(3050, 'Input does not begin with a MSH segment'),
(3051, 'Input Fields'),
(3052, 'INR'),
(3053, 'Ins 1'),
(3054, 'Ins 2 or Ins 3'),
(3055, 'Ins Address'),
(3056, 'Ins adjust'),
(3057, 'Ins bundling'),
(3058, 'Ins Code'),
(3059, 'Ins Group'),
(3060, 'Ins Name'),
(3061, 'Ins overpaid'),
(3062, 'Ins Policy'),
(3063, 'Ins refund'),
(3064, 'Ins Summary'),
(3065, 'Ins1'),
(3066, 'Ins2'),
(3067, 'Ins3'),
(3068, 'Insert'),
(3069, 'Insert failed: '),
(3070, 'Insert old events into tables'),
(3071, 'Insert special field'),
(3072, 'Insomnia'),
(3073, 'Inspect the log'),
(3074, 'Inspection'),
(3075, 'Instability / subluxation'),
(3076, 'INSTALL'),
(3077, 'Install'),
(3078, 'Install Code Set'),
(3079, 'install DB'),
(3080, 'Installed Release'),
(3081, 'Instructed'),
(3082, 'Instruction'),
(3083, 'Instructions'),
(3084, 'Instructions:'),
(3085, 'Insufficient inventory for product ID'),
(3086, 'Insulin Dependent Diabetes'),
(3087, 'Insurance'),
(3088, 'insurance'),
(3089, 'Insurance Adj'),
(3090, 'Insurance Adjustment'),
(3091, 'Insurance Balance'),
(3092, 'Insurance Balance Due'),
(3093, 'Insurance Comp'),
(3094, 'Insurance Companies'),
(3095, 'Insurance Company'),
(3096, 'Insurance Company Search/Add'),
(3097, 'Insurance Credit'),
(3098, 'Insurance Data'),
(3099, 'Insurance information on file'),
(3100, 'Insurance Numbers'),
(3101, 'Insurance Payment'),
(3102, 'Insurance Payments'),
(3103, 'Insurance Provider'),
(3104, 'Insurance Types'),
(3105, 'Insurances'),
(3106, 'Insured'),
(3107, 'Intake Conclusion'),
(3108, 'Intake Date'),
(3109, 'Intellectual Decline'),
(3110, 'Interlingua'),
(3111, 'Interlingue'),
(3112, 'Internal Allergies'),
(3113, 'Internal error - no pages were selected!'),
(3114, 'Internal error - patient ID was not provided!'),
(3115, 'Internal error accessing uploaded file!'),
(3116, 'Internal error!'),
(3117, 'Internal error, no drug ID specified!'),
(3118, 'Internal error: Cannot find MSH-10'),
(3119, 'Internal error: claim '),
(3120, 'Internal error: encounter '''),
(3121, 'Internal error: pid or encounter is missing.'),
(3122, 'Internal error: we do not seem to be in an encounter!'),
(3123, 'Internal Identifier (pid)'),
(3124, 'Internal Medications'),
(3125, 'Internal Problems'),
(3126, 'Internal Referrals'),
(3127, 'Internal Time Collected'),
(3128, 'International Duty'),
(3129, 'Interpreter'),
(3130, 'Interpreter needed?'),
(3131, 'Interstitial Lung Disease'),
(3132, 'Interval'),
(3133, 'Interval (minutes)'),
(3134, 'Interval between message checks (set to zero for manual checks only)'),
(3135, 'Intervention'),
(3136, 'Intervention Provided'),
(3137, 'Intolerance'),
(3138, 'Intradermal'),
(3139, 'intramuscularly'),
(3140, 'intravenously'),
(3141, 'Introduction'),
(3142, 'Inuktitut'),
(3143, 'Inupiaq'),
(3144, 'Invalid character in'),
(3145, 'Invalid date range'),
(3146, 'Invalid encapsulated data encoding type'),
(3147, 'Invalid length for'),
(3148, 'Invalid non-numeric character in'),
(3149, 'Invalid or missing payer in source for code '),
(3150, 'Invalid recipient address. Please try again.'),
(3151, 'Invalid Service Codes'),
(3152, 'Invalid source designation "'),
(3153, 'Invalid username or password'),
(3154, 'InvAmt'),
(3155, 'Inventory'),
(3156, 'Inventory Activity'),
(3157, 'Inventory and sell both drugs and non-drug products'),
(3158, 'Inventory and sell drugs only'),
(3159, 'Inventory is not available for this order.');
INSERT INTO `lang_constants` VALUES
(3160, 'Inventory List'),
(3161, 'Inventory Transactions'),
(3162, 'Invoice'),
(3163, 'invoice'),
(3164, 'Invoice Balance'),
(3165, 'Invoice Balance cannot be posted. No Encounter is created.'),
(3166, 'Invoice Date'),
(3167, 'Invoice has no date!'),
(3168, 'Invoice Number'),
(3169, 'Invoice Reference Number'),
(3170, 'Invoice reference number pool, if used'),
(3171, 'Invoice Reference Number Pools'),
(3172, 'Invoice Refno Pool'),
(3173, 'Invoice:'),
(3174, 'IPPF'),
(3175, 'IPPF Abortion'),
(3176, 'IPPF Contraception'),
(3177, 'IPPF SRH Data for'),
(3178, 'IPPF Statistics Report'),
(3179, 'IPPF Stats'),
(3180, 'IPV 1'),
(3181, 'IPV 2'),
(3182, 'IPV 3'),
(3183, 'IPV 4'),
(3184, 'Irish'),
(3185, 'Irregular Heart Beat'),
(3186, 'Irritability'),
(3187, 'Irritation'),
(3188, 'is a different language version of the following database'),
(3189, 'is a different version of the following database'),
(3190, 'is a more recent version of the following database'),
(3191, 'is a required field.'),
(3192, 'is a root node and can not be deleted.'),
(3193, 'is an extension of the following database'),
(3194, 'Is it ok to map these CVX codes to already existent immunizations?'),
(3195, 'is misplaced or unknown'),
(3196, 'Is not selected'),
(3197, 'is not valid (decimal fractions are OK).'),
(3198, 'Is PHP using Safe Mode?'),
(3199, 'Is selected'),
(3200, 'Is text from form layouts to be translated?'),
(3201, 'Is text from lists to be translated?'),
(3202, 'Is The File Encrypted?'),
(3203, 'Is this a Clinical Term code type?'),
(3204, 'Is this a diagnosis type?'),
(3205, 'Is this a Medical Problem code type?'),
(3206, 'Is this a Medication type?'),
(3207, 'Is this a procedure/service type?'),
(3208, 'Is this active?'),
(3209, 'Is this code type active?'),
(3210, 'Is this code type used in claims?'),
(3211, 'Is this really OK?'),
(3212, 'Is this type hidden in the fee sheet?'),
(3213, 'Is this using external sql tables? If it is, then choose the format.'),
(3214, 'is too long'),
(3215, 'ISO 639-2 Code'),
(3216, 'Issue'),
(3217, 'issue'),
(3218, 'Issue Date'),
(3219, 'Issue ID'),
(3220, 'Issue Title'),
(3221, 'Issue Type'),
(3222, 'Issue Types'),
(3223, 'Issues'),
(3224, 'Issues (Injuries/Medical/Allergy)'),
(3225, 'Issues (Injuries/Medical/Allergy):'),
(3226, 'Issues and Encounters'),
(3227, 'Issues and Encounters for'),
(3228, 'Issues not authorized'),
(3229, 'Issues Section'),
(3230, 'Italian'),
(3231, 'Item'),
(3232, 'item'),
(3233, 'items'),
(3234, 'Items load failed'),
(3235, 'IU/L'),
(3236, 'IUD'),
(3237, 'IV'),
(3238, 'Jan'),
(3239, 'January'),
(3240, 'Japanese'),
(3241, 'Jaundice'),
(3242, 'Javanese'),
(3243, 'Job Description'),
(3244, 'Job ID'),
(3245, 'Joint dislocations'),
(3246, 'Joint Pain'),
(3247, 'Joint sprains'),
(3248, 'Jul'),
(3249, 'July'),
(3250, 'Jun'),
(3251, 'June'),
(3252, 'Just below the check information is a blue area where you put in your search parameters.  You can search by patient name, chart number, encounter number or date of service, or any combination of these.  You may also select whether you want to see all invoices, open invoices, or only invoices that are due (by the patient).  Click the Search button to perform the search.'),
(3253, 'Just Mine'),
(3254, 'Justification Entries'),
(3255, 'Justify'),
(3256, 'Justify/Save'),
(3257, 'J{{Justify Header}}'),
(3258, 'k, here''s the rest '),
(3259, 'Kalaallisut, Greenlandic'),
(3260, 'Kannada'),
(3261, 'Kanuri'),
(3262, 'Kashmiri'),
(3263, 'Kazakh'),
(3264, 'Key'),
(3265, 'Keywords'),
(3266, 'kg'),
(3267, 'kg/m^2'),
(3268, 'Khmer'),
(3269, 'Kidney Cancer'),
(3270, 'Kidney Failure'),
(3271, 'Kidney Infections'),
(3272, 'Kidney Stones'),
(3273, 'Kidney Transplant'),
(3274, 'Kikuyu, Gikuyu'),
(3275, 'Kinyarwanda'),
(3276, 'Kirundi'),
(3277, 'Knee'),
(3278, 'Knee Problems'),
(3279, 'Knee Replacement'),
(3280, 'Komi'),
(3281, 'Kongo'),
(3282, 'Korean'),
(3283, 'Kurdish'),
(3284, 'Kwanyama, Kuanyama'),
(3285, 'Kyrgyz'),
(3286, 'Lab'),
(3287, 'Lab Documents'),
(3288, 'Lab Exchange Site Address'),
(3289, 'Lab Exchange Site ID'),
(3290, 'Lab Exchange Token ID'),
(3291, 'Lab Order'),
(3292, 'Lab overview'),
(3293, 'Lab Overview'),
(3294, 'Lab Query Status'),
(3295, 'Lab Report'),
(3296, 'Lab Result'),
(3297, 'Lab Results'),
(3298, 'Lab Results Category Name'),
(3299, 'Lab Results Report'),
(3300, 'Lab Service'),
(3301, 'Lab Test Results'),
(3302, 'Lab/File'),
(3303, 'Label'),
(3304, 'Label cannot be blank'),
(3305, 'Label Cols'),
(3306, 'Label for this type'),
(3307, 'LabelCols must be a number between 1 and 999'),
(3308, 'Labels'),
(3309, 'Laboratory Information'),
(3310, 'Laboratory Test'),
(3311, 'Labs'),
(3312, 'Laceration / skin condition'),
(3313, 'Laceration/abrasion'),
(3314, 'LADate'),
(3315, 'Landscape'),
(3316, 'Language'),
(3317, 'Language Code'),
(3318, 'Language definition added'),
(3319, 'Language Interface Tool'),
(3320, 'Language List (write,addonly optional)'),
(3321, 'Language Name'),
(3322, 'Language:'),
(3323, 'Lao'),
(3324, 'Laotian'),
(3325, 'Last'),
(3326, 'Last Activity Date'),
(3327, 'Last Appendectomy'),
(3328, 'Last Bill Date:'),
(3329, 'Last Breast Exam'),
(3330, 'Last Calendar Year'),
(3331, 'Last Cataract Surgery'),
(3332, 'Last Cholecystestomy'),
(3333, 'Last Encounter'),
(3334, 'Last Gyn. Exam'),
(3335, 'Last Heart Surgery'),
(3336, 'Last Hernia Repair'),
(3337, 'Last Hip Replacement'),
(3338, 'Last Hysterectomy'),
(3339, 'Last Knee Replacement'),
(3340, 'Last Level Billed'),
(3341, 'Last Mammogram'),
(3342, 'Last Menstrual Period'),
(3343, 'Last Month'),
(3344, 'Last Name'),
(3345, 'Last name'),
(3346, 'Last Name:'),
(3347, 'Last Physical Exam'),
(3348, 'Last Prostate Exam'),
(3349, 'Last Rectal Exam'),
(3350, 'Last Reviewed'),
(3351, 'Last Run Started At'),
(3352, 'Last Saved'),
(3353, 'Last Sigmoid/Colonoscopy'),
(3354, 'Last Stmt'),
(3355, 'Last Tonsillectomy'),
(3356, 'Last update by'),
(3357, 'Last Verified On'),
(3358, 'Last Visit'),
(3359, 'Last X-ray'),
(3360, 'Late Recurrence (2-12 Mo)'),
(3361, 'Lateral Malleolus'),
(3362, 'Lateral malleolus:'),
(3363, 'Laterality'),
(3364, 'Laterality of this procedure, if applicable'),
(3365, 'laterally displaced PMI:'),
(3366, 'Latest Results Only'),
(3367, 'Latest Visit or Consultation'),
(3368, 'Latin'),
(3369, 'Latvian'),
(3370, 'Law Firm'),
(3371, 'Lawyer'),
(3372, 'Layout'),
(3373, 'Layout Based'),
(3374, 'Layout Editor'),
(3375, 'Layout groups'),
(3376, 'Layout Style'),
(3377, 'Layout-Based Transaction Forms'),
(3378, 'Layout-Based Visit Forms'),
(3379, 'Layouts'),
(3380, 'lb'),
(3381, 'lbs'),
(3382, 'LDL'),
(3383, 'leave blank if still active'),
(3384, 'Leave Blank To Keep Original Filename'),
(3385, 'Leave blank to keep password unchanged.'),
(3386, 'Leave Message With'),
(3387, 'Leave The Form'),
(3388, 'Leaving the pass phrase blank will not encrypt the document'),
(3389, 'Ledger'),
(3390, 'Left'),
(3391, 'Left Ear'),
(3392, 'left ear'),
(3393, 'Left Margin (mm)'),
(3394, 'Left:'),
(3395, 'Left: '),
(3396, 'Leg Pain/Cramping'),
(3397, 'Legal'),
(3398, 'Legal Authenticator'),
(3399, 'Legal Paper Size'),
(3400, 'Legend:'),
(3401, 'Length'),
(3402, 'Length of modifier, 0 if none'),
(3403, 'Less Than'),
(3404, 'Less Than or Equal To'),
(3405, 'Less-private information (write,addonly optional)'),
(3406, 'Letter'),
(3407, 'Letter Generator'),
(3408, 'Letter Paper Size'),
(3409, 'Letterhead that doctor signs'),
(3410, 'Letterhead that patient signs'),
(3411, 'Level of urgency'),
(3412, 'Liability'),
(3413, 'Liability Medical'),
(3414, 'License/ID'),
(3415, 'Licensed Prescriber First Name'),
(3416, 'Licensed Prescriber Last Name'),
(3417, 'Licensed Prescriber NPI'),
(3418, 'Licensed Prescriber Title (Prefix)'),
(3419, 'LicensedPrescriber Last name'),
(3420, 'LicensedPrescriber NPI'),
(3421, 'LicensedPrescriber UPIN'),
(3422, 'Life threatening severity'),
(3423, 'Lifestyle'),
(3424, 'Lifestyle status'),
(3425, 'Ligament tear or sprain'),
(3426, 'Light tobacco smoker'),
(3427, 'Limburgish, Limburgan, Limburger'),
(3428, 'Limit Of Events'),
(3429, 'Limits'),
(3430, 'Lingala'),
(3431, 'Link'),
(3432, 'Link To Patient'),
(3433, 'Linked'),
(3434, 'Linked document'),
(3435, 'Linked procedure order'),
(3436, 'linked to document'),
(3437, 'linked to procedure order'),
(3438, 'List'),
(3439, 'List box'),
(3440, 'list box'),
(3441, 'list box w/ add'),
(3442, 'List box w/add'),
(3443, 'List Editor'),
(3444, 'List encounters'),
(3445, 'List groups'),
(3446, 'List Insurance Companies'),
(3447, 'List item ID'),
(3448, 'List items can not start with a number.'),
(3449, 'List items contains illegal character(s).'),
(3450, 'List layout items'),
(3451, 'List lists'),
(3452, 'List Name'),
(3453, 'List names cannot start with numbers.'),
(3454, 'List Prescriptions'),
(3455, 'List used by above Country Data Type option.'),
(3456, 'List used by above State Data Type option.'),
(3457, 'Listening port of the RFC 5425 TLS syslog server.'),
(3458, 'Lists'),
(3459, 'Lithuanian'),
(3460, 'Living Will'),
(3461, 'LLL:'),
(3462, 'LMP'),
(3463, 'Load Compendium'),
(3464, 'Load Definitions'),
(3465, 'Load Lab Configuration'),
(3466, 'Load OE Question Options'),
(3467, 'Load Order Definitions'),
(3468, 'Load Order Entry Questions'),
(3469, 'LOAD SUCCESSFUL. Codes inserted'),
(3470, 'LOADING'),
(3471, 'Loading the files into the database. This will take some time...'),
(3472, 'LOC'),
(3473, 'Local'),
(3474, 'Local Content'),
(3475, 'Local Filesystem'),
(3476, 'Locale'),
(3477, 'Locality'),
(3478, 'Location'),
(3479, 'location of the libreehr machine and may contain sensitive data, so it is recommended to manually delete the files after its use'),
(3480, 'Location of this lot'),
(3481, 'Location unspecified'),
(3482, 'Location where Hylafax stores faxes.'),
(3483, 'Location where scans are stored.'),
(3484, 'Location:'),
(3485, 'Lock'),
(3486, 'Lock an e-signed form individually'),
(3487, 'Lock e-signed encounters and their forms'),
(3488, 'Lock?'),
(3489, 'Locked'),
(3490, 'Log all NewCrop eRx Requests and / or Responses.'),
(3491, 'Log entire document'),
(3492, 'Log In'),
(3493, 'Log in'),
(3494, 'Log Out'),
(3495, 'Logged in'),
(3496, 'Logged in as'),
(3497, 'Logged in as: '),
(3498, 'Logged out.'),
(3499, 'Logging'),
(3500, 'Login'),
(3501, 'login'),
(3502, 'Login name of WordPress user for portal access'),
(3503, 'Login to remote host'),
(3504, 'Login to this remote host failed'),
(3505, 'Logout'),
(3506, 'logout'),
(3507, 'Logs'),
(3508, 'Logs Viewer'),
(3509, 'LOINC'),
(3510, 'Look Up'),
(3511, 'Lot'),
(3512, 'Lot ID missing!'),
(3513, 'Lot Number'),
(3514, 'Low'),
(3515, 'Low Priority'),
(3516, 'Lower leg'),
(3517, 'Lowest Priority'),
(3518, 'Luba-Katanga'),
(3519, 'Lumbar spine'),
(3520, 'LUNCH'),
(3521, 'Lunch'),
(3522, 'Lung Cancer'),
(3523, 'Lung Cancer Surgery'),
(3524, 'LUNGS:'),
(3525, 'Lungs:'),
(3526, 'Lupus'),
(3527, 'Luxembourgish, Letzeburgesch'),
(3528, 'M'),
(3529, 'MA Category'),
(3530, 'MA Client Accepting Abortion'),
(3531, 'MA Stats'),
(3532, 'Macedonian'),
(3533, 'Mail Sent'),
(3534, 'Main'),
(3535, 'Main Address'),
(3536, 'Main Top Pane Screen'),
(3537, 'Maintain active medication allergy list.'),
(3538, 'Maintain active medication list.'),
(3539, 'Maintain an up-to-date problem list of current and active diagnoses.'),
(3540, 'Make modifications to current categories.'),
(3541, 'Make new appointment for'),
(3542, 'Make sure "'),
(3543, 'Making batch text files for uploading to Clearing House and will mark as billed'),
(3544, 'Malagasy'),
(3545, 'Malaise:'),
(3546, 'Malay'),
(3547, 'Malayalam'),
(3548, 'Male'),
(3549, 'Male Condoms'),
(3550, 'Male VSC'),
(3551, 'Maltese'),
(3552, 'Mammogram'),
(3553, 'Manage'),
(3554, 'Manage Hooks'),
(3555, 'Manage Modules'),
(3556, 'Manage Translations'),
(3557, 'Management'),
(3558, 'Mandatory and specified fields'),
(3559, 'Mandatory or specified fields only, dup check, no search'),
(3560, 'Mandatory or specified fields only, search and dup check'),
(3561, 'Manual'),
(3562, 'Manual Posting'),
(3563, 'Manufacturer'),
(3564, 'Manx'),
(3565, 'Mar'),
(3566, 'Marathi'),
(3567, 'Marathi (Marāṭhī)'),
(3568, 'March'),
(3569, 'Marital Status'),
(3570, 'Mark as Billed'),
(3571, 'Mark as billed but skip billing'),
(3572, 'Mark as Cleared'),
(3573, 'Mark as not billed'),
(3574, 'Mark these reports as reviewed'),
(3575, 'Marked as cleared'),
(3576, 'Married'),
(3577, 'Marshallese'),
(3578, 'Mask'),
(3579, 'Mask for Invoice Numbers'),
(3580, 'Mask for Patient IDs'),
(3581, 'Mask for Product IDs'),
(3582, 'Match'),
(3583, 'Match case'),
(3584, 'Match Found'),
(3585, 'Matched Patient'),
(3586, 'MaternalAunt'),
(3587, 'MaternalGrandparent'),
(3588, 'MaternalGreatgrandparent'),
(3589, 'MaternalUncle'),
(3590, 'Matrix'),
(3591, 'Max'),
(3592, 'max file count reached - reload names below'),
(3593, 'Max Size'),
(3594, 'Maxillary Right:'),
(3595, 'Maximum Age'),
(3596, 'Maximum characters'),
(3597, 'Maximum idle time in seconds before logout. Default is 7200 (2 hours).'),
(3598, 'Maximum number of times a Patient can be tested in a year'),
(3599, 'Maximum number of times a Patient can be tested in a year. Zero is no limit.'),
(3600, 'Maximum reasonable inventory, 0 if not applicable'),
(3601, 'Maximum Size'),
(3602, 'Maximum Size (entering 0 will allow any size)'),
(3603, 'May'),
(3604, 'MC'),
(3605, 'mcg'),
(3606, 'MDM Document Category Name'),
(3607, 'Means none of last three passwords are allowed when changing a password.'),
(3608, 'Measure Blood Pressure'),
(3609, 'Measure Group Code'),
(3610, 'Measure INR'),
(3611, 'Measurement'),
(3612, 'Medial malleolus:'),
(3613, 'Medicaid'),
(3614, 'Medical'),
(3615, 'Medical Abortion'),
(3616, 'Medical Administration'),
(3617, 'Medical History'),
(3618, 'Medical Issue'),
(3619, 'Medical issue'),
(3620, 'Medical problem'),
(3621, 'Medical Problem'),
(3622, 'Medical Problem Issue List'),
(3623, 'Medical Problems'),
(3624, 'Medical Record'),
(3625, 'Medical Record #'),
(3626, 'Medical Records'),
(3627, 'Medical Records Sent'),
(3628, 'Medical Specialty'),
(3629, 'Medical Summary Given'),
(3630, 'Medical System'),
(3631, 'Medical Type'),
(3632, 'Medical/History (write,addonly optional)'),
(3633, 'Medicare Part B'),
(3634, 'Medicare Referrer Is Renderer'),
(3635, 'Medication'),
(3636, 'Medication Allergy List'),
(3637, 'Medication Issue List'),
(3638, 'Medication List'),
(3639, 'Medication Reconciliation Performed?'),
(3640, 'Medications'),
(3641, 'Medications:'),
(3642, 'Medicine Units'),
(3643, 'Medium'),
(3644, 'MedlinePlus Connect'),
(3645, 'Member Association Statistics Report'),
(3646, 'Memory Problems'),
(3647, 'Men'),
(3648, 'Men and Women'),
(3649, 'Men Only'),
(3650, 'Menarche'),
(3651, 'Menopause'),
(3652, 'Menstrual Flow'),
(3653, 'Menstrual Frequency'),
(3654, 'Mental Illness'),
(3655, 'Menu Text'),
(3656, 'Menus'),
(3657, 'Merge'),
(3658, 'Merge complete.'),
(3659, 'Merge Patients'),
(3660, 'Merge to any patient'),
(3661, 'Message'),
(3662, 'Message and Reminder Center'),
(3663, 'Message content is not plain text so it has been stored as a document.'),
(3664, 'Message from patient'),
(3665, 'Message Sent'),
(3666, 'Message Status'),
(3667, 'Message Title'),
(3668, 'Message to patient'),
(3669, 'Message type'),
(3670, 'MESSAGE:'),
(3671, 'Messages'),
(3672, 'Messages You have sent Today'),
(3673, 'Method'),
(3674, 'Method and Specific Product'),
(3675, 'Method for sending outgoing email.'),
(3676, 'Method of Destruction'),
(3677, 'Mexican/MexAmer/Chicano'),
(3678, 'Mexico'),
(3679, 'mg'),
(3680, 'mg/1cc'),
(3681, 'mg/2cc'),
(3682, 'mg/3cc'),
(3683, 'mg/4cc'),
(3684, 'mg/5cc'),
(3685, 'MG/DL'),
(3686, 'Middle'),
(3687, 'Middle Name'),
(3688, 'Middle name'),
(3689, 'Midlevel Prescriber'),
(3690, 'Midlevel Prescriber DEA'),
(3691, 'Midlevel Prescriber First name'),
(3692, 'Midlevel Prescriber Last name'),
(3693, 'Midlevel Prescriber Prefix'),
(3694, 'Midlevel Prescriber UPIN'),
(3695, 'Mien'),
(3696, 'Migrant or seasonal worker?'),
(3697, 'Migrant/Seasonal'),
(3698, 'Mil/CU.MM'),
(3699, 'Mild'),
(3700, 'Mild to moderate'),
(3701, 'MIME Type'),
(3702, 'MimeType'),
(3703, 'Min'),
(3704, 'min'),
(3705, 'Minimum Age'),
(3706, 'Minor joint strain +/- synovitis'),
(3707, 'minute'),
(3708, 'Minute'),
(3709, 'minutes'),
(3710, 'Minutes'),
(3711, 'Mirth IP'),
(3712, 'Misc'),
(3713, 'Misc Billing Options'),
(3714, 'Misc Billing Options for HCFA-1500'),
(3715, 'Misc Billing Options HCFA'),
(3716, 'Miscellaneous'),
(3717, 'Missed'),
(3718, 'missing'),
(3719, 'Missing a required field'),
(3720, 'Missing Fee'),
(3721, 'Missing Mods Only'),
(3722, 'Missing or Invalid'),
(3723, 'Missing PID.'),
(3724, 'Missing report date'),
(3725, 'Missing slash after payer in source for code '),
(3726, 'Mixed'),
(3727, 'ml'),
(3728, 'MM/DD/YYYY'),
(3729, 'mm/hg'),
(3730, 'mmHg'),
(3731, 'MMR 1'),
(3732, 'MMR 2'),
(3733, 'Mobile'),
(3734, 'Mobile Phone'),
(3735, 'Mod'),
(3736, 'Mod Date'),
(3737, 'Moderate'),
(3738, 'Moderate Priority'),
(3739, 'Moderate to severe'),
(3740, 'Moderate/Low Priority'),
(3741, 'Modifier'),
(3742, 'Modifiers'),
(3743, 'Modify'),
(3744, 'Modify Date'),
(3745, 'Modify Payments'),
(3746, 'ModLength'),
(3747, 'Module'),
(3748, 'Module Directory not found'),
(3749, 'Module Installer'),
(3750, 'Module Name'),
(3751, 'Module name already exist'),
(3752, 'Modules'),
(3753, 'Mon'),
(3754, 'Mon thru Fri'),
(3755, 'Mon, Wed &amp; Fri'),
(3756, 'Monday'),
(3757, 'Mongolian'),
(3758, 'Month'),
(3759, 'month'),
(3760, 'Month View'),
(3761, 'Month(s)'),
(3762, 'Monthly Income'),
(3763, 'Months'),
(3764, 'months'),
(3765, 'More than 100 records found. Please narrow your search criteria.'),
(3766, 'More than 50 results, please make your search more specific.'),
(3767, 'Most column headers can be clicked to change sort order'),
(3768, 'Most recent from'),
(3769, 'Most recent lab data:'),
(3770, 'Most recent vitals from:'),
(3771, 'Mother'),
(3772, 'Mother''s Name'),
(3773, 'Mothers History'),
(3774, 'Mouth'),
(3775, 'Move'),
(3776, 'Move Document to Category:'),
(3777, 'Move Down'),
(3778, 'Move failed!'),
(3779, 'Move to Patient'),
(3780, 'Move to...'),
(3781, 'Move Up'),
(3782, 'Moving'),
(3783, 'Mr.'),
(3784, 'MRN (pid)'),
(3785, 'Mrs.'),
(3786, 'Ms.'),
(3787, 'MSH-11'),
(3788, 'MSH-3.1'),
(3789, 'MSH-4.1'),
(3790, 'MSH-5.1'),
(3791, 'MSH-6.1'),
(3792, 'MSH.8 message type is not supported'),
(3793, 'MSH.8 message type is not valid'),
(3794, 'MSP Code'),
(3795, 'MSP Remit Codes'),
(3796, 'Multi Language Tool'),
(3797, 'Multiple areas'),
(3798, 'Multiple files can be uploaded at one time by selecting them using CTRL+Click or SHIFT+Click.'),
(3799, 'Multiple Lots'),
(3800, 'Multiple modifiers can be separated by colons or spaces, maximum of 4 (M1:M2:M3:M4)'),
(3801, 'Multiple Select List'),
(3802, 'Multiracial'),
(3803, 'Murmur:'),
(3804, 'Musc Ache'),
(3805, 'Musc Aches'),
(3806, 'Musc Redness'),
(3807, 'Musc Stiffness'),
(3808, 'Musc Swelling'),
(3809, 'Musc Warm'),
(3810, 'Muscle'),
(3811, 'Muscle injury'),
(3812, 'Musculoskeletal'),
(3813, 'Must be empty if SMTP authentication is not used.'),
(3814, 'Mutually Defined'),
(3815, 'MVA'),
(3816, 'MVX Code'),
(3817, 'My Health'),
(3818, 'Myself'),
(3819, 'M{{Monday}}'),
(3820, 'Māori'),
(3821, 'N/A'),
(3822, 'n/a'),
(3823, 'Name'),
(3824, 'NAME'),
(3825, 'Name (click for more)'),
(3826, 'Name 1'),
(3827, 'Name 2'),
(3828, 'Name and Title of Immunization Administrator'),
(3829, 'Name in EMR'),
(3830, 'Name must be like codetype_code_language.pdf, for example icd9_274.11_en.pdf'),
(3831, 'Name of Events'),
(3832, 'Name of insurance company'),
(3833, 'Name of Provider'),
(3834, 'Name of the sender for patient reminders.'),
(3835, 'Name Translation'),
(3836, 'Name/Value'),
(3837, 'Name:'),
(3838, 'NARES:'),
(3839, 'NARES: Normal Right'),
(3840, 'Nasal mucosa pink, septum midline'),
(3841, 'Nation Notes'),
(3842, 'Nation Notes Configure'),
(3843, 'Nation Notes Replace Buttons'),
(3844, 'Nationality'),
(3845, 'NationNotes'),
(3846, 'Native Data Loads'),
(3847, 'Native Hawaiian or Other Pacific Islander'),
(3848, 'Natural Child'),
(3849, 'Natural Parent'),
(3850, 'Natural Sibling'),
(3851, 'Nauru'),
(3852, 'Nausea'),
(3853, 'Navajo, Navaho'),
(3854, 'Navigation'),
(3855, 'Navigation area includes encounter forms'),
(3856, 'Navigation area uses full height of frameset'),
(3857, 'Navigation Area Visit Forms'),
(3858, 'Navigation Area Width'),
(3859, 'Navigation menu consists of pairs of radio buttons'),
(3860, 'Navigation menu is a tree view'),
(3861, 'Navigation uses a sliding menu'),
(3862, 'NDC'),
(3863, 'NDC Data'),
(3864, 'NDC Number'),
(3865, 'Ndonga'),
(3866, 'Neck'),
(3867, 'Neck Problems'),
(3868, 'Neck supple'),
(3869, 'Need to enter a description'),
(3870, 'Need to enter a Return Value'),
(3871, 'Need to enter identifier'),
(3872, 'Need to enter title'),
(3873, 'Needs Auth'),
(3874, 'Needs Justify'),
(3875, 'Needs secondary billing'),
(3876, 'Negative'),
(3877, 'Negatives'),
(3878, 'Neighbor'),
(3879, 'Nepali'),
(3880, 'Nerve injury'),
(3881, 'Neural condition / nerve damage'),
(3882, 'Neuro Numbness'),
(3883, 'Neuro Weakness'),
(3884, 'Neurologic'),
(3885, 'Never'),
(3886, 'Never Alcohol'),
(3887, 'Never smoker'),
(3888, 'New'),
(3889, 'New =>'),
(3890, 'New Acceptors'),
(3891, 'New Alerts'),
(3892, 'New Allergy'),
(3893, 'New amendment request'),
(3894, 'New Appointment'),
(3895, 'New Categories'),
(3896, 'New Category'),
(3897, 'New Clients'),
(3898, 'New Consultation'),
(3899, 'New Crop'),
(3900, 'New Definition set added'),
(3901, 'New Document'),
(3902, 'New Documents'),
(3903, 'New Due Clinical Reminders'),
(3904, 'New Encounter'),
(3905, 'New encounter created with id'),
(3906, 'New Encounter Form'),
(3907, 'New encounters not authorized'),
(3908, 'New Enctr'),
(3909, 'New Facility Information'),
(3910, 'New file'),
(3911, 'New Files'),
(3912, 'New Group'),
(3913, 'New Group Information'),
(3914, 'New Inj/Status'),
(3915, 'New Items (see above for details)'),
(3916, 'New Limit of Events'),
(3917, 'New List'),
(3918, 'New Orders'),
(3919, 'New Paragraph'),
(3920, 'New Password'),
(3921, 'New Patient'),
(3922, 'NEW PATIENT'),
(3923, 'New Patient Encounter'),
(3924, 'New Patient Form'),
(3925, 'New Patient ID'),
(3926, 'New Payment'),
(3927, 'New Portal Login'),
(3928, 'New Pt'),
(3929, 'New results from Lab Exchange'),
(3930, 'New Search'),
(3931, 'New Submissions'),
(3932, 'New User'),
(3933, 'New Value'),
(3934, 'New Visit'),
(3935, 'New/Search'),
(3936, 'NewCrop Account Status'),
(3937, 'NewCrop Admin'),
(3938, 'NewCrop call failed'),
(3939, 'NewCrop Doctor'),
(3940, 'NewCrop eRx Account Id'),
(3941, 'NewCrop eRx Account Name'),
(3942, 'NewCrop eRx Debug Setting'),
(3943, 'NewCrop eRx Default Patient Country'),
(3944, 'NewCrop eRx Name'),
(3945, 'NewCrop eRx Partner Name'),
(3946, 'NewCrop eRx Password'),
(3947, 'NewCrop eRX Role'),
(3948, 'NewCrop eRx Role'),
(3949, 'NewCrop eRx Site Address'),
(3950, 'NewCrop eRx SOAP Request Time-To-Live for Allergies'),
(3951, 'NewCrop eRx SOAP Request Time-To-Live for Medications'),
(3952, 'NewCrop eRx User Role'),
(3953, 'NewCrop eRx User Role * invalid selection *'),
(3954, 'NewCrop eRx Web Service Address'),
(3955, 'NewCrop Manager'),
(3956, 'NewCrop MedEntry'),
(3957, 'NewCrop Midlevel Prescriber'),
(3958, 'NewCrop Nurse'),
(3959, 'NewCrop Supervising Doctor'),
(3960, 'Newer'),
(3961, 'Newspaper'),
(3962, 'Next'),
(3963, 'Next Appointment Date'),
(3964, 'Next Day'),
(3965, 'Next Month'),
(3966, 'Next month (hold for menu)'),
(3967, 'Next Scheduled Run'),
(3968, 'Next Week'),
(3969, 'Next year (hold for menu)'),
(3970, 'Nick Name'),
(3971, 'Nickname'),
(3972, 'Niece/Nephew'),
(3973, 'Night Sweats'),
(3974, 'Nl ext genitalia, vag mucosa, cervix'),
(3975, 'No'),
(3976, 'NO'),
(3977, 'No access'),
(3978, 'No active patient reminders.'),
(3979, 'No adenopathy (2 areas required)'),
(3980, 'No adjustment reason type found for'),
(3981, 'No adnexal tenderness/masses'),
(3982, 'No amendment requests available'),
(3983, 'No Appointments'),
(3984, 'No audit log tampering detected in the selected date range.'),
(3985, 'No billing system is currently active'),
(3986, 'No Bills Found to Include in OFX Export'),
(3987, 'No Bills Found to Include in OFX Export<br>'),
(3988, 'No Changes Detected'),
(3989, 'No code was specified!'),
(3990, 'No Configuration Defined for this Module'),
(3991, 'No Data to Process'),
(3992, 'No Diagnosis'),
(3993, 'No Documents Found'),
(3994, 'No Encounter could be created'),
(3995, 'No end date'),
(3996, 'No entries found, use the form below to add an entry.'),
(3997, 'No errors found'),
(3998, 'No Events'),
(3999, 'No Fax Number Saved For The Selected Organization'),
(4000, 'No files staged for installation'),
(4001, 'No group was selected'),
(4002, 'No hernia'),
(4003, 'No Hooks Available in this Module'),
(4004, 'No Hooks enabled for this Module'),
(4005, 'No injury/illness'),
(4006, 'No Insurance Companies Found'),
(4007, 'No Issues'),
(4008, 'No issues in this encounter.'),
(4009, 'No items under selected category'),
(4010, 'No items were selected!'),
(4011, 'No Known Allergies'),
(4012, 'No Known Clinical Instructions'),
(4013, 'No Known Encounters'),
(4014, 'No Known Immunizations'),
(4015, 'No Known Lab Results'),
(4016, 'No Known Medications'),
(4017, 'No Known Plan of Care'),
(4018, 'No Known Problems'),
(4019, 'No Known Procedures'),
(4020, 'No Known Referrals'),
(4021, 'No Known Social Functional Status'),
(4022, 'No Known Social History'),
(4023, 'No Known Vitals'),
(4024, 'No lab data documented.'),
(4025, 'No log file exist for the selected date'),
(4026, 'No logging'),
(4027, 'No masses, tenderness'),
(4028, 'No match Patient record found for the given Re Idenitification code'),
(4029, 'No matches found. Try search again.'),
(4030, 'No matches were found.'),
(4031, 'No matches were found. Create the new patient now?'),
(4032, 'No matching records found'),
(4033, 'No new results found'),
(4034, 'No notes'),
(4035, 'No ogrganomegoly'),
(4036, 'No openings were found for this period.'),
(4037, 'No other phone numbers listed'),
(4038, 'No parameters selected'),
(4039, 'No Partners Found'),
(4040, 'No Patient record found for given Selection criteria'),
(4041, 'No Patient record found for the given Re Identification code'),
(4042, 'No peripheral edema'),
(4043, 'No Pharmacies Found'),
(4044, 'No Prescriptions Found'),
(4045, 'No presenting illness/injury'),
(4046, 'No previous entries.'),
(4047, 'No Primary Business Entity selected in facility list'),
(4048, 'No prior encounters.'),
(4049, 'No procedures in this encounter.'),
(4050, 'No provider was matched'),
(4051, 'No Providers Found'),
(4052, 'No rash or abnormal lesions'),
(4053, 'No records found'),
(4054, 'No records found.'),
(4055, 'No records found. Please expand your search criteria.'),
(4056, 'No Reminders'),
(4057, 'No Result Found, for the above search criteria.'),
(4058, 'No Results'),
(4059, 'No results found'),
(4060, 'No Results Found For Search'),
(4061, 'No results found, please try again.'),
(4062, 'No results, please tray again.'),
(4063, 'No results, please try again.'),
(4064, 'No Settings avaliable in this module'),
(4065, 'No Show'),
(4066, 'No signatures on file'),
(4067, 'No Sinus Tenderness:'),
(4068, 'No skin dimpling or breast nodules'),
(4069, 'NO SUCH CONTEXT NAME'),
(4070, 'No table selected! Select a table.'),
(4071, 'No testicular tenderness, masses'),
(4072, 'No thrills or heaves'),
(4073, 'No track selected'),
(4074, 'No tracks have been documented.'),
(4075, 'No visit'),
(4076, 'No vitals have been documented.'),
(4077, 'No, Cancel'),
(4078, 'No-fault Insurance including Auto is Primary'),
(4079, 'No:'),
(4080, 'Nocturia'),
(4081, 'Non Paid'),
(4082, 'Non Reported Report'),
(4083, 'Non specific injury'),
(4084, 'Non-electronic'),
(4085, 'Non-Insulin Dependent Diabetes'),
(4086, 'Non-Insured'),
(4087, 'Non-SRH Medical'),
(4088, 'Non-SRH Non-Medical'),
(4089, 'None'),
(4090, 'none'),
(4091, 'None defined'),
(4092, 'None have been documented'),
(4093, 'None of the above'),
(4094, 'None of the Top Distribution Row Can be Completly Blank.'),
(4095, 'Noninsulin Dependent Diabetes'),
(4096, 'Nor'),
(4097, 'Normal'),
(4098, 'Normal BL'),
(4099, 'Normal Cardiac Exam:'),
(4100, 'Normal Cardiac Exam: '),
(4101, 'Normal Lung Exam:'),
(4102, 'Normal Lung Exam: '),
(4103, 'Normal Office Visit'),
(4104, 'Normal Oropharynx:'),
(4105, 'Normal Right'),
(4106, 'Normal Right:'),
(4107, 'Normal View'),
(4108, 'normal:'),
(4109, 'Normally this should be checked. Not related to access control.'),
(4110, 'North Ndebele'),
(4111, 'Northern Sami'),
(4112, 'Norwegian'),
(4113, 'Norwegian Bokmål'),
(4114, 'Norwegian Nynorsk'),
(4115, 'Nose'),
(4116, 'Nosebleed'),
(4117, 'not a letter or number'),
(4118, 'Not Administered'),
(4119, 'Not all fields are required for all codes or code types.'),
(4120, 'Not Allowed'),
(4121, 'Not allowed to delete the Administrators group'),
(4122, 'Not Allowed to Edit'),
(4123, 'Not allowed to inactivate all security objects'),
(4124, 'Not allowed to inactivate anything from the Administrators ACL'),
(4125, 'Not allowed to remove the admin user from the Administrators group'),
(4126, 'Not allowed to remove this user from the Administrators group'),
(4127, 'Not Applicable'),
(4128, 'Not authorised to access PostCalendar module'),
(4129, 'Not authorized'),
(4130, 'Not Authorized'),
(4131, 'Not authorized for this squad!'),
(4132, 'Not authorized for this squad.'),
(4133, 'Not authorized to manage users!'),
(4134, 'Not authorized to sign results'),
(4135, 'Not Available'),
(4136, 'Not Billed'),
(4137, 'Not billed'),
(4138, 'Not Checked'),
(4139, 'Not checked out'),
(4140, 'Not Coded'),
(4141, 'Not Due'),
(4142, 'Not Esigned'),
(4143, 'Not Examined'),
(4144, 'Not Examined:'),
(4145, 'Not Examined: '),
(4146, 'not found'),
(4147, 'Not Found'),
(4148, 'not found!'),
(4149, 'Not Hispanic or Latino'),
(4150, 'Not installed'),
(4151, 'Not Installed'),
(4152, 'Not seen since'),
(4153, 'Not sent'),
(4154, 'Not Sent Yet'),
(4155, 'Not Specified'),
(4156, 'Not Specified.'),
(4157, 'Note'),
(4158, 'Note Codes'),
(4159, 'Note it will take 5-10 minutes to fully process after you click Install'),
(4160, 'Note it will take 5-10 minutes to fully process after you click Upgrade'),
(4161, 'Note that Audit Logging needs to be enabled above'),
(4162, 'Note Type'),
(4163, 'Note: 12:00 noon is PM, not AM'),
(4164, 'NOTE: Importing external data can take more than an hour depending on your hardware configuration. For example, one of the RxNorm data tables contain in excess of 6 million rows.'),
(4165, 'NOTE: Only the Biannual International Snomed Release is currently supported'),
(4166, 'NOTE: Only the full monthly RxNorm release is currently supported'),
(4167, 'Note: This code has not been authorized.'),
(4168, 'Note: This code was not entered by an authorized user. Only authorized codes may be uploaded to the Open Medical Billing Network for processing. If you wish to upload these codes, please select an authorized user here.'),
(4169, 'Note: This copay was entered against billing that has not been authorized. Please review status.'),
(4170, 'NOTE: Uploading files with duplicate names will cause the files to be automatically renamed (for example, file.jpg will become file.1.jpg). Filenames are considered unique per patient, not per category.'),
(4171, 'NOTE: Uploading files with duplicate names will cause the files to be automatically renamed. For example ''<i>file.jpg</i>'' will become ''<i>file.jpg.1</i>''. Filenames are considered unique per patient, not per category. '),
(4172, 'Notes'),
(4173, 'Notes - any encounters (write,addonly optional)'),
(4174, 'Notes - my encounters (write,addonly optional)'),
(4175, 'Notes not authorized'),
(4176, 'Nothing Pending for Approval'),
(4177, 'Nothing Recorded'),
(4178, 'Nothing to display'),
(4179, 'Nothing to import for Allergy'),
(4180, 'Nothing to import for Prescription'),
(4181, 'Nothing to show'),
(4182, 'Nothing was selected'),
(4183, 'Notice Received'),
(4184, 'NOTICE:: PostCalendar Submission/Modification'),
(4185, 'Notification'),
(4186, 'Notification Email Address'),
(4187, 'Notification sent to'),
(4188, 'Notifications'),
(4189, 'Notify Admin About Event Submission/Modification?'),
(4190, 'Nov'),
(4191, 'November'),
(4192, 'Now posting for:'),
(4193, 'Now printing'),
(4194, 'Now printing $stmt_count statements and updating encounters.'),
(4195, 'Now printing $stmt_count statements and updating invoices.'),
(4196, 'Now printing $stmt_count statements; encounters will not be updated.'),
(4197, 'Now printing $stmt_count statements; invoices will not be updated.'),
(4198, 'NPI'),
(4199, 'NQF'),
(4200, 'Number'),
(4201, 'Number labs'),
(4202, 'Number of Appointments to display in the Onsite Patient Portal'),
(4203, 'Number of Appointments to display in the Patient Summary'),
(4204, 'Number of columns in year view.'),
(4205, 'Number of days before showing fifth account message'),
(4206, 'Number of days before showing first account message'),
(4207, 'Number of days before showing first account message.'),
(4208, 'Number of days before showing fourth account message'),
(4209, 'Number of days before showing second account message'),
(4210, 'Number of days before showing third account message'),
(4211, 'Number of days that the client certificate is valid.'),
(4212, 'Number of days to search from the start date'),
(4213, 'Number of digits after decimal point for currency, usually 0 or 2.'),
(4214, 'Number of encounters to display per page.'),
(4215, 'Number of games or events missed, if any'),
(4216, 'Number of hours in advance to send email notifications.'),
(4217, 'Number of hours in advance to send Phone notification.'),
(4218, 'Number of hours in advance to send SMS notifications.'),
(4219, 'Number of Minutes to display completed checkouts'),
(4220, 'Number of Minutes to display completed checkouts. Zero is continuous display'),
(4221, 'Number of past history columns'),
(4222, 'Number of patients to display per page in the patient list.'),
(4223, 'Numbness'),
(4224, 'Numerator'),
(4225, 'Numeric display order'),
(4226, 'Nuosu'),
(4227, 'Nutrition'),
(4228, 'Nutritional'),
(4229, 'O.A.F.V.'),
(4230, 'O2 Sat'),
(4231, 'Obesity I'),
(4232, 'Obesity II'),
(4233, 'Obesity III'),
(4234, 'Objective'),
(4235, 'Observation Form'),
(4236, 'Occitan'),
(4237, 'Occupation'),
(4238, 'Occupational physician'),
(4239, 'Occurrence'),
(4240, 'Oct'),
(4241, 'October'),
(4242, 'OD'),
(4243, 'of'),
(4244, 'of quantity'),
(4245, 'of tablets'),
(4246, 'of the month every'),
(4247, 'Ofc Notes'),
(4248, 'Off'),
(4249, 'Office Notes'),
(4250, 'Office Visit'),
(4251, 'Official Clinical Quality Measures (CQM) Measure Groups'),
(4252, 'Offsite Https link for the Patient Portal.'),
(4253, 'Offsite Https link for the Patient Portal.(Patient Link)'),
(4254, 'Offsite Patient Portal Password'),
(4255, 'Offsite Patient Portal Password(Put Blank If not Registered).'),
(4256, 'Offsite Patient Portal Provider ID'),
(4257, 'Offsite Patient Portal Provider ID(Put Blank If not Registered).'),
(4258, 'Offsite Patient Portal Site Address'),
(4259, 'Offsite Patient Portal Site Address (Patient Link)'),
(4260, 'Offsite Patient Portal Username'),
(4261, 'Offsite Patient Portal Username(Put Blank If not Registered).'),
(4262, 'Offsite Portal web Service Failed'),
(4263, 'Offspring'),
(4264, 'Offspring History'),
(4265, 'ointment'),
(4266, 'Ojibwe, Ojibwa'),
(4267, 'OK'),
(4268, 'OK to close this other popup window?'),
(4269, 'OK to link the GCAC issue dated'),
(4270, 'Old'),
(4271, 'Old Church Slavonic, Church Slavonic, Old Bulgarian'),
(4272, 'Old Clients'),
(4273, 'Old fracture non / malunion'),
(4274, 'Old style layout with no left menu'),
(4275, 'Old-style static form without search or duplication check'),
(4276, 'Older'),
(4277, 'Omit'),
(4278, 'Omit circumferences'),
(4279, 'Omit employer information in patient demographics'),
(4280, 'Omit Employers'),
(4281, 'Omit form, route and interval which then become part of dosage'),
(4282, 'Omit insurance and some other things from the demographics form'),
(4283, 'Omit internal users?'),
(4284, 'Omit method of payment from the co-pay panel'),
(4285, 'omit to autoassign'),
(4286, 'on'),
(4287, 'On'),
(4288, 'On Hand'),
(4289, 'On Order'),
(4290, 'On Site'),
(4291, 'Once the Primary Business Facility is set, it should not be changed. Changing the facility will affect the working in NewCrop ePrescription.'),
(4292, 'Once you change your password, you will have to re-login.'),
(4293, 'Oncology: Medical and Radiation – Pain Intensity Quantified (CQM)'),
(4294, 'One Day Ago'),
(4295, 'One Month Ago'),
(4296, 'One Year Ago'),
(4297, 'Online Support'),
(4298, 'Online Support Link'),
(4299, 'Only Active'),
(4300, 'Only applicable if a provider or collated list was chosen above. PRIMARY only selects patients that the provider is the primary provider. ENCOUNTER selects all patients that the provider has seen.'),
(4301, 'Only for comparisons'),
(4302, 'only if billing location'),
(4303, 'Only Inactive'),
(4304, 'Only Mine'),
(4305, 'Only Show Diagnosis Reporting Codes'),
(4306, 'Only Show Service Code Finance Reporting Codes'),
(4307, 'Only upload active prescriptions'),
(4308, 'Only upload active prescriptions to NewCrop eRx.'),
(4309, 'Onset of Current Symptoms or Illness'),
(4310, 'Onset of Illness:'),
(4311, 'Onset of Ilness: '),
(4312, 'Onset of Swelling:'),
(4313, 'Onset/hosp. date:'),
(4314, 'Onsite Patient Portal Site Address'),
(4315, 'Oops!'),
(4316, 'Open'),
(4317, 'Open Demographics in New Window from Patient Flow Board'),
(4318, 'Open in New Window'),
(4319, 'Open Patient'),
(4320, 'Open Patient in New Window'),
(4321, 'Open Today`s Visit'),
(4322, 'LibreEHR already has a Certificate Authority configured.'),
(4323, 'LibreEHR Application Category'),
(4324, 'LibreEHR Database Upgrade'),
(4325, 'LibreEHR Database Upgrade for De-identification'),
(4326, 'LibreEHR does not recognize the incoming file in the contrib directory. This is most likely because you need to configure the release in the supported_external_dataloads table in the MySQL database.'),
(4327, 'LibreEHR must be configured to use certificates before it can create client certificates.'),
(4328, 'LibreEHR requires Javascript to perform user authentication.'),
(4329, 'LibreEHR Users'),
(4330, 'Openings'),
(4331, 'Operator'),
(4332, 'Opthalmic'),
(4333, 'Option'),
(4334, 'Option to save method of document storage.'),
(4335, 'Option to support inventory and sales of products'),
(4336, 'Optional'),
(4337, 'Optional category name for an ID Card image that can be viewed from the patient summary page.'),
(4338, 'Optional category name for photo images that can be viewed from the patient summary page.'),
(4339, 'Optional category name of a document to link to from the patient summary page. Lets you click on a patient name to see their ID card.'),
(4340, 'Optional default range for manual entry of results'),
(4341, 'Optional default units for manual entry of results'),
(4342, 'Optional Destination Name'),
(4343, 'Optional drug name, use % as a wildcard'),
(4344, 'Optional immunization name or code, use % as a wildcard'),
(4345, 'Optional information about this event'),
(4346, 'Optional lot number, use % as a wildcard'),
(4347, 'Optional numeric patient ID'),
(4348, 'Optional procedure code'),
(4349, 'Optional procedure/service code'),
(4350, 'Options'),
(4351, 'Or'),
(4352, 'OR'),
(4353, 'or choose'),
(4354, 'or click and drag for faster selection.'),
(4355, 'Or create this new field ID'),
(4356, 'Or Out To'),
(4357, 'or select from inventory'),
(4358, 'or Shift-click to decrease it'),
(4359, 'Or upload ERA file:'),
(4360, 'Oral'),
(4361, 'Oral mucosa pink, throat clear'),
(4362, 'Order'),
(4363, 'Order and Result Types'),
(4364, 'Order Catalog'),
(4365, 'Order Date'),
(4366, 'Order Descriptions'),
(4367, 'Order From'),
(4368, 'Order ID'),
(4369, 'Order must be a number between 1 and 999'),
(4370, 'Order Name'),
(4371, 'Order Priorities'),
(4372, 'Order Processor'),
(4373, 'Order Results'),
(4374, 'Order Status'),
(4375, 'Order Statuses'),
(4376, 'Order Summary'),
(4377, 'Order Tracks'),
(4378, 'Order Type'),
(4379, 'Order Types'),
(4380, 'Order/Result Type'),
(4381, 'Ordered'),
(4382, 'Ordered By'),
(4383, 'Ordered Procedure'),
(4384, 'Ordering Provider'),
(4385, 'Orders Path'),
(4386, 'Organ injury'),
(4387, 'Organization'),
(4388, 'Organization Name'),
(4389, 'Organizational Unit Name'),
(4390, 'Organizations'),
(4391, 'Orientated x 3'),
(4392, 'Original'),
(4393, 'Original Checksum'),
(4394, 'Oriya'),
(4395, 'Oromo'),
(4396, 'OROPHARYNX: '),
(4397, 'Orthopnea'),
(4398, 'OS'),
(4399, 'Osetoarthritis'),
(4400, 'Ossetian, Ossetic'),
(4401, 'Osteopathy'),
(4402, 'Other'),
(4403, 'other'),
(4404, 'Other (specify)'),
(4405, 'Other - Specified'),
(4406, 'Other Federal Program'),
(4407, 'Other HCFA'),
(4408, 'Other injury not elsewhere specified'),
(4409, 'Other Liability Insurance is Primary'),
(4410, 'other month'),
(4411, 'Other Non-Federal Programs'),
(4412, 'Other Notes'),
(4413, 'Other Pertinent Symptoms'),
(4414, 'Other Pertinent Symptoms:'),
(4415, 'Other pt resp'),
(4416, 'Other stress/Over use injury'),
(4417, 'Other Surgical'),
(4418, 'Other/Generic Abortion-Related'),
(4419, 'Other/Miscellaneous'),
(4420, 'Others'),
(4421, 'otherwise you will destroy references to/from existing data.'),
(4422, 'Ottawa Ankle Rules'),
(4423, 'OU'),
(4424, 'OUT'),
(4425, 'Out Of Office'),
(4426, 'Outbound Referral'),
(4427, 'Outcome'),
(4428, 'Outlook'),
(4429, 'Output Type'),
(4430, 'Overall Status Of Discharge'),
(4431, 'OVERDUE'),
(4432, 'Overuse'),
(4433, 'Overview'),
(4434, 'Overweight'),
(4435, 'Overwrite HIPAA choice'),
(4436, 'Owner'),
(4437, 'Oxygen Saturation'),
(4438, 'oz'),
(4439, 'P'),
(4440, 'p.c.'),
(4441, 'p.m.'),
(4442, 'p.r.n.'),
(4443, 'Pacific Islander'),
(4444, 'Paedeatric'),
(4445, 'Page'),
(4446, 'Pages'),
(4447, 'Paid'),
(4448, 'Paid amount that you will allocate'),
(4449, 'Paid Amt'),
(4450, 'Paid Via'),
(4451, 'Pain'),
(4452, 'Palliative care physician'),
(4453, 'Palpitation'),
(4454, 'Panjabi, Punjabi'),
(4455, 'Pap Smear'),
(4456, 'Paper'),
(4457, 'Paper Size'),
(4458, 'Paralysis'),
(4459, 'Parent'),
(4460, 'parent in-law'),
(4461, 'Parse HL7'),
(4462, 'Partially Administered'),
(4463, 'Partner'),
(4464, 'Partner Name'),
(4465, 'Partner Name issued for NewCrop eRx service.'),
(4466, 'Pashto, Pushto'),
(4467, 'Pass Phrase'),
(4468, 'Pass phrase to decrypt document'),
(4469, 'Passed Patients'),
(4470, 'Passive Alert'),
(4471, 'Passive Alert Rules'),
(4472, 'Password'),
(4473, 'Password Change'),
(4474, 'Password change successful'),
(4475, 'Password change successful.'),
(4476, 'Password does not meet minimum requirements and should contain at least three of the four following items: A number, a lowercase letter, an uppercase letter, a special character (Not a leter or number).'),
(4477, 'Password Expiration Grace Period'),
(4478, 'Password for Phone Gateway.'),
(4479, 'Password for Phone Gateway. Automated VOIP service provided by Maviq. Please visit http://signup.maviq.com for more information.'),
(4480, 'Password for SMS Gateway'),
(4481, 'Password for SMS Gateway.'),
(4482, 'Password for the above user'),
(4483, 'Password security has recently been upgraded.'),
(4484, 'Password to connect to CouchDB'),
(4485, 'Password too short. Minimum 8 characters required.'),
(4486, 'Password:'),
(4487, 'Passwords Don''t match!'),
(4488, 'Past Appoinments'),
(4489, 'Past Appointment Display Widget'),
(4490, 'Past due'),
(4491, 'Past Due'),
(4492, 'Past Due Interval (Clinical Reminders)'),
(4493, 'Past Due Interval (Patient Reminders)'),
(4494, 'Past Encounter List'),
(4495, 'Past Encounters'),
(4496, 'Past Encounters and Documents'),
(4497, 'Past Encounters for'),
(4498, 'Paste HL7 Data'),
(4499, 'Paste the data to import into the text area below:'),
(4500, 'Pat'),
(4501, 'Pat Ledger'),
(4502, 'Patch'),
(4503, 'PaternalAunt'),
(4504, 'PaternalCousin'),
(4505, 'PaternalGrandparent'),
(4506, 'PaternalGreatgrandparent'),
(4507, 'PaternalUncle'),
(4508, 'Path for Event Log Backup'),
(4509, 'Path to CA Certificate File'),
(4510, 'Path to CA Key File'),
(4511, 'Path to MySQL Binaries'),
(4512, 'Path to Perl Binaries'),
(4513, 'Path to Temporary Files'),
(4514, 'Patient'),
(4515, 'patient'),
(4516, 'PATIENT'),
(4517, 'Patient Address'),
(4518, 'Patient Address is missing'),
(4519, 'Patient Adj'),
(4520, 'Patient Adjustment'),
(4521, 'Patient allergies'),
(4522, 'Patient Allergies'),
(4523, 'Patient Appointment'),
(4524, 'Patient Balance'),
(4525, 'Patient Balance Due'),
(4526, 'Patient Billing Note'),
(4527, 'Patient Characteristics'),
(4528, 'Patient chart ID'),
(4529, 'Patient Checkout'),
(4530, 'Patient Checkout for '),
(4531, 'Patient City'),
(4532, 'Patient City is missing'),
(4533, 'Patient Communication sent'),
(4534, 'Patient Comunication Sent'),
(4535, 'Patient Country'),
(4536, 'Patient Country is missing. Also you have not set default Patient Country in Global Settings'),
(4537, 'Patient Coverage'),
(4538, 'Patient Credit'),
(4539, 'Patient Data'),
(4540, 'Patient Date Of Birth'),
(4541, 'Patient Date Of Birth is missing'),
(4542, 'Patient Details'),
(4543, 'Patient DOB'),
(4544, 'Patient Document'),
(4545, 'Patient Education'),
(4546, 'Patient Education Materials'),
(4547, 'Patient Encounter'),
(4548, 'Patient Encounter Form'),
(4549, 'Patient Encounters'),
(4550, 'Patient Finder'),
(4551, 'Patient First name'),
(4552, 'Patient First Name'),
(4553, 'Patient First name is missing'),
(4554, 'Patient Flow Board'),
(4555, 'Patient Flow Board Report'),
(4556, 'Patient Flow Board Rooms'),
(4557, 'Patient Flow Board Timer Interval'),
(4558, 'Patient Gender'),
(4559, 'Patient Gender is missing'),
(4560, 'Patient has not authorized the Patient Portal.'),
(4561, 'Patient History'),
(4562, 'Patient History / Lifestyle'),
(4563, 'Patient Home phone'),
(4564, 'Patient ID'),
(4565, 'Patient Id'),
(4566, 'Patient ID card'),
(4567, 'Patient ID Category Name'),
(4568, 'Patient Immunization'),
(4569, 'Patient Information'),
(4570, 'Patient Instructions'),
(4571, 'Patient Insurance Distribution'),
(4572, 'Patient Insurance Distribution Report'),
(4573, 'Patient Issues'),
(4574, 'Patient Label Type'),
(4575, 'Patient Last name'),
(4576, 'Patient Last Name'),
(4577, 'Patient Last name is missing'),
(4578, 'Patient Ledger'),
(4579, 'Patient Ledger by Date'),
(4580, 'Patient Level Billing Note (Collections)'),
(4581, 'Patient List'),
(4582, 'Patient List Columns'),
(4583, 'Patient List Creation'),
(4584, 'Patient List New Window'),
(4585, 'Patient List Page Size'),
(4586, 'Patient Lookup Errors'),
(4587, 'Patient Medical Problems'),
(4588, 'Patient Medications'),
(4589, 'Patient Name'),
(4590, 'Patient Name & Address'),
(4591, 'Patient Name and ID'),
(4592, 'Patient Name and Invoice'),
(4593, 'Patient Name Required'),
(4594, 'Patient Name/ID'),
(4595, 'Patient Note'),
(4596, 'Patient Note Types'),
(4597, 'Patient Notes'),
(4598, 'Patient Notes (write,addonly optional)'),
(4599, 'Patient Number'),
(4600, 'Patient Payment'),
(4601, 'Patient Payments'),
(4602, 'Patient Photo Category Name'),
(4603, 'Patient Portal'),
(4604, 'Patient Portal connectivity issue'),
(4605, 'Patient Portal is turned off'),
(4606, 'Patient Portal Login'),
(4607, 'Patient Portal Web Address'),
(4608, 'Patient Printed Report'),
(4609, 'Patient Record Report'),
(4610, 'Patient Record Request'),
(4611, 'Patient Records Request'),
(4612, 'Patient Religion'),
(4613, 'Patient Reminder'),
(4614, 'Patient Reminder Batch Job'),
(4615, 'Patient Reminder Creation Processing Priority'),
(4616, 'Patient Reminder Rules'),
(4617, 'Patient Reminder Sender Email'),
(4618, 'Patient Reminder Sender Name'),
(4619, 'Patient Reminders'),
(4620, 'Patient Report'),
(4621, 'Patient Request'),
(4622, 'Patient Requested Medical Records'),
(4623, 'Patient Results'),
(4624, 'Patient Search Results Style'),
(4625, 'Patient Search/Add Screen'),
(4626, 'Patient Setting'),
(4627, 'Patient State'),
(4628, 'Patient Street Address'),
(4629, 'Patient Summary'),
(4630, 'Patient Transactions'),
(4631, 'Patient Zip'),
(4632, 'patient(s) in the database that match the demographic information you have entered.'),
(4633, 'Patient/Client'),
(4634, 'Patient:'),
(4635, 'PatientID'),
(4636, 'Patients'),
(4637, 'Patients Processed'),
(4638, 'Pay'),
(4639, 'Pay attention to the "Done with" checkboxes.  After the insurances are marked complete then we will start asking the patient to pay the remaining balance; if you fail to mark all of the insurances complete then the remaining amount will not be collected!  Also if there is a balance that the patient should pay, then set the due date appropriately, as this will affect the language that appears on patient statements.'),
(4640, 'Pay Date:'),
(4641, 'Pay Status'),
(4642, 'Payee Name'),
(4643, 'Payer'),
(4644, 'Payer Type'),
(4645, 'Paying'),
(4646, 'Paying Entity'),
(4647, 'Payment'),
(4648, 'payment'),
(4649, 'Payment Adjustment Code'),
(4650, 'Payment against'),
(4651, 'Payment Amount'),
(4652, 'Payment Amount must be Numeric'),
(4653, 'Payment Category'),
(4654, 'Payment Date'),
(4655, 'payment entered on'),
(4656, 'Payment From'),
(4657, 'Payment Gateways'),
(4658, 'Payment Ins'),
(4659, 'Payment List'),
(4660, 'Payment Method'),
(4661, 'Payment Sort By'),
(4662, 'Payment Status'),
(4663, 'Payment Type'),
(4664, 'Payment value for code '),
(4665, 'Payments'),
(4666, 'Payor'),
(4667, 'PCP'),
(4668, 'Pct (%) of rows'),
(4669, 'PDF'),
(4670, 'PDF Download Selected Statements'),
(4671, 'PDF Language'),
(4672, 'Pelvis and buttock'),
(4673, 'Pemphigus'),
(4674, 'Pending'),
(4675, 'Pending Approval'),
(4676, 'Pending F/U'),
(4677, 'Pending followup'),
(4678, 'Pending Followup from Results'),
(4679, 'Pending Orders'),
(4680, 'Pending Res'),
(4681, 'Pending Review'),
(4682, 'Pending Rx Count'),
(4683, 'Penicillin Allergy'),
(4684, 'Pennington Firm LibreEHR  v'),
(4685, 'Peptic Ulcer Disease'),
(4686, 'Per Encounter'),
(4687, 'per min'),
(4688, 'Per Nostril'),
(4689, 'per nostril'),
(4690, 'Per Oris'),
(4691, 'per oris'),
(4692, 'Per Rectum'),
(4693, 'per rectum'),
(4694, 'Percent'),
(4695, 'Percentage of Patients to Drug Test'),
(4696, 'Percentage of Patients to select for Random Drug Testing.'),
(4697, 'Percentile'),
(4698, 'Perforated Right:'),
(4699, 'Perform Search'),
(4700, 'Perform this action'),
(4701, 'Performance Percentage'),
(4702, 'Performer'),
(4703, 'Performing Laboratory Facility'),
(4704, 'Performing organization'),
(4705, 'Period'),
(4706, 'Period in days where a user may login with an expired password.'),
(4707, 'Perioperative Care'),
(4708, 'Peripheral'),
(4709, 'Permit unsalted passwords'),
(4710, 'Persian'),
(4711, 'Persian (Farsi)'),
(4712, 'Person'),
(4713, 'Personalize'),
(4714, 'PG'),
(4715, 'Pharm'),
(4716, 'Pharm Com Count'),
(4717, 'Pharmacies'),
(4718, 'Pharmacy'),
(4719, 'Pharmacy Dispensary'),
(4720, 'Pheumothorax'),
(4721, 'phiMail Allow CCD Send'),
(4722, 'phiMail Allow CCR Send'),
(4723, 'phiMail Message Check Interval (minutes)'),
(4724, 'phiMail notification user'),
(4725, 'phiMail Password'),
(4726, 'phiMail Server Address'),
(4727, 'phiMail Username'),
(4728, 'PHIN Questions'),
(4729, 'Phone'),
(4730, 'Phone call list'),
(4731, 'Phone Call List report'),
(4732, 'Phone Cell'),
(4733, 'Phone Gateway Password'),
(4734, 'Phone Gateway URL'),
(4735, 'Phone Gateway Username'),
(4736, 'Phone Home'),
(4737, 'Phone Notification Hour'),
(4738, 'Phone Number'),
(4739, 'Phone number'),
(4740, 'Photophobia'),
(4741, 'Photos'),
(4742, 'PHP compressed'),
(4743, 'PHP CURL module should be enabled in your server.'),
(4744, 'PHP extracted'),
(4745, 'php-GACL access controls are turned off'),
(4746, 'PHP-gacl is not installed'),
(4747, 'Physical Exam'),
(4748, 'Physician'),
(4749, 'Physician Request'),
(4750, 'Physician Signature'),
(4751, 'Physician Type'),
(4752, 'Physicians'),
(4753, 'pick'),
(4754, 'Pick'),
(4755, 'Pick a CSS theme.'),
(4756, 'PID'),
(4757, 'PID (Pelvic Inflammatory Disease)'),
(4758, 'Pill Size'),
(4759, 'Pills'),
(4760, 'Place the database zip file in the following directory if want the option to install'),
(4761, 'Place the downloaded ICD 10 database zip files into the following directory'),
(4762, 'Place the downloaded ICD 9 database zip file into the following directory'),
(4763, 'Place the downloaded RxNorm database zip file into the following directory'),
(4764, 'Place the downloaded Snomed database zip file into the following directory'),
(4765, 'Placeholder'),
(4766, 'Placeholder (Maintains empty ACLs)'),
(4767, 'Plain Text'),
(4768, 'Plan'),
(4769, 'Plan Added Successfully'),
(4770, 'Plan Already in list_options'),
(4771, 'Plan Name'),
(4772, 'Plan Name Already Exists'),
(4773, 'Plan Name Already Taken'),
(4774, 'Plan Name Missing'),
(4775, 'Plan Set'),
(4776, 'Plan Status Changed'),
(4777, 'Plan Status Failed to Change'),
(4778, 'Plan Updated Successfully'),
(4779, 'Plan:'),
(4780, 'Planned Activity'),
(4781, 'Planned Date'),
(4782, 'Plans'),
(4783, 'Plans Configuration'),
(4784, 'Player'),
(4785, 'Playing Position'),
(4786, 'Please call if any of the above information is incorrect');
INSERT INTO `lang_constants` VALUES
(4787, 'Please change your password.'),
(4788, 'Please Choose a file'),
(4789, 'Please choose a patient'),
(4790, 'Please choose a valid selection from the list.'),
(4791, 'Please choose a valid selection.'),
(4792, 'Please choose a value for'),
(4793, 'Please choose date range criteria above, and click Refresh to view results.'),
(4794, 'Please choose the proper formatted EDI-271 file'),
(4795, 'Please Click download button to download the De Identified data'),
(4796, 'Please Click download button to download the Re Identified data'),
(4797, 'Please close this window.'),
(4798, 'Please compare the new name'),
(4799, 'Please contact your systems administrator, the following component(s) are required but are missing.'),
(4800, 'Please correct the value(s) before proceeding!'),
(4801, 'Please create the following directory before proceeding'),
(4802, 'Please do not accept this prescription unless it was received via facimile.'),
(4803, 'Please do not accept this prescription unless it was received via facsimile.'),
(4804, 'Please do NOT use your browsers stop or reload button while this page is running unless more than 10 minutes have elapsed, this will not cause the process to  stop on the server and will consume uneccesary resources.'),
(4805, 'PLEASE ENABLE CURL EXTENSION'),
(4806, 'PLEASE ENABLE OPENSSL EXTENSION'),
(4807, 'PLEASE ENABLE SOAP EXTENSION'),
(4808, 'PLEASE ENABLE XML EXTENSION'),
(4809, 'Please enter a date for Last Reviewed.'),
(4810, 'Please enter a date.'),
(4811, 'Please enter a due date'),
(4812, 'Please enter a message'),
(4813, 'Please enter a monetary amount using only numbers and a decimal point.'),
(4814, 'Please Enter a New Password'),
(4815, 'Please enter a title!'),
(4816, 'Please enter a valid Direct Address above.'),
(4817, 'Please enter at least the item''s name'),
(4818, 'Please enter at least the track''s name'),
(4819, 'Please enter correct Re Identification code'),
(4820, 'Please Enter End Date greater than Begin Date!'),
(4821, 'Please enter new search string'),
(4822, 'Please enter the correct Re Identification code'),
(4823, 'Please enter the password'),
(4824, 'Please Fill the Check Number'),
(4825, 'Please Fill the Check/Ref Number'),
(4826, 'Please Fill the Date'),
(4827, 'Please Fill the Payment Amount'),
(4828, 'Please Fill the Payment Category'),
(4829, 'Please Fill the Payment From'),
(4830, 'Please Fill the Post To Date'),
(4831, 'Please fill them in before continuing.'),
(4832, 'Please indicate visit reason'),
(4833, 'Please input search criteria above, and click Submit to start report.'),
(4834, 'Please input search criteria above, and click Submit to view results.'),
(4835, 'Please input search criteria above, and click Submit to view results. (Results will be displayed in a pop up window)'),
(4836, 'Please login again.'),
(4837, 'Please note that this can take a very long time, up to several minutes, your web browser may not appear very active during this time but generating a bill is a  complicated process and your web browser is merely waiting for more information.'),
(4838, 'Please Note: constants are case sensitive and any string is allowed.'),
(4839, 'Please only use alphabetic characters'),
(4840, 'Please only use alphabetic characters with no spaces'),
(4841, 'Please pay this amount'),
(4842, 'Please place your install files in following directory'),
(4843, 'Please refer to'),
(4844, 'Please reset the password.'),
(4845, 'Please restart the apache server before playing with de-identification'),
(4846, 'Please see the attached PDF.'),
(4847, 'Please Select'),
(4848, 'Please select a format'),
(4849, 'Please select a language'),
(4850, 'Please Select a Patient.'),
(4851, 'Please select a Primary Business Entity facility with ''Tax ID'' as your facility Tax ID. If you are an individual practitioner, use your tax id. This is used for identifying you in the NewCrop system.'),
(4852, 'Please select a Primary Business Entity facility with ''Tax ID'' as your facility Tax ID. If you are an individual practitioner, use your tax id. This is used for identifying you in the NewCrop system.'),
(4853, 'Please select a procedure provider'),
(4854, 'Please Select A Recipient'),
(4855, 'Please select a start date and end date'),
(4856, 'Please select a valid recipient'),
(4857, 'Please Select an Active Group'),
(4858, 'Please select an adjustment reason for code '),
(4859, 'Please select an event'),
(4860, 'Please select any Search Option.'),
(4861, 'Please select at least one criteria to download'),
(4862, 'Please select at least one patient.'),
(4863, 'Please select at least one prescription!'),
(4864, 'Please select encounter'),
(4865, 'Please select the desired pages to copy or forward:'),
(4866, 'Please Select the Payment Method'),
(4867, 'Please Select Type Of Payment.'),
(4868, 'Please select visit category'),
(4869, 'Please select X12 partner, required to create the 270 batch'),
(4870, 'Please set'),
(4871, 'Please set de_identification_config variable back to zero'),
(4872, 'Please Specify at least One Direct Address'),
(4873, 'Please start new De Identification process'),
(4874, 'Please upgrade LibreEHR Database to include De Identification procedures, function, tables'),
(4875, 'Please view De Identification error log table for more details'),
(4876, 'Please visit De Identification screen after some time'),
(4877, 'Please visit Re Identification screen after some time'),
(4878, 'Please visit the screen after some time'),
(4879, 'Plot item'),
(4880, 'Plot selected Items'),
(4881, 'Plural'),
(4882, 'PM'),
(4883, 'PM Program'),
(4884, 'Pmt Method'),
(4885, 'PND'),
(4886, 'Pneumococcal Conjugate 1'),
(4887, 'Pneumococcal Conjugate 2'),
(4888, 'Pneumococcal Conjugate 3'),
(4889, 'Pneumococcal Conjugate 4'),
(4890, 'Pneumococcal Vaccine'),
(4891, 'Pneumonia Vaccination'),
(4892, 'Pneumonia Vaccination Status for Older Adults'),
(4893, 'Pneumonia Vaccination Status for Older Adults (CQM)'),
(4894, 'Podiatric'),
(4895, 'Podiatry'),
(4896, 'Point of Service (POS)'),
(4897, 'Policy'),
(4898, 'Policy No'),
(4899, 'Policy Number'),
(4900, 'Polish'),
(4901, 'Polydypsia'),
(4902, 'Polyps'),
(4903, 'Polyuria'),
(4904, 'Poor Appetite'),
(4905, 'Poor Circulation'),
(4906, 'Poor Hearing'),
(4907, 'Pop ups need to be enabled to see these reports'),
(4908, 'Populate the year view with events?'),
(4909, 'Popups'),
(4910, 'Portal'),
(4911, 'Portal Activity'),
(4912, 'Portal ID'),
(4913, 'Portal ID does not match request from portal!'),
(4914, 'Portal password is missing'),
(4915, 'Portal Requests'),
(4916, 'Portrait'),
(4917, 'Portuguese'),
(4918, 'Portuguese (Brazilian)'),
(4919, 'Portuguese (European)'),
(4920, 'POS Code'),
(4921, 'Position'),
(4922, 'Positive'),
(4923, 'Positives'),
(4924, 'Post Date'),
(4925, 'Post For'),
(4926, 'Post Nasal Drip'),
(4927, 'Post Payments'),
(4928, 'Post surgical'),
(4929, 'Post to accounting and mark as billed'),
(4930, 'Post To Date'),
(4931, 'Post To Date Cannot be greater than Today'),
(4932, 'Post To Date Must be greater than the Financial Close Date.'),
(4933, 'Post-Abortion Care'),
(4934, 'Post-Abortion Contraception'),
(4935, 'Post-Abortion Counseling'),
(4936, 'Post-Abortion Followup'),
(4937, 'Postal'),
(4938, 'Postal Code'),
(4939, 'Postal code'),
(4940, 'Postal Code and Box Number'),
(4941, 'PostCalendar'),
(4942, 'PostCalendar Administration'),
(4943, 'PostCalendar Category Settings'),
(4944, 'PostCalendar Global Settings'),
(4945, 'Posted on'),
(4946, 'Posting Date'),
(4947, 'Pos{{Abbreviation for Position}}'),
(4948, 'Powered by'),
(4949, 'PPE + Prev Med/Surg Hx'),
(4950, 'PQRI'),
(4951, 'PQRI Registry ID'),
(4952, 'PQRI Registry Name'),
(4953, 'Practice'),
(4954, 'Practice Default Setting'),
(4955, 'Practice Settings'),
(4956, 'Practitioner'),
(4957, 'Pre Participation Assessment'),
(4958, 'Pre Pay'),
(4959, 'Pre Payment'),
(4960, 'Pre-Abortion Consultation'),
(4961, 'Pre-Abortion Counseling'),
(4962, 'Pref Cat'),
(4963, 'Preference'),
(4964, 'Preferences'),
(4965, 'Preferred Event Category'),
(4966, 'Preferred Language'),
(4967, 'Preferred Pharmacy'),
(4968, 'Preferred Provider Organization (PPO)'),
(4969, 'Preg Test'),
(4970, 'Preliminary'),
(4971, 'Preparing To Run Report'),
(4972, 'Prepay'),
(4973, 'Prescription'),
(4974, 'prescription has reached its limit of'),
(4975, 'Prescription History'),
(4976, 'Prescription History import successfully completed'),
(4977, 'Prescription Label'),
(4978, 'Prescription Report'),
(4979, 'Prescriptions'),
(4980, 'Prescriptions and Dispensations'),
(4981, 'Prescriptions and other referrals'),
(4982, 'Prescriptions and/or referrals by specialist'),
(4983, 'Prescriptions Report'),
(4984, 'Prescriptions/Referrals'),
(4985, 'Present'),
(4986, 'Presenting Complaint'),
(4987, 'Presenting Issue(s)'),
(4988, 'Press Continue to proceed'),
(4989, 'Presumed Diagnosis'),
(4990, 'Presumed diagnosis by specialist'),
(4991, 'Prev'),
(4992, 'Prev Med/Surg Hx'),
(4993, 'Prev. month (hold for menu)'),
(4994, 'Prev. year (hold for menu)'),
(4995, 'Preventative Care'),
(4996, 'Prevention Rehab'),
(4997, 'Preventive Care and Screening: Tobacco Use: Screening and Cessation Intervention (CQM)'),
(4998, 'Preview Event'),
(4999, 'Preview not available for this document type'),
(5000, 'Preview of'),
(5001, 'Previous'),
(5002, 'Previous Consultations'),
(5003, 'Previous Day'),
(5004, 'Previous History/Screening'),
(5005, 'Previous Month'),
(5006, 'Previous Week'),
(5007, 'Price'),
(5008, 'Price Discounting'),
(5009, 'Price Level'),
(5010, 'Price Level:'),
(5011, 'Prices'),
(5012, 'Primary'),
(5013, 'Primary Business Entity'),
(5014, 'Primary Business Entity tax id is used as account id for NewCrop ePrescription. Changing the facility will affect the working in NewCrop.'),
(5015, 'Primary Care'),
(5016, 'Primary Care Provider'),
(5017, 'Primary Facility City'),
(5018, 'Primary Facility Country code'),
(5019, 'Primary Facility State'),
(5020, 'Primary Facility Street Address'),
(5021, 'Primary Facility Zip Code'),
(5022, 'Primary Ins'),
(5023, 'Primary Insurance'),
(5024, 'Primary Insurance Data'),
(5025, 'Primary Insurance Provider'),
(5026, 'Primary Provider'),
(5027, 'Print'),
(5028, 'Print (HTML)'),
(5029, 'Print (PDF)'),
(5030, 'Print Amendments'),
(5031, 'Print Any Encounter'),
(5032, 'Print Blank Referral Form'),
(5033, 'Print Command'),
(5034, 'Print Date'),
(5035, 'Print End of Day Report 1'),
(5036, 'Print End of Day Report 2'),
(5037, 'Print End of Day Report 3'),
(5038, 'Print Entire Listing'),
(5039, 'Print Format'),
(5040, 'Print Four Panel'),
(5041, 'Print Ledger'),
(5042, 'Print message'),
(5043, 'Print Multiple'),
(5044, 'Print Multiple To Fax'),
(5045, 'Print name, sign and date.'),
(5046, 'Print Notes'),
(5047, 'Print Page 1'),
(5048, 'Print Page 2'),
(5049, 'Print Patient Address Label'),
(5050, 'Print Patient Billing Note'),
(5051, 'Print Receipts by Provider'),
(5052, 'Print Record'),
(5053, 'Print Selected Statements'),
(5054, 'Print Shot Record'),
(5055, 'Print the Next Appointment on the Bottom of the Ledger'),
(5056, 'Print This Encounter'),
(5057, 'Print this note'),
(5058, 'Print This Note'),
(5059, 'Print To'),
(5060, 'Print To Fax'),
(5061, 'Print View'),
(5062, 'printable'),
(5063, 'Printable Version'),
(5064, 'Printed'),
(5065, 'Printing Log Option'),
(5066, 'Printing results:'),
(5067, 'Printing skipped; see test output in'),
(5068, 'Printing skipped; see test output in '),
(5069, 'Prior Auth'),
(5070, 'Prior Authorization Form'),
(5071, 'Prior Visit'),
(5072, 'Priority'),
(5073, 'Priority '),
(5074, 'Private'),
(5075, 'Problem'),
(5076, 'Problem DX'),
(5077, 'Problem List'),
(5078, 'Problems'),
(5079, 'Problems/Issues'),
(5080, 'Proc Bat'),
(5081, 'Proc Cat'),
(5082, 'Proc Load'),
(5083, 'Proc Pending Rev'),
(5084, 'Proc Prov'),
(5085, 'Proc Res'),
(5086, 'Procedure'),
(5087, 'Procedure Body Sites'),
(5088, 'Procedure Boolean Results'),
(5089, 'Procedure Code'),
(5090, 'Procedure Codes'),
(5091, 'Procedure Lateralities'),
(5092, 'Procedure Name'),
(5093, 'Procedure Order'),
(5094, 'Procedure order'),
(5095, 'Procedure Order for'),
(5096, 'Procedure order not found'),
(5097, 'Procedure Orders and Reports'),
(5098, 'Procedure Picker'),
(5099, 'Procedure provider'),
(5100, 'Procedure Provider'),
(5101, 'Procedure Providers'),
(5102, 'Procedure Report'),
(5103, 'Procedure Report Statuses'),
(5104, 'Procedure Result Abnormal'),
(5105, 'Procedure Result Statuses'),
(5106, 'Procedure Results'),
(5107, 'Procedure Routes'),
(5108, 'Procedure Specimen Types'),
(5109, 'Procedure Statistics Report'),
(5110, 'Procedure Type'),
(5111, 'Procedure Types'),
(5112, 'Procedure Units'),
(5113, 'Procedure/Service'),
(5114, 'Procedures'),
(5115, 'Process'),
(5116, 'Process and Send Reminders'),
(5117, 'Process ERA File'),
(5118, 'Process new files for CSV records'),
(5119, 'Process Reminders'),
(5120, 'Process takes some time'),
(5121, 'Processed'),
(5122, 'Processed By'),
(5123, 'Processed Date'),
(5124, 'processed successfully'),
(5125, 'Processing'),
(5126, 'Processing and Sending Patient Reminders'),
(5127, 'Processing Patient Reminders'),
(5128, 'Processing Time'),
(5129, 'Product'),
(5130, 'Product Contraceptive Method'),
(5131, 'Production'),
(5132, 'Products'),
(5133, 'Products but no prescription drugs and no templates'),
(5134, 'Prof.'),
(5135, 'Progress Notes'),
(5136, 'Prostate Cancer'),
(5137, 'Prostate Cancer Screening'),
(5138, 'Prostate Exam'),
(5139, 'Prostate Problems'),
(5140, 'Prostate w/o enlrgmt, nodules, tender'),
(5141, 'Protocol'),
(5142, 'Provide absolute path'),
(5143, 'Provide absolute path of file'),
(5144, 'Provide clinical summaries for patients for each office visit (New).'),
(5145, 'Provide clinical summaries for patients for each office visit.'),
(5146, 'Provide patients with an electronic copy of their health information (including diagnostic test results, problem list, medication lists, medication allergies), upon request.'),
(5147, 'Provide patients with timely electronic access to their health information (including lab results, problem list, medication lists, medication allergies) within four business days of the information being available to the EP.'),
(5148, 'Provide Records to Patient for Visit'),
(5149, 'Provide valid Email Address'),
(5150, 'Provided Clinical Summary?'),
(5151, 'Provided Education Resource(s)?'),
(5152, 'Provider'),
(5153, 'Provider Id'),
(5154, 'Provider ID'),
(5155, 'Provider ID at Specified Facility'),
(5156, 'Provider Matching Errors'),
(5157, 'Provider not available, please choose another.'),
(5158, 'Provider not available, use it anyway?'),
(5159, 'Provider Number'),
(5160, 'Provider Relationship'),
(5161, 'Provider Type'),
(5162, 'Provider:'),
(5163, 'Providers'),
(5164, 'Providers NPI'),
(5165, 'Providers See Entire Calendar'),
(5166, 'Prv'),
(5167, 'PSA'),
(5168, 'Psoriasis'),
(5169, 'Psych Diagnosis'),
(5170, 'Psych Medication'),
(5171, 'Psychiatric'),
(5172, 'Psychiatric Brief Letter'),
(5173, 'Psychiatric Diagnosis'),
(5174, 'Psychiatric Examination'),
(5175, 'Psychiatric History'),
(5176, 'Psychiatric Intake'),
(5177, 'Psychiatric Medication'),
(5178, 'Pt %'),
(5179, 'Pt Notes'),
(5180, 'Pt Notes/Auth'),
(5181, 'Pt overpaid'),
(5182, 'Pt Paid'),
(5183, 'Pt Rec Request'),
(5184, 'Pt refund'),
(5185, 'Pt released'),
(5186, 'Pt Report'),
(5187, 'PT Student, or leave blank'),
(5188, 'PT_CITY'),
(5189, 'PT_DOB'),
(5190, 'PT_EMAIL'),
(5191, 'PT_FNAME'),
(5192, 'PT_LNAME'),
(5193, 'PT_MNAME'),
(5194, 'PT_PHONE_CELL'),
(5195, 'PT_PHONE_HOME'),
(5196, 'PT_POSTAL'),
(5197, 'PT_SSN'),
(5198, 'PT_STATE'),
(5199, 'PT_STREET'),
(5200, 'Pubid'),
(5201, 'Public'),
(5202, 'Public health physician'),
(5203, 'Public Health Service (PHS) or Other Federal Agency'),
(5204, 'Puerto Rican'),
(5205, 'Pulmonary'),
(5206, 'Pulse'),
(5207, 'Punjabi'),
(5208, 'Purchase'),
(5209, 'Purchase/Return'),
(5210, 'Purchases'),
(5211, 'P{{Justify Header}}'),
(5212, 'Pāli'),
(5213, 'q.3h'),
(5214, 'q.4h'),
(5215, 'q.5h'),
(5216, 'q.6h'),
(5217, 'q.8h'),
(5218, 'q.d.'),
(5219, 'q.i.d.'),
(5220, 'QOH'),
(5221, 'QOH is less than monthly usage'),
(5222, 'Qty'),
(5223, 'QTY'),
(5224, 'Quality'),
(5225, 'Quality Measures (CQM)'),
(5226, 'Quantity'),
(5227, 'Quantity for NDC'),
(5228, 'Quantity On Hand'),
(5229, 'quantity seems unusable'),
(5230, 'Quechua'),
(5231, 'Question Mark'),
(5232, 'Queue for HCFA batch processing'),
(5233, 'Queue for HCFA batch processing and printing'),
(5234, 'Queue for UB-92 batch processing'),
(5235, 'Queue for UB-92 batch processing and printing'),
(5236, 'Queued'),
(5237, 'Queued Events Administration'),
(5238, 'Queued for'),
(5239, 'Queued for Transfer'),
(5240, 'Queued Submissions Administration'),
(5241, 'Quit'),
(5242, 'Quit Alcohol'),
(5243, 'R'),
(5244, 'RA for Patient, Encounter, or Trace'),
(5245, 'Race'),
(5246, 'Race and Ethnicity'),
(5247, 'Race/Ethnicity'),
(5248, 'Radio'),
(5249, 'Radio buttons'),
(5250, 'Random Drug Screen'),
(5251, 'Range'),
(5252, 'Rashes'),
(5253, 'Rate'),
(5254, 'Ratio'),
(5255, 'Raw Report'),
(5256, 'Re Identification'),
(5257, 'Re Identification Process is completed'),
(5258, 'Re Identification Process is ongoing'),
(5259, 'Re-identification files will be saved in'),
(5260, 'Re-Injury?'),
(5261, 'Re-Open'),
(5262, 'Re-opened'),
(5263, 'Reaction'),
(5264, 'Reactions'),
(5265, 'Read'),
(5266, 'Read Only'),
(5267, 'Read-only from History'),
(5268, 'Real Name'),
(5269, 'Really delete'),
(5270, 'Reason'),
(5271, 'Reason Deceased'),
(5272, 'Reason for Death'),
(5273, 'Reason for Referral'),
(5274, 'Reason for referral'),
(5275, 'Reason for Visit'),
(5276, 'Reason/Form'),
(5277, 'Receipt'),
(5278, 'Receipt for Payment'),
(5279, 'Receipt Generated'),
(5280, 'Receipts by Payment Method Report'),
(5281, 'Receipts Summary'),
(5282, 'Received'),
(5283, 'Received By'),
(5284, 'Received Faxes'),
(5285, 'Received, not reviewed'),
(5286, 'Received, unreviewed'),
(5287, 'Receiver'),
(5288, 'Receiver ID'),
(5289, 'Receiver ID (ISA08)'),
(5290, 'Receiver ID Qualifier (ISA07)'),
(5291, 'Receiver IDs'),
(5292, 'Recent three passwords are not allowed.'),
(5293, 'Recipient'),
(5294, 'Recipient List Is Empty'),
(5295, 'Recipient Name'),
(5296, 'Recipient of the Disclosure'),
(5297, 'Recipient required unless status is Done'),
(5298, 'Recommendation'),
(5299, 'Recommendation For Follow Up'),
(5300, 'Recommendations'),
(5301, 'Recommendations and treatment'),
(5302, 'Recommendations by specialist'),
(5303, 'Record'),
(5304, 'Record already exist'),
(5305, 'Record and chart changes in vital signs ( Height / Weight / BP with in scope ).'),
(5306, 'Record and chart changes in vital signs (BP out of scope).'),
(5307, 'Record and chart changes in vital signs (Height / Weight out of scope).'),
(5308, 'Record and chart changes in vital signs (New).'),
(5309, 'Record and chart changes in vital signs (SET 1).'),
(5310, 'Record and chart changes in vital signs.'),
(5311, 'Record demographics.'),
(5312, 'Record Disclosure'),
(5313, 'Record of Fitness'),
(5314, 'Record Payment'),
(5315, 'Record Request Date'),
(5316, 'Record smoking status for patients 13 years old or older.'),
(5317, 'Records'),
(5318, 'records found'),
(5319, 'records found.'),
(5320, 'Recreational drug use'),
(5321, 'Recreational Drugs'),
(5322, 'Rectal'),
(5323, 'Rectal Exam'),
(5324, 'rectally'),
(5325, 'Redirection'),
(5326, 'Redness'),
(5327, 'reduced:'),
(5328, 'Refer'),
(5329, 'Refer By'),
(5330, 'Refer Date'),
(5331, 'Refer To'),
(5332, 'Reference classification (risk level)'),
(5333, 'Reference range of results'),
(5334, 'Reference Reason'),
(5335, 'Referer'),
(5336, 'Referer name and signature'),
(5337, 'Referral'),
(5338, 'Referral By'),
(5339, 'Referral Card'),
(5340, 'Referral Date'),
(5341, 'Referral Form'),
(5342, 'REFERRAL FORM'),
(5343, 'Referral ID'),
(5344, 'Referral Reason'),
(5345, 'Referral Source'),
(5346, 'Referral Source for Encounters'),
(5347, 'Referral To'),
(5348, 'Referrals'),
(5349, 'Referrals Report'),
(5350, 'Referred by'),
(5351, 'Referred By'),
(5352, 'Referred to'),
(5353, 'Referrer'),
(5354, 'Referrer Address'),
(5355, 'Referrer Diagnosis'),
(5356, 'Referrer diagnosis'),
(5357, 'Referring physician and practice'),
(5358, 'Referring Provider'),
(5359, 'ReFill'),
(5360, 'Refills'),
(5361, 'refills'),
(5362, 'Reflexes normal'),
(5363, 'Refresh'),
(5364, 'Refresh Screen'),
(5365, 'Refreshing Reminders'),
(5366, 'Refund'),
(5367, 'Refused'),
(5368, 'Refused To State'),
(5369, 'reg_re'),
(5370, 'register'),
(5371, 'Register'),
(5372, 'Registered'),
(5373, 'registered'),
(5374, 'Registered Modules'),
(5375, 'Registration Date'),
(5376, 'Registration Form'),
(5377, 'Rehabilitation'),
(5378, 'Rehabilitation physician'),
(5379, 'Rejected'),
(5380, 'Relapse Potential'),
(5381, 'Relate To'),
(5382, 'Related'),
(5383, 'Related Issue'),
(5384, 'Related Patient Notes'),
(5385, 'Relation(s) / Children'),
(5386, 'Relations'),
(5387, 'Relationship'),
(5388, 'Relative ordering of this entity'),
(5389, 'Relatives'),
(5390, 'Relatives Blood Pressure'),
(5391, 'Relatives Cancer'),
(5392, 'Relatives Diabetes'),
(5393, 'Relatives Epilepsy'),
(5394, 'Relatives Heart'),
(5395, 'Relatives Mental Illness'),
(5396, 'Relatives Stroke'),
(5397, 'Relatives Suicide'),
(5398, 'Relatives Tuberculosis'),
(5399, 'Relay Health credentials are missing from this user account.'),
(5400, 'Relay Health ID'),
(5401, 'Release'),
(5402, 'Release Date'),
(5403, 'Religion'),
(5404, 'Religious Affiliation'),
(5405, 'Reload'),
(5406, 'Relogin'),
(5407, 'Remdr'),
(5408, 'Remember Selected Facility'),
(5409, 'Reminder'),
(5410, 'Reminder intervals'),
(5411, 'Reminder Not Sent Yet'),
(5412, 'Reminder Sent On'),
(5413, 'Reminders'),
(5414, 'REMIT TO'),
(5415, 'Remote Host'),
(5416, 'Remove'),
(5417, 'Remove all rules from plan'),
(5418, 'Remove Bottom Pane'),
(5419, 'Remove Group'),
(5420, 'Remove Group Form'),
(5421, 'Removes support for immunizations'),
(5422, 'Removes support for phpMyAdmin'),
(5423, 'Removes support for prescriptions'),
(5424, 'Removes the bottom pane by default on start up.'),
(5425, 'Removes the Chart Tracker feature'),
(5426, 'Renal Stones'),
(5427, 'Rename'),
(5428, 'Rename Group'),
(5429, 'Rendering'),
(5430, 'Rendering Provider'),
(5431, 'Rendering Provider Number'),
(5432, 'Reorder'),
(5433, 'Reorder At'),
(5434, 'Reorder point has been reached'),
(5435, 'Reorder point, 0 if not applicable'),
(5436, 'Rep'),
(5437, 'Repeat New Password'),
(5438, 'Repeating event'),
(5439, 'Repeating Info:'),
(5440, 'Repeats'),
(5441, 'REPLACE'),
(5442, 'Replace entire code set'),
(5443, 'replaced'),
(5444, 'Reply Date'),
(5445, 'Reply From'),
(5446, 'Report'),
(5447, 'Report - Clinical'),
(5448, 'Report - Patient List Creation'),
(5449, 'Report by'),
(5450, 'Report Date'),
(5451, 'Report End (Relinquished Care Date)'),
(5452, 'Report has been sent to the patient.'),
(5453, 'Report History/Results'),
(5454, 'Report Results'),
(5455, 'Report Results/History'),
(5456, 'Report Start (Assumed Care Date)'),
(5457, 'Report Status'),
(5458, 'Report Totals'),
(5459, 'Report/ Form'),
(5460, 'Reportable'),
(5461, 'Reported'),
(5462, 'Reported Date'),
(5463, 'Reports'),
(5464, 'Request & Response'),
(5465, 'Request Description'),
(5466, 'Request ID is missing!'),
(5467, 'Request ignored - claims processing is already running!'),
(5468, 'Request Only'),
(5469, 'Request Status'),
(5470, 'Request Type'),
(5471, 'Request type not implemented'),
(5472, 'Requested By'),
(5473, 'Requested Date'),
(5474, 'Requested Service'),
(5475, 'Require Strong Passwords'),
(5476, 'Require Unique Passwords'),
(5477, 'Required'),
(5478, 'Required Co Pay'),
(5479, 'Required Field Missing: Please choose the EDI-271 file to upload'),
(5480, 'Required field missing: Please enter the First name'),
(5481, 'Required field missing: Please enter the Last name'),
(5482, 'Required field missing: Please enter the User Name'),
(5483, 'Required fields'),
(5484, 'Requirements'),
(5485, 'RESERVED'),
(5486, 'Reserved'),
(5487, 'Reserved for use to define Scheduled Vacation Time'),
(5488, 'Reserved to define when a provider may not have available appointments after.'),
(5489, 'Reserved to define when an event did not occur as specified.'),
(5490, 'Reserved todefine when a provider may haveavailable appointments after.'),
(5491, 'Reset'),
(5492, 'Reset Offsite Portal Credentials'),
(5493, 'Reset Onsite Portal Credentials'),
(5494, 'Resident physician'),
(5495, 'Resn'),
(5496, 'Resolved'),
(5497, 'Respiration'),
(5498, 'Respirator effort unlabored'),
(5499, 'Respiratory'),
(5500, 'Response Only'),
(5501, 'Restrict non-authorized users to the Schedule Facilities set in User admin.'),
(5502, 'Restrict Users to Facilities'),
(5503, 'Restricted Training'),
(5504, 'Result'),
(5505, 'Result Name'),
(5506, 'Result Status'),
(5507, 'Result status or abnormality is missing'),
(5508, 'Result, use % as a wildcard'),
(5509, 'Results'),
(5510, 'Results and'),
(5511, 'Results Found For Search'),
(5512, 'Results Group'),
(5513, 'Results Only'),
(5514, 'Results Path'),
(5515, 'Results per page'),
(5516, 'Results/Details'),
(5517, 'Retinal Exam'),
(5518, 'Retracted Right:'),
(5519, 'Return'),
(5520, 'Return above part with your payment'),
(5521, 'Return to calendar'),
(5522, 'Return To Report Results'),
(5523, 'Return to this page and you will be able to complete the ICD10 installation process by clicking on the ICD10 section header'),
(5524, 'Return to this page and you will be able to complete the ICD9 installation process by clicking on the ICD9 section header'),
(5525, 'Return to this page and you will be able to complete the RxNorm installation process by clicking on the RXNORM section header'),
(5526, 'Return to this page and you will be able to complete the Snomed installation process by clicking on the SNOMED section header'),
(5527, 'Return Value'),
(5528, 'Return Visit'),
(5529, 'Returned to Play'),
(5530, 'Reuse of three previous passwords not allowed!'),
(5531, 'Review'),
(5532, 'Review & Approve'),
(5533, 'Review and Approve'),
(5534, 'Review of PMH:'),
(5535, 'Review Of Systems'),
(5536, 'Review of Systems Checks'),
(5537, 'Reviewed'),
(5538, 'Revision'),
(5539, 'Rheumatoid Arthritis'),
(5540, 'Rheumotoid Arthritis'),
(5541, 'Right'),
(5542, 'Right Ear'),
(5543, 'right ear'),
(5544, 'Right Margin (mm)'),
(5545, 'Right:'),
(5546, 'Ringing in Ears'),
(5547, 'Ringing In Ears'),
(5548, 'Risk Category Assessment'),
(5549, 'Risk Factors'),
(5550, 'Risk Level'),
(5551, 'RLL:'),
(5552, 'ROM'),
(5553, 'Romanian'),
(5554, 'Romansh'),
(5555, 'Room 1'),
(5556, 'Room 2'),
(5557, 'Room 3'),
(5558, 'Room Number'),
(5559, 'Roommate'),
(5560, 'Roster'),
(5561, 'Route'),
(5562, 'Route of administration, if applicable'),
(5563, 'Routed'),
(5564, 'Rows'),
(5565, 'RRR without MOR'),
(5566, 'Rub:'),
(5567, 'Rubs:'),
(5568, 'Rule'),
(5569, 'Rule Add'),
(5570, 'Rule Detail'),
(5571, 'Rule Developer'),
(5572, 'Rule Edit'),
(5573, 'Rule Funding Source'),
(5574, 'Rule Release'),
(5575, 'Rule Set'),
(5576, 'Rule Set and Plan Set selections are not consistent. Please fix and Submit again.'),
(5577, 'Rule Title'),
(5578, 'Rules'),
(5579, 'rules already in plan'),
(5580, 'Rules Configuration'),
(5581, 'Running Command: '),
(5582, 'Rupture'),
(5583, 'Russian'),
(5584, 'Rx'),
(5585, 'RX'),
(5586, 'Rx Bottom Margin (px)'),
(5587, 'Rx Enable DEA #'),
(5588, 'Rx Enable NPI'),
(5589, 'Rx Enable State Lic. #'),
(5590, 'Rx Left Margin (px)'),
(5591, 'Rx Paper Size'),
(5592, 'Rx Right Margin (px)'),
(5593, 'Rx Show DEA #'),
(5594, 'Rx Show NPI'),
(5595, 'Rx Show State Lic. #'),
(5596, 'Rx Top Margin (px)'),
(5597, 'RXCUI Medication'),
(5598, 'RxNorm'),
(5599, 'RxNorm Database'),
(5600, 'S'),
(5601, 'S.S.'),
(5602, 'S3:'),
(5603, 'S4:'),
(5604, 'SA  *  * To read the license please read the docs/license.txt or visit  * http://www.gnu.org/copyleft/gpl.html  *  */  //========================================================================= // '),
(5605, 'Sale'),
(5606, 'Sales'),
(5607, 'Sales by Item'),
(5608, 'Sales by Product Report'),
(5609, 'Saliva'),
(5610, 'Same Day'),
(5611, 'Samoan'),
(5612, 'Sample'),
(5613, 'Sanction Type'),
(5614, 'Sango'),
(5615, 'Sanskrit (Saṁskṛta)'),
(5616, 'Sardinian'),
(5617, 'Sat'),
(5618, 'Sat &amp; Sun'),
(5619, 'Saturday'),
(5620, 'Save'),
(5621, 'SAVE'),
(5622, 'Save and Close'),
(5623, 'Save and Delete Request'),
(5624, 'Save and Dispense'),
(5625, 'Save and Transmit'),
(5626, 'Save as New'),
(5627, 'Save as new note'),
(5628, 'Save Certificate Settings'),
(5629, 'Save Changes'),
(5630, 'Save Form'),
(5631, 'Save Immunization'),
(5632, 'Save New Field'),
(5633, 'Save New Group'),
(5634, 'Save New List'),
(5635, 'Save new template'),
(5636, 'Save omission selections'),
(5637, 'Save Patient Demographics'),
(5638, 'Save Successful for chart ID'),
(5639, 'Save Transaction'),
(5640, 'Saved Successfully'),
(5641, 'Scanned'),
(5642, 'Scanned Encounter Note'),
(5643, 'Scanner Directory'),
(5644, 'Scanner In'),
(5645, 'Schedule'),
(5646, 'Schedule Facilities:'),
(5647, 'SCHOOL NOTE'),
(5648, 'Scoliosis'),
(5649, 'Scottish Gaelic- Gaelic'),
(5650, 'Screening / Testing'),
(5651, 'SE'),
(5652, 'SE Address'),
(5653, 'SE City'),
(5654, 'SE Country'),
(5655, 'SE Locality'),
(5656, 'SE Postal Code'),
(5657, 'SE State'),
(5658, 'SE Zip Code'),
(5659, 'Search'),
(5660, 'SEARCH'),
(5661, 'search'),
(5662, 'search again'),
(5663, 'Search all columns'),
(5664, 'Search by:'),
(5665, 'Search for'),
(5666, 'Search for:'),
(5667, 'Search In'),
(5668, 'Search in'),
(5669, 'Search or Add Patient'),
(5670, 'Search Payment'),
(5671, 'Search Results'),
(5672, 'Search Results:'),
(5673, 'Search Selected'),
(5674, 'Search string does not match with list in database'),
(5675, 'Search string should have at least three characters'),
(5676, 'Search Text'),
(5677, 'Search the Events'),
(5678, 'Search/Add'),
(5679, 'Search/Add Insurer'),
(5680, 'Searching for appointments'),
(5681, 'Searching...'),
(5682, 'Seatbelt Use'),
(5683, 'Seatbelt use'),
(5684, 'Second'),
(5685, 'second'),
(5686, 'Second account message'),
(5687, 'Secondary'),
(5688, 'Secondary Insurance'),
(5689, 'Secondary Insurance Data'),
(5690, 'Secondary Insurance Provider'),
(5691, 'Secondary Medicare Type'),
(5692, 'seconds'),
(5693, 'Section ID'),
(5694, 'Section ID and Name Cannot be Empty'),
(5695, 'Section Name'),
(5696, 'Section saved successfully'),
(5697, 'Secure Electronic Messaging'),
(5698, 'Security'),
(5699, 'See All'),
(5700, 'See Authorizations'),
(5701, 'See Growth-Chart'),
(5702, 'See messages from the last set of generated claims'),
(5703, 'See the Clinical Reminders widget for more details'),
(5704, 'Seen since'),
(5705, 'Segment name'),
(5706, 'Segments Batch Claim'),
(5707, 'Seizures'),
(5708, 'Sel'),
(5709, 'Select'),
(5710, 'select'),
(5711, 'Select a Component'),
(5712, 'Select a Context'),
(5713, 'Select a percentage of the rows or or select dates'),
(5714, 'Select a Time Span'),
(5715, 'Select a User'),
(5716, 'Select All'),
(5717, 'Select Amendment Date'),
(5718, 'Select amendments to print'),
(5720, 'Select category'),
(5721, 'Select Communication Preferences'),
(5722, 'Select corresponding checkboxes to delete'),
(5723, 'Select Criteria to Remove'),
(5724, 'Select CSV table'),
(5725, 'Select Data Required for De Identification'),
(5726, 'Select data to be included in De Identified data'),
(5727, 'Select date'),
(5728, 'Select desired squad'),
(5729, 'Select Diagnosis'),
(5730, 'Select Diagnosis for De Identification request'),
(5731, 'Select Drug'),
(5732, 'Select Drugs'),
(5733, 'Select Drugs for De Identification request'),
(5734, 'Select EDI-271 file'),
(5735, 'Select Encounter'),
(5736, 'Select field'),
(5737, 'Select Fields'),
(5738, 'Select for printing'),
(5739, 'Select Immunizations'),
(5740, 'Select Immunizations for De Identification request'),
(5741, 'Select Insurance, by typing'),
(5742, 'Select Issue'),
(5743, 'Select items'),
(5744, 'Select Language'),
(5745, 'Select One'),
(5746, 'Select one or more diagnosis codes to justify the service'),
(5747, 'Select one or more files to upload'),
(5748, 'Select output'),
(5749, 'SELECT PLAN'),
(5750, 'Select Requested By'),
(5751, 'Select Role'),
(5752, 'Select source'),
(5753, 'Select Template'),
(5754, 'Select the configuration items to export'),
(5755, 'Select the issue primarily responsible for any missed events on this day'),
(5756, 'Select to print patient address labels from popups in left nav screen.'),
(5757, 'Select Track'),
(5758, 'Select Type'),
(5759, 'Select User'),
(5760, 'Select Users From The Dropdown List'),
(5761, 'Select which languages, if any, may be chosen at login. (only pertinent if above All Languages Allowed is turned off)'),
(5762, 'Select Yes to confirm group deletion'),
(5763, 'Select1'),
(5764, 'Select2'),
(5765, 'Selected'),
(5766, 'Selected Encounter'),
(5767, 'Selecting this will create a message that needs to be processed by each recipient individually (this is not a group task).'),
(5768, 'Self'),
(5769, 'Self Pay'),
(5770, 'SEND'),
(5771, 'Send'),
(5772, 'Send A Dated Reminder'),
(5773, 'Send a Reminder'),
(5774, 'Send in progress'),
(5775, 'Send message'),
(5776, 'Send Reminders Batch'),
(5777, 'Send reminders to patients per patient preference for preventive/follow up care.'),
(5778, 'Send Summaries with Referrals'),
(5779, 'Send this file'),
(5780, 'Send This Message'),
(5781, 'Send to'),
(5782, 'Send To'),
(5783, 'SEND TO'),
(5784, 'Send to all'),
(5785, 'Send To HIE failed'),
(5786, 'Send to portal'),
(5787, 'Send to Portal'),
(5788, 'Sender'),
(5789, 'Sender ID'),
(5790, 'Sender ID (ISA06)'),
(5791, 'Sender ID Qualifier (ISA05)'),
(5792, 'Sender IDs'),
(5793, 'Sending To'),
(5794, 'Sensitivities'),
(5795, 'Sensitivity:'),
(5796, 'Sensory exam normal'),
(5797, 'Sent'),
(5798, 'Sent - Confirmed'),
(5799, 'Sent By, Leave Blank For All'),
(5800, 'Sent by:'),
(5801, 'Sent Date'),
(5802, 'Sent Items'),
(5803, 'Sent Medical Records?'),
(5804, 'Sent successfully'),
(5805, 'Sent Summary of Care Electronically?'),
(5806, 'Sent Summary of Care?'),
(5807, 'sent to printer.'),
(5808, 'Sent To, Leave Blank For All'),
(5809, 'Sent to:'),
(5810, 'Sent, but delivery not yet confirmed.'),
(5811, 'Sent, not received'),
(5812, 'Sep'),
(5813, 'Separated'),
(5814, 'September'),
(5815, 'Seq'),
(5816, 'Sequence'),
(5817, 'Serbian'),
(5818, 'Serv Rep'),
(5819, 'Server may be offline'),
(5820, 'Server message:'),
(5821, 'Service'),
(5822, 'Service Category'),
(5823, 'Service Code'),
(5824, 'Service Code Finance Reporting'),
(5825, 'Service Codes'),
(5826, 'Service Date'),
(5827, 'Service Date:'),
(5828, 'Service Facility'),
(5829, 'Service Location'),
(5830, 'Service Name'),
(5831, 'Service provided by specialist'),
(5832, 'Service Reporting'),
(5833, 'Service Reporting Only'),
(5834, 'Services'),
(5835, 'Services by Category'),
(5836, 'Services provided'),
(5837, 'Services Provided'),
(5838, 'Services/Products'),
(5839, 'Session Type'),
(5840, 'Set'),
(5841, 'Set a facility cookie to remember the selected facility between logins.'),
(5842, 'Set As Completed'),
(5843, 'Set processing priority for CDR engine based reports.'),
(5844, 'Set processing priority for creation of Patient Reminders (in full clinic mode).'),
(5845, 'Set this to the full absolute path. For creating client SSL certificates for HTTPS.'),
(5846, 'Set To'),
(5847, 'Set to Default'),
(5848, 'Setting the version number in the database...'),
(5849, 'Settings'),
(5850, 'Severe'),
(5851, 'Severe Migraine'),
(5852, 'Severity'),
(5853, 'Severity of Pain'),
(5854, 'Severity of Pain:'),
(5855, 'Sex'),
(5856, 'Sexually Transmitted Disease'),
(5857, 'SFTP'),
(5858, 'Sha-1 Hash'),
(5859, 'Sharing'),
(5860, 'Shell command for printing from the server.'),
(5861, 'Shift'),
(5862, 'Shona'),
(5863, 'Short Description'),
(5864, 'Shortness of Breath'),
(5865, 'Shortness Of Breath'),
(5866, 'Shortness Of Breath 2'),
(5867, 'Shot Record'),
(5868, 'Shot Record as of:'),
(5869, 'Should be Enabled'),
(5870, 'should be like nnnnn-nnnn-nn'),
(5871, 'Should be two letters'),
(5872, 'should contain 10 digits'),
(5873, 'should contain only 10 digits'),
(5874, 'Shoulder'),
(5875, 'Shoulder + clavicle'),
(5876, 'Shoulder Problems'),
(5877, 'Show'),
(5878, 'Show Active'),
(5879, 'Show Additional Insurance Information'),
(5880, 'Show All'),
(5881, 'Show all procedures'),
(5882, 'Show All Results'),
(5883, 'Show All Transactions'),
(5884, 'Show as Busy'),
(5885, 'Show Authorized Only'),
(5886, 'Show Available Times'),
(5887, 'Show both US and metric (main unit is metric)'),
(5888, 'Show both US and metric (main unit is US)'),
(5889, 'Show Details'),
(5890, 'Show Errors Only?'),
(5891, 'Show Graph'),
(5892, 'Show hovering event text on mouseover?'),
(5893, 'Show how many events on admin pages?'),
(5894, 'Show Inactive'),
(5895, 'Show Insurance Address Information in the Insurance Panel of Demographics.'),
(5896, 'Show Menu'),
(5897, 'Show metric only'),
(5898, 'Show Notes'),
(5899, 'Show only latest values reported for each result code'),
(5900, 'Show only procedures not omitted'),
(5901, 'Show Patient Notes'),
(5902, 'Show pounds and ounces'),
(5903, 'Show pounds as decimal value'),
(5904, 'Show Primary Complete'),
(5905, 'Show Reminders'),
(5906, 'Show Report'),
(5907, 'Show search/submit links in block?'),
(5908, 'Show Selected for Drug Screens'),
(5909, 'Show Status of Drug Screens'),
(5910, 'Show the custom state form for the add list widget (will ask for title and abbreviation).'),
(5911, 'Show this category on the patient summary screen even if no issues have been entered for this category.'),
(5912, 'Show track history'),
(5913, 'Show Unbilled Only'),
(5914, 'Show US only'),
(5915, 'Showing'),
(5916, 'Showing result'),
(5917, 'Sibling'),
(5918, 'Sibling History'),
(5919, 'Sibling in-law'),
(5920, 'Siblings'),
(5921, 'Sickle Cell'),
(5922, 'Sig'),
(5923, 'Sigmoid/Colonoscopy'),
(5924, 'Sign'),
(5925, 'Sign Lab Results (write,addonly optional)'),
(5926, 'Sign Results'),
(5927, 'Signature'),
(5928, 'Signature on File'),
(5929, 'Signature:'),
(5930, 'Signed Rx'),
(5931, 'Significant Other'),
(5932, 'Significant Swelling:'),
(5933, 'Simplified'),
(5934, 'Simplified Co-Pay'),
(5935, 'Simplified Demographics'),
(5936, 'Simplified Prescriptions'),
(5937, 'Since'),
(5938, 'Sincerely,'),
(5939, 'Sindhi'),
(5940, 'Single'),
(5941, 'Single-selection list'),
(5942, 'Single-selection list with ability to add to the list'),
(5943, 'Singular'),
(5944, 'Sinhala'),
(5945, 'Sinhala, Sinhalese'),
(5946, 'Sinus Problems'),
(5947, 'Sinus Surgery'),
(5948, 'SINUS TENDERNESS:'),
(5949, 'Sinusitis'),
(5950, 'Site'),
(5951, 'Site ID'),
(5952, 'Site ID for the Medical Information Integration, LLC Lab Exchange Service.'),
(5953, 'Site ID for the LibreEHR Support LLC Lab Exchange Service.'),
(5954, 'Site Worker'),
(5955, 'Six Months Ago'),
(5956, 'Size'),
(5957, 'Size must be a number between 1 and 999'),
(5958, 'Size/List'),
(5959, 'Skin'),
(5960, 'Skin Cancer'),
(5961, 'Skin Disease'),
(5962, 'Skin Other'),
(5963, 'Skip Authorization of Patient Notes'),
(5964, 'Skipping section'),
(5965, 'Skipping SQL-Ledger dump - not implemented for Windows server'),
(5966, 'Sl.No'),
(5967, 'Sleep Patterns'),
(5968, 'Sleep patterns'),
(5969, 'Sleeping'),
(5970, 'Slovak'),
(5971, 'Slovene'),
(5972, 'Sm debt w/o'),
(5973, 'Smarty Cache has been cleared'),
(5974, 'Smoker, current status unknown'),
(5975, 'Smoking'),
(5976, 'Smoking Status'),
(5977, 'SMS Auth'),
(5978, 'SMS Gateway'),
(5979, 'SMS Gateway API key'),
(5980, 'SMS Gateway API Key'),
(5981, 'SMS Gateway Password'),
(5982, 'SMS Gateway Username'),
(5983, 'SMS Notification'),
(5984, 'SMS Notification Hours'),
(5985, 'SMS send before'),
(5986, 'SMS Sent'),
(5987, 'SMS Text, Usable Tag: ***NAME***, ***PROVIDER***, ***DATE***, ***STARTTIME***, ***ENDTIME***<br> i.e. Dear ***NAME***'),
(5988, 'SMS/Email Alert Settings'),
(5989, 'SMTP Password for Authentication'),
(5990, 'SMTP Security Protocol'),
(5991, 'SMTP security protocol to connect with. Required by some servers such as gmail.'),
(5992, 'SMTP Server Hostname'),
(5993, 'SMTP Server Port Number'),
(5994, 'SMTP User for Authentication'),
(5995, 'SNOMED'),
(5996, 'SNOMED (RF1) Clinical Term'),
(5997, 'SNOMED (RF1) Diagnosis'),
(5998, 'SNOMED (RF1) Procedure'),
(5999, 'SNOMED (RF2) Diagnosis'),
(6000, 'SNOMED Clinical Term'),
(6001, 'SNOMED Database'),
(6002, 'SNOMED Diagnosis'),
(6003, 'SNOMED Procedure'),
(6004, 'Snoring'),
(6005, 'SOAP'),
(6006, 'Social Difficulties'),
(6007, 'Social History'),
(6008, 'Social History Element'),
(6009, 'Social History:'),
(6010, 'Social Security Number'),
(6011, 'solution'),
(6012, 'Somali'),
(6013, 'Somatic Context'),
(6014, 'Some authorizations were not displayed. Click here to view all'),
(6015, 'Some codes were not displayed.'),
(6016, 'Some encounters were not displayed. Click here to view all.'),
(6017, 'Some error has occured during De Identification Process'),
(6018, 'Some notes were not displayed.'),
(6019, 'Some office notes were not displayed. Click here to view all.'),
(6020, 'some words'),
(6021, 'Someone else has just changed this visit. Please cancel this page and try again.'),
(6022, 'Something went wrong'),
(6023, 'Something went wrong. Please try again.'),
(6024, 'Soon Due Interval (Clinical Reminders)'),
(6025, 'Soon Due Interval (Patient Reminders)'),
(6026, 'Sore Throat'),
(6027, 'Sorry No Appointment is Fixed'),
(6028, 'Sorry, there was a problem uploading your file'),
(6029, 'Sort by'),
(6030, 'Sort By'),
(6031, 'Sort by Checksum'),
(6032, 'Sort by Comments'),
(6033, 'Sort by Crt User'),
(6034, 'Sort by date'),
(6035, 'Sort by date/time'),
(6036, 'Sort by Event'),
(6037, 'Sort by Group'),
(6038, 'Sort by New Checksum'),
(6039, 'Sort by Old Checksum'),
(6040, 'Sort by PatientID'),
(6041, 'Sort by Success'),
(6042, 'Sort by Tamper date/time'),
(6043, 'Sort by User'),
(6044, 'Sort by vaccine'),
(6045, 'Sort Down'),
(6046, 'Sort Result by'),
(6047, 'Sort Up'),
(6048, 'Source'),
(6049, 'Source File'),
(6050, 'Source File Path'),
(6051, 'Source is missing for code '),
(6052, 'Source Lot'),
(6053, 'Source of the document'),
(6054, 'Source Patient'),
(6055, 'Source patient has no DOB'),
(6056, 'Source patient not found'),
(6057, 'Source:'),
(6058, 'South Ndebele'),
(6059, 'Southern Sotho'),
(6060, 'Space'),
(6061, 'SPACE'),
(6062, 'Spanish'),
(6063, 'Spanish (Latin American)'),
(6064, 'Spanish (Spain)'),
(6065, 'Spanish- Castilian'),
(6066, 'Special characters are not allowed'),
(6067, 'Special treatment for the Vitals form'),
(6068, 'Specialist'),
(6069, 'Specialist name and signature'),
(6070, 'Specialized physician'),
(6071, 'Specialty'),
(6072, 'Specialty Systems'),
(6073, 'Specialty:'),
(6074, 'Specific'),
(6075, 'Specific Application'),
(6076, 'Specific Contraceptive Service'),
(6077, 'Specific Result'),
(6078, 'Specific Service'),
(6079, 'Specified'),
(6080, 'Specifies formatting for codes. # = digit, * = any character. Empty if not used.'),
(6081, 'Specifies formatting for codes. # = digit, @ = alpha, * = any character. Empty if not used.'),
(6082, 'Specifies formatting for invoice reference numbers.  # = digit, * = any character.  Empty if not used.'),
(6083, 'Specifies formatting for invoice reference numbers.  # = digit, @ = alpha, * = any character.  Empty if not used.'),
(6084, 'Specifies formatting for product NDC fields.  # = digit, * = any character.  Empty if not used.'),
(6085, 'Specifies formatting for product NDC fields.  # = digit, @ = alpha, * = any character.  Empty if not used.'),
(6086, 'Specifies formatting for the external patient ID.  # = digit, * = any character.  Empty if not used.'),
(6087, 'Specifies formatting for the external patient ID.  # = digit, @ = alpha, * = any character.  Empty if not used.'),
(6088, 'Specimen'),
(6089, 'Specimen number/identifier'),
(6090, 'Specimen Type'),
(6091, 'Specimen type'),
(6092, 'Speech Dictation'),
(6093, 'Spermicides'),
(6094, 'Splenectomy'),
(6095, 'Spouse'),
(6096, 'Spouses History'),
(6097, 'Sputum'),
(6098, 'Sputum:'),
(6099, 'SQ'),
(6100, 'sql'),
(6101, 'SQL-Ledger'),
(6102, 'Squad'),
(6103, 'Squad Membership'),
(6104, 'Squads'),
(6105, 'SRH'),
(6106, 'SRH - Family Planning'),
(6107, 'SRH Non Family Planning'),
(6108, 'SRH Referrals'),
(6109, 'SRH Visit Form'),
(6110, 'Srv Date'),
(6111, 'SS'),
(6112, 'SSL Certificate Administration'),
(6113, 'SSN'),
(6114, 'Stability'),
(6115, 'Staged Releases'),
(6116, 'Standard'),
(6117, 'Standard Code'),
(6118, 'Standard Measures'),
(6119, 'Standard Measures (Active Alerts)'),
(6120, 'Standard Measures (Passive Alerts)'),
(6121, 'Standard Measures (Patient Reminders)'),
(6122, 'Standard Name'),
(6123, 'Standard; Simplified: only title, start date, comments and an Active checkbox;no diagnosis, occurrence, end date, referred-by or sports fields. ; Football Injury'),
(6124, 'Start'),
(6125, 'Start (yyyy-mm-dd): '),
(6126, 'Start Another Report'),
(6127, 'Start Batch Processing'),
(6128, 'Start Date'),
(6129, 'Start Date at This Clinic'),
(6130, 'Start Date should not be greater than End Date'),
(6131, 'Start date:'),
(6132, 'Start Date:'),
(6133, 'Start Time'),
(6134, 'Starting Date'),
(6135, 'stat'),
(6136, 'State'),
(6137, 'State Data Type'),
(6138, 'State Lic. #'),
(6139, 'State License Number'),
(6140, 'State list'),
(6141, 'State List (write,addonly optional)'),
(6142, 'State List Widget Custom Fields'),
(6143, 'State Or Province'),
(6144, 'State/Locality'),
(6145, 'State/Parish'),
(6146, 'STATEMENT SUMMARY'),
(6147, 'statements and updating invoices.'),
(6148, 'Statements Sent:'),
(6149, 'statements; invoices will not be updated.'),
(6150, 'Static Text'),
(6151, 'Statistics'),
(6152, 'Stats'),
(6153, 'Status'),
(6154, 'Status Of Admission'),
(6155, 'Status of Claim'),
(6156, 'Status quo'),
(6157, 'Status Type'),
(6158, 'STD/AIDS Couns'),
(6159, 'Stength and Conditioning'),
(6160, 'Step Child'),
(6161, 'Step Parent'),
(6162, 'Step Sibling'),
(6163, 'Steps for uploading CCR XML'),
(6164, 'Steps to install the DSM IV database'),
(6165, 'Steps to install the ICD 10 database'),
(6166, 'Steps to install the ICD 9 database'),
(6167, 'Steps to install the RxNorm database'),
(6168, 'Steps to install the Snomed database'),
(6169, 'Stiff Joints'),
(6170, 'Stiffness'),
(6171, 'Stock Months'),
(6172, 'Stomach Pains'),
(6173, 'Stop'),
(6174, 'Stored Hash'),
(6175, 'Strain of muscle'),
(6176, 'Stream'),
(6177, 'Street'),
(6178, 'Street Address'),
(6179, 'Street and Number'),
(6180, 'Strength'),
(6181, 'Strength and Conditioning'),
(6182, 'Strep Throat'),
(6183, 'Stress fracture'),
(6184, 'Stress Test'),
(6185, 'Stroke'),
(6186, 'Strong password means at least 8 characters, and at least three of: a number, a lowercase letter, an uppercase letter, a special character.'),
(6187, 'Style'),
(6188, 'Style of form used for adding new patients'),
(6189, 'Sub-category'),
(6190, 'Sub-Total'),
(6191, 'Subcategory'),
(6192, 'subcategory'),
(6193, 'subcutaneously'),
(6194, 'Subject'),
(6195, 'Subjective'),
(6196, 'Sublingual'),
(6197, 'sublingual'),
(6198, 'Submit'),
(6199, 'submit'),
(6200, 'Submit All Content'),
(6201, 'Submit and Delete Request'),
(6202, 'Submit Event'),
(6203, 'submit form'),
(6204, 'Submit Selected Content'),
(6205, 'submitted'),
(6206, 'Submitted by'),
(6207, 'Submitter EDI Access Number (PER06)'),
(6208, 'Subscriber'),
(6209, 'Subscriber Address'),
(6210, 'Subscriber City'),
(6211, 'Subscriber Country'),
(6212, 'Subscriber Date of Birth'),
(6213, 'Subscriber Employer'),
(6214, 'Subscriber Employer (SE)'),
(6215, 'Subscriber Employer Address'),
(6216, 'Subscriber Employer City'),
(6217, 'Subscriber Employer Country'),
(6218, 'Subscriber Employer State'),
(6219, 'Subscriber Employer Street'),
(6220, 'Subscriber Employer Zip'),
(6221, 'Subscriber Employer Zip Code'),
(6222, 'Subscriber First Name'),
(6223, 'Subscriber Last Name'),
(6224, 'Subscriber Middle Name'),
(6225, 'Subscriber Phone'),
(6226, 'Subscriber Relationship'),
(6227, 'Subscriber relationship is not self but name is the same! Is this really OK?'),
(6228, 'Subscriber relationship is not self but SS number is the same!'),
(6229, 'Subscriber relationship is self but name is different! Is this really OK?'),
(6230, 'Subscriber relationship is self but SS number is different!'),
(6231, 'Subscriber Sex'),
(6232, 'Subscriber SS'),
(6233, 'Subscriber State'),
(6234, 'Subscriber Zip'),
(6235, 'Subscribter Phone'),
(6236, 'Substance'),
(6237, 'Substitution'),
(6238, 'substitution allowed'),
(6239, 'Subtype'),
(6240, 'Success'),
(6241, 'success'),
(6242, 'Success confirming receipt of lab result'),
(6243, 'Success getting lab results'),
(6244, 'Success retrieving results from Lab Exchange Network'),
(6245, 'Successful Transfers'),
(6246, 'Successfully added category'),
(6247, 'successfully added to category,'),
(6248, 'Successfully Deleted'),
(6249, 'Successfully Imported the details. Please approve the patient from the Pending Approval Screen'),
(6250, 'Successfully installed the database.'),
(6251, 'Successfully installed the following database'),
(6252, 'Successfully Modified'),
(6253, 'Successfully Saved.Would you like to Allocate?'),
(6254, 'Successfully Saved.Would you like to Distribute?'),
(6255, 'Successfully Sent'),
(6256, 'successfully stored.'),
(6257, 'Successfully upgraded the database.'),
(6258, 'Successfully upgraded the following database'),
(6259, 'successfully.'),
(6260, 'Suicide'),
(6261, 'Summary'),
(6262, 'Summary of'),
(6263, 'Summary of Care Sent'),
(6264, 'Summary of Care Sent Electronically'),
(6265, 'Sun'),
(6266, 'Sundanese'),
(6267, 'Sunday'),
(6268, 'Superbill'),
(6269, 'Superbill Codes'),
(6270, 'Superbill Codes Administration'),
(6271, 'Superbill Report'),
(6272, 'Superbill/Fee Sheet'),
(6273, 'Superbills'),
(6274, 'Superbills, sometimes referred to as Encounter Forms or Routing Slips, are an essential part of most medical practices.'),
(6275, 'Superuser'),
(6276, 'Supervising'),
(6277, 'Supervising Doctor'),
(6278, 'Supervising Doctor DEA'),
(6279, 'Supervising Doctor First name'),
(6280, 'Supervising Doctor Last name'),
(6281, 'Supervising Doctor NPI'),
(6282, 'Supervising Doctor UPIN'),
(6283, 'Supplier facility name'),
(6284, 'Support calendar events that apply to multiple providers'),
(6285, 'Support export/import of configuration data via the Backup page.'),
(6286, 'Support Multi-Provider Events'),
(6287, 'Support provider in line item in fee sheet'),
(6288, 'Supports TripleDES encryption/decryption only.'),
(6289, 'Surface Type'),
(6290, 'Surgeries'),
(6291, 'Surgery'),
(6292, 'Surgery Issue List'),
(6293, 'Suspended'),
(6294, 'suspension'),
(6295, 'Svc Date'),
(6296, 'Svc Date:'),
(6297, 'Swahili'),
(6298, 'Swati'),
(6299, 'Sweating:'),
(6300, 'Swedish'),
(6301, 'Swelling'),
(6302, 'Swelling Right'),
(6303, 'Swollen Joints'),
(6304, 'Swollen Lymph Nodes'),
(6305, 'Symbol used as the decimal point for currency. Not used if Decimal Places is 0.'),
(6306, 'Symbol used to separate thousands for currency.'),
(6307, 'Symptoms'),
(6308, 'Synchronize'),
(6309, 'Synchronize translations with custom language table.'),
(6310, 'Synchronized new custom constant:'),
(6311, 'Synchronized new custom language:'),
(6312, 'Synchronized new definition (Language, Constant, Definition):'),
(6313, 'Syncope'),
(6314, 'Syndromic Surveillance'),
(6315, 'Syndromic Surveillance - Non Reported Issues'),
(6316, 'Syndromic Surveillance Report'),
(6317, 'Synovitis, impingement, bursitis'),
(6318, 'System'),
(6319, 'Systolic'),
(6320, 'S{{Saturday}}'),
(6321, 'S{{Sunday}}'),
(6322, 'T'),
(6323, 't.i.d.'),
(6324, 'T.V.'),
(6325, 'Table'),
(6326, 'Table Code'),
(6327, 'Table creation failed'),
(6328, 'Table update failed'),
(6329, 'Tables'),
(6330, 'tablet'),
(6331, 'Tag to Encounter'),
(6332, 'Tagalog'),
(6333, 'Tahitian'),
(6334, 'Tajik'),
(6335, 'Take'),
(6336, 'Take Insurance, from Drop Down'),
(6337, 'Take Payment From, from Drop Down'),
(6338, 'Takeback'),
(6339, 'Takes long'),
(6340, 'Tall Navigation Area'),
(6341, 'Tamil'),
(6342, 'Tamper Date'),
(6343, 'Tampered Checksum'),
(6344, 'Target and source DOB do not match'),
(6345, 'Target and source pid may not be the same!'),
(6346, 'Target and source SSN do not match'),
(6347, 'Target Date'),
(6348, 'Target Patient'),
(6349, 'Target patient has no DOB'),
(6350, 'Target patient not found'),
(6351, 'Target/Action Groups'),
(6352, 'Tatar'),
(6353, 'Tax Id'),
(6354, 'Tax ID'),
(6355, 'Tax Rate'),
(6356, 'Taxes'),
(6357, 'Taxonomy'),
(6358, 'Td'),
(6359, 'Team Injury Overview'),
(6360, 'Team Roster'),
(6361, 'Team Roster View'),
(6362, 'Team/Squad'),
(6363, 'Tel'),
(6364, 'Telephone Country Code'),
(6365, 'Telugu'),
(6366, 'Temp'),
(6367, 'Temp Location'),
(6368, 'Temp Method'),
(6369, 'Temperature'),
(6370, 'Template'),
(6371, 'Template Name'),
(6372, 'Template names cannot start with numbers.'),
(6373, 'Template:'),
(6374, 'Templates'),
(6375, 'Temporal Artery'),
(6376, 'Tendon injury'),
(6377, 'Tendonitis / osis / bursitis'),
(6378, 'Tentative Invoice Ref No'),
(6379, 'Tertiary'),
(6380, 'Tertiary Insurance'),
(6381, 'Tertiary Insurance Data'),
(6382, 'Tertiary Insurance provider'),
(6383, 'Test Scheduling'),
(6384, 'Test System'),
(6385, 'Text');
INSERT INTO `lang_constants` VALUES
(6386, 'Text Diagnosis'),
(6387, 'Text field'),
(6388, 'Text for fifth account message.'),
(6389, 'Text for first account message.'),
(6390, 'Text for fourth account message.'),
(6391, 'Text for second account message.'),
(6392, 'Text for third account message.'),
(6393, 'Text-date'),
(6394, 'text-date'),
(6395, 'Textarea'),
(6396, 'textarea'),
(6397, 'Textbox'),
(6398, 'textbox'),
(6399, 'Textbox list'),
(6400, 'textbox list'),
(6401, 'Thai'),
(6402, 'Thank You'),
(6403, 'Thank you for choosing'),
(6404, 'The ''Clear'' button will remove all annotations.'),
(6405, 'The above statement failed'),
(6406, 'The Apache SSL server certificate and public key'),
(6407, 'The Certificate Authority certificate'),
(6408, 'The claim file: '),
(6409, 'The compatible staged US Extension SNOMED package has already been installed.'),
(6410, 'The corresponding private key'),
(6411, 'The data integrity test failed for this form'),
(6412, 'The default code type to search for in the Fee Sheet.'),
(6413, 'the Denial code is'),
(6414, 'the Denial Group code is'),
(6415, 'The destination form was closed'),
(6416, 'The destination form was closed; I cannot act on your selection.'),
(6417, 'The entity performing this procedure'),
(6418, 'The EP, eligible hospital or CAH who receives a patient from another setting of care or provider of care or believes an encounter is relevant should perform medication reconciliation.'),
(6419, 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral (Measure A).'),
(6420, 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral (Measure B).'),
(6421, 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral.'),
(6422, 'The event(s) have been approved.'),
(6423, 'The event(s) have been hidden.'),
(6424, 'The exported data appears in the text area below.  You can copy and paste this into an email or to any other desired destination.'),
(6425, 'The exported data appears in the text area below. You can copy and paste this into an email or to any other desired destination (or) download the below link.'),
(6426, 'The exported data appears in the text area below. You can copy and paste this into an email or to any other desired destination.'),
(6427, 'The exported data appears in the text area below. You can copy and paste this into an email or to any other desired destination.{{MARK FOR DELETION DURING NEXT TRANSLATION BUILD}}'),
(6428, 'The file could not be saved to CouchDB.'),
(6429, 'The file could not be succesfully renamed, this error is usually related to permissions problems on the storage system.'),
(6430, 'The file could not be succesfully stored, this error is usually related to permissions problems on the storage system'),
(6431, 'The first ("target") chart is the one that is considered the most complete and accurate. Demographics, history and insurance sections for this one will be retained.'),
(6432, 'The first step is to download the SNOMED CT release. Access to SNOMED CT is provided by IHTSDO and their member countries. For more information see'),
(6433, 'The first step is to open an account with the Unified Medical Language System web site'),
(6434, 'The following calendar event has been added:'),
(6435, 'The following calendar event has been modifed:'),
(6436, 'The following categories will be removed from your category List'),
(6437, 'The following database release is currently installed'),
(6438, 'The following documents were attached to this Direct message:'),
(6439, 'The following EDI file has been uploaded'),
(6440, 'The following Emergency Login User is activated:'),
(6441, 'The following errors occurred'),
(6442, 'The following field has an invalid value'),
(6443, 'The following fields are empty.'),
(6444, 'The following fields are required'),
(6445, 'The following fields have to be filled to send a request.'),
(6446, 'The following fields have to be filled to send request.'),
(6447, 'The following International Snomed Release languages are supported'),
(6448, 'The following problems have the same diagnosis codes. Encounter issues will not be updated. Please use the encounter interface instead.'),
(6449, 'The hostname of the ATNA audit repository machine.'),
(6450, 'The initial window is the invoice search page.  At the top you may enter a source (e.g. check number), pay date and check amount.  The reason for the source and pay date is so that you don''t have to enter them over and over again for each claim.  The amount that you enter will be decreased for each invoice that is given part of the payment, and hopefully will end at zero when you are done.'),
(6451, 'The installation directory needs to be created.'),
(6452, 'The installed International SNOMED version is not compatible with the staged US Extension SNOMED package.'),
(6453, 'The installed International SNOMED version is out of date and not compatible with the staged US Extension SNOMED file.'),
(6454, 'The installed version and the staged files are the same.'),
(6455, 'The installed version is a more recent version than the staged files.'),
(6456, 'The label that appears to the user on the form'),
(6457, 'The length should not exceed the following number of characters'),
(6458, 'The merge will not run unless SSN and DOB for the two charts are identical. DOBs cannot be empty.'),
(6459, 'The message could not be sent at this time.'),
(6460, 'The new category will be a sub-category of '),
(6461, 'The new password can not be the same as the current password.'),
(6462, 'The new password fields are not the same.'),
(6463, 'The number of staged files is incorrect. Only place the file that you wish to install/upgrade to.'),
(6464, 'The number of staged files is incorrect. Only place the files that you wish to install/upgrade to.'),
(6465, 'The page will be redirected to Demographics. You can edit the country field and clickthrough to NewCrop again.'),
(6466, 'The password must be at least eight characters, and should'),
(6467, 'The password you entered is invalid'),
(6468, 'The patient record request has been recorded.'),
(6469, 'The patient reminders have been sent'),
(6470, 'The patient reminders have been updated'),
(6471, 'The patient was not logged in when submitting this form'),
(6472, 'The payments posted cannot go below this date.This ensures that after taking the final report nobody post for previous dates.'),
(6473, 'The portal has data for this patient and form. Load it now?'),
(6474, 'The raw data feed release can be obtained from'),
(6475, 'The remaining information below applies only if you are posting manually, or if you are doing manual corrections.'),
(6476, 'The requested document is not present at the expected location on the filesystem or there are not sufficient permissions to access it'),
(6477, 'The requested document is not present at the expected location on the filesystem or there are not sufficient permissions to access it.'),
(6478, 'The screen refresh time in Seconds for the Patient Flow Board Screen.'),
(6479, 'The second ("source") chart will have its demographics, history and insurance sections discarded.  Its other data will be merged into the target chart.'),
(6480, 'The Source and Date columns are copied from the first page, so normally you will not need to touch those.  You can put a payment amount in the Pay column, an adjustment amount in the Adjust column, or both.  You can also click the "W" on the right to automatically compute an adjustment value that writes off the remainder of the charge for that line item.'),
(6481, 'The staged files release dates are not all from the same release.'),
(6482, 'The staged files revisions are not all from the same release.'),
(6483, 'The staged US Extension SNOMED package can not be installed until after the International SNOMED package has been installed.'),
(6484, 'The time granularity of the calendar and the smallest interval in minutes for an appointment slot.'),
(6485, 'The translated label that will appear on the form in current language'),
(6486, 'The translated Title that will appear in current language'),
(6487, 'The translation of description in current language'),
(6488, 'The translation tables are synchronized.'),
(6489, 'The type of this entity'),
(6490, 'The vendor-specific code identifying this procedure or result'),
(6491, 'The X12 files as well as the resulting HTML output reports are archived in the "era" subdirectory of the main LibreEHR installation directory.  You will want to refer to these archives from time to time.  The URL is '),
(6492, 'The zip file will contain the following items'),
(6493, 'Theme'),
(6494, 'Then the raw data feed release can be obtained from'),
(6495, 'Therapeutic Injections'),
(6496, 'There are'),
(6497, 'There are currently no prescriptions'),
(6498, 'There are errors with your submission.  These are outlined below.'),
(6499, 'There are multiple patients with portal login'),
(6500, 'There are no charts checked out.'),
(6501, 'There are no disclosures recorded for this patient.'),
(6502, 'There are no New Submissions'),
(6503, 'There are no notes on file for this patient.'),
(6504, 'There are no transactions on file for this patient.'),
(6505, 'There has been a mail error sending to'),
(6506, 'There is already a category named'),
(6507, 'There is already a subcategory named'),
(6508, 'There is already an item named'),
(6509, 'There is already an open patient record request.'),
(6510, 'There is no COA entry for AR account '),
(6511, 'There is no COA entry for cash account '),
(6512, 'There is no COA entry for income account '),
(6513, 'There is no current patient'),
(6514, 'There is no local content for this topic.'),
(6515, 'There is no match for invoice id'),
(6516, 'There is no match for invoice id = '),
(6517, 'There is no parts entry for services ID '),
(6518, 'There is no patient with portal login'),
(6519, 'There was a problem sending the message.'),
(6520, 'There was an error while processing your request.'),
(6521, 'There was an LibreEHR SQL Escaping ERROR of the following string'),
(6522, 'These are the 2012 links'),
(6523, 'Thickened Right:'),
(6524, 'Thigh'),
(6525, 'Thigh + hamstring'),
(6526, 'Things that back office can only read'),
(6527, 'Things that back office can read and enter but not modify'),
(6528, 'Things that back office can read and modify'),
(6529, 'Things that back office can read and partly modify'),
(6530, 'Things that clinicians can only read'),
(6531, 'Things that clinicians can read and enter but not modify'),
(6532, 'Things that clinicians can read and modify'),
(6533, 'Things that clinicians can read and partly modify'),
(6534, 'Things that front office can only read'),
(6535, 'Things that front office can read and enter but not modify'),
(6536, 'Things that front office can read and modify'),
(6537, 'Things that front office can read and partly modify'),
(6538, 'Things that physicians can only read'),
(6539, 'Things that physicians can read and enter but not modify'),
(6540, 'Things that physicians can read and modify'),
(6541, 'Things that physicians can read and partly modify'),
(6542, 'Third'),
(6543, 'Third account message'),
(6544, 'This action CANNOT be undone.'),
(6545, 'This action cannot be undone.'),
(6546, 'This action cannot be undone. Are you sure you wish to delete this form?'),
(6547, 'This action will be logged'),
(6548, 'This appointment slot is already used, please choose another.'),
(6549, 'This appointment slot is already used, use it anyway?'),
(6550, 'This appointment slot is not available, please choose another.'),
(6551, 'This Calendar Year'),
(6552, 'This claim has been canceled.'),
(6553, 'This claim has been closed.'),
(6554, 'This claim has been denied.Reason:-'),
(6555, 'This claim has been forwarded to next level.'),
(6556, 'This code type does not accept relations.'),
(6557, 'This context contains categories, which will be deleted. Do you still want to continue?'),
(6558, 'This determines how appointments display on the calendar.'),
(6559, 'This determines which color schema used for appointment'),
(6560, 'This Enables provider in line item in the fee sheet'),
(6561, 'This Encounter'),
(6562, 'This encounter has been billed. If you need to change it, it must be re-opened.'),
(6563, 'This encounter is locked. No new forms can be added.'),
(6564, 'This feature is not yet available'),
(6565, 'This feature is very experimental and not fully tested. Use at your own risk!'),
(6566, 'This invoice number has been changed to '),
(6567, 'This is a child of result'),
(6568, 'This is the Beginning date for the Ledger Report.'),
(6569, 'This is the chart that is to be merged into the main chart and then deleted.'),
(6570, 'This is the latest of multiple result values.'),
(6571, 'This is the main chart that is to receive the merged data.'),
(6572, 'this location'),
(6573, 'This message text is not saved automatically. Copy and save it as appropriate for the content.'),
(6574, 'This module is being used by '),
(6575, 'This module is in test mode. The database will not be changed.'),
(6576, 'This module promotes efficient entry of EOB data.'),
(6577, 'This Month to Date'),
(6578, 'This order was already transmitted on'),
(6579, 'This page allows you to review each of the supported external dataloads that you can install and upgrade. Each section below can be expanded by clicking on the section header to review the status of the particular database of interest.'),
(6580, 'This page deactivated for security reasons.'),
(6581, 'This page will inline include the login page, so that we do not have to click relogin every time.'),
(6582, 'This patient has no activity.'),
(6583, 'This patient ID is already in use!'),
(6584, 'This product allows only one lot per warehouse.'),
(6585, 'This protocol is not implemented'),
(6586, 'This report currently only works for ICD9 codes.'),
(6587, 'This sets the Default Calendar View, Default is Day.'),
(6588, 'This specifies the Printing of the Custom End of Day Report grouped Provider or allow the Printing of Totals Only'),
(6589, 'This specifies whether to include date in Box 31.'),
(6590, 'This specifies which revision of the form the billing module should generate'),
(6591, 'This step will generate a file which you have to save for future use. The file cannot be generated again. Do you want to proceed?'),
(6592, 'This user is not a member of any group'),
(6593, 'This user will receive notification of new incoming Direct messages'),
(6594, 'This utility is experimental.  Back up your database and documents before using it!'),
(6595, 'This visit begins new contraceptive use'),
(6596, 'This visit will need a GCAC form, referral or procedure service.'),
(6597, 'This was the older metric-only Vitals form, now deprecated.'),
(6598, 'This Week to Date'),
(6599, 'This will abandon your unsaved changes. Are you sure?'),
(6600, 'This will activate the CCR(Continuity of Care Record) and CCD(Continuity of Care Document) reporting.'),
(6601, 'This will allow printing of the Patient Billing Note on the statements.'),
(6602, 'This will allow selection of the debugging (''dummy'') language.'),
(6603, 'This will allow the use of the custom End of Day report and indicate which report to use.'),
(6604, 'This will allow use of the custom Dunning Messages on the statements.'),
(6605, 'This will be a "dry run" with no physical data updates.'),
(6606, 'This will create a backup in tar format and then send it to your web browser so you can save it'),
(6607, 'This will deactivate document the encryption and decryption features, and hide them in the UI.'),
(6608, 'This will disable the Edit button on all forms whose parent encounter is e-signed'),
(6609, 'This will disable the Edit button on any form that is e-signed'),
(6610, 'This will Display the Invoice Number in the Sales Report or the Patient Name and ID or Patient Name and Invoice Number.'),
(6611, 'This will enable signing an entire encounter, rather than individual forms'),
(6612, 'This will enable signing individual forms separately'),
(6613, 'This will force the Billing Widget in the Patient Summary screen to always be open.'),
(6614, 'This will give the user the option to lock (separate locking and signing)'),
(6615, 'This will hide empty e-sign logs on the patient report'),
(6616, 'This will merge two patient charts into one.  It is useful when a patient has been duplicated by mistake.  If that happens often, fix your office procedures - do not run this routinely!'),
(6617, 'This will not prevent you from going to the e-Prescriptions site.'),
(6618, 'This Will Print the Next Appointment on the Bottom of the Patient Ledger'),
(6619, 'This will use the custom immunizations list rather than the standard CVX immunization list.'),
(6620, 'This will use the custom Statment showing the description instead of the codes.'),
(6621, 'Thoracic physician'),
(6622, 'Thoracic spine'),
(6623, 'Thous/CU.MM'),
(6624, 'Three Months Ago'),
(6625, 'Throat'),
(6626, 'Throat Cancer'),
(6627, 'Throat Cancer Surgery'),
(6628, 'Thrombosis/Stroke'),
(6629, 'Thu'),
(6630, 'Thurdsay'),
(6631, 'Thursday'),
(6632, 'Thyroid normal'),
(6633, 'Thyroid Problems'),
(6634, 'TIA'),
(6635, 'Tibetan Standard, Tibetan, Central'),
(6636, 'TID'),
(6637, 'Tigrinya'),
(6638, 'Time'),
(6639, 'Time Display Format'),
(6640, 'Time Increment for Add (minutes 1-60)'),
(6641, 'Time selection'),
(6642, 'Time slot is open, saving event'),
(6643, 'Time-To-Live for Allergies SOAP Request in seconds'),
(6644, 'Time-To-Live for Medications SOAP Request in seconds'),
(6645, 'Time-To-Live for NewCrop eRx Allergies SOAP Request in seconds.'),
(6646, 'Time-To-Live for NewCrop eRx Medications SOAP Request in seconds.'),
(6647, 'Timed event'),
(6648, 'Times array (N/A)'),
(6649, 'Timestamp and Text'),
(6650, 'TIN'),
(6651, 'Tinnitus'),
(6652, 'Title'),
(6653, 'Title V'),
(6654, 'TitleCols must be a number between 1 and 999'),
(6655, 'Titles'),
(6656, 'TM''S:'),
(6657, 'TMs/EAMs/EE, ext nose'),
(6658, 'To'),
(6659, 'TO'),
(6660, 'to'),
(6661, 'to absolute path of file'),
(6662, 'To add notes, please click '),
(6663, 'To add notes, please click here'),
(6664, 'To Affected Area'),
(6665, 'to affected area'),
(6666, 'To automatically open the specified form. Some sports teams use football_injury_audit here.'),
(6667, 'To Billing View'),
(6668, 'to category'),
(6669, 'To Clinical View'),
(6670, 'To copay'),
(6671, 'To date must be later than From date!'),
(6672, 'To ded''ble'),
(6673, 'To Dems'),
(6674, 'To Disable client side SSL certificates, comment above lines in Apache configuration file and set'),
(6675, 'To Disable HTTPS, comment the above lines in Apache configuration file and restart Apache server.'),
(6676, 'To enable Client side ssl certificates'),
(6677, 'To Enable Client side SSL certificates authentication, HTTPS should be enabled.'),
(6678, 'To Enable only HTTPS, perform the above changes and restart Apache server. If you want to configure client side certificates also, please configure them in the next section.'),
(6679, 'To Enctr'),
(6680, 'To filter by sex'),
(6681, 'To History'),
(6682, 'To Issues'),
(6683, 'To link this encounter/consult to an existing issue, click the '),
(6684, 'To link this encounter/consult to an existing issue, click the desired issue above to highlight it and then click [Save]. Hold down [Ctrl] button to select multiple issues.'),
(6685, 'to login again'),
(6686, 'To record disclosures, please click'),
(6687, 'to run'),
(6688, 'To setup https access with client certificate authentication, do the following'),
(6689, 'To Skin'),
(6690, 'to skin'),
(6691, 'to this visit?'),
(6692, 'To upload CCR document of already existing patient use Patient Summary Screen->Documents. For CCR document of a new patient use Miscellanous->New Documents screen'),
(6693, 'To:'),
(6694, 'To: '),
(6695, 'TO_CITY'),
(6696, 'TO_FAX'),
(6697, 'TO_FNAME'),
(6698, 'TO_LNAME'),
(6699, 'TO_MNAME'),
(6700, 'TO_ORGANIZATION'),
(6701, 'TO_PHONE'),
(6702, 'TO_PHONECELL'),
(6703, 'TO_POSTAL'),
(6704, 'TO_STATE'),
(6705, 'TO_STREET'),
(6706, 'TO_TITLE'),
(6707, 'TO_VALEDICTORY'),
(6708, 'Tobacco'),
(6709, 'Tobacco Cessation Intervention'),
(6710, 'Tobacco Cessation Intervention (CQM)'),
(6711, 'Tobacco Use'),
(6712, 'Tobacco use'),
(6713, 'Tobacco Use Assessment'),
(6714, 'Tobacco Use Assessment (CQM)'),
(6715, 'Today'),
(6716, 'TODAY'),
(6717, 'today'),
(6718, 'Today''s Balance'),
(6719, 'Today''s Charges'),
(6720, 'Today''s Date'),
(6721, 'Today''s Events'),
(6722, 'Toggle All'),
(6723, 'Token ID for the Medical Information Integration, LLC Lab Exchange Service.'),
(6724, 'Token ID for the LibreEHR Support LLC Lab Exchange Service.'),
(6725, 'Tonga (Tonga Islands)'),
(6726, 'Tonsillectomy'),
(6727, 'tonsillectomy'),
(6728, 'Top'),
(6729, 'Top Margin (mm)'),
(6730, 'Topic'),
(6731, 'Total'),
(6732, 'total'),
(6733, 'Total active actions'),
(6734, 'Total active reminders after update'),
(6735, 'Total active reminders before update'),
(6736, 'Total Adj'),
(6737, 'Total amount due'),
(6738, 'Total Amount Paid'),
(6739, 'Total Balance Due'),
(6740, 'Total Charge'),
(6741, 'Total Charges'),
(6742, 'Total Clients'),
(6743, 'Total Cost'),
(6744, 'Total Distribution for following check number is not full'),
(6745, 'total entries'),
(6746, 'Total failed reminders sent via email'),
(6747, 'Total failed reminders sent via phone'),
(6748, 'Total for'),
(6749, 'Total for '),
(6750, 'Total for category'),
(6751, 'Total inactivated reminders'),
(6752, 'Total new reminders'),
(6753, 'Total number of appointments'),
(6754, 'Total number of Drug Screen entries'),
(6755, 'Total Number of Immunizations'),
(6756, 'Total Number of Issues'),
(6757, 'Total number of Patient Flow Board entries'),
(6758, 'Total Number of Patients'),
(6759, 'Total Pages'),
(6760, 'Total Patient Balance'),
(6761, 'Total Patients'),
(6762, 'Total Payments'),
(6763, 'Total Records'),
(6764, 'Total Records Found'),
(6765, 'Total SRH & Family Planning'),
(6766, 'Total successful reminders sent via email'),
(6767, 'Total successful reminders sent via phone'),
(6768, 'Total Time'),
(6769, 'Total Transfers'),
(6770, 'Total unchanged reminders'),
(6771, 'Total unsent reminders after sending process'),
(6772, 'Total unsent reminders after update'),
(6773, 'Total unsent reminders before sending process'),
(6774, 'Total unsent reminders before update'),
(6775, 'Total updated reminders'),
(6776, 'Totals'),
(6777, 'Totals for'),
(6778, 'Totals for '),
(6779, 'Totals Only'),
(6780, 'to{{range}}'),
(6781, 'To{{range}}'),
(6782, 'Track'),
(6783, 'Track Report'),
(6784, 'Tracks'),
(6785, 'Training Type'),
(6786, 'Transact'),
(6787, 'Transaction'),
(6788, 'transaction'),
(6789, 'Transaction failed, insufficient quantity in destination lot'),
(6790, 'Transaction failed, quantity is less than zero'),
(6791, 'Transaction Type'),
(6792, 'transactions'),
(6793, 'Transactions'),
(6794, 'Transactions (write optional)'),
(6795, 'Transactions/Referrals'),
(6796, 'Transdermal'),
(6797, 'Transfer'),
(6798, 'Transfer date'),
(6799, 'Transfer failed, insufficient quantity in source lot'),
(6800, 'Transfer Summary'),
(6801, 'Transfer to'),
(6802, 'Transferred By'),
(6803, 'Transferred Date'),
(6804, 'Transfers'),
(6805, 'Transition Of Care'),
(6806, 'Transition/Transfer of Care?'),
(6807, 'Translate Access Control Groups'),
(6808, 'Translate Appointment Categories'),
(6809, 'Translate Document Categories'),
(6810, 'Translate Layouts'),
(6811, 'Translate Lists'),
(6812, 'Translate Patient Note Titles'),
(6813, 'translate this'),
(6814, 'Translation'),
(6815, 'Translations'),
(6816, 'Transmit'),
(6817, 'Transmit failed'),
(6818, 'Transmit Selected Orders'),
(6819, 'Trauma'),
(6820, 'Treatment'),
(6821, 'Treatment Completion Status'),
(6822, 'Treatment Goals'),
(6823, 'Treatment Plan'),
(6824, 'Treatment Planning'),
(6825, 'Treatment Received'),
(6826, 'Treatment:'),
(6827, 'Treatment: '),
(6828, 'Trend'),
(6829, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) );             $month_value'),
(6830, 'Trigger point / compartment syndrome / DOMS / cramp'),
(6831, 'Trimalleolar'),
(6832, 'Trunk and abdomen'),
(6833, 'Trusted Direct Email Address'),
(6834, 'Trusted Email'),
(6835, 'Trying to create user with existing username!'),
(6836, 'Tsonga'),
(6837, 'tsp'),
(6838, 'Tswana'),
(6839, 'TTS'),
(6840, 'Tuberculosis'),
(6841, 'Tue'),
(6842, 'Tues &amp; Thur'),
(6843, 'Tuesday'),
(6844, 'Tumour'),
(6845, 'Turkish'),
(6846, 'Turkmen'),
(6847, 'Twi'),
(6848, 'twice daily'),
(6849, 'Two Years Ago'),
(6850, 'Tympanic Membrane'),
(6851, 'Type'),
(6852, 'Type Id or Name.3 characters minimum (including spaces).'),
(6853, 'Type of columns displayed for patient search results'),
(6854, 'Type of Disclosure'),
(6855, 'Type of Events'),
(6856, 'Type of screen layout'),
(6857, 'Type or scan the patient identifier here'),
(6858, 'Type Your message here'),
(6859, 'Types of Orders and Results'),
(6860, 'T{{Thursday}}'),
(6861, 'T{{Tuesday}}'),
(6862, 'UAC Appl'),
(6863, 'UAC Tot'),
(6864, 'UCSMC codes provided by the University of Calgary Sports Medicine Centre'),
(6865, 'Ukrainian'),
(6866, 'Ulcerations'),
(6867, 'Ulcerative Colitis'),
(6868, 'Ulcers:'),
(6869, 'Unable to access directory'),
(6870, 'Unable to access URL'),
(6871, 'Unable to create'),
(6872, 'Unable to create patient document subdirectory'),
(6873, 'Unable to locate the data in this file.'),
(6874, 'Unable to match this payment in ar_activity'),
(6875, 'Unable to modify application config Please give write permission to'),
(6876, 'Unapplied'),
(6877, 'Unassigned'),
(6878, 'Unauthorized'),
(6879, 'Unauthorized access to ePrescription'),
(6880, 'Unauthorized access.'),
(6881, 'Unbilled'),
(6882, 'Unbilled Only'),
(6883, 'Uncle'),
(6884, 'under tongue'),
(6885, 'Underweight'),
(6886, 'Undiagnosed'),
(6887, 'UNDISTRIBUTED'),
(6888, 'Undistributed'),
(6889, 'Undistributed is'),
(6890, 'Undo Checkout'),
(6891, 'Unexpected non-match, creating new patient for segment'),
(6892, 'Unique Clients'),
(6893, 'Unique human-readable identifier for this type'),
(6894, 'Unique New Clients'),
(6895, 'Unique numeric identifier for this type'),
(6896, 'Unique Seen Patients'),
(6897, 'Unique Seen Patients Report'),
(6898, 'Unique SP'),
(6899, 'Unit'),
(6900, 'Units'),
(6901, 'units'),
(6902, 'Units applicable to the result value'),
(6903, 'Units for Visit Forms'),
(6904, 'Units must be a number'),
(6905, 'Units not defined'),
(6906, 'Units/L'),
(6907, 'Unknown'),
(6908, 'unknown (see log)'),
(6909, 'Unknown Error'),
(6910, 'Unknown if ever smoked'),
(6911, 'Unknown or N/A'),
(6912, 'Unknown user id:'),
(6913, 'unlink patient'),
(6914, 'Unnamed insurance company'),
(6915, 'Unregistered'),
(6916, 'Unregistered Modules'),
(6917, 'Unrelated Friend'),
(6918, 'Unselect All'),
(6919, 'Unselected'),
(6920, 'Unspecified'),
(6921, 'unstructured'),
(6922, 'UNSUPPORTED database load file'),
(6923, 'Unsupported MDM OBX result type'),
(6924, 'until'),
(6925, 'Untimely filing'),
(6926, 'Unused'),
(6927, 'UOR'),
(6928, 'Up to'),
(6929, 'Upcoming Appointments'),
(6930, 'Upcoming Events'),
(6931, 'Update'),
(6932, 'update'),
(6933, 'Update Active'),
(6934, 'Update files'),
(6935, 'Update Info'),
(6936, 'Update List'),
(6937, 'Update Provider Number'),
(6938, 'Update Selected Items'),
(6939, 'Update the following variables in file'),
(6940, 'Update User Information'),
(6941, 'Updated By'),
(6942, 'Updating demographics is not authorized.'),
(6943, 'Updating global configuration defaults'),
(6944, 'Updating version indicators'),
(6945, 'UPGRADE'),
(6946, 'Upgrade'),
(6947, 'Upgrade Database'),
(6948, 'Upgrades the LibreEHR database to include Procedures, Functions and tables needed for De-identification process'),
(6949, 'Upgrading will continue'),
(6950, 'UPIN'),
(6951, 'Upload'),
(6952, 'Upload a Template'),
(6953, 'Upload and Install'),
(6954, 'Upload configuration data'),
(6955, 'Upload Document'),
(6956, 'Upload failed!'),
(6957, 'Upload Image to'),
(6958, 'Upload import file:'),
(6959, 'Upload Patient Education PDF to'),
(6960, 'Upload processed successfully'),
(6961, 'Upload Report'),
(6962, 'Upload the xml file under the category CCR'),
(6963, 'Upload this file:'),
(6964, 'Upon clicking an invoice number the "manual posting window" appears. Here you can change the due date and notes for the invoice, select the party for whom you are posting, and select the insurances for which all expected paymants have been received.  Most importantly, for each billing code for which an amount was charged, you can enter payment and adjustment information.'),
(6965, 'Upon searching you are presented with a list of invoices.  You may click on one of the invoice numbers to open a second window, which is the data entry page for manual posting.  You may also click on a patient name if you want to enter a note that the front office staff will see when the patient checks in, and you may select invoices to appear on patient statements and print those statements.'),
(6966, 'Upper arm'),
(6967, 'Urdu'),
(6968, 'Urgency'),
(6969, 'Urgent Care'),
(6970, 'Urine'),
(6971, 'Urine Dribbling'),
(6972, 'Urine Frequency'),
(6973, 'Urine Hesitancy'),
(6974, 'Urine Microalbumin'),
(6975, 'Urine Stream'),
(6976, 'Urine Urgency'),
(6977, 'URL'),
(6978, 'URL for NewCrop eRx Site Address.'),
(6979, 'URL for LibreEHR support.'),
(6980, 'URL for Phone Gateway.'),
(6981, 'URL for Phone Gateway. Automated VOIP service provided by Maviq. Please visit http://signup.maviq.com for more information.'),
(6982, 'URL for the WordPress site that supports the portal'),
(6983, 'URLs for NewCrop eRx Service Address, separated by a semi-colon.'),
(6984, 'USA'),
(6985, 'Usage'),
(6986, 'Usage Indicator (ISA15)'),
(6987, 'Use % alone in a field to just sort on that column'),
(6988, 'Use 24 hour time format?'),
(6989, 'Use certified EHR technology to identify patient-specific education resources and provide those resources to the patient if appropriate(New).'),
(6990, 'Use certified EHR technology to identify patient-specific education resources and provide those resources to the patient if appropriate.'),
(6991, 'Use Charges Panel'),
(6992, 'Use CPOE for medication orders directly entered by any licensed healthcare professional who can enter orders into the medical record per state, local and professional guidelines.'),
(6993, 'Use CPOE for procedure orders.'),
(6994, 'Use CPOE for radiology orders.'),
(6995, 'Use Custom Dunning Messages'),
(6996, 'Use Custom End of Day Report'),
(6997, 'Use Custom Immunization List'),
(6998, 'Use Custom Statement'),
(6999, 'Use Date Range'),
(7000, 'Use Defaults'),
(7001, 'Use Delete Option to Remove.'),
(7002, 'Use international date style?'),
(7003, 'Use source filename'),
(7004, 'Use the fields below for a purchase or transfer.'),
(7005, 'Use this feature only with newly installed sites, '),
(7006, 'Use topics?'),
(7007, 'User'),
(7008, 'User '),
(7009, 'User / Groups'),
(7010, 'User Administration'),
(7011, 'User and Facility Administration'),
(7012, 'User and Group Administration'),
(7013, 'User Cannot be Deleted'),
(7014, 'User Certificate Authentication is disabled'),
(7015, 'User Defined'),
(7016, 'User Defined Area 11'),
(7017, 'User Defined Area 12'),
(7018, 'User Defined Field'),
(7019, 'User Defined List 1'),
(7020, 'User Defined List 2'),
(7021, 'User Defined List 3'),
(7022, 'User Defined List 4'),
(7023, 'User Defined List 5'),
(7024, 'User Defined List 6'),
(7025, 'User Defined List 7'),
(7026, 'User Defined Text 1'),
(7027, 'User Defined Text 2'),
(7028, 'User Defined Text 3'),
(7029, 'User Defined Text 4'),
(7030, 'User Defined Text 5'),
(7031, 'User Defined Text 6'),
(7032, 'User Defined Text 7'),
(7033, 'User Defined Text 8'),
(7034, 'User First name'),
(7035, 'User ID'),
(7036, 'User is required to have this access control for Active Alerts and Passive Alerts'),
(7037, 'User Logon (If 03 above, else leave spaces) (ISA02)'),
(7038, 'User logon Required Indicator (ISA01~ use 00 or 03)'),
(7039, 'User Manual'),
(7040, 'User Memberships'),
(7041, 'User Name'),
(7042, 'User name or Host name cannot be empty'),
(7043, 'User or Host name'),
(7044, 'User Password (ISA04~ if 01 above, else leave spaces)'),
(7045, 'User password required Indicator (ISA03~ use 00 or 01)'),
(7046, 'User Settings'),
(7047, 'User Specific Setting'),
(7048, 'User''s New Password'),
(7049, 'Username'),
(7050, 'Username for Phone Gateway.'),
(7051, 'Username for Phone Gateway. Automated VOIP service provided by Maviq. Please visit http://signup.maviq.com for more information.'),
(7052, 'Username for SMS Gateway'),
(7053, 'Username for SMS Gateway.'),
(7054, 'Username to connect to CouchDB'),
(7055, 'Username:'),
(7056, 'Users'),
(7057, 'Users/Groups/Logs Administration'),
(7058, 'uses php <a href="http://php.net/strftime">strftime</a> format'),
(7059, 'UTIs'),
(7060, 'Uyghur, Uighur'),
(7061, 'Uzbek'),
(7062, 'VACATION'),
(7063, 'Vacation'),
(7064, 'Vaccine'),
(7065, 'Vaginal Ring'),
(7066, 'Valedictory'),
(7067, 'validate'),
(7068, 'Value'),
(7069, 'Value 1'),
(7070, 'Value 2'),
(7071, 'Value if comparing'),
(7072, 'Value Should be Numeric'),
(7073, 'Var1'),
(7074, 'Var2'),
(7075, 'variable to one to run de-identification upgrade script'),
(7076, 'Varicella 1'),
(7077, 'Varicella 2'),
(7078, 'Varicose Veins'),
(7079, 'Vascular condition'),
(7080, 'Vascular injury'),
(7081, 'Vascular Surgery'),
(7082, 'Venda'),
(7083, 'Vendor'),
(7084, 'Version'),
(7085, 'Vertigo'),
(7086, 'Veteran`s Administration'),
(7087, 'Veterans Administration Plan'),
(7088, 'VFC'),
(7089, 'Vietnamese'),
(7090, 'view'),
(7091, 'View'),
(7092, 'View Allergies'),
(7093, 'View an x12-835 ERA file'),
(7094, 'View Batch Claim x12 text'),
(7095, 'View Blank Referral Form'),
(7096, 'View CCDA'),
(7097, 'View Comprehensive Patient Report'),
(7098, 'View CSV tables'),
(7099, 'View details'),
(7100, 'View document'),
(7101, 'View encounter'),
(7102, 'View ERA x12 text'),
(7103, 'View events in a popup window?'),
(7104, 'View Facility Specific User Information'),
(7105, 'View Four Panel'),
(7106, 'View local x12 file'),
(7107, 'View Log'),
(7108, 'View Page 1'),
(7109, 'View Page 2'),
(7110, 'View Past and Future Reminders'),
(7111, 'View Patient'),
(7112, 'View Plan Rules'),
(7113, 'View Printable'),
(7114, 'View Printable Report'),
(7115, 'View Printable Version'),
(7116, 'View related encounters'),
(7117, 'View Report'),
(7118, 'View the README file'),
(7119, 'View, Download, Transmit (VDT)  (Measure B)'),
(7120, 'View, Download, Transmit (VDT) (Measure A)'),
(7121, 'View/Edit Allergies'),
(7122, 'View/edit issue'),
(7123, 'View/Print'),
(7124, 'View:'),
(7125, 'VISA'),
(7126, 'VISA/MC/AMEX/Dis'),
(7127, 'Visceral damage/trauma/surgery'),
(7128, 'VisForm'),
(7129, 'Visit'),
(7130, 'Visit Attributes'),
(7131, 'Visit Categories'),
(7132, 'Visit Category'),
(7133, 'Visit Category:'),
(7134, 'Visit Date'),
(7135, 'Visit date'),
(7136, 'Visit Form Attributes'),
(7137, 'Visit Forms'),
(7138, 'Visit History'),
(7139, 'Visit Type'),
(7140, 'Visits'),
(7141, 'Visits From'),
(7142, 'Vital Signs'),
(7143, 'Vitals'),
(7144, 'Vitals (Metric)'),
(7145, 'Vitals Form Options'),
(7146, 'Voice'),
(7147, 'Voice Sent'),
(7148, 'Volapük'),
(7149, 'Vomiting'),
(7150, 'Voucher Number'),
(7151, 'W'),
(7152, 'Waist Circ'),
(7153, 'Waist Circumference'),
(7154, 'Waiting'),
(7155, 'Walk-In'),
(7156, 'Walloon'),
(7157, 'Walt Pennington'),
(7158, 'Warehouse'),
(7159, 'Warehouse maximum, 0 if not applicable'),
(7160, 'Warehouse minimum, 0 if not applicable'),
(7161, 'Warehouses'),
(7162, 'Warm'),
(7163, 'Warning'),
(7164, 'WARNING'),
(7165, 'WARNING - FOLLOWING ACTIVE MEDICATIONS ARE ALLERGIES'),
(7166, 'Warning, Check Number already exist in the database'),
(7167, 'Warning, patient has ambiguous codes in the problems list!'),
(7168, 'Warning: A visit was already created for this patient today!'),
(7169, 'WARNING: If you are using the 2012-10-31 Spanish version, then note you need to unzip it once before placing it in the contrib/snomed (this is because the released file was "double-zipped").'),
(7170, 'Warning: Patient ID is not unique!'),
(7171, 'WARNING: This will overwrite configuration information with data from the uploaded file!'),
(7172, 'WARNINGS'),
(7173, 'Warnings'),
(7174, 'WARNINGS and Alerts/Reminders'),
(7175, 'was already uploaded'),
(7176, 'was not found'),
(7177, 'We appreciate prompt payment of balances due'),
(7178, 'we have seen your above patient for evaluation and treatment at our outpatient psychiatry clinic. Thank you for this referral.'),
(7179, 'Weakness'),
(7180, 'Web Reference'),
(7181, 'Web Search'),
(7182, 'Website'),
(7183, 'Website link for the Onsite Patient Portal.'),
(7184, 'Wed'),
(7185, 'Wednesday'),
(7186, 'Week'),
(7187, 'week'),
(7188, 'Week View'),
(7189, 'Week(s)'),
(7190, 'Weekly Exposures'),
(7191, 'weeks'),
(7192, 'Weeks'),
(7193, 'Weight'),
(7194, 'Weight Assessment and Counseling for Children and Adolescents'),
(7195, 'Weight Assessment and Counseling for Children and Adolescents (CQM)'),
(7196, 'Weight Change'),
(7197, 'Weight Loss'),
(7198, 'Weight loss clinic'),
(7199, 'Welcome'),
(7200, 'Welsh'),
(7201, 'Western Frisian'),
(7202, 'What is to be counted?'),
(7203, 'Wheezes:'),
(7204, 'Wheezing'),
(7205, 'Wheezing:'),
(7206, 'When Checked, Demographics Will Open in New Window from Patient Flow Board.'),
(7207, 'When done, click Submit (below) to apply your choices.'),
(7208, 'Where may related scanned or paper documents be found?'),
(7209, 'Whether Insured'),
(7210, 'Which notes are to be displayed in the Billing Screen'),
(7211, 'Whiplash'),
(7212, 'White'),
(7213, 'Who'),
(7214, 'Who replied?'),
(7215, 'Widowed'),
(7216, 'Width'),
(7217, 'Width in pixels of the left navigation frame.'),
(7218, 'will be hidden if'),
(7219, 'With checked items plot'),
(7220, 'with preferred language'),
(7221, 'With selected:'),
(7222, 'with the old name'),
(7223, 'with value'),
(7224, 'With whom may we leave a message?'),
(7225, 'Withheld'),
(7226, 'within hours'),
(7227, 'within hours:'),
(7228, 'within minutes'),
(7229, 'within minutes:'),
(7230, 'Without Facility'),
(7231, 'Without Provider'),
(7232, 'Without Update'),
(7233, 'Witness'),
(7234, 'wk'),
(7235, 'WNL'),
(7236, 'Wolof'),
(7237, 'Women'),
(7238, 'Women Only'),
(7239, 'WordPress Portal'),
(7240, 'Work'),
(7241, 'WORK NOTE'),
(7242, 'Work Phone'),
(7243, 'Work Phone Number'),
(7244, 'Work related?'),
(7245, 'Work/ Education/ Hobbies'),
(7246, 'Work/School Note'),
(7247, 'workday'),
(7248, 'Worker`s Compensation'),
(7249, 'Workers Compensation Health Plan'),
(7250, 'Working Aged Beneficiary or Spouse with Employer Group Health Plan'),
(7251, 'Working... this may take a minute.'),
(7252, 'Worse'),
(7253, 'Would you like the balance amount to apply to Global Account?'),
(7254, 'Would You Like them to be Marked as Cleared.'),
(7255, 'Would you like to Allocate?'),
(7256, 'Would you like to Cancel Distribution for this Patient?'),
(7257, 'Would you like to Delete Payment Distribution?'),
(7258, 'Would you like to Delete Payments?'),
(7259, 'Would you like to Modify and Finish Payments?'),
(7260, 'Would you like to Modify Payments?'),
(7261, 'Would you like to Post and Finish Payments?'),
(7262, 'Would you like to Post Payments?'),
(7263, 'Would you like to save?'),
(7264, 'Wrist'),
(7265, 'Wrist and hand'),
(7266, 'Wrist Problems'),
(7267, 'write'),
(7268, 'write off'),
(7269, 'Write Once'),
(7270, 'wsome'),
(7271, 'WT'),
(7272, 'W{{Wednesday}}'),
(7273, 'x Canceled'),
(7274, 'x Cancelled'),
(7275, 'X-ray'),
(7276, 'X-RAY Interpretation:'),
(7277, 'X-Ray Interpretation:'),
(7278, 'X12 only: Replacement Claim '),
(7279, 'X12 Partner'),
(7280, 'X12 Partners'),
(7281, 'x12 Text'),
(7282, 'Xhosa'),
(7283, 'XML'),
(7284, 'Y'),
(7285, 'Year'),
(7286, 'year'),
(7287, 'Year View'),
(7288, 'Year(s)'),
(7289, 'Years'),
(7290, 'Years or months'),
(7291, 'Years, months and days'),
(7292, 'YES'),
(7293, 'Yes'),
(7294, 'yes'),
(7295, 'YES!'),
(7296, 'Yes, Delete and Log'),
(7297, 'Yes, Delete this form'),
(7298, 'Yes/No'),
(7299, 'Yes:'),
(7300, 'Yiddish'),
(7301, 'Yoruba'),
(7302, 'You are about to delete the following form from this encounter'),
(7303, 'You are about to permanently replace the existing template. Are you sure you wish to continue?'),
(7304, 'You are in Grace Login period. Change your password before'),
(7305, 'You are not allowed to delete this event'),
(7306, 'You are not allowed to edit this event'),
(7307, 'You are not authorized for this.'),
(7308, 'You are not authorized to access this squad.'),
(7309, 'You are not authorized to add/edit issues'),
(7310, 'You are not authorized to schedule appointments.'),
(7311, 'You are not authorized to see this encounter.'),
(7312, 'You are posting against an old encounter?'),
(7313, 'You can not access this function directly.'),
(7314, 'You cannot access this page directly.'),
(7315, 'You cannot add a blank value for a category!'),
(7316, 'You cannot add a blank value for a subcategory!'),
(7317, 'You cannot add a blank value for an item!'),
(7318, 'You cannot enter a future date with a completed value of YES.'),
(7319, 'You did not choose any actions.'),
(7320, 'You do not have access to view/edit this note'),
(7321, 'You have attempted to alter content which is locked. Remove the lock if you want to do this. To unlock, remove the line, ''/*lock::*/'''),
(7322, 'You have been successfully logged out.'),
(7323, 'You may only upload .txt files'),
(7324, 'You may optionally upload HL7 results from a file'),
(7325, 'You may put text here as the default complaint in the New Patient Encounter form.'),
(7326, 'You must enter a pass phrase to encrypt the document'),
(7327, 'You must enter your own password to change user passwords. Leave blank to keep password unchanged.'),
(7328, 'You must first select an item in the section whose radio button is checked.'),
(7329, 'You must first select or add a patient.'),
(7330, 'You must first select or create an encounter.'),
(7331, 'You must select a visit category'),
(7332, 'You must select a visit category.'),
(7333, 'You must select some fields to continue.'),
(7334, 'You should be running this test if this claim appeared to generate successfully but the actual claim file does not contain any data or only an unfinished portion of the amount of data it is supposed to contain. It is obvious with HCFA claims because they are human readable, with X12 claims it is a more difficult process to determine if the claim is properly complete.'),
(7335, 'You should select at least one context'),
(7336, 'You should select at least one Provider'),
(7337, 'You will be automatically redirected to Demographics. You may make the necessary corrections and navigate to NewCrop again.'),
(7338, 'Your Clinical Report'),
(7339, 'Your end date is invalid'),
(7340, 'Your event has been deleted.'),
(7341, 'Your event has been modified.'),
(7342, 'Your event has been submitted.'),
(7343, 'Your file is too large'),
(7344, 'Your Lab Results'),
(7345, 'Your list name has been changed to meet naming requirements.'),
(7346, 'Your message was submitted for delivery to'),
(7347, 'Your name for this category, procedure or result'),
(7348, 'Your Password'),
(7349, 'Your Password Expired. Please change your password.'),
(7350, 'Your Password Expires on'),
(7351, 'Your Password Expires today. Please change your password.'),
(7352, 'Your password is your signature'),
(7353, 'Your PostCalendar configuration has been reset to use defaults.'),
(7354, 'Your PostCalendar configuration has been updated.'),
(7355, 'Your repeating frequency must be an integer.'),
(7356, 'Your repeating frequency must be at least 1.'),
(7357, 'Your start date is greater than your end date'),
(7358, 'Your start date is invalid'),
(7359, 'Your submission failed.'),
(7360, 'yyyy-mm-dd'),
(7361, 'YYYY-MM-DD'),
(7362, 'yyyy-mm-dd date associated with this document'),
(7363, 'yyyy-mm-dd date destroyed'),
(7364, 'yyyy-mm-dd date of birth'),
(7365, 'yyyy-mm-dd Date of Birth'),
(7366, 'yyyy-mm-dd date of expiration'),
(7367, 'yyyy-mm-dd Date of onset or hospitalization'),
(7368, 'yyyy-mm-dd date of onset, surgery or start of medication'),
(7369, 'yyyy-mm-dd date of purchase or transfer'),
(7370, 'yyyy-mm-dd date of recovery or end of medication'),
(7371, 'yyyy-mm-dd Date of return to play'),
(7372, 'yyyy-mm-dd Date of service'),
(7373, 'yyyy-mm-dd date of this letter'),
(7374, 'yyyy-mm-dd date returned to play'),
(7375, 'yyyy-mm-dd document date'),
(7376, 'yyyy-mm-dd event date or starting date'),
(7377, 'yyyy-mm-dd H:m End Date'),
(7378, 'yyyy-mm-dd H:m End date'),
(7379, 'yyyy-mm-dd H:m Start Date'),
(7380, 'yyyy-mm-dd H:m Start date'),
(7381, 'yyyy-mm-dd hh:mm:ss'),
(7382, 'yyyy-mm-dd Hours(24):minutes'),
(7383, 'yyyy-mm-dd last date of this event'),
(7384, 'yyyy-mm-dd starting date for search'),
(7385, 'ZEF segment internal error'),
(7386, 'Zend Module'),
(7387, 'Zero'),
(7388, 'Zhuang, Chuang'),
(7389, 'Zip'),
(7390, 'Zip Code'),
(7391, 'Zip/Country:'),
(7392, 'Zulu'),
(7393, ' but was '),
(7394, ' could not be accessed.'),
(7395, ' Do you really want to delete'),
(7396, ' Drug'),
(7397, ' emails not sent'),
(7398, ' from'),
(7399, ' has been created. '),
(7400, ' has been re-opened.'),
(7401, ' History'),
(7402, ' is not a number'),
(7403, ' is ready for re-billing.'),
(7404, ' LLL:'),
(7405, ' Lot'),
(7406, ' Medicaid Original Reference No. '),
(7407, ' min'),
(7408, ' not found!'),
(7409, ' Pecularities in many browsers may mean that the output below enters your screen in sudden jerks and that there are long pauses of several seconds where it  appears as though things may have crashed. That is not the case, you will eventually see output coming out line by line. There may be sequential numbers appearing  below, this is to indicate that even though nothing else may be displaying there is activity going on. These numbers will be interspersed with the content of the  billing and that is normal.'),
(7410, ' prescription has reached its limit of'),
(7411, ' until '),
(7412, ' update failed, not in database?'),
(7413, ' was marked as billed only.'),
(7414, ' was queued successfully.'),
(7415, '! Left w/o visit'),
(7416, '" for code '),
(7417, '" is CHECKED in PostCalendar Settings!'),
(7418, '# Ins/fin issue'),
(7419, '# of tablets:'),
(7420, '$'),
(7421, '$ Coding done'),
(7422, '$label (yyyy-mm-dd): '),
(7423, '%'),
(7424, '% Canceled < 24h'),
(7425, '% Cancelled <  24h '),
(7426, ''' should exist but does not.'),
(7427, '(% matches any string, _ matches any character)'),
(7428, '([ctrl] + click to select multiple recipients)'),
(7429, '(Back)'),
(7430, '(Click to edit)'),
(7431, '(Email delivery is immediate, while automated VOIP is sent to the service provider for further processing.)'),
(7432, '(More)'),
(7433, '(New Patient)'),
(7434, '(Notes and Authorizations)'),
(7435, '(Patient Notes)'),
(7436, '(Select one of these, or type your own title)'),
(7437, '(Shift-)Click or drag to change value'),
(7438, '* Reminder done'),
(7439, '** Please move surgeries to Issues!'),
(7440, '*Required'),
(7441, '+ Chart pulled'),
(7442, '- None'),
(7443, '-- All --'),
(7444, '--Select Role--'),
(7445, '.'),
(7446, '0'),
(7447, '0-10'),
(7448, '0-24'),
(7449, '02/12{{CMS 1500 format date revision setting in globals}}'),
(7450, '08/05{{CMS 1500 format date revision setting in globals}}'),
(7451, '1'),
(7452, '1 = North America. See http://www.wtng.info/ for a list of other country codes.'),
(7453, '1 Day From Now'),
(7454, '1 Month From Now'),
(7455, '1 Week From Now'),
(7456, '1 Year From Now'),
(7457, '1.Rest 2. Ice for two days 3. Compression, leave the dressing in place unless the foot develops numbness or pale color 4. Elevate the foot and leg'),
(7458, '11-14'),
(7459, '12 hr'),
(7460, '15-19'),
(7461, '1st'),
(7462, '2'),
(7463, '2 Days From Now'),
(7464, '2 Months From Now'),
(7465, '2 Weeks From Now'),
(7466, '2 Years From Now'),
(7467, '2-20 years'),
(7468, '20-24'),
(7469, '2011 Automated Measure Calculations (AMC)'),
(7470, '2011 Clinical Quality Measures (CQM)'),
(7471, '2011 Official Clinical Quality Measures (CQM) Measure Groups'),
(7472, '2014 Automated Measure Calculations (AMC)'),
(7473, '2014 Automated Measure Calculations (AMC) - Stage I'),
(7474, '2014 Automated Measure Calculations (AMC) - Stage II'),
(7475, '2014 Clinical Quality Measures (CQM)'),
(7476, '2014 Official Clinical Quality Measures (CQM) Measure Groups'),
(7477, '2111-13'),
(7478, '24 hr'),
(7479, '25+'),
(7480, '25-29'),
(7481, '2nd'),
(7482, '3 Days From Now'),
(7483, '3 months'),
(7484, '3 Months From Now'),
(7485, '3 times daily'),
(7486, '3 Weeks From Now'),
(7487, '30-34'),
(7488, '35-39'),
(7489, '3rd'),
(7490, '4 Days From Now'),
(7491, '4 months'),
(7492, '4 Months From Now'),
(7493, '4 times daily'),
(7494, '4 Weeks From Now'),
(7495, '40-44'),
(7496, '45+'),
(7497, '465.9, URI'),
(7498, '466.0, Bronchitis, Acute NOS'),
(7499, '486.0, Pneumonia, Acute'),
(7500, '491.21, COPD Exacerbation'),
(7501, '491.8, Bronchitis, Chronic'),
(7502, '493.92, Asthma, Acute Exac.'),
(7503, '496.0, COPD'),
(7504, '4th'),
(7505, '5 Days From Now'),
(7506, '5 Months From Now'),
(7507, '5 Weeks From Now'),
(7508, '519.7, Bronchospasm'),
(7509, '5th'),
(7510, '6 Days From Now'),
(7511, '6 months'),
(7512, '6 Months From Now'),
(7513, '6 Weeks From Now'),
(7514, '6th'),
(7515, '7 Months From Now'),
(7516, '8 Months From Now'),
(7517, '824.0 Fracture, medial malleolus, closed'),
(7518, '824.2 Fracture, lateral malleolus, closed'),
(7519, '824.6 Fracture, Trimalleolar, closed'),
(7520, '825.32 Fracture, of Navicular (ankle)'),
(7521, '825.35 Fracture, Base of fifth (5th) Metatarsal'),
(7522, '845.00 ankle sprain NOS'),
(7523, '845.01 Sprain Medial (Deltoid) Lig.'),
(7524, '845.02 Sprain, Calcaneal fibular'),
(7525, '9 Months From Now'),
(7526, '99212 Established - Uncomplicated'),
(7527, '99213 Established - Low Complexity'),
(7528, '< In exam room'),
(7529, '> Checked out'),
(7530, '?'),
(7531, '? No show'),
(7532, '@ Arrived'),
(7533, '[Change View]'),
(7534, '[Date of Last Encounter]'),
(7535, '[Days Since Last Encounter]'),
(7536, '[EOBs]'),
(7537, '[Export OFX]'),
(7538, '[not recommended]'),
(7539, '[Number Of Encounters]'),
(7540, '[Reports]'),
(7541, '[Select All]'),
(7542, '[SQL-Ledger]'),
(7543, '[Start Batch Processing]'),
(7544, '[View Log]'),
(7545, '[View Printable Report]'),
(7546, '_PC_DUR_HOURS'),
(7547, '_PC_DUR_MINUTES'),
(7548, '_PC_LOCALE'),
(7549, '~ Arrived late');

-- --------------------------------------------------------

--
-- Table structure for table `lang_custom`
--

CREATE TABLE `lang_custom` (
  `lang_description` varchar(100) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `constant_name` mediumtext,
  `definition` mediumtext
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `lang_definitions`
--

CREATE TABLE `lang_definitions` (
  `def_id` int(11) NOT NULL AUTO_INCREMENT,
  `cons_id` int(11) NOT NULL DEFAULT '0',
  `lang_id` int(11) NOT NULL DEFAULT '0',
  `definition` mediumtext,
  UNIQUE KEY `def_id` (`def_id`),
  KEY `cons_id` (`cons_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=150674 ;

--
-- Dumping data for table `lang_definitions`
--

INSERT INTO `lang_definitions` VALUES
(1, 1, 2, 'En'),
(2, 2, 2, 'Ett betalningsnr för att identifiera betalningen'),
(3, 3, 2, 'Klientcertifikat för admin användaren'),
(4, 5, 2, 'Ett klinikdokument är bifogat'),
(5, 7, 2, 'En distributör behövs'),
(6, 8, 2, 'Ett GCAC besöksformulär ska läggas till för detta besök'),
(7, 9, 2, 'Ett lot-nr krävs!'),
(8, 10, 2, 'Ett lot-nr krävs!'),
(9, 11, 2, 'En liten bokstav'),
(10, 12, 2, 'Ett tal'),
(11, 14, 2, 'En patient med detta ID finns redan'),
(12, 15, 2, 'En patient med detta namn finns redan'),
(13, 16, 2, 'En patient med detta personnummer ( SS ) finns redan'),
(14, 18, 2, 'Ett positivt nummer kommer visa antalet tidigare bokningar i en ruta på patientöversikten.'),
(15, 19, 2, 'Den remitterande instansen kan framgå vid varje besök'),
(16, 20, 2, 'En relaterad IPPF kod krävs!'),
(17, 21, 2, 'Ett specialtecken'),
(18, 22, 2, 'Ett unikt värde, som ej är synlig för användaren, identifierar detta fält.'),
(19, 24, 2, 'Före måltid'),
(20, 25, 2, 'förmiddag'),
(21, 27, 2, 'AB'),
(22, 28, 2, 'Förkortning'),
(23, 29, 2, 'Abscess'),
(24, 30, 2, 'Abdominell'),
(25, 31, 2, 'kan bära vikt fyra (4) steg:'),
(26, 32, 2, 'Patologisk'),
(27, 33, 2, 'ABN1'),
(28, 34, 2, 'Patologisk'),
(29, 35, 2, 'Patologiskt blodprov'),
(30, 36, 2, 'Avvikande hårväxt'),
(31, 37, 2, 'Patologisk mammografi'),
(32, 39, 2, 'Abort'),
(33, 40, 2, 'Abortrelaterad problematik'),
(34, 41, 2, 'Abortmetod'),
(35, 42, 2, 'Abortrelaterade kategorier'),
(36, 43, 2, 'Aborter'),
(37, 44, 2, 'Om kalendern'),
(38, 46, 2, 'Frånvaro av Diagnos'),
(39, 47, 2, 'Acceptera uppdrag'),
(40, 48, 2, 'acceptera betalning för'),
(41, 49, 2, 'acceptera betalning för '),
(42, 50, 2, 'Accepterar uppdrag'),
(43, 51, 2, 'Åtkomstkontroll'),
(44, 52, 2, 'Hantera åtkomst'),
(45, 54, 2, 'Åtkomst ej tillåten'),
(46, 55, 2, 'Åtkomst ej tillåten'),
(47, 56, 2, 'Öppna patientöversikten'),
(48, 59, 2, 'Konto namn'),
(49, 62, 2, 'Redovisning'),
(50, 64, 2, 'värker'),
(51, 65, 2, 'Begärt godokännande (ISA14)'),
(52, 66, 2, 'Godkännande, licenser och certifikat'),
(53, 67, 2, 'Användarlista (ACL)'),
(54, 68, 2, 'Administration av användarlista (ACL)'),
(55, 69, 2, 'Ej behörig administrera användarlista (ACL)'),
(56, 71, 2, 'Akne'),
(57, 72, 2, 'Aktuellt'),
(58, 73, 2, 'Aktivitetsdatum'),
(59, 74, 2, 'Åtgärd'),
(60, 75, 2, 'Åtgärder'),
(61, 77, 2, 'Rapportera fortsatt vårdbegäran (CCR/CCD)'),
(62, 78, 2, 'Aktiva'),
(63, 79, 2, 'Aktiv påminnelse'),
(64, 80, 2, 'Regler för aktiv påminnelse'),
(65, 81, 2, 'Aktiva påminnelser'),
(66, 82, 2, 'Aktivt besök'),
(67, 84, 2, 'Aktiva listor'),
(68, 85, 2, 'Aktiv patient'),
(69, 86, 2, 'Aktuella planeringar'),
(70, 87, 2, 'Aktiviteter'),
(71, 88, 2, 'Aktivitetstyp'),
(72, 90, 2, 'Akut förgiftning / Utsättning'),
(73, 92, 2, 'Akut försämring av kronisk'),
(74, 93, 2, 'lägg till'),
(75, 94, 2, 'Lägg till'),
(76, 95, 2, 'Lägg till'),
(77, 96, 2, 'Lägg till ett företag'),
(78, 98, 2, 'Lägg till ett apotek'),
(79, 100, 2, 'lägg till ett händelse för '),
(80, 101, 2, 'Lägg till som en ny anteckning'),
(81, 102, 2, 'Lägg till som ny'),
(82, 104, 2, 'Lägg till knappar'),
(83, 105, 2, 'Lägg till knappar för specialtecken och texter att visa längst upp i editorn för inkludering i texten med ett klick'),
(84, 106, 2, 'Lägg till en ny Kategori'),
(85, 107, 2, 'Lägg till en ny Konstant'),
(86, 108, 2, 'Lägg till ett sammanhang'),
(87, 109, 2, 'Lägg till en delbetalning'),
(88, 110, 2, 'Lägg till ett nytt kriterium'),
(89, 111, 2, 'Lägg till anpassad knapp'),
(90, 112, 2, 'Lägg till en ny diagnos'),
(91, 113, 2, 'Lägg till ett nytt Läkemedel'),
(92, 114, 2, 'Lägg till ett nytt besök'),
(93, 115, 2, 'Lägg till ett nytt besök/anteckning'),
(94, 116, 2, 'Lägg till en ny klinik'),
(95, 117, 2, 'Lägg till ett nytt fält'),
(96, 118, 2, 'Lägg till följande meningar till Apache konfigurationsfilen'),
(97, 119, 2, 'Lägg till en ny Grupp'),
(98, 120, 2, 'Lägg till en ny diagnos-kod (ICD)'),
(99, 121, 2, 'Lägg till en ny vaccination'),
(100, 122, 2, 'Inte tillåtet att lägga till!'),
(101, 123, 2, 'Lägg till händelse'),
(102, 125, 2, 'Lägg till ett nytt Språk'),
(103, 126, 2, 'Lägg till Ny'),
(104, 127, 2, 'Lägg till Ny'),
(105, 128, 2, 'Lägg till en ny kategori: '),
(106, 129, 2, 'Lägg till ett nytt certifikat till Apache konfigurationsfil'),
(107, 132, 2, 'Lägg till en ny grupp'),
(108, 134, 2, 'Lägg till en ny lot och överföring'),
(109, 135, 2, 'Lägg till en ny kommentar'),
(110, 136, 2, 'Lägg till en ny kommentar'),
(111, 137, 2, 'Lägg till en ny partner'),
(112, 140, 2, 'Lägg till en ny anteckning'),
(113, 141, 2, 'Lägg till en ny patient'),
(114, 142, 2, 'Lägg till ett nytt recept'),
(115, 143, 2, 'Lägg till åtgärd'),
(116, 144, 2, 'Lägg till Vårdgivares nummer'),
(117, 145, 2, 'Lägg till rehab'),
(118, 146, 2, 'Lägg till en ny regel'),
(119, 147, 2, 'Tillägg till'),
(120, 148, 2, 'Lägg till i medicinlista'),
(121, 149, 2, 'Tillägg av högsta nivå'),
(122, 150, 2, 'Lägg till en ny överföring'),
(123, 151, 2, 'Lägg till en ny användare'),
(124, 152, 2, 'Lägg till användaren i gruppen'),
(125, 153, 2, 'Lägg till/ändra elektroniskt recept'),
(126, 154, 2, 'Lägg till/ändra patientens överföringar'),
(127, 155, 2, 'tillagd'),
(128, 156, 2, 'Ej tillåtet att lägga till personuppgifter.'),
(129, 158, 2, 'Mb Addison'),
(130, 159, 2, 'Mb Addison'),
(131, 160, 2, 'Flera attribut'),
(132, 161, 2, 'Ytterligare Diagnos:'),
(133, 162, 2, 'Kompletterande anamnes'),
(134, 163, 2, 'Kompletterande anamnesuppgifter'),
(135, 164, 2, 'Kompletterande Information'),
(136, 165, 2, 'Kompletterande Lab. svar'),
(137, 166, 2, 'Kompletterande noteringar'),
(138, 167, 2, 'Ytterligare noteringar för detta resultat eller rekomendation'),
(139, 168, 2, 'Ytterligare noteringar:'),
(140, 169, 2, 'Ytterligare noteringar: '),
(141, 170, 2, 'Ytterligare röntgenanteckningar:'),
(142, 171, 2, 'Som tillägg, motsvarande US Snomed Extension Package can importeras separat efter instalation av den internationella (engelska) Snomed utgåvan'),
(143, 172, 2, 'Lägg endast till'),
(144, 173, 2, 'Adressbok'),
(145, 174, 2, 'Adressbok'),
(146, 175, 2, 'Adress'),
(147, 178, 2, 'Adressbok'),
(148, 179, 2, 'Tillgång till adressboken för företaget som utför denna åtgärd'),
(149, 180, 2, 'Tillgång till adressboken för distributören'),
(150, 181, 2, 'Tillgång till adressboken för försäljare'),
(151, 182, 2, 'Typer av adressböcker'),
(152, 187, 2, 'Adress1'),
(153, 188, 2, 'Adress2'),
(154, 189, 2, 'ADRESSATEN'),
(155, 190, 2, 'Justera'),
(156, 191, 2, 'Korrigera mängd'),
(157, 192, 2, 'Justera'),
(158, 193, 2, 'Korrigering'),
(159, 194, 2, 'Justera mängd'),
(160, 195, 2, 'Orsak till justering'),
(161, 196, 2, 'Justering av värde för kod '),
(162, 197, 2, 'Justeringar'),
(163, 198, 2, 'Administrera justeringar'),
(164, 199, 2, 'Administrera'),
(165, 200, 2, 'Admin E-postadress'),
(166, 201, 2, 'Administrera via'),
(167, 202, 2, 'Administrerad av'),
(168, 203, 2, 'Administrerad av'),
(169, 205, 2, 'Administrera plats'),
(170, 206, 2, 'Administration'),
(171, 207, 2, 'Administrera plats'),
(172, 208, 2, 'Administratörer'),
(173, 209, 2, 'Administratörer kan göra allt'),
(174, 210, 2, 'Godkänn datum'),
(175, 212, 2, 'Viktkontroller med uppföljning för vuxna'),
(176, 213, 2, 'Viktkontroller med uppföljning för vuxna'),
(177, 214, 2, 'Avancerade råd'),
(178, 215, 2, 'Avancerade råd'),
(179, 216, 2, 'Varning i avancerade råd'),
(180, 218, 2, 'Avancerad'),
(181, 219, 2, 'Råd'),
(182, 221, 2, 'Neutral grundstämning'),
(183, 223, 2, 'Joursamtal'),
(184, 224, 2, 'Efter flytt från det gamla lösenordshanteringen där lösenord sparadesokrypterat i användartabellenska denna flagga markeras så att enbart inloggning med den nya metoden kan användas'),
(185, 225, 2, 'Efter genomförandet av ovannämnda konfigurationer, importera admin. klientens certifikat till webläsaren och starta om Apache server ( tömma lösenord )'),
(186, 226, 2, 'Efter att PDF sparats, klicka på [View Log] för att söka efter fel.'),
(187, 227, 2, 'Efter sparandet av TEXT filer , klicka på [View Log] för att leta efter fel'),
(188, 228, 2, 'Efter sparandet av ditt parti, klicka på [View Log] för att granska för fel.'),
(189, 230, 2, 'När informationen är korrekt införd, klicka på Spara knappen.'),
(190, 232, 2, 'Planering av eftervård'),
(191, 233, 2, 'Igen'),
(192, 234, 2, 'Ålder'),
(193, 235, 2, 'Ålder av'),
(194, 236, 2, 'Ålderskategori'),
(195, 237, 2, 'Denna Åder är utanför befintlig intervall'),
(196, 238, 2, 'Format för att visa ålder'),
(197, 239, 2, 'Detta format för "ålder från" är inte tillåtet'),
(198, 240, 2, 'Detta format för "ålder upp till" är inte tillåtet'),
(199, 241, 2, 'Ålder från'),
(200, 242, 2, 'Ändra format för att visa ålder i år'),
(201, 243, 2, 'Högsta ålder'),
(202, 244, 2, 'Lägsta ålder'),
(203, 245, 2, 'Åldersintervall'),
(204, 247, 2, 'Kolumner med åldern'),
(205, 249, 2, 'Albansk'),
(206, 250, 2, 'Alkohol'),
(207, 251, 2, 'Alkoholkonsumtion'),
(208, 253, 2, 'Antal varningar'),
(209, 255, 2, 'Varningar'),
(210, 258, 2, 'Aleut-befolkning'),
(211, 259, 2, 'Alla'),
(212, 260, 2, 'Alla'),
(213, 261, 2, 'Alla (format A)'),
(214, 262, 2, 'Alla (format B)'),
(215, 263, 2, 'Allt ( Kumulativt )'),
(216, 266, 2, 'Alla Kategorier'),
(217, 268, 2, 'Alla koder'),
(218, 269, 2, 'Hela dagen'),
(219, 270, 2, 'Heldagshändelse'),
(220, 271, 2, 'Alla demografiska fält , med sökning och dubbel kontroll'),
(221, 272, 2, 'Alla kliniker'),
(222, 273, 2, 'Alla skador/problem/frågeställningar'),
(223, 274, 2, 'All språk är tillåtna'),
(224, 276, 2, 'Hela förnamnet eller en del av det'),
(225, 277, 2, 'Hela efternamnet eller en del av det'),
(226, 278, 2, 'Hela organisationen eller delar av namnet'),
(227, 280, 2, 'Alla produkter'),
(228, 281, 2, 'Alla vårdgivare'),
(229, 282, 2, 'Alla granskade och Negativa:'),
(230, 283, 2, 'Alla ämnen'),
(231, 284, 2, 'Alla användare'),
(232, 285, 2, 'Allergisk'),
(233, 286, 2, 'Allergier'),
(234, 287, 2, 'Allergier:'),
(235, 288, 2, 'Allergi'),
(236, 289, 2, 'Import av allergier klart'),
(237, 290, 2, 'Lista på allergier'),
(238, 291, 2, 'Allergisk reaktion'),
(239, 294, 2, 'Tilldela'),
(240, 295, 2, 'Tillåta'),
(241, 296, 2, 'Tillåt alla tillgängliga språk som val i menyn vid inloggning'),
(242, 297, 2, 'Tillåt att skapa krav innehållande diagnoser , men ej procedurer eller betalningar. De flesta kliniker vill inte ha det'),
(243, 298, 2, 'Tillåt debugg språk'),
(244, 299, 2, 'E-post tillåten'),
(245, 300, 2, 'Är e-post meddelande tillåtet ?'),
(246, 301, 2, 'Tillåt e-post?'),
(247, 302, 2, 'Tillåt krav i patient möte'),
(248, 303, 2, 'Tillåt utbyte av hälsoinformationen'),
(249, 304, 2, 'Tillåt att informationen om vaccinationer delas'),
(250, 305, 2, 'Tillåt användning av vaccinationsregistret'),
(251, 306, 2, 'Tillåt e-post meddelanden'),
(252, 308, 2, 'Tillåt patient-inloggning'),
(253, 309, 2, 'Tillåt SMS'),
(254, 310, 2, 'Är SMS meddelanden tillåtna ?'),
(255, 311, 2, 'Tillåt aktuella händelser att vara aktiva omedelbart ?'),
(256, 312, 2, 'Tillåt telefon meddelanden?'),
(257, 313, 2, 'Tillåt användare att publicera Globala Händelser'),
(258, 314, 2, 'Tillåt användare att publicera personliga kalendrar'),
(259, 315, 2, 'Tillåt telefonsvarare'),
(260, 316, 2, 'Tillåten'),
(261, 317, 2, 'Godkända språk'),
(262, 318, 2, 'Godkänt'),
(263, 323, 2, 'finns redan'),
(264, 324, 2, 'Finns redan'),
(265, 325, 2, 'Används redan, välj en annan identitetsbeteckning'),
(266, 326, 2, 'Används redan, välj en annan titel'),
(267, 327, 2, 'Alternativ Adress'),
(268, 328, 2, 'Ändra'),
(269, 329, 2, 'Alternativt kan du använda sökfunktionen för att lägga upp ett elektroniskt godkännande (X12 83l fil) som du fått från din betalare eller clearingorganisationer. Du kan göra detta genom att klicka på knappen Bläddra och välj den fil som ska laddas upp och sedan klicka på Sök för att ladda upp och visa motsvarande fakturor. I detta fall gäller inte de andra parametrar som nämns ovan och de kommer att ignoreras. Överföring sparar filen men processar ännuinte innehållet - detta är gjort separat enligt nedan.'),
(270, 330, 2, 'förmiddag'),
(271, 331, 2, 'Förmiddagens program'),
(272, 332, 2, 'Automatisk beräkning av åtgärder (AMC)'),
(273, 333, 2, 'Spåra AMC'),
(274, 338, 2, 'Ändra Befintlig notering'),
(275, 343, 2, 'Amerikansk indian'),
(276, 344, 2, 'Amerikans indian eller född i alaska'),
(277, 345, 2, 'AMEX'),
(278, 346, 2, 'Etiopier'),
(279, 347, 2, 'Belopp'),
(280, 348, 2, 'Administrerat belopp'),
(281, 349, 2, 'Begärt belopp'),
(282, 350, 2, 'Belopp från tidigare Saldo'),
(283, 351, 2, 'Belopp för besöket'),
(284, 352, 2, 'Belopp som betalts'),
(285, 353, 2, 'Belopp:'),
(286, 354, 2, 'fakturerat belopp'),
(287, 355, 2, 'Ett slutdatum senare än startdatum krävs för upprepade händelser!'),
(288, 357, 2, 'ett fel uppstod när LibreEHR sparades'),
(289, 358, 2, 'Ett fel uppstod när phpGACL sparades'),
(290, 359, 2, 'Ett fel uppstod när SQL-ledger sparades'),
(291, 360, 2, 'En ofullständig GCAC fråga har inrättats och knutits. Någon kommer att behöva fylla i det senare.'),
(292, 362, 2, 'Ett oförutsett fel uppkom'),
(293, 363, 2, 'En stor bokstav'),
(294, 365, 2, 'Och'),
(295, 366, 2, 'OCH'),
(296, 367, 2, 'och'),
(297, 368, 2, 'och '),
(298, 369, 2, 'och alla underordnade data? Denna åtgärd kommer att loggas'),
(299, 370, 2, 'och modifierare'),
(300, 371, 2, 'och hanterad.'),
(301, 372, 2, 'och starta om Apache servern.'),
(302, 373, 2, 'och orsaken är'),
(303, 374, 2, 'Anemi'),
(304, 375, 2, 'Ankel'),
(305, 376, 2, 'Ankel + häl'),
(306, 377, 2, 'Ankel Utvärderingsformulär'),
(307, 378, 2, 'Ankel problem'),
(308, 379, 2, 'Ankyloserande Spondylit'),
(309, 380, 2, 'Ankyloserande Spondylit'),
(310, 381, 2, 'Anorexia'),
(311, 382, 2, 'En annan sak du kan göra i utstationering fönstret är att begära en sekundära fakturering. Om du markerar rutan innan du sparar, så kommer den ursprungliga fordran att öppnas igen och köas på faktureringssidan och sedan behandlas under nästa faktureringskörning.'),
(312, 383, 2, 'framåt'),
(313, 384, 2, 'Anus, ingen rektal ömhet'),
(314, 385, 2, 'Ångest'),
(315, 386, 2, 'Valfri'),
(316, 387, 2, 'någon Kategori'),
(317, 388, 2, 'Någon del av en kod eller dess beskrivning'),
(318, 389, 2, 'Någon del av önskad specialitet'),
(319, 390, 2, 'någon del av medicinens namn eller id'),
(320, 391, 2, 'Någon del av vaccinations namn eller id'),
(321, 392, 2, 'Någon del av patientens namn, eller "efternamn, förnamn " eller "X-Y "'),
(322, 393, 2, 'Någon annan relevant information'),
(323, 394, 2, 'API nyckel till SMS portal'),
(324, 395, 2, 'Andningsuppehåll'),
(325, 396, 2, 'Utseende'),
(326, 397, 2, 'Utseende:'),
(327, 398, 2, 'Lägg till denna notering'),
(328, 399, 2, 'Lägg till den nuvarande noteringen'),
(329, 400, 2, 'Lägg till denna anmärkning'),
(330, 401, 2, 'Bifoga till denna notering'),
(331, 402, 2, 'Appendektomi'),
(332, 404, 2, 'Tällämpliga patienter'),
(333, 405, 2, 'Ansökan'),
(334, 406, 2, 'Namn på program vid inloggning och titel på sidan'),
(335, 407, 2, 'Mottagarkod (GS03. Om blank kommer ISA08 användas)'),
(336, 408, 2, 'Sändarkod (GS02)'),
(337, 409, 2, 'Programmets titel'),
(338, 410, 2, 'Gäller Formulär för vitalparametrar och tillväxtkurva'),
(339, 411, 2, 'Gäller formulär för vitalparametrar'),
(340, 412, 2, 'Tillämpa ändringen på nuvarande händelse, nuvarande och alla kommande händelser eller alla händelser?'),
(341, 413, 2, 'tillämpas på berörda området'),
(342, 414, 2, 'appliceras på huden'),
(343, 415, 2, 'Lägger till'),
(344, 416, 2, 'Lägger till patch till sidan'),
(345, 417, 2, 'Bokning'),
(346, 418, 2, 'Boknings datum'),
(347, 419, 2, 'Sätt att visa bokning'),
(348, 420, 2, 'Påminnelser för bokning'),
(349, 421, 2, 'Boknings status'),
(350, 422, 2, 'Boknings status'),
(351, 423, 2, 'Bokas inom'),
(352, 424, 2, 'Bokning/händelse färg'),
(353, 425, 2, 'Bokningar'),
(354, 426, 2, 'Bokningar ( valfritt att skriva )'),
(355, 427, 2, 'Bokningar (Skriv, några valbara)'),
(356, 430, 2, 'Bokningar och besök'),
(357, 431, 2, 'Bokningsrapport'),
(358, 432, 2, 'Boknings och besöksrapport'),
(359, 434, 2, 'Godkänn'),
(360, 436, 2, 'Godkänd'),
(361, 437, 2, 'Godkända administrativa händelser'),
(362, 440, 2, 'Bokningar-besök'),
(363, 441, 2, 'Bokningar'),
(364, 442, 2, 'Apr'),
(365, 443, 2, 'April'),
(366, 444, 2, 'Arabisk'),
(367, 446, 2, 'Arkivera'),
(368, 447, 2, 'Ska gruppnamnen översättas?'),
(369, 448, 2, 'Ska bokningstyperna översättas?'),
(370, 449, 2, 'Ska dokumenttyperna översättas?'),
(371, 450, 2, 'Ska avgifter tas ut för denna typ?'),
(372, 451, 2, 'Ska överskrifter på patientanteckningar översättas?'),
(373, 452, 2, 'Är koderna lagrade i externa sql-tabeller (0-Nej, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2) )'),
(374, 453, 2, 'Är du beredd att genomföra en ny GCAC fråga för detta besök?'),
(375, 454, 2, 'Är du säker du vill bokföra dagens händelser?'),
(376, 455, 2, 'Är du säker på att du vill godkänna dessa händelser?'),
(377, 457, 2, 'Är du säker på att du vill ta bort detta formulär?'),
(378, 459, 2, 'Är du säker på att du vill ta bort denna friskrivning?'),
(379, 460, 2, 'Är du säker på att du vill ta bort denna händelse?'),
(380, 461, 2, 'Är du säker du vill ta bort detta från databasen?'),
(381, 462, 2, 'Är du säker på att du vill ta bort detta meddelande?'),
(382, 464, 2, 'Är du säker på att du vill ändra dessa händelser?'),
(383, 465, 2, 'Är du säker på att du vill dölja dessa händelser?'),
(384, 467, 2, 'Är du säker på att du vill visa dessa händelser?'),
(385, 468, 2, 'Är du säker på att du vill ta bort hela den valda gruppen'),
(386, 469, 2, 'Är du säker på att du vill ta bort hela listan'),
(387, 470, 2, 'Är du säker på att du vill ta bort fältet i'),
(388, 471, 2, 'Är du säker på att du vill ta bort markerade fält?'),
(389, 472, 2, 'Är du säker på att du vill fortsätta med dessa åtgärder?'),
(390, 473, 2, 'Område är ej specifiserat'),
(391, 474, 2, 'Arm'),
(392, 475, 2, 'Armensk'),
(393, 477, 2, 'Arrytmi'),
(394, 478, 2, 'Artrit'),
(395, 479, 2, 'Artrit / Degenerativ ledsjukdom'),
(396, 480, 2, 'Artrit / Degenerativ ledsjukdom'),
(397, 481, 2, 'som'),
(398, 482, 2, 'Per'),
(399, 484, 2, 'Asiatisk'),
(400, 487, 2, 'Bedömning'),
(401, 488, 2, 'Tilldelas'),
(402, 489, 2, 'Assistent'),
(403, 490, 2, 'Astma'),
(404, 491, 2, 'på'),
(405, 492, 2, 'Minst en sök parameter krävs om du väljer Alla'),
(406, 493, 2, 'Vid Båtbenet'),
(407, 494, 2, 'Vid Båtbenet:'),
(408, 495, 2, 'Idrottsgrupp'),
(409, 496, 2, 'Idrottsgrupp'),
(410, 497, 2, 'Idrottsskada'),
(411, 498, 2, 'CA certifikat för ATNA revision'),
(412, 499, 2, 'Värd för ATNA revision'),
(413, 500, 2, 'Lokalt certifikat för ATNA revision'),
(414, 501, 2, 'Posrt för ATNA revision'),
(415, 503, 2, 'Observera'),
(416, 504, 2, 'OBS'),
(417, 506, 2, 'revision CDR urval'),
(418, 509, 2, 'Revisionsloggning backup'),
(419, 510, 2, 'revisionsloggning blandad'),
(420, 511, 2, 'Revisionsloggning sorteringsordning'),
(421, 512, 2, 'Revisionsloggning patientjournal'),
(422, 513, 2, 'revisionsloggning schemaläggning'),
(423, 514, 2, 'Hantera säkerhet för revisorslog'),
(424, 515, 2, 'Urval av revisorlog'),
(425, 516, 2, 'Aug'),
(426, 517, 2, 'Augusti'),
(427, 519, 2, 'Rättigheter'),
(428, 520, 2, 'Rättighet/anteckningar'),
(429, 523, 2, 'Grupprättigheter'),
(430, 524, 2, 'Status på auktorisation'),
(431, 525, 2, 'Tillstånd'),
(432, 526, 2, 'Bemyndiga'),
(433, 527, 2, 'Auktorisera – alla möten'),
(434, 528, 2, 'Auktorisera - Mina möten'),
(435, 529, 2, 'Auktorisera.net'),
(436, 530, 2, 'Auktoriserad'),
(437, 531, 2, 'Enbart auktoriserade'),
(438, 532, 2, 'Skicka automatiskt'),
(439, 535, 2, 'Skapa nytt besök automatiskt'),
(440, 536, 2, 'Autogenererad'),
(441, 537, 2, 'Automatiska beräkningar (AMC)'),
(442, 542, 2, 'Spåra automatiska beräkningar (ATM)'),
(443, 543, 2, 'Automatiska mätningar (AMC)'),
(444, 544, 2, 'Automatiskt'),
(445, 546, 2, 'Automatiskt skapa nytt besök när bokningsstatus är satt till ”@” (Kommit)'),
(446, 549, 2, 'Trafikmedicin'),
(447, 550, 2, 'Sparad automatisk'),
(448, 551, 2, 'Tillgängliga kategorier'),
(449, 552, 2, 'Tillgängliga tider'),
(450, 557, 2, 'Månadsgenomsnitt'),
(451, 558, 2, 'Avulsion / avulsion fraktur'),
(452, 559, 2, 'Avulsion laterala malleolus'),
(453, 560, 2, 'Avulsion mediala malleolus '),
(454, 561, 2, 'Medvetandebaserad'),
(455, 562, 2, 'Axillär'),
(456, 565, 2, '2 ggr/dag'),
(457, 566, 2, 'Tillbaka'),
(458, 567, 2, 'tillbaka'),
(459, 568, 2, 'Bakåt 8 besök'),
(460, 569, 2, 'Bakåt 11 besök'),
(461, 570, 2, 'Bakåt 5 besök'),
(462, 571, 2, 'Bakåt 4 besök'),
(463, 572, 2, 'Bakåt 9 besök'),
(464, 573, 2, 'Bakåt 1 besök'),
(465, 574, 2, 'Ryggsmärta'),
(466, 575, 2, 'Ryggproblem'),
(467, 576, 2, 'Bakåt 7 besök'),
(468, 577, 2, 'Bakåt 6 besök'),
(469, 578, 2, 'Ryggkirurgi'),
(470, 579, 2, 'Bakåt 10 besök'),
(471, 580, 2, 'Bakåt 3 besök'),
(472, 581, 2, 'Tillbaka till Admin sidan'),
(473, 584, 2, 'Tillbaka till patient'),
(474, 585, 2, 'Tillbaka till användare'),
(475, 586, 2, 'Tillbaka till Visa'),
(476, 587, 2, 'Bakåt 12 besök'),
(477, 588, 2, 'Bakåt 2 besök'),
(478, 589, 2, 'Bakgrunds tjänster'),
(479, 590, 2, 'Backup'),
(480, 591, 2, 'Backup-filen har skapats. Kommer nu skicka till nedladdning.'),
(481, 593, 2, 'Backup genomfört i'),
(482, 594, 2, 'Dålig kontroll'),
(483, 595, 2, 'Dålig fordran'),
(484, 596, 2, 'Bahasa Indonesia'),
(485, 597, 2, 'Bal'),
(486, 598, 2, 'Balans'),
(487, 599, 2, 'balans'),
(488, 600, 2, 'Saldo mängd'),
(489, 601, 2, 'Balanserade skulder'),
(490, 603, 2, 'Bankavdrag'),
(491, 607, 2, 'Basen av femte (5e) Metarsal'),
(492, 608, 2, 'Basen av femte (5e) Metarsal'),
(493, 611, 2, 'Samlingsfaktura'),
(494, 612, 2, 'Samlingskummunikationsverktyg'),
(495, 613, 2, 'Samlingsbetalning inskrivning'),
(496, 614, 2, 'samlingsbetalning'),
(497, 615, 2, 'Batchprocess påbörjad, detta kan ta ett tag.'),
(498, 616, 2, 'Samlingsresultat'),
(499, 617, 2, 'BatchCom'),
(500, 619, 2, 'För att ID inte existerar'),
(501, 620, 2, 'Starta'),
(502, 621, 2, 'Startdatum'),
(503, 623, 2, 'Tjänstens startdatum åååå-mm-dd'),
(504, 624, 2, 'Start klockslag för kalenderhändelse'),
(505, 626, 2, 'Rapningar'),
(506, 628, 2, 'Bengali'),
(507, 630, 2, 'Mellan'),
(508, 633, 2, 'Bilateral'),
(509, 634, 2, 'Bilaterala:'),
(510, 636, 2, 'Faktura datuma:'),
(511, 637, 2, 'Faktura'),
(512, 638, 2, 'Fakturerade'),
(513, 640, 2, 'Fakturering'),
(514, 641, 2, 'Fakturering (skriv alternativ)'),
(515, 642, 2, 'Fakturering attestera'),
(516, 644, 2, 'Betalningskod för begärd service'),
(517, 645, 2, 'Betalningskoder'),
(518, 646, 2, 'Faktureringsdata'),
(519, 647, 2, 'Fakturering avdelning'),
(520, 648, 2, 'Fakturering Klinik'),
(521, 649, 2, 'Faktureringsinformation'),
(522, 650, 2, 'Faktureringsadress'),
(523, 655, 2, 'Fakturaansvarig'),
(524, 656, 2, 'Faktura Anmärkning'),
(525, 657, 2, 'Fakturera anmärkning för '),
(526, 658, 2, 'Fakturera notering:'),
(527, 659, 2, 'Fakturera kö resultat:'),
(528, 660, 2, 'Faktureringsrapport'),
(529, 661, 2, 'Faktura status'),
(530, 662, 2, 'Faktura status = Ej skickad'),
(531, 663, 2, 'fakturera till '),
(532, 665, 2, 'Biopsi'),
(533, 666, 2, 'Födelsedatum'),
(534, 667, 2, 'Födelse – 24 månader'),
(535, 669, 2, 'Svart'),
(536, 670, 2, 'Sotlunga'),
(537, 671, 2, 'Afrikans amerikan'),
(538, 672, 2, 'Cancer i urinblåsan'),
(539, 673, 2, 'Infektioner i urinblåsan'),
(540, 674, 2, 'Blankt formulär'),
(541, 675, 2, 'Problem med blödning'),
(542, 676, 2, 'Blinda punkter'),
(543, 677, 2, 'Svullnad'),
(544, 678, 2, 'Blockerade'),
(545, 679, 2, 'Blod'),
(546, 680, 2, 'Blodtryck'),
(547, 681, 2, 'Blodtryck'),
(548, 682, 2, 'Näsblod'),
(549, 683, 2, 'Blått kors blå sköld'),
(550, 684, 2, 'Blå linjerna i denna rapport är informativa. Svarta linjer visar tidigare information. Gröna linjerna visar förändringar som tillämpats framgångsrikt. Röda linjer visar fel eller förändringar som inte har genomförts, och dessa måste behandlas manuellt. För närvarande nekas fordringar och betalning reverseringar inte hanteras automatiskt och det kommer att visas i rött.'),
(551, 685, 2, 'Dimsyn'),
(552, 686, 2, 'BMI'),
(553, 687, 2, 'BMI status'),
(554, 689, 2, 'kroppsregion'),
(555, 690, 2, 'Bkroppsdel'),
(556, 691, 2, 'Kroppsdel, om tillämplig'),
(557, 692, 2, 'Benömhet:'),
(558, 693, 2, 'Benömhet: Malleoulus Medialis'),
(559, 694, 2, 'Logisk'),
(560, 697, 2, 'Båda öronen'),
(561, 698, 2, 'båda öronen'),
(562, 699, 2, 'Botten'),
(563, 701, 2, 'RUTA 10 A. Anställningsrelaterad '),
(564, 702, 2, 'RUTA 10 B. Bilolycka '),
(565, 703, 2, 'RUTA 10 C. Övriga olyckor '),
(566, 706, 2, 'Ruta 15. Datum för samma eller liknande sjukdom (åååå-mm-dd)'),
(567, 708, 2, 'FÄLT 16. Datum, oförmögen till arbete från (åååå-mm-dd):'),
(568, 709, 2, 'FÄLT 16. Datum, oförmögen att arbeta tills (åååå-mm-dd):'),
(569, 710, 2, 'FÄLT 18. Sjukhusvistelse datum, från (åååå-mm-dd): '),
(570, 711, 2, 'FÄLT 18. Sjukhusvistelse till, datum (åååå-mm-dd): '),
(571, 712, 2, 'FÄLT 20. Används externt lab?'),
(572, 713, 2, 'Fält 22. Medicaid återinskickningskod (ICD-9) '),
(573, 714, 2, 'Fält 23. Tidigare godkännande nr. '),
(574, 715, 2, 'Blodtryck'),
(575, 716, 2, 'BT Diastoliskt'),
(576, 717, 2, 'BT Systoliskt'),
(577, 719, 2, 'BT Diastoliskt'),
(578, 721, 2, 'BT Systoliskt'),
(579, 722, 2, 'Brasiliansk portugisiska'),
(580, 723, 2, 'Bröst'),
(581, 724, 2, 'Bröst Biopsi'),
(582, 725, 2, 'Bröst Avsluta'),
(583, 726, 2, 'Bröstsjukdom'),
(584, 727, 2, 'Bröstundersökning'),
(585, 728, 2, 'Bröstvävnad'),
(586, 730, 2, 'Andningsljud:'),
(587, 732, 2, 'Brutna ben'),
(588, 734, 2, 'Bronkit Formulär'),
(589, 735, 2, 'Bläddra'),
(590, 736, 2, 'Bläddra efter journal'),
(591, 737, 2, 'Blåmärken / hematom'),
(592, 739, 2, 'Utbuktningen Höger:'),
(593, 741, 2, 'Sveda vid vattenkastning'),
(594, 742, 2, 'Sveda vid vattenkastning'),
(595, 744, 2, 'Upptagen'),
(596, 745, 2, 'ännu ej behandlad'),
(597, 746, 2, 'Skinka'),
(598, 747, 2, 'Skinkan och SI-led'),
(599, 748, 2, 'via'),
(600, 749, 2, 'via'),
(601, 750, 2, 'via munnen'),
(602, 751, 2, 'Genom / Källa'),
(603, 752, 2, 'Av:'),
(604, 753, 2, 'Kopia'),
(605, 754, 2, 'CA certifikat för att verifiera RFS 5425 TLS syslog server'),
(606, 755, 2, 'Cache, livstid (i sekunder)'),
(607, 756, 2, 'Cache template output?'),
(608, 757, 2, 'Kaffe konsumtion'),
(609, 758, 2, 'Kalender'),
(610, 759, 2, 'Kalender sluttid'),
(611, 760, 2, 'Kalender interval'),
(612, 761, 2, 'Kalender skärm'),
(613, 762, 2, 'Kalenderinställningar'),
(614, 763, 2, 'Kalender starttid'),
(615, 764, 2, 'Kalender UI'),
(616, 765, 2, 'Kalendervy'),
(617, 766, 2, 'Anrop till addForm() skriv här. <br>'),
(618, 767, 2, 'Kalorier'),
(619, 768, 2, 'Kambodjan'),
(621, 774, 2, 'Avbryt'),
(622, 775, 2, 'Förkasta ändringar'),
(623, 776, 2, 'Avbruten'),
(624, 777, 2, 'Cancer'),
(625, 778, 2, 'Cancer screening: Colon cancer screening'),
(626, 779, 2, 'Scancer screening: Mammografi'),
(627, 780, 2, 'Cancer screening: Pap smear'),
(628, 781, 2, 'Cancer screening: Prostata cancer'),
(629, 782, 2, 'Det går ej att lägga till detta för att det redan existerar!'),
(630, 783, 2, 'Kan inte lägga till / uppdatera den här posten eftersom duplikat redan finns!'),
(631, 784, 2, 'Kan inte lagra. Kastat.'),
(632, 785, 2, 'kan inte konverteras till JPEG. Kanske ImageMagick inte är installerad?'),
(633, 786, 2, 'Kan inte tas bort. Utan åtgärd.'),
(634, 787, 2, 'kan inte visas online eftersom denna filtyp inte stöds av webbläsaren.'),
(635, 788, 2, 'kan inte visas online eftersom denna filtyp inte stöds av webbläsaren.'),
(636, 789, 2, 'kan inte visas online eftersom den typen inte stöds av webbläsaren.'),
(637, 790, 2, 'Det går inte att skapa'),
(638, 795, 2, 'Kan ej hitta '),
(639, 796, 2, 'Kan ej hitta filnamnet'),
(640, 799, 2, 'Kan inte hitta patienten från SQL-ledgers kundnummer'),
(641, 800, 2, 'Kan ej hitta postscript dokumenthänvisning i '),
(642, 801, 2, 'Kan inte hitta vårdgivaren i SQL-ledger '),
(643, 802, 2, 'Kan inte ändra betalning. Odebiterat belopp är negativt.'),
(644, 803, 2, 'Går inte att öppna '),
(645, 804, 2, 'Kan inte bokföra på försäkring. Betalningsansvarig är patienten.'),
(646, 805, 2, 'Kan inte bokföra på patient. Betalningsansvarig är försäkring.'),
(647, 806, 2, 'Kan inte bokföra betalning. Odebiterat belopp är negativt.'),
(648, 807, 2, 'Kan ej läsa'),
(649, 808, 2, 'Kan ej läsa i mappen'),
(650, 809, 2, 'Kan inte uppdatera eftersom du inte redigerar en befintlig post!'),
(651, 810, 2, 'Stor bokstav'),
(652, 812, 2, 'kapsel'),
(653, 813, 2, 'Kort'),
(654, 814, 2, 'Hjärtkateterisering'),
(655, 815, 2, 'Hjärteko'),
(656, 816, 2, 'Kardiovaskulära'),
(657, 821, 2, 'Brosk / menisk skada'),
(658, 822, 2, 'Broskskada'),
(659, 823, 2, 'Inga karotispulsar. Inga fotpulsar.'),
(660, 824, 2, 'kontanter'),
(661, 825, 2, 'Kontanter'),
(662, 826, 2, 'Kontantbetalning'),
(663, 827, 2, 'Kontantkvitton från vårdgivare'),
(664, 829, 2, 'Kataraktkirurgi'),
(665, 830, 2, 'Katarakt'),
(666, 831, 2, 'Kategorier'),
(667, 832, 2, 'Kategorier av'),
(668, 833, 2, 'Kategori'),
(669, 834, 2, 'kategori'),
(670, 835, 2, 'Kategori '),
(671, 836, 2, 'Kategori Detaljer'),
(672, 837, 2, 'Kategori Gränser'),
(673, 838, 2, 'Kategorinamn'),
(674, 839, 2, 'Kategorinamn är tomt'),
(675, 840, 2, 'Kategori/Titel'),
(676, 841, 2, 'Kaukasisk'),
(677, 842, 2, 'Kvitto på kontaktorsak att skriva för besök. Primär vårdgivar information'),
(678, 852, 2, 'Mobiltelefon'),
(679, 853, 2, 'Mobiltelefon'),
(680, 855, 2, 'Mobiltelefonnummer'),
(681, 856, 2, 'Central Certifiering'),
(682, 857, 2, 'Central/sydamerikan'),
(683, 858, 2, 'CA certifikats fil-mapp kan inte vara tom'),
(684, 859, 2, 'CA nyckelfilsmapp kan inte vara tom'),
(685, 860, 2, 'CA certifikat för att skicka till RFS 5425 TLS syslog server'),
(686, 861, 2, 'Certifikat användare'),
(687, 862, 2, 'Certifikat'),
(688, 864, 2, 'ChampUS'),
(689, 865, 2, 'ChampUSVA'),
(690, 866, 2, 'ändra'),
(691, 867, 2, 'Ändra'),
(692, 868, 2, 'Ändra Aktivitet'),
(693, 869, 2, 'Gick inte ändra. CouchDB fel?'),
(694, 870, 2, 'Synpåverkan'),
(695, 871, 2, 'Synpåverkan'),
(696, 872, 2, 'Byta lösenord'),
(697, 874, 2, 'Ändrad'),
(698, 875, 2, 'Förändrad tarm'),
(699, 876, 2, 'Byter patientidentitet för dokument'),
(700, 877, 2, 'Karaktär'),
(701, 878, 2, 'Tecken kvar'),
(702, 879, 2, 'Avgift'),
(703, 880, 2, 'Justering av avgift'),
(704, 881, 2, 'Avgift kodad'),
(705, 882, 2, 'Avgifter'),
(706, 883, 2, 'Patientkort'),
(707, 884, 2, 'Patientkort aktivitet'),
(708, 885, 2, 'Patientkort Check-in/out Aktivitetsrapport?'),
(709, 886, 2, 'Patientkort ID'),
(710, 887, 2, 'Patientkort ID'),
(711, 889, 2, 'Patientkort placering Aktivitet'),
(712, 890, 2, 'Patientkort notering'),
(713, 891, 2, 'Patientkort nr'),
(714, 892, 2, 'Patientkort lagring placering'),
(715, 893, 2, 'Patientkort spåra'),
(716, 894, 2, 'Patientkort spåra'),
(717, 895, 2, 'Patientkort utcheckning'),
(718, 896, 2, 'Patientkort utcheckning'),
(719, 898, 2, 'Betalningsanvisning'),
(720, 899, 2, 'Betalningsanvisning'),
(721, 900, 2, 'Alla betalningsanvisningar'),
(722, 902, 2, 'Betalningsanvisning belopp'),
(723, 903, 2, 'Betalningsanvisning datum'),
(724, 904, 2, 'Kontrollera skillnader i översättning med översättningstabellen'),
(725, 906, 2, 'checka in till'),
(726, 907, 2, 'Kontrollera indata'),
(727, 909, 2, 'Kontrollera labdata'),
(728, 910, 2, 'Markering betyder påtittat'),
(729, 911, 2, 'Betalningsanvisning nr'),
(730, 912, 2, 'Betalningsanvisning nr'),
(731, 915, 2, 'Betalningsanvisning betalning'),
(732, 916, 2, 'Markera ifall filen är krypterad'),
(733, 917, 2, 'Markera om vårdgivare ska se alla bokade besök som standard och ej enbart deras egna'),
(734, 918, 2, 'Markera för att skapa ''Problem'' utifrån denna diagnos'),
(735, 919, 2, 'Check / EOB Datum:'),
(736, 920, 2, 'Check / EOB Nr:'),
(737, 921, 2, 'Check / Ref Nr'),
(738, 922, 2, 'Check / Referensnummer'),
(739, 923, 2, 'Markeringsrutor lista'),
(740, 924, 2, 'Markeringsrutor lista'),
(741, 925, 2, 'Markeringsruta m text'),
(742, 926, 2, 'Markeringsruta m text'),
(743, 928, 2, 'Markerade fält = ja, tom = nej'),
(744, 929, 2, 'Markerade fält = ja, tom = nej'),
(745, 932, 2, 'Kassa'),
(746, 933, 2, 'Kontrollsumma'),
(747, 934, 2, 'Bröstkorg'),
(748, 935, 2, 'Chest CTAB'),
(749, 936, 2, 'Bröstsmärtor'),
(750, 937, 2, 'Bröstsmärta:'),
(751, 938, 2, 'Bröstsmärtor'),
(752, 940, 2, 'Byt'),
(753, 942, 2, 'Huvudproblem'),
(754, 943, 2, 'Barn'),
(755, 945, 2, 'Barnvaccinations status'),
(756, 946, 2, 'Frossbrytningar'),
(757, 947, 2, 'Kinesiska'),
(758, 948, 2, 'Kinesiska (Förenklad)'),
(759, 949, 2, 'Kinesiska (traditionell)'),
(760, 951, 2, 'Val'),
(761, 952, 2, 'Kolecystektomi'),
(762, 954, 2, 'Kolecystektomi'),
(763, 955, 2, 'Välj'),
(764, 956, 2, 'Välj ett avsnitt och klicka på ett objekt i den ;i den andra sektionen visas relaterade objekt. Klicka på avsnitten om du vill lägga till och ta bort relationer.'),
(765, 957, 2, 'Välj kriteria'),
(766, 959, 2, 'Välj fil'),
(767, 960, 2, 'Välj från lista'),
(768, 962, 2, 'Välj lista'),
(769, 965, 2, 'Välj utskriftsformat för besöksrapport'),
(770, 967, 2, 'Kronisk bronkit'),
(771, 968, 2, 'Kronisk ledvärk'),
(772, 969, 2, 'Kroniska njurbesvär'),
(773, 970, 2, 'Kronisk synovit / utgjutning / ledvärk / gikt'),
(774, 971, 2, 'Kronisk / Återkommande'),
(775, 973, 2, 'Levercirros'),
(776, 974, 2, 'Levercirros'),
(777, 975, 2, 'Stad'),
(778, 976, 2, 'Stadsnamn'),
(779, 977, 2, 'Stad, stat'),
(780, 978, 2, 'Stad, stat postnummer'),
(781, 979, 2, 'Stad / stat'),
(782, 980, 2, 'Begär'),
(783, 981, 2, 'Begär '),
(784, 982, 2, 'Begäran status'),
(785, 984, 2, 'Begäran typ'),
(786, 985, 2, 'Begäran skapade fil'),
(787, 986, 2, 'Begäran skapade fil '),
(788, 987, 2, 'Begäran'),
(789, 988, 2, 'Klassificering'),
(790, 989, 2, 'Rensa'),
(791, 990, 2, 'RENSA AKTIV PATIENT'),
(792, 991, 2, 'Rensa allt'),
(793, 992, 2, 'Rensa HL7 data'),
(794, 993, 2, 'Rensa justering'),
(795, 994, 2, 'Rensa Smarty Cache'),
(796, 996, 2, 'CLIA Antal'),
(797, 997, 2, 'Klicka'),
(798, 998, 2, 'Klicka ''export'' för att exportera din kategori, underkategori, enhet eller innehållsdata till en textfil. Någon likhet mellan denna textfil och en XML-fil är enbart en tillfällighet. Start och sluttaggar måste vara på samma rad, måste vara med små bokstäver och utan mellanrum. För att importera, bläddra efter filen, klicka på ''import''. Om data är helt annorlunda kommer det läggas till existerande data. Om det finns likvärdiga enhetsnamn kommer de gamla att behållas och de nya läggas till med en siffra i slutet av namnet.'),
(799, 999, 2, 'Klicka på en plats på bilden för att lägga till notering. Klicka igen för att ta bort den.'),
(800, 1000, 2, 'Klicka ”Download Certificate” för att ladda ner certifikatet i filen ssl.zip'),
(801, 1001, 2, 'Klicka för mer'),
(802, 1002, 2, 'Klicka för mer detaljer'),
(803, 1003, 2, 'Klicka för att beställa summering'),
(804, 1004, 2, 'Klicka för resultat'),
(805, 1005, 2, 'Klicka här'),
(806, 1006, 2, 'Klicka här för att lägga till patient'),
(807, 1007, 2, 'Klicka här för att lägga till ny skada, byta status och ändra dagliga aktiviteter'),
(808, 1008, 2, 'Klicka här för att välja ett datum'),
(809, 1009, 2, 'Klicka här för att välja datum och klockslag'),
(810, 1010, 2, 'Klicka här för att välja startdatum'),
(811, 1020, 2, 'Klicka här för att söka'),
(812, 1021, 2, 'Klicka här för att uppdatera prioritet, kategori och smeknamn inställningar'),
(813, 1022, 2, 'Klicka här, för att se alla.'),
(814, 1023, 2, 'Klicka här för att se och rita'),
(815, 1025, 2, 'Klicka här för att se och rita all vitalparametrar'),
(816, 1026, 2, 'Klicka här för att se patient detaljer'),
(817, 1027, 2, 'Klicka här för att se alla'),
(818, 1028, 2, 'Klicka här för att se/ändra mer detaljer'),
(819, 1029, 2, 'Klicka ”install” knappen för att installera databas utgåva sedan följande datum'),
(820, 1030, 2, 'Klicka någonstans på tid för att öka'),
(821, 1031, 2, 'Klicka på patientnamn för att öppna patientfilen'),
(822, 1032, 2, 'Klicka ”uppdatera” för att se alla resultat eller var vänlig ange sökkriterier ovan för att se specifika resultat'),
(823, 1033, 2, 'Klicka för att lägga till diagnos'),
(824, 1034, 2, 'Lklicka för att lägga till komponent'),
(825, 1035, 2, 'Klicka för att lägga till konsultation'),
(826, 1037, 2, 'Klicka för att ladda ner'),
(827, 1038, 2, 'Klicka för att ändra'),
(828, 1039, 2, 'Klicka för att ändra beskrivning'),
(829, 1040, 2, 'Klicka för att ändra denna händelse'),
(830, 1041, 2, 'Klicka för att skapa rapporten'),
(831, 1043, 2, 'Klicka för att skriva ut'),
(832, 1044, 2, 'Klicka för att lägga till/ta emot ny lot'),
(833, 1045, 2, 'Klicka för att välja'),
(834, 1046, 2, 'Klicka för att välja'),
(835, 1047, 2, 'Klicka för att välja en industristandard kod för denna åtgärd'),
(836, 1048, 2, 'Klicka för att välja valbar åtgärdskod'),
(837, 1050, 2, 'Klicka för att välja eller byta CVX kod'),
(838, 1051, 2, 'Klicka för att välja eller ändra diagnoser'),
(839, 1052, 2, 'Klicka för att välja eller ändra tjänst kod'),
(840, 1053, 2, 'Klicka för att välja patient'),
(841, 1054, 2, 'Klicka för att välja tillhörande kod'),
(842, 1055, 2, 'Klicka för att välja tjänster att utföra om resultatet är avvikande'),
(843, 1056, 2, 'Klicka för att välja önskad åtgärd'),
(844, 1057, 2, 'Klicka för att sortera'),
(845, 1058, 2, 'Klicka för att visa eller redigera'),
(846, 1059, 2, 'Klicka för att visa eller redigera'),
(847, 1060, 2, 'Klicka för visa/redigera'),
(848, 1061, 2, 'Klicka Uppdatera knappen för att uppdatera databasutgåvan från följande datum'),
(849, 1063, 2, 'Klicka på:'),
(850, 1064, 2, 'Kund certifikat utgångsdatum'),
(851, 1065, 2, 'kund certifikat giltighetsperiod'),
(852, 1066, 2, 'Kundcertifikats giltighet ska vara ett giltigt nummer'),
(853, 1067, 2, 'kund kopia'),
(854, 1069, 2, 'Sammanfattning av kundens sjukdomshistoria'),
(855, 1070, 2, 'Kund namn'),
(856, 1071, 2, 'Kund nummer'),
(857, 1072, 2, 'Kundprofil - Ny kund'),
(858, 1073, 2, 'Kundprofil - Unika kunder'),
(859, 1074, 2, 'Kunder'),
(860, 1075, 2, 'Klinik'),
(861, 1076, 2, 'Klinik kopiera'),
(862, 1077, 2, 'Kliniken Daily Record'),
(863, 1078, 2, 'Klinik ID'),
(864, 1079, 2, 'Klinisk'),
(865, 1080, 2, 'Kliniskt beslutsstöd Påminnelsehantering'),
(866, 1081, 2, 'Anamnes'),
(867, 1083, 2, 'Klinisk planering'),
(868, 1084, 2, 'Kliniska kvalitetskrav'),
(869, 1087, 2, 'Klinikens påminnelser'),
(870, 1088, 2, 'Klinikens rapporter'),
(871, 1089, 2, 'Kliniskt beslutsstöd Kategorier'),
(872, 1090, 2, 'Kliniskt beslutsstöd Enheter'),
(873, 1091, 2, 'Kliniskt beslutsstöd Urvalsfunktioner'),
(874, 1092, 2, 'Kliniskt beslutsstöd Mål metoder'),
(875, 1093, 2, 'Kliniskt beslutsstöd Enheter'),
(876, 1094, 2, 'Kliniskt beslutsstöd ålders intervaller'),
(877, 1095, 2, 'Kliniskt beslutsstöd jämförelser'),
(878, 1096, 2, 'Kliniskt beslutsstöd Typer av besök'),
(879, 1097, 2, 'Kliniskt beslutsstöd Påminnelser giltighet inställningar'),
(880, 1098, 2, 'Kliniskt beslutsstöd Påminnelser inaktiveringsinställningar'),
(881, 1099, 2, 'Kliniskt beslutsstöd påminnelser intervaller'),
(882, 1100, 2, 'Kliniskt beslutsstöd påminnelser metoder'),
(883, 1101, 2, 'Kliniskt beslutsstöd Mål intervaller'),
(884, 1102, 2, 'Kliniska mål'),
(885, 1103, 2, 'Kliniskt begrepp'),
(886, 1104, 2, 'Kliniska begrepp koder'),
(887, 1106, 2, 'Kliniskt verksamma'),
(888, 1107, 2, 'Kopiera'),
(889, 1108, 2, 'Kopiera tidigare besök'),
(890, 1109, 2, 'Stäng'),
(891, 1111, 2, 'Stäng fönstret'),
(892, 1112, 2, 'Stängt'),
(893, 1113, 2, 'cm'),
(894, 1114, 2, 'CMS 1500 marginal'),
(895, 1118, 2, 'CMS-id'),
(896, 1127, 2, 'CN2-12 intakta'),
(897, 1128, 2, 'Medbetalare'),
(898, 1129, 2, 'Medbetalare Betalning'),
(899, 1130, 2, 'Medbetalare'),
(900, 1131, 2, 'Kod'),
(901, 1132, 2, 'kod'),
(902, 1133, 2, 'Kodsökare'),
(903, 1134, 2, 'Kod måste vara två bokstäver (små bokstäver)'),
(904, 1135, 2, 'Kod eller symbol för att ange valuta'),
(905, 1136, 2, 'Kod text'),
(906, 1138, 2, 'Kod typer'),
(907, 1141, 2, 'Kod typer'),
(908, 1142, 2, 'Koder'),
(909, 1143, 2, 'Kodad'),
(910, 1144, 2, 'Koder'),
(911, 1145, 2, 'Kodning'),
(912, 1147, 2, 'Kodning – alla besök (skriv, med valbara alternativ)'),
(913, 1148, 2, 'Kodning – mina besök (skriv, med valbara alternativ)'),
(914, 1149, 2, 'Kodning ej godkänd'),
(915, 1150, 2, 'Kaffe'),
(916, 1152, 2, 'Med-försäkring'),
(917, 1153, 2, 'Förf.saml w / o'),
(918, 1154, 2, 'Komprimera alla'),
(919, 1155, 2, 'Komprimera alla'),
(920, 1156, 2, 'Komprimera alla'),
(921, 1157, 2, 'Komprimera alla'),
(922, 1158, 2, 'Komprimera alla'),
(923, 1160, 2, 'samlings datum'),
(924, 1161, 2, 'Samlingar'),
(925, 1162, 2, 'Samlingsrapport'),
(926, 1163, 2, 'Koloncancer'),
(927, 1164, 2, 'Koloncancer screening'),
(928, 1165, 2, 'Koloncancer Kirurgi'),
(929, 1166, 2, 'Koloskopi'),
(930, 1167, 2, 'Koloskopi'),
(931, 1168, 2, 'Färg'),
(932, 1169, 2, 'Färg förkortning'),
(933, 1170, 2, 'Kolumn'),
(934, 1171, 2, 'Kolumner'),
(935, 1172, 2, 'Slå ihop grupper'),
(936, 1173, 2, 'Komma'),
(937, 1174, 2, 'Kommentar'),
(938, 1175, 2, 'Kommentarer'),
(939, 1176, 2, 'Kommentarer om detta resultat eller rekomendation'),
(940, 1177, 2, 'Commercial Insurance Co'),
(941, 1178, 2, 'Godkänn Ändringar'),
(942, 1180, 2, 'Förbindelser'),
(943, 1182, 2, 'Företag'),
(944, 1183, 2, 'Företag namn'),
(945, 1184, 2, 'Komplett'),
(946, 1186, 2, 'Avslutat'),
(947, 1188, 2, 'Klar?'),
(948, 1190, 2, 'Komplikationer orsakade av vårdgivare'),
(949, 1191, 2, 'Abortkomplikationer'),
(950, 1192, 2, 'Enheter'),
(951, 1193, 2, 'Datorstödd Medicinskt beställningssystem'),
(952, 1194, 2, 'Slutsatser'),
(953, 1199, 2, 'Inställningar'),
(954, 1200, 2, 'Inställningar import/export'),
(955, 1202, 2, 'Konfigurera Apache och open EMR för att använda klient SSL certifikat'),
(956, 1203, 2, 'Konfigurera Apache att använda Klient SSL certifikat'),
(957, 1204, 2, 'Konfigurera apache för att använda HTTPS'),
(958, 1205, 2, 'Konfigurera LIBREEHR för att använda Klient SSL certifikat'),
(959, 1208, 2, 'Bekräfta Skapa ny patient'),
(960, 1209, 2, 'Bekräfta Nytt lösenord'),
(961, 1210, 2, 'Bekräfta Betalning'),
(962, 1214, 2, 'Medfödd'),
(963, 1215, 2, 'Konjunktiva, pupiller'),
(964, 1217, 2, 'Sammanbindningar'),
(965, 1218, 2, 'Konstant'),
(966, 1219, 2, 'Konstant namn'),
(967, 1220, 2, 'Konstantnamn är tomt'),
(968, 1221, 2, 'Konstanter'),
(969, 1222, 2, 'Förstoppning'),
(970, 1223, 2, 'Konstitutionella'),
(971, 1226, 2, 'Konsultation, kortfattad beskrivning'),
(972, 1227, 2, 'Kontakt'),
(973, 1228, 2, 'E-postadress'),
(974, 1229, 2, 'Epostadresser'),
(975, 1230, 2, 'Kontakta EMR direkt för att prenumerera på phiMail Direct meddelande service'),
(976, 1231, 2, 'Kontaktinformation'),
(977, 1232, 2, 'Kontaktlinser'),
(978, 1233, 2, 'Contact Medical Information Integration, LLC at http://mi-squared.com for Lab Exchange Service.'),
(979, 1234, 2, 'Contact Medical Information Integration, LLC at http://mi-squared.com or ZH Healthcare at http://zhservices.com for subscribing the eRx service'),
(980, 1236, 2, 'Kontaktnamn'),
(981, 1237, 2, 'Kontaktperson'),
(982, 1239, 2, 'Kontakttelefonnummer'),
(983, 1240, 2, 'Contact ZMG, LLC (zmghealth@gmail.com) for subscribing the eRx service'),
(984, 1241, 2, 'Innehåller minst tre av följande fyra enheter:'),
(985, 1242, 2, 'Behållare Gruppnamn'),
(986, 1243, 2, 'Innehåll'),
(987, 1244, 2, 'innehåll'),
(988, 1245, 2, 'Sammanhang'),
(989, 1246, 2, 'Sammanhangsnamn kan inte vara tomt'),
(990, 1247, 2, 'Fortsätt'),
(991, 1248, 2, 'Vårdplanerings dokument'),
(992, 1249, 2, 'Vårdplanering'),
(993, 1250, 2, 'kontraindikationer'),
(994, 1251, 2, 'Preventivmedel'),
(995, 1252, 2, 'Preventivmedelsproblematik'),
(996, 1253, 2, 'Preventivmedelsproblematik (specificera)'),
(997, 1254, 2, 'Preventivmedel Metod'),
(998, 1255, 2, 'Preventivmedel'),
(999, 1256, 2, 'Preventivmedel, tjänster som tidigare startats'),
(1000, 1257, 2, 'Preventivmedel start'),
(1001, 1258, 2, 'Kontrollnummer'),
(1002, 1259, 2, 'Kontrollnummer'),
(1003, 1261, 2, 'medbetalare'),
(1004, 1262, 2, 'Medbetalare'),
(1005, 1263, 2, 'Medbetalare'),
(1006, 1264, 2, 'medbetalare nekar'),
(1007, 1266, 2, 'Medbetalare'),
(1008, 1267, 2, 'COPD'),
(1009, 1268, 2, 'Kopiera Sidor till Patientdiagram'),
(1010, 1269, 2, 'Kopiera Värderingar'),
(1011, 1270, 2, 'Kopiera databasfilen. Detta tar en stund...'),
(1012, 1271, 2, 'Upphovsrättsskydd'),
(1013, 1273, 2, 'Coronary Artery Bypass'),
(1014, 1274, 2, 'Coronary Artery Bypass Graft (CABG)'),
(1015, 1275, 2, 'Rättad'),
(1016, 1277, 2, 'CouchDB'),
(1017, 1278, 2, 'Kunde inte ansluta till CouchDB'),
(1018, 1279, 2, 'CouchDB databas'),
(1019, 1280, 2, 'CouchDB databas namn'),
(1020, 1281, 2, 'CouchDB värd'),
(1021, 1282, 2, 'CouchDB värdnamn'),
(1022, 1283, 2, 'CouchDB log på'),
(1023, 1284, 2, 'CouchDB lösenord'),
(1024, 1285, 2, 'CouchDB port'),
(1025, 1286, 2, 'CouchDB port'),
(1026, 1288, 2, 'CouchDB användarnamn'),
(1027, 1289, 2, 'Hosta'),
(1028, 1290, 2, 'Hosta:'),
(1029, 1294, 2, 'Kunde ej läsa fil'),
(1030, 1296, 2, 'Kunde inte skicka e-post på grund av en server problem '),
(1031, 1297, 2, 'Kunde inte skicka e-post på grund av en server problem '),
(1032, 1298, 2, 'Kunde inte skapa backup'),
(1033, 1299, 2, 'Kunde inte ta bort mapp'),
(1034, 1300, 2, 'Kunde inte ta bort gammal backup fil'),
(1035, 1301, 2, 'Kunde inte ta bort gammal export fil'),
(1036, 1302, 2, 'Waran INR kontroll'),
(1037, 1303, 2, 'Couns av metod'),
(1038, 1304, 2, 'Rådgivning'),
(1039, 1305, 2, 'Rådgivning, Aktivitet'),
(1040, 1306, 2, 'svarsremiss, formulär'),
(1041, 1307, 2, 'Nation'),
(1042, 1308, 2, 'Land'),
(1043, 1309, 2, 'Typ av nationsdata'),
(1044, 1310, 2, 'Nationslista'),
(1045, 1311, 2, 'Nationslista'),
(1046, 1312, 2, 'Nationsnamn ska representeras av två bokstäver'),
(1047, 1313, 2, 'Landsting'),
(1048, 1315, 2, 'kupong'),
(1049, 1318, 2, 'CPT'),
(1050, 1319, 2, 'CPT Koder'),
(1051, 1320, 2, 'CPT Koder'),
(1052, 1321, 2, 'CPT4 Åtgärder/Tjänster'),
(1053, 1322, 2, 'CPTII Mått på utförande'),
(1054, 1323, 2, 'Kvalitetscertifikat (GCP)'),
(1055, 1324, 2, 'Sprickor:'),
(1056, 1325, 2, 'kräm'),
(1057, 1326, 2, 'Skapa klient certifikat SSL för varje användare eller dator'),
(1058, 1327, 2, 'Skapa klientcertifikat för antingen användare eller datornamn'),
(1059, 1329, 2, 'Skapa en händelse'),
(1060, 1330, 2, 'Skapa och ladda ner en fullständig backup'),
(1061, 1332, 2, 'Skapa beackup'),
(1062, 1333, 2, 'Skapa grupp'),
(1063, 1334, 2, 'Skapa kientcertifikat'),
(1064, 1335, 2, 'Skapa klient SSL certifikat'),
(1065, 1336, 2, 'Skapa kopia'),
(1066, 1338, 2, 'Skapa backup av händelselog'),
(1067, 1339, 2, 'Skapa ny aktivitet'),
(1068, 1340, 2, 'Skapa ny patient'),
(1069, 1342, 2, 'Skapa externa port rättigheter'),
(1070, 1343, 2, 'Skapa interna port rättigheter'),
(1071, 1344, 2, 'Skapa Patientanteckning'),
(1072, 1345, 2, 'Skapa SSL certifikat utgivare och server certifikat'),
(1073, 1346, 2, 'Skapa besök'),
(1074, 1347, 2, 'Skapad'),
(1075, 1348, 2, 'Skapa exportfil'),
(1076, 1350, 2, 'Skapande av fil på värden misslyckades'),
(1077, 1351, 2, 'Skapare'),
(1078, 1352, 2, 'kredit'),
(1079, 1353, 2, 'Kreditkort'),
(1080, 1354, 2, 'Kredit'),
(1081, 1356, 2, 'Kriterier'),
(1082, 1358, 2, 'Crohn''s sjukdom'),
(1083, 1359, 2, 'Chrons sjukdom'),
(1084, 1360, 2, 'export av kommaseparerad lista'),
(1085, 1361, 2, 'Kommaseparerad fil'),
(1086, 1362, 2, 'Kommaseparerad tabell'),
(1087, 1363, 2, 'Kubikmillimeter'),
(1088, 1364, 2, 'Kuban'),
(1089, 1365, 2, 'Valuta decimaler'),
(1090, 1366, 2, 'Valuta decimaltecken'),
(1091, 1367, 2, 'Valutatecken'),
(1092, 1368, 2, 'Valuta tusenseparator'),
(1093, 1369, 2, 'Pågående'),
(1094, 1370, 2, 'Alkohol aktuellt'),
(1095, 1371, 2, 'Pågående konsultation'),
(1096, 1372, 2, 'Aktuella kriterier'),
(1097, 1373, 2, 'Markeringsfärg för aktuell dag'),
(1098, 1374, 2, 'Röker dagligen'),
(1099, 1375, 2, 'Nuvarande filnamn är ändrat till'),
(1100, 1376, 2, 'Använder hash'),
(1101, 1377, 2, 'Nuvarande lokalisation'),
(1102, 1378, 2, 'Aktuell medicinering'),
(1103, 1379, 2, 'Aktuellt lösenord'),
(1104, 1380, 2, 'Pågående patient'),
(1105, 1382, 2, 'Aktuella droger'),
(1106, 1383, 2, 'Tillfällighetsrökare'),
(1107, 1386, 2, 'För närvarande Aktiv'),
(1108, 1387, 2, 'Pågår'),
(1109, 1388, 2, 'Ingen aktuell klinik'),
(1110, 1389, 2, 'Cushing Syndrom'),
(1111, 1390, 2, 'Cushings syndrom'),
(1112, 1392, 2, 'Anpassad'),
(1113, 1393, 2, 'Anpassat input'),
(1114, 1394, 2, 'Anpassad tabell'),
(1115, 1396, 2, 'CVX kod'),
(1116, 1397, 2, 'CVX kod koppling'),
(1117, 1398, 2, 'CVX vaccination'),
(1118, 1400, 2, 'CYP'),
(1119, 1401, 2, 'CYP Factor'),
(1120, 1402, 2, 'CYP Rapport'),
(1121, 1403, 2, 'Tjeckisk'),
(1122, 1404, 2, 'D'),
(1123, 1405, 2, 'D & C'),
(1124, 1406, 2, 'D & E'),
(1125, 1407, 2, 'Födelsedatum'),
(1126, 1408, 2, 'dagligen'),
(1127, 1409, 2, 'Daglig registrering'),
(1128, 1410, 2, 'dansk'),
(1129, 1411, 2, 'Liknande data finns redan i databasen, ändra koden och / eller beskrivning'),
(1130, 1412, 2, 'Liknande data finns redan i databasen, ändra koden och / eller beskrivning'),
(1131, 1413, 2, 'Data kolumner'),
(1132, 1416, 2, 'Data fel'),
(1133, 1420, 2, 'Datattyp'),
(1134, 1421, 2, 'Databas'),
(1135, 1422, 2, 'Databas är inte installerad'),
(1136, 1423, 2, 'databas revision'),
(1137, 1424, 2, 'Databasrapportering'),
(1138, 1425, 2, 'Uppdatering av databas avslutad'),
(1139, 1426, 2, 'Datacols måste ha ett nummer mellan 1 och 999'),
(1140, 1427, 2, 'Datum'),
(1141, 1428, 2, 'DATUM'),
(1142, 1429, 2, 'Hantering av datum och tid'),
(1143, 1431, 2, 'Administreringsdatum'),
(1144, 1432, 2, 'datum och tid för insamling'),
(1145, 1433, 2, 'datum och tid för observation'),
(1146, 1435, 2, 'Datum och tid när provet togs'),
(1147, 1436, 2, 'datum kan inte vara senare än idag'),
(1148, 1437, 2, 'Datum då preventivmeddel insattes för första gången'),
(1149, 1438, 2, 'Skapat datum'),
(1150, 1439, 2, 'Datum avslutad'),
(1151, 1440, 2, 'Förstörd datum'),
(1152, 1441, 2, 'Sätt att visa datum'),
(1153, 1442, 2, 'Datumformat för "mötet slutar" är inte giltigt'),
(1154, 1443, 2, 'Datumformat för "mötet startat "är inte giltig'),
(1155, 1444, 2, 'Datumformat för "Nästa Möte" är inte giltig'),
(1156, 1445, 2, 'Datumformat för "sista besök" är inte giltig'),
(1157, 1446, 2, 'Datumformat för "sista besök" är inte giltig'),
(1158, 1447, 2, 'Datum för vaccinationsinformation'),
(1159, 1448, 2, 'Datum saknas för kod '),
(1160, 1449, 2, 'Huvudsakligt kriterium för datum'),
(1161, 1450, 2, 'Datum för bankinsättning åååå-mm-dd'),
(1162, 1451, 2, 'datum för fakturering'),
(1163, 1452, 2, 'Födelsedatum'),
(1164, 1453, 2, 'Födelsedatum'),
(1165, 1454, 2, 'Födelsedatum'),
(1166, 1455, 2, 'datum för registrering'),
(1167, 1456, 2, 'Datum för skada'),
(1168, 1458, 2, 'Datum för betalning åååå-mm-dd'),
(1169, 1459, 2, 'Remissdatum'),
(1170, 1460, 2, 'Svarsdatum'),
(1171, 1461, 2, 'Rapportdatum'),
(1172, 1462, 2, 'Datum för tjänsten'),
(1173, 1463, 2, 'Datum för tjänst'),
(1174, 1464, 2, 'datum för tjänsten = idag'),
(1175, 1465, 2, 'Datum för tjänst MM / DD / ÅÅÅÅ'),
(1176, 1466, 2, 'Datum för tjänst:'),
(1177, 1467, 2, 'datum för signering'),
(1178, 1468, 2, 'datum för förändrat status'),
(1179, 1469, 2, 'Orderdatum'),
(1180, 1470, 2, 'Rapportdatum'),
(1181, 1471, 2, 'Datum för VIS deklaration'),
(1182, 1472, 2, 'datum beställd'),
(1183, 1475, 2, 'Val av datum'),
(1184, 1476, 2, 'Skickat datum');
INSERT INTO `lang_definitions` VALUES
(1185, 1477, 2, 'Datum då meddelande skickades'),
(1186, 1479, 2, 'datumvärde kan inte vara tomt.'),
(1187, 1480, 2, 'datum/planerat besök'),
(1188, 1481, 2, 'Datum/anteckningar'),
(1189, 1482, 2, 'Datum / Anteckningar, senast'),
(1190, 1483, 2, 'datum/tid'),
(1191, 1484, 2, 'Datum:'),
(1192, 1485, 2, 'Daterad meddelande log'),
(1193, 1486, 2, 'Dag'),
(1194, 1487, 2, 'dag'),
(1195, 1489, 2, 'Överblick dag'),
(1196, 1490, 2, 'Dag (ar)'),
(1197, 1491, 2, 'Dag (ar) M-F'),
(1198, 1492, 2, 'dagar'),
(1199, 1493, 2, 'Dagar'),
(1200, 1494, 2, 'dagar sedan'),
(1201, 1495, 2, 'Dagar och spel Missade'),
(1202, 1496, 2, 'Dagar från förra mötet'),
(1203, 1497, 2, 'Missade dagar'),
(1204, 1498, 2, 'Dagar per Kolumn:'),
(1205, 1500, 2, 'dagar/kolumner'),
(1206, 1501, 2, 'DB installerad'),
(1207, 1502, 2, 'DD/MM/ÅÅÅÅ'),
(1208, 1503, 2, 'Avidentifiering'),
(1209, 1504, 2, 'Avidentifiering komplett'),
(1210, 1505, 2, 'Avidentifiering pågår'),
(1211, 1506, 2, 'Avidentifiering påpbörjad och sker i bakgrunden'),
(1212, 1507, 2, 'Avidentifiering kanske inte är komplett'),
(1213, 1508, 2, 'Avidentifierade filer sparas i'),
(1214, 1509, 2, 'Läkemedelsverket (DEA)'),
(1215, 1511, 2, 'Döv'),
(1216, 1512, 2, 'Debuginformation'),
(1217, 1514, 2, 'Debugging'),
(1218, 1515, 2, 'Dec'),
(1219, 1516, 2, 'Avslutad'),
(1220, 1517, 2, 'December'),
(1221, 1518, 2, 'Decimal pound eller pound/ounces delas med # (ex 5#4)'),
(1222, 1520, 2, 'Avdragsgill'),
(1223, 1521, 2, 'Genomförda avdrag'),
(1224, 1522, 2, 'Standard'),
(1225, 1523, 2, 'Standard Kalender vy'),
(1226, 1524, 2, 'Standard Besöksformulär Id'),
(1227, 1526, 2, 'Standard Klinik'),
(1228, 1527, 2, 'Standardspråk'),
(1229, 1528, 2, 'Standardspråk ifall inget annat är tillåtet eller valt'),
(1230, 1529, 2, 'Standardlista'),
(1231, 1530, 2, 'Standardmetod'),
(1232, 1531, 2, 'Standard tid för lösenords giltighet'),
(1233, 1532, 2, 'Standardtid för lösenords giltighetstid. 0 innebär oändlig giltighet.'),
(1234, 1533, 2, 'Standard patient land'),
(1235, 1535, 2, 'Standard prioritet'),
(1236, 1536, 2, 'Standard vårdgivare'),
(1237, 1537, 2, 'Standard range'),
(1238, 1538, 2, 'Standard kontaktorsak'),
(1239, 1540, 2, 'Standard inställningar'),
(1240, 1541, 2, 'Normalt status för ''Nytt fönster'' markering i patientlistan'),
(1241, 1542, 2, 'Standardmall'),
(1242, 1546, 2, 'Standard enhet'),
(1243, 1547, 2, 'Standardvärde'),
(1244, 1548, 2, 'Standard lager'),
(1245, 1549, 2, 'Standard X12 Partner'),
(1246, 1550, 2, 'Default / Global'),
(1247, 1551, 2, 'Ta bort'),
(1248, 1552, 2, 'Ta bort'),
(1249, 1553, 2, 'Fördröjd Återkommande (> 12 mån)'),
(1250, 1554, 2, 'Ta bort'),
(1251, 1555, 2, 'ta bort'),
(1252, 1556, 2, 'Radera Kategorier med ID (s): '),
(1253, 1557, 2, 'Radera katogori'),
(1254, 1559, 2, 'Kunde ej radera!'),
(1255, 1560, 2, 'Ta bort grupp'),
(1256, 1561, 2, 'Ta bort lista'),
(1257, 1562, 2, 'Radera Sidor'),
(1258, 1563, 2, 'Ta bort patient, Möte, Formulär, Ämne, Dokument, Betalning, Fakturering eller transaktionstryck'),
(1259, 1565, 2, 'Ta bort rad'),
(1260, 1566, 2, 'Ta bort markerade enheter'),
(1261, 1568, 2, 'Borttagning OK'),
(1262, 1569, 2, 'Radera detta dokument'),
(1263, 1570, 2, 'Radera detta formulär'),
(1264, 1571, 2, 'Radera denna anteckning'),
(1265, 1573, 2, 'Borttagning OK'),
(1266, 1574, 2, 'Ta bort'),
(1267, 1575, 2, 'Borttagen händelse kan inte återskapas. Är du säker på att du vill ta bort händelsen?'),
(1268, 1576, 2, 'Leverans bekräftad'),
(1269, 1578, 2, 'Leverans är inte tillåten till specificerad direkt adress.'),
(1270, 1580, 2, 'Leverans av bifogat kliniskt dokument var begärt av patienten'),
(1271, 1581, 2, 'Demens'),
(1272, 1582, 2, 'Demografi'),
(1273, 1583, 2, 'Demografi'),
(1274, 1585, 2, 'Demografi filter kriterier'),
(1275, 1586, 2, 'Demografi ej auktoriserad'),
(1276, 1587, 2, 'Demografi ej auktoriserad'),
(1277, 1588, 2, 'Nekad'),
(1278, 1589, 2, 'Nämnare'),
(1279, 1590, 2, 'Dental'),
(1280, 1591, 2, 'Tandvård ärende lista'),
(1281, 1592, 2, 'Tandvårds ärenden'),
(1282, 1595, 2, 'Beroende på vilken typ av räkning som testas kommer man kunna se HCFA liknande utskrift på blankt papper om HFCA-räkning testas, flera rader med blurrig text och information ifall X12-claim testas. Denna text är X12 EDI 4010A format. Ibland ser man udda konstiga tecken som liknar små figurer. Detta är kontrolltecken för sidmatning mm och det är helt normalt.'),
(1283, 1596, 2, 'Insättningsdatum'),
(1284, 1597, 2, 'Insättningsdatum kan inte vara senare än idag.'),
(1285, 1598, 2, 'Insättning Datum:'),
(1286, 1599, 2, 'Deprimerad'),
(1287, 1600, 2, 'Depression'),
(1288, 1602, 2, 'Beskrivning'),
(1289, 1603, 2, 'beskrivning'),
(1290, 1605, 2, 'Beskrivning av upptäckten'),
(1291, 1606, 2, 'Beskrivning av åtgärden eller resultatkod'),
(1292, 1607, 2, 'Beskrivning översättning'),
(1293, 1609, 2, 'Mål'),
(1294, 1610, 2, 'Målfilnamn'),
(1295, 1611, 2, 'Förstör Parti'),
(1296, 1612, 2, 'Förstör ...'),
(1297, 1613, 2, 'Förstörd'),
(1298, 1614, 2, 'Förstörda läkemedel'),
(1299, 1615, 2, 'Förstöras narkotika Rapport'),
(1300, 1616, 2, 'Detalj'),
(1301, 1617, 2, 'Detaljer'),
(1302, 1619, 2, 'Utvecklingsstörning'),
(1303, 1620, 2, 'Diabetes'),
(1304, 1621, 2, 'Diabetes Mellitus'),
(1305, 1622, 2, 'Diabetes: Blodtryckskontroll'),
(1306, 1623, 2, 'Diabetes: Ögonundersökning'),
(1307, 1624, 2, 'Diabetes: Ögonundersökning'),
(1308, 1625, 2, 'Diabetes: Fotundersökning'),
(1309, 1626, 2, 'Diabetes: Fotundersökning'),
(1310, 1627, 2, 'Diabetes: HbA1c dåligt reglerat'),
(1311, 1628, 2, 'Diabetes: HbA1c'),
(1312, 1629, 2, 'Diabetes: Blodfetter'),
(1313, 1630, 2, 'Diabetes: Urin microalbumin'),
(1314, 1631, 2, 'Diag'),
(1315, 1632, 2, 'Diagnoser'),
(1316, 1633, 2, 'Diagnos'),
(1317, 1634, 2, 'Diagnoskod'),
(1318, 1636, 2, 'Diagnos datum'),
(1319, 1637, 2, 'Diagnos måste kodas in i ett länkat patientmöte'),
(1320, 1638, 2, 'Diagnos namn'),
(1321, 1639, 2, 'Diagnos rapport'),
(1322, 1640, 2, 'Diagnos rapport'),
(1323, 1641, 2, 'Diagnos rapport enbart'),
(1324, 1642, 2, 'Diagnos titel'),
(1325, 1643, 2, 'Diagnos:'),
(1326, 1644, 2, 'Diagnos: '),
(1327, 1645, 2, 'Diagnostiska tester:'),
(1328, 1646, 2, 'Skala'),
(1329, 1647, 2, 'Membran/kapsel'),
(1330, 1648, 2, 'Diarée'),
(1331, 1650, 2, 'Diktat'),
(1332, 1651, 2, 'Diktat: '),
(1333, 1652, 2, 'Fick du en kopia av denna HIPAA notering?'),
(1334, 1653, 2, 'Diffus'),
(1335, 1654, 2, 'Digitalt signerad'),
(1336, 1657, 2, 'Direkt mail'),
(1337, 1658, 2, 'Log på direktmeddelande'),
(1338, 1659, 2, 'Direkt meddelande mottaget'),
(1339, 1660, 2, 'Direkt meddelande ej tillgängligt'),
(1340, 1661, 2, 'Kunde ej skicka direkt meddelande'),
(1341, 1663, 2, 'Arbetsledare, namn'),
(1342, 1664, 2, 'Kunde ej ta bort mapp. Fortsätt'),
(1343, 1665, 2, 'Funktionshinder'),
(1344, 1667, 2, 'Stäng av kalender'),
(1345, 1668, 2, 'Stäng av spårning av patientkort'),
(1346, 1669, 2, 'Stäng av vaccination'),
(1347, 1670, 2, 'Stäng av gammal metrisk vitala tecken formulär'),
(1348, 1672, 2, 'Stäng av phpMyAdmin'),
(1349, 1673, 2, 'Stäng av receptförskrivning'),
(1350, 1674, 2, 'Stäng av användargrupp'),
(1351, 1675, 2, 'funktionshindrade'),
(1352, 1676, 2, 'Funktionshindrade'),
(1353, 1677, 2, 'Handikappad under 65 år med LGHP-försäkring'),
(1354, 1678, 2, 'Disk'),
(1355, 1681, 2, 'Utskrivning'),
(1356, 1682, 2, 'Flytningar från urinröret'),
(1357, 1684, 2, 'Rätt utskriven'),
(1358, 1685, 2, 'Rätt utskriven'),
(1359, 1688, 2, 'Utskriven'),
(1360, 1689, 2, 'Kvitto information'),
(1361, 1690, 2, 'Kvitto typ'),
(1362, 1691, 2, 'Kvitton typer'),
(1363, 1692, 2, 'Kvitton'),
(1364, 1694, 2, 'Rabatt'),
(1365, 1695, 2, 'Rabatt Belopp'),
(1366, 1696, 2, 'Rabatt nivå'),
(1367, 1697, 2, 'Rabatt procent'),
(1368, 1698, 2, 'Rabatt som belopp'),
(1369, 1699, 2, 'Rabatt vid checkout skrivs in som belopp i stället för som procent'),
(1370, 1700, 2, 'Diskreta resultat'),
(1371, 1701, 2, 'Sjukdom'),
(1372, 1702, 2, 'Förskjutning'),
(1373, 1703, 2, 'Antal:'),
(1374, 1704, 2, 'Skicka i väg'),
(1375, 1705, 2, 'Skicka mottagna dokument'),
(1376, 1706, 2, 'Utlämnad'),
(1377, 1707, 2, 'Visa avancerade inställningar på demografisidan'),
(1378, 1709, 2, 'Visa händelsedatum i blocket?'),
(1379, 1710, 2, 'Visa format får US vikter?'),
(1380, 1711, 2, 'Visa hur många händelser?'),
(1381, 1713, 2, 'Visa plats i blocket?'),
(1382, 1714, 2, 'Visa namn'),
(1383, 1715, 2, 'Visa kalender?'),
(1384, 1718, 2, 'Display dagens händelser i blocket?'),
(1385, 1719, 2, 'Visa ämne i blocket?'),
(1386, 1720, 2, 'Visa kommande händelser i blocket?'),
(1387, 1721, 2, 'Visa kommande händelser i blocket?'),
(1388, 1722, 2, 'Visa följande antal av de senaste meddelandena.'),
(1389, 1723, 2, 'Visa följande antal av senaste noteringarna'),
(1390, 1724, 2, 'Visa följande antal av de senaste noteringarna'),
(1391, 1725, 2, 'Distrubition'),
(1392, 1726, 2, 'Distribution'),
(1393, 1727, 2, 'Leverantör'),
(1394, 1729, 2, 'Divertikulit'),
(1395, 1730, 2, 'Divertikulit kirurgi'),
(1396, 1731, 2, 'Divertikulit'),
(1397, 1732, 2, 'Divertikulit Kirurgi'),
(1398, 1733, 2, 'Skild'),
(1399, 1734, 2, 'Yrsel:'),
(1400, 1735, 2, 'Ändra inte'),
(1401, 1737, 2, 'Visa inte Allergi uppladdad till NewCrop'),
(1402, 1739, 2, 'Visa inte medicinering uppladdad till NewCrop'),
(1403, 1742, 2, 'Visa inte kalender'),
(1404, 1744, 2, 'Lagra och sälj inga produkter'),
(1405, 1745, 2, 'Kräv inte att patientanteckningar blir godkända'),
(1406, 1746, 2, 'Inte HLR beslut'),
(1407, 1747, 2, 'spara inte'),
(1408, 1748, 2, 'ersätt inte'),
(1409, 1749, 2, 'gör ingenting'),
(1410, 1751, 2, 'Vill du verkligen radera?'),
(1411, 1752, 2, 'Vill du verkligen radera detta urval?'),
(1412, 1753, 2, 'Vill du verkligen ta bort den här gruppen'),
(1413, 1755, 2, 'Vill du fortsätta?'),
(1414, 1756, 2, 'Vill du ta bort detta?'),
(1415, 1757, 2, 'Vill du ta bort?'),
(1416, 1758, 2, 'Vill du ta bort denna post?'),
(1417, 1759, 2, 'Vill du fortsätta att lägga till den nya patienten?'),
(1418, 1760, 2, 'Vill du fortsätta med det nya namnet?'),
(1419, 1761, 2, 'Vill du PERMANENT ta bort vaccinationsregistreringen?'),
(1420, 1762, 2, 'Födelsedatum'),
(1421, 1763, 2, 'Födelsedatum saknas, ange om möjligt'),
(1422, 1764, 2, 'Dokument'),
(1423, 1765, 2, 'Läkare'),
(1424, 1766, 2, 'Läkare:'),
(1425, 1767, 2, 'Läkares namn och underskrift'),
(1426, 1768, 2, 'Dokument'),
(1427, 1769, 2, 'dokument'),
(1428, 1770, 2, 'Dokument Kategorier'),
(1429, 1775, 2, 'Dokument kan inte flyttas till patienten id'),
(1430, 1777, 2, 'Dokument Datum'),
(1431, 1778, 2, 'Dokumentets datum och utförande uppdaterats'),
(1432, 1779, 2, 'Dokument id'),
(1433, 1780, 2, 'Dokument är flyttat till ny kategori'),
(1434, 1781, 2, 'Dokument är flyttat till patienten id'),
(1435, 1783, 2, 'Dokument kontrollerat'),
(1436, 1784, 2, 'Sätt att lagra dokument'),
(1437, 1785, 2, 'Namnbyte av dokument lyckats'),
(1438, 1790, 2, 'Dokument/avbildning lagrad'),
(1439, 1791, 2, 'Dokument'),
(1440, 1792, 2, 'Dokument (skriva, tilllägg frivilligt)'),
(1441, 1794, 2, 'Inskrivningsdatum'),
(1442, 1796, 2, 'stämmer inte med PV1 besöksnummer'),
(1443, 1797, 2, 'Verkar inte giltig'),
(1444, 1798, 2, 'Tillåter denna typ relaterade koder?'),
(1445, 1799, 2, 'Sambo'),
(1446, 1800, 2, 'Spara inte'),
(1447, 1801, 2, 'Spara inte'),
(1448, 1802, 2, 'Spara inte'),
(1449, 1803, 2, 'Klart'),
(1450, 1804, 2, 'Klar med:'),
(1451, 1805, 2, 'Klar. Skickas för nedladdning'),
(1452, 1806, 2, 'Datum för tjänsten'),
(1453, 1807, 2, 'Dosering'),
(1454, 1809, 2, 'dubbelklicka för att redigera'),
(1455, 1810, 2, 'Dubbelseende'),
(1456, 1811, 2, 'Ladda ner'),
(1457, 1814, 2, 'Ladda ner ändå'),
(1458, 1815, 2, 'Ladda ner faktura fil, bokför och markera som skickad.'),
(1459, 1817, 2, 'Ladda ner certifikat'),
(1460, 1818, 2, 'Ladda ner configurationsdata'),
(1461, 1820, 2, 'ladda ner krypterad fil'),
(1462, 1825, 2, 'Ladda ner PDF'),
(1463, 1827, 2, 'Ladda ner utvald redogörelse'),
(1464, 1828, 2, 'Läkarkontroll'),
(1465, 1829, 2, 'Läkarbesök'),
(1466, 1830, 2, 'Dr.'),
(1467, 1831, 2, 'Drag för att flytta'),
(1468, 1832, 2, 'Dribblande'),
(1469, 1833, 2, 'Körkortsnr'),
(1470, 1834, 2, 'Läkemedel'),
(1471, 1835, 2, 'Leta läkemedel'),
(1472, 1836, 2, 'Läkemedelsformulär'),
(1473, 1837, 2, 'Läkemeddels ID saknas!'),
(1474, 1838, 2, 'Läkemedel intervall'),
(1475, 1839, 2, 'Inventarielista, läkemedel'),
(1476, 1840, 2, 'Läkemedelsnamn'),
(1477, 1841, 2, 'Läkemedel administrationssätt'),
(1478, 1845, 2, 'Läkemedel, enheter'),
(1479, 1846, 2, 'Läkemedel'),
(1480, 1847, 2, 'Läkemedel och produkter'),
(1481, 1848, 2, 'Muntorrhet'),
(1482, 1849, 2, 'DSM-4 Diagnos'),
(1483, 1850, 2, 'DT 1'),
(1484, 1851, 2, 'DT 2'),
(1485, 1852, 2, 'DT 3'),
(1486, 1853, 2, 'DT 4'),
(1487, 1854, 2, 'DT 5'),
(1488, 1855, 2, 'DTaP 1'),
(1489, 1856, 2, 'DTaP 2'),
(1490, 1857, 2, 'DTaP 3'),
(1491, 1858, 2, 'DTaP 4'),
(1492, 1859, 2, 'DTaP 5'),
(1493, 1860, 2, 'Förfaller'),
(1494, 1861, 2, 'Förfallodatum'),
(1495, 1862, 2, 'Förfallodatum mm / dd / yyyy eller åååå-mm-dd'),
(1496, 1863, 2, 'Förfallodatum:'),
(1497, 1865, 2, 'Förfaller patienter'),
(1498, 1866, 2, 'Förfaller snart'),
(1499, 1867, 2, 'Förfallostatus'),
(1500, 1868, 2, 'Uppdatera förfallostatus'),
(1501, 1869, 2, 'Dumping LibreEHR database'),
(1502, 1870, 2, 'Dumping LibreEHR web directory tree'),
(1503, 1871, 2, 'Dumping phpGACL database'),
(1504, 1872, 2, 'Dumping phpGACL web directory tree'),
(1505, 1873, 2, 'Dumping SQL-Ledger database'),
(1506, 1874, 2, 'Dumping SQL-Ledger web directory tree'),
(1507, 1875, 2, 'Dubletter kontroll'),
(1508, 1876, 2, 'Dubletter av ID'),
(1509, 1877, 2, 'Dubletter av namn'),
(1510, 1878, 2, 'DUBLETTER VARNING'),
(1511, 1879, 2, 'Varaktig fullmakt'),
(1512, 1880, 2, 'varaktighet'),
(1513, 1881, 2, 'Varaktighet'),
(1514, 1882, 2, 'Holländsk'),
(1515, 1884, 2, 'Dysfagi'),
(1516, 1885, 2, 'Dyspné:'),
(1517, 1886, 2, 'Urinvägsbesvär'),
(1518, 1888, 2, 'E-recept?'),
(1519, 1889, 2, 'E-rapport'),
(1520, 1890, 2, 'E-recept?'),
(1521, 1892, 2, 'Förnya E-recept'),
(1522, 1893, 2, 'Varje mottagare måste själv ange att meddelanden är avslutade'),
(1523, 1894, 2, 'Tidig Återkommande (<2 Mo)'),
(1524, 1895, 2, 'Öron'),
(1525, 1896, 2, 'EKG'),
(1526, 1897, 2, 'Elektronisk begäran'),
(1527, 1898, 2, 'Ödem'),
(1528, 1904, 2, 'Redigera'),
(1529, 1906, 2, 'Redigera allergier'),
(1530, 1907, 2, 'Edit Kategorier'),
(1531, 1909, 2, 'Redigera definitioner'),
(1532, 1910, 2, 'Redigera diagnoser för'),
(1533, 1912, 2, 'Redigera Kliniker'),
(1534, 1914, 2, 'Redigera Klinikinformation'),
(1535, 1917, 2, 'Redigera form'),
(1536, 1920, 2, 'Redigera layout'),
(1537, 1921, 2, 'Redigera lista'),
(1538, 1923, 2, 'Redigera Struktur'),
(1539, 1928, 2, 'Utbildning'),
(1540, 1929, 2, 'Information'),
(1541, 1932, 2, 'Ikraftträdandedatum'),
(1542, 1934, 2, 'Effektivitet'),
(1543, 1936, 2, 'Ejaculation'),
(1544, 1937, 2, 'Armbåge'),
(1545, 1938, 2, 'Problem med armbågen'),
(1546, 1942, 2, 'Elektronisk remiss'),
(1547, 1949, 2, 'Email'),
(1548, 1957, 2, 'E-post från Batchcom'),
(1549, 1958, 2, 'E-postmeddelande'),
(1550, 1961, 2, 'E-post skicka innan'),
(1551, 1962, 2, 'Email, skicka'),
(1552, 1965, 2, 'Epost Ämnesord'),
(1553, 1966, 2, 'Email Text, användbara Tag: *** NAMN ***, dvs Bäste *** NAMN ***'),
(1554, 1971, 2, 'ICE Kontakt'),
(1555, 1972, 2, 'ICE kontaktperson'),
(1556, 1973, 2, 'ICE kontakt telefonnummer'),
(1557, 1974, 2, 'Akut Preventivmedel'),
(1558, 1980, 2, 'ICE Telefon'),
(1559, 1982, 2, 'Emfysem'),
(1560, 1983, 2, 'Anställd'),
(1561, 1984, 2, 'Arbetsgivare'),
(1562, 1985, 2, 'Arbetsgivarens adress'),
(1563, 1986, 2, 'Arbetsgivare Data'),
(1564, 1987, 2, 'Arbetsgivarens namn'),
(1565, 1989, 2, 'Ta bort'),
(1566, 1991, 2, 'Ta bort värdet i "E-tider"'),
(1567, 1992, 2, 'Ta bort värde "Email, skicka"'),
(1568, 1993, 2, 'Ta bort värde i "Email, ämne"'),
(1569, 1994, 2, 'Ta bort i "text"'),
(1570, 1995, 2, 'Ta bort i "Försörjarens namn"'),
(1571, 1996, 2, 'Ta bort i "Lösenord"'),
(1572, 1997, 2, 'Ta bort "SMS tider"'),
(1573, 1998, 2, 'Ta bort "SMS text"'),
(1574, 1999, 2, 'Ta bort värdet i "Användarnamn"'),
(1575, 2068, 2, 'aktiverat'),
(1576, 2071, 2, 'Möte'),
(1577, 2073, 2, 'Patientmöte'),
(1578, 2074, 2, 'patientmöte'),
(1579, 2075, 2, 'Patientmöter '),
(1580, 2086, 2, 'Patientmöte formulär'),
(1581, 2091, 2, 'Patientmöte antal/nummer'),
(1582, 2110, 2, 'Patientmöte har kodats'),
(1583, 2111, 2, 'Patientmöte:'),
(1584, 2113, 2, 'Patientmöten'),
(1585, 2114, 2, 'Patientmöte & Formulär'),
(1586, 2115, 2, 'Patientmöte & Formulär'),
(1587, 2116, 2, 'Encounters inte godkända'),
(1588, 2117, 2, 'Patientmöte, rapport'),
(1589, 2118, 2, 'Patientmöte, avsnitt'),
(1590, 2121, 2, 'Slut'),
(1591, 2122, 2, 'Slutar (åååå-mm-dd): '),
(1592, 2123, 2, 'Slutdatum'),
(1593, 2124, 2, 'Slutdatum'),
(1594, 2127, 2, 'Slutdatum:'),
(1595, 2131, 2, 'Sluttid'),
(1596, 2133, 2, 'Tjänsten slutar åååå-mm-dd'),
(1597, 2137, 2, 'Endokrina'),
(1598, 2138, 2, 'Endoskopi'),
(1599, 2141, 2, 'Engelsk'),
(1600, 2142, 2, 'Engelsk '),
(1601, 2143, 2, 'Engelsk (indien)'),
(1602, 2144, 2, 'Engelsk (standard)'),
(1603, 2147, 2, 'ENT Ansvarsfrihet'),
(1604, 2148, 2, 'ENT Smärta'),
(1605, 2149, 2, 'Skriv en diagnos kod för att utesluta alla fakturor som inte innehåller det'),
(1606, 2165, 2, 'Ange dina sökkriterier ovan'),
(1607, 2168, 2, 'Miljöpåverkan'),
(1608, 2169, 2, 'EOB Data tillträde'),
(1609, 2171, 2, 'EOB Boknings - Instruktioner'),
(1610, 2172, 2, 'EOB Boknings - Faktura'),
(1611, 2173, 2, 'EOB Boknings - Patient Anmärkning'),
(1612, 2174, 2, 'EOB Boknings - Sök'),
(1613, 2176, 2, 'Epilepsi'),
(1614, 2181, 2, 'Radera'),
(1615, 2182, 2, 'Erektion'),
(1616, 2183, 2, 'Fel'),
(1617, 2188, 2, 'Fel i "kön" val'),
(1618, 2189, 2, 'Fel i "HIPAA" val'),
(1619, 2190, 2, 'Fel i "Process" val'),
(1620, 2191, 2, 'Fel i "SMS Gateway" val'),
(1621, 2192, 2, 'Fel i "Sortera efter" val'),
(1622, 2194, 2, 'Fel i JA eller NEJ alternativ'),
(1623, 2205, 2, 'fel under registrering!'),
(1624, 2206, 2, 'Fel vid sparande av fil'),
(1625, 2208, 2, 'Fel vid skrivning till fil'),
(1626, 2211, 2, 'FEL, kunde inte samla in data från servern'),
(1627, 2219, 2, 'FEL: kunde inte öppna table.sql bruten form?'),
(1628, 2225, 2, 'Fel: lösenord matchar inte. Kontrollera din stavning.'),
(1629, 2235, 2, 'Fel'),
(1630, 2242, 2, 'Erythema:'),
(1631, 2247, 2, 'Redan känd patient'),
(1632, 2249, 2, 'Modersmål/tolkspråk'),
(1633, 2250, 2, 'Modersmål/tolkspråk'),
(1634, 2251, 2, 'Modersmål/tolkspråk Lista'),
(1635, 2252, 2, 'ETIN'),
(1636, 2253, 2, 'Händelse'),
(1637, 2254, 2, 'Händelse Begins'),
(1638, 2255, 2, 'Händelse Kategori'),
(1639, 2256, 2, 'Händelse Datum'),
(1640, 2257, 2, 'Händelse, Beskrivning'),
(1641, 2258, 2, 'Händelse, detaljer'),
(1642, 2259, 2, 'Händelsen upprepas ej'),
(1643, 2260, 2, 'Händelse, Varaktighet'),
(1644, 2261, 2, 'Händelsens tid i minuter'),
(1645, 2262, 2, 'Händelse, Avgift'),
(1646, 2263, 2, 'Event Location'),
(1647, 2264, 2, 'Händelsen upprepas varje'),
(1648, 2265, 2, 'Händelsen upprepas den'),
(1649, 2266, 2, 'Händelse börjar timme'),
(1650, 2267, 2, 'Händelserubrik'),
(1651, 2268, 2, 'Händelserubrik'),
(1652, 2269, 2, 'Händelse Website'),
(1653, 2270, 2, 'Händelse'),
(1654, 2271, 2, 'Händelser för'),
(1655, 2272, 2, 'Händelsen öppnas i nytt fönster'),
(1656, 2273, 2, 'Varje'),
(1657, 2274, 2, 'Varje'),
(1658, 2275, 2, 'var 3:e timme'),
(1659, 2276, 2, 'var 4:e timme'),
(1660, 2277, 2, 'var 5:e timme'),
(1661, 2278, 2, 'var 6 timme'),
(1662, 2279, 2, 'var 8 timme'),
(1663, 2280, 2, 'Var fjärde'),
(1664, 2281, 2, 'Varannan'),
(1665, 2282, 2, 'Var tredje'),
(1666, 2283, 2, 'Varje, var andra, var 3:e, etc'),
(1667, 2285, 2, 'Tenta och testresultat'),
(1668, 2286, 2, 'Testresultat'),
(1669, 2290, 2, 'Examination Datum'),
(1670, 2293, 2, 'Exams / Tester'),
(1671, 2295, 2, 'Överdrivet rivande'),
(1672, 2301, 2, 'Övningsmönster'),
(1673, 2302, 2, 'Motions mönster'),
(1674, 2304, 2, 'lämna från Administration'),
(1675, 2311, 2, 'Utökad vy'),
(1676, 2312, 2, 'Förväntad form_mötes.pid att '),
(1677, 2313, 2, 'Utgångsdatum'),
(1678, 2314, 2, 'Utgångsdatum'),
(1679, 2315, 2, 'Förfaller'),
(1680, 2317, 2, 'Exportera'),
(1681, 2318, 2, 'Exportera som CSV'),
(1682, 2327, 2, 'Exportera till CSV'),
(1683, 2328, 2, 'Exportera till externa faktureringssystem'),
(1684, 2329, 2, 'Exponering för andra länder'),
(1685, 2342, 2, 'Extern remiss'),
(1686, 2344, 2, 'Extern remiss?'),
(1687, 2345, 2, 'Externa remisser'),
(1688, 2353, 2, 'F'),
(1689, 2356, 2, 'Kliniker'),
(1690, 2357, 2, 'Klinik'),
(1691, 2358, 2, 'klinik'),
(1692, 2359, 2, 'Klinikadm'),
(1693, 2361, 2, 'Klinikkod'),
(1694, 2365, 2, 'Klinik NPI'),
(1695, 2372, 2, 'Klinik:'),
(1696, 2375, 2, 'Misslyckades'),
(1697, 2390, 2, 'Familjehistoria'),
(1698, 2392, 2, 'Familjehistoria:'),
(1699, 2395, 2, 'Familj Storlek'),
(1700, 2400, 2, 'Fader'),
(1701, 2403, 2, 'Fatigue'),
(1702, 2404, 2, 'Fax'),
(1703, 2409, 2, 'Fax in'),
(1704, 2410, 2, 'Fax ut'),
(1705, 2413, 2, 'Februari'),
(1706, 2415, 2, 'Läkemedel ID'),
(1707, 2417, 2, 'Skatt ID'),
(1708, 2418, 2, 'Avgift'),
(1709, 2419, 2, 'avgift'),
(1710, 2421, 2, 'Avgift blankett'),
(1711, 2423, 2, 'Avgifter'),
(1712, 2424, 2, 'Kvinna'),
(1713, 2426, 2, 'Kvinnliga Kondomer'),
(1714, 2431, 2, 'Kvinna VSC'),
(1715, 2434, 2, 'Feber'),
(1716, 2435, 2, 'Feber:'),
(1717, 2459, 2, 'Filnamn'),
(1718, 2464, 2, 'Fyll här endast om du skickar e-postmeddelande till patienter'),
(1719, 2473, 2, 'Filter'),
(1720, 2475, 2, 'Slutgiltig diagnos'),
(1721, 2476, 2, 'Slutgiltig diagnos av specialist'),
(1722, 2478, 2, 'Finansiella'),
(1723, 2482, 2, 'Financial Review Datum'),
(1724, 2484, 2, 'Hitta'),
(1725, 2485, 2, 'Hitta Ledig'),
(1726, 2486, 2, 'Sök Ledig mötestider'),
(1727, 2487, 2, 'Hitta Patientient'),
(1728, 2489, 2, 'Undersökningsresultat'),
(1729, 2490, 2, 'Undersökningsresultat av specialist'),
(1730, 2491, 2, 'Fin'),
(1731, 2495, 2, 'Första'),
(1732, 2497, 2, 'Första dagen i veckan'),
(1733, 2498, 2, 'Förnamn'),
(1734, 2500, 2, 'Förnamn:'),
(1735, 2503, 2, 'Fitness'),
(1736, 2507, 2, 'Fitness att spela'),
(1737, 2516, 2, 'Influensavaccination'),
(1738, 2517, 2, 'Vätske-och elektrolyt problem'),
(1739, 2520, 2, 'Följa manuellt'),
(1740, 2532, 2, 'Fot'),
(1741, 2533, 2, 'Fotproblem'),
(1742, 2534, 2, 'Fot:'),
(1743, 2537, 2, 'Fotboll Skaderapport'),
(1744, 2538, 2, 'Skotyp'),
(1745, 2539, 2, 'för'),
(1746, 2555, 2, 'för:'),
(1747, 2559, 2, 'Underarm'),
(1748, 2560, 2, 'Formulär'),
(1749, 2564, 2, 'Format'),
(1750, 2567, 2, 'Format felaktigt för NDC'),
(1751, 2572, 2, 'Formulär'),
(1752, 2573, 2, 'Formulär administration'),
(1753, 2576, 2, 'Vidarebefordra Sidor via Fax'),
(1754, 2579, 2, 'Fjärde'),
(1755, 2581, 2, 'Fraktur'),
(1756, 2582, 2, 'Fracture på Navicula'),
(1757, 2583, 2, 'Fracture laterala malleolus'),
(1758, 2584, 2, 'Fracture mediala malleolus'),
(1759, 2593, 2, 'Fre'),
(1760, 2594, 2, 'Fredag'),
(1761, 2595, 2, 'Från'),
(1762, 2599, 2, 'Från:'),
(1763, 2600, 2, 'Från: '),
(1764, 2613, 2, 'Reception'),
(1765, 2614, 2, 'Reception, kvitton'),
(1766, 2615, 2, 'Reception, kvitton, rapport'),
(1767, 2617, 2, 'Frontal Höger:'),
(1768, 2625, 2, 'All utbildning'),
(1769, 2637, 2, 'Gallsten'),
(1770, 2638, 2, 'Game Period'),
(1771, 2639, 2, 'Spel'),
(1772, 2641, 2, 'spel / evenemang'),
(1773, 2644, 2, 'Gastrit'),
(1774, 2646, 2, 'Gastrointestinala'),
(1775, 2647, 2, 'GCAC Statistik Rapport'),
(1776, 2651, 2, 'Kön '),
(1777, 2652, 2, 'Allmänt'),
(1778, 2655, 2, 'Allmänna Tjänstekategori'),
(1779, 2658, 2, 'Skapa och hämta HCFA 1500 papper fordringar'),
(1780, 2659, 2, 'Skapa och hämta X12 parti'),
(1781, 2670, 2, 'Generera Skrivelse angående '),
(1782, 2677, 2, 'Generera rapport'),
(1783, 2682, 2, 'Skapad på'),
(1784, 2683, 2, 'Genererar'),
(1785, 2692, 2, 'Glaukom'),
(1786, 2694, 2, 'Global'),
(1787, 2700, 2, 'gå'),
(1788, 2701, 2, 'Gå'),
(1789, 2712, 2, 'Grad:'),
(1790, 2714, 2, 'Totalsumma'),
(1791, 2715, 2, 'Totalsummor'),
(1792, 2724, 2, 'Grupp'),
(1793, 2729, 2, 'Gruppnummer'),
(1794, 2731, 2, 'Grupp:'),
(1795, 2732, 2, 'Gruppnamn'),
(1796, 2733, 2, 'Grupper och åtkomstkontroller'),
(1797, 2736, 2, 'Droppar'),
(1798, 2746, 2, 'Hematom / blåmärken'),
(1799, 2750, 2, 'Hand + fingrar'),
(1800, 2751, 2, 'Handproblem'),
(1801, 2753, 2, 'Umbäranden w / o'),
(1802, 2761, 2, 'Farliga aktiviteter'),
(1803, 2767, 2, 'han PostCalendar '),
(1804, 2768, 2, 'Huvud'),
(1805, 2772, 2, 'Huvudvärk'),
(1806, 2779, 2, 'Heart Attack'),
(1807, 2781, 2, 'Hjärtsvikt'),
(1808, 2783, 2, 'Hjärtproblem'),
(1809, 2784, 2, 'Hjärtkirurgi'),
(1810, 2785, 2, 'Heart Transplant'),
(1811, 2786, 2, 'Heart:'),
(1812, 2794, 2, 'Längd'),
(1813, 2796, 2, 'Hjälp'),
(1814, 2797, 2, 'hjälp'),
(1815, 2802, 2, 'Hemoglobin'),
(1816, 2805, 2, 'Hepatit'),
(1817, 2813, 2, 'Bråck Reparation'),
(1818, 2814, 2, 'Diskbråck'),
(1819, 2815, 2, 'Herpes'),
(1820, 2817, 2, 'heyyo. du har varit här i '),
(1821, 2822, 2, 'Dolda'),
(1822, 2823, 2, 'Dolda Händelser Administration'),
(1823, 2824, 2, 'Gömma'),
(1824, 2825, 2, 'Dölj detaljer'),
(1825, 2828, 2, 'Göm meny'),
(1826, 2830, 2, 'Göm påminnelser'),
(1827, 2831, 2, 'Göm/Visa kolumner'),
(1828, 2833, 2, 'Hög'),
(1829, 2834, 2, 'Högt blodtryck'),
(1830, 2836, 2, 'Höft + ljumske'),
(1831, 2837, 2, 'Höft och ljumske'),
(1832, 2838, 2, 'Hip Problem'),
(1833, 2839, 2, 'Höftledsplastik'),
(1834, 2840, 2, 'Ej Tilldelad'),
(1835, 2843, 2, 'Spansktalande'),
(1836, 2847, 2, 'Historia'),
(1837, 2848, 2, 'Historikdata'),
(1838, 2862, 2, 'Håll ner [Ctrl] för flera val eller avmarkera'),
(1839, 2863, 2, 'Håll ned Ctrl för att välja flera objekt'),
(1840, 2864, 2, 'Håll ned Ctrl för att välja flera patruller'),
(1841, 2865, 2, 'Hem'),
(1842, 2866, 2, 'Hemtelefon'),
(1843, 2868, 2, 'Hemlös eller liknande?'),
(1844, 2869, 2, 'Hemlös'),
(1845, 2870, 2, 'Hemlös'),
(1846, 2876, 2, 'Timmar'),
(1847, 2878, 2, 'Hur uppstod skadan?'),
(1848, 2879, 2, 'Hur uppstod skadan?:'),
(1849, 2881, 2, 'Hur många månader att fråga efter kommande evenemang?'),
(1850, 2892, 2, 'Hyperaktiv'),
(1851, 2896, 2, 'Hyperthyroidism'),
(1852, 2897, 2, 'Hypotyreoidism'),
(1853, 2898, 2, 'Hysterektomi'),
(1854, 2900, 2, 'Jag är upptagen under denna tid.'),
(1855, 2901, 2, 'Jag har inte behörighet att läsa '),
(1856, 2915, 2, 'Identifierare (ett ord)'),
(1857, 2919, 2, 'Om alla uppgifter för alla kolumner är komplett för denna form'),
(1858, 2922, 2, 'Om namn, någon del av efternamn eller efternamn, förnamn'),
(1859, 2924, 2, 'Om personen avlidit ange dödsdatum'),
(1860, 2927, 2, 'om arbetslösa lägg till student'),
(1861, 2933, 2, 'Om du vill ändra datatyper, lägg till rader eller kolumner'),
(1862, 2937, 2, 'Sjukdom'),
(1863, 2942, 2, 'Vaccinering'),
(1864, 2947, 2, 'Vaccin, Lotnummer'),
(1865, 2948, 2, 'Vaccin, tillverkare'),
(1866, 2953, 2, 'Vaccineringar'),
(1867, 2954, 2, 'Vaccinera'),
(1868, 2956, 2, 'Implantat'),
(1869, 2957, 2, 'Importera'),
(1870, 2964, 2, 'Importera patient'),
(1871, 2965, 2, 'Importera Patientdemografi'),
(1872, 2969, 2, 'Importerad från Accounting'),
(1873, 2972, 2, 'förbättrad'),
(1874, 2973, 2, 'i'),
(1875, 2975, 2, 'i båda ögonen'),
(1876, 2976, 2, 'i vänster öga'),
(1877, 2977, 2, 'i näsborre'),
(1878, 2978, 2, 'Arbetar'),
(1879, 2979, 2, 'i höger öga'),
(1880, 2982, 2, 'Inaktiv Dagar'),
(1881, 2991, 2, 'Inkludera mätväden'),
(1882, 2994, 2, 'Inkomst'),
(1883, 3001, 2, 'ökat:'),
(1884, 3002, 2, 'Ansvarsförsäkring'),
(1885, 3003, 2, 'Obestämd'),
(1886, 3006, 2, 'Indikerar om detta problem/frågeställning är aktiv'),
(1887, 3010, 2, 'Hjälpbehövande Patienter Rapport'),
(1888, 3017, 2, 'Infektion / Abscess'),
(1889, 3018, 2, 'Infektioner'),
(1890, 3019, 2, 'Infert Couns'),
(1891, 3026, 2, 'Info'),
(1892, 3027, 2, 'Info test 1'),
(1893, 3028, 2, 'Info test 2'),
(1894, 3029, 2, 'Info test 3'),
(1895, 3030, 2, 'Info test 4'),
(1896, 3031, 2, 'Info test 5'),
(1897, 3032, 2, 'Info test 6'),
(1898, 3034, 2, 'inhalation'),
(1899, 3035, 2, 'inhalationer'),
(1900, 3037, 2, 'Ursprunglig användare'),
(1901, 3039, 2, 'Injeserbara'),
(1902, 3042, 2, 'Skadade ut'),
(1903, 3044, 2, 'Skademekanism'),
(1904, 3045, 2, 'Skada, översiktsrapport'),
(1905, 3047, 2, 'Skada Typ'),
(1906, 3051, 2, 'Inmatningsfält'),
(1907, 3056, 2, 'Ins justera'),
(1908, 3057, 2, 'Ins paketering'),
(1909, 3061, 2, 'Ins överskjutande'),
(1910, 3063, 2, 'Ins återbetalning'),
(1911, 3064, 2, 'Ins Sammering'),
(1912, 3065, 2, 'Ins1'),
(1913, 3066, 2, 'Ins2'),
(1914, 3067, 2, 'Ins3'),
(1915, 3069, 2, 'isättning misslyckades: '),
(1916, 3070, 2, 'Sätt gamla händelser i tabeller'),
(1917, 3072, 2, 'Insomnia'),
(1918, 3074, 2, 'Inspektion'),
(1919, 3075, 2, 'Instabilitet / subluxation'),
(1920, 3079, 2, 'installera DB'),
(1921, 3081, 2, 'Instruerad'),
(1922, 3084, 2, 'Instruktioner:'),
(1923, 3086, 2, 'Insulinberoende diabetiker'),
(1924, 3087, 2, 'Försäkring'),
(1925, 3088, 2, 'försäkring'),
(1926, 3094, 2, 'Försäkringsbolag'),
(1927, 3095, 2, 'Försäkringsbolag'),
(1928, 3096, 2, 'Försäkringsbolag Sök / Köp'),
(1929, 3098, 2, 'Försäkring Data'),
(1930, 3100, 2, 'Försäkring Number'),
(1931, 3103, 2, 'Försäkringsbolag'),
(1932, 3113, 2, 'Internt fel - inga sidor valdes!'),
(1933, 3114, 2, 'Internt fel - patient-ID fanns inte!'),
(1934, 3116, 2, 'Internt fel!'),
(1935, 3119, 2, 'Internt fel: påstående '),
(1936, 3120, 2, 'Internt fel: möter"'),
(1937, 3126, 2, 'Inre Övergångar'),
(1938, 3129, 2, 'Tolk'),
(1939, 3131, 2, 'Interstitiell lungsjukdom'),
(1940, 3132, 2, 'Interval'),
(1941, 3137, 2, 'Intolerans'),
(1942, 3139, 2, 'intramuskulärt'),
(1943, 3140, 2, 'intravenöst'),
(1944, 3141, 2, 'Introduktion'),
(1945, 3149, 2, 'Ogiltig eller saknas betalaren i källan för kod '),
(1946, 3151, 2, 'Ogiltig Service Kod'),
(1947, 3152, 2, 'Ogiltig källdestination"'),
(1948, 3155, 2, 'Inventering'),
(1949, 3159, 2, 'Inventering är inte tillgänglig för denna beställning.'),
(1950, 3160, 2, 'Inventeringslista'),
(1951, 3162, 2, 'Faktura'),
(1952, 3163, 2, 'faktura'),
(1953, 3166, 2, 'Fakturadatum'),
(1954, 3167, 2, 'Fakturanhar inget datum!'),
(1955, 3173, 2, 'Faktura:'),
(1956, 3185, 2, 'Oregelbunden hjärtrytm'),
(1957, 3186, 2, 'Retlighet'),
(1958, 3187, 2, 'Irritation'),
(1959, 3191, 2, 'är ett obligatoriskt fält.'),
(1960, 3197, 2, 'inte är giltig (decimalbråk är OK).'),
(1961, 3198, 2, 'Är PHP använder felsäkert läge?'),
(1962, 3216, 2, 'Frågeställning'),
(1963, 3217, 2, 'frågeställning'),
(1964, 3223, 2, 'Aktuellt'),
(1965, 3225, 2, 'Aktuellt (Problem / Medicin / Allergi):'),
(1966, 3226, 2, 'Information och Patientmöten'),
(1967, 3227, 2, 'Information och möten för'),
(1968, 3228, 2, 'Problematik, ej behörig'),
(1969, 3229, 2, 'Frågeställningssektion'),
(1970, 3231, 2, 'Artikel'),
(1971, 3232, 2, 'artikel'),
(1972, 3234, 2, 'Poster laddades inte'),
(1973, 3239, 2, 'Januari'),
(1974, 3243, 2, 'Jobb-beskrivning'),
(1975, 3244, 2, 'Jobb id'),
(1976, 3245, 2, 'Led dislokation'),
(1977, 3246, 2, 'Led smärta'),
(1978, 3247, 2, 'Led vrickning'),
(1979, 3249, 2, 'Juli'),
(1980, 3251, 2, 'Juni'),
(1981, 3253, 2, 'Bara min'),
(1982, 3255, 2, 'Motivera'),
(1983, 3256, 2, 'Motivera / Spara'),
(1984, 3258, 2, 'k, här är resten'),
(1985, 3265, 2, 'Nyckelord'),
(1986, 3269, 2, 'Njurcancer'),
(1987, 3270, 2, 'Njursvikt'),
(1988, 3271, 2, 'Njure Infektioner'),
(1989, 3272, 2, 'Njursten'),
(1990, 3273, 2, 'Njurtransplantation'),
(1991, 3277, 2, 'Knä'),
(1992, 3278, 2, 'Knä Problem'),
(1993, 3279, 2, 'Knä Ersättning /protes'),
(1994, 3286, 2, 'Lab'),
(1995, 3295, 2, 'Lab Rapport'),
(1996, 3303, 2, 'Etikett'),
(1997, 3305, 2, 'Label Cols'),
(1998, 3308, 2, 'Etiketter'),
(1999, 3311, 2, 'Labs'),
(2000, 3312, 2, 'Laceration / hudkodition'),
(2001, 3313, 2, 'Laceration / nötning'),
(2002, 3316, 2, 'Språk'),
(2003, 3317, 2, 'Språk-kod'),
(2004, 3318, 2, 'Språk definition tillagd'),
(2005, 3321, 2, 'Språknamn'),
(2006, 3322, 2, 'Språk:'),
(2007, 3325, 2, 'Sist'),
(2008, 3326, 2, 'Datum för senaste aktivitet'),
(2009, 3328, 2, 'Sista betalnings dag på faktura:'),
(2010, 3333, 2, 'Senaste patientmötet'),
(2011, 3344, 2, 'Efternamn'),
(2012, 3345, 2, 'Efternamn'),
(2013, 3346, 2, 'Efternamn:'),
(2014, 3352, 2, 'Senast sparad'),
(2015, 3356, 2, 'Senast uppdaterad av'),
(2016, 3358, 2, 'Senaste besöket'),
(2017, 3360, 2, 'Sen Återkommande (2-12 mån)'),
(2018, 3365, 2, 'sidled fördrivna PMI:'),
(2019, 3374, 2, 'Layout Editor'),
(2020, 3379, 2, 'Layouter'),
(2021, 3382, 2, 'LDL'),
(2022, 3383, 2, 'lämna tom om fortfarande aktiv'),
(2023, 3385, 2, 'Lämna tomt för att hålla lösenord oförändrad.'),
(2024, 3386, 2, 'Kontakt via'),
(2025, 3387, 2, 'Lämna Form'),
(2026, 3390, 2, 'Vänster'),
(2027, 3391, 2, 'vänster öra'),
(2028, 3392, 2, 'vänster öra'),
(2029, 3394, 2, 'Vänster:'),
(2030, 3395, 2, 'Vänster: '),
(2031, 3396, 2, 'Ben smärta / Kramper'),
(2032, 3397, 2, 'Rättsärenden'),
(2033, 3400, 2, 'Förklaring:'),
(2034, 3401, 2, 'Längd'),
(2035, 3406, 2, 'Brev'),
(2036, 3407, 2, 'Brevgenerator'),
(2037, 3412, 2, 'Ansvar'),
(2038, 3413, 2, 'Ansvar för medicinskt'),
(2039, 3414, 2, 'passnr'),
(2040, 3423, 2, 'Livsstil'),
(2041, 3425, 2, 'Ligament skada eller vrickning'),
(2042, 3428, 2, 'Begränsning av händelser'),
(2043, 3438, 2, 'Förteckning'),
(2044, 3443, 2, 'List Editor'),
(2045, 3446, 2, 'Lista Insurance Companies'),
(2046, 3451, 2, 'Lista listor'),
(2047, 3452, 2, 'Lista Namn'),
(2048, 3454, 2, 'Lista recept'),
(2049, 3458, 2, 'Listor'),
(2050, 3464, 2, 'Ladda definitioner'),
(2051, 3470, 2, 'Laddar'),
(2052, 3473, 2, 'Lokalt'),
(2053, 3477, 2, 'Lokalitet'),
(2054, 3478, 2, 'Lokalisation'),
(2055, 3481, 2, 'Lokalisation ospecificerad'),
(2056, 3484, 2, 'Lokalisation'),
(2057, 3495, 2, 'Inloggad'),
(2058, 3496, 2, 'Inloggad som'),
(2059, 3497, 2, 'Inloggad som: '),
(2060, 3498, 2, 'Utloggad.'),
(2061, 3500, 2, 'Logga in'),
(2062, 3501, 2, 'logga in'),
(2063, 3505, 2, 'Logout'),
(2064, 3506, 2, 'logout'),
(2065, 3507, 2, 'Loggar'),
(2066, 3510, 2, 'Slå upp'),
(2067, 3511, 2, 'Batch'),
(2068, 3513, 2, 'Batchnummer'),
(2069, 3514, 2, 'låg'),
(2070, 3516, 2, 'Benet'),
(2071, 3519, 2, 'Lumbal delen av ryggraden'),
(2072, 3520, 2, 'LUNCH'),
(2073, 3521, 2, 'Lunch'),
(2074, 3522, 2, 'Lung Cancer'),
(2075, 3523, 2, 'Lung Cancer kirurgi'),
(2076, 3524, 2, 'Lungor:'),
(2077, 3525, 2, 'Lungor:'),
(2078, 3528, 2, 'M'),
(2079, 3529, 2, 'MA Kategori'),
(2080, 3535, 2, 'Huvudadress'),
(2081, 3540, 2, 'Gör ändringar i nuvarande kategorier.'),
(2082, 3542, 2, 'Försäkra "'),
(2083, 3545, 2, 'Sjukdomskänsla:'),
(2084, 3548, 2, 'Man'),
(2085, 3549, 2, 'Manlig Kondomer'),
(2086, 3552, 2, 'Mammogram'),
(2087, 3557, 2, 'Administration'),
(2088, 3562, 2, 'Manuell post'),
(2089, 3563, 2, 'Tillverkare'),
(2090, 3568, 2, 'Mars'),
(2091, 3569, 2, 'Civilstånd'),
(2092, 3571, 2, 'Markera som faktureras men hoppa fakturering'),
(2093, 3572, 2, 'Markera som avklarad'),
(2094, 3573, 2, 'Markera som ej fakturerad'),
(2095, 3575, 2, 'Markerad som avslutad'),
(2096, 3576, 2, 'Gift'),
(2097, 3594, 2, 'Maxillary Höger:'),
(2098, 3603, 2, 'Maj'),
(2099, 3604, 2, 'MC'),
(2100, 3605, 2, 'mcg'),
(2101, 3614, 2, 'Medicinsk'),
(2102, 3620, 2, 'Medicinska problem'),
(2103, 3623, 2, 'Medicinska problem'),
(2104, 3624, 2, 'Journal'),
(2105, 3625, 2, 'Journal #'),
(2106, 3626, 2, 'Journaler'),
(2107, 3632, 2, 'Journal / Historia ( frivilligt att skriva )'),
(2108, 3635, 2, 'Medicin'),
(2109, 3640, 2, 'Läkemedel'),
(2110, 3641, 2, 'Läkemedel:'),
(2111, 3642, 2, 'Medicinska enheter'),
(2112, 3643, 2, 'Medium'),
(2113, 3645, 2, 'Ledamot Association Statistik Rapport'),
(2114, 3646, 2, 'Minnes Problem'),
(2115, 3647, 2, 'Män'),
(2116, 3648, 2, 'Män och kvinnor'),
(2117, 3649, 2, 'Män Endast'),
(2118, 3651, 2, 'Klimakteriet'),
(2119, 3654, 2, 'Psykisk sjukdom'),
(2120, 3661, 2, 'Meddelande'),
(2121, 3662, 2, 'Meddelanden och Påminnelser'),
(2122, 3670, 2, 'MEDELANDE:'),
(2123, 3671, 2, 'Meddelanden'),
(2124, 3673, 2, 'Metod'),
(2125, 3676, 2, 'Metod för förstöring'),
(2126, 3679, 2, 'mg'),
(2127, 3680, 2, 'mg/ml'),
(2128, 3681, 2, 'g'),
(2129, 3682, 2, 'g/ml'),
(2130, 3686, 2, 'Mellan'),
(2131, 3687, 2, 'Mellannamn'),
(2132, 3688, 2, 'Mellannamn'),
(2133, 3696, 2, 'Migrerande eller säsongsarbetare?'),
(2134, 3697, 2, 'Migrerande / Säsong'),
(2135, 3709, 2, 'minuter'),
(2136, 3710, 2, 'Protokoll'),
(2137, 3716, 2, 'Diverse'),
(2138, 3717, 2, 'Missade'),
(2139, 3726, 2, 'Blandat'),
(2140, 3727, 2, 'ml'),
(2141, 3733, 2, 'Mobil'),
(2142, 3734, 2, 'Mobiltelefon'),
(2143, 3753, 2, 'Mån'),
(2144, 3754, 2, 'Mån tills fredag'),
(2145, 3755, 2, 'Måndag, onsdag och fredag'),
(2146, 3756, 2, 'Måndag'),
(2147, 3758, 2, 'Månad'),
(2148, 3759, 2, 'månad'),
(2149, 3760, 2, 'Månadsvy'),
(2150, 3761, 2, 'Månad (er)'),
(2151, 3762, 2, 'Månadsinkomst'),
(2152, 3766, 2, 'Mer än 50 resultat, gör din sökning mer specifik.'),
(2153, 3771, 2, 'Moder'),
(2154, 3775, 2, 'Flytta'),
(2155, 3779, 2, 'Flytta till patient'),
(2156, 3780, 2, 'Flytta till...'),
(2157, 3781, 2, 'flytta up'),
(2158, 3783, 2, 'Herr.'),
(2159, 3785, 2, 'Fru.'),
(2160, 3786, 2, 'Fröken'),
(2161, 3796, 2, 'Multi Language Tool'),
(2162, 3797, 2, 'Flera områden'),
(2163, 3803, 2, 'Sorla:'),
(2164, 3804, 2, 'Muskel värk'),
(2165, 3810, 2, 'Muskel'),
(2166, 3811, 2, 'Muskel skada'),
(2167, 3812, 2, 'Muskuloskeletala'),
(2168, 3814, 2, 'Ömsesidigt Definierad'),
(2169, 3823, 2, 'Namn'),
(2170, 3826, 2, 'Namn 1'),
(2171, 3827, 2, 'Namn 2'),
(2172, 3828, 2, 'Namn på administratör'),
(2173, 3832, 2, 'Namn på försäkringsbolag'),
(2174, 3833, 2, 'Namn på Provider'),
(2175, 3837, 2, 'Namn:'),
(2176, 3838, 2, 'Narės:'),
(2177, 3839, 2, 'Narės: Normal Rätt'),
(2178, 3840, 2, 'Nasal mucosa rosa, septumets mittlinje'),
(2179, 3844, 2, 'Nationalitet'),
(2180, 3854, 2, 'Navigering'),
(2181, 3866, 2, 'Nacke'),
(2182, 3867, 2, 'Nackproblem'),
(2183, 3869, 2, 'Måste ange en beskrivning'),
(2184, 3870, 2, 'Ange ett returvärde'),
(2185, 3871, 2, 'Ange identifieraren'),
(2186, 3872, 2, 'Ange titel'),
(2187, 3875, 2, 'Ange sekundära fakturering'),
(2188, 3880, 2, 'Nervskada'),
(2189, 3881, 2, 'Neurala tillstånd / nervskada'),
(2190, 3888, 2, 'Ny'),
(2191, 3889, 2, 'Ny =>'),
(2192, 3890, 2, 'Nya mottagare'),
(2193, 3894, 2, 'Nytt möte'),
(2194, 3895, 2, 'Nya kategorier'),
(2195, 3897, 2, 'Nya kunder'),
(2196, 3898, 2, 'Ny konsultation'),
(2197, 3900, 2, 'Nytt definitionset tillagt'),
(2198, 3906, 2, 'Nya Patientbesöksformulär'),
(2199, 3907, 2, 'Nya möten som inte godkänts'),
(2200, 3909, 2, 'Nya Klinikinformation'),
(2201, 3912, 2, 'Ny grupp'),
(2202, 3916, 2, 'Ny begränsning av händelser'),
(2203, 3921, 2, 'Ny Patient'),
(2204, 3922, 2, 'NY PATIENT'),
(2205, 3923, 2, 'Nytt Patientbesök'),
(2206, 3925, 2, 'Nytt patient-ID'),
(2207, 3931, 2, 'Nya förslag'),
(2208, 3932, 2, 'Ny användare'),
(2209, 3934, 2, 'Nytt besök'),
(2210, 3935, 2, 'Ny/Sök'),
(2211, 3961, 2, 'Dagstidning'),
(2212, 3962, 2, 'Nästa'),
(2213, 3964, 2, 'Nästa dag'),
(2214, 3965, 2, 'Nästa Månad'),
(2215, 3968, 2, 'Nästa vecka'),
(2216, 3971, 2, 'Alias'),
(2217, 3973, 2, 'Nattliga svettningar'),
(2218, 3975, 2, 'Nej'),
(2219, 3976, 2, 'NEJ'),
(2220, 3977, 2, 'Ingen tillgång'),
(2221, 3985, 2, 'Inget faktureringssystem är aktivt'),
(2222, 3989, 2, 'Ingen kod specificerades!'),
(2223, 3992, 2, 'Ingen diagnos'),
(2224, 3995, 2, 'Inget slutdatum'),
(2225, 3996, 2, 'Inga poster funna, använda formuläret nedan för att lägga till en post.'),
(2226, 3998, 2, 'Inga händelser'),
(2227, 4001, 2, 'Ingen grupp valdes'),
(2228, 4002, 2, 'Inga bråck'),
(2229, 4006, 2, 'Nr Insurance Companies Found'),
(2230, 4036, 2, 'Inga tider hittades för denna period.'),
(2231, 4039, 2, 'Inga Partners hittades'),
(2232, 4042, 2, 'Inga perifera ödem'),
(2233, 4043, 2, 'Inga apotek hittades'),
(2234, 4044, 2, 'Inga recept hittades'),
(2235, 4045, 2, 'Ingen sjukdom / skada visas'),
(2236, 4060, 2, 'Inga resultat hittades i sökningen'),
(2237, 4062, 2, 'Inga resultat, försök igen.'),
(2238, 4065, 2, 'Ej kommit på avtalad tid'),
(2239, 4068, 2, 'Ingen hud dimpling eller bröst knölar'),
(2240, 4079, 2, 'Nr:'),
(2241, 4083, 2, 'Icke specifika skada'),
(2242, 4085, 2, 'Icke-insulinberoende diabetes'),
(2243, 4087, 2, 'Icke-SRH Medical'),
(2244, 4088, 2, 'Icke-SRH icke-medicinska'),
(2245, 4089, 2, 'Ingen'),
(2246, 4090, 2, 'ingen'),
(2247, 4093, 2, 'Inget av ovanstående'),
(2248, 4096, 2, 'Inte heller'),
(2249, 4097, 2, 'Normal'),
(2250, 4108, 2, 'Normal:'),
(2251, 4119, 2, 'Alla fält är obligatoriska för alla nummer eller kod typer.'),
(2252, 4120, 2, 'Ej tillåtet'),
(2253, 4121, 2, 'Ej tillåtet att ta bort gruppen Administratörer'),
(2254, 4123, 2, 'Ej tillåtet att inaktivera alla trygghet objekt'),
(2255, 4124, 2, 'Ej tillåtet att inaktivera allt från Administratörer ACL'),
(2256, 4125, 2, 'Ej tillåtet att ta bort admin-användare från gruppen Administratörer'),
(2257, 4128, 2, 'Ej behörighet att nå PostCalendar modulen'),
(2258, 4143, 2, 'Inte undersökt'),
(2259, 4144, 2, 'Inte undersökt:'),
(2260, 4145, 2, 'Inte undersökt: '),
(2261, 4152, 2, 'Inte sett sedan'),
(2262, 4157, 2, 'kommentera'),
(2263, 4162, 2, 'Kommentartyp'),
(2264, 4168, 2, 'Anmärkning: Denna kod har inte förts in av en auktoriserad användare. Endast godkända koder kan laddas upp till Open Medical Billing nätverket för bearbetning. Om du vill ladda upp dessa nummer kan du välja en auktoriserad användare här.'),
(2265, 4171, 2, 'OBS: Överföra filer med duplikat namn gör att filerna automatiskt ska döpas. Till exempel "<i> file.jpg </ i>" blir "<i> file.jpg.1 </ i>". Filnamnen anses unika per patient, inte per kategori.'),
(2266, 4172, 2, 'Kommentarer'),
(2267, 4182, 2, 'Ingenting valdes'),
(2268, 4184, 2, 'MEDDELANDE: PostCalendar Inlämning / Modifiering'),
(2269, 4185, 2, 'Besked'),
(2270, 4189, 2, 'Meddela Admin Om Händelse Inlämning / Modifieringsförslag?'),
(2271, 4191, 2, 'November'),
(2272, 4198, 2, 'NPI'),
(2273, 4200, 2, 'Nummer'),
(2274, 4204, 2, 'Antal kolumner i år-vy.'),
(2275, 4234, 2, 'Status'),
(2276, 4237, 2, 'Yrke'),
(2277, 4239, 2, 'Förekomst'),
(2278, 4241, 2, 'Oktober'),
(2279, 4245, 2, 'tabletter'),
(2280, 4246, 2, 'i månaden per'),
(2281, 4249, 2, 'Mottagningskommentarer'),
(2282, 4250, 2, 'Mottagningsbesök'),
(2283, 4263, 2, 'Avkomma'),
(2284, 4265, 2, 'salva'),
(2285, 4267, 2, 'OK'),
(2286, 4272, 2, 'Gamla klienter'),
(2287, 4285, 2, 'underlåtit att autoassign'),
(2288, 4286, 2, 'på'),
(2289, 4288, 2, 'På Hand'),
(2290, 4289, 2, 'På beställning'),
(2291, 4292, 2, 'När du byter lösenord måste du logga in på nytt.'),
(2292, 4299, 2, 'Endast aktiva'),
(2293, 4302, 2, 'endast om faktureringsadress'),
(2294, 4303, 2, 'Endast Inaktiva'),
(2295, 4304, 2, 'Endast Min'),
(2296, 4310, 2, 'Uppkomsten av sjukdom:'),
(2297, 4311, 2, 'Uppkomsten av sjukdom: '),
(2298, 4312, 2, 'Uppkomsten av Svullnad:'),
(2299, 4313, 2, 'Debut / Inskrivning. Datum:'),
(2300, 4316, 2, 'Öppen'),
(2301, 4328, 2, 'LibreEHR kräver Javascript för att utföra användarverifiering.'),
(2302, 4333, 2, 'Alternativ'),
(2303, 4336, 2, 'Valfritt'),
(2304, 4345, 2, 'Frivillig information om denna händelse'),
(2305, 4348, 2, 'Valfri procedurkodkod'),
(2306, 4351, 2, 'Eller'),
(2307, 4352, 2, 'ELLER'),
(2308, 4353, 2, 'Eller välj'),
(2309, 4359, 2, 'Eller ladda upp ERA fil:'),
(2310, 4362, 2, 'Ordning'),
(2311, 4386, 2, 'Organskada'),
(2312, 4387, 2, 'Organisation'),
(2313, 4391, 2, 'Orienterad x 3'),
(2314, 4398, 2, 'P.O. (via munnen)'),
(2315, 4402, 2, 'Övrigt'),
(2316, 4403, 2, 'annan'),
(2317, 4408, 2, 'Andra skador inte specificerade på någon annan plats'),
(2318, 4410, 2, 'annan månad'),
(2319, 4411, 2, 'Andra icke-federala program'),
(2320, 4413, 2, 'Andra relevanta Symtom'),
(2321, 4414, 2, 'Andra relevanta Symtom:'),
(2322, 4417, 2, 'Andra kirurgiska'),
(2323, 4423, 2, 'OU'),
(2324, 4427, 2, 'Utfall'),
(2325, 4428, 2, 'Outlook'),
(2326, 4432, 2, 'Överutnyttjande'),
(2327, 4440, 2, 'vid behov'),
(2328, 4444, 2, 'Pedriatisk'),
(2329, 4446, 2, 'Sidor'),
(2330, 4447, 2, 'Betald'),
(2331, 4448, 2, 'Betalt belopp som du kommer att fördela'),
(2332, 4450, 2, 'Betalas via'),
(2333, 4463, 2, 'Partner'),
(2334, 4472, 2, 'Lösenord'),
(2335, 4473, 2, 'Ändra lösenord'),
(2336, 4480, 2, 'Lösenord för SMS Gateway'),
(2337, 4486, 2, 'Lösenord:'),
(2338, 4495, 2, 'Tidigare möten'),
(2339, 4496, 2, 'Tidigare möten och dokument'),
(2340, 4498, 2, 'Klistra in HL7 Data'),
(2341, 4522, 2, 'Patient Allergier'),
(2342, 4523, 2, 'Patient träff/bokning'),
(2343, 4528, 2, 'Patient diagram ID'),
(2344, 4539, 2, 'Patientdata'),
(2345, 4544, 2, 'Patientdokument'),
(2346, 4547, 2, 'Patientmöten'),
(2347, 4548, 2, 'Patientmötesformulär'),
(2348, 4549, 2, 'Patientmöten'),
(2349, 4550, 2, 'Patientsök'),
(2350, 4561, 2, 'Patienthistoria'),
(2351, 4562, 2, 'Patientens historia / Livsstil'),
(2352, 4564, 2, 'Patient-ID'),
(2353, 4568, 2, 'Patient -vaccination'),
(2354, 4571, 2, 'Ej tilldelad!'),
(2355, 4573, 2, 'Patient -problem'),
(2356, 4581, 2, 'Patientlista'),
(2357, 4587, 2, 'Patientens medicinska problem'),
(2358, 4588, 2, 'Patient -Mediciner'),
(2359, 4590, 2, 'Patient: Namn och Adress'),
(2360, 4596, 2, 'Patientanteckning, typ'),
(2361, 4597, 2, 'Patient -kommentarer'),
(2362, 4599, 2, 'Patientnummer'),
(2363, 4609, 2, 'Patient -Journalrapport'),
(2364, 4620, 2, 'Patientrapport'),
(2365, 4621, 2, 'Patientförfrågan'),
(2366, 4629, 2, 'Patient -Sammanfattning'),
(2367, 4630, 2, 'Patient -Remisser m.m.'),
(2368, 4633, 2, 'Patient / Klient'),
(2369, 4634, 2, 'Patient:'),
(2370, 4636, 2, 'Patienter'),
(2371, 4638, 2, 'Betala'),
(2372, 4640, 2, 'Betalningsdatum:'),
(2373, 4643, 2, 'Betalare'),
(2374, 4644, 2, 'Betalare Typ'),
(2375, 4645, 2, 'Utbetalande'),
(2376, 4647, 2, 'Betalning'),
(2377, 4654, 2, 'Betalningsdatum'),
(2378, 4660, 2, 'Betalningsmetod'),
(2379, 4664, 2, 'Betalning värde för kod '),
(2380, 4665, 2, 'Betalningar'),
(2381, 4674, 2, 'Oavslutad'),
(2382, 4677, 2, 'Oklart'),
(2383, 4688, 2, 'via näsborre'),
(2384, 4689, 2, 'via näsborre'),
(2385, 4692, 2, 'Rektalt'),
(2386, 4693, 2, 'rektalt'),
(2387, 4699, 2, 'Utför sökning'),
(2388, 4700, 2, 'Utför åtgärden'),
(2389, 4717, 2, 'Apotek'),
(2390, 4718, 2, 'Patient Insurance Distribution'),
(2391, 4720, 2, 'Pheumothorax'),
(2392, 4729, 2, 'Telefon'),
(2393, 4730, 2, 'Telefon samtalslistan'),
(2394, 4738, 2, 'Telefonnummer'),
(2395, 4747, 2, 'Hälsokontroll'),
(2396, 4749, 2, 'Läkares Begäran'),
(2397, 4750, 2, 'Läkares Underskrift'),
(2398, 4752, 2, 'Läkare'),
(2399, 4753, 2, 'välj'),
(2400, 4758, 2, 'Tablett Storlek'),
(2401, 4759, 2, 'Tabletter'),
(2402, 4767, 2, 'Vanlig text'),
(2403, 4768, 2, 'Planering'),
(2404, 4771, 2, 'Planering namn'),
(2405, 4779, 2, 'Planering:'),
(2406, 4782, 2, 'Planering'),
(2407, 4784, 2, 'Spelare'),
(2408, 4785, 2, 'Position'),
(2409, 4792, 2, 'Välj ett värde för'),
(2410, 4797, 2, 'Stäng detta fönster'),
(2411, 4798, 2, 'Jämför det nya namnet'),
(2412, 4839, 2, 'Vänligen använ endast alfabetiska tecken'),
(2413, 4840, 2, 'Vänligen använd endast alfabetiska tecken utan mellanslag'),
(2414, 4841, 2, 'Vänligen betala detta belopp'),
(2415, 4859, 2, 'Välj en händelse'),
(2416, 4882, 2, 'EM'),
(2417, 4891, 2, 'Lunginflammations Vaccination'),
(2418, 4897, 2, 'Förhållningssätt'),
(2419, 4902, 2, 'Polyper'),
(2420, 4904, 2, 'Dålig apptit'),
(2421, 4905, 2, 'Dålig cirkulation'),
(2422, 4906, 2, 'Dålig hörsel'),
(2423, 4909, 2, 'Popup-fönster'),
(2424, 4937, 2, 'Postnr'),
(2425, 4938, 2, 'Postnummer'),
(2426, 4946, 2, 'Överförings Datum'),
(2427, 4953, 2, 'Practice'),
(2428, 4969, 2, 'Graviditets test'),
(2429, 4972, 2, 'Förskottsbetalning'),
(2430, 4977, 2, 'Receptbelagda märken'),
(2431, 4979, 2, 'Recept'),
(2432, 4980, 2, 'Föreskrifter och dispenser'),
(2433, 4981, 2, 'Recept och andra råd'),
(2434, 4982, 2, 'Recept och andra råd av specialist'),
(2435, 4983, 2, 'recept rapport'),
(2436, 4984, 2, 'Recept/råd'),
(2437, 4986, 2, 'Presentera Klagomål'),
(2438, 4988, 2, 'Tryck på fortsätt för att fortsätta'),
(2439, 4989, 2, 'Förmodad diagnos'),
(2440, 4990, 2, 'Förmodad diagnos från specialist'),
(2441, 4991, 2, 'Föregående'),
(2442, 5001, 2, 'Föregående'),
(2443, 5002, 2, 'Föregående konsultation'),
(2444, 5003, 2, 'Föregående dag'),
(2445, 5005, 2, 'Föregående månad'),
(2446, 5006, 2, 'Föregående vecka'),
(2447, 5007, 2, 'Pris'),
(2448, 5009, 2, 'Prisnivå'),
(2449, 5010, 2, 'Prisnivå:'),
(2450, 5012, 2, 'Primär'),
(2451, 5023, 2, 'Primära Försäkring'),
(2452, 5024, 2, 'Primära Försäkrings Data'),
(2453, 5025, 2, 'Primär försäkringsbolag'),
(2454, 5027, 2, 'Skriv ut'),
(2455, 5032, 2, 'Printa blankt remissformulär'),
(2456, 5043, 2, 'Skriv ut flera'),
(2457, 5057, 2, 'Skriv ut denna anmärkning'),
(2458, 5058, 2, 'Skriv ut Denna Anmärkning'),
(2459, 5062, 2, 'Utskrivbar'),
(2460, 5063, 2, 'Utskriftsversion'),
(2461, 5066, 2, 'Skriva ut resultat:'),
(2462, 5073, 2, 'Prioritet '),
(2463, 5074, 2, 'Privat'),
(2464, 5079, 2, 'Problem/anledningar'),
(2465, 5086, 2, 'Förfarande'),
(2466, 5114, 2, 'Förfarande'),
(2467, 5115, 2, 'Process'),
(2468, 5125, 2, 'Bearbetning'),
(2469, 5132, 2, 'Produkter'),
(2470, 5134, 2, 'Prof.'),
(2471, 5136, 2, 'Prostata Cancer'),
(2472, 5138, 2, 'Prostata undersökning'),
(2473, 5139, 2, 'Prostata problem'),
(2474, 5152, 2, 'Vårdgivare'),
(2475, 5153, 2, 'Vårdgivare ID'),
(2476, 5154, 2, 'Vårdgivare ID'),
(2477, 5155, 2, 'Vårdgivare ID på specificerad klinik'),
(2478, 5156, 2, 'Kan ej matcha vårdgivare'),
(2479, 5159, 2, 'Vårdgivare, nummmer'),
(2480, 5162, 2, 'Vårdgivare:'),
(2481, 5163, 2, 'Vårdgivare:'),
(2482, 5167, 2, 'PSA'),
(2483, 5168, 2, 'Psoriasis'),
(2484, 5169, 2, 'Psykisk diagnos'),
(2485, 5170, 2, 'Psykiatrisk mediciinering'),
(2486, 5171, 2, 'Psykiatrisk mediciinering'),
(2487, 5206, 2, 'Puls'),
(2488, 5213, 2, 'Var 3:e timme'),
(2489, 5214, 2, 'Var 4:e timme'),
(2490, 5215, 2, 'Var 5:e timme'),
(2491, 5216, 2, 'Var 6:e timme'),
(2492, 5217, 2, 'Var 8:e timme'),
(2493, 5218, 2, '1 ggr/dag'),
(2494, 5219, 2, '4ggr/dag'),
(2495, 5222, 2, 'Antal'),
(2496, 5224, 2, 'Kvalitet'),
(2497, 5226, 2, 'Kvantitet'),
(2498, 5227, 2, 'Kvantitet för NDC'),
(2499, 5236, 2, 'köad'),
(2500, 5237, 2, 'Kö Evenemang Administration'),
(2501, 5238, 2, 'köad för'),
(2502, 5240, 2, 'Kö föreläggande Administration'),
(2503, 5245, 2, 'Modersmål / Tolkspråk'),
(2504, 5246, 2, 'Modersmål / Tolkspråk'),
(2505, 5247, 2, 'Modersmål / Tolkspråk'),
(2506, 5248, 2, 'Radio'),
(2507, 5249, 2, 'Radioknapp'),
(2508, 5252, 2, 'Utslag'),
(2509, 5253, 2, 'Betygsätta'),
(2510, 5254, 2, 'Andel'),
(2511, 5262, 2, 'Åter öppnas'),
(2512, 5264, 2, 'Reaktioner'),
(2513, 5268, 2, 'Riktigt namn'),
(2514, 5270, 2, 'Anledning'),
(2515, 5271, 2, 'Orsak till avslutande'),
(2516, 5274, 2, 'Anledning till remiss'),
(2517, 5275, 2, 'Anledning till besök'),
(2518, 5276, 2, 'Orsak / Form'),
(2519, 5277, 2, 'Kvitto'),
(2520, 5278, 2, 'Kvitto för betalning'),
(2521, 5281, 2, 'Kvitton Sammanfattning'),
(2522, 5282, 2, 'Mottagna'),
(2523, 5283, 2, 'Mottagna av'),
(2524, 5284, 2, 'Mottagna fax'),
(2525, 5287, 2, 'Mottagare'),
(2526, 5288, 2, 'Mottagare ID'),
(2527, 5300, 2, 'Rekomendationer'),
(2528, 5301, 2, 'Rekomendationer och behandling'),
(2529, 5302, 2, 'Rekomendationer av specialist'),
(2530, 5327, 2, 'reduceras:'),
(2531, 5328, 2, 'Remitera'),
(2532, 5329, 2, 'Remiterad av'),
(2533, 5330, 2, 'Remissdatum'),
(2534, 5331, 2, 'Remiteras till'),
(2535, 5332, 2, 'Prioritetsnivå (Risknivå)'),
(2536, 5334, 2, 'Orsak till remiss'),
(2537, 5336, 2, 'Remittent, namn och signatur'),
(2538, 5337, 2, 'Remiss'),
(2539, 5338, 2, 'Remitterad av'),
(2540, 5339, 2, 'Remisskort'),
(2541, 5340, 2, 'Remissdadum'),
(2542, 5341, 2, 'Remissformulär'),
(2543, 5342, 2, 'REMISSFORMULÄR'),
(2544, 5345, 2, 'Remisskälla'),
(2545, 5347, 2, 'Remitteras till'),
(2546, 5348, 2, 'remittering'),
(2547, 5349, 2, 'remiss'),
(2548, 5350, 2, 'Remiterats från'),
(2549, 5351, 2, 'Remiterats från'),
(2550, 5352, 2, 'Remitterats till'),
(2551, 5353, 2, 'Remiterats av'),
(2552, 5360, 2, 'Påfyllnad'),
(2553, 5361, 2, 'påfyllnad'),
(2554, 5362, 2, 'Reflexer normala'),
(2555, 5363, 2, 'Uppdatera'),
(2556, 5372, 2, 'Registrerad'),
(2557, 5373, 2, 'registrerade'),
(2558, 5375, 2, 'Registreringsdag'),
(2559, 5377, 2, 'Rehabilitering');
INSERT INTO `lang_definitions` VALUES
(2560, 5382, 2, 'Relaterat'),
(2561, 5387, 2, 'Förhållande'),
(2562, 5389, 2, 'Anhöriga'),
(2563, 5403, 2, 'Religion'),
(2564, 5406, 2, 'Relogin'),
(2565, 5419, 2, 'Ta bort grupp'),
(2566, 5440, 2, 'Upprepar'),
(2567, 5444, 2, 'Svars Datum'),
(2568, 5446, 2, 'Rapport'),
(2569, 5463, 2, 'Rapporter'),
(2570, 5477, 2, 'Nödvändig'),
(2571, 5485, 2, 'RESERVERAD'),
(2572, 5486, 2, 'reserverad'),
(2573, 5496, 2, 'Löst'),
(2574, 5503, 2, 'Begränsat Utbildning'),
(2575, 5504, 2, 'Resultat'),
(2576, 5518, 2, 'Infällda Höger:'),
(2577, 5519, 2, 'Avkastning'),
(2578, 5527, 2, 'Returvärde'),
(2579, 5528, 2, 'Återresa'),
(2580, 5536, 2, 'Översyn av System Kontroller'),
(2581, 5538, 2, 'Revision'),
(2582, 5541, 2, 'Höger'),
(2583, 5542, 2, 'Höger öra'),
(2584, 5543, 2, 'höger öra'),
(2585, 5545, 2, 'Höger:'),
(2586, 5546, 2, 'Ringningar i öron'),
(2587, 5547, 2, 'Tinitus'),
(2588, 5561, 2, 'Rutt'),
(2589, 5564, 2, 'Rader'),
(2590, 5566, 2, 'Massera:'),
(2591, 5567, 2, 'Gnuggar:'),
(2592, 5581, 2, 'Kör kommando: '),
(2593, 5584, 2, 'Recept'),
(2594, 5585, 2, 'Recept'),
(2595, 5600, 2, 'K'),
(2596, 5601, 2, 'Personnr'),
(2597, 5610, 2, 'Samma dag'),
(2598, 5613, 2, 'Sanktions Typ'),
(2599, 5617, 2, 'Lördag'),
(2600, 5618, 2, 'Lördag & söndag'),
(2601, 5619, 2, 'Lördag'),
(2602, 5620, 2, 'Spara'),
(2603, 5624, 2, 'Spara och fördela'),
(2604, 5626, 2, 'Spara som ny'),
(2605, 5629, 2, 'Spara ändringar'),
(2606, 5631, 2, 'Spara vaccination'),
(2607, 5639, 2, 'Spara transaktionen'),
(2608, 5641, 2, 'Inskannade'),
(2609, 5645, 2, 'Schema'),
(2610, 5648, 2, 'Skolios'),
(2611, 5651, 2, 'SE'),
(2612, 5652, 2, 'SE Adress'),
(2613, 5653, 2, 'SE Stad'),
(2614, 5654, 2, 'SE Land'),
(2615, 5659, 2, 'Söka'),
(2616, 5661, 2, 'söka'),
(2617, 5662, 2, 'Sök igen'),
(2618, 5664, 2, 'Sök efter:'),
(2619, 5666, 2, 'Sök efter:'),
(2620, 5669, 2, 'Sök efter eller lägg till patient'),
(2621, 5672, 2, 'Sökresultat:'),
(2622, 5677, 2, 'Sök i Evenemang'),
(2623, 5679, 2, 'Sök / Lägg till försäkringsgivaren'),
(2624, 5682, 2, 'Bilbältesanvändning'),
(2625, 5684, 2, 'Andra'),
(2626, 5687, 2, 'Sekundär'),
(2627, 5688, 2, 'Sekundär Försäkring'),
(2628, 5689, 2, 'Sekundär Försäkrings Data'),
(2629, 5699, 2, 'Se Alla'),
(2630, 5700, 2, 'Se Auktoriseringar'),
(2631, 5704, 2, 'Sett sedan'),
(2632, 5709, 2, 'Välj'),
(2633, 5716, 2, 'Välj Alla'),
(2634, 5769, 2, 'Egen lön'),
(2635, 5774, 2, 'Överföring pågår'),
(2636, 5788, 2, 'Avsändare'),
(2637, 5789, 2, 'Avsändar ID'),
(2638, 5795, 2, 'Känslighet:'),
(2639, 5804, 2, 'Skickats'),
(2640, 5807, 2, 'skickas till skrivaren.'),
(2641, 5813, 2, 'Separerade'),
(2642, 5814, 2, 'September'),
(2643, 5827, 2, 'Service Datum:'),
(2644, 5829, 2, 'Service Location'),
(2645, 5834, 2, 'Tjänster'),
(2646, 5835, 2, 'Tjänster efter kategori'),
(2647, 5836, 2, 'Tjänster som tillhandahålls'),
(2648, 5837, 2, 'Tjänster som Tillhandahålls'),
(2649, 5849, 2, 'Inställningar'),
(2650, 5851, 2, 'Svår huvudvärk'),
(2651, 5853, 2, 'Svårighetsgrad av smärta'),
(2652, 5854, 2, 'Svårighetsgrad av smärta:'),
(2653, 5855, 2, 'Kön'),
(2654, 5856, 2, 'Sexuellt överförbara sjukdomar'),
(2655, 5859, 2, 'Dela'),
(2656, 5864, 2, 'Andnöd'),
(2657, 5870, 2, 'bör vara som nnnnn-nnnn-nn'),
(2658, 5874, 2, 'Axel'),
(2659, 5875, 2, 'Axel + nyckelben'),
(2660, 5876, 2, 'Axelproblem'),
(2661, 5877, 2, 'visa'),
(2662, 5884, 2, 'Visa som upptagen'),
(2663, 5885, 2, 'Visa endast behöriga'),
(2664, 5889, 2, 'Visa detaljer'),
(2665, 5906, 2, 'Visa rapport'),
(2666, 5913, 2, 'Visa endast icke fakturerad'),
(2667, 5920, 2, 'Syskon'),
(2668, 5927, 2, 'Underskrift'),
(2669, 5929, 2, 'Underskrift:'),
(2670, 5932, 2, 'Betydande Svullnad:'),
(2671, 5940, 2, 'Singel'),
(2672, 5956, 2, 'Storlek'),
(2673, 5958, 2, 'Storlek / Lista'),
(2674, 5959, 2, 'Hud'),
(2675, 5967, 2, 'sömn mönster'),
(2676, 5969, 2, 'sover'),
(2677, 6009, 2, 'Social History:'),
(2678, 6011, 2, 'lösning'),
(2679, 6016, 2, 'Vissa möten visas inte. Klicka här för att visa alla.'),
(2680, 6018, 2, 'Vissa anteckningar visades inte'),
(2681, 6020, 2, 'några ord'),
(2682, 6029, 2, 'Sortera efter'),
(2683, 6048, 2, 'Källa'),
(2684, 6051, 2, 'Källa saknas för kod '),
(2685, 6057, 2, 'Källa:'),
(2686, 6069, 2, 'Specialist namn och signatur'),
(2687, 6071, 2, 'Specialtet'),
(2688, 6073, 2, 'Specialitet:'),
(2689, 6074, 2, 'Särskilda'),
(2690, 6078, 2, 'Särskilda tjänster'),
(2691, 6092, 2, 'Tal diktamen'),
(2692, 6093, 2, 'Spermiedödande'),
(2693, 6095, 2, 'Maka'),
(2694, 6098, 2, 'Sputum:'),
(2695, 6111, 2, 'Personnummmer'),
(2696, 6113, 2, 'Persnr'),
(2697, 6114, 2, 'Stabilitet'),
(2698, 6116, 2, 'Standard'),
(2699, 6124, 2, 'Start'),
(2700, 6125, 2, 'Start (åååå-mm-dd): '),
(2701, 6128, 2, 'Startdatum'),
(2702, 6129, 2, 'Start datum vid denna klinik'),
(2703, 6131, 2, 'Startdatum:'),
(2704, 6132, 2, 'Startdatum:'),
(2705, 6133, 2, 'Start tid'),
(2706, 6134, 2, 'Startdatum'),
(2707, 6136, 2, 'Stat'),
(2708, 6144, 2, 'församling'),
(2709, 6151, 2, 'Statistik'),
(2710, 6152, 2, 'Övrigt'),
(2711, 6153, 2, 'Status'),
(2712, 6156, 2, 'Oförändrat'),
(2713, 6169, 2, 'Stela leder'),
(2714, 6172, 2, 'Ont i magen'),
(2715, 6175, 2, 'Överbelastade muskler'),
(2716, 6177, 2, 'Gata'),
(2717, 6179, 2, 'Gatu nummer'),
(2718, 6180, 2, 'styrka'),
(2719, 6183, 2, 'Stress fraktur'),
(2720, 6184, 2, 'Stresstest'),
(2721, 6185, 2, 'Stroke'),
(2722, 6190, 2, 'Delsumma'),
(2723, 6191, 2, 'Underkategori'),
(2724, 6192, 2, 'underkategori'),
(2725, 6193, 2, 'subkutant'),
(2726, 6195, 2, 'Anamnes'),
(2727, 6196, 2, 'Sublingual'),
(2728, 6197, 2, 'sublingual'),
(2729, 6198, 2, 'Lämna in'),
(2730, 6202, 2, 'Lämna in händelsen'),
(2731, 6203, 2, 'lämna in blanketten'),
(2732, 6206, 2, 'Inlämnat av'),
(2733, 6208, 2, 'Prenuremant'),
(2734, 6209, 2, 'Prenuremants Adress'),
(2735, 6237, 2, 'Ersättare'),
(2736, 6238, 2, 'Ersättare tillåts'),
(2737, 6260, 2, 'Självmord'),
(2738, 6261, 2, 'Sammanfattning'),
(2739, 6265, 2, 'Sön'),
(2740, 6267, 2, 'Söndag'),
(2741, 6291, 2, 'Kirurgi'),
(2742, 6293, 2, 'avstänga'),
(2743, 6294, 2, 'Uppslammad vätska'),
(2744, 6300, 2, 'Svenska'),
(2745, 6323, 2, '3 ggr/dag'),
(2746, 6327, 2, 'Tabell skapas inte'),
(2747, 6328, 2, 'Tabell uppdateringen misslyckades'),
(2748, 6330, 2, 'tablett'),
(2749, 6335, 2, 'Ta'),
(2750, 6339, 2, 'Tar lång tid'),
(2751, 6356, 2, 'Skatter'),
(2752, 6370, 2, 'Mall'),
(2753, 6373, 2, 'Mall:'),
(2754, 6383, 2, 'Testa schema'),
(2755, 6384, 2, 'Testa system'),
(2756, 6402, 2, 'Tack'),
(2757, 6408, 2, 'Påstående ärendet: '),
(2758, 6422, 2, 'Händelsen har godkänts.'),
(2759, 6423, 2, 'Händelsen har gömts undan'),
(2760, 6434, 2, 'Följande kalenderhändelse har lagts till:'),
(2761, 6435, 2, 'Följande kalenderhändelse har modifierats:'),
(2762, 6495, 2, 'Terapeutiska Injektioner'),
(2763, 6498, 2, 'Det är fel med din ansökan. Dessa beskrivs nedan.'),
(2764, 6502, 2, 'Det finns inga nya synpunkter'),
(2765, 6520, 2, 'Det uppstod ett fel när din begäran behandlades.'),
(2766, 6523, 2, 'Förtjockad Höger:'),
(2767, 6524, 2, 'Lår'),
(2768, 6525, 2, 'Lår + knäsena'),
(2769, 6542, 2, 'Tredje'),
(2770, 6561, 2, 'Pågående besök'),
(2771, 6566, 2, 'Detta fakturanumret har ändrats till '),
(2772, 6582, 2, 'Denna patient har ingen aktivitet'),
(2773, 6583, 2, 'Denna patients ID används redan!'),
(2774, 6629, 2, 'Tor'),
(2775, 6630, 2, 'torsdag'),
(2776, 6631, 2, 'Torsdag'),
(2777, 6632, 2, 'Sköldkörtel normal'),
(2778, 6638, 2, 'Tid'),
(2779, 6647, 2, 'beräkna tid på händelse'),
(2780, 6649, 2, 'Tidsstämpel och Text'),
(2781, 6652, 2, 'Titel'),
(2782, 6658, 2, 'Till'),
(2783, 6659, 2, 'TILL'),
(2784, 6660, 2, 'till'),
(2785, 6664, 2, 'På det påverkade området'),
(2786, 6665, 2, 'på det påverkade området'),
(2787, 6668, 2, 'till kategori'),
(2788, 6670, 2, 'Till medbetalare'),
(2789, 6679, 2, 'Till Besök'),
(2790, 6680, 2, 'Om du vill filtrera efter kön'),
(2791, 6681, 2, 'Till Historik'),
(2792, 6682, 2, 'Till frågor'),
(2793, 6684, 2, 'För att länka detta besök till objekt i ovanstående lista, markera önskade objekt och klicka sedan på [spara]. Håll ner [Ctrl] för att markera fler objekt.'),
(2794, 6685, 2, 'för att logga in igen'),
(2795, 6689, 2, 'Huden'),
(2796, 6690, 2, 'huden'),
(2797, 6691, 2, 'Till detta besök?'),
(2798, 6693, 2, 'Till:'),
(2799, 6694, 2, 'Till: '),
(2800, 6708, 2, 'Tobak'),
(2801, 6712, 2, 'Tobaks användande'),
(2802, 6715, 2, 'Idag'),
(2803, 6720, 2, 'Dagens datum'),
(2804, 6721, 2, 'Dagens händelser'),
(2805, 6726, 2, 'Tonsillektomi'),
(2806, 6728, 2, 'Topp'),
(2807, 6730, 2, 'Ämne'),
(2808, 6731, 2, 'Totalt'),
(2809, 6732, 2, 'totalt'),
(2810, 6738, 2, 'Sammanlagt belopp som betalats'),
(2811, 6741, 2, 'Totala kostnader'),
(2812, 6742, 2, 'Totalt antal Kunder'),
(2813, 6748, 2, 'Totalt för'),
(2814, 6749, 2, 'Totalt för '),
(2815, 6750, 2, 'Totalt för kategori'),
(2816, 6758, 2, 'Totalt antal patienter'),
(2817, 6776, 2, 'Totalt'),
(2818, 6777, 2, 'Totalbeloppen för'),
(2819, 6778, 2, 'Totalbeloppen för '),
(2820, 6785, 2, 'Utbildnings sort'),
(2821, 6786, 2, 'Remiss m.m.'),
(2822, 6787, 2, 'Transaktion'),
(2823, 6788, 2, 'Transaktion'),
(2824, 6791, 2, 'Transaktionstyp'),
(2825, 6793, 2, 'Transaktioner'),
(2826, 6794, 2, 'Transaktioner (skriva valfritt)'),
(2827, 6795, 2, 'Transaktioner / Övergångar'),
(2828, 6813, 2, 'översätt detta'),
(2829, 6814, 2, 'översätta'),
(2830, 6819, 2, 'Trauma'),
(2831, 6822, 2, 'Behandlings mål'),
(2832, 6823, 2, 'Behandlings plan'),
(2833, 6826, 2, 'Behandling:'),
(2834, 6827, 2, 'Behandling: '),
(2835, 6837, 2, 'tesked'),
(2836, 6841, 2, 'Tis'),
(2837, 6843, 2, 'Tisdag'),
(2838, 6844, 2, 'Tumör'),
(2839, 6848, 2, 'två gånger dagligen'),
(2840, 6851, 2, 'Typ'),
(2841, 6857, 2, 'Skriv in eller skanna patientidentifikation här'),
(2842, 6866, 2, 'Ulcerations'),
(2843, 6867, 2, 'Ulcerös kolit'),
(2844, 6868, 2, 'Sår:'),
(2845, 6877, 2, 'Ej tilldelad'),
(2846, 6880, 2, 'Obehörig åtkomst.'),
(2847, 6884, 2, 'under tungan'),
(2848, 6885, 2, 'Undervikt'),
(2849, 6886, 2, 'odiagnosticerad'),
(2850, 6890, 2, 'Ångra Kassa'),
(2851, 6892, 2, 'Unika Kunder'),
(2852, 6894, 2, 'Unika nya kunder'),
(2853, 6899, 2, 'Enhet'),
(2854, 6900, 2, 'Enheter'),
(2855, 6901, 2, 'enheter'),
(2856, 6907, 2, 'Okänt'),
(2857, 6911, 2, 'Okänd eller N / A'),
(2858, 6914, 2, 'Namnlöst försäkringsbolag'),
(2859, 6915, 2, 'Oregistrerad'),
(2860, 6918, 2, 'Avmarkera alla'),
(2861, 6919, 2, 'Omarkerat'),
(2862, 6920, 2, 'Ospecificerad'),
(2863, 6924, 2, 'tills'),
(2864, 6926, 2, 'Outnyttjad'),
(2865, 6928, 2, 'Upp till'),
(2866, 6929, 2, 'Kommande möten'),
(2867, 6930, 2, 'Kommande evenemang'),
(2868, 6931, 2, 'Uppdatera'),
(2869, 6932, 2, 'uppdatera'),
(2870, 6934, 2, 'Uppdateringsfilerna'),
(2871, 6935, 2, 'Uppdatera Info'),
(2872, 6951, 2, 'Uppladdning'),
(2873, 6955, 2, 'Ladda upp dokument'),
(2874, 6958, 2, 'Ladda upp fil att importera:'),
(2875, 6961, 2, 'Ladda upp rapport'),
(2876, 6963, 2, 'Ladda upp den här filen:'),
(2877, 6966, 2, 'Överarmen'),
(2878, 6968, 2, 'Brådskande'),
(2879, 6972, 2, 'Urin Frekvens'),
(2880, 6973, 2, 'Urin Tveksamhet'),
(2881, 6977, 2, 'URL'),
(2882, 6988, 2, 'Använd 24-timmars format?'),
(2883, 7000, 2, 'Använd Standardinställningar'),
(2884, 7002, 2, 'Använd internationellt utseende på datum?'),
(2885, 7006, 2, 'Använd ämnen?'),
(2886, 7007, 2, 'Användare'),
(2887, 7010, 2, 'Användaradministration'),
(2888, 7011, 2, 'Användar-och Facility Administration'),
(2889, 7012, 2, 'Användare och grupp Administration'),
(2890, 7015, 2, 'Användardefinierad'),
(2891, 7016, 2, 'Användar definierad Area 11'),
(2892, 7017, 2, 'Användar definierad Area 12'),
(2893, 7040, 2, 'Användare Medlemskap'),
(2894, 7049, 2, 'Användarnamn'),
(2895, 7052, 2, 'Användarnamn för SMS Gateway'),
(2896, 7055, 2, 'Användarnamn:'),
(2897, 7056, 2, 'Användare'),
(2898, 7057, 2, 'Användare / grupper / Logs Administration'),
(2899, 7062, 2, 'SEMESTER'),
(2900, 7063, 2, 'Semester'),
(2901, 7064, 2, 'Vaccin'),
(2902, 7068, 2, 'Wert'),
(2903, 7069, 2, 'Wert 1'),
(2904, 7070, 2, 'Wert 2'),
(2905, 7072, 2, 'Wert muss numerisch sein'),
(2906, 7079, 2, 'Blodkärls kondition'),
(2907, 7080, 2, 'Blodkärsl skada'),
(2908, 7081, 2, 'Kärlkirurgi'),
(2909, 7084, 2, 'Version'),
(2910, 7085, 2, 'Svindel'),
(2911, 7090, 2, 'visa'),
(2912, 7091, 2, 'Visa'),
(2913, 7092, 2, 'Visa allergier'),
(2914, 7097, 2, 'Visa Omfattande Patient Rapport'),
(2915, 7100, 2, 'Visa dokument'),
(2916, 7101, 2, 'Visa möte'),
(2917, 7103, 2, 'Visa händelser i ett popup-fönster?'),
(2918, 7108, 2, 'Visa Sida 1'),
(2919, 7109, 2, 'Visa sida 2'),
(2920, 7116, 2, 'Se relaterade möten'),
(2921, 7124, 2, 'Visa:'),
(2922, 7125, 2, 'VISA'),
(2923, 7126, 2, 'VISA/MC/AMEX/Dis'),
(2924, 7127, 2, 'Visceral skada / trauma / kirurgi'),
(2925, 7133, 2, 'Besökskategori:'),
(2926, 7134, 2, 'Besöks Datum'),
(2927, 7140, 2, 'Besök'),
(2928, 7141, 2, 'Besök från'),
(2929, 7142, 2, 'Vitalparametrar'),
(2930, 7143, 2, 'Vitalparametrar'),
(2931, 7144, 2, 'Vitalparametrar (metriska)'),
(2932, 7145, 2, 'Vitalparametrar Formulär inställningar'),
(2933, 7149, 2, 'Kräkningar'),
(2934, 7151, 2, 'W'),
(2935, 7154, 2, 'Väntar'),
(2936, 7162, 2, 'Varm'),
(2937, 7164, 2, 'VARNING'),
(2938, 7168, 2, 'Varning: Ett besök var redan skapat för denna patient idag!'),
(2939, 7170, 2, 'Varning: patient-ID är inte unikt!'),
(2940, 7179, 2, 'Svaghet'),
(2941, 7182, 2, 'Hemsida'),
(2942, 7184, 2, 'Ons'),
(2943, 7185, 2, 'Onsdag'),
(2944, 7186, 2, 'Vecka'),
(2945, 7187, 2, 'vecka'),
(2946, 7188, 2, 'Veckovy'),
(2947, 7189, 2, 'Veckan (s)'),
(2948, 7193, 2, 'Vikt'),
(2949, 7196, 2, 'Vikt förändring'),
(2950, 7197, 2, 'Viktminskning'),
(2951, 7202, 2, 'Vad är det som räknas?'),
(2952, 7205, 2, 'Wheezing:'),
(2953, 7211, 2, 'Whiplash'),
(2954, 7213, 2, 'Vem'),
(2955, 7214, 2, 'Vem har svarat?'),
(2956, 7215, 2, 'Änka/änkeman'),
(2957, 7216, 2, 'Vidd'),
(2958, 7217, 2, 'Vidd i punkter på vänstra navigeringsfönstret'),
(2959, 7221, 2, 'Med vald:'),
(2960, 7222, 2, 'med det gamla namnet'),
(2961, 7224, 2, 'Med vem kan vi lämna ett meddelande?'),
(2962, 7225, 2, 'Återtagen/innehållen'),
(2963, 7226, 2, 'inom några timmar'),
(2964, 7227, 2, 'inom några timmar:'),
(2965, 7228, 2, 'inom några minuter'),
(2966, 7229, 2, 'inom några minuter:'),
(2967, 7232, 2, 'Utan Updatering'),
(2968, 7233, 2, 'vittne'),
(2969, 7237, 2, 'Kvinnor'),
(2970, 7238, 2, 'Enbart kvinnor'),
(2971, 7240, 2, 'Arbete'),
(2972, 7242, 2, 'Telefon, arbete'),
(2973, 7243, 2, 'Telefon, Arbete, Nummer'),
(2974, 7244, 2, 'Arbetsrelaterat?'),
(2975, 7245, 2, 'Arbete/ Utbildning/ Hobby'),
(2976, 7246, 2, 'Arbete / Skola Anmärkning'),
(2977, 7247, 2, 'arbetsdag'),
(2978, 7252, 2, 'förvärrad'),
(2979, 7264, 2, 'Handled'),
(2980, 7265, 2, 'Handled och hand'),
(2981, 7266, 2, 'Handleds Problem'),
(2982, 7267, 2, 'skriv'),
(2983, 7268, 2, 'avskriva'),
(2984, 7274, 2, 'x inställt'),
(2985, 7275, 2, 'Röntgen'),
(2986, 7276, 2, 'Röntgen Tolkning:'),
(2987, 7277, 2, 'Röntgen Tolkning:'),
(2988, 7278, 2, 'Endast X12: Ersättningskrav '),
(2989, 7279, 2, 'X12 Partner'),
(2990, 7280, 2, 'X12 Partners'),
(2991, 7284, 2, 'Y'),
(2992, 7285, 2, 'År'),
(2993, 7286, 2, 'år'),
(2994, 7287, 2, 'År Visa'),
(2995, 7288, 2, 'År'),
(2996, 7292, 2, 'JA'),
(2997, 7293, 2, 'Ja'),
(2998, 7294, 2, 'ja'),
(2999, 7295, 2, 'JA!'),
(3000, 7296, 2, 'Ja, radera och logga'),
(3001, 7298, 2, 'Ja/Nej'),
(3002, 7299, 2, 'Ja:'),
(3003, 7303, 2, 'Du håller på att permanent ersätta den befintliga mallen. Är du säker på att du vill fortsätta?'),
(3004, 7305, 2, 'Det är inte tillåtet att ta bort denna händelse'),
(3005, 7306, 2, 'Du har inte tillåtelse att redigera den här händelsen'),
(3006, 7307, 2, 'Du har inte behörighet för detta.'),
(3007, 7308, 2, 'Du har inte behörighet att komma åt den här gruppen.'),
(3008, 7309, 2, 'Du har inte behörighet att lägga till / redigera frågor'),
(3009, 7311, 2, 'Du har inte behörighet att se det här mötet.'),
(3010, 7313, 2, 'Du kan inte komma åt denna funktion direkt.'),
(3011, 7314, 2, 'Du kan inte komma åt den här sidan direkt.'),
(3012, 7319, 2, 'Du har inte valt några åtgärder.'),
(3013, 7320, 2, 'Du har inte behörighet att se / redigera denna anmärkning'),
(3014, 7329, 2, 'Du måste först välja eller lägga till en patient.'),
(3015, 7330, 2, 'Du måste först välja eller skapa ett möte.'),
(3016, 7333, 2, 'Du måste välja några områden för att fortsätta.'),
(3017, 7339, 2, 'Ditt slutdatum är ogiltig'),
(3018, 7340, 2, 'Din händelse har strukits.'),
(3019, 7341, 2, 'Din händelse har ändrats.'),
(3020, 7342, 2, 'Din händelse har lämnats in.'),
(3021, 7345, 2, 'Din namnlista har ändrats för att uppfylla namngivnings krav.'),
(3022, 7353, 2, 'Din Post Kalender konfiguration har återställts att använda standardvärden.'),
(3023, 7354, 2, 'Din Post Kalender konfiguration har uppdaterats.'),
(3024, 7355, 2, 'Den upprepade frekvens måste vara ett heltal.'),
(3025, 7356, 2, 'Den upprepade frekvensen måste vara minst 1.'),
(3026, 7357, 2, 'Ditt startdatum är större än ditt slutdatum'),
(3027, 7358, 2, 'Ditt startdatum är ogiltig'),
(3028, 7359, 2, 'Ditt förslag misslyckats.'),
(3029, 7360, 2, 'åååå-mm-dd'),
(3030, 7362, 2, 'åååå-mm-dd dag är förknippade med detta dokument'),
(3031, 7364, 2, 'åååå-mm-dd födelsedatum'),
(3032, 7365, 2, 'åååå-mm-dd Födelsedatum'),
(3033, 7366, 2, 'ååå-mm-dd datum för utlöpande'),
(3034, 7367, 2, 'åååå-mm-dd Datum för uppkomsten eller sjukhusvistelse'),
(3035, 7368, 2, 'åååå-mm-dd datum debut, kirurgi eller början av medicinering'),
(3036, 7370, 2, 'åååå-mm-dd dagen för tillfrisknande eller slutet av medicinering'),
(3037, 7372, 2, 'åååå-mm-dd Delgivningsdatum'),
(3038, 7373, 2, 'åååå-mm-dd dagen för denna skrivelse'),
(3039, 7375, 2, 'åååå-mm-dd dokumentets datum'),
(3040, 7376, 2, 'åååå-mm-dd händelse datum eller startdatum'),
(3041, 7383, 2, 'åååå-mm-dd sista datum för detta evenemang'),
(3042, 7387, 2, 'noll'),
(3043, 7389, 2, 'postadress'),
(3044, 7390, 2, 'postnummer'),
(3045, 7391, 2, 'land'),
(3046, 7393, 2, ' men var '),
(3047, 7394, 2, ' gick inte att komma åt'),
(3048, 7395, 2, 'Vill du verkligen radera'),
(3049, 7396, 2, 'läkemedel'),
(3050, 7397, 2, 'e-postmeddelande ej skickat'),
(3051, 7398, 2, 'från'),
(3052, 7399, 2, 'har skapats '),
(3053, 7400, 2, 'har återupptagits'),
(3054, 7401, 2, 'Historia'),
(3055, 7402, 2, 'är inget nummer'),
(3056, 7403, 2, 'är redo för ny fakturering'),
(3057, 7404, 2, 'LLL:'),
(3058, 7405, 2, 'Batchnr'),
(3059, 7406, 2, 'Medicaid orginal referensnr. '),
(3060, 7408, 2, 'finns ej!'),
(3061, 7411, 2, 'Tills'),
(3062, 7412, 2, 'Uppdateringen misslyckades, inte i databasen?'),
(3063, 7413, 2, 'präglades som faktureras endast.'),
(3064, 7414, 2, 'var kö framgångsrikt.'),
(3065, 7415, 2, '! Lämnat utan besök'),
(3066, 7416, 2, '" För kod'),
(3067, 7417, 2, '" Kontrolleras PostCalendar Inställningar!'),
(3068, 7420, 2, 'kr'),
(3069, 7421, 2, 'Kodningen av kronor är färdig'),
(3070, 7422, 2, '$ etikett (åååå-mm-dd): '),
(3071, 7423, 2, '%'),
(3072, 7425, 2, '% Annullerat <24h '),
(3073, 7426, 2, 'bör finnas, men finns inte.'),
(3074, 7427, 2, '(% Matchar alla strängar, _ matchar alla tecken)'),
(3075, 7429, 2, '(Tillbaka)'),
(3076, 7430, 2, '(Klicka för att redigera)'),
(3077, 7432, 2, '(Mer)'),
(3078, 7433, 2, '(Ny Patient)'),
(3079, 7434, 2, '(Anteckningar och Auktoriseringar)'),
(3080, 7435, 2, '(Patient anteckningar)'),
(3081, 7436, 2, '(Välj ett av dessa, eller skriv din egen rubrik)'),
(3082, 7438, 2, '* Påminnelse skickad'),
(3083, 7439, 2, '** Gör om kirurgi till enheter'),
(3084, 7440, 2, '* Obligatorisk'),
(3085, 7441, 2, '+ Patientkort hämtat'),
(3086, 7442, 2, '- Ingen'),
(3087, 7443, 2, '-- Alla --'),
(3088, 7444, 2, '--Välj uppdrag--'),
(3089, 7445, 2, '.'),
(3090, 7446, 2, '0'),
(3091, 7447, 2, '0-10'),
(3092, 7448, 2, '0-24'),
(3093, 7451, 2, '1'),
(3094, 7452, 2, '46 = Sverige. Se http://www.wtng.info för lista på andra landskoder'),
(3095, 7457, 2, '1.Vila 2. Lägg på is i två dagar 3. Komprimering lämna förbandet på plats om inte foten utvecklar domningar eller blek färg 4. Ha foten och ben i Upphöjt läge.'),
(3096, 7458, 2, '11-14'),
(3097, 7459, 2, '12 hr'),
(3098, 7460, 2, '15-19'),
(3099, 7468, 2, '20-24'),
(3100, 7477, 2, '2111-13'),
(3101, 7480, 2, '25-29'),
(3102, 7481, 2, '2:a'),
(3103, 7483, 2, '3 månader'),
(3104, 7485, 2, '3 gånger dagligen'),
(3105, 7487, 2, '30-34'),
(3106, 7488, 2, '35-39'),
(3107, 7489, 2, '3:e'),
(3108, 7491, 2, '4 månader'),
(3109, 7493, 2, '4 gånger dagligen'),
(3110, 7495, 2, '40-44'),
(3111, 7496, 2, '45'),
(3112, 7504, 2, '4:e'),
(3113, 7509, 2, '5:e'),
(3114, 7510, 2, '6 dagar från nu'),
(3115, 7511, 2, '6 månader'),
(3116, 7512, 2, '6 månader från nu'),
(3117, 7513, 2, '6 veckor från nu'),
(3118, 7514, 2, '6:e'),
(3119, 7515, 2, '7 månader från nu'),
(3120, 7516, 2, '8 månader från nu'),
(3121, 7517, 2, '824.0 Sluten fraktur mediala malleolen'),
(3122, 7518, 2, '824.2 Sluten fraktur laterala malleolen'),
(3123, 7519, 2, '842.6 Sluten trimalleolarfraktur'),
(3124, 7520, 2, '825.32 Fraktur os naviculare (fotled)'),
(3125, 7521, 2, '825.35 Fraktur basen av 5:e metatarsalbenet'),
(3126, 7522, 2, '845.00 Stukad fotled UNS'),
(3127, 7523, 2, '845.01 Stukad fotled deltoideus lig.'),
(3128, 7524, 2, '845.02 Stukad fortled, fc-ligament'),
(3129, 7525, 2, '9 månader från nu'),
(3130, 7526, 2, '99212 Etablerade - okomplicerad'),
(3131, 7527, 2, '99213 Etablerade - Låg komplexitet'),
(3132, 7528, 2, '< I undersökningsrummet'),
(3133, 7529, 2, '> Avslutat'),
(3134, 7530, 2, '?'),
(3135, 7531, 2, '? Har ej dykt upp på avtalad tid'),
(3136, 7532, 2, 'Anlänt'),
(3137, 7533, 2, '[Ändra vy]'),
(3138, 7534, 2, '[Datum för senaste mötet]'),
(3139, 7535, 2, '[Dagar sedan senaste mötet]'),
(3140, 7538, 2, '[rekommenderas inte]'),
(3141, 7539, 2, '[Antalet möten]'),
(3142, 7540, 2, '[Rapporter]'),
(3143, 7541, 2, '[Markera alla]'),
(3144, 7542, 2, '[SQL-Ledger]'),
(3145, 7543, 2, '[Starta batchprocess]'),
(3146, 7544, 2, '[Titta på logg]'),
(3147, 7545, 2, '[Se utskrivbar rapport]'),
(3148, 7546, 2, '_PC_DUR_HOURS'),
(3149, 7547, 2, '_PC_DUR_MINUTES'),
(3150, 7548, 2, '_PC_LOCALE'),
(3151, 7549, 2, '~ Kommit sent'),
(3152, 1, 3, 'Un, Una'),
(3153, 2, 3, 'Un número de cheque o reclamación para identificar el pago'),
(3154, 3, 3, 'Un certificado de cliente para el usuario administrador'),
(3155, 7, 3, 'Se requiere un distribuidor'),
(3156, 8, 3, 'Formulario de visita GCAC debe ser agregado a esta visita'),
(3157, 9, 3, 'Un número de lote es requerido'),
(3158, 10, 3, 'Un número de lote es requerido!'),
(3159, 11, 3, 'Una letra minúscula'),
(3160, 12, 3, 'Un número'),
(3161, 14, 3, 'Un paciente con ese Nº ID ya existe'),
(3162, 15, 3, 'Un paciente con este nombre ya existe.'),
(3163, 16, 3, 'Un paciente con este Nº Seguridad Social ya existe'),
(3164, 19, 3, 'Una fuente de derivación puede ser especificada para cada visita'),
(3165, 20, 3, 'Un código IPPF relacionado es requerido!'),
(3166, 21, 3, 'Un carácter especial'),
(3167, 22, 3, 'Un valor único para identificar este campo, no visible al usuario'),
(3168, 24, 3, 'antes de las comidas'),
(3169, 25, 3, 'a.m.'),
(3170, 26, 3, 'A/F Nivel de Derecho:'),
(3171, 27, 3, 'AB'),
(3172, 28, 3, 'Abreviatura'),
(3173, 29, 3, 'Abceso:'),
(3174, 30, 3, 'Abdominal'),
(3175, 31, 3, 'Capaz de cargar peso cuatro (4) pasos:'),
(3176, 32, 3, 'Anormal'),
(3177, 33, 3, 'ABN1'),
(3178, 34, 3, 'Anormal'),
(3179, 35, 3, 'Análisis de sangre anormal'),
(3180, 36, 3, 'Crecimiento anormal del pelo'),
(3181, 37, 3, 'Mamografía anormal'),
(3182, 39, 3, 'Aborto'),
(3183, 40, 3, 'Problemas del Aborto'),
(3184, 41, 3, 'Método abortivo'),
(3185, 42, 3, 'Categorías relacionadas al Aborto'),
(3186, 43, 3, 'Abortos'),
(3187, 44, 3, 'Acerca del calendario'),
(3188, 46, 3, 'Ausencias por Diagnóstico'),
(3189, 47, 3, 'Aceptar la tarea'),
(3190, 48, 3, 'Aceptar pago por'),
(3191, 49, 3, 'Aceptar Pago por '),
(3192, 50, 3, 'Acepta la tarea'),
(3193, 51, 3, 'Control de acceso'),
(3194, 52, 3, 'Administración de la Lista de Control de Acceso'),
(3195, 54, 3, 'Acceso no permitido'),
(3196, 56, 3, 'Acceder al Portal del Paciente'),
(3197, 59, 3, 'Nombre de la Cuenta'),
(3198, 62, 3, 'Contabilidad'),
(3199, 64, 3, 'Dolores'),
(3200, 65, 3, 'Solicitud de reconocimiento (ISA14)'),
(3201, 66, 3, 'Reconocimientos, Licencias y Certificaciones'),
(3202, 67, 3, 'ACL'),
(3203, 68, 3, 'ACL Administración'),
(3204, 69, 3, 'ACL Administración no autorizada'),
(3205, 71, 3, 'Acné'),
(3206, 72, 3, 'Acta'),
(3207, 73, 3, 'Fecha de Acta'),
(3208, 74, 3, 'Acción'),
(3209, 75, 3, 'Acciones'),
(3210, 77, 3, 'Activar Reportes CCR/CCD'),
(3211, 78, 3, 'Activo'),
(3212, 79, 3, 'Alerta Activa'),
(3213, 80, 3, 'Reglas de Alerta Activa'),
(3214, 81, 3, 'Alertas activas/Recordatorios'),
(3215, 82, 3, 'Visita Activa'),
(3216, 84, 3, 'Listas Activas'),
(3217, 85, 3, 'Paciente Activo'),
(3218, 86, 3, 'Planes Activos'),
(3219, 87, 3, 'Actividad'),
(3220, 88, 3, 'Tipo de Actividad'),
(3221, 92, 3, 'Agudo en Crónico'),
(3222, 93, 3, 'añadir'),
(3223, 94, 3, 'Añadir'),
(3224, 95, 3, 'AÑADIR'),
(3225, 96, 3, 'Añadir una Sociedad'),
(3226, 98, 3, 'Añadir una Farmacia'),
(3227, 100, 3, 'Añadir un evento para '),
(3228, 101, 3, 'Añadir como nueva nota'),
(3229, 102, 3, 'Añadir como Nuevo'),
(3230, 104, 3, 'Agregar Botones'),
(3231, 105, 3, 'Agregar botones para caracteres especiales, Textos serán mostrados sobre el editor para incluir en el texto con un Click.'),
(3232, 106, 3, 'Añadir Categoría'),
(3233, 107, 3, 'Añadir Constante'),
(3234, 108, 3, 'Añadir Contexto'),
(3235, 109, 3, 'Añadir Co-pago'),
(3236, 110, 3, 'Añadir Criterios'),
(3237, 111, 3, 'Añadir Botón Personalizado'),
(3238, 112, 3, 'Añadir Diagnóstico'),
(3239, 113, 3, 'Añadir Medicamento'),
(3240, 114, 3, 'Añadir Visita'),
(3241, 115, 3, 'Añadir Visita/notas'),
(3242, 116, 3, 'Añadir Centro'),
(3243, 117, 3, 'Añadir Campo'),
(3244, 118, 3, 'Añadir las siguientes líneas al fichero de configuración de Apache'),
(3245, 119, 3, 'Añadir Grupo'),
(3246, 120, 3, 'Añadir Código CIE'),
(3247, 121, 3, 'Agregar Vacunación'),
(3248, 122, 3, 'Añadir no permitido!'),
(3249, 123, 3, 'Añadir Incidencia'),
(3250, 125, 3, 'Añadir Idioma'),
(3251, 126, 3, 'Añadir Nuevo'),
(3252, 127, 3, 'Añadir nuevo'),
(3253, 128, 3, 'Añadir nueva categoría: '),
(3254, 129, 3, 'Añadir nuevos Certificados al fichero de configuración de Apache'),
(3255, 132, 3, 'Añadir Nuevo Grupo'),
(3256, 134, 3, 'Añadir nuevo lote y transacción'),
(3257, 135, 3, 'Añadir Nueva Nota'),
(3258, 136, 3, 'Añadir nueva nota'),
(3259, 137, 3, 'Añadir Nuevo Socio'),
(3260, 140, 3, 'Añadir Nota'),
(3261, 141, 3, 'Añadir Registro de Paciente'),
(3262, 142, 3, 'Añadir Receta'),
(3263, 144, 3, 'Añadir numero del proveedor'),
(3264, 145, 3, 'Añadir Rehabilitación'),
(3265, 146, 3, 'Añadir Regla'),
(3266, 147, 3, 'Añadir a'),
(3267, 148, 3, 'Añadir a Lista de Medicación'),
(3268, 149, 3, 'Añadir Nivel Superior'),
(3269, 150, 3, 'Añadir Transacción'),
(3270, 151, 3, 'Añadir Usuario'),
(3271, 152, 3, 'Añadir Usuario al Grupo'),
(3272, 153, 3, 'Añadir/Editar Receta electrónica'),
(3273, 154, 3, 'Añadir/Editar Transacción de paciente'),
(3274, 155, 3, 'añadido'),
(3275, 156, 3, 'Añadir datos demográficos no autorizado.'),
(3276, 158, 3, 'Síndrome de Addison'),
(3277, 159, 3, 'Síndrome de Addison'),
(3278, 160, 3, 'Atributos adicionales'),
(3279, 161, 3, 'Diagnóstico adicional:'),
(3280, 162, 3, 'Historia Adicional'),
(3281, 163, 3, 'Notas adicionales a la historia'),
(3282, 164, 3, 'Información adicional'),
(3283, 165, 3, 'Laboratorios adicionales'),
(3284, 166, 3, 'Notas adicionales'),
(3285, 168, 3, 'Notas adicionales:'),
(3286, 169, 3, 'Notas adicionales: '),
(3287, 170, 3, 'Notas de Rayos X adicionales:'),
(3288, 172, 3, 'Sólo añadir'),
(3289, 173, 3, 'Libreta Direcciones'),
(3290, 174, 3, 'Libreta Direcciones'),
(3291, 175, 3, 'Dirección'),
(3292, 178, 3, 'Libreta de Direcciones'),
(3293, 179, 3, 'Entrada a la libreta de Direcciones de la empresa que realiza este procedimiento'),
(3294, 180, 3, 'Entrada a la libreta de Direcciones para el distribuidor'),
(3295, 181, 3, 'Entrada a la Libreta de Direcciones para el vendedor'),
(3296, 182, 3, 'Tipos de Libreta de Direcciones'),
(3297, 187, 3, 'Dirección1'),
(3298, 188, 3, 'Dirección2'),
(3299, 189, 3, 'DESTINATARIO'),
(3300, 190, 3, 'Ajuste'),
(3301, 191, 3, 'Importe de Ajuste'),
(3302, 192, 3, 'Ajustar'),
(3303, 193, 3, 'Ajuste'),
(3304, 194, 3, 'Ajuste importe'),
(3305, 195, 3, 'Motivos del ajuste'),
(3306, 196, 3, 'Valor de ajuste para código '),
(3307, 197, 3, 'Ajustes'),
(3308, 198, 3, 'Ajuste administrador'),
(3309, 199, 3, 'Administrador'),
(3310, 200, 3, 'email administrador'),
(3311, 201, 3, 'Administrar a través de'),
(3312, 202, 3, 'Administrado'),
(3313, 203, 3, 'Administrado por'),
(3314, 206, 3, 'Administración'),
(3315, 208, 3, 'Administradores'),
(3316, 209, 3, 'Los administradores pueden hacer todo'),
(3317, 212, 3, 'Revisión Peso de Adulto y Seguimiento'),
(3318, 213, 3, 'Revisión Peso de Adulto y Seguimiento (GCC)'),
(3319, 214, 3, 'Instrucción anticipada'),
(3320, 215, 3, 'Directriz Anticipada'),
(3321, 216, 3, 'Aviso Directriz Anticipada'),
(3322, 218, 3, 'Anticipado'),
(3323, 219, 3, 'Consejo'),
(3324, 221, 3, 'Afecta normales'),
(3325, 223, 3, 'llamadas fuera horario laboral'),
(3326, 225, 3, 'Después de hacer las configuraciones mencionadas, importar el certificado del cliente de administrador al navegador y reiniciar el servidor Apache (Contraseña vacía)'),
(3327, 226, 3, 'Después de guardar el PDF, click [Ver Log] para comprobar errores.'),
(3328, 227, 3, 'Después de guardar los ficheros de TEXTO, click [Ver Log] para comprobar errores.'),
(3329, 228, 3, 'Después de guardar su Batch, click [Ver Log] para comprobar errores.'),
(3330, 230, 3, 'Una vez completada la informacion correctamente, click en botón Guardar'),
(3331, 233, 3, 'Otra vez'),
(3332, 234, 3, 'Edad'),
(3333, 235, 3, 'Por Edad'),
(3334, 236, 3, 'Categoría edad'),
(3335, 237, 3, 'Dato edad fuera de rango.'),
(3336, 239, 3, 'Formato edad en ''desde edad'' no es válido'),
(3337, 240, 3, 'Formato edad en ''hasta edad'' no es válido'),
(3338, 241, 3, 'Edad desde'),
(3339, 243, 3, 'Edad Máxima'),
(3340, 244, 3, 'Edad Mínima'),
(3341, 245, 3, 'Rango de Edad'),
(3342, 247, 3, 'Columnas del envejecimiento:'),
(3343, 249, 3, 'Albanés'),
(3344, 250, 3, 'Alcohol'),
(3345, 251, 3, 'Consumo de alcohol'),
(3346, 253, 3, 'Contador de Alerta'),
(3347, 255, 3, 'Alertas'),
(3348, 258, 3, 'ALEUTIANO'),
(3349, 259, 3, 'Todos'),
(3350, 260, 3, 'TODOS'),
(3351, 261, 3, 'Todos (Formatos Compaginados A)'),
(3352, 262, 3, 'Todos (Formatos Compaginados B)'),
(3353, 263, 3, 'Todos (Acumulativo)'),
(3354, 266, 3, 'Todas las Categorías'),
(3355, 268, 3, 'Todos los Códigos'),
(3356, 269, 3, 'Todo el día'),
(3357, 270, 3, 'Evento de día completo'),
(3358, 271, 3, 'Todos los campos demográficos, con búsqueda y chequeo de dupicados'),
(3359, 272, 3, 'Todas las Clínicas'),
(3360, 273, 3, 'Todas las Lesiones/Problemas/Incidencias'),
(3361, 274, 3, 'Permitidos todos los Idiomas'),
(3362, 276, 3, 'Todo o parte del nombre'),
(3363, 277, 3, 'Todo o parte del apellido'),
(3364, 278, 3, 'Todo o parte de la organización'),
(3365, 280, 3, 'Todos los productos'),
(3366, 281, 3, 'Todos los proveedores'),
(3367, 282, 3, 'Todos Revisados y Negativos:'),
(3368, 283, 3, 'Todos los Temas'),
(3369, 284, 3, 'Todos los Usuarios'),
(3370, 285, 3, 'Alérgico'),
(3371, 286, 3, 'Alergias'),
(3372, 287, 3, 'Alergias:'),
(3373, 288, 3, 'Alergia'),
(3374, 289, 3, 'Importación de Alergia completado con éxito'),
(3375, 291, 3, 'Reacción Alérgica'),
(3376, 294, 3, 'Asignar'),
(3377, 295, 3, 'Permitir'),
(3378, 296, 3, 'Permitir todos los idiomas disponibles como opción en el menú de inicio sesión.'),
(3379, 297, 3, 'Permitir creación de reclamaciones con diagnósticos pero no procedimientos o cargos. La mayoría de clínicas no desean esto.'),
(3380, 298, 3, 'Permitir Depuración de Idioma'),
(3381, 299, 3, 'Permitir Email'),
(3382, 300, 3, '¿Permitir mensajes email?'),
(3383, 301, 3, '¿Permitir Email?'),
(3384, 302, 3, 'Permitir reclamación de Visita'),
(3385, 303, 3, 'Permitir el Intercambio de Información de Salud'),
(3386, 304, 3, 'Permitir Compartir Información de Vacunación'),
(3387, 305, 3, 'Permitir el Uso del Registro de Vacunaciones'),
(3388, 306, 3, 'Permitir mensajes email'),
(3389, 308, 3, 'Permitir Portal del Paciente'),
(3390, 309, 3, 'Permitir SMS'),
(3391, 310, 3, '¿Permitir SMS (mensajes de texto)?'),
(3392, 311, 3, '¿Permitir la activación instantánea de los eventos introducidos?'),
(3393, 312, 3, '¿Permitir mensajes telefónicos?'),
(3394, 313, 3, 'Permitir a los usuarios publicar eventos globales'),
(3395, 314, 3, 'Permitir a los usuarios publicar calendarios personales'),
(3396, 315, 3, 'Permitir Mensaje de Voz'),
(3397, 316, 3, 'Permitido'),
(3398, 317, 3, 'Idiomas Permitidos'),
(3399, 318, 3, 'Asignado ©'),
(3400, 323, 3, 'ya existe'),
(3401, 324, 3, 'ya existe.'),
(3402, 325, 3, 'Identificador ya usado, elija otro'),
(3403, 326, 3, 'Título ya usado, elija otro'),
(3404, 327, 3, 'Dirección alternativa'),
(3405, 328, 3, 'modificar'),
(3406, 329, 3, 'De forma alternativa, puede usar la página de búsqueda para cargar un fichero electrónico (X12835) que haya recibido de su pagador. Puede hacerlo presionando el botón Explorar y seleccionar el fichero a cargar, y luego pulsando Explorar para ejecutar la carga y mostrar las facturas correspondientes. En este caso, los otros parámetros mencionados arriba no se aplican y pueden ser ignorados. La carga guarda el fichero pero no procesa su contenido - esto se realiza de forma separada como se describe abajo.'),
(3407, 330, 3, 'AM'),
(3408, 331, 3, 'Programa AM'),
(3409, 332, 3, 'Cálculo Automático de Medidas (CAM)'),
(3410, 333, 3, 'Rastreo CAM'),
(3411, 338, 3, 'Corregir nota existente'),
(3412, 343, 3, 'Indígena americano'),
(3413, 344, 3, 'Indígena americano o Nativo de Alaska'),
(3414, 345, 3, 'AMEX'),
(3415, 346, 3, 'Amárico (Lengua de Etiopia)'),
(3416, 347, 3, 'Importe'),
(3417, 349, 3, 'Importes Cargados'),
(3418, 350, 3, 'Importe Saldo Vencido'),
(3419, 351, 3, 'Importe por esta visita'),
(3420, 352, 3, 'Importe pagado'),
(3421, 353, 3, 'Importe:'),
(3422, 354, 3, 'Importe Facturado'),
(3423, 355, 3, '¡Se requiere una fecha de finalización posterior a la fecha de inicio para los eventos repetidos!'),
(3424, 357, 3, 'Ocurrió un error durante la descarga web de los directorios de LibreEHR'),
(3425, 358, 3, 'Ocurrió un error durante la descarga web de los directorios de phpGACL'),
(3426, 359, 3, 'Ocurrió un error durante la descarga web de los directorios SQL-Ledger'),
(3427, 360, 3, 'Una incidencia GCAC incompleta ha sido creada y vinculada. Alguien tendrá que completarla más tarde.'),
(3428, 362, 3, 'Ocurrio un error inesperado.'),
(3429, 363, 3, 'Una letra mayúscula'),
(3430, 365, 3, 'Y'),
(3431, 366, 3, 'Y'),
(3432, 367, 3, 'y'),
(3433, 368, 3, 'y '),
(3434, 369, 3, '¿y toda la información subordinada? Esta acción será registrada'),
(3435, 370, 3, 'y modificador'),
(3436, 371, 3, 'y procesado.'),
(3437, 372, 3, 'y reiniciar servidor Apache'),
(3438, 373, 3, 'y la Razón es'),
(3439, 374, 3, 'Anemia'),
(3440, 375, 3, 'Tobillo'),
(3441, 376, 3, 'Tobillo + talón'),
(3442, 377, 3, 'Formulario de Evaluación del tobillo'),
(3443, 378, 3, 'Problemas de tobillo'),
(3444, 379, 3, 'Espondilitis anquilosante'),
(3445, 380, 3, 'Espondilitis anquilosante'),
(3446, 381, 3, 'Anorexia'),
(3447, 382, 3, 'Otra cosa que puede hacer en la ventana de publicación es solicitar facturación secundaria. Si selecciona la casilla de verificación antes de guardar, la reclamación original será reabierta y puesta en cola en la página de Facturación, y será procesada en el siguiente proceso de facturación.'),
(3448, 383, 3, 'ante'),
(3449, 384, 3, 'Ano normal, recto sin distensión ni masa'),
(3450, 385, 3, 'Ansiedad'),
(3451, 386, 3, 'Cualquiera'),
(3452, 387, 3, 'Cualquier Categoría'),
(3453, 388, 3, 'Cualquier parte del código deseado o su descripción'),
(3454, 389, 3, 'Cualquier parte de la especialidad deseada'),
(3455, 390, 3, 'Cualquier parte del identificador o nombre de medicamento'),
(3456, 391, 3, 'Cualquier parte del identificador o nombre de vacuna'),
(3457, 392, 3, 'Cualquier parte del nombre del paciente, o Apellido, Nombre, o X-Y'),
(3458, 394, 3, 'Clave API para puerta enlace SMS'),
(3459, 395, 3, 'Apnea'),
(3460, 396, 3, 'Aspecto'),
(3461, 397, 3, 'Aspecto:'),
(3462, 398, 3, 'Añadir esta nota'),
(3463, 399, 3, 'Añadir a la nota existente'),
(3464, 400, 3, 'Añadir a sta nota'),
(3465, 401, 3, 'Añadir a Esta Nota'),
(3466, 402, 3, 'Apendicectomía'),
(3467, 404, 3, 'Pacientes Aplicables'),
(3468, 406, 3, 'Nombre de aplicación para página de inicio de sesión y título de ventana principal'),
(3469, 407, 3, 'Código de Aplicación del receptor (GS03 - si está en blanco se usará ISA08)'),
(3470, 408, 3, 'Codigo de Aplicacion del Enviador (GS02)'),
(3471, 409, 3, 'Título de Aplicación'),
(3472, 410, 3, 'Se aplica al formulario de Constantes Vitales y Gráfica de Crecimiento'),
(3473, 412, 3, '¿Aplicar los cambios sólo al evento actual, a éste y todos los episodios futuros, o a todos los episodios?'),
(3474, 413, 3, 'aplicar a la zona afectada'),
(3475, 414, 3, 'aplicar a la piel'),
(3476, 415, 3, 'Aplicando'),
(3477, 416, 3, 'Aplicando parche al sitio'),
(3478, 417, 3, 'Cita'),
(3479, 418, 3, 'Fecha de Cita'),
(3480, 419, 3, 'Estilo de visualizacion de la cita'),
(3481, 420, 3, 'Regla para recordar Cita'),
(3482, 421, 3, 'Estado de la Cita'),
(3483, 422, 3, 'Estados de la cita'),
(3484, 423, 3, 'Cita dentro de'),
(3485, 424, 3, 'Color de Cita/Evento'),
(3486, 425, 3, 'Citas'),
(3487, 426, 3, 'Citas (escriba opcional)'),
(3488, 427, 3, 'Citas (escribir, algunos opcional)'),
(3489, 430, 3, 'Citas y Visitas'),
(3490, 431, 3, 'Informe de citas'),
(3491, 432, 3, 'Informes Citas-Visitas'),
(3492, 434, 3, 'Aprobar'),
(3493, 436, 3, 'Aprobado'),
(3494, 437, 3, 'Eventos Administrativos Aprobados'),
(3495, 440, 3, 'Citas-Visitas'),
(3496, 441, 3, 'Citas'),
(3497, 442, 3, 'Abr'),
(3498, 443, 3, 'Abril'),
(3499, 444, 3, 'Arabigo'),
(3500, 447, 3, '¿Se traducen los nombres del grupo de control de acceso?'),
(3501, 448, 3, '¿Se traducen los nombres de las categorías de cita?'),
(3502, 449, 3, '¿Se traducen los nombres de categorías de documento?'),
(3503, 450, 3, '¿Se cobran honorarios por este tipo?'),
(3504, 451, 3, '¿Se traducen los títulos de las notas del paciente?'),
(3505, 452, 3, '¿Están los códigos archivados en tablas sql externas (0-No, 1-CIE10, 2-SNOMED(RF1), 3-SNOMED(rf2))?'),
(3506, 453, 3, '¿Está preparado para completar una nueva incidencia de GCAC (Global Connection Admission Control) para esta visita?'),
(3507, 454, 3, '¿Está seguro de enviar hoy?'),
(3508, 455, 3, '¿Está seguro que quiere aprobar estos eventos?'),
(3509, 457, 3, '¿Está seguro de que desea eliminar por completo este formulario?'),
(3510, 459, 3, '¿Está seguro que desea eliminar este aviso?'),
(3511, 460, 3, '¿Está seguro que quiere eliminar este evento?'),
(3512, 461, 3, '¿Está seguro que quiere eliminar este asunto de la base de datos?'),
(3513, 462, 3, '¿Está usted seguro que quiere eliminar esta nota?'),
(3514, 464, 3, '¿Está seguro que quiere editar estos eventos?'),
(3515, 465, 3, '¿Está seguro que quiere ocultar estos eventos?'),
(3516, 467, 3, '¿Está seguro que quiere visualizar estos eventos?'),
(3517, 468, 3, 'Está seguro que desea eliminar el grupo entero nombrado'),
(3518, 469, 3, 'Está seguro que desea eliminar la lista entera'),
(3519, 470, 3, 'Está seguro que quiere eliminar el campo interno'),
(3520, 471, 3, '¿Está seguro que quiere eliminar los campos seleccionados?'),
(3521, 472, 3, '¿Está seguro que quiere continuar con estas acciones?'),
(3522, 473, 3, 'Zona no especificada'),
(3523, 474, 3, 'Brazo'),
(3524, 475, 3, 'Armenio'),
(3525, 477, 3, 'Arritmia'),
(3526, 478, 3, 'Artritis'),
(3527, 479, 3, 'Artritis/Enfermedad degenerativa de articulaciones'),
(3528, 480, 3, 'Artritis/Enfermedad degenerativa de articulaciones'),
(3529, 481, 3, 'como'),
(3530, 482, 3, 'Desde'),
(3531, 484, 3, 'Asiático'),
(3532, 487, 3, 'Evaluación'),
(3533, 488, 3, 'Asignado a'),
(3534, 489, 3, 'Ayudante'),
(3535, 490, 3, 'Asma'),
(3536, 491, 3, 'en'),
(3537, 492, 3, 'Se requiere al menos un parámetro de búsqueda si selecciona Todos.'),
(3538, 493, 3, 'En el Escafoides'),
(3539, 494, 3, 'En el Escafoides:'),
(3540, 495, 3, 'Equipo de atletismo'),
(3541, 497, 3, 'Lesión Deportiva'),
(3542, 498, 3, 'Certificado CA de ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(3543, 499, 3, 'Host de auditoría ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(3544, 500, 3, 'Certificado local de ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(3545, 501, 3, 'Puerto de auditoría ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(3546, 503, 3, 'Atención'),
(3547, 504, 3, 'Atención'),
(3548, 509, 3, 'Auditoría Backups de inicio de sesión'),
(3549, 510, 3, 'Auditoría de inicio de sesión varios'),
(3550, 511, 3, 'Auditoría Orden de inicio de sesión'),
(3551, 512, 3, 'Auditoría registro inicio de sesión del paciente'),
(3552, 513, 3, 'Auditoría Planificación inicio sesión'),
(3553, 514, 3, 'Auditoría Administración de Seguridad inicio sesión'),
(3554, 515, 3, 'Auditoría Consulta SELECT inicio sesión'),
(3555, 516, 3, 'Ago'),
(3556, 517, 3, 'Agosto'),
(3557, 519, 3, 'Autorización'),
(3558, 520, 3, 'Autorización/notas'),
(3559, 523, 3, 'Grupo de Autorización'),
(3560, 524, 3, 'Estatus de autorización'),
(3561, 525, 3, 'Autorizaciones'),
(3562, 526, 3, 'Autorizar'),
(3563, 527, 3, 'Autorizar - cualquier visita'),
(3564, 528, 3, 'Autorizar - mis visitas'),
(3565, 530, 3, 'Autorizado'),
(3566, 531, 3, 'Autorización solamente'),
(3567, 532, 3, 'Envío automático'),
(3568, 535, 3, 'Crear automáticamente nuevas visitas'),
(3569, 536, 3, 'Auto-generado'),
(3570, 537, 3, 'Cálculos Automáticos de Medida (CAM)'),
(3571, 542, 3, 'Seguimiento Cálculos Automáticos de Medida (CAM)'),
(3572, 543, 3, 'Medidas Automatizadas'),
(3573, 544, 3, 'Automático'),
(3574, 546, 3, 'Crear automáticamente nuevas visitas cuando en el estado de una cita se selecciona -@- (llegado)'),
(3575, 549, 3, 'Automóvil Médico'),
(3576, 550, 3, 'Autoguardado'),
(3577, 551, 3, 'Categorías Disponibles'),
(3578, 552, 3, 'Horas disponibles'),
(3579, 557, 3, 'Media Mensual'),
(3580, 558, 3, 'Avulsión/fractura por avulsión'),
(3581, 559, 3, 'Avulsión de maleolo lateral'),
(3582, 560, 3, 'Avulsión de maléolo tibial '),
(3583, 561, 3, 'Basado en el Conocimiento'),
(3584, 562, 3, 'Axilar'),
(3585, 565, 3, 'dos veces por día'),
(3586, 566, 3, 'Atrás'),
(3587, 567, 3, 'atrás'),
(3588, 568, 3, 'Retrocede ocho visitas'),
(3589, 569, 3, 'Retrocede once visitas'),
(3590, 570, 3, 'Retroceder cinco visitas'),
(3591, 571, 3, 'Retrocede cuatro visitas'),
(3592, 572, 3, 'Retrocede nueve visitas'),
(3593, 573, 3, 'Retroced una visita'),
(3594, 574, 3, 'Dolor de espalda'),
(3595, 575, 3, 'Problemas de espalda'),
(3596, 576, 3, 'Retrocede siete visitas'),
(3597, 577, 3, 'Retrocede seis visitas'),
(3598, 578, 3, 'Cirugia de espalda'),
(3599, 579, 3, 'Retrocede diez visitas'),
(3600, 580, 3, 'Retrocede tres visitas'),
(3601, 581, 3, 'Volver a la página de Administración'),
(3602, 584, 3, 'Volver al paciente'),
(3603, 585, 3, 'Volver a los usuarios'),
(3604, 586, 3, 'Volver a Vista'),
(3605, 587, 3, 'Retrocede doce visitas'),
(3606, 588, 3, 'Retrocede dos visitas'),
(3607, 590, 3, 'Backup'),
(3608, 591, 3, 'Se ha creado el fichero de backup. Ahora comenzará la descarga.'),
(3609, 593, 3, 'Backup creado correctamente'),
(3610, 594, 3, 'Cheque sin fondos'),
(3611, 595, 3, 'Mal crédito'),
(3612, 596, 3, 'Bahasa Indonesia'),
(3613, 597, 3, 'Bal'),
(3614, 598, 3, 'Balance'),
(3615, 599, 3, 'balance'),
(3616, 600, 3, 'Importe Balance'),
(3617, 601, 3, 'Balance a pagar'),
(3618, 603, 3, 'Recibo bancario'),
(3619, 607, 3, 'Base del quinto (5to) Metatarsiano'),
(3620, 608, 3, 'Base del quinto (5to) Metatarsiano:'),
(3621, 612, 3, 'Herramienta de Comunicación del Batch'),
(3622, 613, 3, 'Batch de entrada de pagos'),
(3623, 614, 3, 'Serie de Pagos'),
(3624, 615, 3, 'Iniciado proceso Batch; esto puede tardar unos minutos.'),
(3625, 616, 3, 'Resultados de la serie (Batch)'),
(3626, 617, 3, 'Comunicación en serie'),
(3627, 619, 3, 'porque no existe ese id.'),
(3628, 620, 3, 'Empezar'),
(3629, 621, 3, 'Fecha comienzo'),
(3630, 623, 3, 'Fecha de inicio de servicio aaaa-mm-dd'),
(3631, 624, 3, 'Hora de inicio del día para los eventos del calendario'),
(3632, 626, 3, 'Eructo'),
(3633, 628, 3, 'Bengali'),
(3634, 630, 3, 'entre'),
(3635, 633, 3, 'Bilateral'),
(3636, 634, 3, 'Bilateral:'),
(3637, 636, 3, 'Fecha factura:'),
(3638, 637, 3, 'Factura/Cobrar'),
(3639, 638, 3, 'Facturado'),
(3640, 640, 3, 'Facturación'),
(3641, 641, 3, 'Facturación (escritura opcional)'),
(3642, 642, 3, 'Atención facturación'),
(3643, 644, 3, 'Código de facturación para el Servicio Solicitado'),
(3644, 645, 3, 'Códigos de facturación'),
(3645, 646, 3, 'Datos de facturación'),
(3646, 647, 3, 'Departamento de Facturación'),
(3647, 648, 3, 'Centro de Facturación'),
(3648, 649, 3, 'Información facturación'),
(3649, 650, 3, 'Dirección facturación'),
(3650, 655, 3, 'Administrador de Facturación'),
(3651, 656, 3, 'Nota de facturación'),
(3652, 657, 3, 'Nota de facturación para '),
(3653, 658, 3, 'Nota de facturación:'),
(3654, 659, 3, 'Resultados de la cola de la facturación:'),
(3655, 660, 3, 'Informe de Facturación'),
(3656, 661, 3, 'Estado de facturación'),
(3657, 662, 3, 'Estado de Facturación = No facturados'),
(3658, 663, 3, 'facturación para '),
(3659, 665, 3, 'Biopsia'),
(3660, 666, 3, 'F.Nacim.'),
(3661, 669, 3, 'Negro'),
(3662, 670, 3, 'Pulmón negro'),
(3663, 671, 3, 'Negro o Afroamericano'),
(3664, 672, 3, 'Cáncer de vejiga'),
(3665, 673, 3, 'Infecciones de vejiga'),
(3666, 674, 3, 'Formularios en Blanco'),
(3667, 675, 3, 'Problemas de sangrado'),
(3668, 676, 3, 'Puntos ciegos'),
(3669, 677, 3, 'Hinchazón'),
(3670, 678, 3, 'Atascado'),
(3671, 679, 3, 'Sangre'),
(3672, 680, 3, 'Presión Arterial'),
(3673, 681, 3, 'Presión arterial'),
(3674, 682, 3, 'Sangra por la nariz'),
(3675, 683, 3, 'Blue Cross Blue Shield'),
(3676, 684, 3, 'Las líneas azules en este reporte son informativas. Líneas negras muestran información existente. Líneas verdes muestran cambios aplicados correctamente. Líneas rojas indican errores o cambios que no fueron aplicados, y deben ser procesados manualmente. Reclamaciones actuales denegadas y pagos revertidos no se manejan automáticamente y aparecerán en rojo.'),
(3677, 685, 3, 'Visión borrosa'),
(3678, 686, 3, 'IMC'),
(3679, 687, 3, 'Estado del IMC'),
(3680, 689, 3, 'Región corporal'),
(3681, 690, 3, 'Área Corporal'),
(3682, 691, 3, 'Área corporal, si es aplicable'),
(3683, 692, 3, 'Sensibilidad en hueso:'),
(3684, 693, 3, 'Sensibilidad en hueso: Maléolo Tibial'),
(3685, 694, 3, 'Boleano'),
(3686, 696, 3, 'Infer.'),
(3687, 697, 3, 'Ambos Oídos'),
(3688, 698, 3, 'ambos oídos'),
(3689, 699, 3, 'inferior'),
(3690, 701, 3, 'CASILLA 10 A. relacionados con el Empleo '),
(3691, 702, 3, 'CASILLA 10 B. Accidentes de tráfico '),
(3692, 703, 3, 'CASILLA 10 C. Otros Accidentes '),
(3693, 706, 3, 'CASILLA 15. Fecha de la misma o similar enfermedad (aaaa-mm-dd)'),
(3694, 708, 3, 'CASILLA 16. Fecha de incapacidad a partir de (aaaa-mm-dd):'),
(3695, 709, 3, 'CASILLA 16. Fecha de incapacidad (aaaa-mm-dd):'),
(3696, 710, 3, 'CASILLA 18. Fecha de inicio de hospitalización (aaaa-mm-dd): '),
(3697, 711, 3, 'CASILLA 18. Fecha de inicio de hospitalización (aaaa-mm-dd): '),
(3698, 712, 3, 'CASILLA 20. ¿Se utiliza Laboratorio externo?'),
(3699, 713, 3, 'CASILLA 22. Código del re-envío de Medicaid (CIE-9) '),
(3700, 714, 3, 'CASILLA 23. Número de Autorización previa '),
(3701, 715, 3, 'PA'),
(3702, 716, 3, 'PA Diastólica'),
(3703, 717, 3, 'PA Sistólica'),
(3704, 719, 3, 'Pad'),
(3705, 721, 3, 'Pas'),
(3706, 722, 3, 'Portugués brasileño'),
(3707, 723, 3, 'mama'),
(3708, 724, 3, 'Biopsia de mama'),
(3709, 725, 3, 'Secreción de la mama'),
(3710, 726, 3, 'Enfermedad de la mama'),
(3711, 727, 3, 'Revisión de mama'),
(3712, 728, 3, 'Masa en la mama'),
(3713, 730, 3, 'Sonidos respiratorios:'),
(3714, 732, 3, 'Huesos fracturados'),
(3715, 734, 3, 'Forma de bronquitis'),
(3716, 735, 3, 'Explorar'),
(3717, 736, 3, 'Explorar para Registro'),
(3718, 737, 3, 'Contusiones/Hematomas'),
(3719, 739, 3, 'Abultamiento derecho:'),
(3720, 741, 3, 'Ardor al orinar'),
(3721, 742, 3, 'Ardor Al Orinar'),
(3722, 744, 3, 'Ocupado'),
(3723, 745, 3, 'pero todavía no procesado.'),
(3724, 746, 3, 'Glúteo'),
(3725, 747, 3, 'Gluteos + S.I.'),
(3726, 748, 3, 'por'),
(3727, 749, 3, 'Por'),
(3728, 750, 3, 'por boca'),
(3729, 751, 3, 'Por/Origen'),
(3730, 752, 3, 'Por:'),
(3731, 753, 3, 'C'),
(3732, 754, 3, 'Certificado de CA para verificar el RFC 5425 TLS del servidor syslog.'),
(3733, 755, 3, 'Tiempo de Vida del Caché (en segundos)'),
(3734, 756, 3, '¿Plantilla de salida del caché?'),
(3735, 757, 3, 'Consumo de cafeína'),
(3736, 758, 3, 'Calendario'),
(3737, 759, 3, 'Fin Hora Calendario'),
(3738, 760, 3, 'Intervalo Calendario'),
(3739, 761, 3, 'Pantalla de calendario'),
(3740, 762, 3, 'Ajustes del calendario'),
(3741, 763, 3, 'Hora de inicio de calendario'),
(3742, 764, 3, 'Calendario UI'),
(3743, 765, 3, 'Vista de Calendario'),
(3744, 766, 3, 'Llamada para añadir Formulario () va aquí.<br>'),
(3745, 767, 3, 'Calorías'),
(3746, 768, 3, 'Camboyano'),
(3748, 774, 3, 'Cancelar'),
(3749, 775, 3, 'Cancelar cambios'),
(3750, 776, 3, 'Cancelado'),
(3751, 777, 3, 'Cáncer'),
(3752, 778, 3, 'Detección de Cancer: Detección Cancer de Colon'),
(3753, 779, 3, 'Detección de Cancer: Mamografía'),
(3754, 780, 3, 'Detección de Cancer: Prueba de Papanicolau'),
(3755, 781, 3, 'Detección de Cancer: Detección de Cancer de Próstata'),
(3756, 782, 3, 'No se puede agregar esta entrada, ¡porque ya existe!'),
(3757, 783, 3, '¡No se puede agregar/actualizar esta entrada porque ya existe un duplicado!'),
(3758, 785, 3, 'no puede convertirse a JPEG. ¿probablemente ImageMagick no está instalado?'),
(3759, 787, 3, 'no se puede mostrar en línea porque su tipo no está soportado por el navegador.'),
(3760, 788, 3, 'no se puede mostrar en línea porque su tipo no está soportado por el navegador'),
(3761, 789, 3, 'no se puede mostrar en línea porque su tipo no está soportado por el navegador.'),
(3762, 790, 3, 'No se puede crear'),
(3763, 795, 3, 'No se puede encontrar '),
(3764, 796, 3, 'No se puede encontrar fichero de destino'),
(3765, 799, 3, 'No puede encontrar al paciente con ese ID de cliente en SQL-Ledger'),
(3766, 800, 3, 'No se puede encontrar el documento de referencia de postscript en '),
(3767, 801, 3, 'No puede encontrar al facultativo con SQL-Ledger empleado '),
(3768, 802, 3, 'No puede modificar los pagos. La no-distribución es negativa.'),
(3769, 803, 3, 'No se puede abrir '),
(3770, 804, 3, 'No se puede enviar al seguro.La entidad pagadora seleccionada es el paciente.'),
(3771, 805, 3, 'No puede enviar al Paciente. La Entidad pagadora seleccionada es el seguro.'),
(3772, 806, 3, 'No puede enviar pagos. La distribución es negativa.'),
(3773, 807, 3, 'No se puede leer'),
(3774, 808, 3, 'No se puede leer el directorio'),
(3775, 809, 3, '¡No se puede actualizar porque no está editando una entrada existente!.'),
(3776, 810, 3, 'Poner en Mayúsculas'),
(3777, 812, 3, 'cápsula'),
(3778, 813, 3, 'Tarjeta'),
(3779, 814, 3, 'Cateterismo Cardiaco'),
(3780, 815, 3, 'Ecocardiograma'),
(3781, 816, 3, 'Cardiovascular');
INSERT INTO `lang_definitions` VALUES
(3782, 821, 3, 'Daño de cartílago/ condral / disco articular.'),
(3783, 822, 3, 'Lesión de cartílago'),
(3784, 823, 3, 'Nl Pulsos Carotideos, pulsos pedios nl'),
(3785, 824, 3, 'efectivo'),
(3786, 825, 3, 'Efectivo'),
(3787, 826, 3, 'Entradas Efectivo'),
(3788, 827, 3, 'Entradas de efectivo por facultativo'),
(3789, 829, 3, 'Cirugía de cataratas'),
(3790, 830, 3, 'Cataratas'),
(3791, 831, 3, 'Categorías'),
(3792, 832, 3, 'Categorías para'),
(3793, 833, 3, 'Categoría'),
(3794, 834, 3, 'categoría'),
(3795, 835, 3, 'Categoría '),
(3796, 836, 3, 'Detalles de Categoría'),
(3797, 837, 3, 'Límites de Categoría'),
(3798, 838, 3, 'Nombre de Categoría'),
(3799, 839, 3, 'Nombre de la Categoria está vacío'),
(3800, 840, 3, 'Categoría/Título'),
(3801, 841, 3, 'Caucásico'),
(3802, 842, 3, 'Imprime la receta de la visita con la información del proveedor primario'),
(3803, 850, 3, 'CDR'),
(3804, 852, 3, 'Celda'),
(3805, 853, 3, 'Teléfono Móvil'),
(3806, 855, 3, 'Teléfono Móvil'),
(3807, 856, 3, 'Certificación central'),
(3808, 857, 3, 'Centroamericano/Sudamericano'),
(3809, 858, 3, 'La localización del fichero de Certificado de Autoridad crt no puede estar vacía'),
(3810, 859, 3, 'La localizacion de la clave del fichero del Certificado de Autoridad no puede estar vacía'),
(3811, 860, 3, 'Certificado para enviar a la RFC 5425 TLS del servidor syslog.'),
(3812, 861, 3, 'Usuario del Certificado'),
(3813, 862, 3, 'Certificados'),
(3814, 864, 3, 'ChampUS'),
(3815, 865, 3, 'ChampUSVA'),
(3816, 866, 3, 'cambiar'),
(3817, 867, 3, 'Cambio'),
(3818, 868, 3, 'Cambia actividad'),
(3819, 870, 3, 'Cambio en la Visión'),
(3820, 871, 3, 'Cambio en la Visión'),
(3821, 874, 3, 'Cambiado'),
(3822, 875, 3, 'Intestino Cambiado'),
(3823, 877, 3, 'Características'),
(3824, 878, 3, 'Caracteres Restantes'),
(3825, 879, 3, 'Cargo'),
(3826, 880, 3, 'Ajuste del cargo'),
(3827, 881, 3, 'Cobro codificado'),
(3828, 882, 3, 'Cargos'),
(3829, 883, 3, 'Historia'),
(3830, 884, 3, 'Gráfico de Actividad'),
(3831, 885, 3, 'Informe de Actividad - Entradas/Salidas de gráficos'),
(3832, 886, 3, 'Nº Identificación de gráfico'),
(3833, 887, 3, 'Nº Identificación de gráfico:'),
(3834, 889, 3, 'Actividad de Localización de Gráficos'),
(3835, 890, 3, 'Nota en el gráfico'),
(3836, 891, 3, 'Número de gráfico'),
(3837, 892, 3, 'Gráfico de Localizaciones archivadas'),
(3838, 893, 3, 'Gráfico de seguimiento'),
(3839, 894, 3, 'Gráfico de seguimiento'),
(3840, 895, 3, 'Gráficas retiradas'),
(3841, 896, 3, 'Gráficas retiradas'),
(3842, 898, 3, 'Comprobar'),
(3843, 899, 3, 'comprobar'),
(3844, 900, 3, 'Comprobar todo'),
(3845, 902, 3, 'Importe del cheque'),
(3846, 903, 3, 'Fecha del cheque'),
(3847, 904, 3, 'Comprobar diferencias entre las traducciones con Tabla del Idioma Personalizada'),
(3848, 906, 3, 'Llegue a'),
(3849, 907, 3, 'Comprobar Fecha Entrada'),
(3850, 909, 3, 'Revisar los Resultados de Laboratorio'),
(3851, 912, 3, 'Número de cheque'),
(3852, 915, 3, 'Pago por Cheque'),
(3853, 916, 3, 'Marque la casilla si es un fichero encriptado'),
(3854, 917, 3, 'Selecciona ésto si quiere que los facultativos vean todas las citas por defecto y no sólo las suyas.'),
(3855, 919, 3, 'Comprobar Fecha/EOB:'),
(3856, 920, 3, 'Comprobar Número EOB.:'),
(3857, 921, 3, 'Comprobar/Número de Referencia'),
(3858, 922, 3, 'Comprobar/Número de referencia'),
(3859, 923, 3, 'Lista de casillas'),
(3860, 924, 3, 'Lista de casillas'),
(3861, 925, 3, 'Casilla con Texto'),
(3862, 926, 3, 'Casilla con texto'),
(3863, 928, 3, 'Comprobado'),
(3864, 929, 3, 'Casilla marcada = sí, vacía = no'),
(3865, 932, 3, 'Comprobación'),
(3866, 933, 3, 'Sumatorio'),
(3867, 934, 3, 'Pecho'),
(3868, 935, 3, 'Pecho CTAB'),
(3869, 936, 3, 'Dolor de Pecho'),
(3870, 937, 3, 'Dolor de Pecho:'),
(3871, 938, 3, 'Dolores de Pecho'),
(3872, 940, 3, 'Var'),
(3873, 942, 3, 'Síntoma Principal'),
(3874, 943, 3, 'Niño'),
(3875, 945, 3, 'Estado de vacunación de la niñez (GCC)'),
(3876, 946, 3, 'Escalofríos'),
(3877, 947, 3, 'Chino'),
(3878, 948, 3, 'Chino (simplificado)'),
(3879, 949, 3, 'Chino (tradicional)'),
(3880, 951, 3, 'Opciones'),
(3881, 952, 3, 'Colecistectomía'),
(3882, 954, 3, 'Colecistectomía'),
(3883, 955, 3, 'Elegir'),
(3884, 956, 3, 'Elija una sección y haga click en un elemento dentro de ella; luego, en la otra sección, verá remarcados los elementos relacionados, puede hacer click en esa sección para añadir y borrar relaciones.'),
(3885, 957, 3, 'Criterios de selección'),
(3886, 962, 3, 'Lista de Selecciones'),
(3887, 965, 3, 'Seleccione formato de impresión para este informe de visitas.'),
(3888, 967, 3, 'Bronquitis Crónica'),
(3889, 968, 3, 'Dolor crónico de articulaciones'),
(3890, 969, 3, 'Enfermedad Renal Crónica (ERC)'),
(3891, 970, 3, 'Sinovitis crónica/derrame/dolor articular/gota'),
(3892, 971, 3, 'Crónico/Recurrente'),
(3893, 973, 3, 'Cirrosis de hígado'),
(3894, 974, 3, 'Cirrosis del Hígado'),
(3895, 975, 3, 'Ciudad'),
(3896, 976, 3, 'Nombre de Ciudad'),
(3897, 977, 3, 'Ciudad, Provincia'),
(3898, 978, 3, 'Ciudad, Código Postal'),
(3899, 979, 3, 'Ciudad/Provincia'),
(3900, 980, 3, 'Reclamación'),
(3901, 981, 3, 'Reclamación '),
(3902, 983, 3, 'Prueba de Reclamación ha terminado'),
(3903, 984, 3, 'Tipo de Reclamación'),
(3904, 985, 3, 'Reclamación generada para presentar'),
(3905, 986, 3, 'La Reclamación se ha guardado en el fichero '),
(3906, 987, 3, 'Reclamaciones'),
(3907, 988, 3, 'Clasificación'),
(3908, 989, 3, 'Limpiar'),
(3909, 991, 3, 'Limpiar todos'),
(3910, 992, 3, 'Limpiar Datos HL7'),
(3911, 993, 3, 'Limpiar Justificación'),
(3912, 994, 3, 'Vaciar Cache Smarty'),
(3913, 995, 3, 'Información requerida por la Cámara de compensación en la creación del Batch EDI 270'),
(3914, 996, 3, 'Número CLIA'),
(3915, 997, 3, 'Click'),
(3916, 998, 3, 'Click ''export'' para exportar su Categoría, Subcategoría, Item o Datos contenidos a un fichero de texto. Cualquier similitud de este fichero con un fichero tipo XML es pura coincidencia. Las etiquetas de abrir y cerrar deben estar en la misma línea y deben ser minúsculas sin espacios. Para importar, localize el fichero y click ''Importar''. Si los datos son completamente diferentes se unen a los datos existentes. Si hay datos con nombres similares, el nombre más antiguo se mantiene mientras que al nuevo se le agrega un número al final.'),
(3917, 999, 3, 'Click en el gráfico para nueva anotacion, click de nuevo para eliminarla.'),
(3918, 1000, 3, 'Click descargar Certificado para descargar los certificados en el fichero ssl.zip'),
(3919, 1001, 3, 'Click para más'),
(3920, 1005, 3, 'Click aquí'),
(3921, 1006, 3, 'Click aquí para añadir un nuevo paciente.'),
(3922, 1007, 3, 'Click aqui para añadir un nuevo cambio de estado de la lesion y editar la actividad diaria.'),
(3923, 1008, 3, 'Click aquí para elegir una fecha'),
(3924, 1009, 3, 'Click aquí para elegir una fecha y hora'),
(3925, 1010, 3, 'Click aquí para elegir una fecha de inicio'),
(3926, 1020, 3, 'Click aquí para buscar'),
(3927, 1021, 3, 'Click aquí para actualizar configuración de prioridad, categoría y apodos'),
(3928, 1022, 3, 'Click aquí para ver todo.'),
(3929, 1023, 3, 'Click aqui para vista y gráficos'),
(3930, 1025, 3, 'Click aquí para vista y grafico de todas las constantes vitales.'),
(3931, 1026, 3, 'Click aquí para ver los detalles del paciente'),
(3932, 1027, 3, 'Click aquí para ver todos.'),
(3933, 1029, 3, 'Click botón Instalar para instalar la versión de la base de datos desde la siguiente fecha'),
(3934, 1030, 3, 'Click aquí para aumentar los intervalos de tiempo'),
(3935, 1031, 3, 'Click en Nombre Paciente para abrir el fichero del paciente'),
(3936, 1032, 3, 'Click Refrescar para ver todos los resultados o introduzca un criterio de búsqueda arriba para ver resultados específicos.'),
(3937, 1034, 3, 'Nuevo Paciente'),
(3938, 1035, 3, 'Click para agregar nueva consulta'),
(3939, 1037, 3, 'Click para descargar'),
(3940, 1038, 3, 'Click para editar'),
(3941, 1040, 3, 'Click para editar este evento'),
(3942, 1041, 3, 'Click para generar el informe'),
(3943, 1043, 3, 'Click para imprimir'),
(3944, 1044, 3, 'Click para recibir (añadir) nuevo lote'),
(3945, 1045, 3, 'Click para seleccionar'),
(3946, 1046, 3, 'Click Para Seleccionar'),
(3947, 1047, 3, 'Click para seleccionar un código estándar industrial para este procedimiento'),
(3948, 1048, 3, 'Click para seleccionar el codigo de procedimiento opcional'),
(3949, 1050, 3, 'Click para seleccionar o cambiar código CVX'),
(3950, 1051, 3, 'Click para seleccionar o cambiar diagnósticos'),
(3951, 1052, 3, 'Click para seleccionar o cambiar códigos de servicios'),
(3952, 1053, 3, 'Click para seleccionar el paciente'),
(3953, 1054, 3, 'Click para seleccionar un código relacionado'),
(3954, 1055, 3, 'Click para seleccionar servicios a realizar si este resultado es anormal'),
(3955, 1056, 3, 'Click para seleccionar el procedimiento deseado'),
(3956, 1058, 3, 'Click para ver'),
(3957, 1059, 3, 'Click para ver o editar'),
(3958, 1060, 3, 'Click para ver/editar'),
(3959, 1061, 3, 'Click botón Actualizar para actualizar la versión de la base de datos desde la fecha siguiente'),
(3960, 1063, 3, 'Click:'),
(3961, 1064, 3, 'Días para Vencimiento del Certificado del Cliente'),
(3962, 1065, 3, 'Periodo de validación del Certificado del Cliente'),
(3963, 1066, 3, 'El certificado de validación del cliente debe ser un número válido'),
(3964, 1067, 3, 'Copia para el cliente'),
(3965, 1069, 3, 'Resumen de historia clínica del cliente'),
(3966, 1072, 3, 'Perfil de cliente - Nuevos Clientes'),
(3967, 1073, 3, 'Perfil de cliente - Clientes Únicos'),
(3968, 1074, 3, 'Clientes'),
(3969, 1075, 3, 'Clínica'),
(3970, 1076, 3, 'Copia para la Clínica'),
(3971, 1077, 3, 'Registro Diario de la Clínica'),
(3972, 1078, 3, 'Nº Identificación de Clínica'),
(3973, 1079, 3, 'Clínico'),
(3974, 1080, 3, 'Gestor de Alertas para las Reglas de Decisión Clinicas'),
(3975, 1083, 3, 'Planes Clínicos'),
(3976, 1084, 3, 'Medidas de Calidad Clínica (GCC)'),
(3977, 1087, 3, 'Recordatorios Clínicos'),
(3978, 1088, 3, 'Reportes Clínicos'),
(3979, 1089, 3, 'Reglas Clínicas para Categoría de Acción'),
(3980, 1090, 3, 'Reglas Clínicas para Asunto de Acción'),
(3981, 1091, 3, 'Reglas Clínicas para Métodos de filtro'),
(3982, 1092, 3, 'Reglas Clínicas para Objetivo de Métodos'),
(3983, 1093, 3, 'Reglas Clínicas'),
(3984, 1094, 3, 'Reglas Clínicas para Intervalos de Edad'),
(3985, 1095, 3, 'Reglas Clínicas de Comparación'),
(3986, 1096, 3, 'Reglas Clínicas de Tipos de Visitas'),
(3987, 1097, 3, 'Reglas Clínicas de opciones de Vencimientos de Recordatorios'),
(3988, 1098, 3, 'Reglas Clínicas de opciones de Desactivación de Recordatorios'),
(3989, 1099, 3, 'Reglas Clínicas de intervalos de recordatorios'),
(3990, 1100, 3, 'Reglas Clínicas de Métodos de Recordatorios'),
(3991, 1101, 3, 'Reglas Clínicas de Intervalos de Destino'),
(3992, 1102, 3, 'Destinos Clínicos'),
(3993, 1106, 3, 'Médicos'),
(3994, 1107, 3, 'Clonar'),
(3995, 1108, 3, 'Clonar Visita Anterior'),
(3996, 1109, 3, 'Cerrar'),
(3997, 1111, 3, 'cerrar ventana'),
(3998, 1112, 3, 'Cerrado'),
(3999, 1113, 3, 'cm'),
(4000, 1114, 3, 'Margenes del formulario CMS 1500'),
(4001, 1118, 3, 'CMS ID'),
(4002, 1127, 3, 'NC 2-12 Intacto'),
(4003, 1128, 3, 'Copago'),
(4004, 1129, 3, 'Copago pagado'),
(4005, 1130, 3, 'Copago'),
(4006, 1131, 3, 'Código'),
(4007, 1132, 3, 'código'),
(4008, 1133, 3, 'Buscador de Código'),
(4009, 1134, 3, 'Código debe ser dos letras en minúscula'),
(4010, 1135, 3, 'Código o símbolo para indicar moneda'),
(4011, 1136, 3, 'Código de Texto'),
(4012, 1138, 3, 'tipo de código'),
(4013, 1141, 3, 'Típos de Código'),
(4014, 1143, 3, 'Codificado'),
(4015, 1144, 3, 'Códigos'),
(4016, 1145, 3, 'Codificando'),
(4017, 1147, 3, 'Codificación - cualquier visita(escribir, con algunas opciones)'),
(4018, 1148, 3, 'Codificación - mis visitas(escribir, con algunas opciones)'),
(4019, 1149, 3, 'Codificación no autorizada'),
(4020, 1150, 3, 'Café'),
(4021, 1152, 3, 'Coseguro'),
(4022, 1153, 3, 'Coll w/o'),
(4023, 1154, 3, 'Contraer'),
(4024, 1155, 3, 'contraer'),
(4025, 1156, 3, 'Contraer Todo'),
(4026, 1157, 3, 'Contraer todo'),
(4027, 1158, 3, 'contraer todo'),
(4028, 1160, 3, 'Fecha de recolecciòn'),
(4029, 1161, 3, 'Recobro'),
(4030, 1162, 3, 'Informe de Recobro'),
(4031, 1163, 3, 'Cáncer de colon'),
(4032, 1164, 3, 'Detección de Cáncer de colon'),
(4033, 1165, 3, 'Cirugía de Cáncer de colon'),
(4034, 1166, 3, 'Colonoscopia'),
(4035, 1167, 3, 'colonoscopía'),
(4036, 1168, 3, 'Color'),
(4037, 1169, 3, 'Abreviatura de color'),
(4038, 1170, 3, 'Colunma'),
(4039, 1171, 3, 'Columnas'),
(4040, 1172, 3, 'Combinando Lotes'),
(4041, 1173, 3, 'Coma'),
(4042, 1174, 3, 'Comentario'),
(4043, 1175, 3, 'Comentarios'),
(4044, 1176, 3, 'Comentarios para este resultado o recomendación'),
(4045, 1177, 3, 'Sociedad Comercial de Seguros'),
(4046, 1178, 3, 'Guardar Cambios'),
(4047, 1180, 3, 'Comunicaciones'),
(4048, 1182, 3, 'Compañía'),
(4049, 1183, 3, 'Nombre Empresa'),
(4050, 1184, 3, 'Completo'),
(4051, 1186, 3, 'Terminado'),
(4052, 1188, 3, 'Terminado?'),
(4053, 1190, 3, 'Conplicaciones por el proveedor de servicios'),
(4054, 1191, 3, 'Complicaciones de aborto'),
(4055, 1192, 3, 'Componentes'),
(4056, 1193, 3, 'Sistema Computarizado de Pedidos Médicos'),
(4057, 1194, 3, 'Conclusiones'),
(4058, 1198, 3, 'Config'),
(4059, 1199, 3, 'Configuración'),
(4060, 1200, 3, 'Configuración Exportar/Importar'),
(4061, 1202, 3, 'Configure Apache y LibreEHR para usar certificados SSL del Cliente'),
(4062, 1203, 3, 'Configure Apache para usar certificados SSL del Cliente'),
(4063, 1204, 3, 'Configure Apache para usar HTTPS'),
(4064, 1205, 3, 'Configure LIBREEHR para usar certificado SSL del Cliente'),
(4065, 1208, 3, 'Confirma Crear Nuevo Paciente'),
(4066, 1209, 3, 'Confirmar Nueva Contraseña'),
(4067, 1210, 3, 'Confirmar Pago'),
(4068, 1214, 3, 'Congénito'),
(4069, 1215, 3, 'Conjuntiva, pupilas'),
(4070, 1217, 3, 'Conectores'),
(4071, 1218, 3, 'Constante'),
(4072, 1219, 3, 'Nombre constante'),
(4073, 1220, 3, 'Nombre constante está en blanco'),
(4074, 1221, 3, 'constantes'),
(4075, 1222, 3, 'Estreñimiento'),
(4076, 1223, 3, 'Constitucional'),
(4077, 1226, 3, 'Breve Descripción de Consulta'),
(4078, 1227, 3, 'Contacto'),
(4079, 1228, 3, 'email del contacto'),
(4080, 1229, 3, 'email de contacto'),
(4081, 1231, 3, 'Informacion de contacto'),
(4082, 1232, 3, 'Lentes de Contacto'),
(4083, 1236, 3, 'Nombre del contacto'),
(4084, 1237, 3, 'Persona de Contacto'),
(4085, 1239, 3, 'Número de Teléfono de Contacto'),
(4086, 1240, 3, 'Contactar ZMG, LLC (zmghealth@gmail.com) para suscribir el servicio de receta electrónica'),
(4087, 1241, 3, 'contiene por lo menos tres de las cuatro cosas siguientes:'),
(4088, 1243, 3, 'Contenido'),
(4089, 1244, 3, 'contenido'),
(4090, 1245, 3, 'Contexto'),
(4091, 1246, 3, 'El nombre de contexto no puede estar vacío'),
(4092, 1247, 3, 'Continuar'),
(4093, 1248, 3, 'Continuidad del Documento de Atención (CCD)'),
(4094, 1249, 3, 'Continuidad del registro de cuidados (CCR)'),
(4095, 1250, 3, 'Contra Clientes'),
(4096, 1251, 3, 'Contracepción'),
(4097, 1252, 3, 'Incidencias de Anticonceptivos'),
(4098, 1253, 3, 'Complicación anticonceptivos (especificar)'),
(4099, 1254, 3, 'Método Anticonceptivo'),
(4100, 1255, 3, 'Productos Anticonceptivos'),
(4101, 1256, 3, 'Servicios anticonceptivos ya empezados'),
(4102, 1257, 3, 'Comienzo de anticonceptivos'),
(4103, 1258, 3, 'Nº Identificación de control'),
(4104, 1259, 3, 'N º de control'),
(4105, 1261, 3, 'COPAGO'),
(4106, 1262, 3, 'Co-pago'),
(4107, 1263, 3, 'Co-Pago'),
(4108, 1264, 3, 'El Co-pago no es positivo'),
(4109, 1266, 3, 'Co-pagos'),
(4110, 1267, 3, 'COPD'),
(4111, 1268, 3, 'Copiar páginas a la Historia del Paciente'),
(4112, 1269, 3, 'Copiar Valores'),
(4113, 1270, 3, 'Copiando base de datos. Puede tardar algún tiempo'),
(4114, 1271, 3, 'Aviso de Derechos Reservados'),
(4115, 1273, 3, 'Bypass coronario arterial'),
(4116, 1274, 3, 'Cirugía de revascularización coronaria'),
(4117, 1275, 3, 'Corregido'),
(4118, 1277, 3, 'CouchDB'),
(4119, 1278, 3, 'Conexión a CouchDB fallida.'),
(4120, 1279, 3, 'bbdd CouchDB'),
(4121, 1280, 3, 'Nombre de bbdd CouchDB'),
(4122, 1281, 3, 'Host CouchDB'),
(4123, 1282, 3, 'Nombre Host CouchDB'),
(4124, 1283, 3, 'Activar Log CouchDB'),
(4125, 1284, 3, 'Contraseña CouchDB'),
(4126, 1285, 3, 'Puerto CouchDB'),
(4127, 1286, 3, 'puerto CouchDB'),
(4128, 1288, 3, 'Nombre usuario CouchDB'),
(4129, 1289, 3, 'Tos'),
(4130, 1290, 3, 'Tos:'),
(4131, 1294, 3, 'No se pudo leer el fichero'),
(4132, 1296, 3, 'email no enviado por problema en el servidor, '),
(4133, 1297, 3, 'No se pudo enviar email debido a problemas en el servidor. '),
(4134, 1298, 3, 'No se pudo crear el dir de backup:'),
(4135, 1299, 3, 'No se pudo eliminar dir:'),
(4136, 1300, 3, 'No se pudo eliminar el antiguo fichero de Backup:'),
(4137, 1301, 3, 'No se pudo eliminar el antiguo fichero de exportación:'),
(4138, 1302, 3, 'Tratamiento con Coumadin - Seguimiento del Ratio Internacional Normalizado (RIN)'),
(4139, 1303, 3, 'Counseling por Método'),
(4140, 1304, 3, 'Orientación'),
(4141, 1305, 3, 'Actividades de orientación'),
(4142, 1306, 3, 'FORMULARIO CONTADOR DE DERIVACIONES'),
(4143, 1307, 3, 'Contador-Derivación'),
(4144, 1308, 3, 'País'),
(4145, 1309, 3, 'Tipo de datos País'),
(4146, 1310, 3, 'Lista de País'),
(4147, 1311, 3, 'Lista del país (escriba, addonly opcional)'),
(4148, 1312, 3, 'Nombre del Pais deber ser representados por dos letras'),
(4149, 1313, 3, 'condado'),
(4150, 1315, 3, 'Cupón'),
(4151, 1318, 3, 'CPT'),
(4152, 1319, 3, 'Código CPT'),
(4153, 1320, 3, 'Código CPT'),
(4154, 1321, 3, 'Procedimiento/Servicio CPT4'),
(4155, 1322, 3, 'Medidas de Rendimiento CPTII'),
(4156, 1323, 3, 'Gestión Calidad Continua (GCC)'),
(4157, 1324, 3, 'Crujidos, crepitaciones'),
(4158, 1325, 3, 'crema'),
(4159, 1326, 3, 'Crear un certificado SSL del Cliente por usuario o cliente de maquina'),
(4160, 1327, 3, 'Crear un certificado SSL del lado del cliente, ya sea para un usuario o un nombre de host cliente.'),
(4161, 1329, 3, 'Crear un evento'),
(4162, 1330, 3, 'Crear y descargar un respaldo completo'),
(4163, 1332, 3, 'Crear Respaldo'),
(4164, 1333, 3, 'Crear batch'),
(4165, 1334, 3, 'Crear Certificado de Cliente'),
(4166, 1335, 3, 'Crear Certificados SSL del Cliente'),
(4167, 1336, 3, 'Crear Duplicado'),
(4168, 1338, 3, 'Crear backup de registro de eventos'),
(4169, 1339, 3, 'Crear nueva incidencia'),
(4170, 1340, 3, 'Crear Nuevo Paciente'),
(4171, 1342, 3, 'Crear Credenciales para el Portal Offsite'),
(4172, 1343, 3, 'Crear Credenciales para el Portal Onsite'),
(4173, 1344, 3, 'Crear nota de paciente'),
(4174, 1345, 3, 'Crear Certificado de Autoridad SSL y Certificados del Servidor.'),
(4175, 1346, 3, 'Crear visita'),
(4176, 1347, 3, 'Creado'),
(4177, 1348, 3, 'Creando fichero de exportación'),
(4178, 1351, 3, 'Creador'),
(4179, 1352, 3, 'crédito'),
(4180, 1353, 3, 'Tarjeta de Credito'),
(4181, 1354, 3, 'Créditos'),
(4182, 1356, 3, 'Criterio'),
(4183, 1358, 3, 'Enfermedad de Crohn'),
(4184, 1359, 3, 'Enfermedad de Crohn'),
(4185, 1360, 3, 'CSV'),
(4186, 1361, 3, 'Fichero CSV'),
(4187, 1363, 3, 'MM.CU (Mililitros cubicos)'),
(4188, 1364, 3, 'Cubano'),
(4189, 1365, 3, 'Número de decimales en moneda'),
(4190, 1366, 3, 'Tipo de Cambio - Símbolo de Punto Decimal'),
(4191, 1367, 3, 'Indicador de Tipo de Cambio'),
(4192, 1368, 3, 'Tipo de Cambio - Separador de Miles'),
(4193, 1369, 3, 'Actual'),
(4194, 1370, 3, 'Alcohol actual'),
(4195, 1371, 3, 'Consulta Actual'),
(4196, 1372, 3, 'Criterio Actual'),
(4197, 1373, 3, 'Color resaltado del presente día'),
(4198, 1374, 3, 'Actualmente fumador diario'),
(4199, 1375, 3, 'El nombre de fichero actual fue cambiado a'),
(4200, 1376, 3, 'Hash actual'),
(4201, 1377, 3, 'Ubicación actual'),
(4202, 1378, 3, 'Medicamentos Actuales'),
(4203, 1379, 3, 'Contraseña Actual'),
(4204, 1380, 3, 'Paciente Actual'),
(4205, 1382, 3, 'Drogas no farmacológicas actuales'),
(4206, 1383, 3, 'Actualmente fumador ocasional'),
(4207, 1386, 3, 'Actualmente Activo'),
(4208, 1388, 3, 'Actualmente no hay clínicas'),
(4209, 1389, 3, 'Síndrome de Cushing'),
(4210, 1390, 3, 'Síndrome de Cushing'),
(4211, 1392, 3, 'Costumbre'),
(4212, 1393, 3, '¿Entrada cliente?'),
(4213, 1394, 3, 'Tabla Cliente'),
(4214, 1396, 3, 'Código CVX'),
(4215, 1397, 3, 'Mapa de Código CVX'),
(4216, 1398, 3, 'Vacunación CVX'),
(4217, 1399, 3, 'Ciclo'),
(4218, 1400, 3, 'CYP'),
(4219, 1401, 3, 'Factor de CYP'),
(4220, 1402, 3, 'Informe de CYP'),
(4221, 1403, 3, 'Checo'),
(4222, 1404, 3, 'D'),
(4223, 1405, 3, 'D&C'),
(4224, 1406, 3, 'D&E'),
(4225, 1407, 3, 'F.Nacim.'),
(4226, 1408, 3, 'diariamente'),
(4227, 1409, 3, 'Registro Diario'),
(4228, 1410, 3, 'Danés'),
(4229, 1411, 3, 'Información parecida está ya en la base de datos, por favor cambie el código o la descripción'),
(4230, 1412, 3, 'Información parecida está ya en la base de datos, por favor cambie el nombre de la constante'),
(4231, 1413, 3, 'Datos Cols'),
(4232, 1416, 3, 'Error de datos'),
(4233, 1420, 3, 'Tipo de datos'),
(4234, 1421, 3, 'Base de datos'),
(4235, 1422, 3, 'Base de datos sin instalar'),
(4236, 1423, 3, 'Revisión bbdd'),
(4237, 1424, 3, 'Información de la base de datos'),
(4238, 1425, 3, 'Actualización de base de datos completa'),
(4239, 1426, 3, 'DataCols debe ser un número entre 1 y 999'),
(4240, 1427, 3, 'Fecha'),
(4241, 1428, 3, 'FECHA'),
(4242, 1431, 3, 'Fecha adminstrada'),
(4243, 1432, 3, 'Fecha y hora de coleccion de muestra'),
(4244, 1433, 3, 'Fecha y hora de esta observación'),
(4245, 1435, 3, 'Fecha y hora cuando la muestra fue colectada'),
(4246, 1436, 3, 'La fecha no puede ser mayor a la de hoy'),
(4247, 1437, 3, 'Fecha en que fueron provistos inicialmente los servicios anticonceptivos'),
(4248, 1438, 3, 'Fecha Creacion'),
(4249, 1439, 3, 'Fecha Defunción'),
(4250, 1440, 3, 'Fecha destruída'),
(4251, 1441, 3, 'Formato visualización de fecha'),
(4252, 1442, 3, 'Formato fecha para última cita no es válido'),
(4253, 1443, 3, 'Formato fecha para inicio de cita no es válido'),
(4254, 1444, 3, 'Formato fecha en ''Próxima Cita'' no es válido'),
(4255, 1445, 3, 'Formato fecha en ''no visto desde'' no es válido'),
(4256, 1446, 3, 'Formato fecha en ''visto en'' no es válido'),
(4257, 1447, 3, 'Comunicados de fechas de vacunación entregados'),
(4258, 1448, 3, 'Falta fecha para código '),
(4259, 1449, 3, 'Criterio maestro de fecha'),
(4260, 1450, 3, 'Fecha ingreso en banco aaaa-mm-dd'),
(4261, 1451, 3, 'Fecha de factura'),
(4262, 1452, 3, 'F.Nacim.'),
(4263, 1453, 3, 'F.Nacim.'),
(4264, 1454, 3, 'F.Nacim.'),
(4265, 1455, 3, 'Fecha de entrada'),
(4266, 1456, 3, 'Fecha de la lesión'),
(4267, 1458, 3, 'Fecha de pago aaaa-mm-dd'),
(4268, 1459, 3, 'Fecha de derivación'),
(4269, 1460, 3, 'Fecha de la respuesta'),
(4270, 1462, 3, 'Fecha De Servicio'),
(4271, 1463, 3, 'Fecha de servicio'),
(4272, 1464, 3, 'Fecha de servicio = hoy'),
(4273, 1465, 3, 'Fecha de servicio mm/dd/aaaa'),
(4274, 1466, 3, 'Fecha de Servicio:'),
(4275, 1467, 3, 'Fecha de firma'),
(4276, 1469, 3, 'Fecha de esta orden'),
(4277, 1470, 3, 'Fecha de este reporte'),
(4278, 1471, 3, 'Fecha de la Declaración de VIS'),
(4279, 1472, 3, 'Fecha en que se ordenó'),
(4280, 1475, 3, 'Seleccionador de fecha'),
(4281, 1476, 3, 'Fecha Envio'),
(4282, 1477, 3, 'Fecha del mensaje enviado'),
(4283, 1479, 3, 'La fecha no puede estar en blanco'),
(4284, 1480, 3, 'Fecha/Cita'),
(4285, 1481, 3, 'Fecha/Notas'),
(4286, 1482, 3, 'Fecha/Notas de Último'),
(4287, 1483, 3, 'Fecha/Hora'),
(4288, 1484, 3, 'Fecha:'),
(4289, 1485, 3, 'Registro mensaje fechado'),
(4290, 1486, 3, 'Día'),
(4291, 1487, 3, 'dia'),
(4292, 1489, 3, 'Vista de día'),
(4293, 1490, 3, 'Día(s)'),
(4294, 1491, 3, 'Día(s) L-V'),
(4295, 1492, 3, 'días'),
(4296, 1493, 3, 'Días'),
(4297, 1494, 3, 'días pasados'),
(4298, 1495, 3, 'Dïas y juegos perdidos'),
(4299, 1496, 3, 'Días Desde la Última Visita'),
(4300, 1497, 3, 'Dias faltados'),
(4301, 1498, 3, 'Días por columna'),
(4302, 1500, 3, 'Días/Col'),
(4303, 1501, 3, 'DB instalado'),
(4304, 1502, 3, 'DD/MM/AAAA'),
(4305, 1503, 3, 'Anonimato'),
(4306, 1504, 3, 'El proceso de anonimato está completo'),
(4307, 1505, 3, 'El proceso de anonimato está en proceso'),
(4308, 1506, 3, 'El proceso de anonimato ha iniciado y está corriendo en el fondo'),
(4309, 1507, 3, 'Los datos anónimos pueden no estar completos'),
(4310, 1508, 3, 'Los ficheros anónimos serán guardados en'),
(4311, 1509, 3, 'DEA'),
(4312, 1511, 3, 'Sordera'),
(4313, 1512, 3, 'Elimine errores de la información'),
(4314, 1515, 3, 'Dic'),
(4315, 1516, 3, 'DIFUNTO'),
(4316, 1517, 3, 'Diciembre'),
(4317, 1520, 3, 'Deducible'),
(4318, 1521, 3, 'Deducible alcanzado'),
(4319, 1522, 3, 'Por Defecto'),
(4320, 1523, 3, 'Vista Calendario por defecto'),
(4321, 1524, 3, 'Formulario ID para Visita por defecto'),
(4322, 1526, 3, 'Centro por defecto'),
(4323, 1527, 3, 'Idioma por defecto'),
(4324, 1528, 3, 'Idioma por defecto si no se permite otro, o bien elegir.'),
(4325, 1529, 3, 'Lista por defecto (escriba, sólo añadir opcional)'),
(4326, 1530, 3, 'Método por defecto'),
(4327, 1531, 3, 'Días Expiración Contraseña por Defecto'),
(4328, 1532, 3, 'El periodo de vencimiento de la contraseña por defecto es 0. Ésto significa que la función está desactivada'),
(4329, 1533, 3, 'País por defecto del Paciente'),
(4330, 1536, 3, 'Médico por defecto'),
(4331, 1537, 3, 'Rango por defecto'),
(4332, 1538, 3, 'Razón por defecto de la visita'),
(4333, 1540, 3, 'Configuración por defecto'),
(4334, 1541, 3, 'Estado de la casilla por defecto de nueva ventana en la lista de pacientes.'),
(4335, 1542, 3, 'Plantilla por defecto'),
(4336, 1546, 3, 'Unidades por defecto'),
(4337, 1547, 3, 'Valor por defecto'),
(4338, 1548, 3, 'Deposito por defecto'),
(4339, 1549, 3, 'Socio X12 por defecto'),
(4340, 1550, 3, 'Por defecto/Global'),
(4341, 1551, 3, 'Borrar'),
(4342, 1552, 3, 'borrar'),
(4343, 1553, 3, 'Repetición retrasada (> 12 Mo)'),
(4344, 1554, 3, 'Eliminar'),
(4345, 1555, 3, 'eliminar'),
(4346, 1556, 3, 'Eliminar Categorías con identificador(es) : '),
(4347, 1557, 3, 'Borrar Categoría'),
(4348, 1560, 3, 'Eliminar Grupo'),
(4349, 1561, 3, 'Eliminar Lista'),
(4350, 1562, 3, 'Eliminar Páginas'),
(4351, 1563, 3, 'Borrar Paciente, visita, formulario, Incidencia, Documento, Pago, facturación o Transacción'),
(4352, 1565, 3, 'Borrar fila'),
(4353, 1566, 3, 'Borrar ítems selectos'),
(4354, 1568, 3, 'Eliminar éxito.'),
(4355, 1569, 3, 'Eliminar este documento'),
(4356, 1570, 3, 'Eliminar este formulario'),
(4357, 1571, 3, 'Eliminar esta nota'),
(4358, 1573, 3, 'Borrado Completado'),
(4359, 1575, 3, 'No se puede deshacer la eliminación de este evento. No se puede recuperar una vez que se ha hecho. ¿Está seguro que desea eliminar este evento?'),
(4360, 1581, 3, 'Demencia'),
(4361, 1582, 3, 'Datos demográficos'),
(4362, 1583, 3, 'Demografía (escribir, sólo añadir opcional)'),
(4363, 1585, 3, 'Criterio de Filtro Demográficos'),
(4364, 1586, 3, 'Datos demográficos no autorizados'),
(4365, 1587, 3, 'Datos demográficos no autorizados'),
(4366, 1588, 3, 'Denegado'),
(4367, 1589, 3, 'Denominador'),
(4368, 1590, 3, 'Dental'),
(4369, 1592, 3, 'Incidencias Dentales'),
(4370, 1595, 3, 'Dependiendo del tipo de cuenta que usted prueba, usted verá salida tipo HCFA en una página en blanco para las cuentas de HCFA, o usted verá muchas líneas de texto e información alteradas, si usted está probando una demanda X12. Ese texto mutilado es el formato del X12 IED 4010A. Usted verá de vez en cuando los caracteres extraños que parecen dominós o basura, se trata de caracteres de control tales como alimentaciones de página y son normales.'),
(4371, 1596, 3, 'Fecha de depósito'),
(4372, 1597, 3, 'La fecha del deposiito no puede ser mayor a la de hoy'),
(4373, 1598, 3, 'Fecha del depósito'),
(4374, 1599, 3, 'Depresivo'),
(4375, 1600, 3, 'Depresión'),
(4376, 1602, 3, 'Descripción'),
(4377, 1603, 3, 'descripción'),
(4378, 1605, 3, 'Descripción de la publicación'),
(4379, 1606, 3, 'Desceripcion de este procedimiento o codigo resultante'),
(4380, 1607, 3, 'Traducción de la descripción'),
(4381, 1609, 3, 'Destino'),
(4382, 1610, 3, 'Nombre del fichero destino'),
(4383, 1611, 3, 'Destruir todo el lote'),
(4384, 1612, 3, 'Destruido ...'),
(4385, 1613, 3, 'Destruido'),
(4386, 1614, 3, 'Drogas destruidas'),
(4387, 1615, 3, 'Informe drogas destruidas'),
(4388, 1616, 3, 'Detalle'),
(4389, 1617, 3, 'Detalles'),
(4390, 1619, 3, 'Anormalidad del desarrollo'),
(4391, 1620, 3, 'Diabetes'),
(4392, 1621, 3, 'Diabetes Mellitus'),
(4393, 1622, 3, 'Diabetes: Gestión presión arterial (GCC)'),
(4394, 1623, 3, 'Diabetes:Examen Ocular'),
(4395, 1624, 3, 'Diabetes: Examen ocular (GCC)'),
(4396, 1625, 3, 'Diabetes: Examen de los pies'),
(4397, 1626, 3, 'Diabetes: Examen de los pies (GCC)'),
(4398, 1627, 3, 'Diabetes:Control HbA1c Deficiente (GCC)'),
(4399, 1628, 3, 'Diabetes: Hemoglobina A1C'),
(4400, 1629, 3, 'Diabetes: Gestión LDL y Control (GCC)'),
(4401, 1630, 3, 'Diabetes: Microalbúmina de la orina'),
(4402, 1631, 3, 'Diag'),
(4403, 1633, 3, 'Diagnóstico'),
(4404, 1634, 3, 'Cód. Diagnóstico'),
(4405, 1636, 3, 'Fecha de diagnóstico'),
(4406, 1637, 3, 'El diagnóstico debe ser codificado en una visita vinculada'),
(4407, 1638, 3, 'Nombre del diagnóstico'),
(4408, 1639, 3, 'Reporte del diagnóstico'),
(4409, 1640, 3, 'Informe de diagnóstico'),
(4410, 1641, 3, 'Informe sólo de diagnóstico'),
(4411, 1642, 3, 'Título del diagnóstico'),
(4412, 1643, 3, 'Diagnóstico:'),
(4413, 1644, 3, 'Diagnóstico: '),
(4414, 1645, 3, 'Pruebas diagnósticas:'),
(4415, 1646, 3, 'Diales'),
(4416, 1647, 3, 'Diafragmas/Capuchón cervical'),
(4417, 1648, 3, 'Diarrea'),
(4418, 1650, 3, 'Dictado'),
(4419, 1651, 3, 'Dictado: '),
(4420, 1652, 3, '¿Usted recibió una copia del aviso de HIPAA?'),
(4421, 1653, 3, 'Difuso:'),
(4422, 1654, 3, 'Firmado digitalmente'),
(4423, 1657, 3, 'Correo Directo'),
(4424, 1663, 3, 'Nombre del director'),
(4425, 1665, 3, 'inhabilitación'),
(4426, 1667, 3, 'Deshabilitar calendario'),
(4427, 1668, 3, 'Deshabilitar Gráfico de seguimiento'),
(4428, 1669, 3, 'Deshabilitar vacunaciones'),
(4429, 1670, 3, 'Deshabilitar vieja forma métrica de constantes vitales'),
(4430, 1672, 3, 'Deshabilitar phpMyAdmin'),
(4431, 1673, 3, 'Deshabilitar prescriciones'),
(4432, 1674, 3, 'Deshabilitar grupos de usuarios'),
(4433, 1675, 3, 'inhabilitado'),
(4434, 1676, 3, 'inhabilitado'),
(4435, 1677, 3, 'Beneficiario discapacitado menor de 65 años con un Plan de salud para grandes grupos (LGHP)'),
(4436, 1678, 3, 'DISCO'),
(4437, 1681, 3, 'Descarga'),
(4438, 1682, 3, 'Pérdidas/secreciones de la uretra'),
(4439, 1684, 3, 'Derecho de alta'),
(4440, 1685, 3, 'Derecho de alta:'),
(4441, 1689, 3, 'Informacion de publicación'),
(4442, 1690, 3, 'Tipo de publicación'),
(4443, 1691, 3, 'Tipos de publicación'),
(4444, 1692, 3, 'Publicaciones'),
(4445, 1694, 3, 'Descuento'),
(4446, 1695, 3, 'Suma de descuento'),
(4447, 1696, 3, 'Nivel del Descuento'),
(4448, 1697, 3, 'Porcentaje de descuento'),
(4449, 1698, 3, 'Descuentos como importes monetarios'),
(4450, 1699, 3, 'Descuentos a la hora de salida se introducen como cantidades de dinero, a diferencia de porcentaje.'),
(4451, 1700, 3, 'Resultado discreto'),
(4452, 1701, 3, 'Enfermedad'),
(4453, 1702, 3, 'Dislocación'),
(4454, 1703, 3, '# Disp'),
(4455, 1704, 3, 'Informe'),
(4456, 1705, 3, 'Remitir documento recibido'),
(4457, 1706, 3, 'Prescrito'),
(4458, 1707, 3, 'Mostrar las directivas anticipadas en la página de la demografía.'),
(4459, 1709, 3, '¿Mostrar fechas de eventos en bloque?'),
(4460, 1711, 3, '¿Mostrar cuántos eventos?'),
(4461, 1713, 3, '¿Mostrar lugar/sitio en bloque?'),
(4462, 1714, 3, 'Nombre Pantalla'),
(4463, 1715, 3, '¿Mostrar el calendario?'),
(4464, 1718, 3, '¿Mostrar los eventos de hoy en el bloque?'),
(4465, 1719, 3, '¿Mostrar tema en el bloque?'),
(4466, 1720, 3, '¿Mostrar los eventos próximos en tabla?'),
(4467, 1721, 3, 'Mostrar columnas'),
(4468, 1722, 3, 'Viendo el siguiente número de las publicaciones más recientes:'),
(4469, 1723, 3, 'Mostrando el siguiente número de las notas más recientes'),
(4470, 1724, 3, 'Mostrando el siguiente número de las notas más recientes:'),
(4471, 1725, 3, 'Distribución'),
(4472, 1726, 3, 'Distribuciones'),
(4473, 1727, 3, 'Distribuidor'),
(4474, 1729, 3, 'Diverticulitis'),
(4475, 1730, 3, 'Operación de Diverticulitis'),
(4476, 1731, 3, 'Diverticulitis'),
(4477, 1732, 3, 'Operación de Diverticulitis'),
(4478, 1733, 3, 'Divorciado'),
(4479, 1734, 3, 'Mareo:'),
(4480, 1735, 3, 'No cambiar'),
(4481, 1737, 3, 'No mostrar alergia subida a NewCrop'),
(4482, 1739, 3, 'No mostrar medicación subida a NewCrop'),
(4483, 1742, 3, 'No mostrar el calendario'),
(4484, 1744, 3, 'No inventariar ni vender nigun producto'),
(4485, 1745, 3, 'No requiere notas del paciente para ser autorizado'),
(4486, 1746, 3, 'Orden de No Resucitar'),
(4487, 1747, 3, 'no guardar'),
(4488, 1748, 3, 'no sustituir'),
(4489, 1749, 3, 'no actuar'),
(4490, 1751, 3, 'De verdad quiere suprimir?'),
(4491, 1752, 3, '¿Verdaderamente desea borrar la selección?'),
(4492, 1753, 3, 'Está seguro que quiere eliminar este grupo'),
(4493, 1755, 3, '¿Quiere continuar?'),
(4494, 1756, 3, '¿Quiere borrar esto?'),
(4495, 1757, 3, '¿Quiere borrar?'),
(4496, 1758, 3, '¿Desea remover este registro?'),
(4497, 1759, 3, '¿Desea continuar añadiendo este nuevo paciente?'),
(4498, 1760, 3, '¿Usted desea continuar con el nuevo nombre?'),
(4499, 1761, 3, '¿Usted desea suprimir DEFINITIVAMENTE este registro de vacunación?'),
(4500, 1762, 3, 'F.Nacim.'),
(4501, 1763, 3, 'Falta F.Nacimiento, por favor insertarla si es posible'),
(4502, 1764, 3, 'Documentos'),
(4503, 1765, 3, 'Médico'),
(4504, 1766, 3, 'Médico:'),
(4505, 1767, 3, 'Nombre del médico y firma'),
(4506, 1768, 3, 'Documento'),
(4507, 1769, 3, 'documento'),
(4508, 1770, 3, 'Categorías documento'),
(4509, 1775, 3, 'El documento no ha podido ser trasladado al Nº Identificación del paciente'),
(4510, 1777, 3, 'Fecha de documento'),
(4511, 1778, 3, 'Fecha del documento e incidencia actualizadas con éxito'),
(4512, 1779, 3, 'Nº Identificación de Documento'),
(4513, 1780, 3, 'Documento se trasladó a nueva categoría'),
(4514, 1781, 3, 'Documento se trasladó al Nº Identificación del paciente'),
(4515, 1783, 3, 'Documento aprobó la comprobación de integridad'),
(4516, 1784, 3, 'Método de archivo de documentos'),
(4517, 1785, 3, 'Documento renombrado con éxito'),
(4518, 1790, 3, 'Depósito de documentos/Imágenes'),
(4519, 1791, 3, 'Documentos'),
(4520, 1792, 3, 'Documentos (escribir, addonly opcional)'),
(4521, 1794, 3, 'DOE'),
(4522, 1798, 3, '¿Este tipo permite codigos relacionados?'),
(4523, 1799, 3, 'Socio doméstico'),
(4524, 1800, 3, 'No Guardar'),
(4525, 1801, 3, 'No Guardar'),
(4526, 1802, 3, 'No Guardar Cambios'),
(4527, 1803, 3, 'Terminado'),
(4528, 1804, 3, 'Hecho con:'),
(4529, 1805, 3, 'Terminado. Ahora se enviará la descarga'),
(4530, 1806, 3, 'DOS'),
(4531, 1807, 3, 'Dosis'),
(4532, 1809, 3, 'Doble click para editar'),
(4533, 1810, 3, 'Visión doble'),
(4534, 1811, 3, 'Descarga'),
(4535, 1814, 3, 'Descargar de todas formas'),
(4536, 1815, 3, 'Descargar expediente de factura, mandar a contabilidad y marcar como facturado.'),
(4537, 1817, 3, 'Certificados de descargas'),
(4538, 1818, 3, 'Descargar datos de configuración'),
(4539, 1820, 3, 'Descargar fichero encriptado'),
(4540, 1827, 3, 'Descargar seleccionados'),
(4541, 1828, 3, 'Revisar médico'),
(4542, 1829, 3, 'Visitar médico'),
(4543, 1830, 3, 'Dr.'),
(4544, 1831, 3, 'Arrastre para mover'),
(4545, 1832, 3, 'Goteo'),
(4546, 1833, 3, 'Permiso de conducir o D.N.I.'),
(4547, 1834, 3, 'Medicamento'),
(4548, 1835, 3, 'Buscador de medicamentos'),
(4549, 1836, 3, 'Formularios de Medicamento'),
(4550, 1837, 3, 'Nº Identificación medicamento falta!'),
(4551, 1838, 3, 'Intervalos de Medicamento'),
(4552, 1839, 3, 'Inventario de Medicamentos'),
(4553, 1840, 3, 'Nombre del Medicamento'),
(4554, 1841, 3, 'Vía de administración del Medicamento'),
(4555, 1845, 3, 'Unidades de Medicamento'),
(4556, 1846, 3, 'Medicamentos'),
(4557, 1847, 3, 'Medicamentos y productos'),
(4558, 1848, 3, 'Boca seca'),
(4559, 1849, 3, 'Diagnóstico DSMIV'),
(4560, 1850, 3, 'DT 1'),
(4561, 1851, 3, 'DT 2'),
(4562, 1852, 3, 'DT 3'),
(4563, 1853, 3, 'DT 4'),
(4564, 1854, 3, 'DT 5'),
(4565, 1855, 3, 'DTaP 1'),
(4566, 1856, 3, 'DTaP 2'),
(4567, 1857, 3, 'DTaP 3'),
(4568, 1858, 3, 'DTaP 4'),
(4569, 1859, 3, 'DTaP 5'),
(4570, 1860, 3, 'Adeudado'),
(4571, 1861, 3, 'Fecha del parto'),
(4572, 1862, 3, 'Fecha del parto mm/dd/aaaa o aaaa-mm-dd'),
(4573, 1863, 3, 'Fecha del parto:'),
(4574, 1864, 3, 'Deuda Seguro'),
(4575, 1865, 3, 'Deuda Paciente'),
(4576, 1866, 3, 'Deuda próxima'),
(4577, 1867, 3, 'Estado de Deuda'),
(4578, 1868, 3, 'Actualización Estado de Deuda'),
(4579, 1869, 3, 'Vaciar LibreEHR base de datos'),
(4580, 1870, 3, 'Vaciar LibreEHR web de árbol de directorios'),
(4581, 1871, 3, 'Vaciar phpGACL base de datos'),
(4582, 1872, 3, 'Vaciar phpGACL web de árbol de directorios'),
(4583, 1873, 3, 'Vaciar SQL-Ledger base de datos'),
(4584, 1874, 3, 'Vaciar phpGACL web de árbol de directorios'),
(4585, 1875, 3, 'Compruebe duplicado'),
(4586, 1876, 3, 'ID duplicado en linea'),
(4587, 1877, 3, 'Nombre duplicado en linea'),
(4588, 1878, 3, 'AVISO DE DUPLICACION'),
(4589, 1879, 3, 'Poder Legal Duradero'),
(4590, 1880, 3, 'duración'),
(4591, 1881, 3, 'Duración'),
(4592, 1882, 3, 'Holandés'),
(4593, 1883, 3, 'Dx Rep'),
(4594, 1884, 3, 'Disfagia'),
(4595, 1885, 3, 'Disnea'),
(4596, 1886, 3, 'Disuria'),
(4597, 1888, 3, '¿E-Receta?'),
(4598, 1890, 3, 'Receta Electrónica'),
(4599, 1892, 3, 'Renovación Receta Electrónica'),
(4600, 1893, 3, 'Cada destinatario debe establecer sus propios mensajes como terminados.'),
(4601, 1894, 3, 'Repetición Temprana (<2 Mo)'),
(4602, 1895, 3, 'Orejas'),
(4603, 1896, 3, 'Electrocardiograma'),
(4604, 1897, 3, 'Reclamaciones electrónicas'),
(4605, 1898, 3, 'Edema'),
(4606, 1902, 3, 'Adjuntar fichero EDI-271'),
(4607, 1903, 3, 'Respuesta de carga de fichero EDI-271'),
(4608, 1904, 3, 'Editar'),
(4609, 1905, 3, 'editar'),
(4610, 1906, 3, 'Editar alergias'),
(4611, 1907, 3, 'Editar categorías'),
(4612, 1908, 3, 'Editar Definiciones'),
(4613, 1909, 3, 'Editar definiciones'),
(4614, 1910, 3, 'Editar diagnóstico para'),
(4615, 1911, 3, 'editar publicación'),
(4616, 1912, 3, 'Editar Clínicas'),
(4617, 1913, 3, 'Editar Centro'),
(4618, 1914, 3, 'Editar información del Centro'),
(4619, 1915, 3, 'Editar información de instalación de usuario específico'),
(4620, 1916, 3, 'editar fichero en'),
(4621, 1917, 3, 'Editar forma'),
(4622, 1918, 3, 'Editar configuración global'),
(4623, 1919, 3, 'Edición no permitida'),
(4624, 1920, 3, 'Editar el diseño'),
(4625, 1921, 3, 'Editar la lista'),
(4626, 1922, 3, 'Editar Pago'),
(4627, 1923, 3, 'Editar estructura'),
(4628, 1924, 3, 'Editar usuario'),
(4629, 1925, 3, 'Editar configuración de usuario'),
(4630, 1928, 3, 'Educación'),
(4631, 1929, 3, 'Fecha educación'),
(4632, 1931, 3, 'Debería haber recibido una copia del GNU con este programa, si no, escriba al Free '),
(4633, 1932, 3, 'Fecha efectiva'),
(4634, 1934, 3, 'Efectividad'),
(4635, 1935, 3, 'EIN'),
(4636, 1936, 3, 'Eyaculaciones'),
(4637, 1937, 3, 'Codo'),
(4638, 1938, 3, 'Problemas del codo'),
(4639, 1939, 3, 'Electrónico'),
(4640, 1942, 3, 'Mandatos Electronicos'),
(4641, 1944, 3, 'Elegibilidad'),
(4642, 1945, 3, 'Elegibilidad Batch Consulta 270'),
(4643, 1946, 3, 'Elegibilidad de Respuesta'),
(4644, 1947, 3, 'Estado de elegibilidad para la vacuna suministrada para niños'),
(4645, 1948, 3, 'Elegible'),
(4646, 1949, 3, 'email'),
(4647, 1951, 3, 'email'),
(4648, 1953, 3, 'email del remitente para los recordatorios de pacientes. Las respuestas de los pacientes irán a esa dirección. Es importante usar una dirección del dominio de la Clínica para evitar que las respuestas de recordatorios de los pacientes vayan a la carpeta de correo basura.'),
(4649, 1954, 3, 'email, si hay, para recibir notificaciones administrativas.'),
(4650, 1955, 3, 'email, si hay, para recibir mensajes de activación de inicio sesión de usuario.'),
(4651, 1956, 3, 'Autenticación email'),
(4652, 1957, 3, 'email de Batchcom'),
(4653, 1958, 3, 'Notificación email'),
(4654, 1959, 3, 'Horario Notificación Email'),
(4655, 1960, 3, 'Informe de notificación de email'),
(4656, 1961, 3, 'email enviado antes'),
(4657, 1962, 3, 'Remitente de email'),
(4658, 1963, 3, 'Email enviado'),
(4659, 1964, 3, 'email enviado a'),
(4660, 1965, 3, 'Asunto del email'),
(4661, 1966, 3, 'Texto del email, etiqueta útil: ***NAME***, Ej. Estimado ***NAME***'),
(4662, 1967, 3, 'Texto email, etiqueta útil:***NAME***, por ej. Querido ***NAME***{{No traducir el elemento ***NAME*** de esta constante}}'),
(4663, 1968, 3, 'Método de envío de email'),
(4664, 1969, 3, 'Email enviado a las siguientes direcciones'),
(4665, 1971, 3, 'Contacto en caso de emergencia'),
(4666, 1972, 3, 'Persona de Contacto de Emergencia'),
(4667, 1973, 3, 'Teléfono de Contacto de Emergencias'),
(4668, 1974, 3, 'Emergencia anticonceptiva'),
(4669, 1975, 3, 'Acceso de Emergencia'),
(4670, 1976, 3, 'Inicio sesión de Emergencia ACL elegido. El usuario esta aún activo, favor desactivar usuario y activarlo cuando la situación de emergencia lo requiera. Visitar Administración>Usuario para activación o deactivación'),
(4671, 1977, 3, 'El email de activación de inicio de sesión de emergencia ha de circular sólo si los siguientes ajustes del fichero interfase/globals.php están configurados:'),
(4672, 1978, 3, 'email de inicio de sesión de emergencia'),
(4673, 1979, 3, 'El usuario de Inicio de sesión de emergencia puede hacer cualquier cosa'),
(4674, 1980, 3, 'Teléfono de emergencia'),
(4675, 1982, 3, 'Enfisema'),
(4676, 1983, 3, 'Empleado'),
(4677, 1984, 3, 'Empresa'),
(4678, 1985, 3, 'Dirección del empleador'),
(4679, 1986, 3, 'Datos de la empresa'),
(4680, 1987, 3, 'Nombre de Empresa'),
(4681, 1988, 3, 'VACIO'),
(4682, 1989, 3, 'Vacio'),
(4683, 1991, 3, 'Valor vacío en -Horas de eEmail-'),
(4684, 1992, 3, 'Valor vacío en -Remitente de email-'),
(4685, 1993, 3, 'Valor vacío en-Tema de email-'),
(4686, 1994, 3, 'Valor vacío en-Texto de email-'),
(4687, 1995, 3, 'Valor vacío en -Nombre del Facultativo-'),
(4688, 1996, 3, 'Valor vacío en -Contraseña-'),
(4689, 1997, 3, 'Valor vacío en -Horas de SMS-'),
(4690, 1998, 3, 'Vaciar en el valor -Texto SMS-'),
(4691, 1999, 3, 'Vaciar en el valor -Usuario-'),
(4692, 2006, 3, 'Activar aviso MCA'),
(4693, 2008, 3, 'Activar Informe MCA'),
(4694, 2009, 3, 'Activar seguimiento MCA'),
(4695, 2011, 3, 'Activar auditoría RANA'),
(4696, 2013, 3, 'Inicio de sesión Auditoría habilitado'),
(4697, 2014, 3, 'Activar Auditoría Registro y Autenticación del Nodo (ATNA)'),
(4698, 2015, 3, 'Activar Informe Medidas de Cálculo Automático (MCA)'),
(4699, 2016, 3, 'Activar Cliente SSL'),
(4700, 2017, 3, 'Activar Cliente SSL con certificado de autenticación.'),
(4701, 2019, 3, 'Activar Reglas Clínicas de Decisión (CDR)'),
(4702, 2022, 3, 'Activar informe medidas de calidad clínica (GCC)'),
(4703, 2023, 3, 'Activar popup recordatorios clínicos'),
(4704, 2024, 3, 'Activar Widget Recordatorios clínicos'),
(4705, 2027, 3, 'Activar Informes GCC'),
(4706, 2030, 3, 'Habilitar tarifas en el menú de la izquierda'),
(4707, 2031, 3, 'Activar Soporte Hylafax'),
(4708, 2033, 3, 'Activar el estado de importación de mensajes para Receta electrónica NewCrop'),
(4709, 2037, 3, 'Activar intercambio Laboratorio'),
(4710, 2039, 3, 'Habilitar registro para documentos subidos/bajados de CouchDB'),
(4711, 2040, 3, 'Activar registro de todas las consultas SQL SELECT.'),
(4712, 2041, 3, 'Activar registro de backup de actividades relacionadas.'),
(4713, 2043, 3, 'Activar inicio sesión de actividades varias.'),
(4714, 2044, 3, 'Activar registro de actividades solicitadas.'),
(4715, 2045, 3, 'Activar registro de modificaciones del registro de pacientes.'),
(4716, 2046, 3, 'Activar registro de programar actividades.'),
(4717, 2047, 3, 'Activar registro de seguridad y administración de actividades.'),
(4718, 2049, 3, 'Activar servicio Receta electrónica NewCrop'),
(4719, 2051, 3, 'Activar Portal Paciente Externo'),
(4720, 2052, 3, 'Activar Portal paciente desde el exterior.'),
(4721, 2053, 3, 'Activar Portal paciente in-situ'),
(4722, 2055, 3, 'Activar Portal paciente in-situ.'),
(4723, 2056, 3, 'Activar widget recordatorios del paciente'),
(4724, 2058, 3, 'Activar aviso fecha requerida para Medidas de Cálculo Automático (MCA)'),
(4725, 2060, 3, 'Activar Informe de Seguimiento de Fecha para Medidas de Cálculo Automático (MCA)'),
(4726, 2061, 3, 'Activar Soporte escaner'),
(4727, 2065, 3, 'Activar servicio de soporte LibreEHR LLC Laboratorio de intercambio'),
(4728, 2066, 3, 'Activar Certificado de Autenticación del usuario.'),
(4729, 2067, 3, 'Activar servicio ZMG, Receta electrónica LLC'),
(4730, 2068, 3, 'Activado'),
(4731, 2070, 3, 'Activar el viejo panel de cargos para introducir códigos de facturas y pagos. No se recomienda usar la hoja de honorarios en su lugar.'),
(4732, 2071, 3, 'Encuentro'),
(4733, 2072, 3, 'Visita'),
(4734, 2073, 3, 'Visita'),
(4735, 2074, 3, 'visita'),
(4736, 2075, 3, 'Visita '),
(4737, 2076, 3, 'Visita a un hospitalizado agudo o ED'),
(4738, 2081, 3, 'Fecha visita'),
(4739, 2086, 3, 'Formularios visita'),
(4740, 2087, 3, 'visita de salud y evaluación de comportamiento'),
(4741, 2088, 3, 'Histórico de visitas'),
(4742, 2089, 3, 'ID Visita'),
(4743, 2090, 3, 'Visita gripe'),
(4744, 2091, 3, 'número visita'),
(4745, 2093, 3, 'visita cuidado enfermería'),
(4746, 2094, 3, 'visita centro enfermería'),
(4747, 2095, 3, 'visita terapia ocupacional'),
(4748, 2096, 3, 'visita a consultorio'),
(4749, 2097, 3, 'visita paciente externo'),
(4750, 2098, 3, 'visita paciente externo w/PCP y obgyn'),
(4751, 2099, 3, 'Tamaño página visita'),
(4752, 2100, 3, 'Pago visita'),
(4753, 2101, 3, 'visita embarazo'),
(4754, 2102, 3, 'visita medicina preventiva - asesoramiento individual'),
(4755, 2103, 3, 'visita medicina preventiva para mayores de 40'),
(4756, 2104, 3, 'visita de medicina preventiva - asesoramiento en grupo'),
(4757, 2105, 3, 'visita medicina preventiva otros servicios'),
(4758, 2106, 3, 'visita servicios medicina preventiva mayores de 18'),
(4759, 2107, 3, 'visita psiquiatrica y psicológica'),
(4760, 2108, 3, 'Estadísticas de visitas'),
(4761, 2109, 3, 'Resumen de visitas'),
(4762, 2110, 3, 'Visita codificada'),
(4763, 2111, 3, 'Visita:'),
(4764, 2112, 3, 'Visita: visita ingreso no agudo, paciente externo, o oftalmológico'),
(4765, 2113, 3, 'Visitas'),
(4766, 2114, 3, 'Visitas y Formularios'),
(4767, 2115, 3, 'Visitas y Formularios'),
(4768, 2116, 3, 'Visitas no autorizadas'),
(4769, 2117, 3, 'Informe de visitas'),
(4770, 2118, 3, 'Sección visitas'),
(4771, 2120, 3, 'Encriptación'),
(4772, 2121, 3, 'Final'),
(4773, 2122, 3, 'Final (aaaa-mm-dd): '),
(4774, 2123, 3, 'Fecha final'),
(4775, 2124, 3, 'Fecha final'),
(4776, 2126, 3, 'Fecha final debe ser posterior a fecha inicio'),
(4777, 2127, 3, 'Fecha Final:'),
(4778, 2131, 3, 'Hora finalización'),
(4779, 2132, 3, 'Enfermedad renal en Etapa Final - Beneficiario de MCP con un Plan de grupo del empleador'),
(4780, 2133, 3, 'Fecha final de servicio aaaa-mm-dd'),
(4781, 2134, 3, 'Termina DOS dd/mm/aaaa si desea entrar en una serie'),
(4782, 2135, 3, 'Hora final del día para eventos de calendario'),
(4783, 2136, 3, 'Sangre anormal Endo'),
(4784, 2137, 3, 'Endocrino'),
(4785, 2138, 3, 'Endoscopía'),
(4786, 2141, 3, 'Inglés'),
(4787, 2142, 3, 'Inglés '),
(4788, 2143, 3, 'Ingleses (Indios)'),
(4789, 2144, 3, 'Inglés (Estándar)'),
(4790, 2145, 3, 'Enscript comando usado por Hylafax.'),
(4791, 2146, 3, 'Garantizar LibreEHR tiene privilegios al directorio'),
(4792, 2147, 3, 'ENT Descarga'),
(4793, 2148, 3, 'ENT Dolor'),
(4794, 2149, 3, 'Introduzca un código de la diagnosis para excluir todas las facturas que no lo contienen'),
(4795, 2151, 3, 'Incorpore el cuerpo de la carta aquí'),
(4796, 2152, 3, 'Introduzca Contraseña root para Base Datos'),
(4797, 2153, 3, 'Introduzca Usuario root para Base Datos'),
(4798, 2154, 3, 'Introduzca Diagnóstico'),
(4799, 2155, 3, 'Introduzca Medicamentos'),
(4800, 2158, 3, 'Introduzca Vacunas'),
(4801, 2159, 3, 'Introducir Clave'),
(4802, 2161, 3, 'Escriba el nuevo Estado'),
(4803, 2164, 3, 'Introducir código Re-identificación'),
(4804, 2165, 3, 'Incorpore sus criterios de búsqueda arriba'),
(4805, 2167, 3, 'entradas'),
(4806, 2168, 3, 'Ambiental'),
(4807, 2169, 3, 'Entrada de datos de EOB'),
(4808, 2170, 3, 'EOB envío - Remesas electrónicas'),
(4809, 2171, 3, 'EOB envío - Instrucciones'),
(4810, 2172, 3, 'EOB envío - Factura'),
(4811, 2173, 3, 'EOB envío - Nota del Paciente'),
(4812, 2174, 3, 'EOB envío - Buscar'),
(4813, 2176, 3, 'Epilepsia'),
(4814, 2178, 3, 'ERA (Remesa Electrónica de Aviso)'),
(4815, 2180, 3, 'Envío ERA (Remesa Electrónica de Aviso)'),
(4816, 2181, 3, 'Borrar'),
(4817, 2182, 3, 'Erecciones'),
(4818, 2183, 3, 'Error'),
(4819, 2185, 3, 'Error confirmando la recepción de los resultados del laboratorio'),
(4820, 2187, 3, 'Error al obtener los resultados de laboratorio de la red de intercambio del laboratorio'),
(4821, 2188, 3, 'Error en selección de género'),
(4822, 2189, 3, 'Error en -HIPAA- selección'),
(4823, 2190, 3, 'Error en el -Proceso de selección'),
(4824, 2191, 3, 'El error en la selección de -Puerta enlace SMS-'),
(4825, 2192, 3, 'Error en -Ordenar por- selección'),
(4826, 2193, 3, 'Error del file de compresion gzip '),
(4827, 2194, 3, 'Error en la opción SI o NO'),
(4828, 2195, 3, 'Error al abrir fichero adjunto para lectura'),
(4829, 2198, 3, 'Error al eliminar el mensaje'),
(4830, 2199, 3, 'Error recuperando resultados de la red de intercambio del laboratorio'),
(4831, 2202, 3, 'Error en el fichero de concesión de privilegios para el usuario de LibreEHR.'),
(4832, 2205, 3, 'error al registrar la forma!'),
(4833, 2206, 3, 'Error al guardar el fichero'),
(4834, 2208, 3, 'Error al escribir en el fichero'),
(4835, 2210, 3, 'Error, Este file no existe'),
(4836, 2211, 3, 'ERROR, incapaz de recoger los datos de servidor'),
(4837, 2212, 3, 'Error, incapaz de crear certificado de cliente'),
(4838, 2213, 3, 'Error, incapaz de crear el certificado p12 de Admin'),
(4839, 2214, 3, 'Error. No puede crearse certificadodo de Certificado de Autenticación'),
(4840, 2215, 3, 'Error, incapaz de crear el certificado del servidor'),
(4841, 2216, 3, 'Error, incapaz de abrir el file'),
(4842, 2217, 3, 'Error. Certificado de Autenticación de usuario no está activado en LibreEHR'),
(4843, 2218, 3, 'Error. Necesita instalar el fichero/Tar.php módulo php'),
(4844, 2219, 3, 'ERROR: no pudo abrir tabla sql, formulario roto?'),
(4845, 2220, 3, 'Error: ID duplicado en línea'),
(4846, 2221, 3, 'Error: Nombre duplicado en línea'),
(4847, 2222, 3, 'ERROR: Campo'),
(4848, 2223, 3, 'ERROR: Falta el fichero comprimido del Módulo PHP'),
(4849, 2224, 3, 'ERROR: Sin directorio de importación ICD'),
(4850, 2225, 3, 'Error: las contraseñas no coinciden. Por favor, compruebe lo tecleado.'),
(4851, 2226, 3, 'Error: las contraseñas no coinciden. Por favor, compruebe lo tecleado.'),
(4852, 2227, 3, 'Error, este file no existe'),
(4853, 2228, 3, 'ERROR: La siguiente variable contiene caracteres inválidos'),
(4854, 2229, 3, 'ERROR: No se puede copiar el fichero.'),
(4855, 2230, 3, 'Error, incapaz de crear el fichero de descarga'),
(4856, 2231, 3, 'ERROR: No se puede crear el fichero comprimido.');
INSERT INTO `lang_definitions` VALUES
(4857, 2232, 3, 'ERROR: No se puede extraer el fichero.'),
(4858, 2233, 3, 'ERROR: No se puede leer el fichero en la base de datos.'),
(4859, 2234, 3, 'ERROR: No se puede establecer el número de versión.'),
(4860, 2235, 3, 'Errores'),
(4861, 2236, 3, 'Estado cuenta Receta electrónica'),
(4862, 2237, 3, 'Registros Receta electrónica'),
(4863, 2238, 3, 'Nombre Receta electrónica'),
(4864, 2239, 3, 'Contraseña Receta electrónica'),
(4865, 2240, 3, 'Rol Receta electrónica'),
(4866, 2241, 3, 'Usuario Receta electrónica'),
(4867, 2242, 3, 'Eritema'),
(4868, 2245, 3, 'Esquimal'),
(4869, 2247, 3, 'Paciente regular'),
(4870, 2249, 3, 'Raza'),
(4871, 2250, 3, 'La etnia o la raza'),
(4872, 2251, 3, 'Lista de Origen étnico--Raza (escriba, sólo añadir opcional)'),
(4873, 2252, 3, 'ETIN'),
(4874, 2253, 3, 'Evento'),
(4875, 2254, 3, 'Fecha comienzo de evento'),
(4876, 2255, 3, 'Categoría de evento'),
(4877, 2256, 3, 'Fecha evento'),
(4878, 2257, 3, 'Descripción evento'),
(4879, 2258, 3, 'Detalles evento'),
(4880, 2259, 3, 'Evento no se repite'),
(4881, 2260, 3, 'Duración de Evento'),
(4882, 2261, 3, 'Duración de evento en minutos'),
(4883, 2262, 3, 'Honorarios del evento'),
(4884, 2263, 3, 'Lugar de evento'),
(4885, 2264, 3, 'Evento repite cada'),
(4886, 2265, 3, 'Evento repite en'),
(4887, 2266, 3, 'Hora comienzo evento'),
(4888, 2267, 3, 'Título de evento'),
(4889, 2268, 3, 'Título de Evento'),
(4890, 2269, 3, 'Página web de evento'),
(4891, 2270, 3, 'Eventos'),
(4892, 2271, 3, 'Eventos para'),
(4893, 2272, 3, 'Eventos abre en nueva ventana'),
(4894, 2273, 3, 'cada'),
(4895, 2274, 3, 'Cada'),
(4896, 2275, 3, 'cada 3 horas'),
(4897, 2276, 3, 'cada 4 horas'),
(4898, 2277, 3, 'cada 5 horas'),
(4899, 2278, 3, 'cada 6 horas'),
(4900, 2279, 3, 'cada 8 horas'),
(4901, 2280, 3, 'cada cuarto'),
(4902, 2281, 3, 'uno sí, otro no'),
(4903, 2282, 3, 'cada tercero'),
(4904, 2283, 3, 'Cada, cada otro, cada 3ro, etc.'),
(4905, 2285, 3, 'Examen y los resultados de las pruebas'),
(4906, 2286, 3, 'Resultados del examen'),
(4907, 2289, 3, 'Examen'),
(4908, 2290, 3, 'Fecha de examen'),
(4909, 2291, 3, 'Ejemplo'),
(4910, 2292, 3, 'Ejemplos'),
(4911, 2293, 3, 'Exámenes/Pruebas'),
(4912, 2294, 3, 'Excepto'),
(4913, 2295, 3, 'Lagrimeo Excesivo'),
(4914, 2296, 3, 'Pacientes Excluídos'),
(4915, 2297, 3, 'Exclusiones'),
(4916, 2298, 3, 'Organización de provedor exclusivo (OPE)'),
(4917, 2299, 3, 'Tamaño papel ejecutivo'),
(4918, 2300, 3, 'Ejercicio'),
(4919, 2301, 3, 'Patrones del ejercicio'),
(4920, 2302, 3, 'Patrones de ejercicio'),
(4921, 2303, 3, 'Existe'),
(4922, 2304, 3, 'Salir de Administración'),
(4923, 2305, 3, 'Exp'),
(4924, 2306, 3, 'Expandir'),
(4925, 2307, 3, 'Expandir'),
(4926, 2308, 3, 'Expandir Todo'),
(4927, 2311, 3, 'Vista ampliada'),
(4928, 2312, 3, 'Se espera form_encounter.pid para ser '),
(4929, 2313, 3, 'Caducidad'),
(4930, 2314, 3, 'Fecha de caducidad'),
(4931, 2315, 3, 'Caducidad'),
(4932, 2316, 3, 'Expira en'),
(4933, 2317, 3, 'Exportar'),
(4934, 2318, 3, 'Exportar con CSV'),
(4935, 2319, 3, 'Exportar configuración'),
(4936, 2322, 3, 'Exportación de Demograficos del paciente'),
(4937, 2323, 3, 'Exportar Informe PQRI'),
(4938, 2325, 3, 'Selección de exportación como CSV'),
(4939, 2326, 3, 'Selección de las colecciones a la exportación'),
(4940, 2327, 3, 'Exportar a CSV'),
(4941, 2328, 3, 'Exportación al sistema de facturación externo'),
(4942, 2329, 3, 'Exposición a los países extranjeros'),
(4943, 2330, 3, 'Exposición a Países Extranjeros'),
(4944, 2331, 3, 'Ext tiempo de coleccionar'),
(4945, 2332, 3, 'Externo'),
(4946, 2334, 3, 'Carga de datos externos'),
(4947, 2335, 3, 'Utilidad de importación bbdd externa'),
(4948, 2336, 3, 'D.N.I.'),
(4949, 2337, 3, 'ID externo'),
(4950, 2338, 3, 'identificación externos'),
(4951, 2339, 3, 'Identificador externo'),
(4952, 2342, 3, 'Derivación externa'),
(4953, 2343, 3, 'Seguimiento de Derivaciones Externas'),
(4954, 2344, 3, '¿Derivación externa?'),
(4955, 2345, 3, 'Derivaciones externas'),
(4956, 2346, 3, 'Extraer este file comprimido'),
(4957, 2347, 3, 'Extrayendo fichero. Esto puede tardar algún tiempo...'),
(4958, 2348, 3, 'Exudado:'),
(4959, 2349, 3, 'Irritación de Ojo'),
(4960, 2350, 3, 'Dolor de Ojo'),
(4961, 2351, 3, 'Enrojecimiento de Ojo'),
(4962, 2352, 3, 'Ojos'),
(4963, 2353, 3, 'F'),
(4964, 2354, 3, 'F/H Problemas de Sangre'),
(4965, 2355, 3, 'F/H Hirsutismo Femenino/Estrías'),
(4966, 2356, 3, 'Centros'),
(4967, 2357, 3, 'Centro'),
(4968, 2358, 3, 'centro'),
(4969, 2359, 3, 'Administración del Centro'),
(4970, 2360, 3, 'Ciudad del Centro'),
(4971, 2361, 3, 'Código del Centro'),
(4972, 2362, 3, 'Código País del Centro'),
(4973, 2363, 3, 'Fax del Centro'),
(4974, 2364, 3, 'Nombre del Centro'),
(4975, 2365, 3, 'NPI del Centro'),
(4976, 2366, 3, 'Teléfono del Centro'),
(4977, 2367, 3, 'Información de usuario en el centro especificado'),
(4978, 2368, 3, 'Estado del Centro'),
(4979, 2369, 3, 'Dirección del Centro'),
(4980, 2370, 3, 'Código Postal del Centro'),
(4981, 2372, 3, 'Centro:'),
(4982, 2373, 3, 'Fallo'),
(4983, 2374, 3, 'fallado'),
(4984, 2375, 3, 'Fallado'),
(4985, 2380, 3, 'Fallo al crear la carpeta temporal. CouchDB no funcionará.'),
(4986, 2382, 3, 'Fallo'),
(4987, 2383, 3, 'error'),
(4988, 2390, 3, 'Historia familiar'),
(4989, 2391, 3, 'Historia Familiar de Glaucoma'),
(4990, 2392, 3, 'Historia'),
(4991, 2394, 3, 'Familia de pago'),
(4992, 2395, 3, 'Tamaño familia'),
(4993, 2396, 3, 'Suposición'),
(4994, 2398, 3, 'Iraní'),
(4995, 2400, 3, 'Padre'),
(4996, 2402, 3, 'Fatiga'),
(4997, 2403, 3, 'Fatigado'),
(4998, 2404, 3, 'Fax'),
(4999, 2405, 3, 'Contador fax'),
(5000, 2406, 3, 'Número de fax'),
(5001, 2408, 3, 'Fax/Escanear'),
(5002, 2409, 3, 'Faxes entrada'),
(5003, 2410, 3, 'Faxes salida'),
(5004, 2411, 3, 'Características'),
(5005, 2412, 3, 'Feb'),
(5006, 2413, 3, 'Febrero'),
(5007, 2414, 3, 'FECA'),
(5008, 2415, 3, 'Nº Colegiado'),
(5009, 2416, 3, 'Federal EIN'),
(5010, 2417, 3, 'Nº Identificación de impuesto federal'),
(5011, 2418, 3, 'Honorario'),
(5012, 2419, 3, 'honorario'),
(5013, 2420, 3, 'No se permiten honorarios'),
(5014, 2421, 3, 'Hoja de honorarios'),
(5015, 2422, 3, 'Opciones de la hoja de honorarios'),
(5016, 2423, 3, 'Honorarios'),
(5017, 2424, 3, 'Femenino'),
(5018, 2425, 3, 'AP Femenino'),
(5019, 2426, 3, 'Condones femeninos'),
(5020, 2427, 3, 'G Femenino'),
(5021, 2428, 3, 'LC Femenino'),
(5022, 2429, 3, 'P Femenino'),
(5023, 2430, 3, 'Síntomas Femeninos'),
(5024, 2431, 3, 'Mujeres VSC'),
(5025, 2434, 3, 'Fiebre'),
(5026, 2435, 3, 'Fiebre:'),
(5027, 2436, 3, 'Problemas de Sangre FH'),
(5028, 2437, 3, 'Fibromas'),
(5029, 2441, 3, 'Tipo de campo a utilizar para el país del empleador o abonado en demográficos.'),
(5030, 2442, 3, 'Tipo de campo a utilizar para el estado del empleador o abonado en demográficos.'),
(5031, 2443, 3, 'Falta Campo(s)!'),
(5032, 2447, 3, 'Fichero'),
(5033, 2448, 3, 'Fichero en el directorio de documentación para aprender como automatizar el proceso de creación de logs de backup'),
(5034, 2449, 3, 'Ubicacion del file'),
(5035, 2450, 3, 'Gestión de Fichero'),
(5036, 2453, 3, 'Fichero de permisos de usuario de LibreEHR'),
(5037, 2454, 3, 'Fallo en la recuperación de archivo de CouchDB'),
(5038, 2455, 3, 'Sala de archivo'),
(5039, 2456, 3, 'Fichero para adjuntar'),
(5040, 2458, 3, 'Un fichero con el mismo nombre ya existe en la ubicación:'),
(5041, 2459, 3, 'Nombre de fichero'),
(5042, 2461, 3, 'Ficheros'),
(5043, 2462, 3, 'Filipino'),
(5044, 2463, 3, 'Rellene cualquiera de las filas de abajo.'),
(5045, 2464, 3, 'Rellenar sólo si manda notificación a paciente por email'),
(5046, 2465, 3, 'Llenar los valores abajo'),
(5047, 2467, 3, 'Rellene la fila'),
(5048, 2468, 3, 'Filtro'),
(5049, 2469, 3, 'Filtro para los constantes'),
(5050, 2470, 3, 'Filtro por Definición'),
(5051, 2471, 3, 'Filtrado desde'),
(5052, 2472, 3, 'filtros'),
(5053, 2473, 3, 'Filtros'),
(5054, 2474, 3, 'Final'),
(5055, 2475, 3, 'Diagnóstico final'),
(5056, 2476, 3, 'Diagnóstico final por especialista'),
(5057, 2478, 3, 'Financiero'),
(5058, 2479, 3, 'Fecha cierre financiero (aaaa-mm-dd)'),
(5059, 2480, 3, 'Información financiera - cualquier cosa'),
(5060, 2481, 3, 'Información financiera - mis visitas'),
(5061, 2482, 3, 'Fecha de revisión financiero'),
(5062, 2483, 3, 'Resumen Financiero por Código de Servicio'),
(5063, 2484, 3, 'Buscar'),
(5064, 2485, 3, 'Buscar disponible'),
(5065, 2486, 3, 'Buscar citas disponibles'),
(5066, 2487, 3, 'Busca paciente'),
(5067, 2488, 3, 'Buscar materiales educativos para el paciente'),
(5068, 2489, 3, 'Conclusiones'),
(5069, 2490, 3, 'Conclusiones por especialista'),
(5070, 2491, 3, 'Multa'),
(5071, 2492, 3, 'Final Pagos'),
(5072, 2493, 3, 'Terminado'),
(5073, 2495, 3, 'Primero'),
(5074, 2497, 3, 'Primer día de la semana'),
(5075, 2498, 3, 'Nombre'),
(5076, 2499, 3, 'Nombre'),
(5077, 2500, 3, 'Nombre:'),
(5078, 2503, 3, 'Aptitud'),
(5079, 2504, 3, 'Condicion Fisica'),
(5080, 2505, 3, 'Condicion Fisica para este jugador hoy'),
(5081, 2507, 3, 'Aptitud para jugar'),
(5082, 2508, 3, 'Fijar fechas visita - cualquier visita'),
(5083, 2509, 3, 'Solucionar este'),
(5084, 2510, 3, 'FL'),
(5085, 2511, 3, 'Flatulencia'),
(5086, 2512, 3, 'Flujo'),
(5087, 2514, 3, 'Temporada de gripe'),
(5088, 2515, 3, 'Temporada de Gripe'),
(5089, 2516, 3, 'Vacunación gripe'),
(5090, 2517, 3, 'Problema de fluído y electrolito'),
(5091, 2518, 3, 'FMS'),
(5092, 2519, 3, 'Tamaño papel folio'),
(5093, 2520, 3, 'Seguir manualmente'),
(5094, 2521, 3, 'Siga estas instrucciones para instalar o actualizar la siguiente bbdd'),
(5095, 2522, 3, 'Seguimineto'),
(5096, 2524, 3, 'Motivo de seguimiento'),
(5097, 2525, 3, 'A continuación una nueva constante de cliente:'),
(5098, 2526, 3, 'A continuación un nuevo idioma de cliente:'),
(5099, 2527, 3, 'A continuación una nueva definición (Idioma, Constante, Definición):'),
(5100, 2529, 3, 'Servicios de seguimiento'),
(5101, 2530, 3, 'Seguimiento indicado'),
(5102, 2531, 3, 'Intolerancia del Alimento'),
(5103, 2532, 3, 'Pie'),
(5104, 2533, 3, 'Problemas en los píes'),
(5105, 2534, 3, 'Píe:'),
(5106, 2535, 3, 'Lesiones de fútbol'),
(5107, 2537, 3, 'Informe de lesión futbolística'),
(5108, 2538, 3, 'Tipo de calzado'),
(5109, 2539, 3, 'para'),
(5110, 2540, 3, 'Para'),
(5111, 2541, 3, 'Por Código'),
(5112, 2543, 3, 'Para reclamaciones de visita'),
(5113, 2544, 3, 'Por Ejemplo'),
(5114, 2547, 3, 'Por Factura'),
(5115, 2548, 3, 'Para Seguro médico sólo, obliga al facultativo de referencia a ser el mismo que el facultativo del representado.'),
(5116, 2552, 3, 'Para el profesional/Organizacion referida'),
(5117, 2553, 3, 'Por el pasado'),
(5118, 2554, 3, 'por variable'),
(5119, 2555, 3, 'para:'),
(5120, 2556, 3, 'Fuerza la apertura del widget de facturación'),
(5121, 2557, 3, 'Forzar Crear Nuevo Paciente'),
(5122, 2559, 3, 'Antebrazo'),
(5123, 2560, 3, 'Formulario'),
(5124, 2561, 3, 'formulario'),
(5125, 2564, 3, 'Formato'),
(5126, 2565, 3, 'formato'),
(5127, 2567, 3, 'Formato incorrecto para el NDC'),
(5128, 2568, 3, 'Formato usado para la mayoría de fechas'),
(5129, 2569, 3, 'Formato usado para mostrar la mayoría de horas.'),
(5130, 2570, 3, 'Informe Formateado'),
(5131, 2571, 3, 'Ex-fumador'),
(5132, 2572, 3, 'Formularios'),
(5133, 2573, 3, 'Formas de administración'),
(5134, 2575, 3, 'Re-enviar'),
(5135, 2576, 3, 'Reenviar Páginas vía fax'),
(5136, 2577, 3, 'Remitido'),
(5137, 2579, 3, 'Cuarto'),
(5138, 2581, 3, 'Fractura'),
(5139, 2582, 3, 'Fractura de escafoides'),
(5140, 2583, 3, 'Fractura del maléolo lat.'),
(5141, 2584, 3, 'Fractura del maléolo tibial.'),
(5142, 2585, 3, 'Fractura de base quinta (5 ª) metatarsianas'),
(5143, 2587, 3, 'Francés'),
(5144, 2588, 3, 'Francés (Canadiense)'),
(5145, 2589, 3, 'Francés (Standard)'),
(5146, 2590, 3, 'Frecuencia'),
(5147, 2591, 3, 'Resfriados Frecuentes'),
(5148, 2592, 3, 'Enfermedades Frecuentes'),
(5149, 2593, 3, 'Viernes'),
(5150, 2594, 3, 'Viernes'),
(5151, 2595, 3, 'Desde'),
(5152, 2596, 3, 'DESDE'),
(5153, 2597, 3, 'desde'),
(5154, 2598, 3, 'Fecha desde no puede ser mayor que fecha hasta'),
(5155, 2599, 3, 'Desde:'),
(5156, 2600, 3, 'Desde: '),
(5157, 2601, 3, 'FROM_CITY'),
(5158, 2603, 3, 'FROM_FNAME'),
(5159, 2604, 3, 'FROM_LNAME'),
(5160, 2605, 3, 'FROM_MNAME'),
(5161, 2607, 3, 'FROM_PHONECELL'),
(5162, 2608, 3, 'FROM_POSTAL'),
(5163, 2609, 3, 'FROM_STATE'),
(5164, 2610, 3, 'FROM_STREET'),
(5165, 2611, 3, 'FROM_TITLE'),
(5166, 2612, 3, 'FROM_VALEDICTORY'),
(5167, 2613, 3, 'Oficina central'),
(5168, 2614, 3, 'Recibos de la Oficina Central'),
(5169, 2615, 3, 'Reportes de Recibos de la Oficina Central'),
(5170, 2616, 3, 'Rec. Oficina Central'),
(5171, 2617, 3, 'La derecha frontal:'),
(5172, 2619, 3, 'Nombre Completo'),
(5173, 2620, 3, 'Ruta completa del directorio que contiene los ejecutables MySQL.'),
(5174, 2621, 3, 'Ruta completa del directorio que contiene los ejecutables Perl.'),
(5175, 2622, 3, 'Ruta completa del directorio para log de eventos de backup'),
(5176, 2623, 3, 'Ruta completa del directorio usado para ficheros temporales'),
(5177, 2624, 3, 'Juego completo'),
(5178, 2625, 3, 'Entrenamiento completo'),
(5179, 2626, 3, 'Pagado Total'),
(5180, 2633, 3, 'G'),
(5181, 2634, 3, 'G/DL'),
(5182, 2636, 3, 'Afección de la vesícula biliar'),
(5183, 2637, 3, 'Piedras en la vesícula'),
(5184, 2638, 3, 'Periodo de Juego'),
(5185, 2639, 3, 'Juegos'),
(5186, 2640, 3, 'Juegos faltados'),
(5187, 2641, 3, 'juegos/eventos'),
(5188, 2642, 3, 'Juegos/Eventos perdidos'),
(5189, 2644, 3, 'Gastritis'),
(5190, 2645, 3, 'Dolor Gastrointestinal'),
(5191, 2646, 3, 'Gastrointestinal'),
(5192, 2647, 3, 'Informe de estadísticas del GCAC'),
(5193, 2648, 3, 'Estadísticas GCAC'),
(5194, 2649, 3, 'Falta la forma de la visita del GCAC'),
(5195, 2650, 3, 'Género'),
(5196, 2651, 3, 'Género '),
(5197, 2652, 3, 'General'),
(5198, 2655, 3, 'Categoría de servicio general'),
(5199, 2657, 3, 'Generar y Descargar'),
(5200, 2658, 3, 'Generar y descargar HCFA 1500 reclamaciones en papel'),
(5201, 2659, 3, 'Generar y descargar batch X12'),
(5202, 2660, 3, 'Generar y descargar batch X12 de reclamación por visita'),
(5203, 2663, 3, 'Generar y transmitir electrónicamente las recetas autorizadas.'),
(5204, 2664, 3, 'Generar formulario CMS 1500'),
(5205, 2665, 3, 'Generar formulario CMS 1500 PDF'),
(5206, 2666, 3, 'Generar formulario CMS 1500 TEXTO'),
(5207, 2667, 3, 'Genere HCFA'),
(5208, 2668, 3, 'Generar factura'),
(5209, 2669, 3, 'Genere la Carta'),
(5210, 2670, 3, 'Generar carta relacionada '),
(5211, 2671, 3, 'Generar informe PQRI (Método A)'),
(5212, 2673, 3, 'Generar informe PQRI (Método E)'),
(5213, 2677, 3, 'Generar informe'),
(5214, 2678, 3, 'Generar usuario y contraseña para'),
(5215, 2679, 3, 'Generar X12'),
(5216, 2680, 3, 'Generar visita X12'),
(5217, 2682, 3, 'Generado en'),
(5218, 2683, 3, 'genera'),
(5219, 2684, 3, 'Genitourinario'),
(5220, 2687, 3, 'Alemán'),
(5221, 2691, 3, 'Obtener HL7'),
(5222, 2692, 3, 'Glaucoma'),
(5223, 2693, 3, 'Historia Familiar de Glaucoma'),
(5224, 2694, 3, 'Global'),
(5225, 2696, 3, 'ID Global'),
(5226, 2697, 3, 'Ajustes Globales'),
(5227, 2698, 3, 'Globales'),
(5228, 2699, 3, 'GM/DL'),
(5229, 2700, 3, 'ir'),
(5230, 2701, 3, 'Ir'),
(5231, 2704, 3, 'Ir a'),
(5232, 2705, 3, 'Ir a la semana del'),
(5233, 2706, 3, 'Ir hoy'),
(5234, 2711, 3, 'Grado de la lesión'),
(5235, 2712, 3, 'Grado:'),
(5236, 2713, 3, 'Gramos'),
(5237, 2714, 3, 'Suma total'),
(5238, 2715, 3, 'Sumas totales'),
(5239, 2718, 3, 'Posibilidad de gráfico'),
(5240, 2720, 3, 'Mayor que'),
(5241, 2721, 3, 'Mayor que o Igual a'),
(5242, 2722, 3, 'Griego'),
(5243, 2724, 3, 'Grupo'),
(5244, 2725, 3, 'Nombre de Grupo'),
(5245, 2726, 3, 'Los nombres de los grupos no pueden quedar en blanco'),
(5246, 2727, 3, 'Los nombres de los grupos no pueden iniciar con números'),
(5247, 2728, 3, 'Los nombres de grupo no pueden comenzar con números.'),
(5248, 2729, 3, 'Número de grupo'),
(5249, 2730, 3, 'Grupo de pago'),
(5250, 2731, 3, 'Grupo:'),
(5251, 2732, 3, 'Nombre del grupo'),
(5252, 2733, 3, 'Controles de grupos y accesos'),
(5253, 2734, 3, 'Gráfico de Crecimiento'),
(5254, 2735, 3, 'Gráfico de Crecimiento'),
(5255, 2736, 3, 'gtts (gotas)'),
(5256, 2737, 3, 'Guamés'),
(5257, 2739, 3, 'Nombre del tutor'),
(5258, 2741, 3, 'Examen ginecológico'),
(5259, 2742, 3, 'h'),
(5260, 2743, 3, 'h.s.'),
(5261, 2744, 3, 'H/O Hepatitis'),
(5262, 2745, 3, 'se ha suprimido con éxito. Cualquier sub-categorías si fueron trasladados abajo'),
(5263, 2746, 3, 'Hematoma/moratón'),
(5264, 2747, 3, 'HAI Estado'),
(5265, 2750, 3, 'manos + dedos'),
(5266, 2751, 3, 'Problemas de manos'),
(5267, 2752, 3, 'Disco Duro'),
(5268, 2753, 3, 'Dificultad sin'),
(5269, 2754, 3, 'se ha ligado para visitar'),
(5270, 2755, 3, 'ha expirado'),
(5271, 2756, 3, 'Función Hash'),
(5272, 2757, 3, 'No existe hash para este fichero. Un nuevo hash será generado.'),
(5273, 2758, 3, 'Hash no coincide. La integridad de datos se ha visto comprometida.'),
(5274, 2760, 3, 'Hawaiano'),
(5275, 2761, 3, 'Actividades peligrosas'),
(5276, 2762, 3, 'Actividades peligrosas'),
(5277, 2763, 3, 'Margen izquierdo de HCFA en puntos'),
(5278, 2764, 3, 'Márgenes de HCFA'),
(5279, 2765, 3, 'Margen superior en puntos de HCFA'),
(5280, 2766, 3, 'Procedimiento/Servicio HCPCS'),
(5281, 2767, 3, 'PostCalendar '),
(5282, 2768, 3, 'Cabeza'),
(5283, 2769, 3, 'Jefe Circ'),
(5284, 2770, 3, 'Circunferencia de la cabeza'),
(5285, 2771, 3, 'Dolor de cabeza'),
(5286, 2772, 3, 'Dolores de cabeza'),
(5287, 2773, 3, 'Operaciones de atención médica'),
(5288, 2774, 3, 'Operaciones de Atención Médica'),
(5289, 2775, 3, 'Centro de salud/clínica'),
(5290, 2776, 3, 'Organización para el mantenimiento de la salud'),
(5291, 2777, 3, 'Riesgo de Seguro médico de la organización de mantenimiento de salud (HMO)'),
(5292, 2778, 3, 'Pérdida de Oído'),
(5293, 2779, 3, 'Ataque al Corazón'),
(5294, 2780, 3, 'Enfermedad del corazón'),
(5295, 2781, 3, 'Fallo cardiaco'),
(5296, 2782, 3, 'Problema del Corazón'),
(5297, 2783, 3, 'Problemas de corazón'),
(5298, 2784, 3, 'Cirugía del Corazón'),
(5299, 2785, 3, 'Transplante de corazón'),
(5300, 2786, 3, 'CORAZÓN:'),
(5301, 2787, 3, 'Ardor de estómago'),
(5302, 2788, 3, 'Calor o Frío'),
(5303, 2789, 3, 'Calor o Frío'),
(5304, 2791, 3, 'Hebreo'),
(5305, 2793, 3, 'HEENT'),
(5306, 2794, 3, 'Altura'),
(5307, 2796, 3, 'Ayuda'),
(5308, 2797, 3, 'ayuda'),
(5309, 2798, 3, 'Hematemesis'),
(5310, 2799, 3, 'Hematoquecia'),
(5311, 2800, 3, 'Hematológico'),
(5312, 2801, 3, 'Hematuria'),
(5313, 2802, 3, 'Hemoglobina'),
(5314, 2803, 3, 'Hemoglobina A1C'),
(5315, 2804, 3, 'Hemoptisis'),
(5316, 2805, 3, 'Hepatitis'),
(5317, 2806, 3, 'Hepatitis A 1'),
(5318, 2807, 3, 'Hepatitis A 2'),
(5319, 2808, 3, 'Hepatitis B 1'),
(5320, 2809, 3, 'Hepatitis B 2'),
(5321, 2810, 3, 'Hepatitis B 3'),
(5322, 2811, 3, 'aqui'),
(5323, 2813, 3, 'Reparación de la hernia'),
(5324, 2814, 3, 'disco herniado'),
(5325, 2815, 3, 'Herpes'),
(5326, 2816, 3, 'Vacilación'),
(5327, 2817, 3, 'Ey, tú. has estado aquí para '),
(5328, 2818, 3, 'Hib 1'),
(5329, 2819, 3, 'Hib 2'),
(5330, 2820, 3, 'Hib 3'),
(5331, 2821, 3, 'Hib 4'),
(5332, 2822, 3, 'Oculto'),
(5333, 2823, 3, 'Administración de eventos ocultos'),
(5334, 2824, 3, 'Ocultar'),
(5335, 2825, 3, 'Ocultar detalles'),
(5336, 2827, 3, 'Ocultar Opciones Encriptación/Desencriptación en Documento de Gestión'),
(5337, 2828, 3, 'Ocultar Menú'),
(5338, 2830, 3, 'Ocultar avisos'),
(5339, 2831, 3, 'Ocultar/Mostrar Columnas'),
(5340, 2833, 3, 'Alto'),
(5341, 2834, 3, 'Presión Sanguínea Alta'),
(5342, 2835, 3, 'Indú'),
(5343, 2836, 3, 'Cadera + ingle'),
(5344, 2837, 3, 'Cadera y ingle'),
(5345, 2838, 3, 'Problemas de cadera'),
(5346, 2839, 3, 'Reemplazo de Cadera'),
(5347, 2840, 3, 'Aviso Recibido de HIPPA'),
(5348, 2842, 3, 'Hirsutismo/Estrías'),
(5349, 2843, 3, 'Hispano'),
(5350, 2844, 3, 'Hispano - Otro (Nacido en USA)'),
(5351, 2845, 3, 'Hispano - Otro (Nacido fuera de USA)'),
(5352, 2846, 3, 'Hispano o Latino'),
(5353, 2847, 3, 'Historia'),
(5354, 2848, 3, 'Historia de Datos'),
(5355, 2849, 3, 'Fecha historia'),
(5356, 2851, 3, 'Historia de Murmullos'),
(5357, 2852, 3, 'Historia no autorizada'),
(5358, 2853, 3, 'Historia de los Murmullos de Corazón'),
(5359, 2854, 3, 'Hits'),
(5360, 2855, 3, 'HIV'),
(5361, 2858, 3, 'Visor HL7'),
(5362, 2860, 3, 'HMO/L'),
(5363, 2861, 3, 'Hmong'),
(5364, 2862, 3, 'Mantener pulsado [Ctrl] para múltiples selecciones o desmarcados'),
(5365, 2863, 3, 'Mantener pulsado Ctrl para seleccionar múltiples elementos'),
(5366, 2864, 3, 'Mantenga presionada la tecla CTRL para seleccionar varios escuadrones'),
(5367, 2865, 3, 'Inicio'),
(5368, 2866, 3, 'Teléfono de casa'),
(5369, 2867, 3, 'Número de Teléfono de Casa'),
(5370, 2868, 3, 'Sin hogar o similares?'),
(5371, 2869, 3, 'Sin hogar, etc.'),
(5372, 2870, 3, 'Sin hogar, etc'),
(5373, 2872, 3, 'Nombre de Huesped'),
(5374, 2873, 3, 'El nombre del huesped no puede estar vacio'),
(5375, 2875, 3, 'Hora'),
(5376, 2876, 3, 'Horas'),
(5377, 2878, 3, '¿Cómo ocurrió la lesión?'),
(5378, 2879, 3, '¿Cómo ocurrió la lesión?:'),
(5379, 2880, 3, 'Como nos ha conocido'),
(5380, 2881, 3, '¿Cuántos meses de antelación a la consulta para los próximos eventos?'),
(5381, 2882, 3, 'HPI:'),
(5382, 2883, 3, 'Altura'),
(5383, 2884, 3, 'HTML'),
(5384, 2886, 3, 'Vínculo Https segurizado para el soporte LibreEHR LLC Laboratorio de intercambio de sevicio.'),
(5385, 2887, 3, 'Húngaro'),
(5386, 2888, 3, 'Hylafax Directorio'),
(5387, 2889, 3, 'Hylafax Commando Enscript'),
(5388, 2890, 3, 'Hylafax Servidor'),
(5389, 2891, 3, 'Hylafax Servidor Hostname'),
(5390, 2892, 3, 'Hiperactivo'),
(5391, 2893, 3, 'Hipertensión'),
(5392, 2894, 3, 'Hipertensión: Medida de presión arterial'),
(5393, 2895, 3, 'Hipertensión: Medida de presión arterial (GCC)'),
(5394, 2896, 3, 'Hipertiroidismo'),
(5395, 2897, 3, 'Hipotiroidismo'),
(5396, 2898, 3, 'Histerectomía'),
(5397, 2899, 3, 'I'),
(5398, 2900, 3, 'Estoy ocupado durante este periodo.'),
(5399, 2901, 3, 'No tengo permiso para leer '),
(5400, 2902, 3, 'CIE'),
(5401, 2903, 3, 'Diagnóstico ICD10'),
(5402, 2904, 3, 'Procedimiento/Servicio ICD10'),
(5403, 2905, 3, 'CIE9'),
(5404, 2906, 3, 'Diagnóstico ICD9'),
(5405, 2907, 3, 'Procedimiento/Servicio ICD9'),
(5406, 2909, 3, 'Nº Identificación'),
(5407, 2910, 3, 'Id'),
(5408, 2911, 3, 'La ID no puede quedar en blanco'),
(5409, 2912, 3, 'Tarjeta ID'),
(5410, 2913, 3, 'IDays'),
(5411, 2914, 3, 'identificado como'),
(5412, 2915, 3, 'Identificador (una palabra)'),
(5413, 2917, 3, 'Tiempo de espera inactivo en segundos'),
(5414, 2919, 3, 'Si todos los datos para todas las columnas están completos para este formulario'),
(5415, 2920, 3, 'Si la justificación de facturación se utiliza introduzca el nombre del código de tipo de diagnóstico.'),
(5416, 2921, 3, 'Si es introducido, seleccione solamente aquel que ha tenido este servicio'),
(5417, 2922, 3, 'Si el nombre, apellido de cualquier parte o apellido, Nombre'),
(5418, 2923, 3, 'Si pagando por'),
(5419, 2924, 3, 'Si la persona ha fallecido, introducir la fecha de la muerte.'),
(5420, 2925, 3, 'Si usa SMTP, nombre del servidor host o la dirección IP.'),
(5421, 2926, 3, 'Si usa SMTP, puerto TCP del servidor (normalmente 25).'),
(5422, 2927, 3, 'Si no tiene trabajo, poner Estudiante'),
(5423, 2929, 3, 'Si cambia el rol de la ePrescripción de receta electrónica, puede afectar al flujo de la ePrescripción. Frente a cualquier dificultad, contacte con su prescriptor de ePrescripción.'),
(5424, 2931, 3, 'Si ha elegido adjuntar las remesas electrónicas, entonces la ventana de búsqueda se vuelve a mostrar con las facturas correspondientes al fichero X12. Puede hacer click en cualquiera de estos números de factura (como se describe a continuación) si desea hacer las correcciones antes de enviar la remesa. Para aplicar los cambios, haga click en el botón de procesar ficheros ERA en la parte inferior de la pantalla. Esto generará una nueva ventana con un informe detallado.'),
(5425, 2932, 3, 'Si ha introducido una Fecha de Pago en la página de búsqueda, esto sobreescribirá la fecha de contabilización de los pagos y ajustes que de otro modo son tomados del fichero X12. Esto puede ser útil para los informes, si usted quiere que sus informes de recetas usen su fecha en lugar que la de proceso de la Sociedad Médica. Recuerde que esto también afectará a las fechas de pagos anteriores y a los ajustes que se ponen en reclamaciones secundarias.'),
(5426, 2933, 3, 'Si quiere cambiar tipos de datos, o añadir filas o columnas'),
(5427, 2934, 3, 'Si quiere actualizar la base de datos, coloque el fichero comprimido de base de datos en el siguiente directorio'),
(5428, 2936, 3, 'Desconocido'),
(5429, 2937, 3, 'Enfermedad'),
(5430, 2938, 3, 'IM'),
(5431, 2941, 3, 'Servicio de imágenes'),
(5432, 2942, 3, 'Vacunación'),
(5433, 2943, 3, 'Código Vacunación'),
(5434, 2945, 3, 'Fecha Vacunación'),
(5435, 2947, 3, 'Número de lote Vacunación'),
(5436, 2948, 3, 'Fabricante de Vacunación'),
(5437, 2949, 3, 'Registro Vacunación'),
(5438, 2951, 3, 'Servicio de Vacunación'),
(5439, 2952, 3, 'Título Vacunación'),
(5440, 2953, 3, 'Vacunaciones'),
(5441, 2954, 3, 'Vacunar'),
(5442, 2955, 3, 'Inmunológicas'),
(5443, 2956, 3, 'Implantes'),
(5444, 2957, 3, 'Importar'),
(5445, 2961, 3, 'Importarr el certificado al buscador'),
(5446, 2962, 3, 'Importar configuración'),
(5447, 2964, 3, 'Importar Paciente'),
(5448, 2965, 3, 'Importar Demográficos del Paciente'),
(5449, 2966, 3, 'Códigos importantes'),
(5450, 2969, 3, 'Importados de Contabilidad'),
(5451, 2972, 3, 'Mejorado'),
(5452, 2973, 3, 'ingreso'),
(5453, 2974, 3, 'ingreso'),
(5454, 2975, 3, 'dentro de cada ojo'),
(5455, 2976, 3, 'en ojo izquierdo'),
(5456, 2977, 3, 'en los agujeros de la nariz'),
(5457, 2978, 3, 'Entrada'),
(5458, 2979, 3, 'en ojo derecho'),
(5459, 2980, 3, 'Dentro de la empresa'),
(5460, 2981, 3, 'Inactivo'),
(5461, 2982, 3, 'Días no activo'),
(5462, 2983, 3, 'Entrada'),
(5463, 2986, 3, 'Incluya checksum'),
(5464, 2987, 3, 'Incluya completado'),
(5465, 2988, 3, 'Incluir los usuarios inactivos'),
(5466, 2989, 3, 'Incluir a un no clasificado'),
(5467, 2990, 3, 'Incluir datos no estructurados'),
(5468, 2991, 3, 'Incluir constantes vitales'),
(5469, 2992, 3, '¿Incluir las constantes vitales?'),
(5470, 2993, 3, 'Inclusión'),
(5471, 2994, 3, 'Ingresos'),
(5472, 2996, 3, 'Incompleto'),
(5473, 2997, 3, 'Tratamiento Aborto incompleto'),
(5474, 2998, 3, 'Incontinencia'),
(5475, 2999, 3, 'Incorporar resultados clínicos del test de laboratorio al certificado tecnológico EHR como estructura'),
(5476, 3001, 3, 'aumentado:'),
(5477, 3002, 3, 'Seguro de Indemnización'),
(5478, 3003, 3, 'indeterminado'),
(5479, 3004, 3, 'Indio'),
(5480, 3005, 3, 'Indica anormalidad'),
(5481, 3006, 3, 'Indica si esta incidencia está activa'),
(5482, 3008, 3, 'Indicador de uso especializado'),
(5483, 3009, 3, 'Pacientes indigentes'),
(5484, 3010, 3, 'Informe de Pacientes Indigentes'),
(5485, 3011, 3, 'Indigentes'),
(5486, 3014, 3, 'Aborto Inducido'),
(5487, 3016, 3, 'Ilegible'),
(5488, 3017, 3, 'Infección/abceso'),
(5489, 3018, 3, 'Infecciones'),
(5490, 3019, 3, 'Consejo Infertilidad'),
(5491, 3020, 3, 'Infertilidad'),
(5492, 3021, 3, 'Gripe 1'),
(5493, 3022, 3, 'Gripe 2'),
(5494, 3023, 3, 'Vacunación gripe p/ pacientes may.50 años'),
(5495, 3024, 3, 'Vacunación gripe p/ pacientes may.50 años (GCC)'),
(5496, 3025, 3, 'Vacuna gripe'),
(5497, 3026, 3, 'Información'),
(5498, 3027, 3, 'Información de ensayo 1'),
(5499, 3028, 3, 'Información de ensayo 2'),
(5500, 3029, 3, 'Información de ensayo 3'),
(5501, 3030, 3, 'Información de ensayo 4'),
(5502, 3031, 3, 'Información de ensayo 5'),
(5503, 3032, 3, 'Información de ensayo 6'),
(5504, 3034, 3, 'Inhalaciones'),
(5505, 3035, 3, 'Inhalaciones'),
(5506, 3037, 3, 'Usuario Inicial'),
(5507, 3038, 3, 'Lesión/Rehabilitación'),
(5508, 3039, 3, 'Inyectables'),
(5509, 3040, 3, 'Inyeccion'),
(5510, 3041, 3, 'Parte del cuerpo lesionada'),
(5511, 3042, 3, 'Herido a Fuera'),
(5512, 3043, 3, 'Herido'),
(5513, 3044, 3, 'Mecanismo de lesión'),
(5514, 3045, 3, 'Informe General de lesión'),
(5515, 3046, 3, 'Vigilancia de Lesiones'),
(5516, 3047, 3, 'Tipo de lesión'),
(5517, 3048, 3, 'Relacionado a lesion/enfermedad'),
(5518, 3051, 3, 'Campos de entrada'),
(5519, 3052, 3, 'Tiempo Protrombina'),
(5520, 3053, 3, 'Ins 1'),
(5521, 3054, 3, 'Ins 2 o Ins 3'),
(5522, 3056, 3, 'Ajuste Seg'),
(5523, 3057, 3, 'Ins bundling'),
(5524, 3058, 3, 'Código Aseguradora'),
(5525, 3061, 3, 'Sobre pago Seg'),
(5526, 3063, 3, 'Reembolso Seg'),
(5527, 3064, 3, 'Resumen Seg'),
(5528, 3065, 3, 'Seg1'),
(5529, 3066, 3, 'Seg2'),
(5530, 3067, 3, 'Seg3'),
(5531, 3069, 3, 'Insertar fallido: '),
(5532, 3070, 3, 'Introduzca los eventos antiguos en tablas'),
(5533, 3072, 3, 'Insomnio'),
(5534, 3074, 3, 'Inspección'),
(5535, 3075, 3, 'Inestabilidad/subluxación'),
(5536, 3076, 3, 'INSTALAR'),
(5537, 3077, 3, 'Instalar'),
(5538, 3079, 3, 'Instalar DB'),
(5539, 3080, 3, 'Versión instalada'),
(5540, 3081, 3, 'instrucciones'),
(5541, 3082, 3, 'Instrucción'),
(5542, 3084, 3, 'instrucciones:'),
(5543, 3085, 3, 'Inventario insuficiente para ID producto'),
(5544, 3086, 3, 'Diabetes insulino dependente'),
(5545, 3087, 3, 'Seguro'),
(5546, 3088, 3, 'Seguro'),
(5547, 3091, 3, 'Saldo del seguro'),
(5548, 3093, 3, 'Sociedad Médica'),
(5549, 3094, 3, 'Sociedades Médicas'),
(5550, 3095, 3, 'Sociedad Médica'),
(5551, 3096, 3, 'Sociedad Médica Buscar/Añadir'),
(5552, 3098, 3, 'Data Seguro'),
(5553, 3099, 3, 'Información del Seguro en fichero'),
(5554, 3100, 3, 'Num Seguro'),
(5555, 3101, 3, 'Pago Aseguradora'),
(5556, 3103, 3, 'Proveedor de Seguro'),
(5557, 3106, 3, 'Asegurado'),
(5558, 3107, 3, 'Conclusión Ingesta'),
(5559, 3108, 3, 'Fecha de Ingesta'),
(5560, 3109, 3, 'Declinación intelectual'),
(5561, 3113, 3, 'Error interno - no se seleccionó ningunas páginas!'),
(5562, 3114, 3, 'Error interno - Nº Identificación del paciente no proporcionado!'),
(5563, 3115, 3, '¡Error interno al accede al fichero adjunto!'),
(5564, 3116, 3, '¡Error interno!'),
(5565, 3117, 3, 'Error interno, Nº Identificación de medicamento no especificado!'),
(5566, 3119, 3, 'Error interno: reclamación '),
(5567, 3120, 3, 'Error Interno: visita '''),
(5568, 3121, 3, 'Error interno: pid o visita no existe.'),
(5569, 3122, 3, 'Error interno: no parece haber una visita!'),
(5570, 3123, 3, 'Identificador interno (pid)'),
(5571, 3126, 3, 'Derivaciones Internas'),
(5572, 3127, 3, 'Tiempo de coleccion interno'),
(5573, 3128, 3, 'Deber Internacional'),
(5574, 3129, 3, 'Intérprete'),
(5575, 3130, 3, 'Require Intérprete?'),
(5576, 3131, 3, 'Enfermedad Pulmonar Intersticial'),
(5577, 3132, 3, 'Intervalo'),
(5578, 3135, 3, 'Intervención'),
(5579, 3137, 3, 'Intolerancia'),
(5580, 3139, 3, 'Intramuscularmente'),
(5581, 3140, 3, 'Intravenoso'),
(5582, 3141, 3, 'Introducción'),
(5583, 3144, 3, 'Carácter inválido en'),
(5584, 3147, 3, 'Longitud inválida para'),
(5585, 3148, 3, 'Carácter no-numérico inválido en'),
(5586, 3149, 3, 'Inválido o pagador ausente en fuente para código '),
(5587, 3151, 3, 'Códigos de Servicio Inválidos'),
(5588, 3152, 3, 'Designación de la fuente inválida -'),
(5589, 3154, 3, 'InvAmt'),
(5590, 3155, 3, 'Inventario'),
(5591, 3156, 3, 'Actividad de inventario'),
(5592, 3157, 3, 'Inventario y venta, ambos medicamentos y productos no farmacológicos'),
(5593, 3158, 3, 'Inventario y venta medicamentos sólo'),
(5594, 3159, 3, 'El inventario no está disponible para esta orden.'),
(5595, 3160, 3, 'Lista de Inventario'),
(5596, 3161, 3, 'Inventario Transacciones'),
(5597, 3162, 3, 'Factura'),
(5598, 3163, 3, 'factura'),
(5599, 3164, 3, 'Factura saldo'),
(5600, 3165, 3, 'Factura saldo no puede ser enviado. No hay visita creada.'),
(5601, 3166, 3, 'Fecha de Factura'),
(5602, 3167, 3, 'Factura no tiene fecha'),
(5603, 3168, 3, 'Número Factura'),
(5604, 3169, 3, 'Número Referencia Factura'),
(5605, 3170, 3, 'Número referencia factura, si se usa'),
(5606, 3171, 3, 'Número referencia factura'),
(5607, 3172, 3, 'Número referencia factura'),
(5608, 3173, 3, 'Factura:'),
(5609, 3174, 3, 'Fundación Internacional de Planificación Familiar'),
(5610, 3177, 3, 'Datos para SRH IPPF'),
(5611, 3178, 3, 'Informe de las estadísticas de IPPF'),
(5612, 3179, 3, 'Estado Fundación Internacional de Planificación Familiar'),
(5613, 3180, 3, 'IPV 1'),
(5614, 3181, 3, 'IPV 2'),
(5615, 3182, 3, 'IPV 3'),
(5616, 3183, 3, 'IPV 4'),
(5617, 3185, 3, 'Latido de Corazón Irregular'),
(5618, 3186, 3, 'Irritabilidad'),
(5619, 3187, 3, 'Irritación'),
(5620, 3190, 3, 'es la versión más reciente de la siguiente bbdd'),
(5621, 3191, 3, 'es un campo requerido.'),
(5622, 3192, 3, 'es un nodo de raíz y no puede ser suprimido.'),
(5623, 3197, 3, 'no es válido (las fracciones decimales están bien).'),
(5624, 3198, 3, '¿El PHP utiliza el modo a prueba de fallos?'),
(5625, 3200, 3, '¿Se traduce el texto del formulario plantilla?'),
(5626, 3201, 3, '¿Se traduce el texto de listas?'),
(5627, 3202, 3, '¿Está encriptado el fichero?'),
(5628, 3204, 3, '¿Este es un tipo de diagnóstico?'),
(5629, 3207, 3, '¿Es un tipo de procedimiento/servicio?'),
(5630, 3209, 3, '¿Este tipo de código está activo?'),
(5631, 3210, 3, '¿Este código se usa en reclamaciones?'),
(5632, 3212, 3, '¿Es un tipo oculto en la hoja de honorarios?'),
(5633, 3213, 3, '¿Se usa en las tablas sql externas? Si es así, elija el formato.'),
(5634, 3214, 3, 'es muy largo'),
(5635, 3216, 3, 'Incidencia'),
(5636, 3217, 3, 'incidencia'),
(5637, 3218, 3, 'Fecha Incidencia'),
(5638, 3219, 3, 'Nº Identificación incidencia'),
(5639, 3220, 3, 'Título de incidencia'),
(5640, 3223, 3, 'Incidencias'),
(5641, 3224, 3, 'Incidencias (Lesiones, Médicas, Alergias)'),
(5642, 3225, 3, 'Incidencias (Lesiones, Médicas, Alergias):'),
(5643, 3226, 3, 'Incidencias y Encuentros'),
(5644, 3227, 3, 'Incidencias y Encuentros de'),
(5645, 3228, 3, 'Incidencias no autorizadas'),
(5646, 3229, 3, 'Sección de Incidencias'),
(5647, 3230, 3, 'Italiano'),
(5648, 3231, 3, 'Artículo'),
(5649, 3232, 3, 'Artículo'),
(5650, 3233, 3, 'temas'),
(5651, 3234, 3, 'La carga de artículos falló'),
(5652, 3235, 3, 'IU/L'),
(5653, 3236, 3, 'IUD'),
(5654, 3237, 3, 'IV'),
(5655, 3238, 3, 'Ener'),
(5656, 3239, 3, 'Enero'),
(5657, 3240, 3, 'Japonés'),
(5658, 3241, 3, 'Ictericia'),
(5659, 3243, 3, 'Descripción del trabajo'),
(5660, 3244, 3, 'Nº Identificación del trabajo'),
(5661, 3245, 3, 'Dislocaciones de articulaciones'),
(5662, 3246, 3, 'Dolor en las Articulaciones'),
(5663, 3247, 3, 'Esguinces de articulaciones'),
(5664, 3248, 3, 'Jul'),
(5665, 3249, 3, 'Julio'),
(5666, 3250, 3, 'Jun'),
(5667, 3251, 3, 'Junio'),
(5668, 3252, 3, 'Justo debajo, revise la información del área azul donde pone sus parámetros de búsqueda. Puede buscar por nombre del paciente, número de gráfico, número de visita o fecha de servicio, o cualquier combinación de éstos. También puede ver todas las facturas, facturas pendientes o impagadas (por el paciente). Click en el botón de búsqueda para realizar la búsqueda.'),
(5669, 3253, 3, 'Solo mío'),
(5670, 3255, 3, 'Justificar'),
(5671, 3256, 3, 'Justificar/Guardar'),
(5672, 3258, 3, 'k, aquí está el resto'),
(5673, 3264, 3, 'Clave'),
(5674, 3265, 3, 'Palabras Claves'),
(5675, 3266, 3, 'kg'),
(5676, 3267, 3, 'kg/m^2'),
(5677, 3269, 3, 'Cáncer de Riñon'),
(5678, 3270, 3, 'Fallo Renal'),
(5679, 3271, 3, 'Infecciones de Riñón'),
(5680, 3272, 3, 'Piedra en el Riñón'),
(5681, 3273, 3, 'Transplante de Riñon'),
(5682, 3277, 3, 'Rodilla'),
(5683, 3278, 3, 'Problemas de la rodilla'),
(5684, 3279, 3, 'Reemplazo de Rodilla'),
(5685, 3282, 3, 'Coreano'),
(5686, 3286, 3, 'Laboratorio'),
(5687, 3288, 3, 'Sitio Web del Laboratorio de intercambio'),
(5688, 3289, 3, 'Nº Identificación Laboratorio de intercambio'),
(5689, 3290, 3, 'Nº Identificación ficha Laboratorio de intercambio'),
(5690, 3294, 3, 'Consulta de estado de Laboratorio'),
(5691, 3295, 3, 'Informe del Laboratorio'),
(5692, 3296, 3, 'Resultado Laboratorio'),
(5693, 3297, 3, 'Resultados Laboratorio'),
(5694, 3299, 3, 'Informe Resultados Laboratorio'),
(5695, 3300, 3, 'Servicio de laboratorio'),
(5696, 3301, 3, 'Resultados del test de Laboratorio'),
(5697, 3303, 3, 'Etiqueta'),
(5698, 3304, 3, 'Etiqueta no puede estar en blanco'),
(5699, 3305, 3, 'Col etiqueta'),
(5700, 3306, 3, 'Etiqueta para este tipo'),
(5701, 3307, 3, 'EtiquetasColumn debe ser un número entre 1 y 999'),
(5702, 3308, 3, 'Etiquetas'),
(5703, 3311, 3, 'Laboratorio'),
(5704, 3312, 3, 'Laceración/Cond. Piel'),
(5705, 3313, 3, 'Laceración/abrasión'),
(5706, 3316, 3, 'Idioma'),
(5707, 3317, 3, 'Código Idioma'),
(5708, 3318, 3, 'Definición de lenguaje agregada'),
(5709, 3319, 3, 'Herramienta de interfaz de idioma'),
(5710, 3320, 3, 'Lista de lenguajes (escribir, addonly opcional)'),
(5711, 3321, 3, 'Nombre Idioma'),
(5712, 3322, 3, 'Idioma:'),
(5713, 3324, 3, 'Laosiano'),
(5714, 3325, 3, 'Último'),
(5715, 3326, 3, 'Última Actividad Fecha'),
(5716, 3328, 3, 'Última Fecha de Cuenta'),
(5717, 3330, 3, 'Último año calendario'),
(5718, 3333, 3, 'Última visita'),
(5719, 3340, 3, 'Último nivel facturado'),
(5720, 3343, 3, 'Último Mes'),
(5721, 3344, 3, 'Apellido(s)'),
(5722, 3345, 3, 'Apellido(s)'),
(5723, 3346, 3, 'Apellido(s):'),
(5724, 3350, 3, 'Ultima revision'),
(5725, 3352, 3, 'Última guardados'),
(5726, 3356, 3, 'Última actualización por'),
(5727, 3357, 3, 'Ultima verificación el'),
(5728, 3358, 3, 'Última Visita'),
(5729, 3360, 3, 'Recurrencia tardía (2-12 Mes)'),
(5730, 3361, 3, 'Maléolo lateral'),
(5731, 3362, 3, 'Maléolo lateral:'),
(5732, 3363, 3, 'Lateralidad'),
(5733, 3364, 3, 'Lateralidad de este procedimiento si se aplica'),
(5734, 3365, 3, 'desplazados lateralmente PMI:'),
(5735, 3373, 3, 'de la base'),
(5736, 3374, 3, 'Redactor de Disposición'),
(5737, 3375, 3, 'Diseño de Grupos'),
(5738, 3376, 3, 'Estilo plantilla'),
(5739, 3378, 3, 'Diseño basado en la visita las formas'),
(5740, 3379, 3, 'Disposición'),
(5741, 3380, 3, 'libra'),
(5742, 3381, 3, 'libra'),
(5743, 3382, 3, 'Colesterol LDL'),
(5744, 3383, 3, 'dejar en blanco si sigue activo'),
(5745, 3384, 3, 'Dejar en blanco para mantener el nombre de fichero original'),
(5746, 3385, 3, 'Deje en blanco para no cambiar la contraseña'),
(5747, 3386, 3, 'Dejar mensaje Con'),
(5748, 3387, 3, 'Salir del Formulario'),
(5749, 3388, 3, 'Dejando la contraseña en blanco no se encriptará el documento'),
(5750, 3390, 3, 'Izquierda'),
(5751, 3391, 3, 'Oído izquierdo'),
(5752, 3392, 3, 'oreja izquierda'),
(5753, 3394, 3, 'Izquierda:'),
(5754, 3395, 3, 'Izquierda: '),
(5755, 3396, 3, 'Dolor de Pierna/Calambres'),
(5756, 3397, 3, 'Legal'),
(5757, 3399, 3, 'Tamaño papel Legal'),
(5758, 3400, 3, 'Leyenda:'),
(5759, 3401, 3, 'Longitud'),
(5760, 3402, 3, 'Longitud del modificador, 0 si no hay'),
(5761, 3403, 3, 'Menor que'),
(5762, 3404, 3, 'Menor que o Igual a'),
(5763, 3405, 3, 'Menos la información privada (escribir, addonly opcional)'),
(5764, 3406, 3, 'Carta'),
(5765, 3407, 3, 'Carta'),
(5766, 3408, 3, 'Tamaño papel Letter'),
(5767, 3409, 3, 'Papelería membretada que el médico firma'),
(5768, 3410, 3, 'Papelería membretada que el paciente firma'),
(5769, 3411, 3, 'Nivel de urgencia'),
(5770, 3412, 3, 'Responsabilidad'),
(5771, 3413, 3, 'Responsabilidad Médica'),
(5772, 3414, 3, 'Licencia/Nº Id.'),
(5773, 3419, 3, 'Apellido del médico'),
(5774, 3420, 3, 'NºColegiado médico'),
(5775, 3421, 3, 'NºColegiado médico'),
(5776, 3423, 3, 'Estilo de Vida'),
(5777, 3424, 3, 'Estadio del estilo de vida'),
(5778, 3425, 3, 'Rasgón o esguince del ligamento'),
(5779, 3428, 3, 'Límite de Eventos'),
(5780, 3429, 3, 'Límites'),
(5781, 3431, 3, 'Vínculo'),
(5782, 3432, 3, 'Vínculo al paciente'),
(5783, 3433, 3, 'Vinculado'),
(5784, 3436, 3, 'Vinculado a un documento'),
(5785, 3438, 3, 'Lista'),
(5786, 3439, 3, 'Cuadr de lista'),
(5787, 3440, 3, 'caja de lista'),
(5788, 3441, 3, 'agrega cuadro de lista'),
(5789, 3442, 3, 'Lista de cuadro con adición'),
(5790, 3443, 3, 'Editor de Lista'),
(5791, 3444, 3, 'Lista de visitas'),
(5792, 3445, 3, 'Lista de grupos'),
(5793, 3446, 3, 'Lista Sociedades Médicas'),
(5794, 3448, 3, 'Lista de temas no puede comenzar con un número'),
(5795, 3449, 3, 'Items listados contienen caracteres ilegales'),
(5796, 3451, 3, 'Lista Listas'),
(5797, 3452, 3, 'Lista de Nombres'),
(5798, 3453, 3, 'Lista de los nombres no puede empezar con números.'),
(5799, 3454, 3, 'Lista de Recetas'),
(5800, 3455, 3, 'Lista Tipo de datos usada para País.'),
(5801, 3456, 3, 'Lista Tipo de datos usada para Estado.'),
(5802, 3457, 3, 'Puerto de escucha de la RFC 5425 TLS en el servidor syslog.'),
(5803, 3458, 3, 'Listas'),
(5804, 3460, 3, 'Deseos Personales de cuidado'),
(5805, 3461, 3, 'LLL:'),
(5806, 3462, 3, 'LMP'),
(5807, 3464, 3, 'Cargar definiciones'),
(5808, 3470, 3, 'Cargando'),
(5809, 3471, 3, 'Cargando ficheros en la base de datos. Esto puede tardar algún tiempo...'),
(5810, 3472, 3, 'LOC'),
(5811, 3473, 3, 'Local'),
(5812, 3476, 3, 'Lugar'),
(5813, 3477, 3, 'Localidad'),
(5814, 3478, 3, 'Localización'),
(5815, 3479, 3, 'Ubicación de la máquina libreehr puede contener datos sensible, por eso se recomienda borrar manualmente los ficheros después de su uso'),
(5816, 3480, 3, 'Localizacion de este lote'),
(5817, 3481, 3, 'Lugar no especificado'),
(5818, 3482, 3, 'Directorio dónde Hylafax archiva los faxes'),
(5819, 3483, 3, 'Localización dónde se archivan los escaneados'),
(5820, 3484, 3, 'Localización:'),
(5821, 3485, 3, 'Bloquear'),
(5822, 3492, 3, 'Iniciar sesión'),
(5823, 3493, 3, 'Identificación'),
(5824, 3494, 3, 'Finalizar sesión'),
(5825, 3495, 3, 'Iniciar sesión'),
(5826, 3496, 3, 'Abierto una sesión como'),
(5827, 3497, 3, 'Abierto una sesión como: '),
(5828, 3498, 3, 'Salir de sesión.'),
(5829, 3499, 3, 'Identificando'),
(5830, 3500, 3, 'Iniciar sesión'),
(5831, 3501, 3, 'iniciar sesión'),
(5832, 3505, 3, 'Cerrar sesión'),
(5833, 3506, 3, 'cerrar sesión'),
(5834, 3507, 3, 'Registros'),
(5835, 3508, 3, 'Espectador de los registros'),
(5836, 3510, 3, 'Buscar'),
(5837, 3511, 3, 'Lote'),
(5838, 3512, 3, 'Nº Identificación del lote falta!'),
(5839, 3513, 3, 'Número de Lote'),
(5840, 3514, 3, 'Bajo'),
(5841, 3516, 3, 'inferior de la pierna'),
(5842, 3519, 3, 'Columna lumbar'),
(5843, 3520, 3, 'COMIDA'),
(5844, 3521, 3, 'Comida'),
(5845, 3522, 3, 'cáncer de pulmón'),
(5846, 3523, 3, 'Cirugía del cáncer de pulmón'),
(5847, 3524, 3, 'PULMONES:'),
(5848, 3525, 3, 'pulmones:'),
(5849, 3526, 3, 'Lupus'),
(5850, 3528, 3, 'M'),
(5851, 3529, 3, 'Categoría de MA'),
(5852, 3530, 3, 'MA Cliente acepta aborto'),
(5853, 3531, 3, 'MA estadísticas'),
(5854, 3533, 3, 'Correo enviado'),
(5855, 3534, 3, 'Principal'),
(5856, 3535, 3, 'Dirección principal'),
(5857, 3536, 3, 'Pantalla principal del panel superior'),
(5858, 3537, 3, 'Mantener activa la lista de medicación de alergia.'),
(5859, 3538, 3, 'Mantener activa una lista de medicación.'),
(5860, 3539, 3, 'Mantenga actualizada lista de problemas actuales y diagnósticos activos'),
(5861, 3540, 3, 'Hacer modificaciones a las actuales categorías.'),
(5862, 3541, 3, 'Dar nueva cita para'),
(5863, 3542, 3, 'Cerciorarse -'),
(5864, 3543, 3, 'Hacer un batch de ficheros de texto para adjuntar a la Cámara de compensación y que se marcará como facturado'),
(5865, 3545, 3, 'Malestar:'),
(5866, 3548, 3, 'Masculino'),
(5867, 3549, 3, 'Condones Masculinos'),
(5868, 3550, 3, 'Varón VSC'),
(5869, 3552, 3, 'Mamografía'),
(5870, 3553, 3, 'Manejar'),
(5871, 3556, 3, 'Gestionar traducciones'),
(5872, 3557, 3, 'Gerencia'),
(5873, 3558, 3, 'Campos obligatorios y específicos'),
(5874, 3559, 3, 'Campos obligatorios o específicos sólo, cheques duplicados, no de búsqueda'),
(5875, 3560, 3, 'Campos obligatorios o específicos sólo, búsqueda y comprobación de duplicados'),
(5876, 3561, 3, 'Manual'),
(5877, 3562, 3, 'Manual de envío'),
(5878, 3563, 3, 'Fabricante'),
(5879, 3565, 3, 'Mar'),
(5880, 3568, 3, 'Marzo'),
(5881, 3569, 3, 'Estado Civil'),
(5882, 3571, 3, 'Marcar como facturado pero saltar de facturación'),
(5883, 3572, 3, 'Marcar como Resueltos'),
(5884, 3573, 3, 'Marcar como no facturados'),
(5885, 3575, 3, 'Marcado como despejado'),
(5886, 3576, 3, 'Casado'),
(5887, 3578, 3, 'Formato (Máscara)'),
(5888, 3579, 3, 'Formato para Números de Factura'),
(5889, 3580, 3, 'Formato para ID de Pacientes'),
(5890, 3581, 3, 'Formato para ID de Productos'),
(5891, 3582, 3, 'Concuerda'),
(5892, 3591, 3, 'Max'),
(5893, 3594, 3, 'La derecha maxilar:'),
(5894, 3595, 3, 'Edad Máxima'),
(5895, 3596, 3, 'Número máximo de caracteres'),
(5896, 3597, 3, 'Tiempo máximo inactivo antes de cerrar sesión en segundos. Por defecto es 7200 (2 horas).'),
(5897, 3600, 3, 'Inventario máximo razonable, 0 si no es aplicable'),
(5898, 3601, 3, 'Tamaño máximo'),
(5899, 3602, 3, 'Tamaño máximo (poniendo 0 permite cualquier tamaño)'),
(5900, 3603, 3, 'Mayo'),
(5901, 3604, 3, 'MC'),
(5902, 3605, 3, 'mcg (microgramo)'),
(5903, 3607, 3, 'Significa que ninguna de las tres últimas contraseñas son permitidas para cambiar la contraseña.'),
(5904, 3609, 3, 'Medida del Código de Grupo'),
(5905, 3611, 3, 'Medición'),
(5906, 3612, 3, 'Maléolo tibial:'),
(5907, 3613, 3, 'Seguro de enfermedad'),
(5908, 3614, 3, 'Médico'),
(5909, 3615, 3, 'Aborto Médico'),
(5910, 3616, 3, 'Administración Médica'),
(5911, 3617, 3, 'Historia Médica'),
(5912, 3618, 3, 'Incidencia Médica'),
(5913, 3619, 3, 'Incidencia Médica'),
(5914, 3620, 3, 'Problema médico'),
(5915, 3623, 3, 'Problemas médicos'),
(5916, 3624, 3, 'Registo Médico'),
(5917, 3625, 3, 'Informe médico #'),
(5918, 3626, 3, 'Registros Médicos'),
(5919, 3627, 3, 'Registros Médicos enviados'),
(5920, 3629, 3, 'Resumen Médico entregado'),
(5921, 3630, 3, 'Sistema Médico'),
(5922, 3631, 3, 'Tipo de Médico'),
(5923, 3632, 3, 'Médico / Historia (escribir, añadir sólo opcional)'),
(5924, 3633, 3, 'Parte B de Seguro médico'),
(5925, 3634, 3, 'Seguro médico de referencia restablecido'),
(5926, 3635, 3, 'Medicación'),
(5927, 3636, 3, 'Lista Medicación Alergias'),
(5928, 3638, 3, 'Lista Medicación'),
(5929, 3639, 3, '¿Reconciliación Medicación realizada?'),
(5930, 3640, 3, 'Medicamentos'),
(5931, 3641, 3, 'Medicamentos:'),
(5932, 3642, 3, 'Unidades de Medicina'),
(5933, 3643, 3, 'Mediano'),
(5934, 3645, 3, 'Miembro de la Asociación de Estadística Informe'),
(5935, 3646, 3, 'Problemas de Memoria'),
(5936, 3647, 3, 'Hombres'),
(5937, 3648, 3, 'Hombres y Mujeres'),
(5938, 3649, 3, 'Hombres Solamente'),
(5939, 3650, 3, 'Menarquía'),
(5940, 3651, 3, 'Menopausia'),
(5941, 3652, 3, 'Flujo Menstrual'),
(5942, 3653, 3, 'Menstrual Frequency'),
(5943, 3654, 3, 'Enfermedad Mental'),
(5944, 3661, 3, 'Mensaje'),
(5945, 3662, 3, 'Mensajes y Centro de Avisos'),
(5946, 3665, 3, 'Mensaje Enviado'),
(5947, 3666, 3, 'Estado mensaje'),
(5948, 3670, 3, 'MENSAJE:'),
(5949, 3671, 3, 'Mensajes'),
(5950, 3672, 3, 'Mensajes enviados hoy'),
(5951, 3673, 3, 'Método'),
(5952, 3674, 3, 'Método y especificaciones de Producto'),
(5953, 3675, 3, 'Método para el envío de email saliente'),
(5954, 3676, 3, 'Método de destrucción'),
(5955, 3677, 3, 'Mejicano/MexAmer/Chicano'),
(5956, 3679, 3, 'mg'),
(5957, 3680, 3, 'mg/1cc'),
(5958, 3681, 3, 'mg/2cc'),
(5959, 3682, 3, 'mg/3cc'),
(5960, 3683, 3, 'mg/4cc'),
(5961, 3684, 3, 'mg/5cc'),
(5962, 3685, 3, 'MG/DL'),
(5963, 3686, 3, 'Segundo'),
(5964, 3687, 3, 'Segundo Nombre'),
(5965, 3688, 3, 'Segundo nombre'),
(5966, 3690, 3, 'Prescriptor DEA nivel medio'),
(5967, 3691, 3, 'Nombre Prescriptor nivel medio'),
(5968, 3692, 3, 'Apellido Prescriptor nivel medio'),
(5969, 3693, 3, 'Prefijo Prescriptor nivel medio'),
(5970, 3694, 3, 'Nº médico nivel medio'),
(5971, 3695, 3, 'Semblante'),
(5972, 3696, 3, 'Migrante o trabajador de temporada?'),
(5973, 3697, 3, 'Migrantes / temporada'),
(5974, 3698, 3, 'Mil/CU.MM'),
(5975, 3702, 3, 'Mime Tipo'),
(5976, 3703, 3, 'min'),
(5977, 3704, 3, 'Mínimo'),
(5978, 3705, 3, 'Edad Mínima'),
(5979, 3706, 3, 'Menor tensión conjunta /-Sinovitis'),
(5980, 3708, 3, 'Minuto'),
(5981, 3709, 3, 'minutos'),
(5982, 3710, 3, 'Minutos'),
(5983, 3712, 3, 'Varios'),
(5984, 3713, 3, 'Diversas opciones de facturación'),
(5985, 3714, 3, 'Diversas opciones de facturación para HCFA-1500'),
(5986, 3715, 3, 'Diversas opciones de facturación HCFA'),
(5987, 3716, 3, 'Varios'),
(5988, 3717, 3, 'Faltado'),
(5989, 3718, 3, 'No existe'),
(5990, 3719, 3, 'Falta campo requerido'),
(5991, 3720, 3, 'Falta cuota'),
(5992, 3721, 3, 'Solo modulos faltantes'),
(5993, 3722, 3, 'No existe o Inválido'),
(5994, 3723, 3, 'Falta el PID.'),
(5995, 3724, 3, 'Fecha de reporte falta'),
(5996, 3725, 3, 'Raya vertical que falta después del pagador en la fuente para el código '),
(5997, 3726, 3, 'Mixto'),
(5998, 3727, 3, 'ml'),
(5999, 3728, 3, 'MM/DD/AAAA'),
(6000, 3729, 3, 'mm/hg'),
(6001, 3730, 3, 'mmHg'),
(6002, 3731, 3, 'MMR 1'),
(6003, 3732, 3, 'MMR 2'),
(6004, 3733, 3, 'Móvil'),
(6005, 3734, 3, 'Teléfono Móvil'),
(6006, 3735, 3, 'Mod'),
(6007, 3741, 3, 'Modificador'),
(6008, 3742, 3, 'Modificadores'),
(6009, 3743, 3, 'Modificar'),
(6010, 3745, 3, 'Modificar Pagos'),
(6011, 3746, 3, 'Longitud Modelo'),
(6012, 3753, 3, 'Lun'),
(6013, 3754, 3, 'Lun a Vier'),
(6014, 3755, 3, 'Lunes, miércoles y viernes'),
(6015, 3756, 3, 'Lunes'),
(6016, 3758, 3, 'Mes'),
(6017, 3759, 3, 'mes'),
(6018, 3760, 3, 'Ver Mes'),
(6019, 3761, 3, 'Mes(es)'),
(6020, 3762, 3, 'Ingreso Mensual'),
(6021, 3763, 3, 'Meses'),
(6022, 3765, 3, 'Más de 100 registros encontrados. Por favor, reducir su criterio de búsqueda.'),
(6023, 3766, 3, 'Más de 50 resultados, por favor, hacer su búsqueda más específica.'),
(6024, 3767, 3, 'Puede hacer click en la mayoría de las cabeceras de columna para cambiar el orden'),
(6025, 3768, 3, 'Más reciente desde'),
(6026, 3770, 3, 'Constantes vitales mas recientes desde:'),
(6027, 3771, 3, 'Madre'),
(6028, 3772, 3, 'Nombre de la Madre'),
(6029, 3774, 3, 'Boca'),
(6030, 3775, 3, 'Movimiento'),
(6031, 3776, 3, 'Mueva el documento a la categoría:'),
(6032, 3777, 3, 'Mueve Abajo'),
(6033, 3779, 3, 'Mover al paciente'),
(6034, 3780, 3, 'Mover hacia...'),
(6035, 3781, 3, 'Mover Arriba'),
(6036, 3783, 3, 'Sr.'),
(6037, 3785, 3, 'Sra.'),
(6038, 3786, 3, 'Srta.'),
(6039, 3794, 3, 'Código MSP'),
(6040, 3796, 3, 'Herramienta multi idioma'),
(6041, 3797, 3, 'Múltiples áreas'),
(6042, 3799, 3, 'Lotes Multiples'),
(6043, 3800, 3, 'Múltiples modificadores pueden estar separados por dos puntos o espacios, máximo 4 (M1:M2:M3:M4)'),
(6044, 3802, 3, 'Multirracial'),
(6045, 3803, 3, 'Murmullos:'),
(6046, 3804, 3, 'Dolor de Musc'),
(6047, 3805, 3, 'Dolor muscular'),
(6048, 3806, 3, 'Rojez de Musc'),
(6049, 3807, 3, 'Tiesura de Musc'),
(6050, 3808, 3, 'Inflamación muscular'),
(6051, 3809, 3, 'Musc Caliente'),
(6052, 3810, 3, 'Músculo'),
(6053, 3811, 3, 'Lesiones musculares'),
(6054, 3812, 3, 'Musculoesquelético'),
(6055, 3813, 3, 'Debe estar vacío si la autenticación de SMTP no se usa.'),
(6056, 3814, 3, 'Definido mutuamente'),
(6057, 3815, 3, 'MVA'),
(6058, 3818, 3, 'Yo mismo'),
(6059, 3821, 3, 'No Aplicable'),
(6060, 3822, 3, 'no aplicable'),
(6061, 3823, 3, 'Nombre'),
(6062, 3825, 3, 'Nombre (Selecciona por mas)'),
(6063, 3826, 3, 'Nombre 1'),
(6064, 3827, 3, 'Nombre 2'),
(6065, 3828, 3, 'Nombre y título del administrador de la Vacunación'),
(6066, 3831, 3, 'Nombre de Eventos'),
(6067, 3832, 3, 'Nombre de la Sociedad Médica'),
(6068, 3833, 3, 'Nombre del Facultativo'),
(6069, 3834, 3, 'Nombre del remitente para los recordatorios de paciente.'),
(6070, 3835, 3, 'Nombre de Traducción'),
(6071, 3836, 3, 'Nombre/Valor'),
(6072, 3837, 3, 'Nombre:'),
(6073, 3838, 3, 'NARES:'),
(6074, 3839, 3, 'NARES: Normal Derecho'),
(6075, 3840, 3, 'Mucosa nasal de color rosa, septo de línea media'),
(6076, 3841, 3, 'País Notas'),
(6077, 3842, 3, 'Configurar País Notas'),
(6078, 3844, 3, 'Nacionalidad'),
(6079, 3845, 3, 'PaísNotas'),
(6080, 3847, 3, 'Hawaino nativo u otras Islas del Pacífico'),
(6081, 3852, 3, 'Náuseas');
INSERT INTO `lang_definitions` VALUES
(6082, 3854, 3, 'Navegación'),
(6083, 3855, 3, 'Área de navegación incluye formularios de visita'),
(6084, 3856, 3, 'El área de navegación usa la altura completa del marco'),
(6085, 3857, 3, 'Formulario Área Navegación de visita'),
(6086, 3858, 3, 'Ancho del área de navegación'),
(6087, 3859, 3, 'El menú de navegación consiste en pares de botones radiales'),
(6088, 3860, 3, 'El menú de navegación es una vista de árbol'),
(6089, 3861, 3, 'La navegación usa un menú deslizante'),
(6090, 3862, 3, 'NDC'),
(6091, 3863, 3, 'Datos NCD'),
(6092, 3864, 3, 'Número del NDC'),
(6093, 3866, 3, 'Cuello'),
(6094, 3867, 3, 'Problemas de Cuello'),
(6095, 3868, 3, 'Cuello flexible'),
(6096, 3869, 3, 'Necesidad de introducir una descripción'),
(6097, 3870, 3, 'Necesidad de introducir un Valor de Retorno'),
(6098, 3871, 3, 'Necesidad de entrar en el identificador'),
(6099, 3872, 3, 'Necesita introducir título'),
(6100, 3873, 3, 'Requiere autorización'),
(6101, 3874, 3, 'Requiere justificación'),
(6102, 3875, 3, 'Necesita la facturación secundaria'),
(6103, 3876, 3, 'Negativo'),
(6104, 3877, 3, 'Negativos'),
(6105, 3880, 3, 'Lesión del nervio'),
(6106, 3881, 3, 'Condición neural / daño en los nervios'),
(6107, 3882, 3, 'Entumecimiento Neuro'),
(6108, 3883, 3, 'Debilidad Neura'),
(6109, 3884, 3, 'Neurológico'),
(6110, 3885, 3, 'Nunca'),
(6111, 3886, 3, 'No Bebe Alcohol'),
(6112, 3887, 3, 'No Fumador'),
(6113, 3888, 3, 'Nuevo'),
(6114, 3889, 3, 'Nuevo =>'),
(6115, 3890, 3, 'Nuevos aceptadores'),
(6116, 3892, 3, 'Nueva alergia'),
(6117, 3894, 3, 'Cita Nueva'),
(6118, 3895, 3, 'Categoria Nueva'),
(6119, 3896, 3, 'Nueva Categoría'),
(6120, 3897, 3, 'Cliente Nuevo'),
(6121, 3898, 3, 'Nueva consulta'),
(6122, 3899, 3, 'Nuevo cultivo'),
(6123, 3900, 3, 'Nueva definición añadido'),
(6124, 3901, 3, 'Nuevo documento'),
(6125, 3904, 3, 'Nueva visita'),
(6126, 3905, 3, 'Nueva visita creada con id'),
(6127, 3906, 3, 'Formulario Nuevo Encuentro'),
(6128, 3907, 3, 'Nuevas visitas no autorizadas'),
(6129, 3908, 3, 'Nuevos Enctr'),
(6130, 3909, 3, 'Nueva información del Centro'),
(6131, 3912, 3, 'Grupo Nuevo'),
(6132, 3913, 3, 'Nuevo Grupo de Información'),
(6133, 3914, 3, 'Nueva lesión/estado'),
(6134, 3916, 3, 'Nuevo límite de Eventos'),
(6135, 3917, 3, 'Nueva Lista'),
(6136, 3918, 3, 'Nuevos pedidos'),
(6137, 3919, 3, 'Nuevo Párrafo'),
(6138, 3920, 3, 'Nueva Contraseña'),
(6139, 3921, 3, 'Nuevo Paciente'),
(6140, 3922, 3, 'NUEVO PACIENTE'),
(6141, 3923, 3, 'Nueva Visita de Paciente'),
(6142, 3924, 3, 'Formulario de Nuevo Paciente'),
(6143, 3925, 3, 'Nº Identificación de Nuevo Paciente'),
(6144, 3926, 3, 'Nuevo Pago'),
(6145, 3928, 3, 'Nuevos Pt'),
(6146, 3929, 3, 'Nuevos resultados del laboratorio de intercambio'),
(6147, 3930, 3, 'Nueva Busqueda'),
(6148, 3931, 3, 'Nuevas sumisiones'),
(6149, 3932, 3, 'Nuevo Usuario'),
(6150, 3934, 3, 'Nueva visita'),
(6151, 3935, 3, 'Nuevo/búsqueda'),
(6152, 3936, 3, 'Estado de la cuenta NewCrop'),
(6153, 3937, 3, '*Administrador de NewCrop'),
(6154, 3938, 3, 'Llamada fallida a NewCrop'),
(6155, 3939, 3, 'Doctor NewCrop'),
(6156, 3944, 3, 'Nombre Receta electrónica NewCrop'),
(6157, 3945, 3, 'Nombre socio Receta electrónica NewCrop'),
(6158, 3946, 3, 'Contraseña Receta electrónica NewCrop'),
(6159, 3947, 3, 'Rol Receta electrónica NewCrop'),
(6160, 3948, 3, 'Rol Receta electrónica NewCrop'),
(6161, 3949, 3, 'Sitio Web Receta electrónica NewCrop'),
(6162, 3954, 3, 'Sitio Web servicio Receta electrónica NewCrop'),
(6163, 3955, 3, 'Gerente NewCrop'),
(6164, 3956, 3, 'NewCrop MedEntry'),
(6165, 3957, 3, 'Médico nivel medio NewCrop'),
(6166, 3958, 3, 'Enfermera NewCrop'),
(6167, 3959, 3, 'Supervisor médico NewCrop'),
(6168, 3961, 3, 'Periódico'),
(6169, 3962, 3, 'Próximo'),
(6170, 3964, 3, 'Próximo Dia'),
(6171, 3965, 3, 'Próximo mes'),
(6172, 3966, 3, 'Proxima semana'),
(6173, 3968, 3, 'Próxima semana'),
(6174, 3969, 3, 'Año siguiente (Presione para el menu'),
(6175, 3971, 3, 'Apodo'),
(6176, 3973, 3, 'Sudores nocturnos'),
(6177, 3974, 3, 'Órganos genitales de la extensión de NL, mucosa de vag, cuello uterino'),
(6178, 3975, 3, 'NO'),
(6179, 3976, 3, 'No'),
(6180, 3977, 3, 'No tienen acceso'),
(6181, 3978, 3, 'Recordatorios de paciente no activos.'),
(6182, 3979, 3, 'No adenopatías (2 áreas requeridas)'),
(6183, 3980, 3, 'Ninguna razón de tipo de ajuste encontrada para'),
(6184, 3981, 3, 'No dolor/masa en anexos'),
(6185, 3983, 3, 'No hay citas'),
(6186, 3985, 3, 'Sistema de facturación no se encuentra activa'),
(6187, 3986, 3, 'No hay facturas encontradas para incluir en Exportación OFX'),
(6188, 3987, 3, 'No se encontraron cuentas para incluir en la exportación de OFX'),
(6189, 3989, 3, 'No se ha especificado el código!'),
(6190, 3992, 3, 'Sin Diagnóstico'),
(6191, 3993, 3, 'No documentos encontrados'),
(6192, 3994, 3, 'No pueden crearse visitas'),
(6193, 3995, 3, 'Sin fecha de finalización'),
(6194, 3996, 3, 'No se encuentran entradas, utilice el formulario que aparece a continuación para agregar una entrada.'),
(6195, 3997, 3, 'errores no encontrados'),
(6196, 3998, 3, 'No hay Eventos'),
(6197, 4000, 3, 'No hay ficheros preparados para la instalación'),
(6198, 4001, 3, 'Ningún grupo fue seleccionado'),
(6199, 4002, 3, 'Ninguna hernia'),
(6200, 4005, 3, 'No lesion/enfermedad'),
(6201, 4006, 3, 'No se encontro ninguna Sociedad Médica'),
(6202, 4007, 3, 'No hay incidencias'),
(6203, 4009, 3, 'No hay artículos bajo la categoría seleccionada'),
(6204, 4010, 3, '¡Ningun artículo fue seleccionado!'),
(6205, 4025, 3, 'No hay fichero de registro para la fecha seleccionada'),
(6206, 4027, 3, 'Sin masas ni sensibilidad'),
(6207, 4028, 3, 'Ningún registro de paciente encontrado para la Re-identificación dada'),
(6208, 4029, 3, 'No hay coincidencias. Intentar buscar de nuevo.'),
(6209, 4030, 3, 'No se han encontrado coincidencias.'),
(6210, 4031, 3, 'No se encontró. ¿Crear el nuevo paciente ahora?'),
(6211, 4032, 3, 'No hay registros coincidentes'),
(6212, 4033, 3, 'No hay nuevos resultados encontrados'),
(6213, 4034, 3, 'Ningunas notas'),
(6214, 4035, 3, 'No hay organomegalia'),
(6215, 4036, 3, 'No se encontraron huecos para este periodo.'),
(6216, 4037, 3, 'No figuran otros números de teléfono'),
(6217, 4039, 3, 'Socios no encontrados'),
(6218, 4040, 3, 'No hay registros de paciente encontrados para el criterio de selección dado'),
(6219, 4041, 3, 'No hay registros de paciente encontrados para el código de Re-identificación dado'),
(6220, 4042, 3, 'Ningún edema periférico'),
(6221, 4043, 3, 'Ninguna Farmacia Encontrada'),
(6222, 4044, 3, 'Ninguna Prescripción Encontrada'),
(6223, 4045, 3, 'Ninguna enfermedad/lesión actuales'),
(6224, 4046, 3, 'Sin entradas anteriores'),
(6225, 4047, 3, 'Ninguna Empresa Primaria seleccionada en la lista del Centro'),
(6226, 4051, 3, 'Ningun Facultativo Encontrado'),
(6227, 4052, 3, 'Ninguna erupción o lesiones anormales'),
(6228, 4053, 3, 'Registros no encontrados'),
(6229, 4055, 3, 'Registros no encontrados. Por favor amplíe sus criterios de búsqueda.'),
(6230, 4056, 3, 'No hay recordatorios'),
(6231, 4057, 3, 'Resultados no encontrados, para los criterios de búsqueda.'),
(6232, 4058, 3, 'Sin resultados'),
(6233, 4060, 3, 'Búsqueda sin resultado'),
(6234, 4061, 3, 'Ningun resultado, por favor intente de nuevo'),
(6235, 4062, 3, 'Sin resultados, por favor intente de nuevo'),
(6236, 4063, 3, 'Sin resultado, por favor intente de nuevo.'),
(6237, 4065, 3, 'Ausente'),
(6238, 4067, 3, 'Ninguna sensibilidad del Seno:'),
(6239, 4068, 3, 'Sin hoyuelos en la piel o nódulos en la mama'),
(6240, 4069, 3, 'NINGÚN NOMBRE DE CONTEXTO'),
(6241, 4071, 3, 'No hay sensibilidad testicular, masas'),
(6242, 4072, 3, 'Ningunas emociones o tirones'),
(6243, 4075, 3, 'No hay visita'),
(6244, 4076, 3, 'Constantes vitales no han sido documentadas.'),
(6245, 4077, 3, 'No, Cancelar'),
(6246, 4078, 3, 'Ningún seguro de defecto incluyendo Auto es principal'),
(6247, 4079, 3, 'No:'),
(6248, 4080, 3, 'Nocturia'),
(6249, 4081, 3, 'No Pagado'),
(6250, 4082, 3, 'Informe No Reportado'),
(6251, 4083, 3, 'Lesión no específica'),
(6252, 4084, 3, 'No-electrónico'),
(6253, 4085, 3, 'Non-insulin dependent diabetes'),
(6254, 4086, 3, 'No asegurado'),
(6255, 4087, 3, 'No-SRH Médico'),
(6256, 4088, 3, 'No-SRH No-Médico'),
(6257, 4089, 3, 'Ninguno'),
(6258, 4090, 3, 'ninguno'),
(6259, 4091, 3, 'No definido'),
(6260, 4092, 3, 'No ha sido documentado'),
(6261, 4093, 3, 'Ninguna de las anteriores'),
(6262, 4094, 3, 'Ninguna de las Filas de Distribución Superior puede estar Completamente en Blanco.'),
(6263, 4095, 3, 'Diabetes no insulino dependiente'),
(6264, 4096, 3, 'No'),
(6265, 4097, 3, 'Normal'),
(6266, 4098, 3, 'Normal BL'),
(6267, 4099, 3, 'Examen Cardiaco Normal:'),
(6268, 4100, 3, 'Examen Cardiaco Normal: '),
(6269, 4101, 3, 'Examen Normal del Pulmón:'),
(6270, 4102, 3, 'Examen Normal del Pulmón: '),
(6271, 4103, 3, 'Visita normal en el Centro'),
(6272, 4104, 3, 'Orofaringe normal:'),
(6273, 4105, 3, 'Derecho Normal'),
(6274, 4106, 3, 'Derecho Normal:'),
(6275, 4107, 3, 'Ver Normal'),
(6276, 4108, 3, 'normal:'),
(6277, 4109, 3, 'Normalmente esto debe ser comprobado. No relacionado con el control de acceso.'),
(6278, 4112, 3, 'Noruego'),
(6279, 4115, 3, 'Nariz'),
(6280, 4116, 3, 'Sangrado por la nariz'),
(6281, 4117, 3, 'No es letra ni úmero'),
(6282, 4119, 3, 'No todos los campos son obligatorios para todos los códigos o tipos de códigos.'),
(6283, 4120, 3, 'No permitido'),
(6284, 4121, 3, 'No pueden eliminar el grupo Administradores'),
(6285, 4122, 3, 'No permitido Editar'),
(6286, 4123, 3, 'No pueden inactivar todos los objetos de seguridad'),
(6287, 4124, 3, 'No permitido hacer inactivo cualquier cosa de los administradores ACL'),
(6288, 4125, 3, 'No pueden eliminar el usuario administrador del grupo Administradores'),
(6289, 4126, 3, 'No permitido eliminar este usuario del grupo de Administradores'),
(6290, 4128, 3, 'No autorizado para tener acceso al módulo de PostCalendar'),
(6291, 4129, 3, 'No autorizado'),
(6292, 4130, 3, 'No Autorizado'),
(6293, 4131, 3, '¡No autorizado para este equipo!'),
(6294, 4132, 3, 'No autorizados para este equipo.'),
(6295, 4135, 3, 'No disponible'),
(6296, 4137, 3, 'No facturado'),
(6297, 4138, 3, 'No Chequeado'),
(6298, 4139, 3, 'No registró salida'),
(6299, 4140, 3, 'No codificado'),
(6300, 4141, 3, 'No Vencido'),
(6301, 4143, 3, 'No examinado'),
(6302, 4144, 3, 'No Examinado:'),
(6303, 4145, 3, 'No Examinado: '),
(6304, 4146, 3, 'No encontrado'),
(6305, 4148, 3, 'No encontrado!'),
(6306, 4149, 3, 'No Hispano o Latino'),
(6307, 4150, 3, 'No instalado'),
(6308, 4152, 3, 'No visto desde'),
(6309, 4154, 3, 'No enviado todavía'),
(6310, 4156, 3, 'Sin Especificar'),
(6311, 4157, 3, 'Nota'),
(6312, 4158, 3, 'Código Notas'),
(6313, 4159, 3, 'Tenga en cuenta que el proceso completo después de hacer click en instalar puede tardar 5-10 minutos'),
(6314, 4160, 3, 'Tenga en cuenta que el proceso completo después de hacer click en actualizar puede tardar 5-10 minutos'),
(6315, 4161, 3, 'Tenga en cuenta que la Auditoría de inicio sesión necesita estar activada arriba'),
(6316, 4162, 3, 'Tipo de Nota'),
(6317, 4163, 3, 'Nota: 12:00 mediodía es PM, no AM'),
(6318, 4164, 3, 'NOTA: Importar datos externos puede tomar más de una hora dependiendo de su configuración hardware. Por ejemplo, una de las tablas de datos RxNorm contiene más de 6 millones de líneas.'),
(6319, 4165, 3, 'NOTA: Solo la versión Bianual Snomed Internacional es actualmente soportada'),
(6320, 4166, 3, 'NOTA: Solo la versión completa mensual de RxNorm es actualmente soportada'),
(6321, 4168, 3, 'Nota: este código no fue ingresado por un usuario autorizado. Sólo los códigos autorizados pueden ser subidos a la Red Abierta de facturación médica para su procesamiento. Si desea cargar estos códigos, por favor, seleccione un usuario autorizado aquí.'),
(6322, 4170, 3, 'Nota: este código no fue por un usuario autorizado. Sólo están autorizados los códigos pueden ser subidos a la Red Abierta de facturación médica para su procesamiento. Si desea cargar estos códigos, por favor, seleccione un usuario autorizado aquí.'),
(6323, 4171, 3, 'NOTA: Adjuntar ficheros con nombres duplicados hará que los ficheros sean automáticamente renombrados. Por ejemplo '' fichero.jpg'' se convertirá '' fichero.jpg.1''. Los nombres de fichero se consideran únicos por paciente, no por categoría.'),
(6324, 4172, 3, 'Notas'),
(6325, 4173, 3, 'Notas - cualquier visita(escribir, sólo añadir opcional)'),
(6326, 4174, 3, 'Notas - mis visitas(escribir, sólo añadir opcional)'),
(6327, 4175, 3, 'Notas no autorizados'),
(6328, 4177, 3, 'Nada Grabado'),
(6329, 4179, 3, 'Nada que importar para alergia'),
(6330, 4180, 3, 'Nada que importar para receta'),
(6331, 4181, 3, 'Nada que mostrar'),
(6332, 4182, 3, 'Nada fue seleccionado'),
(6333, 4184, 3, 'AVISO:: Sumisión/modificación de PostCalendar'),
(6334, 4185, 3, 'Notificación'),
(6335, 4186, 3, 'Email para Notificación'),
(6336, 4188, 3, 'Notificaciones'),
(6337, 4189, 3, 'Notificar Administrador Acerca del Evento de envío/Modificación?'),
(6338, 4190, 3, 'Nov'),
(6339, 4191, 3, 'Noviembre'),
(6340, 4192, 3, 'Ahora envío para:'),
(6341, 4193, 3, 'Imprimiendo ahora'),
(6342, 4194, 3, 'Ahora impresión $stmt_count declaraciones y actualización de visitas.'),
(6343, 4195, 3, 'Ahora declaraciones de la impresión $stmt_count y facturas de la puesta al día.'),
(6344, 4196, 3, 'Ahora impresión $stmt_count declaraciones;visitas no serán actualizadas.'),
(6345, 4197, 3, 'Ahora declaraciones de la impresión $stmt_count; las facturas no serán actualizadas.'),
(6346, 4198, 3, 'NPI'),
(6347, 4199, 3, 'National Quality Forum'),
(6348, 4200, 3, 'Número'),
(6349, 4201, 3, 'Número laboratorio'),
(6350, 4204, 3, 'Número de columnas en vista/año.'),
(6351, 4211, 3, 'Número de días de validez para el certificado de cliente.'),
(6352, 4213, 3, 'Número de dígitos después del punto decimal, normalmente 0 o 2.'),
(6353, 4214, 3, 'Número de visitas por página'),
(6354, 4215, 3, 'Número de partidas o eventos perdidos, si hay'),
(6355, 4216, 3, 'Número de horas de antelación para enviar notificaciones por email.'),
(6356, 4217, 3, 'Número de horas de antelación para enviar notificaciones por teléfono.'),
(6357, 4218, 3, 'Número de horas de antelación para enviar notificaciones por SMS.'),
(6358, 4221, 3, 'Número de columnas para historia pasada'),
(6359, 4222, 3, 'Número de pacientes que mostrar por página en la lista de pacientes.'),
(6360, 4223, 3, 'Entumecimiento'),
(6361, 4224, 3, 'Numerador'),
(6362, 4225, 3, 'Orden Númerico mostrado'),
(6363, 4227, 3, 'Nutrición'),
(6364, 4229, 3, 'O.A.F.V.'),
(6365, 4230, 3, 'O2 sat'),
(6366, 4231, 3, 'Obesidad I'),
(6367, 4232, 3, 'Obesidad II'),
(6368, 4233, 3, 'Obesidad III'),
(6369, 4234, 3, 'Objetivo'),
(6370, 4237, 3, 'Ocupación'),
(6371, 4239, 3, 'Episodio'),
(6372, 4240, 3, 'Oct'),
(6373, 4241, 3, 'Octubre'),
(6374, 4242, 3, 'OD'),
(6375, 4243, 3, 'de'),
(6376, 4244, 3, 'de la cantidad'),
(6377, 4245, 3, 'de tabletas'),
(6378, 4246, 3, 'de cada mes'),
(6379, 4247, 3, 'Notas de la oficina'),
(6380, 4248, 3, 'Apagado'),
(6381, 4249, 3, 'Notas de la Oficina'),
(6382, 4250, 3, 'Visita en el Centro'),
(6383, 4251, 3, 'Medidas oficiales de calidad clínica (GCC) Grupos de medida'),
(6384, 4252, 3, 'Vínculo https para el Portal Externo del paciente.'),
(6385, 4253, 3, 'Vínculo Https para el Portal del Paciente Externo (Vínculo Paciente)'),
(6386, 4254, 3, 'Contraseña Portal del Paciente Externo'),
(6387, 4255, 3, 'Contraseña Portal del paciente externo (Dejar en blanco si no está registrado)'),
(6388, 4258, 3, 'Sitio Web del Portal del Paciente Externo'),
(6389, 4259, 3, 'Sitio web del Portal del Paciente Externo (Vínculo Paciente)'),
(6390, 4260, 3, 'Usuario del Portal del Paciente Externo'),
(6391, 4261, 3, 'Usuario del Portal del Paciente Externo (Dejar en blanco si no está registrado).'),
(6392, 4263, 3, 'Descendencia'),
(6393, 4265, 3, 'Ungüento'),
(6394, 4267, 3, 'Esta Bien'),
(6395, 4269, 3, 'OK para enlazar la incidencia GCAC fechada'),
(6396, 4270, 3, 'Viejo'),
(6397, 4272, 3, 'Clientes antiguos'),
(6398, 4273, 3, 'Fractura antigua no/malunión'),
(6399, 4274, 3, 'Diseño Estilo antiguo sin menú a la izquierda'),
(6400, 4275, 3, 'Formulario viejo-estilo sin buscar o comprobar duplicados'),
(6401, 4279, 3, 'Omitir información empleador en demográficos del paciente'),
(6402, 4280, 3, 'Omitir Empleador'),
(6403, 4281, 3, 'Forma omitida, vía e intervalo que serán parte de la dosis'),
(6404, 4282, 3, 'Omitir seguro y otras cosas en el formulario de demograficos'),
(6405, 4283, 3, '¿Omitir usuarios internos?'),
(6406, 4284, 3, 'Omitir método de pago para el panel de co-pago'),
(6407, 4285, 3, 'Omitir para firma automatico'),
(6408, 4286, 3, 'en'),
(6409, 4287, 3, 'En'),
(6410, 4288, 3, 'En mano'),
(6411, 4289, 3, 'En Orden'),
(6412, 4290, 3, 'En el sitio'),
(6413, 4291, 3, 'Una vez asignado el Centro para el negocio principal, no deberá ser cambiado. El cambio del Centro afectará al trabajo en NewCrop ePrescription.'),
(6414, 4292, 3, 'Una vez que cambie su contraseña, tendrá que volver a iniciar sesión.'),
(6415, 4297, 3, 'Soporte en línea'),
(6416, 4298, 3, 'Vínculo de soporte online'),
(6417, 4299, 3, 'Sólo activa'),
(6418, 4302, 3, 'sólo si es ubicación de facturación'),
(6419, 4303, 3, 'Sólo inactivo'),
(6420, 4304, 3, 'Sólo mio'),
(6421, 4305, 3, 'Sólo mostrar los Informes de códigos de diagnóstico'),
(6422, 4306, 3, 'Sólo mostrar Código de Servicio de Informes de Códigos de Finanzas'),
(6423, 4307, 3, 'Sólo subir las prescripciones activas'),
(6424, 4310, 3, 'Inicio Enfermedad:'),
(6425, 4311, 3, 'Inicio Enfermedad: '),
(6426, 4312, 3, 'Inicio de Hinchazón:'),
(6427, 4313, 3, 'Fecha de Inicio/hospital.:'),
(6428, 4314, 3, 'Sitio Web del Portal del Paciente Interno'),
(6429, 4315, 3, '¡Uy!'),
(6430, 4316, 3, 'Abrir'),
(6431, 4318, 3, 'Abrir en ventana nueva'),
(6432, 4321, 3, 'Abrir visitas para hoy'),
(6433, 4322, 3, 'LibreEHR ya tiene un Certificado de Autoridad Configurado'),
(6434, 4324, 3, 'Actualización base de datos LibreEHR'),
(6435, 4325, 3, 'Actualización base de datos LibreEHR para De-identificación'),
(6436, 4326, 3, 'LibreEHR no reconoce el archivo de entrada en el directorio contrib. Esto es probablemente porque necesita configurar la versión en la tabla supported_external_dataloads en la base de datos MySQL.'),
(6437, 4327, 3, 'LibreEHR debe configurarse para usar certificado antes de poder crear cliente'),
(6438, 4328, 3, 'LibreEHR requiere Javascript para realizar la autenticación de usuario.'),
(6439, 4329, 3, 'LibreEHR Usuarios'),
(6440, 4330, 3, 'Vacantes'),
(6441, 4332, 3, 'Oftálmico'),
(6442, 4333, 3, 'Opcion'),
(6443, 4334, 3, 'Opción para guardar el método de almacenamiento de documentos.'),
(6444, 4335, 3, 'Opción para soporte de inventario y ventas de productos'),
(6445, 4336, 3, 'Opcional'),
(6446, 4337, 3, 'Nombre de la categoría opcional para una imagen de la tarjeta de identificación que se puede ver desde la página de resumen del paciente.'),
(6447, 4338, 3, 'Nombre de la categoría opcional para una imagen de foto que se puede ver desde la página de resumen del paciente.'),
(6448, 4339, 3, 'Nombre de la categoría opcional de un documento para vincular desde la página de resumen del paciente. Haga click en el nombre del paciente para ver su tarjeta de identificación.'),
(6449, 4340, 3, 'Rango por defecto opcional para la entrada manual de los resultados'),
(6450, 4341, 3, 'Unidades opcionales por defecto para la entrada manual de los resultados'),
(6451, 4342, 3, 'Nombre de destino opcional'),
(6452, 4343, 3, 'Nombre opcional de medicamento, use % como comodín'),
(6453, 4345, 3, 'Información opcional sobre este evento'),
(6454, 4346, 3, 'Opcional número de lote, usar % como un comodin'),
(6455, 4347, 3, 'Nº Identificación Numérico opcional del paciente'),
(6456, 4348, 3, 'Código opcional del procedimiento'),
(6457, 4349, 3, 'Código procedimiento/servicio opcional'),
(6458, 4350, 3, 'Opciones'),
(6459, 4351, 3, 'ó'),
(6460, 4352, 3, 'O'),
(6461, 4353, 3, 'o elija'),
(6462, 4354, 3, 'o Selecciona y arrastrar para selección mas rapida'),
(6463, 4356, 3, 'O hacia fuera a'),
(6464, 4358, 3, 'o Shif-Selecciona para reducirlo'),
(6465, 4359, 3, 'O adjuntar fichero ERA:'),
(6466, 4360, 3, 'Oral'),
(6467, 4361, 3, 'Mucosa oral rosada, garganta clara'),
(6468, 4362, 3, 'Orden'),
(6469, 4363, 3, 'Orden y tipo de resultados'),
(6470, 4364, 3, 'Catálogo de órdenes'),
(6471, 4365, 3, 'Fecha pedido'),
(6472, 4367, 3, 'Formulario de pedido'),
(6473, 4369, 3, 'Orden debe ser un número entre 1 y 999'),
(6474, 4370, 3, 'Nombre pedido'),
(6475, 4371, 3, 'Solicitud Prioridades'),
(6476, 4372, 3, 'Orden de Procesamiento'),
(6477, 4375, 3, 'estatus de la orden'),
(6478, 4378, 3, 'tipo de orden'),
(6479, 4380, 3, 'Tipo de orden/resultado'),
(6480, 4381, 3, 'Ordenado'),
(6481, 4384, 3, 'Profesional que ordeno'),
(6482, 4386, 3, 'Lesión de órganos'),
(6483, 4387, 3, 'Organización'),
(6484, 4388, 3, 'Nombre de organización'),
(6485, 4389, 3, 'Nombre de la unidad organizacional'),
(6486, 4390, 3, 'Organizacións'),
(6487, 4391, 3, 'Orientada x 3'),
(6488, 4392, 3, 'Original'),
(6489, 4396, 3, 'OROFARINGE: '),
(6490, 4397, 3, 'Orthopnea'),
(6491, 4398, 3, 'OS'),
(6492, 4399, 3, 'Osteoartritis'),
(6493, 4402, 3, 'Otro'),
(6494, 4403, 3, 'otro'),
(6495, 4404, 3, 'Otro (especifique)'),
(6496, 4405, 3, 'Otros - especificado'),
(6497, 4406, 3, 'Otro Progama Federal'),
(6498, 4407, 3, 'Otro HCFA'),
(6499, 4408, 3, 'Otra lesión en otra parte especificada'),
(6500, 4409, 3, 'Otro Seguro de Responsabilidad Civil es Primario'),
(6501, 4410, 3, 'Otro mes'),
(6502, 4411, 3, 'Otros programas No-Federales'),
(6503, 4412, 3, 'Otras Notas'),
(6504, 4413, 3, 'Otros síntomas pertinentes'),
(6505, 4414, 3, 'Otros síntomas pertinentes:'),
(6506, 4415, 3, 'Otra respuesta del paciente'),
(6507, 4416, 3, 'Otros tipos de estrés/lesión uso en'),
(6508, 4417, 3, 'Otro Quirúrgico'),
(6509, 4418, 3, 'Otro/Genérico relacionado con Aborto'),
(6510, 4420, 3, 'Otros'),
(6511, 4421, 3, 'De otra forma usted destruirá las referencias a/de los datos existentes'),
(6512, 4422, 3, 'Reglas de tobillo de Ottawa'),
(6513, 4423, 3, 'OU'),
(6514, 4424, 3, 'SALIDA'),
(6515, 4425, 3, 'Salida'),
(6516, 4426, 3, 'Derivación de salida'),
(6517, 4427, 3, 'Resultado'),
(6518, 4428, 3, 'Outlook'),
(6519, 4431, 3, 'VENCIDO'),
(6520, 4432, 3, 'Sobreuso'),
(6521, 4433, 3, 'Información General'),
(6522, 4434, 3, 'Sobrepeso'),
(6523, 4435, 3, 'Sobrescribir la elección HIPAA'),
(6524, 4437, 3, 'Saturación del Oxígeno'),
(6525, 4439, 3, 'P'),
(6526, 4440, 3, 'p.c.'),
(6527, 4441, 3, 'p.m.'),
(6528, 4442, 3, 'p.r.n.'),
(6529, 4443, 3, 'Isleño del Pacifico'),
(6530, 4444, 3, 'Paedeatric'),
(6531, 4445, 3, 'Página'),
(6532, 4446, 3, 'Páginas'),
(6533, 4447, 3, 'Pago'),
(6534, 4448, 3, 'Cantidad pagada que usted asignará'),
(6535, 4449, 3, 'Importe pagado'),
(6536, 4450, 3, 'Pagado Via'),
(6537, 4451, 3, 'Dolor'),
(6538, 4453, 3, 'Palpitaciones'),
(6539, 4455, 3, 'Prueba de Papanicolaou'),
(6540, 4456, 3, 'Papel'),
(6541, 4457, 3, 'Tamaño papel'),
(6542, 4458, 3, 'Parálisis'),
(6543, 4461, 3, 'Analizar HL7'),
(6544, 4463, 3, 'Socio'),
(6545, 4464, 3, 'Nombre Socio'),
(6546, 4467, 3, 'Frase Contraseña'),
(6547, 4468, 3, 'Frase Contraseña para desencriptar documento'),
(6548, 4469, 3, 'Pacientes pasados'),
(6549, 4470, 3, 'Alerta Pasiva'),
(6550, 4471, 3, 'Reglas de Alerta Pasiva'),
(6551, 4472, 3, 'Contraseña'),
(6552, 4473, 3, 'Cambio de la contraseña'),
(6553, 4475, 3, 'Cambio de contraseña con éxito.'),
(6554, 4477, 3, 'Periodo de Gracia de Expiración de Contraseña'),
(6555, 4479, 3, 'Contraseña para puerta de enlace telefónico. Servicio automático de VOIP desarrollado por Maviq. Por favor visite http://signup.maviq.com para más información.'),
(6556, 4480, 3, 'Contraseña para puerta de enlace SMS.'),
(6557, 4481, 3, 'Contraseña para puerta de enlace SMS.'),
(6558, 4483, 3, 'Contraseña de seguridad ha sido recientemente actualizada.'),
(6559, 4484, 3, 'Contraseña para conectar a CouchDB'),
(6560, 4486, 3, 'Contraseña'),
(6561, 4490, 3, 'Vencimiento'),
(6562, 4491, 3, 'Vencimiento'),
(6563, 4492, 3, 'Intervalo Vencido (Recordatorios clínicos)'),
(6564, 4493, 3, 'Intervalo Vencido (Recordatorios Paciente)'),
(6565, 4494, 3, 'Lista de visitas anteriores'),
(6566, 4495, 3, 'Anteriores visitas'),
(6567, 4496, 3, 'Anteriores visitas y Documentos'),
(6568, 4497, 3, 'Anteriores visitas de'),
(6569, 4498, 3, 'Pegar datos HL7'),
(6570, 4499, 3, 'Pegar los datos de importación en el área de texto a continuación:'),
(6571, 4500, 3, 'Paciente'),
(6572, 4502, 3, 'Parche'),
(6573, 4508, 3, 'Ruta de backup del log de eventos'),
(6574, 4509, 3, 'Ruta del fichero de certificado CA'),
(6575, 4510, 3, 'Ruta del fichero clave CA'),
(6576, 4511, 3, 'Ruta de ficheros binarios MySQL'),
(6577, 4512, 3, 'Ruta de ficheros binarios Perl'),
(6578, 4513, 3, 'Ruta de los ficheros temporales'),
(6579, 4514, 3, 'Paciente'),
(6580, 4515, 3, 'paciente'),
(6581, 4516, 3, 'PACIENTE'),
(6582, 4517, 3, 'Dirección del paciente'),
(6583, 4518, 3, 'Falta la dirección del paciente'),
(6584, 4521, 3, 'Alergias del Paciente'),
(6585, 4522, 3, 'Alergias del Paciente'),
(6586, 4523, 3, 'Cita del Paciente'),
(6587, 4524, 3, 'Balance de paciente'),
(6588, 4528, 3, 'Nº Identificación del gráfico del paciente'),
(6589, 4529, 3, 'Comprobación de paciente'),
(6590, 4530, 3, 'Comprobación de paciente para '),
(6591, 4531, 3, 'Ciudad del Paciente'),
(6592, 4532, 3, 'Falta la ciudad del paciente'),
(6593, 4533, 3, 'Comunicación Enviada al Paciente'),
(6594, 4534, 3, 'Comunicación Enviada al Paciente'),
(6595, 4535, 3, 'Pais del Paciente'),
(6596, 4536, 3, 'Falta la ciudad del paciente. Tampoco ha configurado la ciudad del paciente por defecto en la configuración global'),
(6597, 4537, 3, 'Cobertura de paciente'),
(6598, 4539, 3, 'Datos del Paciente'),
(6599, 4541, 3, 'Falta la F.Nacimiento del paciente'),
(6600, 4542, 3, 'Detalles del Paciente'),
(6601, 4543, 3, 'F.Nacimiento del Paciente'),
(6602, 4544, 3, 'Documentos del Paciente'),
(6603, 4545, 3, 'Material Educativo para el Paciente'),
(6604, 4546, 3, 'Materiales educativos para pacientes'),
(6605, 4547, 3, 'Visitas del Paciente'),
(6606, 4548, 3, 'Formulario de visitas del Paciente'),
(6607, 4549, 3, 'Visitas de Pacientes'),
(6608, 4550, 3, 'Buscador de paciente'),
(6609, 4551, 3, 'Nombre del Paciente'),
(6610, 4553, 3, 'Falta el nombre del paciente'),
(6611, 4558, 3, 'Género del Paciente'),
(6612, 4559, 3, 'Falta el género del paciente'),
(6613, 4560, 3, 'Paciente no autorizado al Portal del paciente'),
(6614, 4561, 3, 'Historia del Paciente'),
(6615, 4562, 3, 'Historia del Paciente/Estilo de Vida'),
(6616, 4563, 3, 'Teléfono Casa del Paciente'),
(6617, 4564, 3, 'ID Paciente'),
(6618, 4565, 3, 'Nº Identificación del Paciente'),
(6619, 4566, 3, 'Nº Identificación Tarjeta del Paciente'),
(6620, 4567, 3, 'Nombre categoría ID paciente'),
(6621, 4568, 3, 'Vacunación del paciente'),
(6622, 4569, 3, 'Información del Paciente'),
(6623, 4570, 3, 'Instrucciones al paciente'),
(6624, 4571, 3, 'Distribución de pacientes Asegurados'),
(6625, 4572, 3, 'Informe de distribución de pacientes asegurados'),
(6626, 4573, 3, 'Incidencias del Paciente'),
(6627, 4575, 3, 'Apellido(s)del Paciente'),
(6628, 4577, 3, 'Falta el apellido del paciente'),
(6629, 4581, 3, 'Lista de Pacientes'),
(6630, 4582, 3, 'Columnas Lista de Pacientes'),
(6631, 4584, 3, 'Nuevas ventanas Lista de Pacientes'),
(6632, 4585, 3, 'Tamaño página Lista de Pacientes'),
(6633, 4586, 3, 'Errores de búsqueda de pacientes'),
(6634, 4587, 3, 'Problemas Médicos del Paciente'),
(6635, 4588, 3, 'Medicamentos del Paciente'),
(6636, 4589, 3, 'Nombre del Paciente'),
(6637, 4590, 3, 'Nombre y Dirección del Paciente'),
(6638, 4593, 3, 'Nombre de Paciente Requerido'),
(6639, 4595, 3, 'Nota del paciente'),
(6640, 4596, 3, 'Nota de tipos de pacientes'),
(6641, 4597, 3, 'Notas del Paciente'),
(6642, 4598, 3, 'Notas del paciente (escribir, sólo añadir opcional)'),
(6643, 4599, 3, 'Número del Paciente'),
(6644, 4600, 3, 'Pago del paciente'),
(6645, 4602, 3, 'Nombre de Categoría de Foto del Paciente'),
(6646, 4603, 3, 'Portal del Paciente'),
(6647, 4605, 3, 'Portal del Paciente está apagado'),
(6648, 4606, 3, 'Inicio sesión Portal del Paciente'),
(6649, 4607, 3, 'Sitio web del Portal del Paciente'),
(6650, 4608, 3, 'Informe Impreso del Paciente'),
(6651, 4609, 3, 'Informe de registro del paciente'),
(6652, 4610, 3, 'Solicitud Registro de Paciente'),
(6653, 4611, 3, 'Solicitud Registros de Pacientes'),
(6654, 4613, 3, 'Recordatorios del paciente'),
(6655, 4614, 3, 'Batch Recordatorio del Paciente'),
(6656, 4616, 3, 'Reglas Recordatorio del Paciente'),
(6657, 4617, 3, 'email Remitente de Recordatorio del Paciente'),
(6658, 4618, 3, 'Nombre Remitente de Recordatorio del Paciente'),
(6659, 4619, 3, 'Recordatorios del Paciente'),
(6660, 4620, 3, 'Inforne del Paciente'),
(6661, 4621, 3, 'Solicitud del Paciente'),
(6662, 4622, 3, 'Paciente solicitó Registros Médicos'),
(6663, 4623, 3, 'Resultados del paciente'),
(6664, 4624, 3, 'Resultados de búsqueda de estilo de paciente'),
(6665, 4625, 3, 'Pantalla Buscar/añadir paciente'),
(6666, 4626, 3, 'Ajustes paciente'),
(6667, 4627, 3, 'Estado paciente'),
(6668, 4629, 3, 'Resumen del Paciente'),
(6669, 4630, 3, 'Transacciones del Pacientes'),
(6670, 4631, 3, 'Código Postal paciente'),
(6671, 4632, 3, 'Paciente(s) en la BBDD que coinciden con la información demográfica que usted ha ingresado.'),
(6672, 4633, 3, 'Paciente/Cliente'),
(6673, 4634, 3, 'Paciente:'),
(6674, 4635, 3, 'PacienteID'),
(6675, 4636, 3, 'Pacientes'),
(6676, 4638, 3, 'Pago'),
(6677, 4639, 3, 'Preste atención a la -Hecho con- casillas de verificación. Después de los seguros están marcados completa luego empezaremos a pedir a la paciente a pagar el saldo restante, si usted no marca la totalidad de los seguros luego completar la cantidad restante no serán recogidos! También si hay un equilibrio que el paciente debe pagar, a continuación, establezca la fecha apropiada, ya que esto afecta a la lengua que aparece en las declaraciones del paciente.'),
(6678, 4640, 3, 'Fecha de Pago:'),
(6679, 4641, 3, 'Estado de Pago'),
(6680, 4642, 3, 'Nombre del beneficiario'),
(6681, 4643, 3, 'Pagador'),
(6682, 4644, 3, 'Tipo Pagador'),
(6683, 4645, 3, 'Pagar'),
(6684, 4646, 3, 'Entidad pagadora'),
(6685, 4647, 3, 'Pago'),
(6686, 4648, 3, 'pago'),
(6687, 4649, 3, 'Código ajuste pago'),
(6688, 4650, 3, 'Pago contra'),
(6689, 4651, 3, 'Imnporte pago'),
(6690, 4652, 3, 'Importe pago debe ser numérico'),
(6691, 4653, 3, 'Categoría pago'),
(6692, 4654, 3, 'Fecha de Pago'),
(6693, 4655, 3, 'pago ingresado el'),
(6694, 4656, 3, 'Pago desde'),
(6695, 4657, 3, 'Pasarela de pagos'),
(6696, 4658, 3, 'Imputar pagos'),
(6697, 4659, 3, 'Lista de pagos'),
(6698, 4660, 3, 'Método de Pago'),
(6699, 4661, 3, 'Ordenar pagos por'),
(6700, 4662, 3, 'Estado pagos'),
(6701, 4663, 3, 'Tipo pagos'),
(6702, 4664, 3, 'Valor de pago para el código '),
(6703, 4665, 3, 'Pagos'),
(6704, 4667, 3, 'PCP'),
(6705, 4669, 3, 'PDF'),
(6706, 4670, 3, 'Descargar PDF de seleccionados'),
(6707, 4672, 3, 'Pelvis y nalga'),
(6708, 4673, 3, 'Pénfigo'),
(6709, 4674, 3, 'Pendiente'),
(6710, 4676, 3, 'Pendiente F/U'),
(6711, 4677, 3, 'Seguimento Pendiente'),
(6712, 4678, 3, 'Seguimiento de resultados pendientes'),
(6713, 4679, 3, 'Ordenes pendientes'),
(6714, 4680, 3, 'Ordenes pendientes'),
(6715, 4681, 3, 'Revisión Pendientes'),
(6716, 4682, 3, 'Contador Recetas pendientes'),
(6717, 4684, 3, 'Pennington firme LibreEHR v'),
(6718, 4685, 3, 'La úlcera péptica'),
(6719, 4687, 3, 'por minuto'),
(6720, 4688, 3, 'Por las fosas nasales'),
(6721, 4689, 3, 'por las fosas nasales'),
(6722, 4690, 3, 'Por Oris'),
(6723, 4691, 3, 'por oris'),
(6724, 4692, 3, 'Por Recto'),
(6725, 4693, 3, 'por recto'),
(6726, 4694, 3, 'Porcentaje'),
(6727, 4697, 3, 'Percentil'),
(6728, 4698, 3, 'Derecho Perforado:'),
(6729, 4699, 3, 'Realizar la búsqueda'),
(6730, 4700, 3, 'Realizar esta acción'),
(6731, 4701, 3, 'Porcentaje Rendimiento'),
(6732, 4703, 3, 'Realización Laboratorio del Centro'),
(6733, 4705, 3, 'Periodo'),
(6734, 4706, 3, 'Periodo en días donde un usuario puede iniciar sesión con una contraseña caducada.'),
(6735, 4707, 3, 'Cuidados perioperatorios'),
(6736, 4708, 3, 'Periférico'),
(6737, 4712, 3, 'Persona'),
(6738, 4713, 3, 'Personalizar'),
(6739, 4714, 3, 'PG'),
(6740, 4715, 3, 'Farmacia'),
(6741, 4716, 3, 'Pharm Com Count'),
(6742, 4717, 3, 'Farmacias'),
(6743, 4718, 3, 'Farmacia'),
(6744, 4719, 3, 'Dispensario de la Farmacia'),
(6745, 4720, 3, 'Neumotorax'),
(6746, 4729, 3, 'Teléfono'),
(6747, 4730, 3, 'Lista de llamadas de teléfono'),
(6748, 4731, 3, 'Informe Lista de llamadas'),
(6749, 4733, 3, 'Contraseña de la puerta de enlace telefónico'),
(6750, 4734, 3, 'URL de la puerta de enlace telefónico'),
(6751, 4735, 3, 'Usuario puerta de enlace telefónico'),
(6752, 4737, 3, 'Hora notificación teléfono'),
(6753, 4738, 3, 'Número de teléfono'),
(6754, 4740, 3, 'Fotofobia'),
(6755, 4741, 3, 'Fotografías'),
(6756, 4742, 3, 'PHP comprimida'),
(6757, 4743, 3, 'Módulo PHP CURL debe estar activado en su servidor.'),
(6758, 4744, 3, 'Extraído de PHP'),
(6759, 4745, 3, 'controles de acceso de PHP-GACL están desactivados.'),
(6760, 4746, 3, 'controles de acceso de PHP-GACL are desactivados.'),
(6761, 4747, 3, 'Examen Físico'),
(6762, 4749, 3, 'Solicitud de Fisio'),
(6763, 4750, 3, 'Firma del Fisio'),
(6764, 4752, 3, 'Fisios'),
(6765, 4753, 3, 'escoger'),
(6766, 4754, 3, 'Seleccionar'),
(6767, 4755, 3, 'Seleccionar un tema CSS'),
(6768, 4756, 3, 'PID'),
(6769, 4757, 3, 'PID (enfermedad pélvica inflamatoria)'),
(6770, 4758, 3, 'Tamaño de la Píldora'),
(6771, 4759, 3, 'Píldoras'),
(6772, 4760, 3, 'Coloque el fichero de database zip en el siguiente directorio si quiere la opción de instalar'),
(6773, 4761, 3, 'Ponga el fichero zip de bbdd ICD 10 en la siguiente carpeta'),
(6774, 4762, 3, 'Ponga el fichero zip de bbdd ICD 9 en la siguiente carpeta'),
(6775, 4763, 3, 'Ponga el fichero zip de bbdd RxNorm en la siguiente carpeta'),
(6776, 4764, 3, 'Ponga el fichero zip de bbdd Snomed en la siguiente carpeta'),
(6777, 4765, 3, 'Marcador de posición'),
(6778, 4766, 3, 'Marcador de posición (Mantiene vacia ACL)'),
(6779, 4767, 3, 'Texto sin Formato'),
(6780, 4768, 3, 'Plan'),
(6781, 4771, 3, 'Nombre del Plan'),
(6782, 4775, 3, 'Ajuste Planes'),
(6783, 4779, 3, 'Plan:'),
(6784, 4782, 3, 'Planes'),
(6785, 4784, 3, 'Jugador'),
(6786, 4785, 3, 'Posición de juego'),
(6787, 4786, 3, 'Favor de llamar si la informacion arriba es incorrecta'),
(6788, 4787, 3, 'Por favor cambie su contraseña'),
(6789, 4788, 3, 'Por favor, elige un fichero'),
(6790, 4789, 3, 'Por favor, elige un paciente'),
(6791, 4790, 3, 'Por favor, elija una selección válida de la lista.'),
(6792, 4791, 3, 'Por favor elige una selecion valida'),
(6793, 4792, 3, 'Por favor, elija un valor para'),
(6794, 4793, 3, 'Por favor elija el rango de fechas, y haga click en refrescar para ver los resultados.'),
(6795, 4794, 3, 'Por favor elegir el formato adecuado del fichero EDI-271'),
(6796, 4795, 3, 'Por favor click en el botón Descargar para descargar los datos de DE identificación'),
(6797, 4796, 3, 'Por favor click en el botón descargar para descargar los datos de Re-identificación'),
(6798, 4797, 3, 'Por favor, cierre esta ventana.'),
(6799, 4798, 3, 'Por favor, comparar el nuevo nombre'),
(6800, 4801, 3, 'Por favor cree la siguiente carpeta antes de proceder'),
(6801, 4802, 3, 'No acepte por favor esta prescripción a menos que fuera recibida vía facimile.'),
(6802, 4803, 3, 'Por favor no aceptar esta receta a menos que sea recibida por fax.'),
(6803, 4804, 3, 'Por favor, no utilice el botón de parada o recarga de su navegador, mientras esta página está funcionando a menos que transcurran mas de 10 minutos, esto no detendrá el proceso en el servidor y consumirá recursos innecesarios.'),
(6804, 4805, 3, 'POR FAVOR ACTIVE LA EXTENSIÓN CURL'),
(6805, 4806, 3, 'POR FAVOR ACTIVE LA EXTENSIÓN OPENSSL'),
(6806, 4807, 3, 'POR FAVOR ACTIVE LA EXTENSIÓN SOAP'),
(6807, 4808, 3, 'POR FAVOR ACTIVE LA EXTENSIÓN XML'),
(6808, 4809, 3, 'Favor de entrar fecha de la ultima revision'),
(6809, 4810, 3, 'Por favor introduzca la fecha'),
(6810, 4811, 3, 'Por favor introduzca una fecha de vencimiento'),
(6811, 4812, 3, 'Por favor introduzca un mensaje'),
(6812, 4813, 3, 'Por favor, introduzca un importe monetario, utilizando sólo números y un punto decimal.'),
(6813, 4814, 3, 'Por favor introduzca una Nueva Contraseña'),
(6814, 4815, 3, 'Por favor, escriba un título!'),
(6815, 4819, 3, 'Por favor introduzca el código de Re-identificación correcto'),
(6816, 4821, 3, 'Por favor, introduzca el dato de la nueva búsqueda'),
(6817, 4822, 3, 'Por favor introduzca el código de re-identificación'),
(6818, 4823, 3, 'Por favor introduzca contraseña'),
(6819, 4824, 3, 'Por favor rellene el número de cheque'),
(6820, 4825, 3, 'Por favor rellene el número Check/Ref'),
(6821, 4826, 3, 'Por favor rellene la fecha'),
(6822, 4827, 3, 'Por favor rellene el importe del pago'),
(6823, 4828, 3, 'Por favor rellene la categoría del pago'),
(6824, 4829, 3, 'Por favor rellene la procedencia del pago'),
(6825, 4830, 3, 'Por favor rellene la casilla de la Fecha'),
(6826, 4831, 3, 'Favor de llenar antes de continuar'),
(6827, 4832, 3, 'Por favor indique el motivo de la visita'),
(6828, 4834, 3, 'Por favor introducir criterios de búsqueda arriba, haga clic en aceptar para ver los resultados.'),
(6829, 4835, 3, 'Por favor introduzca los criterios de búsqueda arriba, y haga click en aceptar para ver los resultados. (Los resultados serán mostrados en una ventana emergente)'),
(6830, 4836, 3, 'Por favor inicie sesión de nuevo'),
(6831, 4837, 3, 'Por Favor tenga en cuenta que esto puede tomar mucho tiempo, hasta varios minutos, el navegador web puede no aparecer muy activa durante este tiempo, pero la generación de una factura es un proceso complicado y su navegador web está a la espera de más información.'),
(6832, 4838, 3, 'Por favor Nota: constantes son sensibles a mayúsculas y minúsculas y se permite cualquier cadena.'),
(6833, 4839, 3, 'Por favor, utilice únicamente caracteres alfabéticos'),
(6834, 4840, 3, 'Por favor, utilice únicamente caracteres alfabéticos sin espacios'),
(6835, 4841, 3, 'Por favor, pagar esta cantidad'),
(6836, 4842, 3, 'Por favor ponga sus ficheros de instalación en la siguiente carpeta'),
(6837, 4843, 3, 'Favor de referise a'),
(6838, 4844, 3, 'Por favor, reinicie la contraseña.'),
(6839, 4845, 3, 'Por favor resetear el servidor apache antes de intentar la finalización de sesión'),
(6840, 4847, 3, 'Por favor seleccione'),
(6841, 4849, 3, 'Por favor seleccione un idioma'),
(6842, 4850, 3, 'Por favor seleccione un Paciente'),
(6843, 4851, 3, 'Por favor seleccione una entidad de negocio primario con ''C.I.F.'' como su centro ''C.I.F.''. Si usted es autónomo, ponga su ''C.I.F.''. Será usado para identificarle en el sistema NewCrop.'),
(6844, 4854, 3, 'Por favor Seleccione un Destinatario'),
(6845, 4855, 3, 'Por favor seleccione la fecha de inicio y fin'),
(6846, 4856, 3, 'Por favor Seleccione un Destinatario válido'),
(6847, 4858, 3, 'Por favor, seleccione un razón de ajuste para el código '),
(6848, 4859, 3, 'Por favor, seleccione un evento'),
(6849, 4860, 3, 'Por favor seleccione una Opción de Búsqueda'),
(6850, 4863, 3, 'Favor seleccionar al menos una receta'),
(6851, 4865, 3, 'Por favor, seleccione las pags. que desee copiar o reenviar:'),
(6852, 4866, 3, 'Por favor seleccione la Forma de Pago'),
(6853, 4867, 3, 'Por favor seleccione el tipo de pago.'),
(6854, 4869, 3, 'Por favor seleccione socio X12, requerido para crear el batch 270'),
(6855, 4870, 3, 'Por favor ajuste'),
(6856, 4871, 3, 'Por favor ponga la variable de_identification_config a cero'),
(6857, 4873, 3, 'Por favor inicie un nuevo proceso de De identificación'),
(6858, 4874, 3, 'Por favor actualice la base de datos LibreEHR para incluir procedimientos, funciones, tablas para De identificación'),
(6859, 4875, 3, 'Por favor, consulte la tabla de log de errores de De Identificación para más detalles'),
(6860, 4876, 3, 'Por favor visite la pantalla de Re-Identificación después de algún tiempo'),
(6861, 4877, 3, 'Por favor visite la pantalla de Re-Identificación después de algún tiempo'),
(6862, 4878, 3, 'Por favor visite la página pasado algún tiempo'),
(6863, 4882, 3, 'PM'),
(6864, 4883, 3, 'PM Program'),
(6865, 4884, 3, 'Método de pago'),
(6866, 4885, 3, 'PND'),
(6867, 4886, 3, 'Conjugado Neumocócico 1'),
(6868, 4887, 3, 'Conjugado Neumocócico 2'),
(6869, 4888, 3, 'Conjugado Neumocócico 3'),
(6870, 4889, 3, 'Conjugado Neumocócico 4'),
(6871, 4890, 3, 'vacuna contra el neumococo'),
(6872, 4891, 3, 'Vacunación Neumonía'),
(6873, 4892, 3, 'Estado de vacunación de neumonía de adultos mayores'),
(6874, 4893, 3, 'Estado de vacunación de neumonía de adultos mayores (GCC)'),
(6875, 4894, 3, 'Podológica'),
(6876, 4896, 3, 'Punto del servicio (posición)'),
(6877, 4897, 3, 'Póliza'),
(6878, 4898, 3, 'Póliza Nº'),
(6879, 4899, 3, 'Número Póliza'),
(6880, 4900, 3, 'Polaco'),
(6881, 4901, 3, 'Polidipsia'),
(6882, 4902, 3, 'Pólipos'),
(6883, 4903, 3, 'Poliuria'),
(6884, 4904, 3, 'Falta de Apetito'),
(6885, 4905, 3, 'Pobre Circulación'),
(6886, 4906, 3, 'Déficit auditivo'),
(6887, 4907, 3, 'Pop-ups necesitan estar activos para ver estos reportes'),
(6888, 4908, 3, '¿Rellenar la vista del año con eventos?'),
(6889, 4909, 3, 'Los menús emergentes'),
(6890, 4910, 3, 'Portal'),
(6891, 4911, 3, 'Actividad del Portal'),
(6892, 4917, 3, 'Portugués'),
(6893, 4918, 3, 'Portugués (Brasileño)'),
(6894, 4919, 3, 'Portugués (Europeo)'),
(6895, 4920, 3, 'Código de POS'),
(6896, 4922, 3, 'Positivo'),
(6897, 4923, 3, 'Positivos'),
(6898, 4925, 3, 'Enviar por'),
(6899, 4926, 3, 'Goteo nasal posterior'),
(6900, 4927, 3, 'Enviar pagos'),
(6901, 4928, 3, 'Post-quirúrgico'),
(6902, 4929, 3, 'Publique en la contabilidad y marque como facturado'),
(6903, 4930, 3, 'Publicar en fecha'),
(6904, 4931, 3, 'Publicar en fecha no puede ser mayor que hoy'),
(6905, 4932, 3, 'Publicar en fecha debe ser mayor que la fecha de cierre financiero'),
(6906, 4933, 3, 'Cuidado del Post-Aborto'),
(6907, 4934, 3, 'Contracepción del Post-Aborto'),
(6908, 4935, 3, 'Asesoramiento del Post-Aborto'),
(6909, 4936, 3, 'Seguimiento Post-Aborto'),
(6910, 4937, 3, 'Postal'),
(6911, 4938, 3, 'Código Postal'),
(6912, 4939, 3, 'Código Postal'),
(6913, 4941, 3, 'PostCalendar'),
(6914, 4942, 3, 'Administración del PostCalendar'),
(6915, 4943, 3, 'Configuración de la Categoría PostCalendar'),
(6916, 4944, 3, 'Configuración Global de PostCalendar'),
(6917, 4945, 3, 'Publicado en'),
(6918, 4946, 3, 'Fecha de Envío'),
(6919, 4948, 3, 'Desarrollado por'),
(6920, 4949, 3, 'PPE+ Prev Med/Surg Hx'),
(6921, 4950, 3, 'PQRI (Iniciativa Informe Calidad Médica)'),
(6922, 4951, 3, 'Registro ID PQRI'),
(6923, 4952, 3, 'Registro Nombre PQRI'),
(6924, 4953, 3, 'Práctica'),
(6925, 4954, 3, 'Centro establecido por defecto'),
(6926, 4955, 3, 'Ajustes del Centro'),
(6927, 4956, 3, 'Prestador'),
(6928, 4958, 3, 'Pago anticipado'),
(6929, 4959, 3, 'Prepago'),
(6930, 4960, 3, 'Consulta del Pre-Aborto'),
(6931, 4961, 3, 'Asesoramiento del Pre-Aborto'),
(6932, 4962, 3, 'Categoría Pref'),
(6933, 4964, 3, 'Preferencias'),
(6934, 4965, 3, 'Categoría preferida del evento'),
(6935, 4966, 3, 'Lengua preferida'),
(6936, 4967, 3, 'Preferencia Farmacia'),
(6937, 4968, 3, 'Organización Proveedora Preferida (PPO)'),
(6938, 4969, 3, 'Prueba de embarazo'),
(6939, 4970, 3, 'Preliminar'),
(6940, 4972, 3, 'Pague por Adelantado'),
(6941, 4973, 3, 'Prescripción'),
(6942, 4974, 3, 'Receta ha alcanzado sus limites de'),
(6943, 4975, 3, 'Histórico de Prescripciones'),
(6944, 4976, 3, 'Importación de Histórico de Prescripciones completado'),
(6945, 4977, 3, 'Etiqueta de la prescripción'),
(6946, 4978, 3, 'Informe de Prescripción'),
(6947, 4979, 3, 'Prescripciónes'),
(6948, 4980, 3, 'Prescripciones y dispensaciones'),
(6949, 4981, 3, 'Recetas y otras derivaciones'),
(6950, 4982, 3, 'Prescripciones y/o derivaciones a especialista'),
(6951, 4983, 3, 'Informe de las prescripciones'),
(6952, 4984, 3, 'Prescripciones/Derivaciones'),
(6953, 4985, 3, 'Presente'),
(6954, 4986, 3, 'Presentación de queja'),
(6955, 4988, 3, 'Pulse Continuar para proseguir'),
(6956, 4989, 3, 'Presunción de Diagnóstico'),
(6957, 4990, 3, 'Presunción de Diagnóstico por el especialista'),
(6958, 4991, 3, 'Previa'),
(6959, 4992, 3, 'Prev Med/Surg Hx'),
(6960, 4993, 3, 'Mes anterior. (Presione para menu)'),
(6961, 4994, 3, 'Año anterior (Presione para el menu)'),
(6962, 4995, 3, 'Cuidado Preventivo'),
(6963, 4998, 3, 'Vista previa del evento'),
(6964, 5000, 3, 'Previsualización de'),
(6965, 5001, 3, 'Anterior'),
(6966, 5002, 3, 'Consultas Anteriores'),
(6967, 5003, 3, 'Dia Anterior'),
(6968, 5004, 3, 'Para Historia'),
(6969, 5005, 3, 'Mes Anterior'),
(6970, 5006, 3, 'Semana Anterior'),
(6971, 5007, 3, 'Precio'),
(6972, 5008, 3, 'Precio de descuento'),
(6973, 5009, 3, 'Nivel de Precio'),
(6974, 5010, 3, 'Nivel de Precio:'),
(6975, 5011, 3, 'Precios'),
(6976, 5012, 3, 'Primario'),
(6977, 5013, 3, 'Entidad Empresa Primaria'),
(6978, 5014, 3, 'La entidad de negocio principal es usada como cuenta Id para la ePrescipción. Cambiando el centro afectará al funcionamiento en NewCrop.'),
(6979, 5022, 3, 'Seguro principal'),
(6980, 5023, 3, 'Seguro principal'),
(6981, 5024, 3, 'Datos principales del Seguro'),
(6982, 5025, 3, 'Proveedor principal del Seguro'),
(6983, 5026, 3, 'Proveedor primario'),
(6984, 5027, 3, 'Imprimir'),
(6985, 5028, 3, 'Imprimir (HTML)'),
(6986, 5029, 3, 'Imprimir (PDF)'),
(6987, 5031, 3, 'Imprimir cualquier visita'),
(6988, 5032, 3, 'Imprimir el formulario de derivación en blanco'),
(6989, 5033, 3, 'Comando Imprimir'),
(6990, 5039, 3, 'Imprimir el Formato'),
(6991, 5040, 3, 'Imprimir cuatro paneles'),
(6992, 5042, 3, 'Mensaje Imprimir'),
(6993, 5043, 3, 'Imprimir Múltiples'),
(6994, 5044, 3, 'Para imprimir múltiples Fax'),
(6995, 5045, 3, 'Imprima nombre, fecha y firma'),
(6996, 5046, 3, 'Imprimir notas'),
(6997, 5047, 3, 'Imprimir Página 1'),
(6998, 5048, 3, 'Imprimir Página 2'),
(6999, 5051, 3, 'Impresión Receta del Facultativo'),
(7000, 5052, 3, 'Grabar Imprimir'),
(7001, 5053, 3, 'Imprimir Seleccionados'),
(7002, 5054, 3, 'Registro de tiro impresión'),
(7003, 5056, 3, 'Imprimir ásta visita'),
(7004, 5057, 3, 'Imprimir esta nota'),
(7005, 5058, 3, 'Imprimir Esta Nota'),
(7006, 5060, 3, 'Para imprimir Fax'),
(7007, 5061, 3, 'Ver Imprenta'),
(7008, 5062, 3, 'Imprimible'),
(7009, 5063, 3, 'Versión Imprimible'),
(7010, 5064, 3, 'Impreso'),
(7011, 5066, 3, 'Resultados de la impresión:'),
(7012, 5067, 3, 'Impresión omitida; ver la salida de prueba en'),
(7013, 5068, 3, 'Impresión saltado; ver la prueba de salida en '),
(7014, 5069, 3, 'Antes de autentificación'),
(7015, 5070, 3, 'Formulario de Autorización Previa'),
(7016, 5071, 3, 'Antes de visita'),
(7017, 5072, 3, 'Prioridad'),
(7018, 5073, 3, 'Prioridad '),
(7019, 5074, 3, 'Privado'),
(7020, 5075, 3, 'Problema'),
(7021, 5076, 3, 'Problema Diagnóstico (DX)'),
(7022, 5077, 3, 'Lista de Problema'),
(7023, 5079, 3, 'Problemas/Incidencias'),
(7024, 5080, 3, 'Proc Bat'),
(7025, 5081, 3, 'Proc Cat'),
(7026, 5083, 3, 'Proc.Pendientes Revisión'),
(7027, 5085, 3, 'Proc Res'),
(7028, 5086, 3, 'Procedimiento'),
(7029, 5087, 3, 'Procedmiento por area corporal'),
(7030, 5088, 3, 'Procedimientos con resultados Boolean'),
(7031, 5089, 3, 'Codigo de Procedimiento'),
(7032, 5090, 3, 'Códigos de procedimiento'),
(7033, 5091, 3, 'Lateralidades del procedimiento'),
(7034, 5093, 3, 'Orden del procedimiento'),
(7035, 5095, 3, 'Procedimiento ordenado para'),
(7036, 5102, 3, 'Informe Procedimiento'),
(7037, 5103, 3, 'Situaciones del reporte de procedimientos'),
(7038, 5104, 3, 'Resultado anormal del procedimiento'),
(7039, 5105, 3, 'Situacion del resultado del procedimiento'),
(7040, 5106, 3, 'Resultados del procedimientos'),
(7041, 5107, 3, 'Rutas del procedimiento'),
(7042, 5108, 3, 'Tipos de especímenes del procedimiento'),
(7043, 5109, 3, 'Reportes estadísticos del procedimiento'),
(7044, 5110, 3, 'Tipo del procedimiento'),
(7045, 5111, 3, 'Tipos de procedimientos'),
(7046, 5112, 3, 'Unidades del procedimiento'),
(7047, 5113, 3, 'Procedimiento/Servicio'),
(7048, 5114, 3, 'Procedimientos'),
(7049, 5115, 3, 'Aceptar'),
(7050, 5117, 3, 'Procesar fichero ERA'),
(7051, 5120, 3, 'El proceso puede tardar algún tiempo'),
(7052, 5121, 3, 'Procesado'),
(7053, 5122, 3, 'Procesado por'),
(7054, 5123, 3, 'Fecha procesado'),
(7055, 5125, 3, 'Procesamiento'),
(7056, 5129, 3, 'Producto'),
(7057, 5130, 3, 'Método Producto Anticonceptivo'),
(7058, 5132, 3, 'Productos'),
(7059, 5133, 3, 'Productos pero no medicamentos con receta y sin plantillas'),
(7060, 5134, 3, 'Prof.'),
(7061, 5135, 3, 'Notas de progreso'),
(7062, 5136, 3, 'Cáncer de Próstata'),
(7063, 5137, 3, 'Detección de cancer de próstata'),
(7064, 5138, 3, 'Examen de Próstata'),
(7065, 5139, 3, 'Problemas de Próstata'),
(7066, 5140, 3, 'Próstata sin enlrgmt, nódulos, dolor'),
(7067, 5142, 3, 'Provee ruta absoluta'),
(7068, 5143, 3, 'Provee ruta absoluta del file'),
(7069, 5145, 3, 'Proporcione resúmenes clínicos a los pacientes en cada visita.'),
(7070, 5146, 3, 'Proporcionar a los pacientes una copia electrónica de su información de salud (incluyendo resultados de pruebas de diagnóstico, lista de problemas, lista de medicamentos, medicación para alergias), bajo petición.'),
(7071, 5147, 3, 'Ofrecer a los pacientes el acceso oportuno a su información electrónica de salud (incluyendo resultados de laboratorio, lista de problemas, listas de medicamentos, alergias a medicamentos) dentro de cuatro días hábiles de que la información esté disponible para el EP.'),
(7072, 5148, 3, 'Proporcionar Registros de Paciente por Visita'),
(7073, 5149, 3, 'Proporcionar email válido'),
(7074, 5150, 3, '¿Resumen médico proporcionado?'),
(7075, 5151, 3, '¿Recusros educativos proporcionados?'),
(7076, 5152, 3, 'Facultativo'),
(7077, 5154, 3, 'Facultativo ID'),
(7078, 5155, 3, 'Facultativo ID en el centro especificado'),
(7079, 5156, 3, 'Errores de correspondencia de Proveedor'),
(7080, 5159, 3, 'Número de Proveedor'),
(7081, 5162, 3, 'Facultativo:'),
(7082, 5163, 3, 'Facultativos'),
(7083, 5164, 3, 'NPI Facultativos'),
(7084, 5165, 3, 'Proveedores Ver calendario completo'),
(7085, 5166, 3, 'Prv'),
(7086, 5167, 3, 'PSA'),
(7087, 5168, 3, 'Psoriasis'),
(7088, 5169, 3, 'Psiqu. Diagnóstico'),
(7089, 5170, 3, 'Psych Medicamentos'),
(7090, 5171, 3, 'Psiquiátricos'),
(7091, 5172, 3, 'Breve carta Psiquiátrica'),
(7092, 5173, 3, 'Diagnóstico psiquiátrico'),
(7093, 5174, 3, 'Examinación psiquiátrica'),
(7094, 5175, 3, 'Historia Psiquiátrica'),
(7095, 5176, 3, 'Producto Psiquiátrico'),
(7096, 5177, 3, 'Medicación Psiquiátrica'),
(7097, 5178, 3, 'Pt %'),
(7098, 5179, 3, 'Notas Paciente'),
(7099, 5180, 3, 'Notas/Autorización PAciente'),
(7100, 5181, 3, 'Pt en exceso'),
(7101, 5182, 3, 'Pt Pagado'),
(7102, 5183, 3, 'Solicitud Registro Pacienten'),
(7103, 5184, 3, 'Pt Reembolso'),
(7104, 5185, 3, 'Pt liberados'),
(7105, 5186, 3, 'Informe Paciente'),
(7106, 5187, 3, 'PT Estudiante, o dejar en blanco'),
(7107, 5188, 3, 'PT_CITY'),
(7108, 5189, 3, 'PT_DOB'),
(7109, 5191, 3, 'PT_FNAME');
INSERT INTO `lang_definitions` VALUES
(7110, 5192, 3, 'PT_LNAME'),
(7111, 5193, 3, 'PT_MNAME'),
(7112, 5196, 3, 'PT_POSTAL'),
(7113, 5198, 3, 'PT_STATE'),
(7114, 5199, 3, 'PT_STREET'),
(7115, 5201, 3, 'Público'),
(7116, 5203, 3, 'Seguridad Social (SS) u otro organismo oficial'),
(7117, 5204, 3, 'Puertorriqueño'),
(7118, 5205, 3, 'Pulmonar'),
(7119, 5206, 3, 'Pulso'),
(7120, 5207, 3, 'Penyabí'),
(7121, 5208, 3, 'Comprar'),
(7122, 5209, 3, 'Compra/Devolución'),
(7123, 5210, 3, 'Adquisiciones'),
(7124, 5213, 3, 'q.3h'),
(7125, 5214, 3, 'q.4h'),
(7126, 5215, 3, 'q.5h'),
(7127, 5216, 3, 'q.6h'),
(7128, 5217, 3, 'q.8h'),
(7129, 5218, 3, 'q.d.'),
(7130, 5219, 3, 'q.i.d.'),
(7131, 5220, 3, 'QOH'),
(7132, 5221, 3, 'QOH es menor que el consumo mensual'),
(7133, 5222, 3, 'Cantidad'),
(7134, 5223, 3, 'Cantidad'),
(7135, 5224, 3, 'Calidad'),
(7136, 5225, 3, 'Medidas de calidad (GCC)'),
(7137, 5226, 3, 'Cantidad'),
(7138, 5227, 3, 'Cantidad para NDC'),
(7139, 5228, 3, 'Cantidad En Mano'),
(7140, 5229, 3, 'cantidad parece inservible'),
(7141, 5231, 3, 'interrogante'),
(7142, 5232, 3, 'HCFA cola de proceso batch'),
(7143, 5233, 3, 'HCFA cola de proceso batch y de impresión'),
(7144, 5234, 3, 'Cola de la UB-92 del proceso batch'),
(7145, 5235, 3, 'Cola de la UB-92 del proceso batch y de impresión'),
(7146, 5236, 3, 'Cola'),
(7147, 5237, 3, 'Administración de Eventos en cola'),
(7148, 5238, 3, 'Cola para'),
(7149, 5240, 3, 'Cola de Peticiones Administración'),
(7150, 5241, 3, 'Dejar'),
(7151, 5242, 3, 'Dejar el alcohol'),
(7152, 5243, 3, 'R'),
(7153, 5245, 3, 'Raza'),
(7154, 5246, 3, 'Raza y Etnia'),
(7155, 5247, 3, 'Raza/etnia'),
(7156, 5248, 3, 'Radio'),
(7157, 5249, 3, 'Botones de radio'),
(7158, 5251, 3, 'Rango'),
(7159, 5252, 3, 'Erupciones'),
(7160, 5253, 3, 'Tasa'),
(7161, 5254, 3, 'Proporcion'),
(7162, 5255, 3, 'Informe sin procesar'),
(7163, 5256, 3, 'Re-Identificación'),
(7164, 5257, 3, 'Proceso Re-Identificación completado'),
(7165, 5258, 3, 'Proceso Re identificación en curso'),
(7166, 5259, 3, 'Ficheros de Re-identificación serán salvados en'),
(7167, 5260, 3, '¿Misma lesión?'),
(7168, 5261, 3, 'Abra de nuevo'),
(7169, 5262, 3, 'Volvió a abrir'),
(7170, 5263, 3, 'Reacción'),
(7171, 5264, 3, 'reacciones'),
(7172, 5265, 3, 'Leído'),
(7173, 5268, 3, 'Nombre Real'),
(7174, 5269, 3, 'Realmente borrado'),
(7175, 5270, 3, 'Razón'),
(7176, 5271, 3, 'Motivo del fallecimiento'),
(7177, 5272, 3, 'Motivo de la Muerte'),
(7178, 5274, 3, 'Motivo de la derivación'),
(7179, 5275, 3, 'Motivo de la Visita'),
(7180, 5276, 3, 'Motivo/Forma'),
(7181, 5277, 3, 'Recibo'),
(7182, 5278, 3, 'Recibo de Pago'),
(7183, 5279, 3, 'Recibo de Creación'),
(7184, 5280, 3, 'Recibos de pago por Informe'),
(7185, 5281, 3, 'Resumen del Recibo'),
(7186, 5282, 3, 'Recibido'),
(7187, 5283, 3, 'Recibido Por'),
(7188, 5284, 3, 'Recibido faxes'),
(7189, 5287, 3, 'Receptor'),
(7190, 5288, 3, 'Nº Identificación del destinatario'),
(7191, 5289, 3, 'Recibidor ID (ISA08)'),
(7192, 5290, 3, 'Calificador del recibidor ID (ISA07)'),
(7193, 5292, 3, 'Las últimas tres contraseñas no están permitidas.'),
(7194, 5293, 3, 'Beneficiario'),
(7195, 5294, 3, 'Lista de Beneficiarios vacía'),
(7196, 5295, 3, 'Nombre destinatario'),
(7197, 5296, 3, 'Destinatario de la publicación'),
(7198, 5298, 3, 'Recomendación'),
(7199, 5300, 3, 'Recomendaciones'),
(7200, 5301, 3, 'Recomendaciones y el tratamiento'),
(7201, 5302, 3, 'Recomendaciones del especialista'),
(7202, 5303, 3, 'Registro'),
(7203, 5304, 3, 'Registro ya existe'),
(7204, 5310, 3, 'Registro y gráfico de los cambios en las constantes vitales.'),
(7205, 5311, 3, 'Registro demográficos.'),
(7206, 5312, 3, 'Grabar aviso'),
(7207, 5313, 3, 'Registro de estado físico'),
(7208, 5314, 3, 'Pago de Registro'),
(7209, 5315, 3, 'Fecha registro de solicitud'),
(7210, 5316, 3, 'Registro estado pacientes fumadores de 13 años o más'),
(7211, 5317, 3, 'Registros'),
(7212, 5318, 3, 'registros encontrados'),
(7213, 5319, 3, 'registros encontrados.'),
(7214, 5320, 3, 'Uso de drogas no farmacológicas'),
(7215, 5321, 3, 'Drogas no farmacológicas'),
(7216, 5322, 3, 'Rectal'),
(7217, 5323, 3, 'Examen Rectal'),
(7218, 5324, 3, 'Rectal'),
(7219, 5325, 3, 'Redirección'),
(7220, 5326, 3, 'Enrojecimiento'),
(7221, 5327, 3, 'Reducido:'),
(7222, 5328, 3, 'Referir'),
(7223, 5329, 3, 'Referir Por'),
(7224, 5330, 3, 'Referir Fecha'),
(7225, 5331, 3, 'Referir Para'),
(7226, 5332, 3, 'Clasificación de referencia (nivel de riesgo)'),
(7227, 5333, 3, 'Referencia de rango de resultados'),
(7228, 5334, 3, 'Motivo de referencia'),
(7229, 5336, 3, 'Referer nombre y la firma'),
(7230, 5337, 3, 'Derivación'),
(7231, 5338, 3, 'Derivado Por'),
(7232, 5339, 3, 'Tarjeta de derivado'),
(7233, 5340, 3, 'Fecha de derivación'),
(7234, 5341, 3, 'Formulario de derivación'),
(7235, 5342, 3, 'FORMULARIO DE DERIVACIÓN'),
(7236, 5343, 3, 'Nº ID derivación'),
(7237, 5345, 3, 'Origen derivación'),
(7238, 5346, 3, 'Origen derivación para visitas'),
(7239, 5347, 3, 'Derivado a'),
(7240, 5348, 3, 'Derivados'),
(7241, 5349, 3, 'Informes de Derivados'),
(7242, 5350, 3, 'Derivado por'),
(7243, 5351, 3, 'Referido Por'),
(7244, 5352, 3, 'Referido a'),
(7245, 5353, 3, 'Referencia'),
(7246, 5355, 3, 'Diagnóstico de Referencia'),
(7247, 5356, 3, 'Diagnóstico de referencia'),
(7248, 5357, 3, 'Fisio de referencia y centro'),
(7249, 5358, 3, 'Facultativo de referencia'),
(7250, 5359, 3, 'Recargar'),
(7251, 5360, 3, 'Repuesto'),
(7252, 5361, 3, 'repuestos'),
(7253, 5362, 3, 'Reflejos normales'),
(7254, 5363, 3, 'Refrescar'),
(7255, 5365, 3, 'Refrescando avisos'),
(7256, 5368, 3, 'Se negó a declarar'),
(7257, 5369, 3, 'reg_re'),
(7258, 5370, 3, 'Registrar'),
(7259, 5372, 3, 'Registrado'),
(7260, 5373, 3, 'registrado'),
(7261, 5375, 3, 'Fecha de Registro'),
(7262, 5376, 3, 'Formulario de Inscripción'),
(7263, 5377, 3, 'Rehabilitación'),
(7264, 5381, 3, 'Relaciónese Con'),
(7265, 5382, 3, 'Relacionado'),
(7266, 5383, 3, 'Incidencia relacionada'),
(7267, 5385, 3, 'Relacion(es)/niños'),
(7268, 5386, 3, 'Relaciones'),
(7269, 5387, 3, 'Relación'),
(7270, 5388, 3, 'Orden relativo de esta entidad'),
(7271, 5389, 3, 'Familiares'),
(7272, 5399, 3, 'Las credenciales de la salud del relais faltan de esta cuenta de usuario.'),
(7273, 5400, 3, 'Relay Health ID'),
(7274, 5402, 3, 'Fecha versión'),
(7275, 5403, 3, 'Religión'),
(7276, 5406, 3, 'Reinicie sesión'),
(7277, 5407, 3, 'Aviso'),
(7278, 5408, 3, 'Recordar Centro Seleccionado'),
(7279, 5409, 3, 'Recordatorio'),
(7280, 5410, 3, 'Intervalos recordatorio'),
(7281, 5411, 3, 'Recordatorio No Enviado Todavía'),
(7282, 5412, 3, 'Recordatorio Enviado El'),
(7283, 5413, 3, 'Avisos'),
(7284, 5414, 3, 'REMITIR A'),
(7285, 5416, 3, 'Quitar'),
(7286, 5419, 3, 'Eliminar Grupo'),
(7287, 5420, 3, 'Eliminar el formulario del grupo'),
(7288, 5421, 3, 'Eliminar soporte para las vacunas'),
(7289, 5422, 3, 'Eliminar soporte para phpMyAdmin'),
(7290, 5423, 3, 'Eliminar soporte para prescripciones'),
(7291, 5425, 3, 'Elimina la función del gráfico de seguimiento'),
(7292, 5426, 3, 'Litiasis Renal'),
(7293, 5427, 3, 'Renombrar'),
(7294, 5428, 3, 'Renombrar Grupo'),
(7295, 5429, 3, 'Representación'),
(7296, 5430, 3, 'Representación del Facultativo'),
(7297, 5431, 3, 'Número Representación del Facultativo'),
(7298, 5432, 3, 'Reordenar'),
(7299, 5433, 3, 'Al reordenar'),
(7300, 5434, 3, 'Alcanzado el punto de pedido'),
(7301, 5435, 3, 'Punto de pedido, 0 no es válido'),
(7302, 5438, 3, 'Repetición eventos'),
(7303, 5439, 3, 'Repetir Información:'),
(7304, 5440, 3, 'Repite'),
(7305, 5444, 3, 'Fecha de Respuesta'),
(7306, 5445, 3, 'De respuesta'),
(7307, 5446, 3, 'Informe'),
(7308, 5447, 3, 'Informe Clínico'),
(7309, 5449, 3, 'Informe por'),
(7310, 5457, 3, 'Reporte de estatus'),
(7311, 5458, 3, 'Informe Totales'),
(7312, 5459, 3, 'Informe/Formulario'),
(7313, 5460, 3, 'Informable'),
(7314, 5461, 3, 'Reportado'),
(7315, 5462, 3, 'Fecha Informada'),
(7316, 5463, 3, 'Informes'),
(7317, 5467, 3, '¡Solicitud ignorada - proceso de reclamaciones ya se está ejecutando!'),
(7318, 5474, 3, 'Servicio Solicitado'),
(7319, 5475, 3, 'Se requiere Contraseña más compleja'),
(7320, 5476, 3, 'Se requiere Contraseña única'),
(7321, 5477, 3, 'Requerido'),
(7322, 5478, 3, 'Copago requerido'),
(7323, 5479, 3, 'Falta campo requerido:Por favor elija el fichero EDI-271 para adjuntar'),
(7324, 5480, 3, 'Falta campo requerido: Por favor introduzca el nombre'),
(7325, 5481, 3, 'Falta campo requerido: Por favor introduzca el apellido'),
(7326, 5482, 3, 'Falta campo requerido: Por favor introduzca el nombre de usuario'),
(7327, 5483, 3, 'Campos requeridos'),
(7328, 5484, 3, 'Requerimientos'),
(7329, 5485, 3, 'RESERVADO'),
(7330, 5486, 3, 'Reservado'),
(7331, 5487, 3, 'Reservado para uso del Tiempo Programado de Vacaciones'),
(7332, 5488, 3, 'Reservado para definir cuando un facultativo no podrá tener citas disponibles posteriores.'),
(7333, 5489, 3, 'Reservado para definir cuando un evento no ocurrió como se especificó.'),
(7334, 5490, 3, 'Reservados para definir cuando un facultativo puede tener citas disponibles posteriores.'),
(7335, 5491, 3, 'Reinicio'),
(7336, 5492, 3, 'Resetear credenciales del Portal externo'),
(7337, 5493, 3, 'Resetear credenciales del Portal interno'),
(7338, 5496, 3, 'Resuelto'),
(7339, 5497, 3, 'Respiración'),
(7340, 5498, 3, 'Esfuerzo al Respirar'),
(7341, 5499, 3, 'Respiratorias'),
(7342, 5501, 3, 'Restringir a usuarios no autorizados el calendario de la clínica establecido en usuario admin.'),
(7343, 5502, 3, 'Restringir usuarios a Clínicas'),
(7344, 5503, 3, 'Entrenamiento Restringido'),
(7345, 5504, 3, 'Resultado'),
(7346, 5506, 3, 'Estado del resultado'),
(7347, 5507, 3, 'Estado del resultado o anormalidad ausente'),
(7348, 5508, 3, 'Resultado, use % como comodín'),
(7349, 5510, 3, 'Resultados y'),
(7350, 5511, 3, 'Resultados Encontrados para la Búsqueda'),
(7351, 5512, 3, 'Grupo Resultados'),
(7352, 5515, 3, 'Resultados por página'),
(7353, 5516, 3, 'Resultados / Detalles'),
(7354, 5517, 3, 'Examen de Retina'),
(7355, 5518, 3, 'Se retractó de la derecha:'),
(7356, 5519, 3, 'Volver'),
(7357, 5520, 3, 'Retorne la parte superior con su pago'),
(7358, 5521, 3, 'Retornar al calendario'),
(7359, 5523, 3, 'Vuelva a esta página y podrá completar el proceso de instalación ICD 10 haciendo click en la sección de la cabecera ICD 10'),
(7360, 5524, 3, 'Vuelva a esta página y podrá completar el proceso de instalación ICD 9 haciendo click en la sección de la cabecera ICD 9'),
(7361, 5525, 3, 'Vuelva a esta página y podrá completar el proceso de instalación RxNorm haciendo click en la sección de la cabecera RXNORM'),
(7362, 5526, 3, 'Vuelva a esta página y podrá completar el proceso de instalación Snomed haciendo click en la sección de la cabecera SNOMED'),
(7363, 5527, 3, 'Valor Devuelto'),
(7364, 5528, 3, 'Visita de Vuelta'),
(7365, 5529, 3, 'Volvió a jugar'),
(7366, 5534, 3, 'Examen de PMH:'),
(7367, 5535, 3, 'Revisión de los sistemas'),
(7368, 5536, 3, 'Revisión de chequeos de sistemas'),
(7369, 5537, 3, 'Revisado'),
(7370, 5538, 3, 'Revisión'),
(7371, 5539, 3, 'Artritis reumatoide'),
(7372, 5540, 3, 'Artritis reumatoide'),
(7373, 5541, 3, 'Derecho'),
(7374, 5542, 3, 'Oido Derecho'),
(7375, 5543, 3, 'oido derecho'),
(7376, 5545, 3, 'Derecho:'),
(7377, 5546, 3, 'Zumbido en Oídos'),
(7378, 5547, 3, 'Sonido en Oídos'),
(7379, 5549, 3, 'Factores Riesgo'),
(7380, 5550, 3, 'Nivel de Riesgo'),
(7381, 5551, 3, 'RLL:'),
(7382, 5552, 3, 'ROM'),
(7383, 5553, 3, 'Rumano'),
(7384, 5560, 3, 'Lista'),
(7385, 5561, 3, 'Ruta'),
(7386, 5562, 3, 'Ruta de administracion si aplicable'),
(7387, 5563, 3, 'Encaminado'),
(7388, 5564, 3, 'Filas'),
(7389, 5565, 3, 'RRR sin MOR'),
(7390, 5566, 3, 'Frotar'),
(7391, 5567, 3, 'Frotaciones:'),
(7392, 5568, 3, 'Regla'),
(7393, 5569, 3, 'Añadir regla'),
(7394, 5570, 3, 'Detalle Regla'),
(7395, 5572, 3, 'Editar Regla'),
(7396, 5575, 3, 'Ajuste Regla'),
(7397, 5578, 3, 'Reglas'),
(7398, 5580, 3, 'Configuración Regla'),
(7399, 5581, 3, 'Ejecutando comando '),
(7400, 5582, 3, 'ruptura'),
(7401, 5583, 3, 'Ruso'),
(7402, 5584, 3, 'Receta'),
(7403, 5585, 3, 'Receta'),
(7404, 5586, 3, 'Margen inferior Receta (px)'),
(7405, 5587, 3, 'Receta Activa DEA#'),
(7406, 5588, 3, 'Receta Activa NPI'),
(7407, 5589, 3, 'Receta Activa Estado Lic.#'),
(7408, 5590, 3, 'Margen izquierdo Receta (px)'),
(7409, 5591, 3, 'Tamaño papel Receta'),
(7410, 5592, 3, 'Margen derecho Receta (px)'),
(7411, 5593, 3, 'Mostrar Receta DEA#'),
(7412, 5594, 3, 'Mostrar Receta NPI'),
(7413, 5595, 3, 'Mostrar Receta Estado Lic.#'),
(7414, 5596, 3, 'Margen superior Receta (px)'),
(7415, 5598, 3, 'Receta Normal (RxNorm)'),
(7416, 5599, 3, 'Base de datos RxNorm'),
(7417, 5600, 3, 'S'),
(7418, 5601, 3, 'S.S.'),
(7419, 5602, 3, 'S3:'),
(7420, 5603, 3, 'S4:'),
(7421, 5604, 3, 'SA ** para leer la licencia por favor lea la documentos/licencia.texto o visite * http://www.gnu.org/copyleft/gpl.html * * / / / '),
(7422, 5605, 3, 'Venta'),
(7423, 5606, 3, 'Ventas'),
(7424, 5607, 3, 'Ventas por Partida'),
(7425, 5608, 3, 'Informe de ventas por producto'),
(7426, 5609, 3, 'Saliva'),
(7427, 5610, 3, 'Mismo Día'),
(7428, 5611, 3, 'Samoano'),
(7429, 5612, 3, 'Muestra'),
(7430, 5613, 3, 'Tipo de sanción'),
(7431, 5617, 3, 'Sabado'),
(7432, 5618, 3, 'Sábado y Domingo'),
(7433, 5619, 3, 'Sabado'),
(7434, 5620, 3, 'Guardar'),
(7435, 5621, 3, 'SALVAR'),
(7436, 5622, 3, 'Guardar y Cerrar'),
(7437, 5624, 3, 'Guardar y Distribuir'),
(7438, 5626, 3, 'Guradar como Nuevo'),
(7439, 5627, 3, 'Guarda como nota nueva'),
(7440, 5628, 3, 'Guardar configuración del certificado'),
(7441, 5629, 3, 'Guardar Cambios'),
(7442, 5630, 3, 'Guardar Formulario'),
(7443, 5631, 3, 'Guardar Vacunación'),
(7444, 5632, 3, 'Guardar Nuevo Campo'),
(7445, 5633, 3, 'Guardar Nuevo Grupo'),
(7446, 5634, 3, 'Guardar Nueva Lista'),
(7447, 5635, 3, 'Guardar la nueva plantilla'),
(7448, 5637, 3, 'Guardar Demograficas de Paciente'),
(7449, 5638, 3, 'Nº Identificación gráfico guardado correctamente'),
(7450, 5639, 3, 'Guardar ITransacción'),
(7451, 5641, 3, 'Escaneados'),
(7452, 5642, 3, 'Nota Escaneada de visita'),
(7453, 5643, 3, 'Directorio del escáner'),
(7454, 5644, 3, 'Escáner En'),
(7455, 5645, 3, 'Horario'),
(7456, 5646, 3, 'Calendario de Clínicas:'),
(7457, 5647, 3, 'Nota Escolar'),
(7458, 5648, 3, 'Escoliosis'),
(7459, 5651, 3, 'SE'),
(7460, 5652, 3, 'SE Dirección'),
(7461, 5653, 3, 'SE Ciudad'),
(7462, 5654, 3, 'SE Pais'),
(7463, 5655, 3, 'SE Localidad'),
(7464, 5656, 3, 'SE Código Postal'),
(7465, 5657, 3, 'SE Estado'),
(7466, 5658, 3, 'SE Código Postal'),
(7467, 5659, 3, 'Buscar'),
(7468, 5661, 3, 'Buscar'),
(7469, 5662, 3, 'Búsqar Nuevamente'),
(7470, 5663, 3, 'Buscar en todas las columnas'),
(7471, 5664, 3, 'Búscar por:'),
(7472, 5665, 3, 'Buscar por'),
(7473, 5666, 3, 'Búscar para:'),
(7474, 5668, 3, 'Buscar en'),
(7475, 5669, 3, 'Buscar o Añadir Paciente'),
(7476, 5670, 3, 'Buscar Pago'),
(7477, 5671, 3, 'Resultados de búsqueda'),
(7478, 5672, 3, 'Resultados de la Búsqueda:'),
(7479, 5673, 3, 'Buscar seleccionados'),
(7480, 5674, 3, 'Cadena buscada no coincide con la lista de la base de datos'),
(7481, 5675, 3, 'Cadena buscada debe tener al menos tres caracteres'),
(7482, 5676, 3, 'Buscar Texto'),
(7483, 5677, 3, 'Búsqueda de eventos'),
(7484, 5678, 3, 'Buscar/añadir'),
(7485, 5679, 3, 'Buscar/Añadir Asegurador'),
(7486, 5680, 3, 'Buscando las citas'),
(7487, 5681, 3, 'Buscando'),
(7488, 5682, 3, 'Uso de cinturón de seguridad'),
(7489, 5683, 3, 'Uso de cinturón de seguridad'),
(7490, 5684, 3, 'Segundo'),
(7491, 5687, 3, 'Secundario'),
(7492, 5688, 3, 'Seguro Secundario'),
(7493, 5689, 3, 'Datos de Seguro Secundario'),
(7494, 5690, 3, 'Proveedor del Seguro Secundario'),
(7495, 5691, 3, 'Tipo secundario de Medicare'),
(7496, 5698, 3, 'Seguridad'),
(7497, 5699, 3, 'Ver Todo'),
(7498, 5700, 3, 'Ver Autorizaciones'),
(7499, 5701, 3, 'Véase el Gráfico de Crecimiento'),
(7500, 5702, 3, 'Ver los mensajes de la última serie de reclamaciones generadas'),
(7501, 5704, 3, 'Visto en'),
(7502, 5707, 3, 'Convulsiones'),
(7503, 5708, 3, 'Seleción'),
(7504, 5709, 3, 'Seleción'),
(7505, 5710, 3, 'seleccionar'),
(7506, 5712, 3, 'Seleccionar un contexto'),
(7507, 5714, 3, 'Seleccione un intervalo de tiempo'),
(7508, 5715, 3, 'Seleccionar un usuario'),
(7509, 5716, 3, 'Seleccionar Todos'),
(7511, 5720, 3, 'Seleccionar una categoría'),
(7512, 5722, 3, 'Seleccionar las casillas correspondientes para borrar'),
(7513, 5723, 3, 'Seleccionar el criterio para eliminar'),
(7514, 5725, 3, 'Seleccione datos requeridos para De Identificación'),
(7515, 5726, 3, 'Seleccione datos para incluir en los datos de De Identificación'),
(7516, 5727, 3, 'Elegir fecha'),
(7517, 5728, 3, 'Seleccione plantilla deseada'),
(7518, 5729, 3, 'Seleccione diagnóstico'),
(7519, 5730, 3, 'Seleccione diagnóstico para identificación DE requerida'),
(7520, 5731, 3, 'Seleccione Medicamento'),
(7521, 5732, 3, 'Seleccione Medicamentos'),
(7522, 5733, 3, 'Seleccione los medicamentos para la solicitud anónima'),
(7523, 5734, 3, 'Seleccione fichero EDI-271'),
(7524, 5735, 3, 'Seleccione encuentro'),
(7525, 5736, 3, 'Elegir campo'),
(7526, 5737, 3, 'Seleccione Sector'),
(7527, 5738, 3, 'Seleccionar para Imprimir'),
(7528, 5739, 3, 'Seleccione vacunas'),
(7529, 5740, 3, 'Seleccione las vacunas para la solicitud anónima'),
(7530, 5741, 3, 'Seleccionar Seguro, escribiendo'),
(7531, 5742, 3, 'Seleccione Incidencia'),
(7532, 5743, 3, 'Seleccione items'),
(7533, 5744, 3, 'Seleccionar idioma'),
(7534, 5745, 3, 'Seleccione uno'),
(7535, 5746, 3, 'Seleccione uno o más códigos de diagnóstico para justificar el servicio'),
(7536, 5747, 3, 'Seleccione uno o más archivos para subir'),
(7537, 5748, 3, 'Seleccione salida'),
(7538, 5750, 3, 'Seleccione origen del pedido'),
(7539, 5754, 3, 'Elija los items de configuración para exportar'),
(7540, 5755, 3, 'Elija la incidencia principal responsable para los eventos fallidos en este día'),
(7541, 5757, 3, 'Seleccione pista'),
(7542, 5759, 3, 'Seleccionar usuario'),
(7543, 5760, 3, 'Seleccionar usuarios de la lista desplegable'),
(7544, 5761, 3, 'Seleccionar que idiomas, si los hay, pueden ser elegidos al inicio de sesión. (solo si arriba todos los idiomas permitidos está desactivados)'),
(7545, 5762, 3, 'Seleccione Sí para confirmar la eliminación del grupo'),
(7546, 5765, 3, 'Seleccionado'),
(7547, 5766, 3, 'Visita seleccionada'),
(7548, 5767, 3, 'Seleccionando ésto se creará un mensaje que necesita ser procesado por cada receptor individualmente (ésto no es una tarea de grupo)'),
(7549, 5768, 3, 'Uno Mismo'),
(7550, 5769, 3, 'Paga del uno mismo'),
(7551, 5771, 3, 'Enviar'),
(7552, 5772, 3, 'Enviar Fecha aviso'),
(7553, 5773, 3, 'Enviar un Recordatorio'),
(7554, 5774, 3, 'Envíe en curso'),
(7555, 5775, 3, 'enviar mensaje'),
(7556, 5776, 3, 'Batch de Envío de Recordatorios'),
(7557, 5777, 3, 'Enviar recordatorios a pacientes por preferencia para preventiva/seguimiento de cuidados.'),
(7558, 5778, 3, 'Enviar resúmenes con derivados'),
(7559, 5779, 3, 'Enviar este file'),
(7560, 5780, 3, 'Enviar este mensaje'),
(7561, 5781, 3, 'Enviar a'),
(7562, 5784, 3, 'Enviar a todos'),
(7563, 5786, 3, 'Enviar al portal'),
(7564, 5787, 3, 'Enviar al portal'),
(7565, 5788, 3, 'Remitente'),
(7566, 5789, 3, 'Nº Identificación del remitente'),
(7567, 5790, 3, 'Remitente ID (ISA06)'),
(7568, 5791, 3, 'Calificador del remitente ID (ISA05)'),
(7569, 5794, 3, 'Sensibilidades'),
(7570, 5795, 3, 'Sensibilidad:'),
(7571, 5796, 3, 'Examen sensorial normal'),
(7572, 5797, 3, 'Enviado'),
(7573, 5798, 3, 'Enviado - Confirmado'),
(7574, 5799, 3, 'Enviado por, dejar en blanco para todos'),
(7575, 5800, 3, 'Enviado por:'),
(7576, 5801, 3, 'Fecha de envio'),
(7577, 5802, 3, 'Incidencias Enviadas'),
(7578, 5803, 3, '¿Enviar Registros Médicos?'),
(7579, 5804, 3, 'Enviado con éxito'),
(7580, 5807, 3, 'Enviado a Impresora'),
(7581, 5808, 3, 'Enviado a, dejar en blanco para todos'),
(7582, 5812, 3, 'Sep'),
(7583, 5813, 3, 'Separado'),
(7584, 5814, 3, 'Septiembre'),
(7585, 5816, 3, 'Secuencia'),
(7586, 5821, 3, 'Servicio'),
(7587, 5822, 3, 'Categoría de Servicio'),
(7588, 5823, 3, 'Código Servicio'),
(7589, 5824, 3, 'Informe de códigos de servicio Financiero'),
(7590, 5825, 3, 'Códigos Servicio'),
(7591, 5826, 3, 'Fecha de Servicio'),
(7592, 5827, 3, 'Fecha de Servicio:'),
(7593, 5829, 3, 'Servicio de Localización'),
(7594, 5831, 3, 'Servicio prestado por el especialista'),
(7595, 5832, 3, 'Informe de servicio'),
(7596, 5833, 3, 'Informe de servicio sólo'),
(7597, 5834, 3, 'Servicios'),
(7598, 5835, 3, 'Servicios por Categoría'),
(7599, 5836, 3, 'Servicios prestados'),
(7600, 5837, 3, 'Servicios proporcionados'),
(7601, 5838, 3, 'Servicios/Productos'),
(7602, 5839, 3, 'Tipo Sesión'),
(7603, 5840, 3, 'Set'),
(7604, 5841, 3, 'Habilitar cookie para recordar el centro seleccionado entre sesiones.'),
(7605, 5842, 3, 'Definir como terminado'),
(7606, 5845, 3, 'Asignar este para la ruta absoluta. Para crear certificados clientes SSL para HTTPPS.'),
(7607, 5846, 3, 'Ajustar a'),
(7608, 5847, 3, 'Ajustar por defecto'),
(7609, 5848, 3, 'Ajustar el número de versión en la base de datos...'),
(7610, 5849, 3, 'Ajustes'),
(7611, 5851, 3, 'Migraña Grave'),
(7612, 5853, 3, 'Severidad del dolor'),
(7613, 5854, 3, 'Severidad del dolor'),
(7614, 5855, 3, 'Sexo'),
(7615, 5856, 3, 'Enfermedades de Transmisión Sexual'),
(7616, 5859, 3, 'Conpartir'),
(7617, 5860, 3, 'Intérprete de comandos para imprimir desde el servidor'),
(7618, 5864, 3, 'Falta de aire al respirar'),
(7619, 5865, 3, 'Falta de Aliento'),
(7620, 5866, 3, 'Falta de Aliento 2'),
(7621, 5867, 3, 'Registro de Tiro'),
(7622, 5868, 3, 'Fecha de Expediente de Tiro:'),
(7623, 5870, 3, 'debe ser como nnnnn-nnnn-nn'),
(7624, 5871, 3, 'Deben ser dos letras'),
(7625, 5872, 3, 'Debe contener 10 dígitos'),
(7626, 5873, 3, 'Debe contener sólo 10 dígitos'),
(7627, 5874, 3, 'Hombro'),
(7628, 5875, 3, 'Hombro + Clavicula'),
(7629, 5876, 3, 'Prob. de Hombro'),
(7630, 5877, 3, 'Presente'),
(7631, 5878, 3, 'Mostar Activo'),
(7632, 5880, 3, 'Mostrar Todo'),
(7633, 5883, 3, 'Mostrar Todas las Transacciones'),
(7634, 5884, 3, 'Occupado'),
(7635, 5885, 3, 'Mostrar Sólo Autorizado'),
(7636, 5886, 3, 'Mostrar Horas Disponibles'),
(7637, 5887, 3, 'Mostrar ambos US y métrica (unidad principal es métrica)'),
(7638, 5888, 3, 'Mostrar ambos US y métrica (unidad principal es US)'),
(7639, 5889, 3, 'Mostrar Detalles'),
(7640, 5891, 3, 'Mostrar Gráfico'),
(7641, 5892, 3, '¿Demuestre el texto de cernido del acontecimiento en mouseover?'),
(7642, 5893, 3, 'Mostrar el número de eventos en las páginas de administrador?'),
(7643, 5894, 3, 'Mostrar Inactivo'),
(7644, 5896, 3, 'Mostrar Menú'),
(7645, 5897, 3, 'Mostrar sólo métrica'),
(7646, 5898, 3, 'Cuantos eventos mostrar en paginas de admin'),
(7647, 5901, 3, 'Mostrar notas de pacientes'),
(7648, 5904, 3, 'Mostrar primario completo'),
(7649, 5905, 3, 'Mostrar avisos'),
(7650, 5906, 3, 'Mostrar Informe'),
(7651, 5907, 3, 'Mostrar enlace búsqueda/aceptar en bloque?'),
(7652, 5910, 3, 'Mostrar el formulario de estado personalizado para agregar a lista de widget (preguntará por el título y la abreviatura).'),
(7653, 5913, 3, 'Mostrar sólo no facturados'),
(7654, 5914, 3, 'Mostrar solo USA'),
(7655, 5915, 3, 'Mostrando'),
(7656, 5920, 3, 'Hermanos'),
(7657, 5921, 3, 'Célula de hoz (falciforme)'),
(7658, 5922, 3, 'Sig'),
(7659, 5923, 3, 'Sigmoide/Colonoscopia'),
(7660, 5925, 3, 'Firma resultados laboratorio (escribir, opcional sólo añadir)'),
(7661, 5926, 3, 'Firmar Resultados'),
(7662, 5927, 3, 'Firma'),
(7663, 5929, 3, 'Firma:'),
(7664, 5930, 3, 'Receta firmada'),
(7665, 5932, 3, 'Hinchazón Significativa:'),
(7666, 5934, 3, 'Co-Pago Simplificado'),
(7667, 5935, 3, 'Demográficos Simplificados'),
(7668, 5936, 3, 'Prescripciones Simplificadas'),
(7669, 5937, 3, 'Desde'),
(7670, 5938, 3, 'Sinceramente,'),
(7671, 5940, 3, 'Soltero'),
(7672, 5941, 3, 'Lista selección única'),
(7673, 5942, 3, 'Lista de selección única con posibilidad de añadir a la lista'),
(7674, 5946, 3, 'Problemas del Seno'),
(7675, 5947, 3, 'Cirugía de Seno'),
(7676, 5948, 3, 'SENSIBILIDAD DE SENO:'),
(7677, 5949, 3, 'Sinusitis'),
(7678, 5951, 3, 'Nº Identificación'),
(7679, 5953, 3, 'Nº Identificación para soporte LibreEHR del Servicio Intercambio Laboratorio LLC.'),
(7680, 5956, 3, 'Tamaño'),
(7681, 5957, 3, 'El tamaño debe ser un número entre 1 y 999'),
(7682, 5958, 3, 'Tamaño/Lista'),
(7683, 5959, 3, 'Piel'),
(7684, 5960, 3, 'Cáncer de Piel'),
(7685, 5961, 3, 'Enfermedad de Piel'),
(7686, 5962, 3, 'Otra Piel'),
(7687, 5963, 3, 'Saltar autorización o Notas de paciente'),
(7688, 5964, 3, 'Saltar sección'),
(7689, 5965, 3, 'Saltarse SQL-Ledger dump - no se han aplicado para el servidor de Windows'),
(7690, 5967, 3, 'Patrones de Sueño'),
(7691, 5968, 3, 'Patrones de Sueño'),
(7692, 5969, 3, 'Durmiendo'),
(7693, 5970, 3, 'Eslovaco'),
(7694, 5972, 3, 'La deuda de SM sin'),
(7695, 5973, 3, 'Smarty caché ha sido borrada'),
(7696, 5974, 3, 'Fumador, estado actual desconocido'),
(7697, 5976, 3, 'Tabaquismo'),
(7698, 5977, 3, 'SMS Autorización'),
(7699, 5978, 3, 'Puerta de enlace SMS'),
(7700, 5979, 3, 'Clave API puerta enlace SMS'),
(7701, 5980, 3, 'Clave API puerta enlace SMS'),
(7702, 5981, 3, 'Contraseña puerta de enlace SMS'),
(7703, 5982, 3, 'Usuario puerta de enlace SMS'),
(7704, 5983, 3, 'Notificación de SMS'),
(7705, 5984, 3, 'Horario Notificación SMS'),
(7706, 5985, 3, 'SMS envían antes'),
(7707, 5986, 3, 'SMS Enviado'),
(7708, 5987, 3, 'SMS de texto, Etiqueta Utilizable: ***NOMBRE *** *** FACULTATIVO, *** *** FECHA *** *** HORA DE COMIENZO*** , *** HORA DE SALIDA *** *** <br> i.e. Estimado ***NOMBRE ***'),
(7709, 5988, 3, 'Ajustes Alerta SMS/email'),
(7710, 5989, 3, 'Contraseña para Autenticación SMTP'),
(7711, 5992, 3, 'SMTP Nombre servidor Host'),
(7712, 5993, 3, 'SMTP Puerto servidor'),
(7713, 5994, 3, 'SMTP Usuario para Autenticación'),
(7714, 5995, 3, 'SNOMED'),
(7715, 5997, 3, 'Diagnóstico SNOMED (RF1)'),
(7716, 5999, 3, 'Diagnóstico SNOMED (RF2)'),
(7717, 6001, 3, 'Base de datos SNOMED'),
(7718, 6002, 3, 'Diagnóstico SNOMED'),
(7719, 6004, 3, 'Ronquidos'),
(7720, 6005, 3, 'SOEP'),
(7721, 6006, 3, 'Dificultades Sociales'),
(7722, 6009, 3, 'Historia'),
(7723, 6010, 3, 'Número de Seguridad Social'),
(7724, 6011, 3, 'solución'),
(7725, 6013, 3, 'Contexto Somático'),
(7726, 6014, 3, 'Algunas autorizaciones no fueron exhibidas. Clic aquí para ver todas'),
(7727, 6015, 3, 'Algunos códigos no fueron exhibidos.'),
(7728, 6016, 3, 'Algunas visitas no fueron mostradas. Click aquí para ver todas.'),
(7729, 6017, 3, 'Se han producido algunos errores en el proceso de De Identificación'),
(7730, 6018, 3, 'Algunas notas no fueron mostradas.'),
(7731, 6020, 3, 'algunas palabras'),
(7732, 6023, 3, 'Algo salió mal. Por favor inténtelo de nuevo.'),
(7733, 6024, 3, 'Intervalo para Vencimiento Próximo (Avisos clínicos)'),
(7734, 6025, 3, 'Intervalo vencimiento próximo (Avisos paciente)'),
(7735, 6026, 3, 'Dolor de Garganta'),
(7736, 6027, 3, 'Lo siento no se ha fijado una cita'),
(7737, 6028, 3, 'Lo sentimos, hubo un problema subiendo su fichero'),
(7738, 6029, 3, 'Organizado por'),
(7739, 6030, 3, 'Orden por'),
(7740, 6031, 3, 'Organizar por checksum'),
(7741, 6032, 3, 'Ordenar por Comentarios'),
(7742, 6033, 3, 'Ordenar por usuario de Crt'),
(7743, 6034, 3, 'Ordenar por fecha'),
(7744, 6035, 3, 'Ordenar por fecha/hora'),
(7745, 6036, 3, 'Ordenar por Evento'),
(7746, 6037, 3, 'Ordenar por Grupo'),
(7747, 6040, 3, 'Ordenar por pacienteID'),
(7748, 6041, 3, 'ordenar por exito'),
(7749, 6043, 3, 'Ordenar por Usuario'),
(7750, 6044, 3, 'Ordenar por vacuna'),
(7751, 6045, 3, 'Orden descendente'),
(7752, 6046, 3, 'Ordenar resultado por'),
(7753, 6047, 3, 'Orden ascendente'),
(7754, 6048, 3, 'Fuente'),
(7755, 6049, 3, 'Fichero fuente'),
(7756, 6050, 3, 'Ruta fichero fuente'),
(7757, 6051, 3, 'Fuente falta de código '),
(7758, 6052, 3, 'Lote de fuente'),
(7759, 6057, 3, 'Fuente:'),
(7760, 6060, 3, 'Espacio'),
(7761, 6061, 3, 'ESPACIO'),
(7762, 6062, 3, 'Español'),
(7763, 6063, 3, 'Español (Latín América)'),
(7764, 6064, 3, 'Español (España)'),
(7765, 6068, 3, 'Especialista'),
(7766, 6069, 3, 'Nombre y firma del especialista'),
(7767, 6071, 3, 'Especialidad'),
(7768, 6072, 3, 'Sistemas de la especialidad'),
(7769, 6073, 3, 'Especialidad:'),
(7770, 6074, 3, 'Específico'),
(7771, 6075, 3, 'Aplicación específica'),
(7772, 6076, 3, 'Servicio específico anticonceptivo'),
(7773, 6077, 3, 'Resultado específico'),
(7774, 6078, 3, 'Servicio Específico'),
(7775, 6079, 3, 'Especificado'),
(7776, 6080, 3, 'Formato específico para códigos.#=dígito, *=cualquier caracter. Vacío si no se usa.'),
(7777, 6081, 3, 'Formato específico para códigos.#=dígito, @=alfabético, *=cualquier caracter. Vacío si no se usa.'),
(7778, 6082, 3, 'Formato específico para número de referencia de facturas.#=dígito, *=cualquier caracter. Vacío si no se usa.'),
(7779, 6083, 3, 'Formato específico para número de referencia de facturas.#=dígito, @=alfabético, *=cualquier caracter. Vacío si no se usa.'),
(7780, 6084, 3, 'Formato producto campos NCD. #=dígito, *=cualquier carácter. Vacío si no se usa.'),
(7781, 6085, 3, 'Formato producto campos NCD. #=dígito, @=alfabético, *=cualquier carácter. Vacío si no se usa.'),
(7782, 6086, 3, 'Formato ID paciente externo.#=dígito,*=cualquier carácter. Vacío si no se usa.'),
(7783, 6087, 3, 'Formato ID paciente externo.#=dígito, @=Alfabético, *=cualquier carácter. Vacío si no se usa.'),
(7784, 6088, 3, 'Especimen'),
(7785, 6089, 3, 'Especimen número/Identificador'),
(7786, 6090, 3, 'Tipo de especimen'),
(7787, 6092, 3, 'Dictado'),
(7788, 6093, 3, 'Espermicidas'),
(7789, 6094, 3, 'Esplenectomía'),
(7790, 6095, 3, 'Esposa'),
(7791, 6097, 3, 'Esputo'),
(7792, 6098, 3, 'Esputo:'),
(7793, 6099, 3, 'SQ'),
(7794, 6102, 3, 'Equipo'),
(7795, 6103, 3, 'Miembro de Equipo'),
(7796, 6104, 3, 'Equipos'),
(7797, 6105, 3, 'SRH'),
(7798, 6106, 3, 'SRH - Planificación de la Familia'),
(7799, 6107, 3, 'SRH Sin Planificación de la Familia'),
(7800, 6108, 3, 'SRH Derivados'),
(7801, 6109, 3, 'Forma de la visita del SRH'),
(7802, 6110, 3, 'Fecha servicio'),
(7803, 6111, 3, 'SS'),
(7804, 6112, 3, 'Certificado de Administracion SSL'),
(7805, 6113, 3, 'Nº SS'),
(7806, 6114, 3, 'comienzo'),
(7807, 6115, 3, 'Versiones preparadas'),
(7808, 6116, 3, 'Estándar'),
(7809, 6117, 3, 'Codigo usual'),
(7810, 6118, 3, 'Medidas estándar'),
(7811, 6122, 3, 'Nombre estándar'),
(7812, 6124, 3, 'Comienzo'),
(7813, 6125, 3, 'Comienzo (aaaa-mm-dd): '),
(7814, 6128, 3, 'Fecha Comienzo:'),
(7815, 6129, 3, 'Fecha de inicio en esta clínica'),
(7816, 6130, 3, 'Fecha de inicio no debe ser mayor que la fecha final'),
(7817, 6131, 3, 'Fecha comienzo:'),
(7818, 6132, 3, 'Fecha Comienzo:'),
(7819, 6133, 3, 'Hora de Comienzo'),
(7820, 6134, 3, 'Fecha el Comenzar'),
(7821, 6135, 3, 'Estado'),
(7822, 6136, 3, 'Estado'),
(7823, 6137, 3, 'Tipo de datos estado'),
(7824, 6139, 3, 'D.N.I.'),
(7825, 6140, 3, 'Lista estado'),
(7826, 6141, 3, 'Lista estado (escriba, sólo añadir opcional)'),
(7827, 6142, 3, 'Lista de estados de los campos Widget personalizados'),
(7828, 6143, 3, 'Estado o Provincia'),
(7829, 6144, 3, 'Provincia/Localidad'),
(7830, 6145, 3, 'Provincia/Parroquia'),
(7831, 6146, 3, 'RESUMEN SUMARIO'),
(7832, 6147, 3, 'extractos y facturas de actualización.'),
(7833, 6148, 3, 'Declaraciones enviadas:n'),
(7834, 6149, 3, 'extractos, facturas no seran actualizadas'),
(7835, 6150, 3, 'Texto estático'),
(7836, 6151, 3, 'Estadísticas'),
(7837, 6152, 3, 'Estadísticas'),
(7838, 6153, 3, 'Estado'),
(7839, 6156, 3, 'Estado actual'),
(7840, 6158, 3, 'Couns de ETS/SIDA'),
(7841, 6159, 3, 'Stength y Acondicionado'),
(7842, 6164, 3, 'Pasos para instalar la bbdd DSM IV'),
(7843, 6165, 3, 'Pasos para instalar la bbdd ICD 10'),
(7844, 6166, 3, 'Pasos para instalar la bbdd ICD 9'),
(7845, 6167, 3, 'Pasos para instalar la bbdd RxNorm'),
(7846, 6168, 3, 'Pasos para instalar la bbdd Snomed'),
(7847, 6169, 3, 'Coyunturas Tiesas'),
(7848, 6170, 3, 'Tiesura'),
(7849, 6171, 3, 'Meses de Reservas'),
(7850, 6172, 3, 'Dolores de Estómago'),
(7851, 6174, 3, 'Hash almacenado'),
(7852, 6175, 3, 'Tensión del músculo'),
(7853, 6176, 3, 'Corriente'),
(7854, 6177, 3, 'Calle'),
(7855, 6178, 3, 'Calle de direccion'),
(7856, 6179, 3, 'Calle y Número'),
(7857, 6180, 3, 'Fuerza'),
(7858, 6182, 3, 'Estrep Garganta'),
(7859, 6183, 3, 'Fractura de Estrés'),
(7860, 6184, 3, 'Prueba de Estrés'),
(7861, 6185, 3, 'Derrame Cerebral'),
(7862, 6186, 3, 'Contraseña segura significa al menos 8 caracteres, y que al menos tres sean: un número, una minúscula, una mayúscula, un carácter especial.'),
(7863, 6188, 3, 'Estilo del formulario usado para añadir nuevos pacientes'),
(7864, 6189, 3, 'Sub-categoría'),
(7865, 6190, 3, 'Sub-Total'),
(7866, 6191, 3, 'Subcategoria'),
(7867, 6192, 3, 'subcategoria'),
(7868, 6193, 3, 'Subcutáneo'),
(7869, 6194, 3, 'Asunto'),
(7870, 6195, 3, 'Subjetivo'),
(7871, 6196, 3, 'Sublingual'),
(7872, 6197, 3, 'sublingual'),
(7873, 6198, 3, 'Aceptar'),
(7874, 6199, 3, 'Aceptar'),
(7875, 6200, 3, 'Aceptar todo el contenido'),
(7876, 6202, 3, 'Aceptar Evento'),
(7877, 6203, 3, 'Aceptar Formulario'),
(7878, 6204, 3, 'Aceptar contenido seleccionado'),
(7879, 6205, 3, 'Aceptado'),
(7880, 6206, 3, 'Aceptado por'),
(7881, 6207, 3, 'Número de acceso EDI del Presentador(PER06)'),
(7882, 6208, 3, 'Suscriptor'),
(7883, 6209, 3, 'Dirección del Suscriptor'),
(7884, 6213, 3, 'empleador del suscriptor'),
(7885, 6214, 3, 'empleador del suscriptor (SE)'),
(7886, 6215, 3, 'Dirección del empleador del suscriptor'),
(7887, 6216, 3, 'Ciudad del empleador del suscriptor'),
(7888, 6217, 3, 'Subscriber Employer Country'),
(7889, 6218, 3, 'Estado del empleador del suscriptor'),
(7890, 6221, 3, 'Código postal del empleador del suscriptor'),
(7891, 6225, 3, 'Teléfono de Suscriptor'),
(7892, 6226, 3, 'Relación con el Suscriptor'),
(7893, 6227, 3, '¡La relación del suscriptor no es uno mismo pero el nombre es igual! ¿Es esto realmente ACEPTABLE?'),
(7894, 6228, 3, '¡La relación del suscriptor no es uno mismo pero el número de SS es igual!'),
(7895, 6229, 3, '¡La relación del suscriptor es uno mismo pero el nombre es diferente! ¿Es esto realmente ACEPTABLE?'),
(7896, 6230, 3, '¡La relación del suscriptor es uno mismo pero el número de SS es diferente!'),
(7897, 6231, 3, 'Sexo de Suscriptor'),
(7898, 6237, 3, 'Sustituto'),
(7899, 6238, 3, 'sustituto permitido'),
(7900, 6240, 3, 'Exito'),
(7901, 6241, 3, 'éxito'),
(7902, 6242, 3, 'Confirmación de la recepción de resultados del laboratorio'),
(7903, 6243, 3, 'Confirmación obtención resultados de laboratorio'),
(7904, 6244, 3, 'Éxito obteniendo los resultados de la Red de Intercambio del Laboratorio'),
(7905, 6246, 3, 'Categoría añadida correctamente'),
(7906, 6247, 3, 'agregado con éxito a la categoría,'),
(7907, 6248, 3, 'Borrado completado'),
(7908, 6250, 3, 'Instalado en Base Datos completado'),
(7909, 6251, 3, 'La siguiente bbdd ha sido instalada correctamente'),
(7910, 6252, 3, 'Modificación Completada'),
(7911, 6253, 3, 'Correctamente salvado. ¿Le gustaría asignarlo?'),
(7912, 6254, 3, 'Correctamente salvado. ¿Le gustaría distribuir?'),
(7913, 6256, 3, 'almacenado con éxito.'),
(7914, 6257, 3, 'Base de datos actualizada correctamente.'),
(7915, 6258, 3, 'La siguiente bbdd ha sido actualizada correctamente'),
(7916, 6259, 3, 'con éxito.'),
(7917, 6260, 3, 'Suicidio'),
(7918, 6261, 3, 'Resumen'),
(7919, 6262, 3, 'Sumario de'),
(7920, 6265, 3, 'Domingo'),
(7921, 6267, 3, 'Domingo'),
(7922, 6268, 3, 'Superbill'),
(7923, 6269, 3, 'Códigos de superbill'),
(7924, 6270, 3, 'Códigos Superbill Administración'),
(7925, 6271, 3, 'Reportes de superbill'),
(7926, 6272, 3, 'Superbill/Hoja de precios'),
(7927, 6273, 3, 'Superbills'),
(7928, 6274, 3, 'Superbills, referido a veces a Formularios de visitas u hojas de ruta, son una parte esencial en la mayoría de los centros médicos.'),
(7929, 6275, 3, 'Superusuario'),
(7930, 6276, 3, 'Supervisando'),
(7931, 6278, 3, 'Dr.Supervisor DEA'),
(7932, 6279, 3, 'Primer Nombre Doctor Supervisor'),
(7933, 6280, 3, 'Apellido Doctor Supervisor'),
(7934, 6281, 3, 'Dr.Supervisor NPI'),
(7935, 6282, 3, 'Dr.Supervisor UPIN'),
(7936, 6283, 3, 'Nombre del centro proveedor'),
(7937, 6284, 3, 'Soporte de los eventos de calendario que se aplican a múltiples facultativos'),
(7938, 6285, 3, 'Soporte configuración de datos de importación/exportación a través de la página de backup'),
(7939, 6286, 3, 'Soporte eventos multi-facultativo'),
(7940, 6288, 3, 'Soporta sólo enciptación/desencriptación TripleDES'),
(7941, 6289, 3, 'Tipo de Superficie'),
(7942, 6290, 3, 'Cirugías'),
(7943, 6291, 3, 'Cirugía'),
(7944, 6293, 3, 'Suspendido'),
(7945, 6294, 3, 'suspención'),
(7946, 6295, 3, 'Fecha Servicio'),
(7947, 6296, 3, 'Fecha Servicio:'),
(7948, 6299, 3, 'Sudoración:'),
(7949, 6300, 3, 'Sueco'),
(7950, 6301, 3, 'Hinchazón'),
(7951, 6302, 3, 'Hinchazón a la Derecha'),
(7952, 6303, 3, 'Articulaciones Inflamadas'),
(7953, 6304, 3, 'Inflamación de los ganglios linfáticos'),
(7954, 6305, 3, 'Símbolo usado como punto decimal para moneda. No usado si los decimales son 0.'),
(7955, 6306, 3, 'Símbolo usado para separar miles en moneda.'),
(7956, 6307, 3, 'Síntomas'),
(7957, 6308, 3, 'Sincronizar'),
(7958, 6309, 3, 'Sincronizar traducción con la tabla de idioma del cliente'),
(7959, 6310, 3, 'Sincronizado constante de nuevo cliente:'),
(7960, 6311, 3, 'Sincronizar nuevo idioma cliente'),
(7961, 6312, 3, 'Sincronizado nueva definición (Idioma, Constante, Definición):'),
(7962, 6313, 3, 'Síncope'),
(7963, 6314, 3, 'Vigilancia de Síndrome'),
(7964, 6315, 3, 'Vigilancia síndrome - Sin problemas notificados'),
(7965, 6317, 3, 'Sinovitis, pinzamiento, bursitis'),
(7966, 6318, 3, 'Sistema'),
(7967, 6322, 3, 'T'),
(7968, 6323, 3, 't.i.d.'),
(7969, 6324, 3, 'T.V.'),
(7970, 6325, 3, 'Tabla'),
(7971, 6327, 3, 'La creación de la tabla falló'),
(7972, 6328, 3, 'La actualización de la tabla falló'),
(7973, 6330, 3, 'tableta'),
(7974, 6332, 3, 'Tagalog'),
(7975, 6335, 3, 'Tomar'),
(7976, 6336, 3, 'Escoger seguro, en el desplegable'),
(7977, 6337, 3, 'Escoger forma de pago, en el desplegable'),
(7978, 6338, 3, 'Recogida'),
(7979, 6339, 3, 'Toma tiempo'),
(7980, 6340, 3, 'Altura del área de navegación'),
(7981, 6347, 3, 'Fecha límite'),
(7982, 6351, 3, 'Objetivo/Grupos de Acción'),
(7983, 6354, 3, 'N.I.F./C.I.F.'),
(7984, 6355, 3, 'Tasa de Impuestos'),
(7985, 6356, 3, 'Impuestos'),
(7986, 6357, 3, 'Taxonomía'),
(7987, 6358, 3, 'TD'),
(7988, 6359, 3, 'Descripción de lesión del equipo'),
(7989, 6360, 3, 'Lista del Equipo'),
(7990, 6361, 3, 'Ver Lista de Equipo'),
(7991, 6362, 3, 'Equipo/Plantilla'),
(7992, 6363, 3, 'Tel'),
(7993, 6364, 3, 'Código País telefónico'),
(7994, 6366, 3, 'Temp'),
(7995, 6367, 3, 'Localización de la toma de temperat.'),
(7996, 6368, 3, 'Método para Temperat.'),
(7997, 6369, 3, 'Temperatura'),
(7998, 6370, 3, 'Plantilla'),
(7999, 6371, 3, 'Nombre de Plantilla'),
(8000, 6372, 3, 'Los nombres de la plantilla no pueden comenzar con números.'),
(8001, 6373, 3, 'Plantilla:'),
(8002, 6374, 3, 'Pantillas'),
(8003, 6375, 3, 'Arteria Temporal'),
(8004, 6376, 3, 'Daño al tendón'),
(8005, 6377, 3, 'Tendinitis / osis / bursitis'),
(8006, 6378, 3, 'Nºreferencia factura provisional'),
(8007, 6379, 3, 'Terciario'),
(8008, 6380, 3, 'Seguro Terciario'),
(8009, 6381, 3, 'Datos terciarios del seguro'),
(8010, 6382, 3, 'Proveedor terciario del seguro'),
(8011, 6383, 3, 'Planificación de estudios'),
(8012, 6384, 3, 'Sistema de Prueba'),
(8013, 6385, 3, 'Texto'),
(8014, 6386, 3, 'Texto Diagnóstico'),
(8015, 6387, 3, 'campo texto'),
(8016, 6393, 3, 'Fecha del texto'),
(8017, 6394, 3, 'texto actualizado'),
(8018, 6395, 3, 'Area de texto'),
(8019, 6396, 3, 'erea de texto'),
(8020, 6397, 3, 'Cuadro de texto'),
(8021, 6398, 3, 'caja de texto'),
(8022, 6399, 3, 'Lista del cuadro de texto'),
(8023, 6400, 3, 'lista de texto'),
(8024, 6401, 3, 'Tailandés'),
(8025, 6402, 3, 'Gracias'),
(8026, 6403, 3, 'Gracias por elegir'),
(8027, 6404, 3, 'El botón ''Limpiar'' eliminará todas las anotaciones.'),
(8028, 6405, 3, 'Falló la declaración anterior'),
(8029, 6406, 3, 'Llave publica y Certificado del Servidor Apache SSL'),
(8030, 6407, 3, 'El certificado de Autoridad Certificada'),
(8031, 6408, 3, 'El fichero de reclamación: '),
(8032, 6410, 3, 'La llave privada correspondiente'),
(8033, 6413, 3, 'El código de denegación es'),
(8034, 6414, 3, 'El código del grupo denegación es'),
(8035, 6415, 3, 'El formulario de destino está cerrado'),
(8036, 6416, 3, 'La forma de la destinación era cerrada; No puedo actuar en su selección.'),
(8037, 6422, 3, 'El evento(s) han sido aprobadas.'),
(8038, 6423, 3, 'Se han ocultado el evento(s).'),
(8039, 6424, 3, 'Los datos exportados aparecen en el área de texto a continuación. Puede copiarla y pegarla en un email o cualquier otro destino.'),
(8040, 6426, 3, 'Los datos exportados aparecen en el área de texto a continuación. Puede copiarla y pegarla en un email o cualquier otro destino.'),
(8041, 6427, 3, 'Los datos exportados aparecen en el área de texto de abajo. Puede copiar y pegar en el mail o cualquier otro destino deseado.'),
(8042, 6428, 3, 'El no puede salvarse en CouchDB.'),
(8043, 6429, 3, 'El fichero puede no estar correctamente renombrado, este error está normalmente relacionado con problemas de permiso en el sistema de almacenamiento.'),
(8044, 6430, 3, 'El fichero no ha sido archivado correctamente'),
(8045, 6433, 3, 'El primer paso es abrir una cuenta en el sitio web Unified Medical Language System'),
(8046, 6434, 3, 'Los siguientes eventos del calendario han sido añadido:'),
(8047, 6435, 3, 'Los siguientes eventos del calendario han sido modificado:'),
(8048, 6436, 3, 'Las siguentes categorías serán eliminadas de su lista de categorías'),
(8049, 6437, 3, 'La siguiente versión de la base de datos está actualmente instalada'),
(8050, 6439, 3, 'El siguiente fichero EDI ha sido subido'),
(8051, 6440, 3, 'El inicio sesión de usuario de emergencia siguiente esta activado:'),
(8052, 6441, 3, 'Los errores siguientes ocurrieron'),
(8053, 6444, 3, 'Los campos soguientes son requeridos'),
(8054, 6446, 3, 'Los siguientes campos tienen que estar rellenos para enviar la solicitud.'),
(8055, 6449, 3, 'Nombre del Host de la máquina repositoria auditoría ATNA'),
(8056, 6450, 3, 'La pantalla inicial es la página de búsqueda de la factura. En la parte superior puede introducir un dato (ej. número de cheque), fecha de pago e importe del cheque. El motivo del dato y la fecha de pago es para que no tenga que introducir una y otra vez para cada reclamación. La cantidad que usted introduzca será disminuido por cada factura que tenga pago parcial, y se espera que acabará en cero cuando haya terminado.'),
(8057, 6454, 3, 'La versión instalada y los ficheros preparados son iguales.'),
(8058, 6455, 3, 'La versión instalada es más reciente que los ficheros preparados.'),
(8059, 6456, 3, 'La etiqueta que aparece al usuario en la forma'),
(8060, 6457, 3, 'La longitud no debe exceder el siguiente número de caracteres'),
(8061, 6460, 3, 'La nueva categoría será una subcategoría de '),
(8062, 6461, 3, 'La nueva contraseña no puede ser la misma que la actual.'),
(8063, 6462, 3, 'Las contraseñas no son iguales'),
(8064, 6464, 3, 'El número de ficheros preparados es incorrecto. Sólo coloque los ficheros que quiera instalar/actualizar.'),
(8065, 6465, 3, 'La página será redirigida a demográficos. Puede editar el campo de país y click a través de NewCrop de nuevo.'),
(8066, 6466, 3, 'La contraseña debe tener al menos ocho caracteres, y debe'),
(8067, 6468, 3, 'El registro del paciente ha sido grabado'),
(8068, 6469, 3, 'Los recordatorios del paciente han sido enviados'),
(8069, 6470, 3, 'Los recordatorios del paciente han sido actualizados'),
(8070, 6472, 3, 'Los pagos enviados no pueden ser antes de esta fecha. Esto asegura que después del informe final nadie puede enviar fechas anteriores.'),
(8071, 6475, 3, 'La información restante abajo se aplica solamente si usted está fijando manualmente, o si usted está haciendo correcciones manuales.'),
(8072, 6477, 3, 'El documento solicitado no está presente en el lugar previsto en el sistema de ficheros o no hay suficientes permisos para acceder a ella.'),
(8073, 6480, 3, 'Las columnas de la fuente y de fecha se copian de la primera página, por lo que normalmente no será necesario que los toque. Usted puede poner una cantidad del pago en la columna de pagos, una cantidad de ajuste en la columna de ajuste, o ambas. Puedes también hacer clic en - W- a la derecha de computar automáticamente un ajuste valorar que escriba del resto de la carga para esa línea artículo.'),
(8074, 6481, 3, 'La versión de todos los ficheros preparados no es la misma.'),
(8075, 6482, 3, 'La revisión de todos los ficheros preparados no es la misma.'),
(8076, 6484, 3, 'La división temporal del calendario y el menor intervalo en minutos para una ranura de cita.'),
(8077, 6485, 3, 'La etiqueta traducida que aparecerá en la forma en lengua actual'),
(8078, 6486, 3, 'El título traducido que aparecerá en lengua actual'),
(8079, 6487, 3, 'La traducción de descripción en lengua actual'),
(8080, 6488, 3, 'La tabla de traducción está sincronizada'),
(8081, 6489, 3, 'Tipo de esta entidad'),
(8082, 6490, 3, 'El código de identificación específico del proveedor de este procedimiento o el resultado'),
(8083, 6491, 3, 'Los ficheros X12, así como la salida de informes HTML resultantes son archivados en el subdirectorio -era- del directorio principal de la instalación de LibreEHR. Si quiere hacer referencia a estos ficheros de vez en cuando. La URL es'),
(8084, 6492, 3, 'El file comprimido ha de contener los siguientes items'),
(8085, 6493, 3, 'Tema'),
(8086, 6495, 3, 'Inyecciones Terapéuticas'),
(8087, 6496, 3, 'Existen'),
(8088, 6497, 3, 'Actualmente no hay recetas'),
(8089, 6498, 3, 'Hay errores con su sumisión. Éstos se contornean abajo.'),
(8090, 6500, 3, 'No hay gráficos comprobados.'),
(8091, 6501, 3, 'No hay publicaciones grabadas para este paciente.'),
(8092, 6502, 3, 'No hay nuevas sumisiones'),
(8093, 6503, 3, 'No hay notas en el file para este paciente'),
(8094, 6504, 3, 'No hay transacciones archivadas para ese paciente'),
(8095, 6505, 3, 'Se ha producido un error al enviar correo a'),
(8096, 6506, 3, 'Ya existe una categoria nombrada'),
(8097, 6507, 3, 'Ya existe una subcategoria nombrada'),
(8098, 6508, 3, 'Ya existe un item nombrado'),
(8099, 6509, 3, 'Ya está abierto el registro de paciente solicitado.'),
(8100, 6510, 3, 'No hay entrada de COA para la cuenta de AR '),
(8101, 6511, 3, 'No hay entrada de COA para la cuenta de efectivo '),
(8102, 6512, 3, 'No hay entrada de COA para la cuenta de ingresos '),
(8103, 6513, 3, 'El paciente actual no existe'),
(8104, 6515, 3, 'No hay coicincidencia para el Nº Identificación factura'),
(8105, 6516, 3, 'No hay coicincidencia para el Nº Identificación factura = '),
(8106, 6517, 3, 'No hay partes de entrada para el Nº Identificación de los servicios '),
(8107, 6520, 3, 'Se ha producido un error mientras se procesaba su solicitud.'),
(8108, 6522, 3, 'Estos son los enlaces de 2012'),
(8109, 6523, 3, 'Espesado a la derecha:'),
(8110, 6524, 3, 'Muslo'),
(8111, 6525, 3, 'Muslo + tendón de la corva'),
(8112, 6527, 3, 'Cosas que la oficina trasera puede leer y entrar pero no modificar'),
(8113, 6528, 3, 'Things that back office can read and modify'),
(8114, 6531, 3, 'Cosas que los médicos pueden leer y entrar pero no modificar'),
(8115, 6532, 3, 'Cosas que los médicos pueden leer y modificar'),
(8116, 6535, 3, 'Cosas que la oficina central puede leer y entrar pero no modificar'),
(8117, 6536, 3, 'Cosas que la oficina central puede leer y modificar'),
(8118, 6539, 3, 'Cosas que los fisios pueden entrar y leer pero no modificar'),
(8119, 6540, 3, 'Cosas que los fisios pueden leer y modificar'),
(8120, 6542, 3, 'Tercera'),
(8121, 6544, 3, 'Esta acción NO SE PUEDE deshacer.'),
(8122, 6545, 3, 'Esta acción no se puede deshacer.'),
(8123, 6547, 3, 'Esta acción se registrará'),
(8124, 6549, 3, 'El espacio para la cita está ocupado, ¿usarlo de todas formas?'),
(8125, 6550, 3, 'Este espacio para cita no está disponible, por favor elegir otro.'),
(8126, 6551, 3, 'Este año de calendario'),
(8127, 6552, 3, 'Esta reclamación ha sido cancelada.'),
(8128, 6553, 3, 'La reclamación ha sido cerrada.'),
(8129, 6554, 3, 'La reclamación ha sido denegada. Razón:-'),
(8130, 6555, 3, 'La reclamación ha sido enviada a otro nivel'),
(8131, 6556, 3, 'Este tipo de código no acepta las relaciones.'),
(8132, 6557, 3, 'Este contexto contiene categorias, las cuales serán borradas. ¿Quiere continuar?'),
(8133, 6558, 3, 'Esto determina como se visualizarán las citas en el calendario.'),
(8134, 6559, 3, 'Esto determina como será el esquema de color usado para las citas'),
(8135, 6561, 3, 'Esta Visita'),
(8136, 6562, 3, 'Esta visita ha sido facturada. Si necesita cambiarlo, debe ser re-abierta.'),
(8137, 6564, 3, 'Esta caracteristica ya no está disponible'),
(8138, 6565, 3, 'Este atributo es experimental y no probado. Use a riesgo propio.'),
(8139, 6566, 3, 'Este número de factura se ha cambiado a '),
(8140, 6572, 3, 'esta ubicación'),
(8141, 6575, 3, 'Este módulo está en modo de prueba. La base de datos no será cambiada.'),
(8142, 6576, 3, 'Este módulo promueve la entrada eficiente de los datos de EOB.'),
(8143, 6577, 3, 'Este mes a fecha'),
(8144, 6579, 3, 'Esta página le permite revisar cada uno de los dataloads externos compatibles que puede instalar y actualizar. Cada sección de abajo se puede ampliar haciendo clic en la cabecera de sección para revisar el estado de interés de la bbdd.'),
(8145, 6581, 3, 'En esta página se incluye en línea la página de inicio de sesión, de modo que no tenemos que hacer clic en iniciar la sesión cada vez.'),
(8146, 6582, 3, 'Este paciente no tiene ninguna actividad.'),
(8147, 6583, 3, 'Este Nº Identificación de paciente ya está en uso!'),
(8148, 6584, 3, 'Este producto solo permite un lote por deposito'),
(8149, 6586, 3, 'Este informe actualmente sólo funciona para códigos ICD9.'),
(8150, 6591, 3, 'Este paso generará un fichero el cual salvará para uso futuro. El fichero no se puede generar de nuevo. ¿Quiere proceder?'),
(8151, 6592, 3, 'Este usuario no es miembro de ningún grupo'),
(8152, 6595, 3, 'Esta visita comienza nuevo uso anticonceptivo'),
(8153, 6596, 3, 'Esta visita necesitará un formulario GCAC, derivación o procedimiento de servicio.'),
(8154, 6597, 3, 'Esta fue la métrica más antigua de formularios de constantes vitales, ahora en desuso.'),
(8155, 6598, 3, 'Esta semana a fecha'),
(8156, 6600, 3, 'Esto activará informes CCR(Continuity of Care Record) y CCD(Continuity of Care Document)'),
(8157, 6602, 3, 'Esto permitirá la selección de la depuración (''dummy'') de idioma.'),
(8158, 6606, 3, 'Esto creará un backup en formato tar y luego lo envia a su navegador web para que lo pueda guardar'),
(8159, 6607, 3, 'Esto desactivará las características de encriptación/desencriptación del documento, y lo ocultará en el UI.'),
(8160, 6613, 3, 'Esto forzará el widget de facturación en la pantalla resumen del paciente para que se abra siempre.'),
(8161, 6617, 3, 'Esto no le impiderá ir al sitio de recetas electrónicas.'),
(8162, 6619, 3, 'Esto usará la lista de vacunación personalizada en lugar de la lista de vacunación estándar CVX.'),
(8163, 6622, 3, 'Espina dorsal torácica');
INSERT INTO `lang_definitions` VALUES
(8164, 6623, 3, 'Miles/CU.MM'),
(8165, 6625, 3, 'Garganta'),
(8166, 6626, 3, 'Cáncer de Garganta'),
(8167, 6627, 3, 'Cirugía del Cáncer de Garganta'),
(8168, 6628, 3, 'Trombosis/Derrame Cerebral'),
(8169, 6629, 3, 'Jueves'),
(8170, 6630, 3, 'Jueves'),
(8171, 6631, 3, 'Jueves'),
(8172, 6632, 3, 'Normal de la tiroides'),
(8173, 6633, 3, 'Problemas de la Tiroides'),
(8174, 6634, 3, 'TIA'),
(8175, 6638, 3, 'Tiempo'),
(8176, 6639, 3, 'Formato visualización de hora'),
(8177, 6640, 3, 'Incremento de tiempo para agrega (minutos 1-60)'),
(8178, 6641, 3, 'Seleccion de tiempo'),
(8179, 6642, 3, 'La ventana de tiempo está abieta, salvando evento'),
(8180, 6647, 3, 'El tiempo de evento'),
(8181, 6648, 3, 'Matriz tiempos (NO APLICABLE)'),
(8182, 6649, 3, 'Reloj fechador y texto'),
(8183, 6650, 3, 'TIN'),
(8184, 6651, 3, 'Tinnitus'),
(8185, 6652, 3, 'Título'),
(8186, 6653, 3, 'Título V'),
(8187, 6654, 3, 'Título de columnas debe ser un número entre 1 y 999'),
(8188, 6655, 3, 'Títulos'),
(8189, 6656, 3, 'TM''S:'),
(8190, 6657, 3, 'TMs/EAMs/EE, ext nariz'),
(8191, 6658, 3, 'Para'),
(8192, 6659, 3, 'PARA'),
(8193, 6660, 3, 'para'),
(8194, 6661, 3, 'Hacia la ruta absoluta del file'),
(8195, 6662, 3, 'Favor Selecciona para agregar notas '),
(8196, 6663, 3, 'Para añadir notas, por favor haga click aquí'),
(8197, 6664, 3, 'Área afectada'),
(8198, 6665, 3, 'área afectada'),
(8199, 6666, 3, 'Para abrir automáticamente el formulario específico. Algunos equipos deportivos usan aquí auditoria de fútbol.'),
(8200, 6667, 3, 'Ver a facturación'),
(8201, 6668, 3, 'a la categoría'),
(8202, 6669, 3, 'Ver a Clínica'),
(8203, 6670, 3, 'De copago'),
(8204, 6672, 3, 'Para ded''ble'),
(8205, 6673, 3, 'Para DEMs'),
(8206, 6674, 3, 'Para deshabilitar certificado del cliente SSL, comente en lineas de arriba en la configuración del file Apache y configurar'),
(8207, 6675, 3, 'Para deshabilitar HTTPS, comente en líneas de arriba en el file de configuración de Apache y reiniciar el servidor Apache'),
(8208, 6676, 3, 'Para activar certificados ssl del lado cliente'),
(8209, 6677, 3, 'Para activar certificados de autenticación SSl, HTTPS debe estar activado.'),
(8210, 6678, 3, 'Para activar sólo HTTPS, ejecute los cambios mencionados arriba y reinicie el servidor Apache. Si quiere configurar los certificados del lado cliente también, por favor configúrelos en la siguiente sección.'),
(8211, 6679, 3, 'Para Enctr'),
(8212, 6680, 3, 'Para filtrar por sexo'),
(8213, 6681, 3, 'La Historia'),
(8214, 6682, 3, 'Para Incidencias'),
(8215, 6683, 3, 'Para vincular esta visita/consulta con una incidencia existente, haga click '),
(8216, 6684, 3, 'Para vincular esta cita/consulta con una incidencia existente, haga click encima de la incidencia deseada para seleccionar y, después click en [Guardar]. Mantenga pulsada la tecla [Ctrl] para seleccionar múltiples incidencias.'),
(8217, 6685, 3, 'volver a iniciar sesión'),
(8218, 6686, 3, 'Para grabar publicaciones, por favor click'),
(8219, 6687, 3, 'Para Ejecutar'),
(8220, 6688, 3, 'Para configurar el acceso https con autenticación de certificados de cliente, haga lo siguiente'),
(8221, 6689, 3, 'Para la piel'),
(8222, 6690, 3, 'para la piel'),
(8223, 6691, 3, '¿a esta visita?'),
(8224, 6693, 3, 'Para:'),
(8225, 6694, 3, 'Para: '),
(8226, 6695, 3, 'TO_CITY'),
(8227, 6696, 3, 'TO_FAX'),
(8228, 6697, 3, 'TO_FNAME'),
(8229, 6698, 3, 'TO_LNAME'),
(8230, 6699, 3, 'TO_MNAME'),
(8231, 6700, 3, 'TO_ORGANIZATION'),
(8232, 6703, 3, 'TO_POSTAL'),
(8233, 6704, 3, 'TO_STATE'),
(8234, 6705, 3, 'TO_STREET'),
(8235, 6706, 3, 'TO_TITLE'),
(8236, 6707, 3, 'TO_VALEDICTORY'),
(8237, 6708, 3, 'Tabaco'),
(8238, 6709, 3, 'Intervención para dejar el tabaco'),
(8239, 6710, 3, 'Intervención para dejar el tabaco (GCC)'),
(8240, 6712, 3, 'Consumo de tabaco'),
(8241, 6713, 3, 'Evaluación consumo tabaco'),
(8242, 6714, 3, 'Evaluación consumo tabaco (GCC)'),
(8243, 6715, 3, 'Hoy'),
(8244, 6716, 3, 'HOY'),
(8245, 6717, 3, 'hoy'),
(8246, 6718, 3, 'Balance actual'),
(8247, 6719, 3, 'Cargos actuales'),
(8248, 6720, 3, 'Fecha de Hoy'),
(8249, 6721, 3, 'Eventos de Hoy'),
(8250, 6726, 3, 'Tonsilectomía'),
(8251, 6728, 3, 'Sup.'),
(8252, 6730, 3, 'Tema'),
(8253, 6731, 3, 'Total'),
(8254, 6732, 3, 'total'),
(8255, 6733, 3, 'Total acciones activas'),
(8256, 6734, 3, 'Total recordatorios activos después de actualizar'),
(8257, 6735, 3, 'Total recordatorios activos antes de actualizar'),
(8258, 6737, 3, 'Total de cantidad adeudada'),
(8259, 6738, 3, 'Cantidad total pagada'),
(8260, 6740, 3, 'Total carga'),
(8261, 6741, 3, 'Total de cargos'),
(8262, 6742, 3, 'Total de Clientes'),
(8263, 6743, 3, 'Costo total'),
(8264, 6744, 3, 'La distribución total para los siguientes números de cheque es incompleta'),
(8265, 6745, 3, 'total entradas'),
(8266, 6746, 3, 'Total recordatorios enviados vía email fallidos'),
(8267, 6747, 3, 'Total recordatorios enviados vía teléfono fallidos'),
(8268, 6748, 3, 'Total para'),
(8269, 6749, 3, 'Total para '),
(8270, 6750, 3, 'Total para la categoría'),
(8271, 6751, 3, 'Total recordatorios inactivos'),
(8272, 6752, 3, 'Total nuevos recordatorios'),
(8273, 6755, 3, 'NºTotal de vacunas'),
(8274, 6756, 3, 'NºTotal de incidencias'),
(8275, 6758, 3, 'Total número de pacientes'),
(8276, 6760, 3, 'Saldo total de pacientes'),
(8277, 6761, 3, 'Total Pacientes'),
(8278, 6764, 3, 'Total Registros Encontrados'),
(8279, 6765, 3, 'Total SRH & Planificación Familiar'),
(8280, 6766, 3, 'Total recordatorios enviados via email correctos'),
(8281, 6767, 3, 'Total recordatorios enviados via teléfono correctos'),
(8282, 6770, 3, 'Tpotal recordatorios sin cambios'),
(8283, 6771, 3, 'Total recordatorios no enviados después del proceso de envío'),
(8284, 6772, 3, 'Total recordatorios no enviados después de actualizar'),
(8285, 6773, 3, 'Total recordatorios no enviados antes del proceso de envío'),
(8286, 6774, 3, 'Total recordatorios no enviados antes de actualizar'),
(8287, 6775, 3, 'Total recordatorios actualizados'),
(8288, 6776, 3, 'Total'),
(8289, 6777, 3, 'Total para'),
(8290, 6778, 3, 'Total para '),
(8291, 6780, 3, 'para{{rango}}'),
(8292, 6785, 3, 'Tipo de Entrenamiento'),
(8293, 6786, 3, 'Transacciones'),
(8294, 6787, 3, 'Transacción'),
(8295, 6788, 3, 'transacción'),
(8296, 6789, 3, 'Transaccion fallida, cantidad insuficiente en lote de destino'),
(8297, 6790, 3, 'Transaccion fallida, cantidad es menor de cero'),
(8298, 6791, 3, 'Tipo de Transacción'),
(8299, 6792, 3, 'transacciones'),
(8300, 6793, 3, 'Transacción'),
(8301, 6794, 3, 'Transacciones (escriba opcional)'),
(8302, 6795, 3, 'Transacciones/Derivados'),
(8303, 6797, 3, 'Transferir'),
(8304, 6799, 3, 'Transferencia fallida, cantidad insuficiebnte el el lote de fuente'),
(8305, 6804, 3, 'Transferencias'),
(8306, 6806, 3, '¿Transición/Transferencia de cuidados?'),
(8307, 6807, 3, 'Traducir Grupos de Control de Acceso'),
(8308, 6808, 3, 'Traducir Categorías de Citas'),
(8309, 6809, 3, 'Traducir Categorías de Documento'),
(8310, 6810, 3, 'Traducir Diseños'),
(8311, 6811, 3, 'Traducir Listas'),
(8312, 6812, 3, 'Traducir título de notas de paciente'),
(8313, 6813, 3, 'traducir este'),
(8314, 6814, 3, 'Traducción'),
(8315, 6815, 3, 'Traducciones'),
(8316, 6819, 3, 'Trauma'),
(8317, 6820, 3, 'Tratamiento'),
(8318, 6822, 3, 'Objetivos de Tratamiento'),
(8319, 6823, 3, 'Plan de Tratamiento'),
(8320, 6826, 3, 'Tratamiento:'),
(8321, 6827, 3, 'Tratamiento: '),
(8322, 6828, 3, 'Tendencia'),
(8323, 6829, 3, 'trftime ($ mes_formato, mkhora(0, 0, 0, $i, 1, 2000))); $ mes_valor'),
(8324, 6830, 3, 'Punto de activación / síndrome compartimental / DOM / calambres'),
(8325, 6831, 3, 'Trimalleolar'),
(8326, 6832, 3, 'Tronco y abdomen'),
(8327, 6837, 3, 'tsp'),
(8328, 6839, 3, 'TTS'),
(8329, 6840, 3, 'Tuberculosis'),
(8330, 6841, 3, 'Martes'),
(8331, 6842, 3, 'Martes y Jueves'),
(8332, 6843, 3, 'Martes'),
(8333, 6844, 3, 'Tumor'),
(8334, 6845, 3, 'Turco'),
(8335, 6848, 3, 'Dos veses al dia'),
(8336, 6850, 3, 'Membrana Timpánica'),
(8337, 6851, 3, 'Tipo'),
(8338, 6852, 3, 'Teclee ID o nombre. Mínimo 3 caracteres (incluyendo espacios).'),
(8339, 6853, 3, 'Teclee columnas mostradas en los resultados de búsqueda de pacientes'),
(8340, 6854, 3, 'Tipos de publicaciones'),
(8341, 6855, 3, 'Tipo de Eventos'),
(8342, 6856, 3, 'Teclee el diseño de pantalla'),
(8343, 6857, 3, 'Escriba o escaneae el identificador del paciente aquí'),
(8344, 6858, 3, 'Teclee su mensaje aquí'),
(8345, 6859, 3, 'Tipo de orden y resultados'),
(8346, 6864, 3, 'Los códigos de UCSMC proporcionaron por la universidad del centro de la medicina de deportes de Calgary'),
(8347, 6865, 3, 'Ucraniano'),
(8348, 6866, 3, 'Ulceraciones'),
(8349, 6867, 3, 'Colitis ulcerosa'),
(8350, 6868, 3, 'Úlceras:'),
(8351, 6871, 3, 'No se puede crear'),
(8352, 6876, 3, 'No aplicado'),
(8353, 6877, 3, 'No asignado'),
(8354, 6878, 3, 'No autorizado'),
(8355, 6879, 3, 'Acceso no autorizado a ePrescripción'),
(8356, 6880, 3, 'Acceso no autorizado.'),
(8357, 6881, 3, 'No facturado'),
(8358, 6882, 3, 'no facturado solamente'),
(8359, 6884, 3, 'debajo de la lengüeta'),
(8360, 6885, 3, 'De peso insuficiente'),
(8361, 6886, 3, 'Sin diagnosticar'),
(8362, 6887, 3, 'SIN DISTRIBUIR'),
(8363, 6888, 3, 'Sin distribuir'),
(8364, 6889, 3, 'No es distribuido'),
(8365, 6890, 3, 'Deshacer desprotección'),
(8366, 6892, 3, 'Clientes distintos'),
(8367, 6893, 3, 'Identificador para este tipo sólo legible por humanos'),
(8368, 6894, 3, 'Nuevos Clientes Distintos'),
(8369, 6895, 3, 'Identificador para este tipo sólo numérico'),
(8370, 6896, 3, 'Pacientes Distintos Vistos'),
(8371, 6897, 3, 'Informe de Pacientes Distintos Vistos'),
(8372, 6898, 3, 'Pacientes Distintos Vistos'),
(8373, 6899, 3, 'Unidad'),
(8374, 6900, 3, 'Unidades'),
(8375, 6901, 3, 'unidades'),
(8376, 6903, 3, 'Unidades de formularios de visita'),
(8377, 6904, 3, 'Unidades deben ser un número'),
(8378, 6905, 3, 'Unidades no definidas'),
(8379, 6906, 3, 'Unidades/L'),
(8380, 6907, 3, 'Desconocido'),
(8381, 6910, 3, 'Desconoce si ha fumado alguna vez'),
(8382, 6911, 3, 'Desconocidos o N/A'),
(8383, 6913, 3, 'Desvincular paciente'),
(8384, 6914, 3, 'Sociedad Médica sin nombre'),
(8385, 6915, 3, 'No registrado'),
(8386, 6918, 3, 'Desmarcar todos'),
(8387, 6919, 3, 'Desmarcado'),
(8388, 6920, 3, 'Sin especificar'),
(8389, 6921, 3, 'no estructurado'),
(8390, 6922, 3, 'Fichero de carga NO SOPORTADO por la bbdd'),
(8391, 6924, 3, 'Hasta'),
(8392, 6925, 3, 'Presentación extemporánea'),
(8393, 6926, 3, 'No utilizados'),
(8394, 6927, 3, 'UOR'),
(8395, 6928, 3, 'Hasta'),
(8396, 6929, 3, 'Próximas Citas'),
(8397, 6930, 3, 'Próximos Eventos'),
(8398, 6931, 3, 'Actualizar'),
(8399, 6932, 3, 'actualizar'),
(8400, 6933, 3, 'Actualizacion activa'),
(8401, 6934, 3, 'Actualizar archivos'),
(8402, 6935, 3, 'Actualizar Informacion'),
(8403, 6936, 3, 'Actualizar lista'),
(8404, 6937, 3, 'Actualizar número de facultativo'),
(8405, 6938, 3, 'Actualizar items seleccionados'),
(8406, 6939, 3, 'Actualizar las siguientes variables en el file'),
(8407, 6940, 3, 'Actualizar informacion de usuario'),
(8408, 6942, 3, 'Updating demographics is not authorized.'),
(8409, 6943, 3, 'Actualizando la configuración global predeterminada'),
(8410, 6944, 3, 'Actualizando indicadores de versión'),
(8411, 6945, 3, 'ACTUALIZACIÓN'),
(8412, 6946, 3, 'Actualizar'),
(8413, 6947, 3, 'Actualizar BBDD'),
(8414, 6948, 3, 'Actualización de base de datos LibreEHR para incluir procedimientos, funciones y tablas necesarias para el proceso de De-identificación.'),
(8415, 6949, 3, 'la actualización continuará'),
(8416, 6950, 3, 'UPIN'),
(8417, 6951, 3, 'Adjuntar'),
(8418, 6954, 3, 'Cargar datos de configuración'),
(8419, 6955, 3, 'Adjuntar Documento'),
(8420, 6956, 3, 'Carga del documento fallo'),
(8421, 6957, 3, 'Adjuntar imagen a'),
(8422, 6958, 3, 'Adjuntar fichero de importación:'),
(8423, 6961, 3, 'Upload Report'),
(8424, 6963, 3, 'Adjuntar este fichero:'),
(8425, 6964, 3, 'Al hacer clic en un número de factura el -manual de desplazamiento ventana- aparece. Aquí puede cambiar la fecha de vencimiento y toma nota de la factura, para seleccionar la parte a quien se le envío por correo, y seleccione los seguros para que todos esperemos los pagos se han recibidos. Lo que es más importante, para cada código de facturación para los que fue acusado una cantidad, puede introducir la información de pago y el ajuste.'),
(8426, 6965, 3, 'Tras la búsqueda se le presenta con una lista de las facturas. Puede hacer clic en uno de los números de la factura para abrir una segunda ventana, que es la página de entrada de datos manual de desplazamiento. También puede hacer clic sobre el nombre de un paciente si desea escribir una nota que la oficina de personal se verá cuando el paciente en los controles, y usted puede seleccionar que aparezca en las facturas del paciente declaraciones e imprimir esas declaraciones.'),
(8427, 6966, 3, 'Parte superior del brazo'),
(8428, 6968, 3, 'Urgencia'),
(8429, 6970, 3, 'Orina'),
(8430, 6971, 3, 'Goteo de Orina'),
(8431, 6972, 3, 'Frecuencia de la Orina'),
(8432, 6973, 3, 'Vacilación de la Orina'),
(8433, 6974, 3, 'Microalbúmina de la orina'),
(8434, 6975, 3, 'Flujo de Orina'),
(8435, 6976, 3, 'Urgencia de la Orina'),
(8436, 6977, 3, 'URL'),
(8437, 6979, 3, 'URL para soporte LibreEHR'),
(8438, 6981, 3, 'URL para puerta de enlace telefónico. Servicio automático de VOIP desarrollado por Maviq. Por favor visite http://signup.maviq.com para más información.'),
(8439, 6986, 3, 'Indicador de uso (ISA15)'),
(8440, 6987, 3, 'Use % solo en un campo para ordenar por esa columna'),
(8441, 6988, 3, 'Utilice el formato de 24 horas?'),
(8442, 6991, 3, 'Usar panel de cargos'),
(8443, 6997, 3, 'Usar lista personalizada de vacunación'),
(8444, 6999, 3, 'Utilice Rango de Fechas'),
(8445, 7000, 3, 'Use opciones por defecto'),
(8446, 7001, 3, 'Utilice la Opción Borrar para Eliminar.'),
(8447, 7002, 3, '¿Utilice el estilo internacional de la fecha?'),
(8448, 7003, 3, 'Utilice nombre de fichero fuente'),
(8449, 7004, 3, 'Use los cambpos abajo para una adquisicion o transferencia'),
(8450, 7005, 3, 'Utilice esta función sólo con los sitios nuevos instalados, '),
(8451, 7006, 3, 'Usar temas?'),
(8452, 7007, 3, 'Usar'),
(8453, 7009, 3, 'Usuarios/Grupos'),
(8454, 7010, 3, 'Usar Administración'),
(8455, 7011, 3, 'Administración de usuarios y Centros'),
(8456, 7012, 3, 'Administración de usuarios y grupos'),
(8457, 7014, 3, 'Certificado de Autenticación del usuario está deshabilitado'),
(8458, 7015, 3, 'Usarios Definidos'),
(8459, 7016, 3, 'Definido por el usuario Zona 11'),
(8460, 7017, 3, 'Definido por el usuario Zona 12'),
(8461, 7018, 3, 'Campo definido por el usuario'),
(8462, 7019, 3, 'Definido por el usuario Lista 1'),
(8463, 7020, 3, 'Definido por el usuario Lista 2'),
(8464, 7021, 3, 'Definido por el usuario Lista 3'),
(8465, 7022, 3, 'Definido por el usuario Lista 4'),
(8466, 7023, 3, 'Definido por el usuario Lista 5'),
(8467, 7024, 3, 'Definido por el usuario Lista 6'),
(8468, 7025, 3, 'Definido por el usuario Lista 7'),
(8469, 7026, 3, 'Definido por el usuario Texto 1'),
(8470, 7027, 3, 'Definido por el usuario Texto 2'),
(8471, 7028, 3, 'Definido por el usuario Texto 3'),
(8472, 7029, 3, 'Definido por el usuario Texto 4'),
(8473, 7030, 3, 'Definido por el usuario Texto 5'),
(8474, 7031, 3, 'Definido por el usuario Texto 6'),
(8475, 7032, 3, 'Definido por el usuario Texto 7'),
(8476, 7033, 3, 'Definido por el usuario Texto 8'),
(8477, 7034, 3, 'Usuario Nombre'),
(8478, 7039, 3, 'Manual de Uso'),
(8479, 7040, 3, 'Asociaciones de usuarios'),
(8480, 7041, 3, 'Usuario Apelido(s)'),
(8481, 7042, 3, 'Usuario o nombre de Host no pueden estar vacios'),
(8482, 7043, 3, 'Usuario o nombre Host'),
(8483, 7046, 3, 'Ajustes de Usuario'),
(8484, 7047, 3, 'Ajuste Usuario Específico'),
(8485, 7049, 3, 'Nombre de usuario'),
(8486, 7051, 3, 'Usuario para puerta de enlace telefónico. Servicio automático de VOIP desarrollado por Maviq. Por favor visite http://signup.maviq.com para más información.'),
(8487, 7052, 3, 'Usuario para puerta de enlace de SMS'),
(8488, 7053, 3, 'Usuario para puerta de enlace SMS'),
(8489, 7054, 3, 'Nombre de usuario para conectar con CouchDB'),
(8490, 7055, 3, 'Nombre de usuario:'),
(8491, 7056, 3, 'Usuarios'),
(8492, 7057, 3, 'Usuarios / Grupos / Administración de Registros'),
(8493, 7058, 3, 'usar php <a href=-http://php.net/strftime->strfhora</a> formato'),
(8494, 7059, 3, 'Infecciones'),
(8495, 7062, 3, 'VACACIONES'),
(8496, 7063, 3, 'Vacaciones'),
(8497, 7064, 3, 'Vacuna'),
(8498, 7065, 3, 'Anillo Vaginal'),
(8499, 7066, 3, 'Despedida'),
(8500, 7067, 3, 'Validar'),
(8501, 7068, 3, 'Valor'),
(8502, 7069, 3, 'Valor 1'),
(8503, 7070, 3, 'Valor 2'),
(8504, 7072, 3, 'El valor debe ser Numérico'),
(8505, 7073, 3, 'Var1'),
(8506, 7074, 3, 'Var2'),
(8507, 7075, 3, 'variable a uno para ejecutar script de actualización des-identificación'),
(8508, 7076, 3, 'Varicela 1'),
(8509, 7077, 3, 'Varicela 2'),
(8510, 7078, 3, 'Venas varicosas'),
(8511, 7079, 3, 'Condición vascular'),
(8512, 7080, 3, 'Lesión vascular'),
(8513, 7081, 3, 'Cirugía Vascular'),
(8514, 7083, 3, 'Vendedor'),
(8515, 7084, 3, 'Versión'),
(8516, 7085, 3, 'Vértigo'),
(8517, 7086, 3, 'Administración de Veteranos'),
(8518, 7087, 3, 'Plan de Administración de veteranos'),
(8519, 7088, 3, 'VFC'),
(8520, 7089, 3, 'Vietnamita'),
(8521, 7090, 3, 'ver'),
(8522, 7091, 3, 'Ver'),
(8523, 7092, 3, 'Ver Alergias'),
(8524, 7097, 3, 'Ver Informe comprensiva del paciente'),
(8525, 7100, 3, 'Ver documento'),
(8526, 7101, 3, 'Ver visita'),
(8527, 7103, 3, 'Ver los eventos en una ventana móvil?'),
(8528, 7104, 3, 'Ver información de usuario en el centro especificado'),
(8529, 7107, 3, 'Ver Registro'),
(8530, 7108, 3, 'Ver Página 1'),
(8531, 7109, 3, 'Ver Página 2'),
(8532, 7110, 3, 'Ver avisos pasados y futuros'),
(8533, 7111, 3, 'Ver Paciente'),
(8534, 7116, 3, 'Ver visitas relacionadas'),
(8535, 7121, 3, 'Ver/Editar Alergias'),
(8536, 7122, 3, 'Ver/Editar incidencia'),
(8537, 7123, 3, 'Ver/Imprimir'),
(8538, 7124, 3, 'Ver:'),
(8539, 7125, 3, 'VISA'),
(8540, 7126, 3, 'VISA/MasterCard/AMEREXPRESS/Discovery'),
(8541, 7127, 3, 'Daño viscerales/trauma/cirugía'),
(8542, 7133, 3, 'Visita Categoría:'),
(8543, 7134, 3, 'Fecha de Visita'),
(8544, 7135, 3, 'Fecha visita'),
(8545, 7137, 3, 'Formularios de visita'),
(8546, 7138, 3, 'Histórico de Visitas'),
(8547, 7140, 3, 'Visitas'),
(8548, 7141, 3, 'Visitas Desde'),
(8549, 7142, 3, 'Constantes Vitales'),
(8550, 7143, 3, 'Constantes Vitales'),
(8551, 7144, 3, 'Constantes Vitales (Métrico)'),
(8552, 7146, 3, 'Voz'),
(8553, 7147, 3, 'Voz Enviada'),
(8554, 7149, 3, 'Vómitos'),
(8555, 7151, 3, 'W'),
(8556, 7152, 3, 'Circ cintura'),
(8557, 7153, 3, 'Circunferencia de la Cintura'),
(8558, 7154, 3, 'Espera'),
(8559, 7155, 3, 'Entrar'),
(8560, 7157, 3, 'Walt Pennington'),
(8561, 7158, 3, 'Tienda de deposito'),
(8562, 7159, 3, 'Almacén máximo, 0 si no es aplicable'),
(8563, 7160, 3, 'Almacén mínimo, 0 si no es aplicable'),
(8564, 7161, 3, 'Tiendas de deposito'),
(8565, 7162, 3, 'Cálido'),
(8566, 7163, 3, 'Aviso'),
(8567, 7164, 3, 'AVISO'),
(8568, 7166, 3, 'Aviso, número de cheque ya existe en la base de datos'),
(8569, 7168, 3, 'Aviso: Una cita ya ha sido para este paciente hoy!'),
(8570, 7170, 3, 'Aviso: Nº Identificación del paciente no es único!'),
(8571, 7171, 3, 'AVISO: Esto sobreescribirá la información de configuración con los datos del fichero adjunto!'),
(8572, 7173, 3, 'Avisos'),
(8573, 7175, 3, 'ya se ha subido'),
(8574, 7177, 3, 'Agradecemos su pago a tiempo del balance debido'),
(8575, 7178, 3, 'hemos visto a su paciente arriba indicado para evaluación y tratamiento en nuestra clínica de consulta externa de psiquiatría. Gracias por esta derivación.'),
(8576, 7179, 3, 'Debilidad'),
(8577, 7181, 3, 'Búsqueda web'),
(8578, 7182, 3, 'Sitio Web'),
(8579, 7183, 3, 'Vínculo sitio web para el Portal del Paciente interno'),
(8580, 7184, 3, 'Miércoles'),
(8581, 7185, 3, 'Miércoles'),
(8582, 7186, 3, 'Semana'),
(8583, 7187, 3, 'semana'),
(8584, 7188, 3, 'Ver Semana'),
(8585, 7189, 3, 'Semana(s)'),
(8586, 7190, 3, 'Exposicion semanal'),
(8587, 7192, 3, 'Semanas'),
(8588, 7193, 3, 'Peso'),
(8589, 7194, 3, 'Peso de Evaluación y Orientación para Niños y Adolescentes'),
(8590, 7195, 3, 'Peso evaluación y orientación para niños y adolescentes (GCC)'),
(8591, 7196, 3, 'Cambio de peso'),
(8592, 7197, 3, 'Perdida de Peso'),
(8593, 7198, 3, 'Clínica de Adelgazamiento'),
(8594, 7199, 3, 'Bienvenido'),
(8595, 7202, 3, '¿Cuál debe ser contado?'),
(8596, 7203, 3, 'Los Resuellos:'),
(8597, 7204, 3, 'Sibilancia'),
(8598, 7205, 3, 'Resollando:'),
(8599, 7208, 3, '¿Donde se pueden encontrar los documentos escaneados o en papel?'),
(8600, 7209, 3, 'Asegurado'),
(8601, 7211, 3, 'Trallazo'),
(8602, 7212, 3, 'Blanco'),
(8603, 7213, 3, 'Quién'),
(8604, 7214, 3, '¿Quién respondió?'),
(8605, 7215, 3, 'Viudo'),
(8606, 7216, 3, 'Ancho'),
(8607, 7217, 3, 'Ancho en píxeles de la barra de navegación izquierda.'),
(8608, 7221, 3, 'Con el seleccionado'),
(8609, 7222, 3, 'con el viejo nombre'),
(8610, 7224, 3, '¿Con quién podemos dejar un mensaje?'),
(8611, 7225, 3, 'Retenido'),
(8612, 7226, 3, 'dentro de horas'),
(8613, 7227, 3, 'dentro de horas:'),
(8614, 7228, 3, 'dentro de minutos'),
(8615, 7229, 3, 'dentro de minutos:'),
(8616, 7232, 3, 'Sin Actualización'),
(8617, 7233, 3, 'Testigo'),
(8618, 7234, 3, 'Semana'),
(8619, 7235, 3, 'WNL'),
(8620, 7237, 3, 'Mujer'),
(8621, 7238, 3, 'Sólo las Mujeres'),
(8622, 7240, 3, 'Trabajo'),
(8623, 7241, 3, 'NOTA DE TRABAJO'),
(8624, 7242, 3, 'Teléfono de Trabajo'),
(8625, 7243, 3, 'Número de Teléfono de Trabajo'),
(8626, 7244, 3, 'Relacionados con el trabajo?'),
(8627, 7245, 3, 'Trabajo / Educación / aficiones'),
(8628, 7246, 3, 'Nota de Trabajo/Escuela'),
(8629, 7247, 3, 'día de trabajo'),
(8630, 7248, 3, 'Compensación al Trabajador'),
(8631, 7249, 3, 'Indemnización de los trabajadores del Plan de Salud'),
(8632, 7250, 3, 'Beneficiario de edad trabajando o esposa con el Plan de Grupo de Salud Empleador'),
(8633, 7252, 3, 'Peor'),
(8634, 7253, 3, '¿Quieres que el saldo se aplique a la cuanta global?'),
(8635, 7254, 3, 'quiere marcarlo como borrado.'),
(8636, 7255, 3, '¿Quiere asignarlo?'),
(8637, 7256, 3, '¿Quiere Cancelar la distribución para este paciente?'),
(8638, 7257, 3, '¿Quiere borrar la distribución de pago?'),
(8639, 7258, 3, '¿Quiere borrar los pagos?'),
(8640, 7259, 3, '¿Quiere modificar y terminar los pagos?'),
(8641, 7260, 3, '¿Quiere modificar los pagos?'),
(8642, 7261, 3, '¿Quiere enviar y terminar los pagos?'),
(8643, 7262, 3, '¿Quiere enviar los pagos?'),
(8644, 7263, 3, '¿Quiere salvar?'),
(8645, 7264, 3, 'Muñeca'),
(8646, 7265, 3, 'Muñeca y mano'),
(8647, 7266, 3, 'Problemas de Mano'),
(8648, 7267, 3, 'escribir'),
(8649, 7268, 3, 'Borrar cuenta'),
(8650, 7270, 3, 'con algunos'),
(8651, 7271, 3, 'peso'),
(8652, 7273, 3, 'x Cancelado'),
(8653, 7274, 3, 'x Cancelado'),
(8654, 7275, 3, 'Rayos X'),
(8655, 7276, 3, 'Interpretación de RAYOS X:'),
(8656, 7277, 3, 'Interpretación de Rayos X:'),
(8657, 7278, 3, 'X12 solamente: Demanda del reemplazo '),
(8658, 7279, 3, 'Socio X12'),
(8659, 7280, 3, 'Socios X12'),
(8660, 7284, 3, 'A'),
(8661, 7285, 3, 'Año'),
(8662, 7286, 3, 'Año'),
(8663, 7287, 3, 'Ver año'),
(8664, 7288, 3, 'Año(s)'),
(8665, 7289, 3, 'Años'),
(8666, 7292, 3, 'SI'),
(8667, 7293, 3, 'Si'),
(8668, 7294, 3, 'si'),
(8669, 7295, 3, 'SI!'),
(8670, 7296, 3, 'Sí, Borrar y Registros'),
(8671, 7298, 3, 'Si/No'),
(8672, 7299, 3, 'Si:'),
(8673, 7300, 3, 'Judío'),
(8674, 7303, 3, 'Estás a punto de reemplazar permanentemente la plantilla existente. ¿Estás seguro de que desea continuar?'),
(8675, 7304, 3, 'Está en el periodo de Gracia de inicio de sesión. Cambie su contraseña antes de'),
(8676, 7305, 3, 'No está permitido eliminar este evento'),
(8677, 7306, 3, 'No está permitido a editar este evento'),
(8678, 7307, 3, 'Usted no está autorizado para esto.'),
(8679, 7308, 3, 'Usted no está autorizado para acceder a esta escuadra.'),
(8680, 7309, 3, 'No está autorizado para añadir/editar incidencias'),
(8681, 7310, 3, 'No está autorizado a programar citas'),
(8682, 7311, 3, 'Usted no está autorizado para ver este encuentro.'),
(8683, 7313, 3, 'No se puede acceder a esta función directamente.'),
(8684, 7314, 3, 'No se puede acceder a esta página directamente.'),
(8685, 7315, 3, 'Ud no puede añadir un valor en blanco para una categoria!'),
(8686, 7316, 3, 'Ud no puede añadir un valor en blanco para una subcategoria!'),
(8687, 7317, 3, 'Ud. no puede añadir un valor en blanco para un item!'),
(8688, 7318, 3, 'No puede poner una fecha futura, con un valor completo de SI.'),
(8689, 7319, 3, 'Usted no escogió ninguna acción.'),
(8690, 7320, 3, 'Usted no tiene acceso para ver o editar esta nota'),
(8691, 7321, 3, 'Ud. ha tratado de alterar contenido que está bloqueado. Quite el bloqueo si desea hacer ésto. Para desbloquear, elimine la línea, ''*lock::*'''),
(8692, 7322, 3, 'Ha sido desidentificado'),
(8693, 7323, 3, 'Sólo puede actualizar ficheros .txt'),
(8694, 7325, 3, 'Puede poner el texto aquí como queja por defecto en el formulario de visita de nuevo paciente.'),
(8695, 7326, 3, 'Debe introducir la frase clave para encriptar el documento'),
(8696, 7329, 3, 'Primero debe seleccionar o agregar un paciente.'),
(8697, 7330, 3, 'Primero debe seleccionar o crear un encuentro.'),
(8698, 7331, 3, 'Debe seleccionar una categoría de visita'),
(8699, 7332, 3, 'Ud. debe seleccionar una categoria para la visita'),
(8700, 7333, 3, 'Debe seleccionar algunos campos para continuar.'),
(8701, 7334, 3, 'Usted debe estar ejecutando esta prueba si esta reclamación aparece para generar con éxito, pero el fichero de reclamación actual no contiene datos o sólo una parte inconclusa de la cantidad de datos que se supone que contiene. Es evidente con reclamaciones HCFA porque son legibles, con reclamaciones X12 es más difícil un proceso para determinar si la demanda está bien completa.'),
(8702, 7335, 3, 'Debe seleccionar al menos un contexto'),
(8703, 7336, 3, 'Debe seleccionar al menos un Facultativo'),
(8704, 7339, 3, 'Su fecha de finalización no es válida'),
(8705, 7340, 3, 'Su evento ha sido suprimido'),
(8706, 7341, 3, 'Su evento ha sido modificado'),
(8707, 7342, 3, 'Su evento ha sido aceptado'),
(8708, 7343, 3, 'El fichero es demasiado grande'),
(8709, 7345, 3, 'Su nombre de la lista se ha cambiado para resolver requisitos de nombre.'),
(8710, 7347, 3, 'Su nombre para esta categoria, procedmiento o resultado'),
(8711, 7349, 3, 'Su Palabra Clave ha Expirado. Por favor cambie su contraseña.'),
(8712, 7350, 3, 'Su Contraseña expira en'),
(8713, 7351, 3, 'Su Contraseña expira hoy. Por favor cambie su contraseña.'),
(8714, 7353, 3, 'Su PostCalendar se ha reseteado para usar la configuración por defecto.'),
(8715, 7354, 3, 'Se ha actualizado su configuración de PostCalendar.'),
(8716, 7355, 3, 'Su frecuencia de repetición debe ser un número entero.'),
(8717, 7356, 3, 'Su frecuencia de repetición debe ser por lo menos 1.'),
(8718, 7357, 3, 'Su fecha de inicio es mayor que su fecha de finalización'),
(8719, 7358, 3, 'Su fecha de inicio no es válida'),
(8720, 7359, 3, 'Su sumisión falló.'),
(8721, 7360, 3, 'aaaa-mm-dd'),
(8722, 7361, 3, 'AAAA-MM-DD'),
(8723, 7362, 3, 'aaaa-mm-dd fecha asociada con este documento'),
(8724, 7363, 3, 'aaaa-mm-dd fecha destruida'),
(8725, 7364, 3, 'aaaa-mm-dd F.Nacim.'),
(8726, 7365, 3, 'aaaa-mm-dd F.Nacim.'),
(8727, 7366, 3, 'aaaa-mm-dd fecha de expiración'),
(8728, 7367, 3, 'aaaa-mm-dd Fecha de inicio o de hospitalización'),
(8729, 7368, 3, 'aaaa-mm-dd fecha de inicio, cirugía o comienzo de la medicación'),
(8730, 7369, 3, 'aaaa-mm-dd fecha de adquisicion o transferencia'),
(8731, 7370, 3, 'aaaa-mm-dd fecha de recuperación o al final de la medicación'),
(8732, 7371, 3, 'aaaa-mm-dd Fecha de volver a jugar'),
(8733, 7372, 3, 'aaaa-mm-dd Fecha de servicios'),
(8734, 7373, 3, 'aaaa-mm-dd fecha de esta carta'),
(8735, 7374, 3, 'aaaa-mm-dd fecha que volvió a jugar'),
(8736, 7375, 3, 'aaaa-mm-dd fecha del documento'),
(8737, 7376, 3, 'aaaa-mm-dd fecha de evento o fecha de inicio'),
(8738, 7381, 3, 'aaaa-mm-dd hh:mm:ss'),
(8739, 7383, 3, 'aaaa-mm-dd última fecha de este evento'),
(8740, 7387, 3, 'Cero'),
(8741, 7389, 3, 'Postal'),
(8742, 7390, 3, 'Código postal'),
(8743, 7391, 3, 'Postal/Pais'),
(8744, 7392, 3, 'Zulú'),
(8745, 7393, 3, ' pero ha sido '),
(8746, 7394, 3, ' no se ha podido acceder.'),
(8747, 7395, 3, 'Seguro que quiere borrar'),
(8748, 7396, 3, 'Medicamento'),
(8749, 7397, 3, 'emails no enviados'),
(8750, 7398, 3, 'de'),
(8751, 7399, 3, 'ha sido creado '),
(8752, 7400, 3, 'ha sido abierto de nuevo.'),
(8753, 7401, 3, 'Historia'),
(8754, 7402, 3, 'no es un número'),
(8755, 7403, 3, 'listo para refacturar'),
(8756, 7404, 3, 'LLL:'),
(8757, 7405, 3, 'Lote'),
(8758, 7406, 3, 'Nº de Referencia original de Medicaid '),
(8759, 7407, 3, 'min'),
(8760, 7408, 3, 'no encontrado!'),
(8761, 7409, 3, 'Peculiaridades en varios programas de exploración pueden asumir que la información abajo aparece bruscamente, y ocurren pausas extensas que aparentan que el sistema se ha dañado. Este no es el caso, y eventualmente verá información desplegada línea por línea. Podrían aparecer números secuenciales para indicar que aunque no aparezca nada más, el sistema tiene actividad. Estos números serán entremezclados con el contenido de la facturación, y es normal.'),
(8762, 7410, 3, 'la receta ha alcanzado el límite de'),
(8763, 7411, 3, 'hasta'),
(8764, 7412, 3, '¿falló la actualización, no está en la base de datos?'),
(8765, 7413, 3, 'marcado como solo facturado.'),
(8766, 7414, 3, 'puesto en cola.'),
(8767, 7415, 3, '! se retiró sin consulta'),
(8768, 7416, 3, '- para código'),
(8769, 7417, 3, '- está marcado en configuración PostCalendar'),
(8770, 7418, 3, '# Incidencia de seguro o financiero'),
(8771, 7419, 3, '# número de tabletas:'),
(8772, 7420, 3, '$'),
(8773, 7421, 3, '$ Codificado'),
(8774, 7422, 3, '$etiqueta (yyyy-mm-dd) '),
(8775, 7423, 3, '%'),
(8776, 7424, 3, '% Cancelado <24 hrs'),
(8777, 7425, 3, '% Cancelado < 24 hrs '),
(8778, 7426, 3, 'debería, pero no existe'),
(8779, 7427, 3, '(% Coincide con cualquier cadena, _ Coincide con cualquier carácter)'),
(8780, 7428, 3, '([ctrl] + click para seleccionar múltiples destinatarios)'),
(8781, 7429, 3, '(Volver)'),
(8782, 7430, 3, '(Haga clic para editar)'),
(8783, 7431, 3, '(el email tiene entrega inmediata, mientras que el mensaje de VOIP es enviado al proveedor del servicio para su proceso futuro)'),
(8784, 7432, 3, '(Mas)'),
(8785, 7433, 3, '(Nuevo Paciente)'),
(8786, 7434, 3, '(Notas y Autorizaciones)'),
(8787, 7435, 3, 'Notas del Paciente'),
(8788, 7436, 3, '(Seleccione uno de estos, o escriba su propio título)'),
(8789, 7437, 3, '(Shift-) Selecciona o arrastrar para cambiar valor'),
(8790, 7438, 3, '*Recordatorio realizado'),
(8791, 7439, 3, '** ¡Por Favor mover cirugías a incidencias!'),
(8792, 7440, 3, '* Requerido'),
(8793, 7441, 3, 'Historia Clínica retirada'),
(8794, 7442, 3, '- Ninguno'),
(8795, 7445, 3, '.'),
(8796, 7446, 3, '0'),
(8797, 7447, 3, '0-10'),
(8798, 7448, 3, '0-24'),
(8799, 7451, 3, '1'),
(8800, 7452, 3, '1=Norteamerica. Ver http://www.wtng.info/ para lista de códigos de otros países.'),
(8801, 7453, 3, 'Dentro de 1 día'),
(8802, 7454, 3, 'Dentro de 1 mes'),
(8803, 7455, 3, 'Dentro de 1 semana'),
(8804, 7456, 3, 'Dentro de 1 año'),
(8805, 7457, 3, '1. Descanso 2. Hielo por dos días 3. Compresión, dejar el vendaje en su lugar a menos que el pie presente hormigueo o color pálido 4. Elevar la pierna y el pie'),
(8806, 7458, 3, '11-14'),
(8807, 7459, 3, '12 hr'),
(8808, 7460, 3, '15-19'),
(8809, 7462, 3, '2'),
(8810, 7463, 3, 'Dentro de 2 días'),
(8811, 7464, 3, 'Dentro de 2 meses'),
(8812, 7465, 3, 'Dentro de 2 semanas'),
(8813, 7466, 3, 'Dentro de 2 años'),
(8814, 7468, 3, '20-24'),
(8815, 7477, 3, '2111-13'),
(8816, 7478, 3, '24 hr'),
(8817, 7479, 3, '25+'),
(8818, 7480, 3, '25-29'),
(8819, 7481, 3, '2da'),
(8820, 7482, 3, 'Dentro de 3 días'),
(8821, 7483, 3, '3 meses'),
(8822, 7484, 3, 'Dentro de 3 meses'),
(8823, 7485, 3, '3 veces al día'),
(8824, 7486, 3, 'Dentro de 3 semanas'),
(8825, 7487, 3, '30-34'),
(8826, 7488, 3, '35-39'),
(8827, 7489, 3, '3era'),
(8828, 7490, 3, 'Dentro de 4 días'),
(8829, 7491, 3, '4 meses'),
(8830, 7492, 3, 'Dentro de 4 meses'),
(8831, 7493, 3, '4 veces al día'),
(8832, 7494, 3, 'Dentro de 4 semanas'),
(8833, 7495, 3, '40-44'),
(8834, 7496, 3, '45+'),
(8835, 7497, 3, '465,9, URI'),
(8836, 7498, 3, '466.0, Bronquitis, Aguda'),
(8837, 7499, 3, '486.0, Neumonía, Aguda'),
(8838, 7500, 3, '491.21 Gravedad de Enfermedad Pulmonar Obstructiva Crónica'),
(8839, 7501, 3, '491.8, Bronquitis, Crónica'),
(8840, 7502, 3, '493.92, Asma, Aguda'),
(8841, 7503, 3, '496.0 Enfermedad Pulmonar Obstructiva Crónica'),
(8842, 7504, 3, '4ta'),
(8843, 7505, 3, 'Dentro de 5 días'),
(8844, 7506, 3, 'Dentro de 5 meses'),
(8845, 7507, 3, 'Dentro de 5 semanas'),
(8846, 7508, 3, '519.7, Broncoespasmo'),
(8847, 7509, 3, '5ta'),
(8848, 7510, 3, 'Dentro de 6 días'),
(8849, 7511, 3, '6 meses'),
(8850, 7512, 3, 'Dentro de 6 meses'),
(8851, 7513, 3, 'Dentro de 6 semanas'),
(8852, 7514, 3, '6ta'),
(8853, 7515, 3, 'Dentro de 7 meses'),
(8854, 7516, 3, 'Dentro de 8 meses'),
(8855, 7517, 3, '824.0 Fractura, maléolo tibial, cerrado'),
(8856, 7518, 3, '824.2 Fractura, maléolo lateral, cerrado'),
(8857, 7519, 3, '824,6 Fractura, Trimaleolar, cerrada'),
(8858, 7520, 3, '825.32 Fractura de navicular (tobillo)'),
(8859, 7521, 3, '825,35 Fractura, Base de la quinta (5 ª) metatarsianas'),
(8860, 7522, 3, '845,00 torcedura del tobillo NOS'),
(8861, 7523, 3, '845,01 Esquince ligamento tibial (Deltoides).'),
(8862, 7524, 3, '845,02 Torcedura, fibular Calcánea'),
(8863, 7525, 3, 'Dentro de 9 meses'),
(8864, 7526, 3, 'Establecido 99212 - sin complicaciones'),
(8865, 7527, 3, 'Establecido 99213 - Baja Complejidad'),
(8866, 7528, 3, '< en consultorio'),
(8867, 7529, 3, '> De Alta / Salida'),
(8868, 7531, 3, '? ausente'),
(8869, 7532, 3, '@ En Espera'),
(8870, 7533, 3, '[cambiar vista]'),
(8871, 7534, 3, '[Fecha de último encuentro]'),
(8872, 7535, 3, '[Días desde último encuentro]'),
(8873, 7536, 3, '[EOBs]'),
(8874, 7537, 3, '[Exportar OFX]'),
(8875, 7538, 3, '[no recomendado]'),
(8876, 7539, 3, '[Número de visitas]'),
(8877, 7540, 3, '[Informes]'),
(8878, 7541, 3, '[Seleccionar todos]'),
(8879, 7542, 3, '[SQL-Ledger]'),
(8880, 7543, 3, '[Iniciar Proceso batch]'),
(8881, 7544, 3, '[Visualizar registro]'),
(8882, 7545, 3, '[Ver reporte de variables]'),
(8883, 7546, 3, '_PC_DUR_HOURS'),
(8884, 7547, 3, '_PC_DUR_MINUTES'),
(8885, 7548, 3, '_PC_LOCALE'),
(8886, 7549, 3, '~ Llegó tarde'),
(8887, 1, 4, 'Un, Una'),
(8888, 2, 4, 'Un número de cheque o reclamación para identificar el pago'),
(8889, 3, 4, 'Un certificado del cliente para el usuario de admin'),
(8890, 4, 4, 'Adjunto está un documento clínico.'),
(8891, 5, 4, 'Adjunto está un documento clínico.'),
(8892, 7, 4, 'Se requiere un distribuidor'),
(8893, 8, 4, 'Formulario de visita GCAC debe ser agregado a esta visita'),
(8894, 9, 4, 'Un número de lote es requerido'),
(8895, 10, 4, 'Un número de lote es requerido!'),
(8896, 11, 4, 'Una letra minuscula'),
(8897, 12, 4, 'Un número'),
(8898, 14, 4, 'Un paciente con esta ID ya existe'),
(8899, 15, 4, 'Un paciente con este nombre ya existe'),
(8900, 16, 4, 'Un paciente con este numero de Seguro Social ya existe'),
(8901, 17, 4, 'Un número positivo mostrará tantas citas pasadas en un Widget en la pantalla de resumen del cliente (un número negativo mostrará las citas pasadas en orden descendente)'),
(8902, 18, 4, 'Un número positivo mostrará tantas citas pasadas en un Widget en la pantalla de resumen del cliente.'),
(8903, 19, 4, 'Una fuente de referencia puede ser especificada para cada visita'),
(8904, 20, 4, 'Un código IPPF relacionado es requerido'),
(8905, 21, 4, 'Un caracter especial'),
(8906, 22, 4, 'Un valor único para identificar este campo, no visible al usuario'),
(8907, 23, 4, 'Una visita ya existe para este paciente hoy día. Haga click en Cancelar para abrirla, o en OK para crear una nueva.'),
(8908, 24, 4, 'antes de las comidas'),
(8909, 25, 4, 'a.m.'),
(8910, 26, 4, 'Nivel aire/fluido correcto'),
(8911, 27, 4, 'AB'),
(8912, 28, 4, 'Abreviatura'),
(8913, 29, 4, 'Absceso'),
(8914, 30, 4, 'Abdominal'),
(8915, 31, 4, 'Capaz de cargar peso cuatro pasos'),
(8916, 32, 4, 'Anormal'),
(8917, 33, 4, 'ABN1'),
(8918, 34, 4, 'Anormal'),
(8919, 35, 4, 'Análisis de sangre anormal'),
(8920, 36, 4, 'Crecimiento anormal del pelo'),
(8921, 37, 4, 'Mamografía anormal'),
(8922, 39, 4, 'Aborto'),
(8923, 40, 4, 'Problemas del Aborto'),
(8924, 41, 4, 'Método de Aborto'),
(8925, 42, 4, 'Categorías relacionadas al Aborto'),
(8926, 43, 4, 'Abortos'),
(8927, 44, 4, 'Acerca del calendario'),
(8928, 46, 4, 'Ausencias por Diagnóstico'),
(8929, 47, 4, 'Aceptar la tarea'),
(8930, 48, 4, 'Aceptar pago por'),
(8931, 49, 4, 'Aceptar Pago por '),
(8932, 50, 4, 'Acepta tarea'),
(8933, 51, 4, 'Control de acceso'),
(8934, 52, 4, 'Administración de la Lista de Control de Acceso'),
(8935, 53, 4, 'Fecha de acceso'),
(8936, 54, 4, 'Acceso no permitido'),
(8937, 55, 4, 'Acceso no autorizado'),
(8938, 56, 4, 'Acceder al Portal del Paciente'),
(8939, 57, 4, 'Accidente'),
(8940, 59, 4, 'Nombre de la Cuenta'),
(8941, 62, 4, 'Contabilidad'),
(8942, 64, 4, 'Dolores'),
(8943, 65, 4, 'Solicitud de reconocimiento (ISA14)'),
(8944, 66, 4, 'Reconocimientos, Licencias y Certificaciones'),
(8945, 67, 4, 'ACL'),
(8946, 68, 4, 'Administración del ACL'),
(8947, 69, 4, 'Administración de ACL no autorizada'),
(8948, 70, 4, 'ACL actualizada exitósamente'),
(8949, 71, 4, 'Acné'),
(8950, 72, 4, 'Acta'),
(8951, 73, 4, 'Fecha de Acta'),
(8952, 74, 4, 'Accion'),
(8953, 75, 4, 'Acciones'),
(8954, 77, 4, 'Activar Reportes CCR/CCD'),
(8955, 78, 4, 'Activo'),
(8956, 79, 4, 'Alerta Activa'),
(8957, 80, 4, 'Reglas de Alerta Activa'),
(8958, 81, 4, 'Alertas activas/recordatorios'),
(8959, 82, 4, 'Encuentro Activo'),
(8960, 84, 4, 'Listas Activas'),
(8961, 85, 4, 'Paciente Activo'),
(8962, 86, 4, 'Planes Activos'),
(8963, 87, 4, 'Actividad'),
(8964, 88, 4, 'Tipo de Actividad'),
(8965, 90, 4, 'Intoxicación aguda/Retirada'),
(8966, 91, 4, 'Manifestación de condición crónica aguda'),
(8967, 92, 4, 'Agudo en Crónico'),
(8968, 93, 4, 'añadir'),
(8969, 94, 4, 'Añadir'),
(8970, 95, 4, 'AÑADIR'),
(8971, 96, 4, 'Añadir una compañía'),
(8972, 98, 4, 'Añadir una farmacia'),
(8973, 100, 4, 'Añadir un evento para '),
(8974, 101, 4, 'Añadir como nueva nota'),
(8975, 102, 4, 'Añadir como nuevo'),
(8976, 104, 4, 'Agregar Botones'),
(8977, 105, 4, 'Agregar botones para caracteres especiales, texto a mostrar encima del editor para incluir en el texto con un Click.'),
(8978, 106, 4, 'Añadir categoria'),
(8979, 107, 4, 'Añadir constante'),
(8980, 108, 4, 'Añadir contexto'),
(8981, 109, 4, 'Añadir Co-pago'),
(8982, 110, 4, 'Añadir Criterios'),
(8983, 111, 4, 'Añadir Boton Deseado'),
(8984, 112, 4, 'Añadir diagnóstico'),
(8985, 113, 4, 'Añadir medicamento'),
(8986, 114, 4, 'Añadir encuentro'),
(8987, 115, 4, 'Añadir encuentro/notas'),
(8988, 116, 4, 'Añadir Centro'),
(8989, 117, 4, 'Añadir Campo'),
(8990, 118, 4, 'Añadir las siguientes lineas al file de configuracion de Apache'),
(8991, 119, 4, 'Añadir grupo'),
(8992, 120, 4, 'Añadir código CIE'),
(8993, 121, 4, 'Agregar vacunación'),
(8994, 122, 4, 'Añadir no permitido!'),
(8995, 123, 4, 'Añadir Incidente'),
(8996, 124, 4, 'Añadir objeto a seguir'),
(8997, 125, 4, 'Añadir idioma'),
(8998, 126, 4, 'Añadir nuevo'),
(8999, 127, 4, 'Agregar Nuevo'),
(9000, 128, 4, 'Añadir nuevo categoría : '),
(9001, 129, 4, 'Añadir Certificados nuevos al archivo de configuracion de Apache'),
(9002, 130, 4, 'Añadir nuevo componente'),
(9003, 131, 4, 'Añadir nuevos componentes'),
(9004, 132, 4, 'Añadir nuevo grupo'),
(9005, 133, 4, 'Añadir nuevo problema'),
(9006, 134, 4, 'Añadir lote nuevo y transacción'),
(9007, 135, 4, 'Añadir nueva nota'),
(9008, 136, 4, 'Añadir nueva nota'),
(9009, 137, 4, 'Añadir nuevo socio'),
(9010, 138, 4, 'Añadir nuevo paciente'),
(9011, 140, 4, 'Añadir nota'),
(9012, 141, 4, 'Añadir registro del paciente'),
(9013, 142, 4, 'Añadir receta'),
(9014, 143, 4, 'Añadir procedimiento'),
(9015, 144, 4, 'Añadir numero del proveedor'),
(9016, 145, 4, 'Añadir Rehabilitacion'),
(9017, 146, 4, 'Añadir Regla'),
(9018, 147, 4, 'Añadir a'),
(9019, 148, 4, 'Añadir a lista de medicación'),
(9020, 149, 4, 'Añadir nivel superior'),
(9021, 150, 4, 'Añadir Transacción'),
(9022, 151, 4, 'Añadir usuario'),
(9023, 152, 4, 'Añadir Usuario al Grupo'),
(9024, 153, 4, 'Añadir/Editar eRx'),
(9025, 154, 4, 'Añadir/Editar transaccion de paciente'),
(9026, 155, 4, 'Añadido'),
(9027, 156, 4, 'No se autoriza añadir datos demograficos.'),
(9028, 157, 4, 'Añadir objeto a seguir falló'),
(9029, 158, 4, 'Síndrome de Addison'),
(9030, 159, 4, 'Síndrome de Addison'),
(9031, 160, 4, 'Atributos adicionales'),
(9032, 161, 4, 'Diagnóstico adicional:'),
(9033, 162, 4, 'Historial adicional'),
(9034, 163, 4, 'Notas adicionales de la historia'),
(9035, 164, 4, 'Información adicional'),
(9036, 165, 4, 'Laboratorios adicionales'),
(9037, 166, 4, 'Notas adicionales'),
(9038, 167, 4, 'Notas adicionales para este resultado o recomendación'),
(9039, 168, 4, 'Notas adicionales:'),
(9040, 169, 4, 'Notas adicionales: '),
(9041, 170, 4, 'Notas de Rayos X adicionales:'),
(9042, 172, 4, 'solo añadir'),
(9043, 173, 4, 'Lbta Direcciones'),
(9044, 174, 4, 'Lbta Direcciones'),
(9045, 175, 4, 'Dirección'),
(9046, 178, 4, 'Libreta de direcciones'),
(9047, 179, 4, 'Entrada al Libro de Direcciones para la compañia que hace este procedimiento'),
(9048, 180, 4, 'Entrada al libro de Direcciones para el distribuidor'),
(9049, 181, 4, 'Entrada al Libro de Direcciones para el vendedor'),
(9050, 182, 4, 'Tipos de Libro de Direcciones'),
(9051, 183, 4, 'Etiqueta de dirección'),
(9052, 187, 4, 'Dirección1'),
(9053, 188, 4, 'Dirección2'),
(9054, 189, 4, 'DESTINATARIO'),
(9055, 190, 4, 'Ajuste'),
(9056, 191, 4, 'Monto de Ajuste'),
(9057, 192, 4, 'Ajustar'),
(9058, 193, 4, 'Ajuste'),
(9059, 194, 4, 'Ajuste importe'),
(9060, 195, 4, 'Motivos del ajuste'),
(9061, 196, 4, 'Valor de ajuste para código '),
(9062, 197, 4, 'Ajustes'),
(9063, 198, 4, 'Ajuste administrativo'),
(9064, 199, 4, 'Administrativo'),
(9065, 200, 4, 'Dirección correo electrónico administración'),
(9066, 201, 4, 'Via de administracion'),
(9067, 202, 4, 'Administrado'),
(9068, 203, 4, 'Administrado por'),
(9069, 204, 4, 'Fecha de administrado'),
(9070, 205, 4, 'Sitio de administrado'),
(9071, 206, 4, 'Administración'),
(9072, 207, 4, 'Sitio de administración'),
(9073, 208, 4, 'Administradores'),
(9074, 209, 4, 'Los administradores pueden hacer cualquier cosa'),
(9075, 210, 4, 'Fecha de admisión'),
(9076, 212, 4, 'Revisión Peso de Adulto y Seguimiento'),
(9077, 213, 4, 'Revisión Peso de Adulto y Seguimiento (GCC)'),
(9078, 214, 4, 'Instrucción anticipada'),
(9079, 215, 4, 'Directivas Avanzadas'),
(9080, 216, 4, 'Aviso Directivas Avanzadas'),
(9081, 218, 4, 'Avanzado'),
(9082, 219, 4, 'Consejo'),
(9083, 221, 4, 'Afecta normales'),
(9084, 223, 4, 'llamadas fuera horario laboral'),
(9085, 225, 4, 'Despues de hacer las configuraciones mencionadas, importar el certificado de cliente de admin al navegador y reiniciar el server Apache (Palabra clave vacia)'),
(9086, 226, 4, 'Después de guardar el PDF, clic [Ver registro] para comprobar si hay errores.'),
(9087, 227, 4, 'Despues de guardar los archivos de TEXTO, clic [Ver registro] para comprobar errores.'),
(9088, 228, 4, 'Después de guardar su lote, clic [Ver registro] para comprobar si hay errores.'),
(9089, 230, 4, 'Una vez completada la informacion correcta, clic guardar'),
(9090, 233, 4, 'Otra vez'),
(9091, 234, 4, 'Edad'),
(9092, 235, 4, 'Edad por'),
(9093, 236, 4, 'Categoría edad'),
(9094, 237, 4, 'Datos de edad están fuera de rango.'),
(9095, 239, 4, 'Formato de edad para ''desde x edad'' no es válido'),
(9096, 240, 4, 'Formato de edad para ''hasta x edad'' no es válido'),
(9097, 241, 4, 'Edad desde'),
(9098, 243, 4, 'Edad Maxima'),
(9099, 244, 4, 'Edad Minima'),
(9100, 245, 4, 'Rango de Edad'),
(9101, 247, 4, 'Columnas envejecimiento:'),
(9102, 249, 4, 'Albanés'),
(9103, 250, 4, 'Alcohol'),
(9104, 251, 4, 'Consumo de alcohol'),
(9105, 253, 4, 'Conteo de Alerta'),
(9106, 255, 4, 'Alertas'),
(9107, 258, 4, 'Aleutiano'),
(9108, 259, 4, 'Todos'),
(9109, 260, 4, 'TODOS'),
(9110, 261, 4, 'Todos (Formatos Cotejados A)'),
(9111, 262, 4, 'Todos (Formatos Cotejados B)'),
(9112, 263, 4, 'Todos (Acumulativo)'),
(9113, 266, 4, 'Todas las categorías'),
(9114, 268, 4, 'Todos los Codigos'),
(9115, 269, 4, 'Todo el día'),
(9116, 270, 4, 'Evento de día completo'),
(9117, 271, 4, 'Verificacion con busqueda de Demograficas y duplicados'),
(9118, 272, 4, 'Todas los Centros'),
(9119, 273, 4, 'Toda Injuria/Problema/Questiones'),
(9120, 274, 4, 'Permitir todos los Idiomas'),
(9121, 276, 4, 'Todo o parte del nombre'),
(9122, 277, 4, 'Todo o parte del apellido'),
(9123, 278, 4, 'Nombre de la organización parcial o completo'),
(9124, 280, 4, 'Todos los productos'),
(9125, 281, 4, 'Todos los provedores'),
(9126, 282, 4, 'Todos revisados y negativos:'),
(9127, 283, 4, 'Todos los temas'),
(9128, 284, 4, 'Todos los usuarios'),
(9129, 285, 4, 'Alérgico'),
(9130, 286, 4, 'Alergias'),
(9131, 287, 4, 'Alergias:'),
(9132, 288, 4, 'Alergia'),
(9133, 289, 4, 'Importe de Alergia completado con exito'),
(9134, 291, 4, 'Reacción Alérgica'),
(9135, 294, 4, 'Asignar'),
(9136, 295, 4, 'Permitir'),
(9137, 296, 4, 'Permitir todos los idiomas disponibles en el menu de inicio'),
(9138, 297, 4, 'Permitir creación de reclamos (facturas) con diagnósticos pero no procedimientos o cargos. Muchas clinicas no desean esto.'),
(9139, 298, 4, 'Permitir depuracion de Lenguaje'),
(9140, 299, 4, 'Permitir el Email'),
(9141, 300, 4, '¿Permitir los correos electrónicos?'),
(9142, 301, 4, '¿Permitir Email?'),
(9143, 302, 4, 'Permitir reclamos de encuentros'),
(9144, 303, 4, 'Permitir el intercambio de informacion medica'),
(9145, 304, 4, 'Permitir compartir informacion de inmunizaciones'),
(9146, 305, 4, 'Permitir el registro de uso de inmunizaciones'),
(9147, 306, 4, 'Permitir el mensaje de correo'),
(9148, 308, 4, 'Permitir Portal del Paciente'),
(9149, 309, 4, 'Permitir SMS'),
(9150, 310, 4, '¿Permitir SMS (mensaje de texto)?'),
(9151, 311, 4, 'Permitir la activación instantánea de los eventos entrados?'),
(9152, 312, 4, '¿Permitir mensaje telefonico?'),
(9153, 313, 4, 'Permitir a los usuarios publicar eventos globales'),
(9154, 314, 4, 'Permitir a los usuarios publicar calendarios personales'),
(9155, 315, 4, 'Permitir Mensaje de Voz'),
(9156, 316, 4, 'Permitido'),
(9157, 317, 4, 'Idiomas Permitidos'),
(9158, 318, 4, 'Asignado ©'),
(9159, 323, 4, 'ya existe.'),
(9160, 324, 4, 'ya existe.'),
(9161, 325, 4, 'Indentificador ya usado, elige otro'),
(9162, 326, 4, 'Título ya usado, elige otro'),
(9163, 327, 4, 'Dirección alternativa'),
(9164, 328, 4, 'modificar'),
(9165, 329, 4, 'De forma alternativa, puede usar la página de búsqueda para cargar un archivo electrónico (X12835) que haya recibido de su pagador. Puede hacerlo oprimiendo el botón "Explorar" y seleccionar el archivo a cargar, y luego oprimir "Explorar" para ejecutar la carga y desplegar las facturas correspondientes. En este caso, los parámetros mencionados arriba no aplican y pueden ser ignorados. La carga guarda el archivo pero no procesa su contenido - esto se realiza de forma separada tal y como se describe abajo.'),
(9166, 330, 4, 'AM'),
(9167, 331, 4, 'Programa en AM'),
(9168, 332, 4, 'Calculo Automatico de Medidas (CAM)'),
(9169, 333, 4, 'Rastreo CAM'),
(9170, 338, 4, 'Enmendar nota existente'),
(9171, 341, 4, 'Cambios'),
(9172, 343, 4, 'Indigena americano'),
(9173, 344, 4, 'Indio Nativo (EU) o Esquimal'),
(9174, 345, 4, 'AMEX'),
(9175, 346, 4, 'Amárico (Lengua de Etiopia)'),
(9176, 347, 4, 'Balance'),
(9177, 349, 4, 'Cantidad cargada'),
(9178, 350, 4, 'Cantidad para balance anterior'),
(9179, 351, 4, 'Cantidad por esta visita'),
(9180, 352, 4, 'Cantidad pagada'),
(9181, 353, 4, 'Balance:'),
(9182, 354, 4, 'Importe Facturado'),
(9183, 355, 4, '¡Se requiere una fecha de finalización posterior a la fecha de inicio para los eventos repetidos!'),
(9184, 357, 4, 'Ocurrió un error al vaciar el directorio de arbol de la web LibreEHR'),
(9185, 358, 4, 'Ocurrió un error al vaciar el directorio de arbol de la web phpGACL'),
(9186, 359, 4, 'Ocurrió un error al vaciar el directorio de arbol de la web SQL-Ledger'),
(9187, 360, 4, 'Se ha creado y se ha ligado una edición incompleta de GCAC. Alguien necesitará terminarla más adelante.'),
(9188, 362, 4, 'Ocurrio error inesperado'),
(9189, 363, 4, 'Una letra mayuscula'),
(9190, 365, 4, 'Y'),
(9191, 366, 4, 'Y'),
(9192, 367, 4, 'y'),
(9193, 368, 4, 'y '),
(9194, 369, 4, '¿y toda la información subordinada? Esta acción será registrada'),
(9195, 370, 4, 'y modificador'),
(9196, 371, 4, 'y procesado'),
(9197, 372, 4, 'y reiniciar Servidor Apache'),
(9198, 373, 4, 'y la razon es'),
(9199, 374, 4, 'Anemia'),
(9200, 375, 4, 'Tobillo'),
(9201, 376, 4, 'Tobillo + talón'),
(9202, 377, 4, 'Formulario de Evaluación del tobillo'),
(9203, 378, 4, 'Problemas de tobillo'),
(9204, 379, 4, 'Espondilitis anquilosante'),
(9205, 380, 4, 'Espondilitis anquilosante'),
(9206, 381, 4, 'Anorexia'),
(9207, 382, 4, 'Otra cosa que puede hacer en la ventana de publicación es solicitar facturación secundaria. Si selecciona la casilla de verificación antes de guardar, la reclamación original será reabierta y asignada en la página de Facturación, y será procesada en la siguiente corrida de facturación.'),
(9208, 383, 4, 'ante'),
(9209, 384, 4, 'Ano normal, recto sin distension ni masa'),
(9210, 385, 4, 'Ansiedad'),
(9211, 386, 4, 'Cualquiera'),
(9212, 387, 4, 'Cualquier categoría'),
(9213, 388, 4, 'Cualquier parte del código deseado o su descripción'),
(9214, 389, 4, 'Cualquier parte de la especialidad deseada'),
(9215, 390, 4, 'Parte de identificador o Nombre de Medicamento'),
(9216, 391, 4, 'Parte de identificador o Nombre de Vacuna'),
(9217, 392, 4, 'Cualquier parte del nombre del paciente, o "Apellido, Nombre", o "X-Y"'),
(9218, 394, 4, 'API para la puerta de enlace SMS'),
(9219, 395, 4, 'Apnea'),
(9220, 396, 4, 'Aspecto'),
(9221, 397, 4, 'Aspecto:'),
(9222, 398, 4, 'Añadir esta nota'),
(9223, 399, 4, 'Añadir a la nota existente'),
(9224, 400, 4, 'Añadir a esta nota'),
(9225, 401, 4, 'Añadir a Esta Nota'),
(9226, 402, 4, 'Apendicectomía'),
(9227, 404, 4, 'Pacientes Aplicables'),
(9228, 406, 4, 'Nombre de solicitud para página de ingreso y título de ventana principal'),
(9229, 407, 4, 'Código de Aplicación del receptor (GS03 - si está en blanco se usará ISA08)'),
(9230, 408, 4, 'Codigo de Aplicacion del Enviador'),
(9231, 409, 4, 'Título de la Aplicación'),
(9232, 410, 4, 'Aplica al formulario de Signos Vitales y Cartilla de Crecimiento'),
(9233, 412, 4, 'Aplicar los cambios a la cita actual solamente, a este y todos los acontecimientos futuros, o para Todos los casos?'),
(9234, 413, 4, 'aplicar a la zona afectada'),
(9235, 414, 4, 'aplicar a la piel'),
(9236, 415, 4, 'Aplicando'),
(9237, 416, 4, 'Aplicando parche al sitio'),
(9238, 417, 4, 'Cita'),
(9239, 418, 4, 'Fecha de Cita'),
(9240, 419, 4, 'Estilo de visualizacion de la cita'),
(9241, 420, 4, 'Regla para recordar Cita'),
(9242, 421, 4, 'Estado de la Cita'),
(9243, 422, 4, 'Estados de la cita'),
(9244, 423, 4, 'Cita dentro');
INSERT INTO `lang_definitions` VALUES
(9245, 424, 4, 'Color de Cita/Evento'),
(9246, 425, 4, 'Citas'),
(9247, 426, 4, 'Citas (escriba opcional)'),
(9248, 427, 4, 'Citas (escribir, algunos opcional)'),
(9249, 430, 4, 'Citas y encuentros'),
(9250, 431, 4, 'Informe Citas'),
(9251, 432, 4, 'Informes Citas-Encuentros'),
(9252, 434, 4, 'Aprobar'),
(9253, 436, 4, 'Aprobado'),
(9254, 437, 4, 'Eventos Administrativos Aprobados'),
(9255, 440, 4, 'Citas-Encuentros'),
(9256, 441, 4, 'Citas'),
(9257, 442, 4, 'Abr'),
(9258, 443, 4, 'Abril'),
(9259, 444, 4, 'Arabigo'),
(9260, 446, 4, 'Archivo'),
(9261, 447, 4, '¿Se traducirán los nombres del grupo de control de acceso?'),
(9262, 448, 4, '¿Se traducirán los nombres de las categorías de citas?'),
(9263, 449, 4, '¿Se traducirán los nombres de categorías de documentos?'),
(9264, 450, 4, 'Son cobrados los honorarios por este tipo?'),
(9265, 451, 4, '¿Se traducirán los títulos de las notas del paciente?'),
(9266, 452, 4, '¿Están los códigos almacenados en tablas SQL externas? (0: No; 1: “ICD10”; 2: “SNOMED(RF1)”; 3: “SNOMED(RF2)”)'),
(9267, 453, 4, '¿Está preparado para completar una nueva incidencia de GCAC (Global Connection Admission Control) para esta visita?'),
(9268, 454, 4, '¿Está seguro de enviar hoy?'),
(9269, 455, 4, '¿Estás seguro quer quieres aprobar estos eventos?'),
(9270, 457, 4, '¿Estás seguro de que deseas eliminar por completo este formulario?'),
(9271, 459, 4, '¿Está seguro que desea eliminar este acceso?'),
(9272, 460, 4, '¿Estás seguro que quieres eliminar estos eventos?'),
(9273, 461, 4, '¿Esta seguro que quiere eliminar este item de la base de datos?'),
(9274, 462, 4, '¿Está usted seguro usted quiere suprimir esta nota?'),
(9275, 464, 4, '¿Estás seguro que quieres editar estos eventos?'),
(9276, 465, 4, '¿Estás seguro que quieres ocultar estos eventos?'),
(9277, 467, 4, '¿Estás seguro que quieres visualizar estos eventos?'),
(9278, 468, 4, 'Está usted seguro usted que desea suprimir al grupo entero nombrado'),
(9279, 469, 4, 'Está usted seguro que desea suprimir la lista entera'),
(9280, 470, 4, 'Está usted seguro que quiere suprimir el campo interno'),
(9281, 471, 4, '¿Está usted seguro que quiere borrar los campos seleccionados?'),
(9282, 472, 4, '¿Estás seguro que quieres continuar con estas acciones?'),
(9283, 473, 4, 'Zona no especificada'),
(9284, 474, 4, 'Brazo'),
(9285, 475, 4, 'Armenio'),
(9286, 477, 4, 'Arritmia'),
(9287, 478, 4, 'Artritis'),
(9288, 479, 4, 'Artritis / Enfermedad degenerativa de articulaciones'),
(9289, 480, 4, 'Artritis / Enfermedad degenerativa de articulaciones'),
(9290, 481, 4, 'como'),
(9291, 482, 4, 'Desde'),
(9292, 484, 4, 'Asiático'),
(9293, 487, 4, 'Evaluación'),
(9294, 488, 4, 'Asignado a'),
(9295, 489, 4, 'Ayudante'),
(9296, 490, 4, 'Asma'),
(9297, 491, 4, 'en'),
(9298, 492, 4, 'Se requiere al menos un parámetro de búsqueda si usted seleccionó Todos'),
(9299, 493, 4, 'En el Escafoides'),
(9300, 494, 4, 'En el Escafoides:'),
(9301, 495, 4, 'Equipo de atletismo'),
(9302, 497, 4, 'Lesión Deportiva'),
(9303, 498, 4, 'Certificado CA de ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(9304, 499, 4, 'Anfitrión de audito ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(9305, 500, 4, 'Certificado local de ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(9306, 501, 4, 'Puerto de audito ATNA (Seguimiento de auditoría y autenticación del nodo)'),
(9307, 503, 4, 'Atención'),
(9308, 504, 4, 'Atención'),
(9309, 509, 4, 'Copias de seguridad de registro de auditoría'),
(9310, 510, 4, 'Miscelaneos de Registro de auditoría'),
(9311, 511, 4, 'Orden de Registro de auditoría'),
(9312, 512, 4, 'Registro de auditoría de registro del paciente'),
(9313, 513, 4, 'Planificación registro de auditoría'),
(9314, 514, 4, 'Registro de auditoría Administración de la Seguridad'),
(9315, 515, 4, 'Registro de auditoría consulta SELECT'),
(9316, 516, 4, 'Ago'),
(9317, 517, 4, 'Agosto'),
(9318, 519, 4, 'Autorización'),
(9319, 520, 4, 'Autorizacion/Notas'),
(9320, 523, 4, 'Grupo de Autorizacion'),
(9321, 524, 4, 'Estatus de autorización'),
(9322, 525, 4, 'Autorizaciones'),
(9323, 526, 4, 'Autorizar'),
(9324, 527, 4, 'Autorice - cualquier encuentro'),
(9325, 528, 4, 'Autorice - mis encuentros'),
(9326, 530, 4, 'Autorizado'),
(9327, 531, 4, 'Autorizacion solamente'),
(9328, 532, 4, 'Mandar automáticamente'),
(9329, 535, 4, 'Crear automaticamente nuevos encuentros'),
(9330, 536, 4, 'Auto-generado'),
(9331, 537, 4, 'Calculos Automaticos de Medida (CAM)'),
(9332, 542, 4, 'Rastreo Calculos Automaticos de Medida (CAM)'),
(9333, 543, 4, 'Medidas Automatizadas'),
(9334, 544, 4, 'Automatica'),
(9335, 546, 4, 'Crear automáticamente nuevos encuentros cuando el estado de una cita se selecciona en "@" (llegado)'),
(9336, 549, 4, 'Automovil Medico'),
(9337, 550, 4, 'Guardado automáticamente'),
(9338, 551, 4, 'Categorias Disponibles'),
(9339, 552, 4, 'Horas disponbiles'),
(9340, 557, 4, 'Media Mensual'),
(9341, 558, 4, 'Avulsión / fractura por avulsión'),
(9342, 559, 4, 'Avulsión de maleolo lateral'),
(9343, 560, 4, 'Avulsión de maleolo medial '),
(9344, 561, 4, 'Basado en Conocimiento'),
(9345, 562, 4, 'Axilar'),
(9346, 565, 4, 'dos veces por día'),
(9347, 566, 4, 'Atrás'),
(9348, 567, 4, 'atrás'),
(9349, 568, 4, 'Retrocede ocho visitas'),
(9350, 569, 4, 'Retroceder once visitas'),
(9351, 570, 4, 'Retroceder cinco visitas'),
(9352, 571, 4, 'Retroceder cuatro visitas'),
(9353, 572, 4, 'Retroceder nueve visitas'),
(9354, 573, 4, 'Retroceder una visita'),
(9355, 574, 4, 'Dolor de Espaldas'),
(9356, 575, 4, 'Problemas de espalda'),
(9357, 576, 4, 'Retroceder siete visitas'),
(9358, 577, 4, 'Retroceder seis visitas'),
(9359, 578, 4, 'Cirugia de la espalda'),
(9360, 579, 4, 'Retroceder diez visitas'),
(9361, 580, 4, 'Retroceder tres visitas'),
(9362, 581, 4, 'Volver a la página de Administración'),
(9363, 582, 4, 'Volver a encuentro'),
(9364, 583, 4, 'Volver al paciente'),
(9365, 584, 4, 'Volver al paciente'),
(9366, 585, 4, 'Volver a los usuarios'),
(9367, 586, 4, 'Volver a Vista'),
(9368, 587, 4, 'Retroceder doce visitas'),
(9369, 588, 4, 'Retroceder dos visitas'),
(9370, 590, 4, 'Backup'),
(9371, 591, 4, 'Se ha creado el archivo de respaldo, ahora empezará la descarga'),
(9372, 593, 4, 'Archivo de respaldo creado con exito'),
(9373, 594, 4, 'Cheque sin fondos'),
(9374, 595, 4, 'Mal crédito'),
(9375, 596, 4, 'Bahasa Indonesia'),
(9376, 597, 4, 'Bal'),
(9377, 598, 4, 'Balance'),
(9378, 599, 4, 'balance'),
(9379, 600, 4, 'Importe Balance'),
(9380, 601, 4, 'Balance a pagar'),
(9381, 603, 4, 'Letra Bancaria'),
(9382, 607, 4, 'Base del quinto (5to) Metatarsiano'),
(9383, 608, 4, 'Base del quinto (5to) Metatarsiano:'),
(9384, 612, 4, 'Herramienta de Comunicación para series'),
(9385, 613, 4, 'Entrada de pagos en serie (Batch)'),
(9386, 614, 4, 'Pagos en serie'),
(9387, 615, 4, 'Proceso de Batch iniciado; puede tomar unos minutos'),
(9388, 616, 4, 'Resultados del lote'),
(9389, 617, 4, 'Comunicación'),
(9390, 618, 4, 'Sea paciente, puede demorar varios minutos para procesar'),
(9391, 619, 4, 'porque no existe esa número de identificación.'),
(9392, 620, 4, 'Empezar'),
(9393, 621, 4, 'Fecha de comienzo'),
(9394, 623, 4, 'Fecha de inicio de servicio aaaa-mm.dd'),
(9395, 624, 4, 'Hora de inicio del día para los eventos del calendario'),
(9396, 626, 4, 'Eructo'),
(9397, 628, 4, 'Bengali'),
(9398, 630, 4, 'entre'),
(9399, 633, 4, 'Bilateral'),
(9400, 634, 4, 'Bilateral:'),
(9401, 636, 4, 'Fecha factura:'),
(9402, 637, 4, 'Facturar/Cobrar'),
(9403, 638, 4, 'Facturado'),
(9404, 640, 4, 'Facturación'),
(9405, 641, 4, 'Facturación (escritura opcional)'),
(9406, 642, 4, 'Atención factura'),
(9407, 644, 4, 'Código de factura para el Servicio Solicitado'),
(9408, 645, 4, 'Código de factura'),
(9409, 646, 4, 'Datos de factura'),
(9410, 647, 4, 'Departamento de Facturación'),
(9411, 648, 4, 'Centro de Facturacion'),
(9412, 649, 4, 'Información factura'),
(9413, 650, 4, 'Dirección para factura'),
(9414, 655, 4, 'Administrador de Facturación'),
(9415, 656, 4, 'Nota de factura'),
(9416, 657, 4, 'Nota de factura para '),
(9417, 658, 4, 'Nota de factura:'),
(9418, 659, 4, 'Resultados de la cola de facturación:'),
(9419, 660, 4, 'Informe de Facturación'),
(9420, 661, 4, 'Estado de facturación'),
(9421, 662, 4, 'Estado de Facturación = no facturados'),
(9422, 663, 4, 'factura para '),
(9423, 665, 4, 'Biopsia'),
(9424, 666, 4, 'F.Nacim.'),
(9425, 669, 4, 'Negro'),
(9426, 670, 4, 'Pulmón ennegrecido'),
(9427, 671, 4, 'Negro o Afro Americano'),
(9428, 672, 4, 'Cáncer de vejiga'),
(9429, 673, 4, 'Infecciones de vejiga'),
(9430, 674, 4, 'Formas en blanco'),
(9431, 675, 4, 'Problemas de sangrado'),
(9432, 676, 4, 'Puntos Ciegos'),
(9433, 677, 4, 'Hinchazón'),
(9434, 678, 4, 'Atascado'),
(9435, 679, 4, 'Sangre'),
(9436, 680, 4, 'Presión Arterial'),
(9437, 681, 4, 'Presión arterial'),
(9438, 682, 4, 'Sangra de la nariz'),
(9439, 683, 4, 'Blue Cross Blue Shield'),
(9440, 684, 4, 'En este reporte líneas azules son informativas. Líneas negras muestran información existente. Líneas verdes muestran cambios aplicados exitosamente. Líneas rojas indican errores o cambios que no fueron aplicados, y deben ser procesados manualmente. Reclamos denegados y pagos revertidos no se manejan automáticamente y aparecerán en rojo.'),
(9441, 685, 4, 'Visión borrosa'),
(9442, 686, 4, 'IMC'),
(9443, 687, 4, 'Estado del IMC'),
(9444, 689, 4, 'Región corporal'),
(9445, 690, 4, 'Área Corporall'),
(9446, 691, 4, 'Área corporal si aplica'),
(9447, 692, 4, 'Sensibilidad en hueso:'),
(9448, 693, 4, 'Sensibilidad en hueso: Maléolo Tibial'),
(9449, 694, 4, 'Boleano'),
(9450, 696, 4, 'Infer'),
(9451, 697, 4, 'Ambos Oídos'),
(9452, 698, 4, 'ambas orejas/ ambos oídos'),
(9453, 699, 4, 'Parte inferior'),
(9454, 701, 4, 'CAJA 10 A. relacionados con el Empleo '),
(9455, 702, 4, 'CAJA 10 B. Accidentes de Autos '),
(9456, 703, 4, 'CAJA 10 C. Otros Accidentes '),
(9457, 706, 4, 'CAJA 15. Día en el que tuvo la misma enfermedad, o alguna similar (aaaa-mm-dd):'),
(9458, 708, 4, 'CAJA 16. Fecha de incapacidad de trabajar apartir de (aaaa-mm-dd):'),
(9459, 709, 4, 'CAJA 16. Fecha incapacidad de trabajar (aaaa-mm-dd):'),
(9460, 710, 4, 'CAJA 18. Fecha de incicio de hospitalización (aaaa-mm-dd): '),
(9461, 711, 4, 'CAJA 18. Fecha de inicio de hospitalización a (aaaa-mm-dd): '),
(9462, 712, 4, 'CASILLA 20. ¿Se utiliza Laboratorio externo?'),
(9463, 713, 4, 'CAJA 22. Código de la resumisión de Medicaid (ICD-9) '),
(9464, 714, 4, 'CAJA 23. Número de Autorización previa '),
(9465, 715, 4, 'TA'),
(9466, 716, 4, 'PA Diastólica'),
(9467, 717, 4, 'PA Sistólica'),
(9468, 719, 4, 'Pad'),
(9469, 721, 4, 'Pas'),
(9470, 722, 4, 'Portugués brasileño'),
(9471, 723, 4, 'Seno'),
(9472, 724, 4, 'Biopsia del Seno'),
(9473, 725, 4, 'Secrecion del seno'),
(9474, 726, 4, 'Enfermedad de la mama'),
(9475, 727, 4, 'Revisión mama'),
(9476, 728, 4, 'Masa en la mama'),
(9477, 730, 4, 'Sonidos respiratorios:'),
(9478, 732, 4, 'Huesos fracturados'),
(9479, 734, 4, 'Formulario de bronquitis'),
(9480, 735, 4, 'Explorar'),
(9481, 736, 4, 'Explorar para Registro'),
(9482, 737, 4, 'Contusiones/Hematomas'),
(9483, 739, 4, 'Abultamiento derecho:'),
(9484, 741, 4, 'Ardor al orinar'),
(9485, 742, 4, 'Ardor al orinar'),
(9486, 744, 4, 'Ocupado'),
(9487, 745, 4, 'pero todavía no procesado.'),
(9488, 746, 4, 'Gluteos'),
(9489, 747, 4, 'Gluteos + S.I.'),
(9490, 748, 4, 'por'),
(9491, 749, 4, 'Por'),
(9492, 750, 4, 'por boca'),
(9493, 751, 4, 'Por / Fuente'),
(9494, 752, 4, 'Por:'),
(9495, 753, 4, 'C'),
(9496, 754, 4, 'Certificado de CA para verificar el RFC 5425 TLS del servidor syslog.'),
(9497, 755, 4, 'Tiempo de Vida del Cache (en segundos)'),
(9498, 756, 4, '¿Plantilla de salida del caché?'),
(9499, 757, 4, 'Consumo de cafeína'),
(9500, 758, 4, 'Calendario'),
(9501, 759, 4, 'Hora de finalización del calendario'),
(9502, 760, 4, 'Intervalo Calendario'),
(9503, 761, 4, 'Pantalla de calendario'),
(9504, 762, 4, 'Ajustes del calendario'),
(9505, 763, 4, 'Hora de inicio de calendario'),
(9506, 764, 4, 'Calendario UI'),
(9507, 765, 4, 'Vista de Calendario'),
(9508, 766, 4, 'Llamada para añadir Formulario () va aquí.<br>'),
(9509, 767, 4, 'Calorias'),
(9510, 768, 4, 'Camboyano'),
(9512, 774, 4, 'Cancelar'),
(9513, 775, 4, 'Cancelar cambios'),
(9514, 776, 4, 'Cancelado'),
(9515, 777, 4, 'Cáncer'),
(9516, 778, 4, 'Detección de Cancer: Detección Cancer de Colon'),
(9517, 779, 4, 'Detección de Cancer: Mamograma'),
(9518, 780, 4, 'Detección de Cancer: Prueba de Papanicolau'),
(9519, 781, 4, 'Detección de Cancer: Detección de Cancer de Prostata'),
(9520, 782, 4, 'No se puede agregar esta entrada, ¡por que ya existe!'),
(9521, 783, 4, '¡No se puede agregar/actualizar esta entrada porque ya existe un duplicado!'),
(9522, 785, 4, 'no puede convertirse a JPEG. ¿probablemente ImageMagick no está instalado?'),
(9523, 787, 4, 'no se puede mostrar en línea porque su tipo no es soportado por el navegador.'),
(9524, 788, 4, 'no se puede mostrar en línea porque su tipo no es soportado por el navegador'),
(9525, 789, 4, 'no se puede mostrar en línea porque su tipo no es soportado por el navegador.'),
(9526, 790, 4, 'No se puede crear'),
(9527, 795, 4, 'No se puede encontrar '),
(9528, 796, 4, 'No se puede encontrar archivo de destino'),
(9529, 799, 4, 'No puede encontrar al paciente con esa identificación en SQL-Libro mayor'),
(9530, 800, 4, 'No se puede encontrar el documento de referencia de postdata en '),
(9531, 801, 4, 'No puede encontrar el proveedor del empleado del SQL-Libro mayor = '),
(9532, 802, 4, 'No puede modificar los pagos. La distribución es negativa.'),
(9533, 803, 4, 'No se puede abrir '),
(9534, 804, 4, 'No hay mensajes de Seguros. La entidad que paga seleccionada un Paciente.'),
(9535, 805, 4, 'No puede enviar para Paciente. La Entidad de pago seleccionado es un seguro.'),
(9536, 806, 4, 'No puede enviar pagos. La distribución es negativa.'),
(9537, 807, 4, 'No se puede leer'),
(9538, 808, 4, 'No se puede leer el directorio'),
(9539, 809, 4, 'No se puede actualizar porque no estás editando una entrada que ya exista.'),
(9540, 810, 4, 'Poner en Mayúsculas'),
(9541, 812, 4, 'cápsula'),
(9542, 813, 4, 'Tarjeta'),
(9543, 814, 4, 'Cateterismo Cardiaco'),
(9544, 815, 4, 'Ecocardiograma cardiaco'),
(9545, 816, 4, 'Cardiovascular'),
(9546, 821, 4, 'Daño de cartílago, condral o del disco articular.'),
(9547, 822, 4, 'Lesión de cartílago'),
(9548, 823, 4, 'Nl Pulsos Carotideos, pulsos pedios nl'),
(9549, 824, 4, 'efectivo'),
(9550, 825, 4, 'Efectivo'),
(9551, 826, 4, 'Recibos Efectivo'),
(9552, 827, 4, 'Recibos de efectivo por Proveedor'),
(9553, 829, 4, 'Cirugía de cataratas'),
(9554, 830, 4, 'Cataratas'),
(9555, 831, 4, 'Categorías'),
(9556, 832, 4, 'Categorias para'),
(9557, 833, 4, 'Categoría'),
(9558, 834, 4, 'categoría'),
(9559, 835, 4, 'Categoría '),
(9560, 836, 4, 'Detalles de Categoría'),
(9561, 837, 4, 'Límites de Categoría'),
(9562, 838, 4, 'Nombre de Categoría'),
(9563, 839, 4, 'Nombre de la Categoria esta vacio'),
(9564, 840, 4, 'Titulo de la Categoria'),
(9565, 841, 4, 'Caucásico'),
(9566, 842, 4, 'Induce a imprimir recibo del encuentro con la informacion del proveedor'),
(9567, 850, 4, 'CDR'),
(9568, 852, 4, 'Celular'),
(9569, 853, 4, 'Teléfono Celular'),
(9570, 855, 4, 'Teléfono Móvil'),
(9571, 856, 4, 'Certificación central'),
(9572, 857, 4, 'Centro Americano / Sud Americano'),
(9573, 858, 4, 'La ubicación del archivo de Certificado de Autoridad crt no puede estar vacía'),
(9574, 859, 4, 'La ubicación de la clave del archivo del Certificado de Autoridad no puede estar vacía'),
(9575, 860, 4, 'Certificado para enviar a la RFC 5425 TLS del servidor syslog.'),
(9576, 861, 4, 'Usuario del Certificado'),
(9577, 862, 4, 'Certificados'),
(9578, 864, 4, 'ChampUS'),
(9579, 865, 4, 'ChampUSVA'),
(9580, 866, 4, 'cambiar'),
(9581, 867, 4, 'Cambio'),
(9582, 868, 4, 'Cambia actividad'),
(9583, 870, 4, 'Cambio en la Visión'),
(9584, 871, 4, 'Cambio en la Visión'),
(9585, 874, 4, 'Cambiado'),
(9586, 875, 4, 'Intestino Cambiado'),
(9587, 877, 4, 'Caracteristicas'),
(9588, 878, 4, 'Carácteres restantes'),
(9589, 879, 4, 'Cobrar'),
(9590, 880, 4, 'Ajuste del cargo'),
(9591, 881, 4, 'Cobro codificado'),
(9592, 882, 4, 'Cargos'),
(9593, 883, 4, 'Historia'),
(9594, 884, 4, 'Histórico de Actividad'),
(9595, 885, 4, 'Entradas / Salidas Informe Historial de Actividad'),
(9596, 886, 4, 'Nº Identificación de gráfico'),
(9597, 887, 4, 'Nº Identificación de gráfico:'),
(9598, 889, 4, 'Actividad de Localización de gráfico'),
(9599, 890, 4, 'Nota en la historia'),
(9600, 891, 4, 'Número de gráfico'),
(9601, 892, 4, 'Lugares en donde está guardado la gráfica'),
(9602, 893, 4, 'Rastreador de gráfico'),
(9603, 894, 4, 'Rastreador de gráfico'),
(9604, 895, 4, 'Gráficas retiradas'),
(9605, 896, 4, 'Gráficas retiradas'),
(9606, 898, 4, 'Comprobar'),
(9607, 899, 4, 'comprobar'),
(9608, 900, 4, 'Marcar todo'),
(9609, 902, 4, 'Cantidad del cheque'),
(9610, 903, 4, 'Fecha del cheque'),
(9611, 904, 4, 'Comprobar diferencias entre las traducciones con Tabla del Idioma Personalizada'),
(9612, 906, 4, 'Llegue a'),
(9613, 907, 4, 'Comprobar data insertado'),
(9614, 909, 4, 'Revise los resultados de laboratorio'),
(9615, 912, 4, 'Número de cheque'),
(9616, 915, 4, 'Pago por Cheque'),
(9617, 916, 4, 'Marque el cuadrito si es un documento cifrado'),
(9618, 917, 4, 'Seleccione esto si quiere que los proveedores vean todas las citas por defecto y no solo las suyas.'),
(9619, 919, 4, 'Comprobar Fecha /EOB:'),
(9620, 920, 4, 'Comprobar Número EOB.:'),
(9621, 921, 4, 'Comprobar/número de referencia'),
(9622, 922, 4, 'Comprobar/Número de referencia'),
(9623, 923, 4, 'Lista de Selecciones'),
(9624, 924, 4, 'Lista de Selecciones'),
(9625, 925, 4, 'Casilla con Texto'),
(9626, 926, 4, 'Casilla con texto'),
(9627, 928, 4, 'Comprobado'),
(9628, 929, 4, 'Casilla marcada = sí, vacío = no'),
(9629, 932, 4, 'Comprobación / Salir'),
(9630, 933, 4, 'Sumatoria'),
(9631, 934, 4, 'Pecho'),
(9632, 935, 4, 'Pecho CTAB'),
(9633, 936, 4, 'Dolor de Pecho'),
(9634, 937, 4, 'Dolor de Pecho'),
(9635, 938, 4, 'Dolores de Pecho'),
(9636, 940, 4, 'Var'),
(9637, 942, 4, 'Queja Principal'),
(9638, 943, 4, 'Niño'),
(9639, 945, 4, 'Estado de Inmunizacion de la Niñez (GCC)'),
(9640, 946, 4, 'Escalofríos'),
(9641, 947, 4, 'Chino'),
(9642, 948, 4, 'Chino (simplificado)'),
(9643, 949, 4, 'Chino (tradicional)'),
(9644, 951, 4, 'Opciones'),
(9645, 952, 4, 'Colecistectomía'),
(9646, 954, 4, 'Colecistectomía'),
(9647, 955, 4, 'Elegir'),
(9648, 956, 4, 'Elija una sección y seleccione un elemento dentro de ella; luego, en la otra sección, verá remarcados los elementos relacionados y puede seleccionar de esa sección para añadir y borrar relaciones.'),
(9649, 957, 4, 'Criterios de selección'),
(9650, 962, 4, 'Lista de Selecciones'),
(9651, 965, 4, 'Seleccione formato para imprimir para este Informe de Visitas.'),
(9652, 967, 4, 'Bronquitis Crónica'),
(9653, 968, 4, 'Dolor crónico de articulaciones'),
(9654, 969, 4, 'Enfermedad Renal Cronica (ERC)'),
(9655, 970, 4, 'Sinovitis crónica/derrame/dolor articular/gota'),
(9656, 971, 4, 'Crónico/Recurrente'),
(9657, 973, 4, 'Cirrosis del hígado'),
(9658, 974, 4, 'Cirrosis del Hígado'),
(9659, 975, 4, 'Ciudad'),
(9660, 976, 4, 'Nombre de Ciudad'),
(9661, 977, 4, 'Ciudad, Estado'),
(9662, 978, 4, 'Ciudad, Estado Código Postal'),
(9663, 979, 4, 'Ciudad/Estado'),
(9664, 980, 4, 'Reclamo'),
(9665, 981, 4, 'Reclamo '),
(9666, 983, 4, 'La prueba de Reclamo pedido ha terminado'),
(9667, 984, 4, 'Tipo de Reclamo'),
(9668, 985, 4, 'Reclamo generado para presentar'),
(9669, 986, 4, 'El reclamo se ha guardado en el fichero '),
(9670, 987, 4, 'Reclamos'),
(9671, 988, 4, 'Clasificación'),
(9672, 989, 4, 'Borrar'),
(9673, 991, 4, 'Desmarcar todos'),
(9674, 992, 4, 'Borrar Datos HL7'),
(9675, 993, 4, 'Borrar Justificación'),
(9676, 994, 4, 'Borrar Cache Smarty'),
(9677, 995, 4, 'Centro de Intercambio de información necesaria para la creación de la serie EDI 270.'),
(9678, 996, 4, 'Número CLIA'),
(9679, 997, 4, 'Seleccionar'),
(9680, 998, 4, 'Seleccionar ´export´ para exportar su Categoria, Subcategoria, Item o Datos contenidos a un archivo de texto. Cualquier similaridad de este archivo a un archivo tipo XML es pura coincidencia. Las etiquetas de abrir y cerrar deben estar en la misma línea y deber ser minúsculas sin espacios. Para importar, localize el archivo y selecciona ´Importar´. Si los datos son completamente diferentes se une a los datos existentes. Si hay datos con nombres similares, el nombre más antiguo se retiene mientras que al nuevo se le agrega un número al final.'),
(9681, 999, 4, 'Pinche en el grafico para nueva anotacion, pinche de nuevo para eliminarla.'),
(9682, 1000, 4, 'Seleccionar Bajar Certificado para bajar los certificados en el archivo ssl.zip'),
(9683, 1001, 4, 'Seleccionar para más'),
(9684, 1005, 4, 'Selecciona aquí'),
(9685, 1006, 4, 'Click aqui para añadir un nuevo paciente'),
(9686, 1007, 4, 'Pinche aqui para indicar cambio de estado de la nueva lesion y editar la actividad diaria.'),
(9687, 1008, 4, 'Click aquí para elegir fecha'),
(9688, 1009, 4, 'Click aquí para elegir fecha y hora'),
(9689, 1010, 4, 'Click aquí para elegir fecha de inicio'),
(9690, 1020, 4, 'Click aquí para buscar'),
(9691, 1021, 4, 'Click aquí para actualizar prioridad, categoría y apodos'),
(9692, 1022, 4, 'Click aquí para ver todos.'),
(9693, 1023, 4, 'Click aqui para ver y graficar'),
(9694, 1025, 4, 'Click aquí para ver y graficar todos los signos vitales.'),
(9695, 1026, 4, 'Click aca para ver los detalles del paciente'),
(9696, 1027, 4, 'Selecciona aquí para ver todos.'),
(9697, 1029, 4, 'Pinchar boton Instalar para aceptar descargar de la base de datos emitida desde la siguiente fecha'),
(9698, 1030, 4, 'Selecciona aquí para aumentar los intervalos de tiempo'),
(9699, 1031, 4, 'Click en Nombre Paciente para abrir el fichero del paciente'),
(9700, 1032, 4, 'Selecciona Refrescar para ver todos los resultados ó favor de colocar el criterio de búsqueda arriba para ver resultados específicos.'),
(9701, 1034, 4, 'Escoja para agregar componentes nuevos'),
(9702, 1035, 4, 'Escoja para agregar consulta nueva'),
(9703, 1037, 4, 'Haga Click para bajar'),
(9704, 1038, 4, 'Haga Click para editar'),
(9705, 1040, 4, 'Haga Click para editar este evento'),
(9706, 1041, 4, 'Haga Click para generar el reporte'),
(9707, 1043, 4, 'Haga Click para imprimir'),
(9708, 1044, 4, 'Haga Click aquí para recibir (añadir) nuevo lote'),
(9709, 1045, 4, 'Haga Click para elegir'),
(9710, 1046, 4, 'Haga Click para elegir'),
(9711, 1047, 4, 'Seleccionar para elegir un codigo usual de la industria para este procedimiento'),
(9712, 1048, 4, 'Click para seleccionar el codigo de procedimiento opcional'),
(9713, 1050, 4, 'Escoja para seleccionar o cambiar codigo CVX'),
(9714, 1051, 4, 'Seleccionar para elegir o cambiar diagnóstico'),
(9715, 1052, 4, 'Haga click para elegir o cambiar códigos de servicios'),
(9716, 1053, 4, 'Selecciona para elegir paciente'),
(9717, 1054, 4, 'Selecciona para elegir código relacionado'),
(9718, 1055, 4, 'Selecciona para elegir servicios a rendir si este resultado es anormal'),
(9719, 1056, 4, 'Selecciona para elegir el procedimiento deseado'),
(9720, 1058, 4, 'Seleccione para ver'),
(9721, 1059, 4, 'Selecciona para ver o para corregir'),
(9722, 1060, 4, 'Selecciona para ver/editar'),
(9723, 1061, 4, 'Pinche Actualizar para descargar la base de datos actualizada desde la fecha siguiente.'),
(9724, 1063, 4, 'Selecciona:'),
(9725, 1064, 4, 'Días de Vencimiento del Certificado del Cliente'),
(9726, 1065, 4, 'Periodo de validacion del Certificado del Cliente'),
(9727, 1066, 4, 'Validez del certificado del cliente debe ser un número válido'),
(9728, 1067, 4, 'Copia para el cliente'),
(9729, 1069, 4, 'Resumen de historia clínica del cliente'),
(9730, 1072, 4, 'Perfil de cliente - Nuevos Clientes'),
(9731, 1073, 4, 'Perfil de cliente - Clientes Únicos'),
(9732, 1074, 4, 'Clientes'),
(9733, 1075, 4, 'Clínica'),
(9734, 1076, 4, 'Copia para la Clínica'),
(9735, 1077, 4, 'Informe Diario de la Clínica'),
(9736, 1078, 4, 'Número de Identificación de la Clínica'),
(9737, 1079, 4, 'Clínico'),
(9738, 1080, 4, 'Gestor de Alertas para las Reglas de Decisiones Clinicas'),
(9739, 1083, 4, 'Planes Clinicos'),
(9740, 1084, 4, 'Medidas de Calidad Clinica (GCC)'),
(9741, 1087, 4, 'Recordatorios Clinicos'),
(9742, 1088, 4, 'Reportes Clínicos'),
(9743, 1089, 4, 'Categoria de Accion de Reglas Clinicas'),
(9744, 1090, 4, 'Asunto de Accion de Reglas Clinicas'),
(9745, 1091, 4, 'Metodos de filtrado de Reglas Clinicas'),
(9746, 1092, 4, 'Objetivo de Metodos de Reglas Clinicas.'),
(9747, 1093, 4, 'Reglas Clinicas'),
(9748, 1094, 4, 'Intervalos de Edad de las Reglas Clinicas'),
(9749, 1095, 4, 'Comparaciones de las Reglas Clínicas'),
(9750, 1096, 4, 'Tipos de Encuentros de las Reglas Clínicas'),
(9751, 1097, 4, 'Opciones de Recordatorios de las Reglas Clínicas'),
(9752, 1098, 4, 'Opciones de Desactivación de los Recordatorios de las Reglas Clínicas'),
(9753, 1099, 4, 'Intervalos de los Recordatorios de las Reglas Clínicas'),
(9754, 1100, 4, 'Métodos para los Recordatorios de las Reglas Clínicas'),
(9755, 1101, 4, 'Intervalos buscados de las Reglas Clínicas'),
(9756, 1102, 4, 'Objetivos Clínicos'),
(9757, 1106, 4, 'Clínicos'),
(9758, 1107, 4, 'Clonar'),
(9759, 1108, 4, 'Clonar visita anterior'),
(9760, 1109, 4, 'Cerrar'),
(9761, 1111, 4, 'cerrar ventana'),
(9762, 1112, 4, 'Cerrado'),
(9763, 1113, 4, 'cm'),
(9764, 1114, 4, 'Margenes del formulario CMS 1500'),
(9765, 1118, 4, 'CMS ID'),
(9766, 1120, 4, 'Registro en el portal CMS'),
(9767, 1127, 4, 'CN2-12 Intacto'),
(9768, 1128, 4, 'Copago'),
(9769, 1129, 4, 'Copago pagado'),
(9770, 1130, 4, 'Copago'),
(9771, 1131, 4, 'Código'),
(9772, 1132, 4, 'código'),
(9773, 1133, 4, 'Buscador de Código'),
(9774, 1134, 4, 'Código debe ser 2 letras en minúscula'),
(9775, 1135, 4, 'Código o símbolo para indicar tipo de cambio'),
(9776, 1136, 4, 'Código de Texto'),
(9777, 1138, 4, 'tipo de código'),
(9778, 1141, 4, 'Típos de Código'),
(9779, 1143, 4, 'Codificado'),
(9780, 1144, 4, 'Códigos'),
(9781, 1145, 4, 'Codificación'),
(9782, 1146, 4, 'Codificación (clic para educación)'),
(9783, 1147, 4, 'Codificación - cualquier encuentros (escribir, con algunas opciones)'),
(9784, 1148, 4, 'Codificación - mis encuentros (escribir, con algunas opciones)'),
(9785, 1149, 4, 'Codificación no autorizada'),
(9786, 1150, 4, 'Café'),
(9787, 1151, 4, 'Consumo de café'),
(9788, 1152, 4, 'Coseguro'),
(9789, 1153, 4, 'Coll w/o'),
(9790, 1154, 4, 'Colapsar'),
(9791, 1155, 4, 'Colapsar'),
(9792, 1156, 4, 'Colapsar Todo'),
(9793, 1157, 4, 'Colapsar Todos'),
(9794, 1158, 4, 'colapsar todos'),
(9795, 1160, 4, 'Fecha de recolecciòn'),
(9796, 1161, 4, 'Colecciones'),
(9797, 1162, 4, 'Informe de recogidas'),
(9798, 1163, 4, 'Cáncer de colon'),
(9799, 1164, 4, 'Detección de Cáncer de colon'),
(9800, 1165, 4, 'Cirugía del cáncer de colon'),
(9801, 1166, 4, 'Colonoscopia'),
(9802, 1167, 4, 'colonoscopía'),
(9803, 1168, 4, 'Color'),
(9804, 1169, 4, 'Abreviatura de color'),
(9805, 1170, 4, 'Columna'),
(9806, 1171, 4, 'Columnas'),
(9807, 1172, 4, 'Combinando Lotes'),
(9808, 1173, 4, 'Coma'),
(9809, 1174, 4, 'Commentario'),
(9810, 1175, 4, 'Comentarios'),
(9811, 1176, 4, 'Comentarios para este resultado o recomendación'),
(9812, 1177, 4, 'Compañía Aseguradora'),
(9813, 1178, 4, 'Guardar Cambios'),
(9814, 1179, 4, 'Comunicación'),
(9815, 1180, 4, 'Comunicaciones'),
(9816, 1182, 4, 'Compañía'),
(9817, 1183, 4, 'Nombre de la Compañía'),
(9818, 1184, 4, 'Completo'),
(9819, 1186, 4, 'Terminado'),
(9820, 1188, 4, '¿Completado?'),
(9821, 1190, 4, 'Conplicaciones por el proveedor de servicios'),
(9822, 1191, 4, 'Complicaciones de aborto'),
(9823, 1192, 4, 'Componentes'),
(9824, 1193, 4, 'Sistema Computarizado de Pedidos Médicos'),
(9825, 1194, 4, 'Conclusiones'),
(9826, 1198, 4, 'Config'),
(9827, 1199, 4, 'Configuración'),
(9828, 1200, 4, 'Configuración Exportar / Importar'),
(9829, 1202, 4, 'Configure Apache y LibreEHR para usar certificados SSL del Cliente'),
(9830, 1203, 4, 'Configure Apache para usar certificados SSL del Cliente'),
(9831, 1204, 4, 'Configure Apache para usar HTTPS'),
(9832, 1205, 4, 'Configure LIBREEHR para usar certificado SSL del Cliente'),
(9833, 1208, 4, 'Confirmar creación de Nuevo Paciente'),
(9834, 1209, 4, 'Confirmar la nueva contraseña'),
(9835, 1210, 4, 'Confirmar Pago'),
(9836, 1214, 4, 'Congénito'),
(9837, 1215, 4, 'Conjuntiva, pupilas'),
(9838, 1216, 4, 'Error de conexión'),
(9839, 1217, 4, 'Conectores'),
(9840, 1218, 4, 'Constante'),
(9841, 1219, 4, 'Nombre constante'),
(9842, 1220, 4, 'Nombre constante está en blanco'),
(9843, 1221, 4, 'constantes'),
(9844, 1222, 4, 'Estreñimiento'),
(9845, 1223, 4, 'Constitucional'),
(9846, 1226, 4, 'Breve Descripción de Consulta'),
(9847, 1227, 4, 'Contacto'),
(9848, 1228, 4, 'email de contacto'),
(9849, 1229, 4, 'email de contacto'),
(9850, 1231, 4, 'Informacion de contacto'),
(9851, 1232, 4, 'Lentes de Contacto'),
(9852, 1236, 4, 'Nombre de contacto'),
(9853, 1237, 4, 'Persona de Contacto'),
(9854, 1238, 4, 'Teléfono de Contacto'),
(9855, 1239, 4, 'Teléfono de Contacto'),
(9856, 1240, 4, 'Contacte a ZMG, LLC (zmghealth@gmail.com) para suscribirse al servicio de eRx'),
(9857, 1241, 4, 'contiene por lo menos tres de las cuatro cosas siguientes:'),
(9858, 1243, 4, 'Contenido'),
(9859, 1244, 4, 'contenido'),
(9860, 1245, 4, 'Contexto'),
(9861, 1246, 4, 'El nombre del contexto no puede estar vacío'),
(9862, 1247, 4, 'Continuar'),
(9863, 1248, 4, 'Documento de Continuidad de Atención (CCD)'),
(9864, 1249, 4, 'Registro de Continuidad de Cuidados (CCR)'),
(9865, 1250, 4, 'Contra Clientes'),
(9866, 1251, 4, 'Contracepción'),
(9867, 1252, 4, 'Problemas Anticonceptivos'),
(9868, 1253, 4, 'Complicación anticonceptivos (especificar)'),
(9869, 1254, 4, 'Método Anticonceptivo'),
(9870, 1255, 4, 'Productos Anticonceptivos'),
(9871, 1256, 4, 'Servicios anticonceptivos ya empezados'),
(9872, 1257, 4, 'Comienzo de anticonceptivos'),
(9873, 1258, 4, 'Identificacion de control'),
(9874, 1259, 4, 'N º de control'),
(9875, 1261, 4, 'Co-Pago'),
(9876, 1262, 4, 'Co-pago'),
(9877, 1263, 4, 'Co-Pago'),
(9878, 1264, 4, 'El Co-pago no es positivo'),
(9879, 1265, 4, 'Copago pagado'),
(9880, 1266, 4, 'Co-pagos'),
(9881, 1267, 4, 'COPD'),
(9882, 1268, 4, 'Copiar páginas al Historial del Paciente'),
(9883, 1269, 4, 'Copiar Valores'),
(9884, 1270, 4, 'Copiando el archivo de la base de datos. Esto puede tardar unos minutos...'),
(9885, 1271, 4, 'Anuncio de Derechos Reservados'),
(9886, 1273, 4, 'Bypass coronario arterial'),
(9887, 1274, 4, 'Cirugía de revascularización coronaria'),
(9888, 1275, 4, 'Corregido'),
(9889, 1277, 4, 'CouchDB'),
(9890, 1278, 4, 'Conexión a CouchDB fallida.'),
(9891, 1279, 4, 'bbdd CouchDB'),
(9892, 1280, 4, 'Nombre de bbdd CouchDB'),
(9893, 1281, 4, 'Host CouchDB'),
(9894, 1282, 4, 'Nombre Host CouchDB'),
(9895, 1283, 4, 'Activar Log CouchDB'),
(9896, 1284, 4, 'Contraseña CouchDB'),
(9897, 1285, 4, 'Puerto CouchDB'),
(9898, 1286, 4, 'puerto CouchDB'),
(9899, 1288, 4, 'Nombre usuario CouchDB'),
(9900, 1289, 4, 'Tos'),
(9901, 1290, 4, 'Tos:'),
(9902, 1291, 4, 'No pudo conectar servidor'),
(9903, 1293, 4, 'No pudo abrir tabla'),
(9904, 1294, 4, 'No se pudo leer el archivo'),
(9905, 1295, 4, 'No pudo leer archivo'),
(9906, 1296, 4, 'Correo no salió por problema con servidor, '),
(9907, 1297, 4, 'No se pudo enviar email debido a problemas en el servidor. '),
(9908, 1298, 4, 'No se pudo crear el dir de backup:'),
(9909, 1299, 4, 'No se pudo eliminar dir:'),
(9910, 1300, 4, 'No se pudo eliminar el antiguo fichero de Backup:'),
(9911, 1301, 4, 'No se pudo eliminar el antiguo fichero de exportación:'),
(9912, 1302, 4, 'Tratamiento con Coumadin - Seguimiento del Ratio Internacional Normalizado (RIN)'),
(9913, 1303, 4, 'Counseling por Método'),
(9914, 1304, 4, 'Orientación'),
(9915, 1305, 4, 'Actividades de orientación'),
(9916, 1306, 4, 'CONTADOR DE REMISIÓN'),
(9917, 1307, 4, 'Retorno de la derivación'),
(9918, 1308, 4, 'País'),
(9919, 1309, 4, 'Tipo de datos País'),
(9920, 1310, 4, 'Lista de País'),
(9921, 1311, 4, 'Lista del país (escriba, addonly opcional)'),
(9922, 1312, 4, 'Nombre del Pais debe ser representado por dos letras'),
(9923, 1313, 4, 'condado'),
(9924, 1315, 4, 'Cupón'),
(9925, 1318, 4, 'CPT'),
(9926, 1319, 4, 'Código CPT'),
(9927, 1320, 4, 'Código CPT'),
(9928, 1321, 4, 'Procedimiento/Servicio CPT4'),
(9929, 1322, 4, 'Medidas de Rendimiento CPTII'),
(9930, 1323, 4, 'Gestión Calidad Continua (GCC)'),
(9931, 1324, 4, 'Crujidos, crepitaciones'),
(9932, 1325, 4, 'crema'),
(9933, 1326, 4, 'Crear un certificado SSL del Cliente por usuario o cliente de maquina'),
(9934, 1327, 4, 'Crear un certificado SSL del cliente para usuario o nombre del invitado'),
(9935, 1329, 4, 'Crear un evento'),
(9936, 1330, 4, 'Crear y descargar un respaldo completo'),
(9937, 1332, 4, 'Crear Respaldo'),
(9938, 1333, 4, 'Crear batch (serie o lote)'),
(9939, 1334, 4, 'Crear Certificado de Cliente'),
(9940, 1335, 4, 'Crear Certificados SSL del Cliente'),
(9941, 1336, 4, 'Crear duplicado'),
(9942, 1338, 4, 'Crear copia de seguridad de registro de eventos'),
(9943, 1339, 4, 'Crear nuevo asunto'),
(9944, 1340, 4, 'Crear paciente nuevo'),
(9945, 1342, 4, 'Crear credenciales del portal fuera del sitio'),
(9946, 1343, 4, 'Crear credenciales del portal dentro del sitio'),
(9947, 1344, 4, 'Crear nota de paciente'),
(9948, 1345, 4, 'Crear Certificado de Autoridad SSL y Certificados del Servidor.'),
(9949, 1346, 4, 'Crear Encuentro'),
(9950, 1347, 4, 'Creado'),
(9951, 1348, 4, 'Creando archivo de exportación'),
(9952, 1351, 4, 'Creador'),
(9953, 1352, 4, 'crédito'),
(9954, 1353, 4, 'Tarjeta de Crédito'),
(9955, 1354, 4, 'Créditos'),
(9956, 1356, 4, 'Criterio'),
(9957, 1358, 4, 'Enfermedad de Crohn'),
(9958, 1359, 4, 'Enfermedad de Crohn'),
(9959, 1360, 4, 'CSV'),
(9960, 1361, 4, 'Archivo de CSV'),
(9961, 1363, 4, 'MM.CU (Mililitros cubicos)'),
(9962, 1364, 4, 'Cubano'),
(9963, 1365, 4, 'Número de decimales en moneda'),
(9964, 1366, 4, 'Símbolo de Punto Decimal en moneda'),
(9965, 1367, 4, 'Indicador de moneda'),
(9966, 1368, 4, 'Moneda - Separador de Miles'),
(9967, 1369, 4, 'Actual'),
(9968, 1370, 4, 'Alcohol actual'),
(9969, 1371, 4, 'Consulta Actual'),
(9970, 1372, 4, 'Criterios Actuales'),
(9971, 1373, 4, 'Color resaltado del presente día'),
(9972, 1374, 4, 'Actualmente fumador diario'),
(9973, 1375, 4, 'El nombre de archivo actual fue cambiado a'),
(9974, 1376, 4, 'Clave encriptada actual'),
(9975, 1377, 4, 'Ubicación actual'),
(9976, 1378, 4, 'Medicamentos actuales'),
(9977, 1379, 4, 'Contraseña actual'),
(9978, 1380, 4, 'Paciente Actual'),
(9979, 1382, 4, 'Actuales drogas recreativas'),
(9980, 1383, 4, 'Actualmente fumador ocasional'),
(9981, 1386, 4, 'Actualmente Activo'),
(9982, 1388, 4, 'No hay centros'),
(9983, 1389, 4, 'Síndrome de Cushing'),
(9984, 1390, 4, 'Síndrome de Cushing'),
(9985, 1392, 4, 'A medida'),
(9986, 1393, 4, '¿Entrada personalizada?'),
(9987, 1394, 4, 'Tabla personalizada'),
(9988, 1396, 4, 'Código CVX'),
(9989, 1397, 4, 'Mapeo del código CVX'),
(9990, 1398, 4, 'Vacunación CVX'),
(9991, 1399, 4, 'Ciclo'),
(9992, 1400, 4, 'CYP'),
(9993, 1401, 4, 'Factor de CYP'),
(9994, 1402, 4, 'Informe de CYP'),
(9995, 1403, 4, 'Checo'),
(9996, 1404, 4, 'D'),
(9997, 1405, 4, 'D&C'),
(9998, 1406, 4, 'D&E'),
(9999, 1407, 4, 'F.D.N.'),
(10000, 1408, 4, 'diariamente'),
(10001, 1409, 4, 'Registro Diario'),
(10002, 1410, 4, 'Danés'),
(10003, 1411, 4, 'Información parecida está ya en la base de datos, por favor cambie el código o la descripción'),
(10004, 1412, 4, 'Información parecida está ya en la base de datos, por favor cambie el nombre de la constante'),
(10005, 1413, 4, 'Datos Cols'),
(10006, 1416, 4, 'Error en los datos'),
(10007, 1420, 4, 'Tipo de datos'),
(10008, 1421, 4, 'Base de datos'),
(10009, 1422, 4, 'La base de datos no ha sido instalada'),
(10010, 1423, 4, 'Revisión bbdd'),
(10011, 1424, 4, 'Información de la base de datos'),
(10012, 1425, 4, 'Actualización de base de datos completa'),
(10013, 1426, 4, 'DataCols debe ser un número entre 1 y 999'),
(10014, 1427, 4, 'Fecha'),
(10015, 1428, 4, 'FECHA'),
(10016, 1431, 4, 'Fecha administrada'),
(10017, 1432, 4, 'Fecha y hora de coleccion de muestra'),
(10018, 1433, 4, 'Fecha y hora de esta observación'),
(10019, 1435, 4, 'Fecha y hora cuando la muestra fue colectada'),
(10020, 1436, 4, 'La fecha no puede ser mayor a la de hoy'),
(10021, 1437, 4, 'Fecha en que fueron provistos inicialmente los servicios anticonceptivos'),
(10022, 1438, 4, 'Fecha de creación'),
(10023, 1439, 4, 'Fecha del fallecimiento'),
(10024, 1440, 4, 'Fecha de destrucción'),
(10025, 1441, 4, 'Formato de muestra de fecha'),
(10026, 1442, 4, 'Formato fecha para última cita no es válido'),
(10027, 1443, 4, 'Formato fecha para primera cita no es válido'),
(10028, 1444, 4, 'Formato fecha para ''Próxima Cita'' no es válida'),
(10029, 1445, 4, 'Formato fecha para ''no visto desde'' no es válido'),
(10030, 1446, 4, 'Formato fecha para ''visto desde'' no es válido'),
(10031, 1447, 4, 'Comunicados de fechas de vacunación entregados'),
(10032, 1448, 4, 'Falta fecha para código '),
(10033, 1449, 4, 'Criterio maestro de fecha'),
(10034, 1450, 4, 'Fecha ingreso en banco aaaa-mm-dd'),
(10035, 1451, 4, 'Fecha de factura'),
(10036, 1452, 4, 'F.Nacim.'),
(10037, 1453, 4, 'F.Nacim.'),
(10038, 1454, 4, 'F.Nacim.'),
(10039, 1455, 4, 'Fecha de entrada'),
(10040, 1456, 4, 'Fecha de la lesión'),
(10041, 1458, 4, 'Fecha de pago aaaa-mm-dd'),
(10042, 1459, 4, 'Fecha de derivación'),
(10043, 1460, 4, 'Fecha de la respuesta'),
(10044, 1462, 4, 'Fecha De Servicio'),
(10045, 1463, 4, 'Fecha de servicio'),
(10046, 1464, 4, 'Fecha de servicio = hoy'),
(10047, 1465, 4, 'Fecha de servicio mm/dd/aaaa'),
(10048, 1466, 4, 'Fecha de Servicio:'),
(10049, 1467, 4, 'Fecha de firma'),
(10050, 1469, 4, 'Fecha de esta orden'),
(10051, 1470, 4, 'Fecha de este reporte'),
(10052, 1471, 4, 'Fecha de la Declaración de VIS'),
(10053, 1472, 4, 'Fecha en que se ordenó'),
(10054, 1475, 4, 'Seleccionador de fecha'),
(10055, 1476, 4, 'Fecha del envío'),
(10056, 1477, 4, 'Fecha en la que el mensaje fue enviado'),
(10057, 1479, 4, 'La fecha no puede estar en blanco'),
(10058, 1480, 4, 'Fecha/Cita'),
(10059, 1481, 4, 'Fecha/Notas'),
(10060, 1482, 4, 'Fecha/Notas de Último'),
(10061, 1483, 4, 'Fecha/Hora'),
(10062, 1484, 4, 'Fecha:'),
(10063, 1485, 4, 'Registro de mensajes con sus fechas'),
(10064, 1486, 4, 'Día'),
(10065, 1487, 4, 'dia'),
(10066, 1489, 4, 'Vista de día'),
(10067, 1490, 4, 'Día(s)'),
(10068, 1491, 4, 'Día(s) L-V'),
(10069, 1492, 4, 'días'),
(10070, 1493, 4, 'Días'),
(10071, 1494, 4, 'días pasados'),
(10072, 1495, 4, 'Dïas y juegos perdidos'),
(10073, 1496, 4, 'Días Desde la Última Visita'),
(10074, 1497, 4, 'Dias faltados'),
(10075, 1498, 4, 'Días por columna'),
(10076, 1500, 4, 'Días/Col'),
(10077, 1501, 4, 'DB instalado'),
(10078, 1502, 4, 'DD/MM/AAAA'),
(10079, 1503, 4, 'Anonimato'),
(10080, 1504, 4, 'El proceso de anonimato está completo'),
(10081, 1505, 4, 'El proceso de anonimato está en proceso'),
(10082, 1506, 4, 'El proceso de anonimato ha iniciado y está corriendo en el fondo'),
(10083, 1507, 4, 'Los datos anónimos pueden no estar completos'),
(10084, 1508, 4, 'Los ficheros anónimos serán guardados en'),
(10085, 1509, 4, 'DEA'),
(10086, 1511, 4, 'Sordera'),
(10087, 1512, 4, 'Elimine errores de la información'),
(10088, 1515, 4, 'Dic'),
(10089, 1516, 4, 'DIFUNTO'),
(10090, 1517, 4, 'Diciembre'),
(10091, 1520, 4, 'Deducible'),
(10092, 1521, 4, 'Deducible alcanzado'),
(10093, 1522, 4, 'Por Defecto'),
(10094, 1523, 4, 'Vista Calendario por defecto'),
(10095, 1524, 4, 'Formulario ID para Visita por defecto'),
(10096, 1526, 4, 'Centro por defecto'),
(10097, 1527, 4, 'Idioma por defecto'),
(10098, 1528, 4, 'Idioma por defecto si no se elige o permite otro'),
(10099, 1529, 4, 'Lista del defecto (escriba, sólo añadir opcional)'),
(10100, 1530, 4, 'Método por defecto'),
(10101, 1531, 4, 'Días Expiración Contraseña por Defecto'),
(10102, 1532, 4, 'El periodo de vencimiento de la contraseña por defecto es 0. Ésto significa que la función está desactivada'),
(10103, 1533, 4, 'País por defecto del Paciente'),
(10104, 1536, 4, 'Médico por defecto'),
(10105, 1537, 4, 'Rango por defecto'),
(10106, 1538, 4, 'Razón por defecto de la visita'),
(10107, 1540, 4, 'Configuración por defecto'),
(10108, 1541, 4, 'Estado por defecto de la casilla de chequeo de nueva ventana en la lista de pacientes.'),
(10109, 1542, 4, 'Plantilla por defecto'),
(10110, 1546, 4, 'Unidades por defecto'),
(10111, 1547, 4, 'Valor por defecto'),
(10112, 1548, 4, 'Deposito por defecto'),
(10113, 1549, 4, 'Socio X12 por defecto'),
(10114, 1550, 4, 'Por defecto/Global'),
(10115, 1551, 4, 'Borrar'),
(10116, 1552, 4, 'borrar'),
(10117, 1553, 4, 'Repetición retrasada (> 12 Mo)'),
(10118, 1554, 4, 'Eliminar'),
(10119, 1555, 4, 'eliminar'),
(10120, 1556, 4, 'Eliminar Categrorías con identificador(es) : '),
(10121, 1557, 4, 'Borrar Categoría'),
(10122, 1560, 4, 'Eliminar Grupo'),
(10123, 1561, 4, 'Eliminar Lista'),
(10124, 1562, 4, 'Eliminar Páginas'),
(10125, 1563, 4, 'Borrar Paciente, visita, formulario, Incidencia, Documento, Pago, facturación o Transacción'),
(10126, 1565, 4, 'Borrar fila'),
(10127, 1566, 4, 'Borrar ítems selectos'),
(10128, 1568, 4, 'Eliminación con éxito.'),
(10129, 1569, 4, 'Eliminar este documento'),
(10130, 1570, 4, 'Eliminar este formulario'),
(10131, 1571, 4, 'Eliminar esta nota'),
(10132, 1573, 4, 'Borrado Completado'),
(10133, 1575, 4, 'No se puede deshacer la eliminación de este evento. No se puede recuperar una vez que se ha hecho. ¿Está seguro que desea eliminar este evento?'),
(10134, 1581, 4, 'Demencia'),
(10135, 1582, 4, 'Datos demográficos'),
(10136, 1583, 4, 'Demografía (escribir, sólo añadir opcional)'),
(10137, 1585, 4, 'Criterio de Filtro Demográficos'),
(10138, 1586, 4, 'Datos demográficos no autorizados'),
(10139, 1587, 4, 'Datos demográficos no autorizados'),
(10140, 1588, 4, 'Denegado'),
(10141, 1589, 4, 'Denominador'),
(10142, 1590, 4, 'Dental'),
(10143, 1592, 4, 'Incidencias Dentales'),
(10144, 1595, 4, 'Dependiendo del tipo de cuenta que usted prueba, usted verá salida tipo HCFA en una página en blanco para las cuentas de HCFA, o usted verá muchas líneas de texto e información alteradas, si usted está probando una demanda X12. Ese texto mutilado es el formato del X12 IED 4010A. Usted verá de vez en cuando los caracteres extraños que parecen dominós o basura, se trata de caracteres de control tales como alimentaciones de página y son normales.'),
(10145, 1596, 4, 'Fecha de depósito'),
(10146, 1597, 4, 'La fecha del deposiito no puede ser mayor a la de hoy'),
(10147, 1598, 4, 'Fecha del depósito'),
(10148, 1599, 4, 'Depresivo'),
(10149, 1600, 4, 'Depresión'),
(10150, 1602, 4, 'Descripción'),
(10151, 1603, 4, 'descripción'),
(10152, 1605, 4, 'Descripción del acceso a información'),
(10153, 1606, 4, 'Desceripcion de este procedimiento o codigo resultante'),
(10154, 1607, 4, 'Traducción de la descripción'),
(10155, 1609, 4, 'Destino'),
(10156, 1610, 4, 'Nombre del archivo destino'),
(10157, 1611, 4, 'Destruir todo el lote'),
(10158, 1612, 4, 'Destruido ...'),
(10159, 1613, 4, 'Destruido'),
(10160, 1614, 4, 'Drogas destruidas'),
(10161, 1615, 4, 'Informe drogas destruido'),
(10162, 1616, 4, 'Detalles'),
(10163, 1617, 4, 'Detalles'),
(10164, 1619, 4, 'Anormalidad del desarrollo'),
(10165, 1620, 4, 'Diabetes'),
(10166, 1621, 4, 'Diabetes Mellitus'),
(10167, 1622, 4, 'Diabetes: Gestión presión arterial (GCC)'),
(10168, 1623, 4, 'Diabetes:Examen Ocular'),
(10169, 1624, 4, 'Diabetes: Examen ocular (GCC)'),
(10170, 1625, 4, 'Diabetes: Examen de los pies'),
(10171, 1626, 4, 'Diabetes: Examen de los pies (GCC)'),
(10172, 1627, 4, 'Diabetes:Control HbA1c Deficiente (GCC)'),
(10173, 1628, 4, 'Diabetes: Hemoglobina A1C'),
(10174, 1629, 4, 'Diabetes: Gestión LDL y Control (GCC)'),
(10175, 1630, 4, 'Diabetes: Microalbúmina de la orina'),
(10176, 1631, 4, 'Diagnóstico'),
(10177, 1633, 4, 'Diagnóstico'),
(10178, 1634, 4, 'Código de diagnostico'),
(10179, 1636, 4, 'Fecha de diagnostico'),
(10180, 1637, 4, 'El diagnóstico debe ser codificado en una visita vinculada'),
(10181, 1638, 4, 'Nombre del diagnóstico'),
(10182, 1639, 4, 'Reporte de diagnóstico'),
(10183, 1640, 4, 'Informe de diagnóstico'),
(10184, 1641, 4, 'Sólo inf. de diag.'),
(10185, 1642, 4, 'Título del diagnóstico'),
(10186, 1643, 4, 'Diagnóstico:'),
(10187, 1644, 4, 'Diagnóstico: '),
(10188, 1645, 4, 'Pruebas diagnósticas:'),
(10189, 1646, 4, 'Diales'),
(10190, 1647, 4, 'Diafragmas/Capuchón cervical'),
(10191, 1648, 4, 'Diarrea'),
(10192, 1650, 4, 'Dictado'),
(10193, 1651, 4, 'Dictado: '),
(10194, 1652, 4, '¿Usted recibió una copia del aviso de HIPAA?'),
(10195, 1653, 4, 'Difuso:'),
(10196, 1654, 4, 'Firmado digitalmente'),
(10197, 1657, 4, 'Correo Directo'),
(10198, 1663, 4, 'Nombre del director'),
(10199, 1665, 4, 'inhabilitación'),
(10200, 1667, 4, 'Deshabilitar calendario'),
(10201, 1668, 4, 'Deshabilitar tabla de seguimiento'),
(10202, 1669, 4, 'Deshabilitar inmunizaciones'),
(10203, 1670, 4, 'Deshabilitar vieja forma métrica de datos vitales'),
(10204, 1672, 4, 'Deshabilitar phpMyAdmin'),
(10205, 1673, 4, 'Deshabilitar prescripciones'),
(10206, 1674, 4, 'Deshabilitar grupos de usuarios'),
(10207, 1675, 4, 'inhabilitado'),
(10208, 1676, 4, 'inhabilitado'),
(10209, 1677, 4, 'Beneficiario discapacitado menor de 65 años con un Plan de salud para grandes grupos (LGHP)'),
(10210, 1678, 4, 'DISCO'),
(10211, 1681, 4, 'Descarga'),
(10212, 1682, 4, 'Pérdidas/secreciones de la uretra'),
(10213, 1684, 4, 'Descarga derecha'),
(10214, 1685, 4, 'Descarga derecha:'),
(10215, 1689, 4, 'Informacion de acceso a información'),
(10216, 1690, 4, 'Tipo de Acceso a información'),
(10217, 1691, 4, 'Tipos de Acceso a información'),
(10218, 1692, 4, 'Acceso a información'),
(10219, 1694, 4, 'Descuento'),
(10220, 1695, 4, 'Suma de descuentos'),
(10221, 1696, 4, 'Nivel del Descuento'),
(10222, 1697, 4, 'porcentajes de descuento'),
(10223, 1698, 4, 'Descuentos como importes monetarios'),
(10224, 1699, 4, 'Descuentos a la hora de salida se introducen como cantidades de dinero, a diferencia de porcentaje.'),
(10225, 1700, 4, 'Resultado discreto'),
(10226, 1701, 4, 'Enfermedad'),
(10227, 1702, 4, 'Dislocación'),
(10228, 1703, 4, '# Disp'),
(10229, 1704, 4, 'Informe'),
(10230, 1705, 4, 'Remitir documento recibido'),
(10231, 1706, 4, 'Prescrito'),
(10232, 1707, 4, 'Mostrar las directivas anticipadas en la página de la demografía.'),
(10233, 1709, 4, '¿Mostrar fechas de eventos en bloque?'),
(10234, 1711, 4, '¿Mostrar cuántos eventos?'),
(10235, 1713, 4, '¿Mostrar lugar/sitio en bloque?'),
(10236, 1714, 4, 'Nombre de Pantalla'),
(10237, 1715, 4, '¿Mostrar el calendario?'),
(10238, 1718, 4, '¿Mostrar los eventos de hoy en el bloque?'),
(10239, 1719, 4, '¿Mostrar tema en el bloque?'),
(10240, 1720, 4, '¿Mostrar los eventos próximos en tabla?'),
(10241, 1721, 4, 'Columnas mostradas'),
(10242, 1722, 4, 'Mostrando el siguiente número de revelaciones más recientes:'),
(10243, 1723, 4, 'Mostrando el siguiente número de las notas más recientes'),
(10244, 1724, 4, 'Mostrando el siguiente número de las notas más recientes:'),
(10245, 1725, 4, 'Distribución'),
(10246, 1726, 4, 'Distribuciones'),
(10247, 1727, 4, 'Distribuidor'),
(10248, 1729, 4, 'Diverticulitis'),
(10249, 1730, 4, 'Operación de Diverticulitis'),
(10250, 1731, 4, 'Diverticulitis'),
(10251, 1732, 4, 'Operación de Diverticulitis'),
(10252, 1733, 4, 'Divorciado'),
(10253, 1734, 4, 'Mareo:'),
(10254, 1735, 4, 'No cambiar'),
(10255, 1737, 4, 'No mostrar alergia subida a NewCrop'),
(10256, 1739, 4, 'No mostrar medicación subida a NewCrop'),
(10257, 1742, 4, 'No mostrar el calendario'),
(10258, 1744, 4, 'No inventariar ni vender nigun producto'),
(10259, 1745, 4, 'No requiere notas del paciente para ser autorizado'),
(10260, 1746, 4, 'Orden de No Resucitar'),
(10261, 1747, 4, 'no guardar'),
(10262, 1748, 4, 'no sustituir'),
(10263, 1749, 4, 'no actuar'),
(10264, 1751, 4, 'De verdad quiere suprimir?'),
(10265, 1752, 4, '¿Verdaderamente desea borrar la selección?'),
(10266, 1753, 4, 'Está seguro que quiere eliminar este grupo'),
(10267, 1755, 4, '¿Quiere continuar?'),
(10268, 1756, 4, '¿Quiere borrar esto?'),
(10269, 1757, 4, '¿Quiere borrar?'),
(10270, 1758, 4, '¿Desea remover este registro?'),
(10271, 1759, 4, '¿Desea continuar agregando este nuevo paciente?'),
(10272, 1760, 4, '¿Usted desea continuar con el nuevo nombre?'),
(10273, 1761, 4, '¿Usted desea suprimir DEFINITIVAMENTE este registro de vacunación?'),
(10274, 1762, 4, 'F.Nacim.'),
(10275, 1763, 4, 'Falta fecha de nacimiento, por favor insertarla al ser posible'),
(10276, 1764, 4, 'Documentos'),
(10277, 1765, 4, 'Médico'),
(10278, 1766, 4, 'Médico:'),
(10279, 1767, 4, 'Nombre del médico y la firma'),
(10280, 1768, 4, 'Documento'),
(10281, 1769, 4, 'documento'),
(10282, 1770, 4, 'Categorías documento'),
(10283, 1775, 4, 'El documento no ha podido ser trasladado a la identificación del paciente'),
(10284, 1777, 4, 'Fecha de documento'),
(10285, 1778, 4, 'Fecha del documento e incidencia actualizadas con éxito'),
(10286, 1779, 4, 'Nº Identificación de Documento'),
(10287, 1780, 4, 'Documento se trasladó a nueva categoría'),
(10288, 1781, 4, 'Documento se trasladó al Nº Identificación del paciente'),
(10289, 1783, 4, 'Documento aprobó la comprobación de integridad'),
(10290, 1784, 4, 'Método de archivo de documentos'),
(10291, 1785, 4, 'Documento renombrado con éxito'),
(10292, 1790, 4, 'Depósito de documentos/Imágenes'),
(10293, 1791, 4, 'Documentos'),
(10294, 1792, 4, 'Documentos (escribir, addonly opcional)'),
(10295, 1794, 4, 'DOE'),
(10296, 1798, 4, '¿Este tipo permite codigos relacionados?'),
(10297, 1799, 4, 'Socio doméstico'),
(10298, 1800, 4, 'No Guardar'),
(10299, 1801, 4, 'No Guardar'),
(10300, 1802, 4, 'No Guardar Cambios'),
(10301, 1803, 4, 'Terminado'),
(10302, 1804, 4, 'Hecho con:'),
(10303, 1805, 4, 'Terminado. Ahora se enviará la descarga'),
(10304, 1806, 4, 'DOS'),
(10305, 1807, 4, 'Dosis'),
(10306, 1809, 4, 'Doble click para editar'),
(10307, 1810, 4, 'Visión doble'),
(10308, 1811, 4, 'Descarga'),
(10309, 1814, 4, 'Descargar de todas formas'),
(10310, 1815, 4, 'Descargar expediente de factura, mandar a contabilidad y marcar como facturado.'),
(10311, 1817, 4, 'Certificados de descargas'),
(10312, 1818, 4, 'Descargar datos de configuración'),
(10313, 1820, 4, 'Descargar fichero encriptado'),
(10314, 1827, 4, 'Descargar estados selectos'),
(10315, 1828, 4, 'Revisar médico'),
(10316, 1829, 4, 'Visitar médico'),
(10317, 1830, 4, 'Médico'),
(10318, 1831, 4, 'Arrastre para mover'),
(10319, 1832, 4, 'Goteo'),
(10320, 1833, 4, 'Licencia de Manejar o Identificación del Estado'),
(10321, 1834, 4, 'Medicamento'),
(10322, 1835, 4, 'Buscador de farmacos'),
(10323, 1836, 4, 'Forma de Medicamento'),
(10324, 1837, 4, 'Identificación de la droga está ausente!'),
(10325, 1838, 4, 'Intervalos de Medicamento'),
(10326, 1839, 4, 'Inventorio de Medicamento'),
(10327, 1840, 4, 'Nombre del Medicamento'),
(10328, 1841, 4, 'Vía de administración del Medicamento'),
(10329, 1845, 4, 'Unidades de Medicamento'),
(10330, 1846, 4, 'Medicamentos'),
(10331, 1847, 4, 'Medicamentos y productos'),
(10332, 1848, 4, 'Boca seca'),
(10333, 1849, 4, 'Diagnóstico DSMIV'),
(10334, 1850, 4, 'DT 1'),
(10335, 1851, 4, 'DT 2');
INSERT INTO `lang_definitions` VALUES
(10336, 1852, 4, 'DT 3'),
(10337, 1853, 4, 'DT 4'),
(10338, 1854, 4, 'DT 5'),
(10339, 1855, 4, 'DTaP 1'),
(10340, 1856, 4, 'DTaP 2'),
(10341, 1857, 4, 'DTaP 3'),
(10342, 1858, 4, 'DTaP 4'),
(10343, 1859, 4, 'DTaP 5'),
(10344, 1860, 4, 'Adeudado'),
(10345, 1861, 4, 'Fecha de la cita'),
(10346, 1862, 4, 'Fecha de la cita mm/dd/aaaa o aaaa-mm-dd'),
(10347, 1863, 4, 'Fecha de la cita:'),
(10348, 1864, 4, 'Deuda Seguro'),
(10349, 1865, 4, 'Deuda Paciente'),
(10350, 1866, 4, 'Deuda próxima'),
(10351, 1867, 4, 'Estado de Deuda'),
(10352, 1868, 4, 'Actualización Estado de Deuda'),
(10353, 1869, 4, 'Vaciar base de datos LibreEHR'),
(10354, 1870, 4, 'Vaciar árbol de directorios web de LibreEHR'),
(10355, 1871, 4, 'Vaciar base de datos phpGACL'),
(10356, 1872, 4, 'Vaciar phpGACL web de árbol de directorios'),
(10357, 1873, 4, 'Vaciar SQL-Ledger base de datos'),
(10358, 1874, 4, 'Vaciar phpGACL árbol de directorios web'),
(10359, 1875, 4, 'Compruebe duplicado'),
(10360, 1876, 4, 'ID duplicado en linea'),
(10361, 1877, 4, 'Nombre duplicado en linea'),
(10362, 1878, 4, 'AVISO DE DUPLICACION'),
(10363, 1879, 4, 'Poder Legal Duradero'),
(10364, 1880, 4, 'duración'),
(10365, 1881, 4, 'Duración'),
(10366, 1882, 4, 'Holandés'),
(10367, 1883, 4, 'Dx Rep'),
(10368, 1884, 4, 'Disfagia'),
(10369, 1885, 4, 'Disnea'),
(10370, 1886, 4, 'Disuria'),
(10371, 1888, 4, '¿E-Receta?'),
(10372, 1890, 4, 'Receta Electrónica'),
(10373, 1892, 4, 'Renovación Receta Electrónica'),
(10374, 1893, 4, 'Cada destinatario debe establecer sus propios mensajes como terminados.'),
(10375, 1894, 4, 'Repetición Temprana (<2 Mo)'),
(10376, 1895, 4, 'Orejas'),
(10377, 1896, 4, 'Electrocardiograma'),
(10378, 1897, 4, 'Reclamos electrónicos'),
(10379, 1898, 4, 'Edema'),
(10380, 1902, 4, 'Adjuntar fichero EDI-271'),
(10381, 1903, 4, 'Respuesta de carga de fichero EDI-271'),
(10382, 1904, 4, 'Editar'),
(10383, 1905, 4, 'editar'),
(10384, 1906, 4, 'Editar alergias'),
(10385, 1907, 4, 'Editar categorías'),
(10386, 1908, 4, 'Editar Definiciones'),
(10387, 1909, 4, 'Editar definiciones'),
(10388, 1910, 4, 'Editar diagnóstico para'),
(10389, 1911, 4, 'editar acceso a la info'),
(10390, 1912, 4, 'Editar Centros'),
(10391, 1913, 4, 'Editar Centro'),
(10392, 1914, 4, 'Editar información del Centro'),
(10393, 1915, 4, 'Editar información de usuario específica de Centro'),
(10394, 1916, 4, 'editar archivo en'),
(10395, 1917, 4, 'Editar forma'),
(10396, 1918, 4, 'Editar configuracion global'),
(10397, 1919, 4, 'Edición no permitida'),
(10398, 1920, 4, 'Editar el diseño'),
(10399, 1921, 4, 'Editar la lista'),
(10400, 1922, 4, 'editar pago'),
(10401, 1923, 4, 'Editar estructura'),
(10402, 1924, 4, 'Editar usuario'),
(10403, 1925, 4, 'editar configuracion de usuario'),
(10404, 1928, 4, 'Educación'),
(10405, 1929, 4, 'Fecha educación'),
(10406, 1931, 4, 'Debería haber recibido una copia del GNU con este programa, si no, escriba al Free '),
(10407, 1932, 4, 'Fecha efectiva'),
(10408, 1934, 4, 'Efectividad'),
(10409, 1935, 4, 'EIN'),
(10410, 1936, 4, 'Eyaculaciones'),
(10411, 1937, 4, 'Codo'),
(10412, 1938, 4, 'Problemas del codo'),
(10413, 1939, 4, 'Electrónico'),
(10414, 1942, 4, 'Mandatos Electronicos'),
(10415, 1944, 4, 'Elegibilidad'),
(10416, 1945, 4, 'Elegibilidad Batch Consulta 270'),
(10417, 1946, 4, 'Elegibilidad de Respuesta'),
(10418, 1947, 4, 'Estado de elegibilidad para la vacuna suministrada para niños'),
(10419, 1948, 4, 'Elegible'),
(10420, 1949, 4, 'email'),
(10421, 1951, 4, 'email'),
(10422, 1953, 4, 'email del remitente para los recordatorios de pacientes. Las respuestas de los pacientes irán a esa dirección. Es importante usar una dirección del dominio de la Clínica para evitar que las respuestas de recordatorios de los pacientes vayan a la carpeta de correo basura.'),
(10423, 1954, 4, 'email, si hay, para recibir notificaciones administrativas.'),
(10424, 1955, 4, 'email, si hay, para recibir mensajes de activación de inicio sesión de usuario.'),
(10425, 1956, 4, 'Autenticación email'),
(10426, 1957, 4, 'email de Batchcom'),
(10427, 1958, 4, 'Notificación email'),
(10428, 1959, 4, 'Horario Notificación Email'),
(10429, 1960, 4, 'Informe de notificación de email'),
(10430, 1961, 4, 'email enviado antes'),
(10431, 1962, 4, 'Remitente de email'),
(10432, 1963, 4, 'Email enviado'),
(10433, 1964, 4, 'email enviado a'),
(10434, 1965, 4, 'Asunto del email'),
(10435, 1966, 4, 'Texto del email, etiqueta útil: ***NAME***, Ej. Estimado ***NAME***'),
(10436, 1967, 4, 'Texto email, etiqueta útil:***NAME***, por ej. Estimado ***NAME***{{No traducir el elemento ***NAME*** de esta constante}}'),
(10437, 1968, 4, 'Método de envío de email'),
(10438, 1969, 4, 'Email enviado a las siguientes direcciones'),
(10439, 1971, 4, 'Contacto en caso de emergencia'),
(10440, 1972, 4, 'Persona de Contacto de Emergencia'),
(10441, 1973, 4, 'Teléfono de Contacto de Emergencia'),
(10442, 1974, 4, 'Emergencia anticonceptiva'),
(10443, 1975, 4, 'Acceso de Emergencia'),
(10444, 1976, 4, 'Acceso de Emergencia ACL elegido. El usuario esta aun activo, favor desactivar usuario y activarlo cuando la situacion de emergencia lo requiera. Visitar Administracio>Usuario para activación o deactivación.'),
(10445, 1977, 4, 'El email de activación de inicio de sesión de emergencia ha de circular sólo si los siguientes ajustes del fichero interfase/globals.php están configurados:'),
(10446, 1978, 4, 'email de inicio de sesión de emergencia'),
(10447, 1979, 4, 'El usuario de Inicio de sesión de emergencia puede hacer cualquier cosa'),
(10448, 1980, 4, 'Telefono de emergencia'),
(10449, 1982, 4, 'Enfisema'),
(10450, 1983, 4, 'Empleado'),
(10451, 1984, 4, 'Empresa'),
(10452, 1985, 4, 'Dirección del empleador'),
(10453, 1986, 4, 'Datos de la empresa'),
(10454, 1987, 4, 'Nombre de Empresa'),
(10455, 1988, 4, 'VACIO'),
(10456, 1989, 4, 'Vacio'),
(10457, 1991, 4, 'Valor vacío en "Correo electrónico Horas"'),
(10458, 1992, 4, 'Valor vacío en "Correo electrónico Remitente"'),
(10459, 1993, 4, 'Valor vacío en "Correo electrónico Asunto"'),
(10460, 1994, 4, 'Valor vacío en "Correo electrónico de texto"'),
(10461, 1995, 4, 'Valor vacío en "Nombre del Proveedor"'),
(10462, 1996, 4, 'Valor vacío en "Contraseña"'),
(10463, 1997, 4, 'Valor vacío en "Horas de SMS"'),
(10464, 1998, 4, 'Vaciar en el valor "Texto SMS"'),
(10465, 1999, 4, 'Vaciar en el valor "Usuario"'),
(10466, 2006, 4, 'Activar aviso MCA'),
(10467, 2008, 4, 'Activar Informe MCA'),
(10468, 2009, 4, 'Activar seguimiento MCA'),
(10469, 2011, 4, 'Activar auditoría ATNA'),
(10470, 2013, 4, 'Inicio de sesión Auditoría habilitado'),
(10471, 2014, 4, 'Activar Auditoría Registro y Autenticación del Nodo (ATNA)'),
(10472, 2015, 4, 'Activar Informe Medidas de Cálculo Automático (MCA)'),
(10473, 2016, 4, 'Activar Cliente SSL'),
(10474, 2017, 4, 'Activar Cliente SSL con certificado de autenticación.'),
(10475, 2019, 4, 'Activar Reglas Clínicas de Decisión (CDR)'),
(10476, 2022, 4, 'Activar informe medidas de calidad clínica (GCC)'),
(10477, 2023, 4, 'Activar popup recordatorios clínicos'),
(10478, 2024, 4, 'Activar Widget Recordatorios clínicos'),
(10479, 2027, 4, 'Activar Informes GCC'),
(10480, 2030, 4, 'Habilitar tarifas en el menú de la izquierda'),
(10481, 2031, 4, 'Activar Soporte Hylafax'),
(10482, 2033, 4, 'Activar el estado de importación de mensajes para Receta electrónica NewCrop'),
(10483, 2037, 4, 'Activar intercambio Laboratorio'),
(10484, 2039, 4, 'Habilitar registro para documentos subidos/bajados de CouchDB'),
(10485, 2040, 4, 'Activar registro de todas las consultas SQL SELECT.'),
(10486, 2041, 4, 'Activar registro de backup de actividades relacionadas.'),
(10487, 2043, 4, 'Activar inicio sesión de actividades varias.'),
(10488, 2044, 4, 'Activar registro de actividades solicitadas.'),
(10489, 2045, 4, 'Activar registro de modificaciones del registro de pacientes.'),
(10490, 2046, 4, 'Activar registro de programar actividades.'),
(10491, 2047, 4, 'Activar registro de seguridad y administración de actividades.'),
(10492, 2049, 4, 'Activar servicio Receta electrónica NewCrop'),
(10493, 2051, 4, 'Activar Portal Paciente Externo'),
(10494, 2052, 4, 'Activar Portal paciente desde el exterior.'),
(10495, 2053, 4, 'Activar Portal paciente in-situ'),
(10496, 2055, 4, 'Activar Portal paciente in-situ.'),
(10497, 2056, 4, 'Activar widget recordatorios del paciente'),
(10498, 2058, 4, 'Activar aviso fecha requerida para Medidas de Cálculo Automático (MCA)'),
(10499, 2060, 4, 'Activar Informe de Seguimiento de Fecha para Medidas de Cálculo Automático (MCA)'),
(10500, 2061, 4, 'Activar Soporte escaner'),
(10501, 2065, 4, 'Activar servicio de soporte LibreEHR LLC Laboratorio de intercambio'),
(10502, 2066, 4, 'Activar Certificado de Autenticación del usuario.'),
(10503, 2067, 4, 'Activar servicio ZMG, Receta electrónica LLC'),
(10504, 2068, 4, 'Activado'),
(10505, 2070, 4, 'Activar el viejo panel de cargos para introducir códigos de facturas y pagos. No se recomienda usar la hoja de honorarios en su lugar.'),
(10506, 2071, 4, 'Encuentro'),
(10507, 2072, 4, 'Visita'),
(10508, 2073, 4, 'Visita'),
(10509, 2074, 4, 'visita'),
(10510, 2075, 4, 'Visita '),
(10511, 2076, 4, 'Visita a un hospitalizado agudo o ED'),
(10512, 2081, 4, 'Fecha visita'),
(10513, 2086, 4, 'Formularios visita'),
(10514, 2087, 4, 'visita de salud y evaluación de comportamiento'),
(10515, 2088, 4, 'Histórico de visitas'),
(10516, 2089, 4, 'ID Visita'),
(10517, 2090, 4, 'Visita gripe'),
(10518, 2091, 4, 'número visita'),
(10519, 2093, 4, 'visita cuidado enfermería'),
(10520, 2094, 4, 'visita centro enfermería'),
(10521, 2095, 4, 'visita terapia ocupacional'),
(10522, 2096, 4, 'visita a consultorio'),
(10523, 2097, 4, 'visita paciente externo'),
(10524, 2098, 4, 'visita paciente externo con médico y Obs/Gin'),
(10525, 2099, 4, 'Tamaño página visita'),
(10526, 2100, 4, 'Pago visita'),
(10527, 2101, 4, 'visita embarazo'),
(10528, 2102, 4, 'visita medicina preventiva - asesoramiento individual'),
(10529, 2103, 4, 'visita medicina preventiva para mayores de 40'),
(10530, 2104, 4, 'visita de medicina preventiva - asesoramiento en grupo'),
(10531, 2105, 4, 'visita medicina preventiva otros servicios'),
(10532, 2106, 4, 'visita servicios medicina preventiva mayores de 18'),
(10533, 2107, 4, 'visita psiquiatrica y psicológica'),
(10534, 2108, 4, 'Estadísticas de visitas'),
(10535, 2109, 4, 'Resumen de visitas'),
(10536, 2110, 4, 'Visita codificada'),
(10537, 2111, 4, 'Visita:'),
(10538, 2112, 4, 'Visita: visita ingreso no agudo, paciente externo, o oftalmológico'),
(10539, 2113, 4, 'Visitas'),
(10540, 2114, 4, 'Visitas y Formularios'),
(10541, 2115, 4, 'Visitas y Formularios'),
(10542, 2116, 4, 'Visitas no autorizadas'),
(10543, 2117, 4, 'Informe de visitas'),
(10544, 2118, 4, 'Sección visitas'),
(10545, 2120, 4, 'Encriptación'),
(10546, 2121, 4, 'Final'),
(10547, 2122, 4, 'Final (aaaa-mm-dd): '),
(10548, 2123, 4, 'Fecha final'),
(10549, 2124, 4, 'Fecha final'),
(10550, 2126, 4, 'Fecha final debe ser posterior a fecha inicio'),
(10551, 2127, 4, 'Fecha Final:'),
(10552, 2131, 4, 'Hora finalización'),
(10553, 2132, 4, 'Enfermedad renal en Etapa Final - Beneficiario de MCP con un Plan de grupo del empleador'),
(10554, 2133, 4, 'Fecha final de servicio aaaa-mm-dd'),
(10555, 2134, 4, 'Termina DOS dd/mm/aaaa si desea entrar en una serie'),
(10556, 2135, 4, 'Hora final del día para eventos de calendario'),
(10557, 2136, 4, 'Sangre anormal Endo'),
(10558, 2137, 4, 'Endocrino'),
(10559, 2138, 4, 'Endoscopía'),
(10560, 2141, 4, 'Inglés'),
(10561, 2142, 4, 'Inglés '),
(10562, 2143, 4, 'Ingleses (Indios)'),
(10563, 2144, 4, 'Inglés (Estándar)'),
(10564, 2145, 4, 'Enscript comando usado por Hylafax.'),
(10565, 2146, 4, 'Garantizar LibreEHR tiene privilegios al directorio'),
(10566, 2147, 4, 'Descarga ORL'),
(10567, 2148, 4, 'Dolor ORL'),
(10568, 2149, 4, 'Introduzca un código de la diagnosis para excluir todas las facturas que no lo contienen'),
(10569, 2151, 4, 'Incorpore el cuerpo de la carta aquí'),
(10570, 2152, 4, 'Introduzca Contraseña root para Base Datos'),
(10571, 2153, 4, 'Introduzca Usuario root para Base Datos'),
(10572, 2154, 4, 'Introduzca Diagnóstico'),
(10573, 2155, 4, 'Introduzca Medicamentos'),
(10574, 2158, 4, 'Introduzca Vacunas'),
(10575, 2159, 4, 'Introducir Clave'),
(10576, 2161, 4, 'Escriba el nuevo Estado'),
(10577, 2164, 4, 'Introducir código Re-identificación'),
(10578, 2165, 4, 'Incorpore sus criterios de búsqueda arriba'),
(10579, 2167, 4, 'entradas'),
(10580, 2168, 4, 'Ambiental'),
(10581, 2169, 4, 'Entrada de datos de EOB'),
(10582, 2170, 4, 'EOB envío - Remesas electrónicas'),
(10583, 2171, 4, 'EOB envío - Instrucciones'),
(10584, 2172, 4, 'EOB envío - Factura'),
(10585, 2173, 4, 'EOB envío - Nota del Paciente'),
(10586, 2174, 4, 'EOB envío - Buscar'),
(10587, 2176, 4, 'Epilepsia'),
(10588, 2178, 4, 'ERA (Aviso de Remesa Electrónica)'),
(10589, 2180, 4, 'Envío ERA'),
(10590, 2181, 4, 'Borrar'),
(10591, 2182, 4, 'Erecciones'),
(10592, 2183, 4, 'Error'),
(10593, 2185, 4, 'Error confirmando la recepción de los resultados del laboratorio'),
(10594, 2187, 4, 'Error al obtener los resultados de laboratorio de la red de intercambio del laboratorio'),
(10595, 2188, 4, 'Error en selección de género'),
(10596, 2189, 4, 'Error en "HIPAA" selección'),
(10597, 2190, 4, 'Error en el "Proceso de selección'),
(10598, 2191, 4, 'El error en la selección de "Puerta de SMS"'),
(10599, 2192, 4, 'Error en "Ordenar por" selección'),
(10600, 2193, 4, 'Error del file de compresion gzip '),
(10601, 2194, 4, 'Error en la opción SI o NO'),
(10602, 2195, 4, 'Error al abrir archivo cargado para lectura'),
(10603, 2198, 4, 'Error al eliminar el mensaje'),
(10604, 2199, 4, 'Error recuperando resultados de la red de intercambio del laboratorio'),
(10605, 2202, 4, 'Error en el fichero de concesión de privilegios para el usuario de LibreEHR.'),
(10606, 2205, 4, 'error al registrar la forma!'),
(10607, 2206, 4, 'Error al guardar en el archivo'),
(10608, 2208, 4, 'Error al escribir en el archivo'),
(10609, 2210, 4, 'Error, Este file no existe'),
(10610, 2211, 4, 'ERROR, incapaz de recoger los datos de servidor'),
(10611, 2212, 4, 'Error, incapaz de crear certificado de cliente'),
(10612, 2213, 4, 'Error, incapaz de crear el certificado p12 de Admin'),
(10613, 2214, 4, 'Error. No puede crearse certificadodo de Certificado de Autenticacion'),
(10614, 2215, 4, 'Error, incapaz de crear el certificado del servidor'),
(10615, 2216, 4, 'Error, incapaz de abrir el file'),
(10616, 2217, 4, 'Error. Certificado de Autenticacion de usuario no esta habilitado en LibreEHR'),
(10617, 2218, 4, 'Error. Necesita instalar el Archivo/Tar.php php modulo'),
(10618, 2219, 4, 'ERROR: no pudo abrir tabla sql, formulario roto?'),
(10619, 2220, 4, 'Error: ID duplicado en línea'),
(10620, 2221, 4, 'Error: Nombre duplicado en línea'),
(10621, 2222, 4, 'ERROR: Campo'),
(10622, 2223, 4, 'ERROR: Falta el fichero comprimido del Módulo PHP'),
(10623, 2224, 4, 'ERROR: Sin directorio de importación ICD'),
(10624, 2225, 4, 'Error: las contraseñas no coinciden. Por favor, compruebe lo tecleado.'),
(10625, 2226, 4, 'Error: las contraseñas no coinciden. Por favor, compruebe lo tecleado.'),
(10626, 2227, 4, 'Error, este file no existe'),
(10627, 2228, 4, 'ERROR: La siguiente variable contiene caracteres inválidos'),
(10628, 2229, 4, 'ERROR: No se puede copiar el fichero.'),
(10629, 2230, 4, 'Error, incapaz de crear el fichero de descarga'),
(10630, 2231, 4, 'ERROR: No se puede crear el fichero comprimido.'),
(10631, 2232, 4, 'ERROR: No se puede extraer el fichero.'),
(10632, 2233, 4, 'ERROR: No se puede leer el fichero en la base de datos.'),
(10633, 2234, 4, 'ERROR: No se puede establecer el número de versión.'),
(10634, 2235, 4, 'Errores'),
(10635, 2236, 4, 'Estado cuenta Receta electrónica'),
(10636, 2237, 4, 'Registros Receta electrónica'),
(10637, 2238, 4, 'Nombre Receta electrónica'),
(10638, 2239, 4, 'Contraseña Receta electrónica'),
(10639, 2240, 4, 'Rol Receta electrónica'),
(10640, 2241, 4, 'Usuario Receta electrónica'),
(10641, 2242, 4, 'Eritema'),
(10642, 2245, 4, 'Esquimal'),
(10643, 2247, 4, 'Paciente regular'),
(10644, 2249, 4, 'Raza'),
(10645, 2250, 4, 'La etnia o la raza'),
(10646, 2251, 4, 'Lista de Origen étnico--Raza (escriba, sólo añadir opcional)'),
(10647, 2252, 4, 'ETIN'),
(10648, 2253, 4, 'Evento'),
(10649, 2254, 4, 'Fecha comienzo de evento'),
(10650, 2255, 4, 'Categoría de evento'),
(10651, 2256, 4, 'Fecha evento'),
(10652, 2257, 4, 'Descripción evento'),
(10653, 2258, 4, 'Detalles evento'),
(10654, 2259, 4, 'Evento no se repite'),
(10655, 2260, 4, 'Duración de Evento'),
(10656, 2261, 4, 'Duración de evento en minutos'),
(10657, 2262, 4, 'Honorarios del evento'),
(10658, 2263, 4, 'Lugar de evento'),
(10659, 2264, 4, 'Evento repite cada'),
(10660, 2265, 4, 'Evento repite en'),
(10661, 2266, 4, 'Hora comienzo evento'),
(10662, 2267, 4, 'Título de evento'),
(10663, 2268, 4, 'Título de Evento'),
(10664, 2269, 4, 'Página web de evento'),
(10665, 2270, 4, 'Eventos'),
(10666, 2271, 4, 'Eventos para'),
(10667, 2272, 4, 'Eventos abre en nueva ventana'),
(10668, 2273, 4, 'cada'),
(10669, 2274, 4, 'Cada'),
(10670, 2275, 4, 'cada 3 horas'),
(10671, 2276, 4, 'cada 4 horas'),
(10672, 2277, 4, 'cada 5 horas'),
(10673, 2278, 4, 'cada 6 horas'),
(10674, 2279, 4, 'cada 8 horas'),
(10675, 2280, 4, 'cada cuarto'),
(10676, 2281, 4, 'uno sí, otro no'),
(10677, 2282, 4, 'cada tercero'),
(10678, 2283, 4, 'Cada, cada otro, cada 3ro, etc.'),
(10679, 2285, 4, 'Examen y los resultados de las pruebas'),
(10680, 2286, 4, 'Resultados del examen'),
(10681, 2289, 4, 'Examen'),
(10682, 2290, 4, 'Fecha de examen'),
(10683, 2291, 4, 'Ejemplo'),
(10684, 2292, 4, 'Ejemplos'),
(10685, 2293, 4, 'Exámenes/Pruebas'),
(10686, 2294, 4, 'Excepto'),
(10687, 2295, 4, 'Lagrimeo Excesivo'),
(10688, 2296, 4, 'Pacientes Excluídos'),
(10689, 2297, 4, 'Exclusiones'),
(10690, 2298, 4, 'Organización de provedor exclusivo (OPE)'),
(10691, 2299, 4, 'Tamaño papel ejecutivo'),
(10692, 2300, 4, 'Ejercicio'),
(10693, 2301, 4, 'Patrones del ejercicio'),
(10694, 2302, 4, 'Patrones de ejercicio'),
(10695, 2303, 4, 'Existe'),
(10696, 2304, 4, 'Salir de Administración'),
(10697, 2305, 4, 'Exp'),
(10698, 2306, 4, 'Expandir'),
(10699, 2307, 4, 'Expandir'),
(10700, 2308, 4, 'Expandir Todo'),
(10701, 2311, 4, 'Vista ampliada'),
(10702, 2312, 4, 'Se espera form_encounter.pid para ser '),
(10703, 2313, 4, 'Caducidad'),
(10704, 2314, 4, 'Fecha de caducidad'),
(10705, 2315, 4, 'Caducidad'),
(10706, 2316, 4, 'Expira en'),
(10707, 2317, 4, 'Exportar'),
(10708, 2318, 4, 'Exportar con CSV'),
(10709, 2319, 4, 'Exportar configuración'),
(10710, 2322, 4, 'Exportación de Demograficos del paciente'),
(10711, 2323, 4, 'Exportar Informe PQRI'),
(10712, 2325, 4, 'Selección de exportación como CSV'),
(10713, 2326, 4, 'Exportar lo marcado a cobranzas'),
(10714, 2327, 4, 'Exportar a CSV'),
(10715, 2328, 4, 'Exportación al sistema de facturación externo'),
(10716, 2329, 4, 'Exposición a los países extranjeros'),
(10717, 2330, 4, 'Exposición a Países Extranjeros'),
(10718, 2331, 4, 'Ext tiempo de coleccionar'),
(10719, 2332, 4, 'Externo'),
(10720, 2334, 4, 'Carga de datos externos'),
(10721, 2335, 4, 'Utilidad de importación bbdd externa'),
(10722, 2336, 4, 'Identificador externo'),
(10723, 2337, 4, 'ID externo'),
(10724, 2338, 4, 'Identificador externo'),
(10725, 2339, 4, 'Identificador externo'),
(10726, 2342, 4, 'Derivación externa'),
(10727, 2343, 4, 'Seguimiento de Derivaciones Externas'),
(10728, 2344, 4, '¿Derivación externa?'),
(10729, 2345, 4, 'Derivaciones externas'),
(10730, 2346, 4, 'Extraer este file comprimido'),
(10731, 2347, 4, 'Extrayendo fichero. Esto puede tardar algún tiempo...'),
(10732, 2348, 4, 'Exudado:'),
(10733, 2349, 4, 'Irritación de Ojo'),
(10734, 2350, 4, 'Dolor de Ojo'),
(10735, 2351, 4, 'Enrojecimiento de Ojo'),
(10736, 2352, 4, 'Ojos'),
(10737, 2353, 4, 'F'),
(10738, 2354, 4, 'F/H Problemas de Sangre'),
(10739, 2355, 4, 'F/H Hirsutismo Femenino/Estrías'),
(10740, 2356, 4, 'Centros'),
(10741, 2357, 4, 'Centro'),
(10742, 2358, 4, 'centro'),
(10743, 2359, 4, 'Administración de Centro'),
(10744, 2360, 4, 'Ciudad del Centro'),
(10745, 2361, 4, 'Código del Centro'),
(10746, 2362, 4, 'Código País del Centro'),
(10747, 2363, 4, 'Fax del Centro'),
(10748, 2364, 4, 'Nombre del Centro'),
(10749, 2365, 4, 'NPI del Centro'),
(10750, 2366, 4, 'Teléfono del Centro'),
(10751, 2367, 4, 'Información de usuario específica de Centro'),
(10752, 2368, 4, 'Estado del Centro'),
(10753, 2369, 4, 'Dirección del Centro'),
(10754, 2370, 4, 'Código Postal del Centro'),
(10755, 2372, 4, 'Centro:'),
(10756, 2373, 4, 'Fallo'),
(10757, 2374, 4, 'fallado'),
(10758, 2375, 4, 'Fallado'),
(10759, 2380, 4, 'Fallo al crear la carpeta temporal. CouchDB no funcionará.'),
(10760, 2382, 4, 'Fallo'),
(10761, 2383, 4, 'error'),
(10762, 2390, 4, 'Historia familiar'),
(10763, 2391, 4, 'Historia Familiar de Glaucoma'),
(10764, 2392, 4, 'Historia'),
(10765, 2394, 4, 'Pago por familia'),
(10766, 2395, 4, 'Tamaño familia'),
(10767, 2396, 4, 'Suposición'),
(10768, 2398, 4, 'Iraní'),
(10769, 2400, 4, 'Padre'),
(10770, 2402, 4, 'Fatiga'),
(10771, 2403, 4, 'Fatigado'),
(10772, 2404, 4, 'Fax'),
(10773, 2405, 4, 'Contador fax'),
(10774, 2406, 4, 'Número de fax'),
(10775, 2408, 4, 'Fax/Escanear'),
(10776, 2409, 4, 'Faxes entrada'),
(10777, 2410, 4, 'Faxes salida'),
(10778, 2411, 4, 'Características'),
(10779, 2412, 4, 'Feb'),
(10780, 2413, 4, 'Febrero'),
(10781, 2414, 4, 'FECA'),
(10782, 2415, 4, 'Identificación de medicamento federal'),
(10783, 2416, 4, 'Federal EIN'),
(10784, 2417, 4, 'Identificación de impuesto federal'),
(10785, 2418, 4, 'Tarifa'),
(10786, 2419, 4, 'tarifa'),
(10787, 2420, 4, 'No se permite la tarifa'),
(10788, 2421, 4, 'Hoja de tarifas'),
(10789, 2422, 4, 'Opciones de la hoja de tarifas'),
(10790, 2423, 4, 'Tarifas'),
(10791, 2424, 4, 'Mujer'),
(10792, 2425, 4, 'Pild. anticoncep. fem.'),
(10793, 2426, 4, 'Condones femeninos'),
(10794, 2427, 4, 'Gentif. Femenino'),
(10795, 2428, 4, 'Fem.: último embar.'),
(10796, 2429, 4, 'Pelv. Femenina'),
(10797, 2430, 4, 'Síntomas Femeninos'),
(10798, 2431, 4, 'Fem.: contracepción quir. volunt.'),
(10799, 2434, 4, 'Fiebre'),
(10800, 2435, 4, 'Fiebre'),
(10801, 2436, 4, 'Problemas de Sangre FH'),
(10802, 2437, 4, 'Fibromas'),
(10803, 2441, 4, 'Tipo de campo a utilizar para el país del empleador o abonado en demográficos.'),
(10804, 2442, 4, 'Tipo de campo a utilizar para el estado del empleador o abonado en demográficos.'),
(10805, 2443, 4, 'Falta Campo(s)!'),
(10806, 2447, 4, 'Fichero'),
(10807, 2448, 4, 'Archivo en el directorio de documentación para aprender a automatizar el proceso de creación de copias de seguridad de registro'),
(10808, 2449, 4, 'Ubicacion del file'),
(10809, 2450, 4, 'Gestión de Fichero'),
(10810, 2453, 4, 'Fichero de permisos de usuario de LibreEHR'),
(10811, 2454, 4, 'Fallo en la recuperación de archivo de CouchDB'),
(10812, 2455, 4, 'Sala de archivo'),
(10813, 2456, 4, 'Fichero para adjuntar'),
(10814, 2458, 4, 'Un fichero con el mismo nombre ya existe en la ubicación:'),
(10815, 2459, 4, 'Nombre de fichero'),
(10816, 2461, 4, 'Ficheros'),
(10817, 2462, 4, 'Filipino'),
(10818, 2463, 4, 'Rellene cualquiera de las filas de abajo.'),
(10819, 2464, 4, 'Rellenar sólo si manda notificación a paciente por email'),
(10820, 2465, 4, 'Llenar los valores abajo'),
(10821, 2467, 4, 'Rellene la fila'),
(10822, 2468, 4, 'Filtro'),
(10823, 2469, 4, 'Filtro para los constantes'),
(10824, 2470, 4, 'Filtro por Definición'),
(10825, 2471, 4, 'Filtrado desde'),
(10826, 2472, 4, 'filtros'),
(10827, 2473, 4, 'Filtros'),
(10828, 2474, 4, 'Final'),
(10829, 2475, 4, 'Diagnóstico final'),
(10830, 2476, 4, 'Diagnóstico final por especialista'),
(10831, 2478, 4, 'Financiero'),
(10832, 2479, 4, 'Fecha cierre financiero (aaaa-mm-dd)'),
(10833, 2480, 4, 'Información financiera - cualquier cosa'),
(10834, 2481, 4, 'Información financiera - mis visitas'),
(10835, 2482, 4, 'Fecha de revisión financiero'),
(10836, 2483, 4, 'Resumen Financiero por Código de Servicio'),
(10837, 2484, 4, 'Buscar'),
(10838, 2485, 4, 'Buscar disponible'),
(10839, 2486, 4, 'Buscar citas disponibles'),
(10840, 2487, 4, 'Busca paciente'),
(10841, 2488, 4, 'Buscar materiales educativos para el paciente'),
(10842, 2489, 4, 'Conclusiones'),
(10843, 2490, 4, 'Conclusiones por especialista'),
(10844, 2491, 4, 'Multa'),
(10845, 2492, 4, 'Final Pagos'),
(10846, 2493, 4, 'Terminado'),
(10847, 2495, 4, 'Primero'),
(10848, 2497, 4, 'Primer día de la semana'),
(10849, 2498, 4, 'Nombre'),
(10850, 2499, 4, 'Nombre'),
(10851, 2500, 4, 'Nombre'),
(10852, 2503, 4, 'Aptitud'),
(10853, 2504, 4, 'Condicion Fisica'),
(10854, 2505, 4, 'Condicion Fisica para este jugador hoy'),
(10855, 2507, 4, 'Aptitud a jugar'),
(10856, 2508, 4, 'Encuentro fijar fechas - cualquier encuentros'),
(10857, 2509, 4, 'Solucionar este'),
(10858, 2510, 4, 'FL'),
(10859, 2511, 4, 'Flatulencia'),
(10860, 2512, 4, 'Flujo'),
(10861, 2514, 4, 'Temporada de gripe'),
(10862, 2515, 4, 'Temporada de Gripe'),
(10863, 2516, 4, 'Vacunación gripe'),
(10864, 2517, 4, 'Problema de fluído y electrolito'),
(10865, 2518, 4, 'FMS'),
(10866, 2519, 4, 'Tamaño papel folio'),
(10867, 2520, 4, 'Seguir manualmente'),
(10868, 2521, 4, 'Siga estas instrucciones para instalar o actualizar la siguiente bbdd'),
(10869, 2522, 4, 'Seguimineto'),
(10870, 2524, 4, 'Motivo de seguimiento'),
(10871, 2525, 4, 'A continuación una nueva constante de cliente:'),
(10872, 2526, 4, 'A continuación un nuevo idioma de cliente:'),
(10873, 2527, 4, 'A continuación una nueva definición (Idioma, Constante, Definición):'),
(10874, 2529, 4, 'Servicios de seguimiento'),
(10875, 2530, 4, 'Seguimiento indicado'),
(10876, 2531, 4, 'Intolerancia del Alimento'),
(10877, 2532, 4, 'Pie'),
(10878, 2533, 4, 'Problemas en los píes'),
(10879, 2534, 4, 'Píe:'),
(10880, 2535, 4, 'Lesiones de fútbol'),
(10881, 2537, 4, 'Informe de lesión futbolística'),
(10882, 2538, 4, 'Tipo de calzado'),
(10883, 2539, 4, 'para'),
(10884, 2540, 4, 'Para'),
(10885, 2541, 4, 'Por Código'),
(10886, 2543, 4, 'Reclamo por visita'),
(10887, 2544, 4, 'Poe Ejemplo'),
(10888, 2547, 4, 'Por Factura'),
(10889, 2548, 4, 'Para Seguro médico sólo, obliga al facultativo de referencia a ser el mismo que el facultativo del representado.'),
(10890, 2552, 4, 'Para el profesional/Organizacion referida'),
(10891, 2553, 4, 'Por el pasado'),
(10892, 2554, 4, 'por variable'),
(10893, 2555, 4, 'para:'),
(10894, 2556, 4, 'Fuerza la apertura del widget de facturación'),
(10895, 2557, 4, 'Forzar Crear Nuevo Paciente'),
(10896, 2559, 4, 'Antebrazo'),
(10897, 2560, 4, 'Formulario'),
(10898, 2561, 4, 'formulario'),
(10899, 2564, 4, 'Formato'),
(10900, 2565, 4, 'formato'),
(10901, 2567, 4, 'Formato incorrecto para el NDC'),
(10902, 2568, 4, 'Formato usado para la mayoría de fechas'),
(10903, 2569, 4, 'Formato usado para mostrar la mayoría de horas.'),
(10904, 2570, 4, 'Informe Formateado'),
(10905, 2571, 4, 'Ex-fumador'),
(10906, 2572, 4, 'Formularios'),
(10907, 2573, 4, 'Formas de administración'),
(10908, 2575, 4, 'Re-enviar'),
(10909, 2576, 4, 'Reenviar Páginas vía fax'),
(10910, 2577, 4, 'Remitido'),
(10911, 2579, 4, 'Cuarto'),
(10912, 2581, 4, 'Fractura'),
(10913, 2582, 4, 'Fractura de escafoides'),
(10914, 2583, 4, 'Fractura del maléolo lat.'),
(10915, 2584, 4, 'Fractura del maléolo med.'),
(10916, 2585, 4, 'Fractura de base quinta (5 ª) metatarsianas'),
(10917, 2587, 4, 'Francés'),
(10918, 2588, 4, 'Francés (Canadiense)'),
(10919, 2589, 4, 'Francés (Standard)'),
(10920, 2590, 4, 'Frecuencia'),
(10921, 2591, 4, 'Resfriados Frecuentes'),
(10922, 2592, 4, 'Enfermedades Frecuentes'),
(10923, 2593, 4, 'Viernes'),
(10924, 2594, 4, 'Viernes'),
(10925, 2595, 4, 'Desde'),
(10926, 2596, 4, 'DESDE'),
(10927, 2597, 4, 'desde'),
(10928, 2598, 4, 'Fecha desde no puede ser mayor que fecha hasta'),
(10929, 2599, 4, 'Desde:'),
(10930, 2600, 4, 'Desde: '),
(10931, 2601, 4, 'DESDE_CIUDAD'),
(10932, 2603, 4, 'DESDE_NOMBRE'),
(10933, 2604, 4, 'DESDE_APELLIDO'),
(10934, 2605, 4, 'DESDE_SEGUNDONOMBRE'),
(10935, 2607, 4, 'DESDE_TELÉFONOCELULAR'),
(10936, 2608, 4, 'DESDE_POSTAL'),
(10937, 2609, 4, 'DESDE_ESTADO'),
(10938, 2610, 4, 'DESDE_CALLE'),
(10939, 2611, 4, 'DESDE_TÍTULO'),
(10940, 2612, 4, 'DESDE_DESPEDIDA'),
(10941, 2613, 4, 'Oficina central'),
(10942, 2614, 4, 'Recibos de la Oficina Central'),
(10943, 2615, 4, 'Reportes de Recibos de la Oficina Central'),
(10944, 2616, 4, 'Rec. Oficina Central'),
(10945, 2617, 4, 'Frontal derecha'),
(10946, 2619, 4, 'Nombre Completo'),
(10947, 2620, 4, 'Ruta completa del directorio que contiene los ejecutables MySQL.'),
(10948, 2621, 4, 'Ruta completa del directorio que contiene los ejecutables Perl.'),
(10949, 2622, 4, 'Ruta completa del directorio para log de eventos de backup'),
(10950, 2623, 4, 'Ruta completa del directorio usado para ficheros temporales'),
(10951, 2624, 4, 'Juego completo'),
(10952, 2625, 4, 'Entrenamiento completo'),
(10953, 2626, 4, 'Pagado Total'),
(10954, 2633, 4, 'G'),
(10955, 2634, 4, 'G/DL'),
(10956, 2636, 4, 'Afección de la vesícula biliar'),
(10957, 2637, 4, 'Cálculos en la vesícula'),
(10958, 2638, 4, 'Periodo de Juego'),
(10959, 2639, 4, 'Juegos'),
(10960, 2640, 4, 'Juegos faltados'),
(10961, 2641, 4, 'juegos/eventos'),
(10962, 2642, 4, 'Juegos/Eventos perdidos'),
(10963, 2644, 4, 'Gastritis'),
(10964, 2645, 4, 'Dolor Gastrointestinal'),
(10965, 2646, 4, 'Gastrointestinal'),
(10966, 2647, 4, 'Informe de estadísticas del GCAC'),
(10967, 2648, 4, 'Estadísticas GCAC'),
(10968, 2649, 4, 'Falta la forma de la visita del GCAC'),
(10969, 2650, 4, 'Género'),
(10970, 2651, 4, 'Género '),
(10971, 2652, 4, 'General'),
(10972, 2655, 4, 'Categoría de servicio general'),
(10973, 2657, 4, 'Generar y Descargar'),
(10974, 2658, 4, 'Generar y descargar reclamos HCFA 1500 en papel'),
(10975, 2659, 4, 'Generar y descargar batch X12'),
(10976, 2660, 4, 'Generar y descargar batch X12 de reclamo por visita'),
(10977, 2663, 4, 'Generar y transmitir electrónicamente las recetas autorizadas.'),
(10978, 2664, 4, 'Generar formulario CMS 1500'),
(10979, 2665, 4, 'Gen.form.CMS1500 pdf'),
(10980, 2666, 4, 'Gen.form. CMS1500 texto'),
(10981, 2667, 4, 'Genere HCFA'),
(10982, 2668, 4, 'Generar recibo'),
(10983, 2669, 4, 'Genere la Carta'),
(10984, 2670, 4, 'Generar carta relacionada '),
(10985, 2671, 4, 'Generar informe PQRI (Método A)'),
(10986, 2673, 4, 'Generar informe PQRI (Método E)'),
(10987, 2677, 4, 'Generar informe'),
(10988, 2678, 4, 'Generar usuario y contraseña para'),
(10989, 2679, 4, 'Generar X12'),
(10990, 2680, 4, 'Generar visita X12'),
(10991, 2682, 4, 'Generado en'),
(10992, 2683, 4, 'genera'),
(10993, 2684, 4, 'Genitourinario'),
(10994, 2687, 4, 'Alemán'),
(10995, 2691, 4, 'Obtener HL7'),
(10996, 2692, 4, 'Glaucoma'),
(10997, 2693, 4, 'Historia Familiar de Glaucoma'),
(10998, 2694, 4, 'Global'),
(10999, 2696, 4, 'ID Global'),
(11000, 2697, 4, 'Ajustes Globales'),
(11001, 2698, 4, 'Globales'),
(11002, 2699, 4, 'GM/DL'),
(11003, 2700, 4, 'ir'),
(11004, 2701, 4, 'Ir'),
(11005, 2704, 4, 'Ir a'),
(11006, 2705, 4, 'Ir a la semana del'),
(11007, 2706, 4, 'Ir hoy'),
(11008, 2711, 4, 'Grado de la lesión'),
(11009, 2712, 4, 'Grado:'),
(11010, 2713, 4, 'Gramos'),
(11011, 2714, 4, 'Suma total'),
(11012, 2715, 4, 'Sumas totales'),
(11013, 2718, 4, 'Posibilidad de gráfico'),
(11014, 2720, 4, 'Mayor que'),
(11015, 2721, 4, 'Mayor que o Igual a'),
(11016, 2722, 4, 'Griego'),
(11017, 2724, 4, 'Grupo'),
(11018, 2725, 4, 'Nombre de Grupo'),
(11019, 2726, 4, 'Los nombres de los grupos no pueden quedar en blanco'),
(11020, 2727, 4, 'Los nombres de los grupos no pueden iniciar con números'),
(11021, 2728, 4, 'Los nombres de grupo no pueden comenzar con números.'),
(11022, 2729, 4, 'Número de grupo'),
(11023, 2730, 4, 'Pago en grupo'),
(11024, 2731, 4, 'Grupo:'),
(11025, 2732, 4, 'Nombre del grupo'),
(11026, 2733, 4, 'Controles de grupos y accesos'),
(11027, 2734, 4, 'Gráfico de Crecimiento'),
(11028, 2735, 4, 'Gráfico de Crecimiento'),
(11029, 2736, 4, 'gtts (gotas)'),
(11030, 2737, 4, 'Guamés'),
(11031, 2739, 4, 'Nombre del tutor'),
(11032, 2741, 4, 'Examen ginecológico'),
(11033, 2742, 4, 'h'),
(11034, 2743, 4, 'h.s.'),
(11035, 2744, 4, 'H/O Hepatitis'),
(11036, 2745, 4, 'se ha suprimido con éxito. Cualquier eventual sub-categoría, trasladada abajo'),
(11037, 2746, 4, 'Hematoma/moretón'),
(11038, 2747, 4, 'Estado HAI'),
(11039, 2750, 4, 'manos + dedos'),
(11040, 2751, 4, 'Problemas de manos'),
(11041, 2752, 4, 'Disco Duro'),
(11042, 2753, 4, 'Dificultad sin'),
(11043, 2754, 4, 'se ha ligado para visitar'),
(11044, 2755, 4, 'ha expirado'),
(11045, 2756, 4, 'Función Hash'),
(11046, 2757, 4, 'No existe hash para este fichero. Un nuevo hash será generado.'),
(11047, 2758, 4, 'Hash no coincide. La integridad de datos se ha visto comprometida.'),
(11048, 2760, 4, 'Hawaiano'),
(11049, 2761, 4, 'Actividades peligrosas'),
(11050, 2762, 4, 'Actividades peligrosas'),
(11051, 2763, 4, 'Margen izquierdo de HCFA en puntos'),
(11052, 2764, 4, 'Márgenes de HCFA'),
(11053, 2765, 4, 'Margen superior de HCFA en puntos'),
(11054, 2766, 4, 'Procedimiento/Servicio HCPCS'),
(11055, 2767, 4, 'Publicar Calendario '),
(11056, 2768, 4, 'Cabeza'),
(11057, 2769, 4, 'Circunferencia de la cabeza'),
(11058, 2770, 4, 'Circunferencia de la cabeza'),
(11059, 2771, 4, 'Dolor de cabeza'),
(11060, 2772, 4, 'Dolores de cabeza'),
(11061, 2773, 4, 'Operaciones de atención médica'),
(11062, 2774, 4, 'Operaciones de Atención Médica'),
(11063, 2775, 4, 'Centro de salud/clínica'),
(11064, 2776, 4, 'Organización para el mantenimiento de la salud'),
(11065, 2777, 4, 'Riesgo de Medicare de la organización de mantenimiento de salud (HMO)'),
(11066, 2778, 4, 'Pérdida de Oído'),
(11067, 2779, 4, 'Ataque del Corazón'),
(11068, 2780, 4, 'Enfermedad del corazón'),
(11069, 2781, 4, 'Fallo cardiaco'),
(11070, 2782, 4, 'Problema del Corazón'),
(11071, 2783, 4, 'Problemas de corazón'),
(11072, 2784, 4, 'Cirugía del Corazón'),
(11073, 2785, 4, 'Transplante de corazón'),
(11074, 2786, 4, 'CORAZÓN:'),
(11075, 2787, 4, 'Ardor de estómago'),
(11076, 2788, 4, 'Calor o Frío'),
(11077, 2789, 4, 'Calor o Frío'),
(11078, 2791, 4, 'Hebreo'),
(11079, 2793, 4, 'Cabeza, ojos, ORL'),
(11080, 2794, 4, 'Altura'),
(11081, 2796, 4, 'Ayuda'),
(11082, 2797, 4, 'ayuda'),
(11083, 2798, 4, 'Hematemesis'),
(11084, 2799, 4, 'Hematoquecia (rectorragia)'),
(11085, 2800, 4, 'Hematológico'),
(11086, 2801, 4, 'Hematuria'),
(11087, 2802, 4, 'Hemoglobina'),
(11088, 2803, 4, 'Hemoglobina A1C'),
(11089, 2804, 4, 'Hemoptisis'),
(11090, 2805, 4, 'Hepatitis'),
(11091, 2806, 4, 'Hepatitis A 1'),
(11092, 2807, 4, 'Hepatitis A 2'),
(11093, 2808, 4, 'Hepatitis B 1'),
(11094, 2809, 4, 'Hepatitis B 2'),
(11095, 2810, 4, 'Hepatitis B 3'),
(11096, 2811, 4, 'aqui'),
(11097, 2813, 4, 'Reparación de la hernia'),
(11098, 2814, 4, 'disco herniado'),
(11099, 2815, 4, 'Herpes'),
(11100, 2816, 4, 'Vacilación'),
(11101, 2817, 4, 'Ey, tú. has estado aquí para '),
(11102, 2818, 4, 'Hib 1'),
(11103, 2819, 4, 'Hib 2'),
(11104, 2820, 4, 'Hib 3'),
(11105, 2821, 4, 'Hib 4'),
(11106, 2822, 4, 'Oculto'),
(11107, 2823, 4, 'Administración de eventos ocultos'),
(11108, 2824, 4, 'Ocultar'),
(11109, 2825, 4, 'Ocultar detalles'),
(11110, 2827, 4, 'Ocultar las opciones de cifrado/descifrado en la gestión de documentos'),
(11111, 2828, 4, 'Ocultar Menu'),
(11112, 2830, 4, 'Ocultar Recordatorios'),
(11113, 2831, 4, 'Ocultar/Mostrar Columnas'),
(11114, 2833, 4, 'Alto'),
(11115, 2834, 4, 'Presión Sanguínea Alta'),
(11116, 2835, 4, 'Hindú'),
(11117, 2836, 4, 'Cadera + ingle'),
(11118, 2837, 4, 'Cadera y ingle'),
(11119, 2838, 4, 'Problemas de cadera'),
(11120, 2839, 4, 'Reemplazo de Cadera'),
(11121, 2840, 4, 'Aviso Recibido de HIPPA'),
(11122, 2842, 4, 'Hirsutismo/Estrías'),
(11123, 2843, 4, 'Hispano'),
(11124, 2844, 4, 'Hispano - Otro (Nacido en EEUU)'),
(11125, 2845, 4, 'Hispano - Otro (Nacido fura de EEUU)'),
(11126, 2846, 4, 'Hispano o Latino'),
(11127, 2847, 4, 'Historial'),
(11128, 2848, 4, 'Historia de Datos'),
(11129, 2849, 4, 'Fecha de Historia'),
(11130, 2851, 4, 'Historia de Murmullos'),
(11131, 2852, 4, 'Historia no está Autorizado'),
(11132, 2853, 4, 'Historia de Murmullos de Corazón'),
(11133, 2854, 4, 'Hits'),
(11134, 2855, 4, 'HIV'),
(11135, 2858, 4, 'Visor HL7'),
(11136, 2860, 4, 'HMO/L'),
(11137, 2861, 4, 'Hmong'),
(11138, 2862, 4, 'Mantener apretado Control para selecciones múltiples o deseleccionar'),
(11139, 2863, 4, 'Mantener apretado Control para seleccionar múltiples elementos'),
(11140, 2864, 4, 'Mantenga presionada la tecla CTRL para seleccionar varios escuadrones'),
(11141, 2865, 4, 'Inicio'),
(11142, 2866, 4, 'Teléfono de casa'),
(11143, 2867, 4, 'Teléfono de Casa'),
(11144, 2868, 4, 'Sin hogar o similares?'),
(11145, 2869, 4, 'Sin hogar, etc.'),
(11146, 2870, 4, 'Sin hogar, etc'),
(11147, 2872, 4, 'Nombre de Huesped'),
(11148, 2873, 4, 'El nombre del huesped no puede estar vacio'),
(11149, 2875, 4, 'Hora'),
(11150, 2876, 4, 'Horas'),
(11151, 2878, 4, '¿Cómo ocurrió la lesión?'),
(11152, 2879, 4, '¿Cómo ocurrió la lesión?:'),
(11153, 2880, 4, 'Como nos ha conocido'),
(11154, 2881, 4, '¿Cuántos meses de antelación a la consulta para los próximos eventos?'),
(11155, 2882, 4, 'Hist.Enfd.Actual:'),
(11156, 2883, 4, 'Altura'),
(11157, 2884, 4, 'HTML'),
(11158, 2886, 4, 'Vínculo Https segurizado para el soporte LibreEHR LLC Servicio de tránsito de datos de laboratorio.'),
(11159, 2887, 4, 'Húngaro'),
(11160, 2888, 4, 'Hylafax Directorio'),
(11161, 2889, 4, 'Hylafax Commando Enscript'),
(11162, 2890, 4, 'Hylafax Servidor'),
(11163, 2891, 4, 'Hylafax Servidor Hostname'),
(11164, 2892, 4, 'Hiperactivo'),
(11165, 2893, 4, 'Hipertensión'),
(11166, 2894, 4, 'Hipertensión: Medida de presión arterial'),
(11167, 2895, 4, 'Hipertensión: Medida de presión arterial (GCC)'),
(11168, 2896, 4, 'Hipertiroidismo'),
(11169, 2897, 4, 'Hipotiroidismo'),
(11170, 2898, 4, 'Histerectomía'),
(11171, 2899, 4, 'I'),
(11172, 2900, 4, 'Estoy ocupado durante este periodo.'),
(11173, 2901, 4, 'No tengo permiso para leer '),
(11174, 2902, 4, 'ICD'),
(11175, 2903, 4, 'Diagnóstico ICD10'),
(11176, 2904, 4, 'Procedimiento/Servicio ICD10'),
(11177, 2905, 4, 'ICD9'),
(11178, 2906, 4, 'Diagnóstico ICD9'),
(11179, 2907, 4, 'Procedimiento/Servicio ICD9'),
(11180, 2909, 4, 'Nº Identificación'),
(11181, 2910, 4, 'Id'),
(11182, 2911, 4, 'La ID no puede quedar en blanco'),
(11183, 2912, 4, 'Tarjeta ID'),
(11184, 2913, 4, 'IDays'),
(11185, 2914, 4, 'identificado como'),
(11186, 2915, 4, 'Identificador (una palabra)'),
(11187, 2917, 4, 'Tiempo de espera inactivo en segundos'),
(11188, 2919, 4, 'Si todos los datos para todas las columnas están completos para este formulario'),
(11189, 2920, 4, 'Si la justificación de facturación se utiliza introduzca el nombre del código de tipo de diagnóstico.'),
(11190, 2921, 4, 'Si es introducido, seleccione solamente aquel que ha tenido este servicio'),
(11191, 2922, 4, 'Si el nombre, apellido de cualquier parte o apellido, Nombre'),
(11192, 2923, 4, 'Si pagando por'),
(11193, 2924, 4, 'Si la persona ha fallecido, introducir la fecha de la muerte.'),
(11194, 2925, 4, 'Si usa SMTP, nombre del servidor host o la dirección IP.'),
(11195, 2926, 4, 'Si usa SMTP, puerto TCP del servidor (normalmente 25).'),
(11196, 2927, 4, 'Si no tiene trabajo, poner Estudiante'),
(11197, 2929, 4, 'Si cambia el rol de la ePrescripción de receta electrónica, puede afectar al flujo de la ePrescripción. Frente a cualquier dificultad, contacte con su prescriptor de ePrescripción.'),
(11198, 2931, 4, 'Si ha optado por subir remesas electrónicas la ventana de búsqueda muestra las facturas X12 correspondientes del archivo. Puede hacer clic en cualquiera de estos números de factura (como se describe a continuación) si desea hacer las correcciones antes de enviar la información. Para aplicar los cambios, haga clic en el botón de Procesar Archivos ERA en la parte inferior de la página. Esto producirá una nueva ventana con un informe detallado.'),
(11199, 2932, 4, 'Si usted ha incorporado una fecha de pago a la página de la búsqueda, ésta eliminará la fecha de pagos original y los ajustes que se toman del archivo X12. Esto puede serle útil si usted quiere que sus recibos muestren la fecha original en lugar de la fecha admitida por el seguro. Observe que esto también afectará a las fechas de pagos anteriores y a los ajustes que se ponen en demandas secundarias.'),
(11200, 2933, 4, 'Si quiere cambiar tipos de datos, o añadir filas o columnas'),
(11201, 2934, 4, 'Si quiere actualizar la base de datos, coloque el fichero comprimido de base de datos en el siguiente directorio'),
(11202, 2936, 4, 'Desconocido'),
(11203, 2937, 4, 'Enfermedad'),
(11204, 2938, 4, 'IM'),
(11205, 2941, 4, 'Servicio de imágenes'),
(11206, 2942, 4, 'Vacunación'),
(11207, 2943, 4, 'Código Vacunación'),
(11208, 2945, 4, 'Fecha Vacunación'),
(11209, 2947, 4, 'Número de lote Vacunación'),
(11210, 2948, 4, 'Fabricante de Vacuna'),
(11211, 2949, 4, 'Registro Vacunación'),
(11212, 2951, 4, 'Servicio de Vacunación'),
(11213, 2952, 4, 'Título Vacunación'),
(11214, 2953, 4, 'Inmunizaciones'),
(11215, 2954, 4, 'inmunizar'),
(11216, 2955, 4, 'Inmunológicas'),
(11217, 2956, 4, 'Implantes'),
(11218, 2957, 4, 'Importar'),
(11219, 2961, 4, 'Importarr el certificado al buscador'),
(11220, 2962, 4, 'Importar configuración'),
(11221, 2964, 4, 'Paciente de importación'),
(11222, 2965, 4, 'Paciente de importación Demografía'),
(11223, 2966, 4, 'Códigos importantes'),
(11224, 2969, 4, 'Importados de Contabilidad'),
(11225, 2972, 4, 'Mejorado'),
(11226, 2973, 4, 'en'),
(11227, 2974, 4, 'ingreso'),
(11228, 2975, 4, 'dentro de cada ojo'),
(11229, 2976, 4, 'en ojo izquierdo'),
(11230, 2977, 4, 'en los agujeros de la nariz'),
(11231, 2978, 4, 'En la oficina'),
(11232, 2979, 4, 'en ojo derecho'),
(11233, 2980, 4, 'Dentro de la empresa'),
(11234, 2981, 4, 'Inactivo'),
(11235, 2982, 4, 'Días no activo'),
(11236, 2983, 4, 'Entrada'),
(11237, 2986, 4, 'Incluya checksum'),
(11238, 2987, 4, 'Incluya completado'),
(11239, 2988, 4, 'Incluir los usuarios inactivos'),
(11240, 2989, 4, 'Incluir a un no clasificado'),
(11241, 2990, 4, 'Incluir datos no estructurados'),
(11242, 2991, 4, 'Incluir constantes vitales'),
(11243, 2992, 4, '¿Incluir las constantes vitales?'),
(11244, 2993, 4, 'Inclusión'),
(11245, 2994, 4, 'Ingresos'),
(11246, 2996, 4, 'Incompleto'),
(11247, 2997, 4, 'Tratamiento Aborto incompleto'),
(11248, 2998, 4, 'Incontinencia'),
(11249, 2999, 4, 'Incorporar resultados clínicos del test de laboratorio al certificado tecnológico EHR como estructura'),
(11250, 3001, 4, 'aumentado:'),
(11251, 3002, 4, 'Seguro de Indemnización'),
(11252, 3003, 4, 'indeterminado'),
(11253, 3004, 4, 'Indio'),
(11254, 3005, 4, 'Indica anormalidad'),
(11255, 3006, 4, 'Indica si esta incidencia está activa'),
(11256, 3008, 4, 'Indicador de uso especializado'),
(11257, 3009, 4, 'Pacientes indigentes'),
(11258, 3010, 4, 'Informe de Pacientes Indigentes'),
(11259, 3011, 4, 'Indigentes'),
(11260, 3014, 4, 'Aborto Inducido'),
(11261, 3016, 4, 'Inelegible'),
(11262, 3017, 4, 'Infección/abceso'),
(11263, 3018, 4, 'Infecciones'),
(11264, 3019, 4, 'Consejo Infertilidad'),
(11265, 3020, 4, 'Infertilidad'),
(11266, 3021, 4, 'Gripe 1'),
(11267, 3022, 4, 'Gripe 2'),
(11268, 3023, 4, 'Vacunación gripe p/ pacientes may.50 años'),
(11269, 3024, 4, 'Vacunación gripe p/ pacientes may.50 años (GCC)'),
(11270, 3025, 4, 'Vacuna gripe'),
(11271, 3026, 4, 'Información'),
(11272, 3027, 4, 'Información de ensayo 1'),
(11273, 3028, 4, 'Información de ensayo 2'),
(11274, 3029, 4, 'Información de ensayo 3'),
(11275, 3030, 4, 'Información de ensayo 4'),
(11276, 3031, 4, 'Información de ensayo 5'),
(11277, 3032, 4, 'Información de ensayo 6'),
(11278, 3034, 4, 'Inhalaciones'),
(11279, 3035, 4, 'Inhalaciones'),
(11280, 3037, 4, 'Usuario Inicial'),
(11281, 3038, 4, 'Lesión/Rehabilitación'),
(11282, 3039, 4, 'Inyectables'),
(11283, 3040, 4, 'Inyeccion'),
(11284, 3041, 4, 'Parte del cuerpo lesionada'),
(11285, 3042, 4, 'Herido a Fuera'),
(11286, 3043, 4, 'Herido'),
(11287, 3044, 4, 'Mecanismo de lesión'),
(11288, 3045, 4, 'Informe General de lesión'),
(11289, 3046, 4, 'Vigilancia de Lesiones'),
(11290, 3047, 4, 'Tipo de lesión'),
(11291, 3048, 4, 'Relacionado a lesion/enfermedad'),
(11292, 3051, 4, 'Campos de entrada'),
(11293, 3052, 4, 'Tiempo Protrombina'),
(11294, 3053, 4, 'Aseg 1'),
(11295, 3054, 4, 'Aseg 2 o Aseg 3'),
(11296, 3056, 4, 'Ajuste Seg'),
(11297, 3057, 4, 'paquete de seguro'),
(11298, 3058, 4, 'Código Aseguradora'),
(11299, 3061, 4, 'Sobre pago Seg'),
(11300, 3063, 4, 'Reembolso Seg'),
(11301, 3064, 4, 'Resumen Seg'),
(11302, 3065, 4, 'Seg1'),
(11303, 3066, 4, 'Seg2'),
(11304, 3067, 4, 'Seg3'),
(11305, 3069, 4, 'Insertar fallido: '),
(11306, 3070, 4, 'Introduzca los eventos antiguos en tablas'),
(11307, 3072, 4, 'Insomnio'),
(11308, 3074, 4, 'Inspección'),
(11309, 3075, 4, 'Inestabilidad/subluxación'),
(11310, 3076, 4, 'INSTALAR'),
(11311, 3077, 4, 'Instalar'),
(11312, 3079, 4, 'Instalar BD'),
(11313, 3080, 4, 'Versión instalada'),
(11314, 3081, 4, 'instrucciones'),
(11315, 3082, 4, 'Instrucción'),
(11316, 3084, 4, 'instrucciones:'),
(11317, 3085, 4, 'Inventario insuficiente para ID producto'),
(11318, 3086, 4, 'Diabetes insulino dependente'),
(11319, 3087, 4, 'Seguro'),
(11320, 3088, 4, 'Seguro'),
(11321, 3091, 4, 'Saldo del seguro'),
(11322, 3093, 4, 'Sociedad Médica'),
(11323, 3094, 4, 'Cñias.Seguro Médico'),
(11324, 3095, 4, 'Cñia.Seguro Médico'),
(11325, 3096, 4, 'Cñia.Seguro Médico Buscar/Añadir'),
(11326, 3098, 4, 'Data Seguro'),
(11327, 3099, 4, 'Información del Seguro en fichero'),
(11328, 3100, 4, 'Num Seguro'),
(11329, 3101, 4, 'Pago Aseguradora'),
(11330, 3103, 4, 'Proveedor de Seguro'),
(11331, 3106, 4, 'Asegurado'),
(11332, 3107, 4, 'Conclusión Ingesta'),
(11333, 3108, 4, 'Fecha de Ingesta'),
(11334, 3109, 4, 'Declinación intelectual'),
(11335, 3113, 4, 'Error interno - no se seleccionó ningunas páginas!'),
(11336, 3114, 4, 'Error interno - Nº Identificación del paciente no proporcionado!'),
(11337, 3115, 4, '¡Error interno al accede al fichero adjunto!'),
(11338, 3116, 4, '¡Error interno!'),
(11339, 3117, 4, 'Error interno, no identificación de drogas especificada'),
(11340, 3119, 4, 'Error interno: reclamo '),
(11341, 3120, 4, 'Error Interno: Encuentro'),
(11342, 3121, 4, 'Error interno: pid o se encuentran desaparecidos.'),
(11343, 3122, 4, 'Error interno: no parece haber una visita!'),
(11344, 3123, 4, 'Identificador interno (pid)'),
(11345, 3126, 4, 'Derivaciones Internas'),
(11346, 3127, 4, 'Tiempo de coleccion interno'),
(11347, 3128, 4, 'Deber Internacional'),
(11348, 3129, 4, 'Intérprete'),
(11349, 3130, 4, 'Require Intérprete?'),
(11350, 3131, 4, 'Enfermedad Pulmonar Intersticial'),
(11351, 3132, 4, 'Intervalo'),
(11352, 3135, 4, 'Intervención'),
(11353, 3137, 4, 'Intolerancia'),
(11354, 3139, 4, 'Intramuscularmente'),
(11355, 3140, 4, 'Intravenoso'),
(11356, 3141, 4, 'Introducción'),
(11357, 3144, 4, 'Carácter inválido en'),
(11358, 3147, 4, 'Longitud inválida para'),
(11359, 3148, 4, 'Carácter no-numérico inválido en'),
(11360, 3149, 4, 'Inválido o pagador ausente en fuente para código '),
(11361, 3151, 4, 'Códigos de Servicio Inválidos'),
(11362, 3152, 4, 'Designación de la fuente inválida -'),
(11363, 3154, 4, 'InvAmt'),
(11364, 3155, 4, 'Inventario'),
(11365, 3156, 4, 'Actividad de inventario'),
(11366, 3157, 4, 'Inventario y venta, ambos medicamentos y productos no farmacológicos'),
(11367, 3158, 4, 'Inventario y venta medicamentos sólo'),
(11368, 3159, 4, 'El inventario no está disponible para esta orden.'),
(11369, 3160, 4, 'Lista de Inventario'),
(11370, 3161, 4, 'Inventario Transacciones'),
(11371, 3162, 4, 'Factura'),
(11372, 3163, 4, 'factura'),
(11373, 3164, 4, 'Factura saldo'),
(11374, 3165, 4, 'Factura saldo no puede ser enviado. No hay visita creada.'),
(11375, 3166, 4, 'Fecha de Factura'),
(11376, 3167, 4, 'Factura no tiene fecha'),
(11377, 3168, 4, 'Número Factura'),
(11378, 3169, 4, 'Número Referencia Factura'),
(11379, 3170, 4, 'Número referencia lote de facturas, si se usa'),
(11380, 3171, 4, 'Número referencia de lotes de factura'),
(11381, 3172, 4, 'Número referencia factura'),
(11382, 3173, 4, 'Factura:'),
(11383, 3174, 4, 'Fundación Internacional de Planificación Familiar'),
(11384, 3177, 4, 'Datos para SRH IPPF'),
(11385, 3178, 4, 'Informe de las estadísticas de IPPF'),
(11386, 3179, 4, 'Estado Fundación Internacional de Planificación Familiar'),
(11387, 3180, 4, 'IPV 1'),
(11388, 3181, 4, 'IPV 2'),
(11389, 3182, 4, 'IPV 3'),
(11390, 3183, 4, 'IPV 4'),
(11391, 3185, 4, 'Latido de Corazón Irregular'),
(11392, 3186, 4, 'Irritabilidad'),
(11393, 3187, 4, 'Irritación'),
(11394, 3190, 4, 'es la versión más reciente de la siguiente bbdd'),
(11395, 3191, 4, 'es un campo requerido.'),
(11396, 3192, 4, 'es un nodo de raíz y no puede ser suprimido.'),
(11397, 3197, 4, 'no es válido (las fracciones decimales están bien).'),
(11398, 3198, 4, '¿El PHP utiliza el modo a prueba de fallos?'),
(11399, 3200, 4, '¿Se traduce el texto del formulario plantilla?'),
(11400, 3201, 4, '¿Se traduce el texto de listas?'),
(11401, 3202, 4, '¿Está encriptado el fichero?'),
(11402, 3204, 4, '¿Este es un tipo de diagnóstico?'),
(11403, 3207, 4, '¿Es un tipo de procedimiento/servicio?'),
(11404, 3209, 4, '¿Este tipo de código está activo?'),
(11405, 3210, 4, '¿Este tipo de código se usa en reclamos?'),
(11406, 3212, 4, '¿Es un tipo oculto en la hoja de honorarios?'),
(11407, 3213, 4, '¿Se usa en las tablas sql externas? Si es así, elija el formato.'),
(11408, 3214, 4, 'es muy largo'),
(11409, 3216, 4, 'Incidencia'),
(11410, 3217, 4, 'incidencia'),
(11411, 3218, 4, 'Fecha Incidencia'),
(11412, 3219, 4, 'Nº Identificación incidencia'),
(11413, 3220, 4, 'Título de incidencia'),
(11414, 3223, 4, 'Incidencias'),
(11415, 3224, 4, 'Incidencias (Lesiones, Médicas, Alergias)'),
(11416, 3225, 4, 'Incidencias (Lesiones, Médicas, Alergias):'),
(11417, 3226, 4, 'Incidencias y Encuentros'),
(11418, 3227, 4, 'Incidencias y Encuentros de'),
(11419, 3228, 4, 'Incidencias no autorizadas'),
(11420, 3229, 4, 'Sección de Incidencias'),
(11421, 3230, 4, 'Italiano'),
(11422, 3231, 4, 'Artículo'),
(11423, 3232, 4, 'Artículo'),
(11424, 3233, 4, 'temas'),
(11425, 3234, 4, 'La carga de artículos falló'),
(11426, 3235, 4, 'IU/L'),
(11427, 3236, 4, 'IUD'),
(11428, 3237, 4, 'IV'),
(11429, 3238, 4, 'Ener'),
(11430, 3239, 4, 'Enero'),
(11431, 3240, 4, 'Japonés'),
(11432, 3241, 4, 'Ictericia'),
(11433, 3243, 4, 'Descripción del trabajo'),
(11434, 3244, 4, 'Identificación del trabajo'),
(11435, 3245, 4, 'Dislocaciones de articulaciones'),
(11436, 3246, 4, 'Dolor en las Articulaciones'),
(11437, 3247, 4, 'Esguinces de articulaciones'),
(11438, 3248, 4, 'Jul'),
(11439, 3249, 4, 'Julio'),
(11440, 3250, 4, 'Jun'),
(11441, 3251, 4, 'Junio'),
(11442, 3252, 4, 'Justo debajo, la información de comprobación es un área azul donde pones los parámetros de búsqueda. Puedes buscar por apellido del paciente, número de informe, número de cita o fecha de servicio, o cualquier combinación de éstas. Tu también puedes seleccionar si quieres ver todas las facturas, facturas abiertas o sólo las que debe el paciente. Pincha el botón de búsqueda para realizarla.'),
(11443, 3253, 4, 'Solo mío'),
(11444, 3255, 4, 'Justificar'),
(11445, 3256, 4, 'Justificar / Guardar'),
(11446, 3258, 4, 'k, aquí está el resto'),
(11447, 3264, 4, 'Clave'),
(11448, 3265, 4, 'Palabras Claves'),
(11449, 3266, 4, 'kg');
INSERT INTO `lang_definitions` VALUES
(11450, 3267, 4, 'kg/m^2'),
(11451, 3269, 4, 'Cáncer de Riñon'),
(11452, 3270, 4, 'Fallo Renal'),
(11453, 3271, 4, 'Infecciones de Riñón'),
(11454, 3272, 4, 'Piedra en el Riñón'),
(11455, 3273, 4, 'Transplante de Riñon'),
(11456, 3277, 4, 'Rodilla'),
(11457, 3278, 4, 'Problemas de la rodilla'),
(11458, 3279, 4, 'Reemplazo de Rodilla'),
(11459, 3282, 4, 'Coreano'),
(11460, 3286, 4, 'Laboratorio'),
(11461, 3288, 4, 'Sitio Web del Laboratorio de intercambio'),
(11462, 3289, 4, 'Nº Identificación Laboratorio de intercambio'),
(11463, 3290, 4, 'Nº Identificación ficha Laboratorio de intercambio'),
(11464, 3294, 4, 'Consulta de estado de Laboratorio'),
(11465, 3295, 4, 'Informe del Laboratorio'),
(11466, 3296, 4, 'Resultado Laboratorio'),
(11467, 3297, 4, 'Resultados Laboratorio'),
(11468, 3299, 4, 'Informe Resultados Laboratorio'),
(11469, 3300, 4, 'Servicio de laboratorio'),
(11470, 3301, 4, 'Resultados del test de Laboratorio'),
(11471, 3303, 4, 'Etiqueta'),
(11472, 3304, 4, 'Etiqueta no puede estar en blanco'),
(11473, 3305, 4, 'Col etiqueta'),
(11474, 3306, 4, 'Etiqueta para este tipo'),
(11475, 3307, 4, 'EtiquetasColumn debe ser un numero entre 1 y 999'),
(11476, 3308, 4, 'Etiquetas'),
(11477, 3311, 4, 'Laboratorio'),
(11478, 3312, 4, 'Laceración/Cond. Piel'),
(11479, 3313, 4, 'Laceración/abrasión'),
(11480, 3316, 4, 'Idioma'),
(11481, 3317, 4, 'Codio Idioma'),
(11482, 3318, 4, 'Definición de lenguaje agregada'),
(11483, 3319, 4, 'Herramienta de interfaz de idioma'),
(11484, 3320, 4, 'Lista de lenguajes (escribir, addonly opcional)'),
(11485, 3321, 4, 'Nombre Idioma'),
(11486, 3322, 4, 'Idioma:'),
(11487, 3324, 4, 'Laosiano'),
(11488, 3325, 4, 'Último'),
(11489, 3326, 4, 'Última Actividad Fecha'),
(11490, 3328, 4, 'Última Fecha de Cuenta'),
(11491, 3330, 4, 'Último año calendario'),
(11492, 3333, 4, 'Última visita'),
(11493, 3340, 4, 'Último nivel facturado'),
(11494, 3343, 4, 'Último Mes'),
(11495, 3344, 4, 'Apellido(s)'),
(11496, 3345, 4, 'Apellido(s)'),
(11497, 3346, 4, 'Apellido(s):'),
(11498, 3350, 4, 'Ultima revision'),
(11499, 3352, 4, 'Última guardados'),
(11500, 3356, 4, 'Última actualización por'),
(11501, 3357, 4, 'Ultima verificación el'),
(11502, 3358, 4, 'Última Visita'),
(11503, 3360, 4, 'Recurrencia tardía (2-12 Mes)'),
(11504, 3361, 4, 'Maléolo lateral'),
(11505, 3362, 4, 'Maléolo lateral:'),
(11506, 3363, 4, 'Lateralidad'),
(11507, 3364, 4, 'Lateralidad de este procedimiento si se aplica'),
(11508, 3365, 4, 'desplazados lateralmente PMI:'),
(11509, 3373, 4, 'Basado en un diseño'),
(11510, 3374, 4, 'Editor de diseño'),
(11511, 3375, 4, 'Grupos de diseño'),
(11512, 3376, 4, 'Estilo de diseño'),
(11513, 3378, 4, 'Formularios de visita con pre-diseño'),
(11514, 3379, 4, 'Disposición'),
(11515, 3380, 4, 'libra'),
(11516, 3381, 4, 'libra'),
(11517, 3382, 4, 'Colesterol LDL'),
(11518, 3383, 4, 'dejar en blanco si sigue activo'),
(11519, 3384, 4, 'Dejar en blanco para mantener el nombre de fichero original'),
(11520, 3385, 4, 'Deje en blanco para no cambiar la contraseña'),
(11521, 3386, 4, 'Dejar mensaje Con'),
(11522, 3387, 4, 'Salir del Formulario'),
(11523, 3388, 4, 'Dejando la contraseña en blanco no se encriptará el documento'),
(11524, 3390, 4, 'Izquierda'),
(11525, 3391, 4, 'Oído izquierdo'),
(11526, 3392, 4, 'oreja izquierda'),
(11527, 3394, 4, 'Izquierda:'),
(11528, 3395, 4, 'Izquierda: '),
(11529, 3396, 4, 'Dolor de Pierna/Calambres'),
(11530, 3397, 4, 'Legal'),
(11531, 3399, 4, 'Tamaño papel Legal'),
(11532, 3400, 4, 'Leyenda:'),
(11533, 3401, 4, 'Longitud'),
(11534, 3402, 4, 'Longitud del modificador, 0 si no hay'),
(11535, 3403, 4, 'Menor que'),
(11536, 3404, 4, 'Menor que o Igual a'),
(11537, 3405, 4, 'Menos la información privada (escribir, addonly opcional)'),
(11538, 3406, 4, 'Carta'),
(11539, 3407, 4, 'Carta'),
(11540, 3408, 4, 'Tamaño papel Letter'),
(11541, 3409, 4, 'Papelería membretada que el médico firma'),
(11542, 3410, 4, 'Papelería membretada que el paciente firma'),
(11543, 3411, 4, 'Nivel de urgencia'),
(11544, 3412, 4, 'Responsabilidad'),
(11545, 3413, 4, 'Responsabilidad Médica'),
(11546, 3414, 4, 'Licencia/Nº Id.'),
(11547, 3419, 4, 'Apellido del médico'),
(11548, 3420, 4, 'NºColegiado médico'),
(11549, 3421, 4, 'NºColegiado médico'),
(11550, 3423, 4, 'Estilo de Vida'),
(11551, 3424, 4, 'Estado del estilo de vida'),
(11552, 3425, 4, 'Rasgón o esguince del ligamento'),
(11553, 3428, 4, 'Límite de Eventos'),
(11554, 3429, 4, 'Límites'),
(11555, 3431, 4, 'Vínculo'),
(11556, 3432, 4, 'Vínculo al paciente'),
(11557, 3433, 4, 'Vinculado'),
(11558, 3436, 4, 'Vinculado a un documento'),
(11559, 3438, 4, 'Lista'),
(11560, 3439, 4, 'Cuadr de lista'),
(11561, 3440, 4, 'caja de lista'),
(11562, 3441, 4, 'agrega cuadro de lista'),
(11563, 3442, 4, 'Lista de cuadro con adición'),
(11564, 3443, 4, 'Editor de Lista'),
(11565, 3444, 4, 'Lista de visitas'),
(11566, 3445, 4, 'Lista de grupos'),
(11567, 3446, 4, 'Lista Cñías.Seguro Méd.'),
(11568, 3448, 4, 'Lista de temas no puede comenzar con un número'),
(11569, 3449, 4, 'Items listados contienen caracteres ilegales'),
(11570, 3451, 4, 'Lista Listas'),
(11571, 3452, 4, 'Lista de Nombres'),
(11572, 3453, 4, 'Lista de los nombres no puede empezar con números.'),
(11573, 3454, 4, 'Lista de Recetas'),
(11574, 3455, 4, 'Lista Tipo de datos usada para País.'),
(11575, 3456, 4, 'Lista Tipo de datos usada para Estado.'),
(11576, 3457, 4, 'Puerto de escucha de la RFC 5425 TLS en el servidor syslog.'),
(11577, 3458, 4, 'Listas'),
(11578, 3460, 4, 'Deseos Personales de cuidado'),
(11579, 3461, 4, 'LLL:'),
(11580, 3462, 4, 'UFM (ult.fecha menstr.)'),
(11581, 3464, 4, 'Cargar definiciones'),
(11582, 3470, 4, 'Cargando'),
(11583, 3471, 4, 'Cargando ficheros en la base de datos. Esto puede tardar algún tiempo...'),
(11584, 3472, 4, 'LOC'),
(11585, 3473, 4, 'Local'),
(11586, 3476, 4, 'Lugar'),
(11587, 3477, 4, 'Localidad'),
(11588, 3478, 4, 'Localización'),
(11589, 3479, 4, 'Ubicación de la máquina libreehr puede contener datos sensible, por eso se recomienda borrar manualmente los ficheros después de su uso'),
(11590, 3480, 4, 'Localizacion de este lote'),
(11591, 3481, 4, 'Lugar no especificado'),
(11592, 3482, 4, 'Directorio dónde Hylafax archiva los faxes'),
(11593, 3483, 4, 'Localización dónde se archivan los escaneados'),
(11594, 3484, 4, 'Localización:'),
(11595, 3485, 4, 'Bloquear'),
(11596, 3492, 4, 'Iniciar sesión'),
(11597, 3493, 4, 'Identificación'),
(11598, 3494, 4, 'Finalizar sesión'),
(11599, 3495, 4, 'Iniciar sesión'),
(11600, 3496, 4, 'Abierto una sesión como'),
(11601, 3497, 4, 'Abierto una sesión como: '),
(11602, 3498, 4, 'Salir de sesión.'),
(11603, 3499, 4, 'Registros'),
(11604, 3500, 4, 'Iniciar sesión'),
(11605, 3501, 4, 'conexión'),
(11606, 3505, 4, 'Salir'),
(11607, 3506, 4, 'Salir'),
(11608, 3507, 4, 'Registros'),
(11609, 3508, 4, 'Visor de los registros'),
(11610, 3510, 4, 'Buscar'),
(11611, 3511, 4, 'Lote'),
(11612, 3512, 4, 'Falta Identificación del lote !'),
(11613, 3513, 4, 'Número de Lote'),
(11614, 3514, 4, 'Bajo'),
(11615, 3516, 4, 'Pierna inferior'),
(11616, 3519, 4, 'Columna lumbar'),
(11617, 3520, 4, 'ALMUERZO'),
(11618, 3521, 4, 'almuerzo'),
(11619, 3522, 4, 'cáncer de pulmón'),
(11620, 3523, 4, 'Cirugía del cáncer de pulmón'),
(11621, 3524, 4, 'PULMONES:'),
(11622, 3525, 4, 'pulmones:'),
(11623, 3526, 4, 'Lupus'),
(11624, 3528, 4, 'M'),
(11625, 3529, 4, 'Categoría de MA'),
(11626, 3530, 4, 'MA Cliente acepta aborto'),
(11627, 3531, 4, 'MA estadísticas'),
(11628, 3533, 4, 'Correo enviado'),
(11629, 3534, 4, 'Principal'),
(11630, 3535, 4, 'Dirección principal'),
(11631, 3536, 4, 'Pantalla principal del panel superior'),
(11632, 3537, 4, 'Mantener activa la lista de medicación de alergia.'),
(11633, 3538, 4, 'Mantener activa una lista de medicación.'),
(11634, 3539, 4, 'Mantenga actualizada lista de problemas actuales y diagnósticos activos'),
(11635, 3540, 4, 'Hacer modificaciones a las actuales categorías.'),
(11636, 3541, 4, 'Dar nueva cita para'),
(11637, 3542, 4, 'Cerciorarse -'),
(11638, 3543, 4, 'Hacer un batch de ficheros de texto para adjuntar a la Cámara de compensación y que se marcará como facturado'),
(11639, 3545, 4, 'Malestar:'),
(11640, 3548, 4, 'Masculino'),
(11641, 3549, 4, 'Condones Masculinos'),
(11642, 3550, 4, 'Varón VSC'),
(11643, 3552, 4, 'Mamografía'),
(11644, 3553, 4, 'Manejar'),
(11645, 3554, 4, 'Manejar'),
(11646, 3555, 4, 'Manejar módulos'),
(11647, 3556, 4, 'Gestionar traducciones'),
(11648, 3557, 4, 'Gerencia'),
(11649, 3558, 4, 'Campos obligatorios y específicos'),
(11650, 3559, 4, 'Campos obligatorios o específicos sólo, cheques duplicados, no de búsqueda'),
(11651, 3560, 4, 'Campos obligatorios o específicos sólo, búsqueda y comprobación de duplicados'),
(11652, 3561, 4, 'Manual'),
(11653, 3562, 4, 'Manual de envío'),
(11654, 3563, 4, 'Fabricante'),
(11655, 3565, 4, 'Mar'),
(11656, 3568, 4, 'Marzo'),
(11657, 3569, 4, 'Estado Civil'),
(11658, 3571, 4, 'Marcar como facturado pero saltar de facturación'),
(11659, 3572, 4, 'Marcar como Resueltos'),
(11660, 3573, 4, 'Marcar como no facturados'),
(11661, 3575, 4, 'Marcado como despejado'),
(11662, 3576, 4, 'Casado'),
(11663, 3578, 4, 'Formato (Máscara)'),
(11664, 3579, 4, 'Formato para Números de Factura'),
(11665, 3580, 4, 'Formato para ID de Pacientes'),
(11666, 3581, 4, 'Formato para ID de Productos'),
(11667, 3582, 4, 'Concuerda'),
(11668, 3583, 4, 'Emparejar caso'),
(11669, 3584, 4, 'Pareja encontrada'),
(11670, 3590, 4, 'Matriz'),
(11671, 3591, 4, 'Max'),
(11672, 3594, 4, 'La derecha maxilar:'),
(11673, 3595, 4, 'Edad Máxima'),
(11674, 3596, 4, 'Número máximo de caracteres'),
(11675, 3597, 4, 'Tiempo máximo inactivo antes de cerrar sesión en segundos. Por defecto es 7200 (2 horas).'),
(11676, 3600, 4, 'Inventario máximo razonable, 0 si no es aplicable'),
(11677, 3601, 4, 'Tamaño máximo'),
(11678, 3602, 4, 'Tamaño máximo (poniendo 0 permite cualquier tamaño)'),
(11679, 3603, 4, 'Mayo'),
(11680, 3604, 4, 'MC'),
(11681, 3605, 4, 'mcg (microgramo)'),
(11682, 3607, 4, 'Significa que ninguna de las tres últimas contraseñas son permitidas para cambiar la contraseña.'),
(11683, 3609, 4, 'Medida del Código de Grupo'),
(11684, 3611, 4, 'Medición'),
(11685, 3612, 4, 'Maléolo medial:'),
(11686, 3613, 4, 'Seguro de enfermedad'),
(11687, 3614, 4, 'Médico'),
(11688, 3615, 4, 'Aborto Médico'),
(11689, 3616, 4, 'Administración Médica'),
(11690, 3617, 4, 'Historia Médica'),
(11691, 3618, 4, 'Incidencia Médica'),
(11692, 3619, 4, 'Incidencia Médica'),
(11693, 3620, 4, 'Problema médico'),
(11694, 3623, 4, 'Problemas médicos'),
(11695, 3624, 4, 'Registo Médico'),
(11696, 3625, 4, 'Informe médico #'),
(11697, 3626, 4, 'Registros Médicos'),
(11698, 3627, 4, 'Registros Médicos enviados'),
(11699, 3629, 4, 'Resumen Médico entregado'),
(11700, 3630, 4, 'Sistema Médico'),
(11701, 3631, 4, 'Tipo de Médico'),
(11702, 3632, 4, 'Médico / Historia (escribir, añadir sólo opcional)'),
(11703, 3633, 4, 'Parte B de Seguro médico'),
(11704, 3634, 4, 'Seguro médico de referencia restablecido'),
(11705, 3635, 4, 'Medicación'),
(11706, 3636, 4, 'Lista Medicación Alergias'),
(11707, 3638, 4, 'Lista Medicación'),
(11708, 3639, 4, '¿Reconciliación Medicación realizada?'),
(11709, 3640, 4, 'Medicamentos'),
(11710, 3641, 4, 'Medicamentos:'),
(11711, 3642, 4, 'Unidades de Medicina'),
(11712, 3643, 4, 'Mediano'),
(11713, 3645, 4, 'Miembro de la Asociación de Estadística Informe'),
(11714, 3646, 4, 'Problemas de Memoria'),
(11715, 3647, 4, 'Hombres'),
(11716, 3648, 4, 'Hombres y Mujeres'),
(11717, 3649, 4, 'Hombres Solamente'),
(11718, 3650, 4, 'Menarquía'),
(11719, 3651, 4, 'Menopausia'),
(11720, 3652, 4, 'Flujo Menstrual'),
(11721, 3653, 4, 'Menstrual Frequency'),
(11722, 3654, 4, 'Enfermedad Mental'),
(11723, 3659, 4, 'Unir pacientes'),
(11724, 3661, 4, 'Mensaje'),
(11725, 3662, 4, 'Centro de Recordatorios y Mensajes'),
(11726, 3665, 4, 'Mensaje Enviado'),
(11727, 3666, 4, 'Estado mensaje'),
(11728, 3670, 4, 'MENSAJE:'),
(11729, 3671, 4, 'Avisos'),
(11730, 3672, 4, 'Mensajes enviados hoy'),
(11731, 3673, 4, 'Método'),
(11732, 3674, 4, 'Método y especificaciones de Producto'),
(11733, 3675, 4, 'Método para el envío de email saliente'),
(11734, 3676, 4, 'Método de destrucción'),
(11735, 3677, 4, 'Mejicano/MexAmer/Chicano'),
(11736, 3679, 4, 'mg'),
(11737, 3680, 4, 'mg/1cc'),
(11738, 3681, 4, 'mg/2cc'),
(11739, 3682, 4, 'mg/3cc'),
(11740, 3683, 4, 'mg/4cc'),
(11741, 3684, 4, 'mg/5cc'),
(11742, 3685, 4, 'MG/DL'),
(11743, 3686, 4, 'Segundo'),
(11744, 3687, 4, 'Segundo Nombre'),
(11745, 3688, 4, 'Segundo nombre'),
(11746, 3690, 4, 'Prescriptor DEA nivel medio'),
(11747, 3691, 4, 'Nombre Prescriptor nivel medio'),
(11748, 3692, 4, 'Apellido Prescriptor nivel medio'),
(11749, 3693, 4, 'Prefijo Prescriptor nivel medio'),
(11750, 3694, 4, 'Nº médico nivel medio'),
(11751, 3695, 4, 'Semblante'),
(11752, 3696, 4, 'Migrante o trabajador de temporada?'),
(11753, 3697, 4, 'Migrantes / temporada'),
(11754, 3698, 4, 'Mil/CU.MM'),
(11755, 3702, 4, 'Mime Tipo'),
(11756, 3703, 4, 'min'),
(11757, 3704, 4, 'Mínimo'),
(11758, 3705, 4, 'Edad Mínima'),
(11759, 3706, 4, 'Distensión menor de articulación /-Sinovitis'),
(11760, 3708, 4, 'Minuto'),
(11761, 3709, 4, 'minutos'),
(11762, 3710, 4, 'Minutos'),
(11763, 3712, 4, 'Varios'),
(11764, 3713, 4, 'Diversas opciones de facturación'),
(11765, 3714, 4, 'Diversas opciones de facturación para HCFA-1500'),
(11766, 3715, 4, 'Diversas opciones de facturación HCFA'),
(11767, 3716, 4, 'Misceláneos'),
(11768, 3717, 4, 'Faltado'),
(11769, 3718, 4, 'No existe'),
(11770, 3719, 4, 'Falta campo requerido'),
(11771, 3720, 4, 'Falta cuota'),
(11772, 3721, 4, 'Solo modulos faltantes'),
(11773, 3722, 4, 'No existe o Inválido'),
(11774, 3723, 4, 'Falta el PID.'),
(11775, 3724, 4, 'Fecha de reporte falta'),
(11776, 3725, 4, 'Raya vertical que falta después del pagador en la fuente para el código '),
(11777, 3726, 4, 'Mixto'),
(11778, 3727, 4, 'ml'),
(11779, 3728, 4, 'MM/DD/AAAA'),
(11780, 3729, 4, 'mm/hg'),
(11781, 3730, 4, 'mmHg'),
(11782, 3731, 4, 'MMR 1'),
(11783, 3732, 4, 'MMR 2'),
(11784, 3733, 4, 'Móvil'),
(11785, 3734, 4, 'Teléfono Móvil'),
(11786, 3735, 4, 'Mod'),
(11787, 3741, 4, 'Modificador'),
(11788, 3742, 4, 'Modificadores'),
(11789, 3743, 4, 'Modificar'),
(11790, 3745, 4, 'Modificar Pagos'),
(11791, 3746, 4, 'Longitud Modelo'),
(11792, 3747, 4, 'Mòdulo'),
(11793, 3748, 4, 'Directorio de mòdulos no hallado'),
(11794, 3749, 4, 'Instalador de módulos'),
(11795, 3750, 4, 'Nombre de mòdulo'),
(11796, 3751, 4, 'Nombre de mòdulo ya existe'),
(11797, 3752, 4, 'Mòdulos'),
(11798, 3753, 4, 'Lun'),
(11799, 3754, 4, 'Lun a Vier'),
(11800, 3755, 4, 'Lunes, miércoles y viernes'),
(11801, 3756, 4, 'Lunes'),
(11802, 3758, 4, 'Mes'),
(11803, 3759, 4, 'mes'),
(11804, 3760, 4, 'Ver Mes'),
(11805, 3761, 4, 'Mes(es)'),
(11806, 3762, 4, 'Ingreso Mensual'),
(11807, 3763, 4, 'Meses'),
(11808, 3765, 4, 'Más de 100 registros encontrados. Por favor, reducir su criterio de búsqueda.'),
(11809, 3766, 4, 'Más de 50 resultados, por favor, hacer su búsqueda más específica.'),
(11810, 3767, 4, 'Puede hacer click en la mayoría de las cabeceras de columna para cambiar el orden'),
(11811, 3768, 4, 'Más reciente desde'),
(11812, 3769, 4, 'Datos de lab. más recientes'),
(11813, 3770, 4, 'Constantes vitales mas recientes desde:'),
(11814, 3771, 4, 'Madre'),
(11815, 3772, 4, 'Nombre de la Madre'),
(11816, 3774, 4, 'Boca'),
(11817, 3775, 4, 'Movimiento'),
(11818, 3776, 4, 'Mueva el documento a la categoría:'),
(11819, 3777, 4, 'Mueve Abajo'),
(11820, 3779, 4, 'Mover al paciente'),
(11821, 3780, 4, 'Mover hacia...'),
(11822, 3781, 4, 'Mover Arriba'),
(11823, 3783, 4, 'Sr.'),
(11824, 3785, 4, 'Sra.'),
(11825, 3786, 4, 'Srta.'),
(11826, 3794, 4, 'Código MSP'),
(11827, 3795, 4, 'Codigos de remito MSP'),
(11828, 3796, 4, 'Herramienta multi idioma'),
(11829, 3797, 4, 'Múltiples áreas'),
(11830, 3799, 4, 'Lotes Multiples'),
(11831, 3800, 4, 'Múltiples modificadores pueden estar separados por dos puntos o espacios, máximo 4 (M1:M2:M3:M4)'),
(11832, 3802, 4, 'Multirracial'),
(11833, 3803, 4, 'Murmullos:'),
(11834, 3804, 4, 'Dolor de Musc'),
(11835, 3805, 4, 'Dolor muscular'),
(11836, 3806, 4, 'Rojez de Musc'),
(11837, 3807, 4, 'Tiesura de Musc'),
(11838, 3808, 4, 'Inflamación muscular'),
(11839, 3809, 4, 'Musc Caliente'),
(11840, 3810, 4, 'Músculo'),
(11841, 3811, 4, 'Lesiones musculares'),
(11842, 3812, 4, 'Musculoesquelético'),
(11843, 3813, 4, 'Debe estar vacío si la autenticación de SMTP no se usa.'),
(11844, 3814, 4, 'Definido mutuamente'),
(11845, 3815, 4, 'MVA'),
(11846, 3818, 4, 'Yo mismo'),
(11847, 3821, 4, 'No Aplicable'),
(11848, 3822, 4, 'no interesa'),
(11849, 3823, 4, 'e'),
(11850, 3825, 4, 'Nombre (Selecciona por mas)'),
(11851, 3826, 4, 'Nombre 1'),
(11852, 3827, 4, 'Nombre 2'),
(11853, 3828, 4, 'Nombre y título del administrador de la inmunización'),
(11854, 3831, 4, 'Nombre de Eventos'),
(11855, 3832, 4, 'Nombre de la compañía de seguros'),
(11856, 3833, 4, 'Nombre del Proveedor'),
(11857, 3834, 4, 'Nombre del remitente para los recordatorios de paciente.'),
(11858, 3835, 4, 'Traducción del nombre'),
(11859, 3836, 4, 'Nombre/Valor'),
(11860, 3837, 4, 'Nombre:'),
(11861, 3838, 4, 'NARINAS:'),
(11862, 3839, 4, 'NARINAS: Normal Derecho'),
(11863, 3840, 4, 'Mucosa nasal de color rosa, septo de línea media'),
(11864, 3841, 4, 'NationNotes'),
(11865, 3842, 4, 'Configurar NationNotes'),
(11866, 3843, 4, 'Botones de reemplazo para Notas Nation'),
(11867, 3844, 4, 'Nacionalidad'),
(11868, 3845, 4, 'NationNotes'),
(11869, 3846, 4, 'Carga de datos nativos'),
(11870, 3847, 4, 'Hawaino nativo u otras Islas del Pacífico'),
(11871, 3852, 4, 'Náuseas'),
(11872, 3854, 4, 'Navegación'),
(11873, 3855, 4, 'Área de navegación incluye formularios de visita'),
(11874, 3856, 4, 'El área de navegación usa la altura completa del marco'),
(11875, 3857, 4, 'Formulario Área Navegación de visita'),
(11876, 3858, 4, 'Ancho del área de navegación'),
(11877, 3859, 4, 'El menú de navegación consiste en pares de botones radiales'),
(11878, 3860, 4, 'El menú de navegación es una vista de árbol'),
(11879, 3861, 4, 'La navegación usa un menú deslizante'),
(11880, 3862, 4, 'NDC'),
(11881, 3863, 4, 'Datos NCD'),
(11882, 3864, 4, 'Número del NDC'),
(11883, 3866, 4, 'Cuello'),
(11884, 3867, 4, 'Problemas de Cuello'),
(11885, 3868, 4, 'Cuello flexible'),
(11886, 3869, 4, 'Necesidad de introducir una descripción'),
(11887, 3870, 4, 'Necesidad de introducir un Valor de Retorno'),
(11888, 3871, 4, 'Necesidad de entrar en el identificador'),
(11889, 3872, 4, 'Necesita introducir título'),
(11890, 3873, 4, 'Requiere autorización'),
(11891, 3874, 4, 'Requiere justificación'),
(11892, 3875, 4, 'Necesita la facturación secundaria'),
(11893, 3876, 4, 'Negativo'),
(11894, 3877, 4, 'Negativos'),
(11895, 3880, 4, 'Lesión del nervio'),
(11896, 3881, 4, 'Condición neural / daño en los nervios'),
(11897, 3882, 4, 'Entumecimiento Neuro'),
(11898, 3883, 4, 'Debilidad Neura'),
(11899, 3884, 4, 'Neurológico'),
(11900, 3885, 4, 'Nunca'),
(11901, 3886, 4, 'No Bebe Alcohol'),
(11902, 3887, 4, 'No Fumador'),
(11903, 3888, 4, 'Nuevo'),
(11904, 3889, 4, 'Nuevo =>'),
(11905, 3890, 4, 'Nuevos aceptadores'),
(11906, 3892, 4, 'Nueva alergia'),
(11907, 3894, 4, 'Cita Nueva'),
(11908, 3895, 4, 'Categoria Nueva'),
(11909, 3896, 4, 'Nueva Categoría'),
(11910, 3897, 4, 'Cliente Nuevo'),
(11911, 3898, 4, 'Nueva consulta'),
(11912, 3899, 4, 'Nuevo cultivo'),
(11913, 3900, 4, 'Nueva definición añadido'),
(11914, 3901, 4, 'Nuevo documento'),
(11915, 3902, 4, 'Nuevos documentos'),
(11916, 3904, 4, 'Nuevo Encuentro'),
(11917, 3905, 4, 'Nuevo Encuentro creado con id'),
(11918, 3906, 4, 'Formulario Nuevo Encuentro'),
(11919, 3907, 4, 'Nuevos encuentros no autorizados'),
(11920, 3908, 4, 'Nuevos Enctr'),
(11921, 3909, 4, 'Información de nuevo Centro'),
(11922, 3912, 4, 'Grupo Nuevo'),
(11923, 3913, 4, 'Información de nuevo grupo'),
(11924, 3914, 4, 'Nueva lesión/estado'),
(11925, 3916, 4, 'Nuevo límite de Eventos'),
(11926, 3917, 4, 'Nueva Lista'),
(11927, 3918, 4, 'Nuevos pedidos'),
(11928, 3919, 4, 'Nuevo Párrafo'),
(11929, 3920, 4, 'Nueva Contraseña'),
(11930, 3921, 4, 'Nuevo Paciente'),
(11931, 3922, 4, 'NUEVO PACIENTE'),
(11932, 3923, 4, 'Nuevo Encuentro con Paciente'),
(11933, 3924, 4, 'Formulario de Nuevo Paciente'),
(11934, 3925, 4, 'Nº Identificación de Nuevo Paciente'),
(11935, 3926, 4, 'Nuevo Pago'),
(11936, 3927, 4, 'Nuevo ingreso a portal'),
(11937, 3928, 4, 'Nuevos Pt'),
(11938, 3929, 4, 'Nuevos resultados del laboratorio de intercambio'),
(11939, 3930, 4, 'Nueva Busqueda'),
(11940, 3931, 4, 'Nuevas sumisiones'),
(11941, 3932, 4, 'Nuevo Usuario'),
(11942, 3934, 4, 'Nuevo Encuentro'),
(11943, 3935, 4, 'Nuevo/búsqueda'),
(11944, 3936, 4, 'Estado de la cuenta NewCrop'),
(11945, 3937, 4, '*Administrador de NewCrop'),
(11946, 3938, 4, 'Llamada fallida a NewCrop'),
(11947, 3939, 4, 'Doctor NewCrop'),
(11948, 3944, 4, 'Nombre Receta electrónica NewCrop'),
(11949, 3945, 4, 'Nombre socio Receta electrónica NewCrop'),
(11950, 3946, 4, 'Contraseña Receta electrónica NewCrop'),
(11951, 3947, 4, 'Rol Receta electrónica NewCrop'),
(11952, 3948, 4, 'Rol Receta electrónica NewCrop'),
(11953, 3949, 4, 'Sitio Web Receta electrónica NewCrop'),
(11954, 3954, 4, 'Sitio Web servicio Receta electrónica NewCrop'),
(11955, 3955, 4, 'Gerente NewCrop'),
(11956, 3956, 4, 'NewCrop MedEntry'),
(11957, 3957, 4, 'Médico nivel medio NewCrop'),
(11958, 3958, 4, 'Enfermera NewCrop'),
(11959, 3959, 4, 'Supervisor médico NewCrop'),
(11960, 3960, 4, 'Más nuevo'),
(11961, 3961, 4, 'Periódico'),
(11962, 3962, 4, 'Próximo'),
(11963, 3964, 4, 'Próximo Dia'),
(11964, 3965, 4, 'Próximo mes'),
(11965, 3966, 4, 'Proxima semana'),
(11966, 3968, 4, 'Próxima semana'),
(11967, 3969, 4, 'Año siguiente (Presione para el menu'),
(11968, 3971, 4, 'Apodo'),
(11969, 3973, 4, 'Sudores nocturnos'),
(11970, 3974, 4, 'Órganos genitales de la extensión de NL, mucosa de vag, cuello uterino'),
(11971, 3975, 4, 'No'),
(11972, 3976, 4, 'NO'),
(11973, 3977, 4, 'No tienen acceso'),
(11974, 3978, 4, 'Recordatorios de paciente no activos.'),
(11975, 3979, 4, 'No adenopatías (2 áreas requeridas)'),
(11976, 3980, 4, 'Ninguna razón de tipo de ajuste encontrada para'),
(11977, 3981, 4, 'No dolor/masa en anexos'),
(11978, 3983, 4, 'No hay citas'),
(11979, 3985, 4, 'Sistema de facturación no se encuentra activa'),
(11980, 3986, 4, 'No hay facturas encontradas para incluir en Exportación OFX'),
(11981, 3987, 4, 'Ningunas cuentas se encuentran para incluir en la exportación de OFX'),
(11982, 3989, 4, 'No se ha especificado el código!'),
(11983, 3992, 4, 'Ninguna diagnosis'),
(11984, 3993, 4, 'Ningunos documentos encontrados'),
(11985, 3994, 4, 'No pueden crearse visitas'),
(11986, 3995, 4, 'Sin fecha de finalización'),
(11987, 3996, 4, 'No se encuentran entradas, utilice el formulario que aparece a continuación para agregar una entrada.'),
(11988, 3997, 4, 'errores no encontrados'),
(11989, 3998, 4, 'No hay Eventos'),
(11990, 4000, 4, 'No hay ficheros preparados para la instalación'),
(11991, 4001, 4, 'Ningún grupo fue seleccionado'),
(11992, 4002, 4, 'Ninguna hernia'),
(11993, 4005, 4, 'No lesion/enfermedad'),
(11994, 4006, 4, 'No se encontro ninguna Sociedad Médica'),
(11995, 4007, 4, 'No hay incidencias'),
(11996, 4009, 4, 'No hay artículos bajo la categoría seleccionada'),
(11997, 4010, 4, '¡Ningun artículo fue seleccionado!'),
(11998, 4024, 4, 'Sin datos de lab. documentados'),
(11999, 4025, 4, 'No hay fichero de registro para la fecha seleccionada'),
(12000, 4027, 4, 'Sin masas ni sensibilidad'),
(12001, 4028, 4, 'Ningún registro de paciente encontrado para el código de Re-identificación'),
(12002, 4029, 4, 'No hay coincidencias. Intentar buscar de nuevo.'),
(12003, 4030, 4, 'No se han encontrado coincidencias.'),
(12004, 4031, 4, 'No se encontró. ¿Crear el nuevo paciente ahora?'),
(12005, 4032, 4, 'No hay registros coincidentes'),
(12006, 4033, 4, 'No hay nuevos resultados encontrados'),
(12007, 4034, 4, 'Ningunas notas'),
(12008, 4035, 4, 'No hay organomegalia'),
(12009, 4036, 4, 'No se encontraron huecos para este periodo.'),
(12010, 4037, 4, 'No figuran otros números de teléfono'),
(12011, 4039, 4, 'Socios no encontrado'),
(12012, 4040, 4, 'No se hallaron registros de paciente para el criterio proporcionado'),
(12013, 4041, 4, 'No hay registros de paciente encontrados para el código de Re-identificación dado'),
(12014, 4042, 4, 'Ningún edema periférico'),
(12015, 4043, 4, 'Ninguna Farmacia Encontrada'),
(12016, 4044, 4, 'Ninguna Prescripción Encontrada'),
(12017, 4045, 4, 'Ninguna enfermedad/lesión actuales'),
(12018, 4046, 4, 'Sin entradas anteriores'),
(12019, 4047, 4, 'Ninguna Empresa Primaria seleccionada en la lista del Centro'),
(12020, 4048, 4, 'No hay encuentros anteriores'),
(12021, 4049, 4, 'No hay procedimientos en este encuentro'),
(12022, 4051, 4, 'Ningun Facultativo Encontrado'),
(12023, 4052, 4, 'Ninguna erupción o lesiones anormales'),
(12024, 4053, 4, 'Registros no encontrados'),
(12025, 4055, 4, 'Registros no encontrados. Por favor amplíe sus criterios de búsqueda.'),
(12026, 4056, 4, 'No hay recordatorios'),
(12027, 4057, 4, 'Resultados no encontrados, para los criterios de búsqueda.'),
(12028, 4058, 4, 'Sin resultados'),
(12029, 4060, 4, 'Búsqueda sin resultado'),
(12030, 4061, 4, 'Ningun resultado, por favor intente de nuevo'),
(12031, 4062, 4, 'Ningun resultado, por favor trate de nuevo'),
(12032, 4063, 4, 'Sin resultados, por favor intente de nuevo'),
(12033, 4065, 4, 'Ausente'),
(12034, 4066, 4, 'No hay firmas en el archivo'),
(12035, 4067, 4, 'Ninguna sensibilidad del Seno:'),
(12036, 4068, 4, 'Sin hoyuelos en la piel o nódulos en la mama'),
(12037, 4069, 4, 'NINGÚN NOMBRE DE CONTEXTO'),
(12038, 4071, 4, 'No hay sensibilidad testicular, masas'),
(12039, 4072, 4, 'Ningunas emociones o tirones'),
(12040, 4075, 4, 'No hay Encuentro'),
(12041, 4076, 4, 'Constantes vitales no han sido documentadas.'),
(12042, 4077, 4, 'No, Cancelar'),
(12043, 4078, 4, 'Ningún seguro de defecto incluyendo Auto es principal'),
(12044, 4079, 4, 'No:'),
(12045, 4080, 4, 'Nocturia'),
(12046, 4081, 4, 'No Pagado'),
(12047, 4082, 4, 'Informe No Reportado'),
(12048, 4083, 4, 'Lesión no específica'),
(12049, 4084, 4, 'No-electrónico'),
(12050, 4085, 4, 'Diabetes no insulino dependiente'),
(12051, 4086, 4, 'No asegurado'),
(12052, 4087, 4, 'No-SRH Médico'),
(12053, 4088, 4, 'No-SRH No-Médico'),
(12054, 4089, 4, 'Ninguno'),
(12055, 4090, 4, 'ninguno'),
(12056, 4091, 4, 'No definido'),
(12057, 4092, 4, 'No ha sido documentado'),
(12058, 4093, 4, 'Ninguna de las anteriores'),
(12059, 4094, 4, 'Ninguna de las Filas de Distribución Superior puede estar Completamente en Blanco.'),
(12060, 4095, 4, 'Diabetes no insulino dependiente'),
(12061, 4096, 4, 'Tampoco'),
(12062, 4097, 4, 'Normal'),
(12063, 4098, 4, 'Normal BL'),
(12064, 4099, 4, 'Examen Cardiaco Normal:'),
(12065, 4100, 4, 'Examen Cardiaco Normal: '),
(12066, 4101, 4, 'Examen Normal del Pulmón:'),
(12067, 4102, 4, 'Examen Normal del Pulmón: '),
(12068, 4103, 4, 'Visita normal en el Centro'),
(12069, 4104, 4, 'Orofaringe normal:'),
(12070, 4105, 4, 'Derecho Normal'),
(12071, 4106, 4, 'Derecho Normal:'),
(12072, 4107, 4, 'Ver Normal'),
(12073, 4108, 4, 'normal:'),
(12074, 4109, 4, 'Normalmente esto debe ser comprobado. No relacionado con el control de acceso.'),
(12075, 4112, 4, 'Noruego'),
(12076, 4115, 4, 'Nariz'),
(12077, 4116, 4, 'Sangrado por la nariz'),
(12078, 4117, 4, 'No es letra ni úmero'),
(12079, 4119, 4, 'No todos los campos son obligatorios para todos los códigos o tipos de códigos.'),
(12080, 4120, 4, 'No permitido'),
(12081, 4121, 4, 'No pueden eliminar el grupo Administradores'),
(12082, 4122, 4, 'No permitido Editar'),
(12083, 4123, 4, 'No pueden inactivar todos los objetos de seguridad'),
(12084, 4124, 4, 'No permitido hacer inactivo cualquier cosa de los administradores ACL'),
(12085, 4125, 4, 'No pueden eliminar el usuario administrador del grupo Administradores'),
(12086, 4126, 4, 'No permitido eliminar este usuario del grupo de Administradores'),
(12087, 4128, 4, 'No autorizado para tener acceso al módulo de PostCalendar'),
(12088, 4129, 4, 'No autorizado'),
(12089, 4130, 4, 'No Autorizado'),
(12090, 4131, 4, '¡No autorizado para este equipo!'),
(12091, 4132, 4, 'No autorizados para este equipo.'),
(12092, 4134, 4, 'No autorizado para firmar resultados'),
(12093, 4135, 4, 'No disponible'),
(12094, 4137, 4, 'No facturado'),
(12095, 4138, 4, 'No Chequeado'),
(12096, 4139, 4, 'No registró salida'),
(12097, 4140, 4, 'No codificado'),
(12098, 4141, 4, 'No Vencido'),
(12099, 4143, 4, 'No examinado'),
(12100, 4144, 4, 'No Examinado:'),
(12101, 4145, 4, 'No Examinado: '),
(12102, 4146, 4, 'No se ha encontrado'),
(12103, 4148, 4, 'No encontrado!'),
(12104, 4149, 4, 'No Hispano o Latino'),
(12105, 4150, 4, 'No instalado'),
(12106, 4152, 4, 'No visto desde'),
(12107, 4154, 4, 'No enviado todavía'),
(12108, 4156, 4, 'Sin Especificar'),
(12109, 4157, 4, 'Nota'),
(12110, 4158, 4, 'Código Notas'),
(12111, 4159, 4, 'Tenga en cuenta que el proceso completo después de hacer click en instalar puede tardar 5-10 minutos'),
(12112, 4160, 4, 'Tenga en cuenta que el proceso completo después de hacer click en actualizar puede tardar 5-10 minutos'),
(12113, 4161, 4, 'Tenga en cuenta que la Auditoría de inicio sesión necesita estar activada arriba'),
(12114, 4162, 4, 'Tipo de Nota'),
(12115, 4163, 4, 'Nota: 12:00 mediodía es PM, no AM'),
(12116, 4164, 4, 'NOTA: Importar datos externos puede tomar más de una hora dependiendo de su configuración hardware. Por ejemplo, una de las tablas de datos RxNorm contiene más de 6 millones de líneas.'),
(12117, 4165, 4, 'NOTA: Solo la versión Bianual Snomed Internacional es actualmente soportada'),
(12118, 4166, 4, 'NOTA: Solo la versión completa mensual de RxNorm es actualmente soportada'),
(12119, 4168, 4, 'Nota: este código no fue ingresado por un usuario autorizado. Sólo los códigos autorizados pueden ser subidos a la Red Abierta de facturación médica para su procesamiento. Si desea cargar estos códigos, por favor, seleccione un usuario autorizado aquí.'),
(12120, 4170, 4, 'Nota: este código no fue por un usuario autorizado. Sólo están autorizados los códigos pueden ser subidos a la Red Abierta de facturación médica para su procesamiento. Si desea cargar estos códigos, por favor, seleccione un usuario autorizado aquí.'),
(12121, 4171, 4, 'NOTA: Los archivos que cargan con nombres duplicados harán los archivos ser retitulados automáticamente. Por ejemplo '' archivo.jpg'' se convertirá '' archivo.jpg.1''. Los nombres de fichero se consideran únicos por paciente, no por categoría.'),
(12122, 4172, 4, 'Notas'),
(12123, 4173, 4, 'Notas - cualquier encuentros (escribir, sólo añadir opcional)'),
(12124, 4174, 4, 'Notas - mis encuentros (escribir, sólo añadir opcional)'),
(12125, 4175, 4, 'Notas no autorizados'),
(12126, 4177, 4, 'Nada Grabado'),
(12127, 4179, 4, 'Nada que importar para alergia'),
(12128, 4180, 4, 'Nada que importar para receta'),
(12129, 4181, 4, 'Nada que mostrar'),
(12130, 4182, 4, 'Nada fue seleccionado'),
(12131, 4184, 4, 'AVISO:: Sumisión/modificación de PostCalendar'),
(12132, 4185, 4, 'Notificación'),
(12133, 4186, 4, 'Email para Notificación'),
(12134, 4188, 4, 'Notificaciones'),
(12135, 4189, 4, 'Notificar Administrador Acerca del Evento de presentación / Modificación?'),
(12136, 4190, 4, 'Nov'),
(12137, 4191, 4, 'Noviembre'),
(12138, 4192, 4, 'Ahora, la publicación de:'),
(12139, 4193, 4, 'Imprimiendo ahora'),
(12140, 4194, 4, 'Ahora impresión $ stmt_contra declaraciones y actualización de los encuentros.'),
(12141, 4195, 4, 'Ahora declaraciones de la impresión $stmt_contra y facturas de la puesta al día.'),
(12142, 4196, 4, 'Ahora declaraciones de la impresión $stmt_contra; los encuentros no serán actualizados.'),
(12143, 4197, 4, 'Ahora declaraciones de la impresión $stmt_contra; las facturas no serán actualizadas.'),
(12144, 4198, 4, 'NPI'),
(12145, 4199, 4, 'National Quality Forum'),
(12146, 4200, 4, 'Número'),
(12147, 4201, 4, 'Número laboratorio'),
(12148, 4204, 4, 'Número de columnas en vista/año.'),
(12149, 4211, 4, 'Número de días de validez para el certificado de cliente.'),
(12150, 4213, 4, 'Número de dígitos después del punto decimal, normalmente 0 o 2.'),
(12151, 4214, 4, 'Número de visitas por página'),
(12152, 4215, 4, 'Número de partidas o eventos perdidos, si hay'),
(12153, 4216, 4, 'Número de horas de antelación para enviar notificaciones por email.'),
(12154, 4217, 4, 'Número de horas de antelación para enviar notificaciones por teléfono.'),
(12155, 4218, 4, 'Número de horas de antelación para enviar notificaciones por SMS.'),
(12156, 4221, 4, 'Número de columnas para historia pasada'),
(12157, 4222, 4, 'Número de pacientes que mostrar por página en la lista de pacientes.'),
(12158, 4223, 4, 'Entumecimiento'),
(12159, 4224, 4, 'Numerador'),
(12160, 4225, 4, 'Orden Númerico mostrado'),
(12161, 4227, 4, 'Nutrición'),
(12162, 4229, 4, 'O.A.F.V.'),
(12163, 4230, 4, 'O2 sat'),
(12164, 4231, 4, 'Obesidad I'),
(12165, 4232, 4, 'Obesidad II'),
(12166, 4233, 4, 'Obesidad III'),
(12167, 4234, 4, 'Objetivo'),
(12168, 4237, 4, 'Ocupación'),
(12169, 4239, 4, 'Acontecimiento'),
(12170, 4240, 4, 'Oct'),
(12171, 4241, 4, 'Octubre'),
(12172, 4242, 4, 'OD'),
(12173, 4243, 4, 'de'),
(12174, 4244, 4, 'de la cantidad'),
(12175, 4245, 4, 'de tabletas'),
(12176, 4246, 4, 'de cada mes'),
(12177, 4247, 4, 'Notas de la oficina'),
(12178, 4248, 4, 'Apagado'),
(12179, 4249, 4, 'Notas de la Oficina'),
(12180, 4250, 4, 'Visita en el Centro'),
(12181, 4251, 4, 'Medidas oficiales de calidad clínica (GCC) Grupos de medida'),
(12182, 4252, 4, 'Vínculo https para el Portal Externo del paciente.'),
(12183, 4253, 4, 'Vínculo Https para el Portal del Paciente Externo (Vínculo Paciente)'),
(12184, 4254, 4, 'Contraseña Portal del Paciente Externo'),
(12185, 4255, 4, 'Contraseña Portal del paciente externo (Dejar en blanco si no está registrado)'),
(12186, 4258, 4, 'Sitio Web del Portal del Paciente Externo'),
(12187, 4259, 4, 'Sitio web del Portal del Paciente Externo (Vínculo Paciente)'),
(12188, 4260, 4, 'Usuario del Portal del Paciente Externo'),
(12189, 4261, 4, 'Usuario del Portal del Paciente Externo (Dejar en blanco si no está registrado).'),
(12190, 4263, 4, 'Descendencia'),
(12191, 4265, 4, 'Ungüento'),
(12192, 4267, 4, 'Esta Bien'),
(12193, 4269, 4, 'OK para vincular la cuestión de fecha GCAC'),
(12194, 4270, 4, 'Viejo'),
(12195, 4272, 4, 'Clientes antiguos'),
(12196, 4273, 4, 'La fractura vieja no/malunion'),
(12197, 4274, 4, 'Diseño Estilo antiguo sin menú a la izquierda'),
(12198, 4275, 4, 'Formulario viejo-estilo sin buscar o comprobar duplicados'),
(12199, 4279, 4, 'Omitir información empleador en demográficos del paciente'),
(12200, 4280, 4, 'Omitir Empleador'),
(12201, 4281, 4, 'Omitir forma farm., vía e intervalo, que serán parte de la dosis'),
(12202, 4282, 4, 'Omitir seguro y otras cosas en el formulario de demograficos'),
(12203, 4283, 4, '¿Omitir usuarios internos?'),
(12204, 4284, 4, 'Omitir método de pago para el panel de co-pago'),
(12205, 4285, 4, 'Omitir para asignación automatica'),
(12206, 4286, 4, 'en'),
(12207, 4287, 4, 'Activo'),
(12208, 4288, 4, 'En mano'),
(12209, 4289, 4, 'En Orden'),
(12210, 4290, 4, 'En el sitio'),
(12211, 4291, 4, 'Una vez asignado el Centro para el negocio principal, no deberá ser cambiado. El cambio del Centro afectará al trabajo en NewCrop ePrescription.'),
(12212, 4292, 4, 'Una vez que cambie su contraseña, tendrá que volver a iniciar sesión.'),
(12213, 4297, 4, 'Soporte en línea'),
(12214, 4298, 4, 'Vínculo de soporte online'),
(12215, 4299, 4, 'Sólo activa'),
(12216, 4302, 4, 'sólo si es ubicación de facturación'),
(12217, 4303, 4, 'Sólo inactivo'),
(12218, 4304, 4, 'Sólo mio'),
(12219, 4305, 4, 'Sólo mostrar los Informes de códigos de diagnóstico'),
(12220, 4306, 4, 'Sólo mostrar Código de Servicio de Informes de Códigos de Finanzas'),
(12221, 4307, 4, 'Sólo subir las prescripciones activas'),
(12222, 4310, 4, 'Inicio Enfermedad:'),
(12223, 4311, 4, 'Inicio Enfermedad: '),
(12224, 4312, 4, 'Inicio de Hinchazón:'),
(12225, 4313, 4, 'Fecha de Inicio/hospital.:'),
(12226, 4314, 4, 'Sitio Web del Portal del Paciente Interno'),
(12227, 4315, 4, '¡Uy!'),
(12228, 4316, 4, 'Abrir'),
(12229, 4318, 4, 'Abrir en ventana nueva'),
(12230, 4321, 4, 'Abrir visitas para hoy'),
(12231, 4322, 4, 'LibreEHR ya tiene un Certificado de Autoridad Configurado'),
(12232, 4324, 4, 'Actualización base de datos LibreEHR'),
(12233, 4325, 4, 'Actualización base de datos LibreEHR para De-identificación'),
(12234, 4326, 4, 'LibreEHR no reconoce el archivo de entrada en el directorio contrib. Esto es probablemente porque necesita configurar la versión en la tabla supported_external_dataloads en la base de datos MySQL.'),
(12235, 4327, 4, 'LibreEHR debe configurarse para usar certificado antes de poder crear cliente'),
(12236, 4328, 4, 'LibreEHR requiere Javascript para realizar la autenticación de usuario.'),
(12237, 4329, 4, 'LibreEHR Usuarios'),
(12238, 4330, 4, 'Vacantes'),
(12239, 4332, 4, 'Oftálmico'),
(12240, 4333, 4, 'Opcion'),
(12241, 4334, 4, 'Opción para guardar el método de almacenamiento de documentos.'),
(12242, 4335, 4, 'Opción para soporte de inventario y ventas de productos'),
(12243, 4336, 4, 'Opcional'),
(12244, 4337, 4, 'Nombre de la categoría opcional para una imagen de la tarjeta de identificación que se puede ver desde la página de resumen del paciente.'),
(12245, 4338, 4, 'Nombre de la categoría opcional para una imagen de foto que se puede ver desde la página de resumen del paciente.'),
(12246, 4339, 4, 'Nombre de la categoría opcional de un documento para vincular desde la página de resumen del paciente. Haga click en el nombre del paciente para ver su tarjeta de identificación.'),
(12247, 4340, 4, 'Rango por defecto opcional para la entrada manual de los resultados'),
(12248, 4341, 4, 'Unidades opcionales por defecto para la entrada manual de los resultados'),
(12249, 4342, 4, 'Nombre de destino opcional'),
(12250, 4343, 4, 'Nombre opcional de medicamento, use % como comodín'),
(12251, 4345, 4, 'Información opcional sobre este evento'),
(12252, 4346, 4, 'Opcional número de lote, usar % como un comodin'),
(12253, 4347, 4, 'Nº Identificación Numérico opcional del paciente'),
(12254, 4348, 4, 'Código opcional del procedimiento'),
(12255, 4349, 4, 'Código procedimiento/servicio opcional'),
(12256, 4350, 4, 'Opciones'),
(12257, 4351, 4, 'ó'),
(12258, 4352, 4, 'O'),
(12259, 4353, 4, 'o elija'),
(12260, 4354, 4, 'o Selecciona y arrastrar para selección mas rapida'),
(12261, 4356, 4, 'O hacia fuera a'),
(12262, 4358, 4, 'o Shif-Selecciona para reducirlo'),
(12263, 4359, 4, 'O cargar archivo ERA:'),
(12264, 4360, 4, 'Oral'),
(12265, 4361, 4, 'Mucosa oral rosada, garganta clara'),
(12266, 4362, 4, 'Orden'),
(12267, 4363, 4, 'Orden y tipo de resultados'),
(12268, 4364, 4, 'Catálogo de órdenes'),
(12269, 4365, 4, 'Fecha pedido'),
(12270, 4367, 4, 'Formulario de pedido'),
(12271, 4369, 4, 'Orden debe ser un número entre 1 y 999'),
(12272, 4370, 4, 'Nombre pedido'),
(12273, 4371, 4, 'Solicitud Prioridades'),
(12274, 4372, 4, 'Orden de Procesamiento'),
(12275, 4375, 4, 'estatus de la orden'),
(12276, 4378, 4, 'tipo de orden'),
(12277, 4380, 4, 'Tipo de orden/resultado'),
(12278, 4381, 4, 'Ordenado'),
(12279, 4384, 4, 'Profesional que ordeno'),
(12280, 4386, 4, 'Lesión de órganos'),
(12281, 4387, 4, 'Organización'),
(12282, 4388, 4, 'Nombre de organización'),
(12283, 4389, 4, 'Nombre de la unidad organizacional'),
(12284, 4390, 4, 'Organizaciones'),
(12285, 4391, 4, 'Orientada x 3'),
(12286, 4392, 4, 'Original'),
(12287, 4396, 4, 'OROFARINGE: '),
(12288, 4397, 4, 'Orthopnea'),
(12289, 4398, 4, 'OS'),
(12290, 4399, 4, 'Osteoartritis'),
(12291, 4402, 4, 'Otro'),
(12292, 4403, 4, 'otro'),
(12293, 4404, 4, 'Otro (especifique)'),
(12294, 4405, 4, 'Otros - especificado'),
(12295, 4406, 4, 'Otro Progama Federal'),
(12296, 4407, 4, 'Otro HCFA'),
(12297, 4408, 4, 'Otra lesión en otra parte especificada'),
(12298, 4409, 4, 'Otro Seguro de Responsabilidad Civil es Primario'),
(12299, 4410, 4, 'Otro mes'),
(12300, 4411, 4, 'Otros programas No-Federales'),
(12301, 4412, 4, 'Otras Notas'),
(12302, 4413, 4, 'Otros síntomas pertinentes'),
(12303, 4414, 4, 'Otros síntomas pertinentes:'),
(12304, 4415, 4, 'Otra respuesta del paciente'),
(12305, 4416, 4, 'Otros tipos de estrés/lesión por sobreuso'),
(12306, 4417, 4, 'Otro Quirúrgico'),
(12307, 4418, 4, 'Otro/Genérico relacionado con Aborto'),
(12308, 4420, 4, 'Otros'),
(12309, 4421, 4, 'De otra forma usted destruirá las referencias a/de los datos existentes'),
(12310, 4422, 4, 'Reglas de tobillo de Ottawa'),
(12311, 4423, 4, 'OU'),
(12312, 4424, 4, 'SALIDA'),
(12313, 4425, 4, 'Salida'),
(12314, 4426, 4, 'Derivación de salida'),
(12315, 4427, 4, 'Resultado'),
(12316, 4428, 4, 'Outlook'),
(12317, 4431, 4, 'VENCIDO'),
(12318, 4432, 4, 'Sobreuso'),
(12319, 4433, 4, 'Información General'),
(12320, 4434, 4, 'Sobrepeso'),
(12321, 4435, 4, 'Sobrescribir la elección HIPAA'),
(12322, 4437, 4, 'Saturación del Oxígeno'),
(12323, 4439, 4, 'P'),
(12324, 4440, 4, 'p.c.'),
(12325, 4441, 4, 'p.m.'),
(12326, 4442, 4, 'p.r.n.'),
(12327, 4443, 4, 'Isleño del Pacifico'),
(12328, 4444, 4, 'Pediátrico'),
(12329, 4445, 4, 'Página'),
(12330, 4446, 4, 'Páginas'),
(12331, 4447, 4, 'Pago'),
(12332, 4448, 4, 'Cantidad pagada que usted asignará'),
(12333, 4449, 4, 'Importe pagado'),
(12334, 4450, 4, 'Pagado Via'),
(12335, 4451, 4, 'Dolor'),
(12336, 4453, 4, 'Palpitaciones'),
(12337, 4455, 4, 'Prueba de Papanicolaou'),
(12338, 4456, 4, 'Papel'),
(12339, 4457, 4, 'Tamaño papel'),
(12340, 4458, 4, 'Parálisis'),
(12341, 4461, 4, 'Analizar HL7'),
(12342, 4463, 4, 'Socio'),
(12343, 4464, 4, 'Nombre Socio'),
(12344, 4467, 4, 'Frase Contraseña'),
(12345, 4468, 4, 'Frase Contraseña para desencriptar documento'),
(12346, 4469, 4, 'Pacientes pasados'),
(12347, 4470, 4, 'Alerta Pasiva'),
(12348, 4471, 4, 'Reglas de Alerta Pasiva'),
(12349, 4472, 4, 'Contraseña'),
(12350, 4473, 4, 'Cambio de la contraseña'),
(12351, 4475, 4, 'Cambio de contraseña con éxito.'),
(12352, 4477, 4, 'Periodo de Gracia de Expiración de Contraseña'),
(12353, 4479, 4, 'Contraseña para puerta de enlace telefónico. Servicio automático de VOIP desarrollado por Maviq. Por favor visite http://signup.maviq.com para más información.'),
(12354, 4480, 4, 'Contraseña para puerta de enlace SMS.'),
(12355, 4481, 4, 'Contraseña para puerta de enlace SMS.'),
(12356, 4483, 4, 'Contraseña de seguridad ha sido recientemente actualizada.'),
(12357, 4484, 4, 'Contraseña para conectar a CouchDB'),
(12358, 4486, 4, 'Contraseña'),
(12359, 4490, 4, 'Vencimiento'),
(12360, 4491, 4, 'Vencimiento'),
(12361, 4492, 4, 'Intervalo Vencido (Recordatorios clínicos)'),
(12362, 4493, 4, 'Intervalo Vencido (Recordatorios Paciente)'),
(12363, 4494, 4, 'Lista de visitas anteriores'),
(12364, 4495, 4, 'Anteriores visitas'),
(12365, 4496, 4, 'Anteriores visitas y Documentos'),
(12366, 4497, 4, 'Anteriores visitas de'),
(12367, 4498, 4, 'Pegar datos HL7'),
(12368, 4499, 4, 'Pegar los datos de importación en el área de texto a continuación:'),
(12369, 4500, 4, 'Paciente'),
(12370, 4502, 4, 'Parche'),
(12371, 4508, 4, 'Ruta de backup del log de eventos'),
(12372, 4509, 4, 'Ruta del fichero de certificado CA'),
(12373, 4510, 4, 'Ruta del fichero clave CA'),
(12374, 4511, 4, 'Ruta de ficheros binarios MySQL'),
(12375, 4512, 4, 'Ruta de ficheros binarios Perl'),
(12376, 4513, 4, 'Ruta de los ficheros temporales'),
(12377, 4514, 4, 'Paciente'),
(12378, 4515, 4, 'paciente'),
(12379, 4516, 4, 'PACIENTE'),
(12380, 4517, 4, 'Dirección del paciente'),
(12381, 4518, 4, 'Falta la dirección del paciente'),
(12382, 4521, 4, 'Alergias del Paciente'),
(12383, 4522, 4, 'Alergias del Paciente'),
(12384, 4523, 4, 'Cita del Paciente'),
(12385, 4524, 4, 'Balance de paciente'),
(12386, 4528, 4, 'Nº Identificación del gráfico del paciente'),
(12387, 4529, 4, 'Comprobación de paciente'),
(12388, 4530, 4, 'Liquidación de paciente por '),
(12389, 4531, 4, 'Ciudad del Paciente'),
(12390, 4532, 4, 'Falta la ciudad del paciente'),
(12391, 4533, 4, 'Comunicación Enviada al Paciente'),
(12392, 4534, 4, 'Comunicación Enviada al Paciente'),
(12393, 4535, 4, 'Pais del Paciente'),
(12394, 4536, 4, 'Falta la ciudad del paciente. Tampoco ha configurado la ciudad del paciente por defecto en la configuración global'),
(12395, 4537, 4, 'Cobertura de paciente'),
(12396, 4539, 4, 'Datos del Paciente'),
(12397, 4541, 4, 'Falta la F.Nacimiento del paciente'),
(12398, 4542, 4, 'Detalles del Paciente'),
(12399, 4543, 4, 'F.Nacimiento del Paciente'),
(12400, 4544, 4, 'Documentos del Paciente'),
(12401, 4545, 4, 'Material Educativo para el Paciente'),
(12402, 4546, 4, 'Materiales educativos para pacientes'),
(12403, 4547, 4, 'Encuentros del Paciente'),
(12404, 4548, 4, 'Formulario de Encuentros del Paciente'),
(12405, 4549, 4, 'Encuentros de Pacientes'),
(12406, 4550, 4, 'Buscador de pacientes'),
(12407, 4551, 4, 'Nombre del Paciente'),
(12408, 4553, 4, 'Falta el nombre del paciente'),
(12409, 4558, 4, 'Género del Paciente'),
(12410, 4559, 4, 'Falta el género del paciente'),
(12411, 4560, 4, 'Paciente no autorizado al Portal del paciente'),
(12412, 4561, 4, 'Historia del Paciente'),
(12413, 4562, 4, 'Historia del Paciente/Estilo de Vida'),
(12414, 4563, 4, 'Teléfono Casa del Paciente'),
(12415, 4564, 4, 'ID Paciente'),
(12416, 4565, 4, 'Nº Identificación del Paciente'),
(12417, 4566, 4, 'Nº Identificación Tarjeta del Paciente'),
(12418, 4567, 4, 'Nombre categoría ID paciente'),
(12419, 4568, 4, 'Inmunización del paciente'),
(12420, 4569, 4, 'Información de Pacientes'),
(12421, 4570, 4, 'Instrucciones al paciente'),
(12422, 4571, 4, 'Distribución de pacientes de Seguros'),
(12423, 4572, 4, 'Informe de distribución de seguros de pacientes'),
(12424, 4573, 4, 'Cuestiones del Paciente'),
(12425, 4575, 4, 'Apellido(s)del Paciente'),
(12426, 4577, 4, 'Falta el apellido del paciente'),
(12427, 4581, 4, 'Lista de Pacientes'),
(12428, 4582, 4, 'Columnas Lista de Pacientes'),
(12429, 4584, 4, 'Nuevas ventanas Lista de Pacientes'),
(12430, 4585, 4, 'Tamaño página Lista de Pacientes'),
(12431, 4586, 4, 'Errores de búsqueda de pacientes'),
(12432, 4587, 4, 'Problemas Médicos del Paciente'),
(12433, 4588, 4, 'Medicamentos del Paciente'),
(12434, 4589, 4, 'Nombre del Paciente'),
(12435, 4590, 4, 'Nombre y Dirección del Paciente'),
(12436, 4593, 4, 'Nombre de Paciente Requerido'),
(12437, 4595, 4, 'Nota del paciente'),
(12438, 4596, 4, 'Nota de tipos de pacientes'),
(12439, 4597, 4, 'Notas del Paciente'),
(12440, 4598, 4, 'Notas del paciente (escribir, sólo añadir opcional)'),
(12441, 4599, 4, 'Número del Paciente'),
(12442, 4600, 4, 'Pago del paciente'),
(12443, 4602, 4, 'Nombre de Categoría de Foto del Paciente'),
(12444, 4603, 4, 'Portal del Paciente'),
(12445, 4605, 4, 'Portal del Paciente está apagado'),
(12446, 4606, 4, 'Inicio sesión Portal del Paciente'),
(12447, 4607, 4, 'Sitio web del Portal del Paciente'),
(12448, 4608, 4, 'Informe Impreso del Paciente'),
(12449, 4609, 4, 'Informe de registros de paciente'),
(12450, 4610, 4, 'Solicitud de registros de paciente'),
(12451, 4611, 4, 'Solicitud de registros de paciente'),
(12452, 4613, 4, 'Recordatorios del paciente'),
(12453, 4614, 4, 'Batch Recordatorio del Paciente'),
(12454, 4616, 4, 'Reglas Recordatorio del Paciente'),
(12455, 4617, 4, 'email Remitente de Recordatorio del Paciente'),
(12456, 4618, 4, 'Nombre Remitente de Recordatorio del Paciente'),
(12457, 4619, 4, 'Recordatorios del Paciente'),
(12458, 4620, 4, 'Informe del Paciente'),
(12459, 4621, 4, 'Solicitud del Paciente'),
(12460, 4622, 4, 'Paciente solicitó Registros Médicos'),
(12461, 4623, 4, 'Resultados del paciente'),
(12462, 4624, 4, 'Estilo de resultados de búsqueda de paciente'),
(12463, 4625, 4, 'Pantalla Buscar/añadir paciente'),
(12464, 4626, 4, 'Ajustes paciente'),
(12465, 4627, 4, 'Estado paciente'),
(12466, 4629, 4, 'Resumen del Paciente'),
(12467, 4630, 4, 'Transacciones del Paciente'),
(12468, 4631, 4, 'Código Postal paciente'),
(12469, 4632, 4, 'Paciente(s) en la base de datos que coinciden con la información demográfica que usted ha ingresado.'),
(12470, 4633, 4, 'Paciente/Cliente'),
(12471, 4634, 4, 'Paciente:'),
(12472, 4635, 4, 'PacienteID'),
(12473, 4636, 4, 'Pacientes'),
(12474, 4638, 4, 'Pago'),
(12475, 4639, 4, 'Preste atención a la "Hecho con" casillas de verificación. Después de los seguros están marcados completa luego empezaremos a pedir a la paciente a pagar el saldo restante, si usted no marca la totalidad de los seguros luego completar la cantidad restante no serán recogidos! También si hay un equilibrio que el paciente debe pagar, a continuación, establezca la fecha apropiada, ya que esto afecta a la lengua que aparece en las declaraciones del paciente.'),
(12476, 4640, 4, 'Fecha de Pago:'),
(12477, 4641, 4, 'Estado de Pago'),
(12478, 4642, 4, 'Nombre del beneficiario'),
(12479, 4643, 4, 'Pagador'),
(12480, 4644, 4, 'Tipo Pagador'),
(12481, 4645, 4, 'Pagar'),
(12482, 4646, 4, 'Entidad pagadora'),
(12483, 4647, 4, 'Pago'),
(12484, 4648, 4, 'pago'),
(12485, 4649, 4, 'Código ajuste pago'),
(12486, 4650, 4, 'Pago contra'),
(12487, 4651, 4, 'Importe pago'),
(12488, 4652, 4, 'Importe pago debe ser numérico'),
(12489, 4653, 4, 'Categoría pago'),
(12490, 4654, 4, 'Fecha de Pago'),
(12491, 4655, 4, 'pago ingresado el'),
(12492, 4656, 4, 'Pago desde'),
(12493, 4657, 4, 'Pasarela de pagos'),
(12494, 4658, 4, 'Imputar pagos'),
(12495, 4659, 4, 'Lista de pagos'),
(12496, 4660, 4, 'Método de Pago'),
(12497, 4661, 4, 'Ordenar pagos por'),
(12498, 4662, 4, 'Estado pagos'),
(12499, 4663, 4, 'Tipo pagos'),
(12500, 4664, 4, 'Valor de pago para el código '),
(12501, 4665, 4, 'Pagos'),
(12502, 4667, 4, 'PCP'),
(12503, 4669, 4, 'PDF'),
(12504, 4670, 4, 'Descargar PDF de seleccionados'),
(12505, 4672, 4, 'Pelvis y nalga'),
(12506, 4673, 4, 'Pénfigo'),
(12507, 4674, 4, 'Pendiente'),
(12508, 4676, 4, 'Pendiente F/U'),
(12509, 4677, 4, 'Seguimento Pendiente'),
(12510, 4678, 4, 'Seguimiento de resultados pendientes'),
(12511, 4679, 4, 'Ordenes pendientes'),
(12512, 4680, 4, 'Ordenes pendientes'),
(12513, 4681, 4, 'Revisión Pendientes'),
(12514, 4682, 4, 'Contador Recetas pendientes'),
(12515, 4684, 4, 'Pennington firme LibreEHR v'),
(12516, 4685, 4, 'La úlcera péptica'),
(12517, 4687, 4, 'por minuto'),
(12518, 4688, 4, 'Por las fosas nasales'),
(12519, 4689, 4, 'por las fosas nasales'),
(12520, 4690, 4, 'Por Oris'),
(12521, 4691, 4, 'por oris'),
(12522, 4692, 4, 'Por Recto'),
(12523, 4693, 4, 'por recto'),
(12524, 4694, 4, 'Porcentaje'),
(12525, 4697, 4, 'Percentil'),
(12526, 4698, 4, 'Derecho Perforado:'),
(12527, 4699, 4, 'Realizar la búsqueda'),
(12528, 4700, 4, 'Realizar esta acción'),
(12529, 4701, 4, 'Porcentaje Rendimiento'),
(12530, 4703, 4, 'Centro q realiza los estudios de Lab.'),
(12531, 4705, 4, 'Periodo'),
(12532, 4706, 4, 'Periodo en días donde un usuario puede iniciar sesión con una contraseña caducada.'),
(12533, 4707, 4, 'Cuidados perioperatorios'),
(12534, 4708, 4, 'Periférico'),
(12535, 4712, 4, 'Persona'),
(12536, 4713, 4, 'Personalizar'),
(12537, 4714, 4, 'PG'),
(12538, 4715, 4, 'Farmacia'),
(12539, 4716, 4, 'Pharm Com Count'),
(12540, 4717, 4, 'Farmacias'),
(12541, 4718, 4, 'Farmacia'),
(12542, 4719, 4, 'Dispensario de la Farmacia');
INSERT INTO `lang_definitions` VALUES
(12543, 4720, 4, 'Neumotorax'),
(12544, 4729, 4, 'Teléfono'),
(12545, 4730, 4, 'Lista de llamadas de teléfono'),
(12546, 4731, 4, 'Informe Lista de llamadas'),
(12547, 4733, 4, 'Contraseña de la puerta de enlace telefónico'),
(12548, 4734, 4, 'URL de la puerta de enlace telefónico'),
(12549, 4735, 4, 'Usuario puerta de enlace telefónico'),
(12550, 4737, 4, 'Hora notificación teléfono'),
(12551, 4738, 4, 'Número de teléfono'),
(12552, 4740, 4, 'Fotofobia'),
(12553, 4741, 4, 'Fotografías'),
(12554, 4742, 4, 'PHP comprimida'),
(12555, 4743, 4, 'Módulo PHP CURL debe estar activado en su servidor.'),
(12556, 4744, 4, 'Extraído de PHP'),
(12557, 4745, 4, 'controles de acceso de PHP-GACL están desactivados.'),
(12558, 4746, 4, 'controles de acceso de PHP-GACL are desactivados.'),
(12559, 4747, 4, 'Examen Físico'),
(12560, 4749, 4, 'Solicitud de Médico'),
(12561, 4750, 4, 'Firma del Médico'),
(12562, 4752, 4, 'Médicos'),
(12563, 4753, 4, 'escoger'),
(12564, 4754, 4, 'Seleccionar'),
(12565, 4755, 4, 'Seleccionar un tema CSS'),
(12566, 4756, 4, 'PID'),
(12567, 4757, 4, 'PID (enfermedad pélvica inflamatoria)'),
(12568, 4758, 4, 'Tamaño de la Píldora'),
(12569, 4759, 4, 'Píldoras'),
(12570, 4760, 4, 'Coloque el fichero de database zip en el siguiente directorio si quiere la opción de instalar'),
(12571, 4761, 4, 'Ponga el fichero zip de bbdd ICD 10 en la siguiente carpeta'),
(12572, 4762, 4, 'Ponga el fichero zip de bbdd ICD 9 en la siguiente carpeta'),
(12573, 4763, 4, 'Ponga el fichero zip de bbdd RxNorm en la siguiente carpeta'),
(12574, 4764, 4, 'Ponga el fichero zip de bbdd Snomed en la siguiente carpeta'),
(12575, 4765, 4, 'Marcador de posición'),
(12576, 4766, 4, 'Marcador de posición (Mantiene vacia ACL)'),
(12577, 4767, 4, 'Texto sin Formato'),
(12578, 4768, 4, 'Plan'),
(12579, 4771, 4, 'Nombre del Plan'),
(12580, 4775, 4, 'Ajuste Planes'),
(12581, 4779, 4, 'Plan:'),
(12582, 4782, 4, 'Planes'),
(12583, 4784, 4, 'Jugador'),
(12584, 4785, 4, 'Posición de juego'),
(12585, 4786, 4, 'Favor de llamar si la informacion arriba es incorrecta'),
(12586, 4787, 4, 'Favor de cambiar palabra clave'),
(12587, 4788, 4, 'Por favor, elige un fichero'),
(12588, 4789, 4, 'Por favor, elige un paciente'),
(12589, 4790, 4, 'Por favor, elija una selección válida de la lista.'),
(12590, 4791, 4, 'Favor elegir selecion valida'),
(12591, 4792, 4, 'Por favor, elija un valor para'),
(12592, 4793, 4, 'Por favor elija el rango de fechas, y haga click en refrescar para ver los resultados.'),
(12593, 4794, 4, 'Por favor elegir el formato adecuado del fichero EDI-271'),
(12594, 4795, 4, 'Por favor click en el botón Descargar para descargar los datos de DE identificación'),
(12595, 4796, 4, 'Por favor click en el botón descargar para descargar los datos de Re-identificación'),
(12596, 4797, 4, 'Por favor, cierre esta ventana.'),
(12597, 4798, 4, 'Por favor, comparar el nuevo nombre'),
(12598, 4801, 4, 'Por favor cree la siguiente carpeta antes de proceder'),
(12599, 4802, 4, 'No acepte por favor esta prescripción a menos que fuera recibida vía facimile.'),
(12600, 4803, 4, 'Favor de no aceptar esta receta a menos que fuera recibida por fax'),
(12601, 4804, 4, 'Por favor, no utilice su navegador botón de parada o recarga, mientras que esta página está funcionando a menos que más de 10 minutos han transcurrido, esto no causa para detener el proceso en el servidor y se consumen innecesario recursos.'),
(12602, 4805, 4, 'POR FAVOR ACTIVE LA EXTENSIÓN CURL'),
(12603, 4806, 4, 'POR FAVOR ACTIVE LA EXTENSIÓN OPENSSL'),
(12604, 4807, 4, 'POR FAVOR ACTIVE LA EXTENSIÓN SOAP'),
(12605, 4808, 4, 'POR FAVOR ACTIVE LA EXTENSIÓN XML'),
(12606, 4809, 4, 'Favor de entrar fecha de la ultima revision'),
(12607, 4810, 4, 'Por favor introduzca la fecha'),
(12608, 4811, 4, 'Por favor introduzca una fecha de vencimiento'),
(12609, 4812, 4, 'Por favor introduzca un mensaje'),
(12610, 4813, 4, 'Por favor, introduzca un importe monetario, utilizando sólo números y un punto decimal.'),
(12611, 4814, 4, 'Por favor introduzca una Nueva Contraseña'),
(12612, 4815, 4, 'Por favor, escriba un título!'),
(12613, 4819, 4, 'Por favor introduzca el código de Re-identificación correcto'),
(12614, 4821, 4, 'Por favor, introduzca el dato de la nueva búsqueda'),
(12615, 4822, 4, 'Por favor introduzca el código de re-identificación'),
(12616, 4823, 4, 'Por favor introduzca contraseña'),
(12617, 4824, 4, 'Por favor rellene el número de cheque'),
(12618, 4825, 4, 'Por favor rellene el número Check/Ref'),
(12619, 4826, 4, 'Por favor rellene la fecha'),
(12620, 4827, 4, 'Por favor rellene el importe del pago'),
(12621, 4828, 4, 'Por favor rellene la categoría del pago'),
(12622, 4829, 4, 'Por favor rellene la procedencia del pago'),
(12623, 4830, 4, 'Por favor rellene la casilla de la Fecha'),
(12624, 4831, 4, 'Favor de llenar antes de continuar'),
(12625, 4832, 4, 'Por favor indique el motivo de la visita'),
(12626, 4834, 4, 'Favor digitar criterios de busqueda, luego Selecciona para ver resultados'),
(12627, 4835, 4, 'Por favor introduzca los criterios de búsqueda arriba, y haga click en aceptar para ver los resultados. (Los resultados serán mostrados en una ventana emergente)'),
(12628, 4836, 4, 'Por favor inicie sesión de nuevo'),
(12629, 4837, 4, 'Por favor tenga en cuenta que esto puede tomar mucho tiempo, hasta varios minutos, el navegador web puede no aparecer muy activo durante este tiempo, pero la generación de una factura es un proceso complicado y su navegador web está a la espera de más información.'),
(12630, 4838, 4, 'Note que las constantes son sensibles a mayúsculas y minúsculas y se permite cualquier cadena.'),
(12631, 4839, 4, 'Por favor, utilice únicamente caracteres alfabéticos'),
(12632, 4840, 4, 'Por favor, utilice únicamente caracteres alfabéticos sin espacios'),
(12633, 4841, 4, 'Por favor, pagar esta cantidad'),
(12634, 4842, 4, 'Por favor ponga sus ficheros de instalación en la siguiente carpeta'),
(12635, 4843, 4, 'Favor de referise a'),
(12636, 4844, 4, 'Por favor, reinicie la contraseña.'),
(12637, 4845, 4, 'Por favor resetear el servidor apache antes de intentar la finalización de sesión'),
(12638, 4847, 4, 'Por favor seleccione'),
(12639, 4849, 4, 'Por favor seleccione un idioma'),
(12640, 4850, 4, 'Por favor seleccione un Paciente'),
(12641, 4851, 4, 'Por favor seleccione una entidad de negocio primario con ''C.I.F.'' como su centro ''C.I.F.''. Si usted es autónomo, ponga su ''C.I.F.''. Será usado para identificarle en el sistema NewCrop.'),
(12642, 4854, 4, 'Por favor Seleccione un Destinatario'),
(12643, 4855, 4, 'Por favor seleccione la fecha de inicio y fin'),
(12644, 4856, 4, 'Por favor Seleccione un Destinatario válido'),
(12645, 4858, 4, 'Por favor, seleccione un razón de ajuste para el código '),
(12646, 4859, 4, 'Por favor, seleccione un evento'),
(12647, 4860, 4, 'Por favor seleccione una Opción de Búsqueda'),
(12648, 4863, 4, 'Favor seleccionar al menos una receta'),
(12649, 4865, 4, 'Por favor, seleccione las pags. que desee copiar o reenviar:'),
(12650, 4866, 4, 'Por favor seleccione la Forma de Pago'),
(12651, 4867, 4, 'Por favor seleccione el tipo de pago.'),
(12652, 4869, 4, 'Por favor seleccione socio X12, requerido para crear el batch 270'),
(12653, 4870, 4, 'Por favor ajuste'),
(12654, 4871, 4, 'Por favor ponga la variable de_identification_config a cero'),
(12655, 4873, 4, 'Por favor inicie un nuevo proceso de De identificación'),
(12656, 4874, 4, 'Por favor actualice la base de datos LibreEHR para incluir procedimientos, funciones, tablas para De identificación'),
(12657, 4875, 4, 'Por favor, consulte la tabla de log de errores de De Identificación para más detalles'),
(12658, 4876, 4, 'Por favor visite la pantalla de Re-Identificación después de algún tiempo'),
(12659, 4877, 4, 'Por favor visite la pantalla de Re-Identificación después de algún tiempo'),
(12660, 4878, 4, 'Por favor visite la página pasado algún tiempo'),
(12661, 4882, 4, 'PM'),
(12662, 4883, 4, 'PM Program'),
(12663, 4884, 4, 'Método de pago'),
(12664, 4885, 4, 'PND'),
(12665, 4886, 4, 'Conjugado Neumocócico 1'),
(12666, 4887, 4, 'Conjugado Neumocócico 2'),
(12667, 4888, 4, 'Conjugado Neumocócico 3'),
(12668, 4889, 4, 'Conjugado Neumocócico 4'),
(12669, 4890, 4, 'vacuna contra el neumococo'),
(12670, 4891, 4, 'Vacunación Neumonía'),
(12671, 4892, 4, 'Estado de vacunación de neumonía de adultos mayores'),
(12672, 4893, 4, 'Estado de vacunación de neumonía de adultos mayores (GCC)'),
(12673, 4894, 4, 'Podológica'),
(12674, 4896, 4, 'Punto del servicio (posición)'),
(12675, 4897, 4, 'Póliza'),
(12676, 4898, 4, 'Póliza Nº'),
(12677, 4899, 4, 'Número Póliza'),
(12678, 4900, 4, 'Polaco'),
(12679, 4901, 4, 'Polidipsia'),
(12680, 4902, 4, 'Pólipos'),
(12681, 4903, 4, 'Poliuria'),
(12682, 4904, 4, 'Falta de Apetito'),
(12683, 4905, 4, 'Pobre Circulación'),
(12684, 4906, 4, 'Déficit auditivo'),
(12685, 4907, 4, 'Se requieren Pop-ups activos para ver estos reportes'),
(12686, 4908, 4, '¿Rellenar la vista del año con eventos?'),
(12687, 4909, 4, 'Menús emergentes'),
(12688, 4910, 4, 'Portal'),
(12689, 4911, 4, 'Actividad del Portal'),
(12690, 4917, 4, 'Portugués'),
(12691, 4918, 4, 'Portugués (Brasileño)'),
(12692, 4919, 4, 'Portugués (Europeo)'),
(12693, 4920, 4, 'Código de POS'),
(12694, 4922, 4, 'Positivo'),
(12695, 4923, 4, 'Positivos'),
(12696, 4925, 4, 'Enviar por'),
(12697, 4926, 4, 'Goteo nasal posterior'),
(12698, 4927, 4, 'Enviar pagos'),
(12699, 4928, 4, 'Post-quirúrgico'),
(12700, 4929, 4, 'Publique en la contabilidad y marque como facturado'),
(12701, 4930, 4, 'Publicar en fecha'),
(12702, 4931, 4, 'Publicar en fecha no puede ser mayor que hoy'),
(12703, 4932, 4, 'Publicar en fecha debe ser mayor que la fecha de cierre financiero'),
(12704, 4933, 4, 'Cuidado del Post-Aborto'),
(12705, 4934, 4, 'Contracepción del Post-Aborto'),
(12706, 4935, 4, 'Asesoramiento del Post-Aborto'),
(12707, 4936, 4, 'Seguimiento Post-Aborto'),
(12708, 4937, 4, 'Postal'),
(12709, 4938, 4, 'Código Postal'),
(12710, 4939, 4, 'Código Postal'),
(12711, 4941, 4, 'PostCalendar'),
(12712, 4942, 4, 'Administración del PostCalendar'),
(12713, 4943, 4, 'Configuración de la Categoría PostCalendar'),
(12714, 4944, 4, 'Configuración Global de PostCalendar'),
(12715, 4945, 4, 'Publicado en'),
(12716, 4946, 4, 'Fecha de Envío'),
(12717, 4948, 4, 'Desarrollado por'),
(12718, 4949, 4, 'PPE+ Prev Med/Surg Hx'),
(12719, 4950, 4, 'PQRI (Iniciativa Informe Calidad Médica)'),
(12720, 4951, 4, 'Registro ID PQRI'),
(12721, 4952, 4, 'Registro Nombre PQRI'),
(12722, 4953, 4, 'Práctica'),
(12723, 4954, 4, 'Práctica establecida por defecto'),
(12724, 4955, 4, 'Configuración de la práctica'),
(12725, 4956, 4, 'Prestador'),
(12726, 4958, 4, 'Pago anticipado'),
(12727, 4959, 4, 'Prepago'),
(12728, 4960, 4, 'Consulta del Pre-Aborto'),
(12729, 4961, 4, 'Asesoramiento del Pre-Aborto'),
(12730, 4962, 4, 'Categoría Pref'),
(12731, 4964, 4, 'Preferencias'),
(12732, 4965, 4, 'Categoría preferida del evento'),
(12733, 4966, 4, 'Lengua preferida'),
(12734, 4967, 4, 'Preferencia Farmacia'),
(12735, 4968, 4, 'Organización de Proveedor Preferido (PPO)'),
(12736, 4969, 4, 'Prueba de embarazo'),
(12737, 4970, 4, 'Preliminar'),
(12738, 4972, 4, 'Pague por Adelantado'),
(12739, 4973, 4, 'Prescripción'),
(12740, 4974, 4, 'Receta ha alcanzado sus limites de'),
(12741, 4975, 4, 'Histórico de Prescripciones'),
(12742, 4976, 4, 'Importación de Histórico de Prescripciones completado'),
(12743, 4977, 4, 'Etiqueta de la prescripción'),
(12744, 4978, 4, 'Informe de Prescripción'),
(12745, 4979, 4, 'Prescripciónes'),
(12746, 4980, 4, 'Prescripciones y dispensaciones'),
(12747, 4981, 4, 'Recetas y otras referencias'),
(12748, 4982, 4, 'Prescripciones y/o remisiones del especialista'),
(12749, 4983, 4, 'Informe de las prescripciones'),
(12750, 4984, 4, 'Prescripciones/remisiones'),
(12751, 4985, 4, 'Presente'),
(12752, 4986, 4, 'Presentación de queja'),
(12753, 4988, 4, 'Pulse Continuar para proseguir'),
(12754, 4989, 4, 'Presunción de Diagnóstico'),
(12755, 4990, 4, 'Presunción de Diagnóstico por el especialista'),
(12756, 4991, 4, 'Previa'),
(12757, 4992, 4, 'Prev Med/Surg Hx'),
(12758, 4993, 4, 'Mes anterior. (Presione para menu)'),
(12759, 4994, 4, 'Año anterior (Presione para el menu)'),
(12760, 4995, 4, 'Cuidado Preventivo'),
(12761, 4998, 4, 'Vista previa del evento'),
(12762, 5000, 4, 'Previsualización de'),
(12763, 5001, 4, 'Anterior'),
(12764, 5002, 4, 'Consultas Anteriores'),
(12765, 5003, 4, 'Dia Anterior'),
(12766, 5004, 4, 'Historia Anterior/Tamizaje'),
(12767, 5005, 4, 'Mes Anterior'),
(12768, 5006, 4, 'Semana Anterior'),
(12769, 5007, 4, 'Precio'),
(12770, 5008, 4, 'Precio de descuento'),
(12771, 5009, 4, 'Nivel de Precio'),
(12772, 5010, 4, 'Nivel de Precio:'),
(12773, 5011, 4, 'Precios'),
(12774, 5012, 4, 'Primaria'),
(12775, 5013, 4, 'Entidad de negocios primaria'),
(12776, 5014, 4, 'La entidad de negocio primaria es usada como cuenta Id para la ePrescipción. Cambiando el centro afectará al funcionamiento en NewCrop.'),
(12777, 5022, 4, 'Seguro Primario'),
(12778, 5023, 4, 'Seguro Primario'),
(12779, 5024, 4, 'Datos Primarios del Seguro'),
(12780, 5025, 4, 'Proveedor Primario del Seguro'),
(12781, 5026, 4, 'Proveedor de primaria'),
(12782, 5027, 4, 'Imprime'),
(12783, 5028, 4, 'Imprimir (HTML)'),
(12784, 5029, 4, 'Imprimir (PDF)'),
(12785, 5031, 4, 'Imprimir cualquier encuentro'),
(12786, 5032, 4, 'Imprimir el formulario de remisión en blanco'),
(12787, 5033, 4, 'Comando Imprimir'),
(12788, 5039, 4, 'Imprimir el Formato'),
(12789, 5040, 4, 'Imprimir cuatro paneles'),
(12790, 5042, 4, 'Mensaje Imprimir'),
(12791, 5043, 4, 'Imprimir Múltiples'),
(12792, 5044, 4, 'Para imprimir múltiples Fax'),
(12793, 5045, 4, 'Imprima nombre, fecha y firma'),
(12794, 5046, 4, 'Imprimir notas'),
(12795, 5047, 4, 'Imprimir Página 1'),
(12796, 5048, 4, 'Imprimir Página 2'),
(12797, 5051, 4, 'Impresión Receta por Facultativo'),
(12798, 5052, 4, 'Grabar Imprimir'),
(12799, 5053, 4, 'Imprimir estados seleccionados'),
(12800, 5054, 4, 'Registro de tiro impresión'),
(12801, 5056, 4, 'Imprimir este encuentro'),
(12802, 5057, 4, 'Imprimir esta nota'),
(12803, 5058, 4, 'Imprimir Esta Nota'),
(12804, 5060, 4, 'Imprimir Fax'),
(12805, 5061, 4, 'Ver Imprenta'),
(12806, 5062, 4, 'Imprimible'),
(12807, 5063, 4, 'Versión Imprimible'),
(12808, 5064, 4, 'Impreso'),
(12809, 5066, 4, 'Resultados de la impresión:'),
(12810, 5067, 4, 'Impresión omitida; ver la salida de prueba en'),
(12811, 5068, 4, 'Impresión saltado; ver la prueba de salida en '),
(12812, 5069, 4, 'Antes de autentificación'),
(12813, 5070, 4, 'Formulario de Autorización Previa'),
(12814, 5071, 4, 'Visita anterior'),
(12815, 5072, 4, 'Prioridad'),
(12816, 5073, 4, 'Prioridad '),
(12817, 5074, 4, 'Privado'),
(12818, 5075, 4, 'Problema'),
(12819, 5076, 4, 'Problema Diagnóstico (DX)'),
(12820, 5077, 4, 'Lista de Problema'),
(12821, 5079, 4, 'Problemas y Cuestiones'),
(12822, 5080, 4, 'Proc Bat'),
(12823, 5081, 4, 'Proc Cat'),
(12824, 5083, 4, 'Proc.Pendientes Revisión'),
(12825, 5085, 4, 'Proc Res'),
(12826, 5086, 4, 'Procedimiento'),
(12827, 5087, 4, 'Procedmiento por area corporal'),
(12828, 5088, 4, 'Procedimientos con resultados Boolean'),
(12829, 5089, 4, 'Codigo de Procedimiento'),
(12830, 5090, 4, 'Códigos de procedimiento'),
(12831, 5091, 4, 'Lateralidades del procedimiento'),
(12832, 5093, 4, 'Orden de Procedimiento'),
(12833, 5095, 4, 'Procedimiento ordenado para'),
(12834, 5102, 4, 'Informe Procedimiento'),
(12835, 5103, 4, 'Situaciones del reporte de procedimientos'),
(12836, 5104, 4, 'Resultado anormal del procedimiento'),
(12837, 5105, 4, 'Situacion del resultado del procedimiento'),
(12838, 5106, 4, 'Resultados del procedimientos'),
(12839, 5107, 4, 'Rutas del procedimiento'),
(12840, 5108, 4, 'Tipos de especimenes del procedimiento'),
(12841, 5109, 4, 'Reportes estadisticos del procedimiento'),
(12842, 5110, 4, 'Tipo de procedimiento'),
(12843, 5111, 4, 'Tipos de procedimientos'),
(12844, 5112, 4, 'Unidades del procedimiento'),
(12845, 5113, 4, 'Procedimiento/Servicio'),
(12846, 5114, 4, 'Procedimientos'),
(12847, 5115, 4, 'Proceso'),
(12848, 5117, 4, 'Procesar ERA file'),
(12849, 5120, 4, 'El proceso puede tardar algún tiempo'),
(12850, 5121, 4, 'Procesado'),
(12851, 5122, 4, 'Procesado por'),
(12852, 5123, 4, 'Fecha procesado'),
(12853, 5125, 4, 'Procesamiento'),
(12854, 5129, 4, 'Producto'),
(12855, 5130, 4, 'Método Producto Anticonceptivo'),
(12856, 5132, 4, 'Productos'),
(12857, 5133, 4, 'Productos pero no medicamentos con receta y sin plantillas'),
(12858, 5134, 4, 'Prof.'),
(12859, 5135, 4, 'Notas de progreso'),
(12860, 5136, 4, 'Cáncer de Próstata'),
(12861, 5137, 4, 'Detección de cancer de próstata'),
(12862, 5138, 4, 'Examen de Próstata'),
(12863, 5139, 4, 'Problemas de Próstata'),
(12864, 5140, 4, 'Próstata sin agrandamiento, nódulos o sensibilidad'),
(12865, 5142, 4, 'Provee ruta absoluta'),
(12866, 5143, 4, 'Provee ruta absoluta del file'),
(12867, 5145, 4, 'Proporcione resúmenes clínicos a los pacientes en cada visita.'),
(12868, 5146, 4, 'Proporcionar a los pacientes una copia electrónica de su información de salud (incluyendo resultados de pruebas de diagnóstico, lista de problemas, lista de medicamentos, medicación para alergias), bajo petición.'),
(12869, 5147, 4, 'Ofrecer a los pacientes el acceso oportuno a su información electrónica de salud (incluyendo resultados de laboratorio, lista de problemas, listas de medicamentos, alergias a medicamentos) dentro de cuatro días hábiles de que la información esté disponible para el EP (profesional elegible).'),
(12870, 5148, 4, 'Proporcionar Registros al Paciente por Visita'),
(12871, 5149, 4, 'Proporcionar email válido'),
(12872, 5150, 4, '¿Resumen médico proporcionado?'),
(12873, 5151, 4, '¿Recursos educativos proporcionados?'),
(12874, 5152, 4, 'Proveedor'),
(12875, 5154, 4, 'Facultativo ID'),
(12876, 5155, 4, 'Facultativo ID en el centro especificado'),
(12877, 5156, 4, 'Errores de correspondencia de Proveedor'),
(12878, 5159, 4, 'Número de Proveedor'),
(12879, 5162, 4, 'Facultativo:'),
(12880, 5163, 4, 'Facultativos'),
(12881, 5164, 4, 'NPI Facultativos'),
(12882, 5165, 4, 'Proveedores Ver calendario completo'),
(12883, 5166, 4, 'Imp'),
(12884, 5167, 4, 'PSA'),
(12885, 5168, 4, 'Psoriasis'),
(12886, 5169, 4, 'Psiq. Diagnóstico'),
(12887, 5170, 4, 'Psiq. Medicamentos'),
(12888, 5171, 4, 'Psiquiátricos'),
(12889, 5172, 4, 'Breve carta Psiquiátrica'),
(12890, 5173, 4, 'Diagnosis psiquiátrica'),
(12891, 5174, 4, 'Examinación psiquiátrica'),
(12892, 5175, 4, 'Historia Psiquiátrica'),
(12893, 5176, 4, 'Producto Psiquiátrico'),
(12894, 5177, 4, 'Medicación Psiquiátrica'),
(12895, 5178, 4, 'Pt %'),
(12896, 5179, 4, 'Pt Notas'),
(12897, 5180, 4, 'Pt Notas/Autorización'),
(12898, 5181, 4, 'Pt en exceso'),
(12899, 5182, 4, 'Pt Pagado'),
(12900, 5183, 4, 'Solicitud Registro Pacienten'),
(12901, 5184, 4, 'Pt Reembolso'),
(12902, 5185, 4, 'Pt liberados'),
(12903, 5186, 4, 'Pt Informe'),
(12904, 5187, 4, 'PT Estudiante, o dejar en blanco'),
(12905, 5188, 4, 'PT_CIUDAD'),
(12906, 5189, 4, 'PT_FDN'),
(12907, 5191, 4, 'PT_NOMBRE'),
(12908, 5192, 4, 'PT_APELLIDO'),
(12909, 5193, 4, 'PT_NOMBRE'),
(12910, 5196, 4, 'PT_POSTAL'),
(12911, 5198, 4, 'PT_ESTADO'),
(12912, 5199, 4, 'PT_CALLE'),
(12913, 5201, 4, 'Público'),
(12914, 5203, 4, 'Seguridad Social (SS) u otro organismo oficial'),
(12915, 5204, 4, 'Puertorriqueño'),
(12916, 5205, 4, 'Pulmonar'),
(12917, 5206, 4, 'Pulso'),
(12918, 5207, 4, 'Penyabí'),
(12919, 5208, 4, 'Comprar'),
(12920, 5209, 4, 'Compra/Devolución'),
(12921, 5210, 4, 'Adquisiciones'),
(12922, 5213, 4, 'q.3h'),
(12923, 5214, 4, 'q.4h'),
(12924, 5215, 4, 'q.5h'),
(12925, 5216, 4, 'q.6h'),
(12926, 5217, 4, 'q.8h'),
(12927, 5218, 4, 'q.d.'),
(12928, 5219, 4, 'q.i.d.'),
(12929, 5220, 4, 'Cant.disp.'),
(12930, 5221, 4, 'QOH es menor que el consumo mensual'),
(12931, 5222, 4, 'Cantidad'),
(12932, 5223, 4, 'Cantidad'),
(12933, 5224, 4, 'Calidad'),
(12934, 5225, 4, 'Medidas de calidad (GCC)'),
(12935, 5226, 4, 'Cantidad'),
(12936, 5227, 4, 'Cantidad para NDC'),
(12937, 5228, 4, 'Cantidad En Mano'),
(12938, 5229, 4, 'cantidad parece inservible'),
(12939, 5231, 4, 'interrogante'),
(12940, 5232, 4, 'HCFA cola de procesamiento por lotes'),
(12941, 5233, 4, 'HCFA cola de procesamiento por lotes y la impresión'),
(12942, 5234, 4, 'Cola de la UB-92 del procesamiento por lotes'),
(12943, 5235, 4, 'Cola de la UB-92 del procesamiento por lotes y la impresión'),
(12944, 5236, 4, 'Cola'),
(12945, 5237, 4, 'Administración de Eventos en cola'),
(12946, 5238, 4, 'Cola para'),
(12947, 5240, 4, 'Cola de Peticiones Administración'),
(12948, 5241, 4, 'Dejar'),
(12949, 5242, 4, 'Dejar el alcohol'),
(12950, 5243, 4, 'R'),
(12951, 5245, 4, 'Raza'),
(12952, 5246, 4, 'Raza y Etnia'),
(12953, 5247, 4, 'Raza/etnia'),
(12954, 5248, 4, 'Radio'),
(12955, 5249, 4, 'Botones de radio'),
(12956, 5251, 4, 'Rango'),
(12957, 5252, 4, 'Erupciones'),
(12958, 5253, 4, 'Tasa'),
(12959, 5254, 4, 'Proporcion'),
(12960, 5255, 4, 'Informe sin procesar'),
(12961, 5256, 4, 'Re-Identificación'),
(12962, 5257, 4, 'Proceso Re-Identificación completado'),
(12963, 5258, 4, 'Proceso Re identificación en curso'),
(12964, 5259, 4, 'Ficheros de Re-identificación serán salvados en'),
(12965, 5260, 4, '¿Misma lesión?'),
(12966, 5261, 4, 'Abra de nuevo'),
(12967, 5262, 4, 'Volvió a abrir'),
(12968, 5263, 4, 'Reacción'),
(12969, 5264, 4, 'reacciones'),
(12970, 5265, 4, 'Leído'),
(12971, 5268, 4, 'Nombre Real'),
(12972, 5269, 4, 'Realmente borrar'),
(12973, 5270, 4, 'Razón'),
(12974, 5271, 4, 'Motivo del fallecimiento'),
(12975, 5272, 4, 'Causa de fallecimiento'),
(12976, 5274, 4, 'Motivo de la remisión'),
(12977, 5275, 4, 'Motivo de la Visita'),
(12978, 5276, 4, 'Motivo / Forma'),
(12979, 5277, 4, 'Recibo'),
(12980, 5278, 4, 'Recibo de Pago'),
(12981, 5279, 4, 'Recibo generado'),
(12982, 5280, 4, 'Informe de Recibos por método de pago'),
(12983, 5281, 4, 'Resumen de Recibos'),
(12984, 5282, 4, 'Recibido'),
(12985, 5283, 4, 'Recibido Por'),
(12986, 5284, 4, 'Faxes recibidos'),
(12987, 5287, 4, 'Receptor'),
(12988, 5288, 4, 'Identificación del receptor'),
(12989, 5289, 4, 'Recibidor ID (ISA08)'),
(12990, 5290, 4, 'Calificador del recibidor ID (ISA07)'),
(12991, 5292, 4, 'No se permiten las tres palabras claves recientes'),
(12992, 5293, 4, 'Beneficiario'),
(12993, 5294, 4, 'Lista de Beneficiarios vacía'),
(12994, 5295, 4, 'Nombre destinatario'),
(12995, 5296, 4, 'Destinatario de la info'),
(12996, 5298, 4, 'Recomendación'),
(12997, 5300, 4, 'Recomendaciones'),
(12998, 5301, 4, 'Recomendaciones y el tratamiento'),
(12999, 5302, 4, 'Recomendaciones del especialista'),
(13000, 5303, 4, 'Registro'),
(13001, 5304, 4, 'Registro ya existe'),
(13002, 5310, 4, 'Registro y gráfico de los cambios en las constantes vitales.'),
(13003, 5311, 4, 'Registro demográficos.'),
(13004, 5312, 4, 'Grabar revelación info'),
(13005, 5313, 4, 'Registro de estado físico'),
(13006, 5314, 4, 'Pago de Registro'),
(13007, 5315, 4, 'Fecha registro de solicitud'),
(13008, 5316, 4, 'Registro estado pacientes fumadores de 13 años o más'),
(13009, 5317, 4, 'Registros'),
(13010, 5318, 4, 'registros encontrados'),
(13011, 5319, 4, 'registros encontrados.'),
(13012, 5320, 4, 'Uso de drogas no farmacológicas'),
(13013, 5321, 4, 'Drogas no farmacológicas'),
(13014, 5322, 4, 'Rectal'),
(13015, 5323, 4, 'Examen Rectal'),
(13016, 5324, 4, 'Rectal'),
(13017, 5325, 4, 'Redirección'),
(13018, 5326, 4, 'Enrojecimiento'),
(13019, 5327, 4, 'Reducido:'),
(13020, 5328, 4, 'Referir'),
(13021, 5329, 4, 'Referido Por'),
(13022, 5330, 4, 'Referido en Fecha:'),
(13023, 5331, 4, 'Referido para:'),
(13024, 5332, 4, 'Clasificación de derivación (nivel de riesgo)'),
(13025, 5333, 4, 'Rango de resultados de derivación'),
(13026, 5334, 4, 'Motivo de derivación'),
(13027, 5336, 4, 'Nombre y firma del derivador'),
(13028, 5337, 4, 'Derivación'),
(13029, 5338, 4, 'Derivado Por'),
(13030, 5339, 4, 'Tarjeta de Derivación'),
(13031, 5340, 4, 'Fecha de Derivación'),
(13032, 5341, 4, 'Formulario de derivación'),
(13033, 5342, 4, 'FORMULARIO DE DERIVACIÓN'),
(13034, 5343, 4, 'Nº ID derivación'),
(13035, 5345, 4, 'Origen derivación'),
(13036, 5346, 4, 'Origen derivación para encuentros'),
(13037, 5347, 4, 'Derivado a'),
(13038, 5348, 4, 'Derivados'),
(13039, 5349, 4, 'Informes de Derivados'),
(13040, 5350, 4, 'Derivado por'),
(13041, 5351, 4, 'Derivado Por'),
(13042, 5352, 4, 'Derivado a'),
(13043, 5353, 4, 'Derivador'),
(13044, 5355, 4, 'Diagnóstico de Derivación'),
(13045, 5356, 4, 'Diagnóstico de Derivación'),
(13046, 5357, 4, 'Médico y Centro que deriva'),
(13047, 5358, 4, 'Proveedor que deriva'),
(13048, 5359, 4, 'Recargar'),
(13049, 5360, 4, 'Recargas'),
(13050, 5361, 4, 'recargas'),
(13051, 5362, 4, 'Reflejos normales'),
(13052, 5363, 4, 'Refrescar'),
(13053, 5365, 4, 'Refrescando recordatorios'),
(13054, 5368, 4, 'Se negó a declarar'),
(13055, 5369, 4, 'reg_re'),
(13056, 5370, 4, 'Registrar'),
(13057, 5372, 4, 'Registrado'),
(13058, 5373, 4, 'registrado'),
(13059, 5375, 4, 'Fecha de Registro'),
(13060, 5376, 4, 'Formulario de Inscripción'),
(13061, 5377, 4, 'Rehabilitación'),
(13062, 5381, 4, 'Relaciónese Con'),
(13063, 5382, 4, 'Relacionado'),
(13064, 5383, 4, 'Incidencia relacionada'),
(13065, 5385, 4, 'Relacion(es)/niños'),
(13066, 5386, 4, 'Relaciones'),
(13067, 5387, 4, 'Relación'),
(13068, 5388, 4, 'Orden relativo de esta entidad'),
(13069, 5389, 4, 'Familiares'),
(13070, 5399, 4, 'Las credenciales de la salud del relais faltan de esta cuenta de usuario.'),
(13071, 5400, 4, 'Relay Health ID'),
(13072, 5402, 4, 'Fecha versión'),
(13073, 5403, 4, 'Religión'),
(13074, 5406, 4, 'Reinicie sesión'),
(13075, 5407, 4, 'Recordatorio'),
(13076, 5408, 4, 'Recordar Centro Seleccionado'),
(13077, 5409, 4, 'Recordatorio'),
(13078, 5410, 4, 'Intervalos recordatorio'),
(13079, 5411, 4, 'Recordatorio No Enviado Todavía'),
(13080, 5412, 4, 'Recordatorio Enviado El'),
(13081, 5413, 4, 'Recordatorios'),
(13082, 5414, 4, 'REMITIR A'),
(13083, 5416, 4, 'Quitar'),
(13084, 5419, 4, 'Eliminar Grupo'),
(13085, 5420, 4, 'Eliminar el formulario del grupo'),
(13086, 5421, 4, 'Eliminar soporte para las vacunas'),
(13087, 5422, 4, 'Eliminar soporte para phpMyAdmin'),
(13088, 5423, 4, 'Eliminar soporte para prescripciones'),
(13089, 5425, 4, 'Elimina la función del gráfico de seguimiento'),
(13090, 5426, 4, 'Litiasis Renal'),
(13091, 5427, 4, 'Renombrar'),
(13092, 5428, 4, 'Renombrar Grupo'),
(13093, 5429, 4, 'Representación'),
(13094, 5430, 4, 'Representación del Facultativo'),
(13095, 5431, 4, 'Número Representación del Facultativo'),
(13096, 5432, 4, 'Reordenar'),
(13097, 5433, 4, 'Al reordenar'),
(13098, 5434, 4, 'Alcanzado el punto de pedido'),
(13099, 5435, 4, 'Punto de pedido, 0 no es válido'),
(13100, 5438, 4, 'Repetición eventos'),
(13101, 5439, 4, 'Repetir Información:'),
(13102, 5440, 4, 'Repite'),
(13103, 5444, 4, 'Fecha de Respuesta'),
(13104, 5445, 4, 'De respuesta'),
(13105, 5446, 4, 'Informe'),
(13106, 5447, 4, 'Informe Clínico'),
(13107, 5449, 4, 'Informe por'),
(13108, 5457, 4, 'Reporte de estado'),
(13109, 5458, 4, 'Informe Totales'),
(13110, 5459, 4, 'Informe/Formulario'),
(13111, 5460, 4, 'Informable'),
(13112, 5461, 4, 'Reportado'),
(13113, 5462, 4, 'Fecha Informada'),
(13114, 5463, 4, 'Informes'),
(13115, 5467, 4, '¡Solicitud ignorada - proceso de reclamos ya se está ejecutando!'),
(13116, 5473, 4, 'Fecha pedida'),
(13117, 5474, 4, 'Servicio Solicitado'),
(13118, 5475, 4, 'Se requiere Contraseña más compleja'),
(13119, 5476, 4, 'Se requiere Contraseña única'),
(13120, 5477, 4, 'Requerido'),
(13121, 5478, 4, 'Copago requerido'),
(13122, 5479, 4, 'Falta campo requerido:Por favor elija el fichero EDI-271 para adjuntar'),
(13123, 5480, 4, 'Falta campo requerido: Por favor introduzca el nombre'),
(13124, 5481, 4, 'Falta campo requerido: Por favor introduzca el apellido'),
(13125, 5482, 4, 'Falta campo requerido: Por favor introduzca el nombre de usuario'),
(13126, 5483, 4, 'Campos requeridos'),
(13127, 5484, 4, 'Requerimientos'),
(13128, 5485, 4, 'RESERVADO'),
(13129, 5486, 4, 'Reservado'),
(13130, 5487, 4, 'Reservados para su uso para definir el Tiempo Programado de Vacaciones'),
(13131, 5488, 4, 'Reservados para definir cuando un proveedor no podrá tener citas disponibles después.'),
(13132, 5489, 4, 'Reservado para definir cuando un evento no ocurrió tal como se especificaba.'),
(13133, 5490, 4, 'Reservados para definir cuando un proveedor puede tener citas disponibles después.'),
(13134, 5491, 4, 'Reinicio'),
(13135, 5492, 4, 'Resetear credenciales del Portal externo'),
(13136, 5493, 4, 'Resetear credenciales del Portal interno'),
(13137, 5496, 4, 'Resuelto'),
(13138, 5497, 4, 'Respiración'),
(13139, 5498, 4, 'Esfuerzo al Respirar'),
(13140, 5499, 4, 'Respiratorias'),
(13141, 5501, 4, 'Restringir a usuarios no autorizados el calendario de la clínica establecido en usuario admin.'),
(13142, 5502, 4, 'Restringir usuarios a Centros'),
(13143, 5503, 4, 'Entrenamiento Restringido'),
(13144, 5504, 4, 'Resultado'),
(13145, 5506, 4, 'Estado del resultado'),
(13146, 5507, 4, 'Falta estado o anormalidad del resultado'),
(13147, 5508, 4, 'Resultado, use % como comodín'),
(13148, 5510, 4, 'Resultados y'),
(13149, 5511, 4, 'Resultados Encontrados para la Búsqueda'),
(13150, 5512, 4, 'Grupo Resultados'),
(13151, 5515, 4, 'Resultados por página'),
(13152, 5516, 4, 'Resultados / Detalles'),
(13153, 5517, 4, 'Examen de Retina'),
(13154, 5518, 4, 'Derecho retractado:'),
(13155, 5519, 4, 'Volver'),
(13156, 5520, 4, 'Retorne la parte superior con su pago'),
(13157, 5521, 4, 'Retornar al calendario'),
(13158, 5523, 4, 'Vuelva a esta página y podrá completar el proceso de instalación ICD 10 haciendo click en la sección de la cabecera ICD 10'),
(13159, 5524, 4, 'Vuelva a esta página y podrá completar el proceso de instalación ICD 9 haciendo click en la sección de la cabecera ICD 9'),
(13160, 5525, 4, 'Vuelva a esta página y podrá completar el proceso de instalación RxNorm haciendo click en la sección de la cabecera RXNORM'),
(13161, 5526, 4, 'Vuelva a esta página y podrá completar el proceso de instalación Snomed haciendo click en la sección de la cabecera SNOMED'),
(13162, 5527, 4, 'Valor Devuelto'),
(13163, 5528, 4, 'Visita de Vuelta'),
(13164, 5529, 4, 'Volvió a jugar'),
(13165, 5534, 4, 'Revisión Hist.Med.Pasada:'),
(13166, 5535, 4, 'Revisión de los sistemas'),
(13167, 5536, 4, 'Revisión de chequeos de sistemas'),
(13168, 5537, 4, 'Revisado'),
(13169, 5538, 4, 'Revisión'),
(13170, 5539, 4, 'Artritis reumatoide'),
(13171, 5540, 4, 'Artritis reumatoide'),
(13172, 5541, 4, 'Derecho'),
(13173, 5542, 4, 'Oido Derecho'),
(13174, 5543, 4, 'oido derecho'),
(13175, 5545, 4, 'Derecho:'),
(13176, 5546, 4, 'Zumbido en Oídos'),
(13177, 5547, 4, 'Sonido en Oídos'),
(13178, 5549, 4, 'Factores de Riesgo'),
(13179, 5550, 4, 'Nivel de Riesgo'),
(13180, 5551, 4, 'RLL:'),
(13181, 5552, 4, 'ROM'),
(13182, 5553, 4, 'Rumano'),
(13183, 5560, 4, 'Lista'),
(13184, 5561, 4, 'Ruta'),
(13185, 5562, 4, 'Ruta de administracion si aplicable'),
(13186, 5563, 4, 'Encaminado'),
(13187, 5564, 4, 'Filas'),
(13188, 5565, 4, 'RRR sin MOR'),
(13189, 5566, 4, 'Frotar'),
(13190, 5567, 4, 'Frotaciones:'),
(13191, 5568, 4, 'Regla'),
(13192, 5569, 4, 'Añadir regla'),
(13193, 5570, 4, 'Detalle Regla'),
(13194, 5572, 4, 'Editar Regla'),
(13195, 5575, 4, 'Ajuste Regla'),
(13196, 5578, 4, 'Reglas'),
(13197, 5580, 4, 'Configuración Regla'),
(13198, 5581, 4, 'Ejecutando comando '),
(13199, 5582, 4, 'ruptura'),
(13200, 5583, 4, 'Ruso'),
(13201, 5584, 4, 'Receta'),
(13202, 5585, 4, 'Receta'),
(13203, 5586, 4, 'Margen inferior Receta (px)'),
(13204, 5587, 4, 'Receta Activa DEA#'),
(13205, 5588, 4, 'Receta Activa NPI'),
(13206, 5589, 4, 'Receta Activa Estado Lic.#'),
(13207, 5590, 4, 'Margen izquierdo Receta (px)'),
(13208, 5591, 4, 'Tamaño papel Receta'),
(13209, 5592, 4, 'Margen derecho Receta (px)'),
(13210, 5593, 4, 'Mostrar Receta DEA#'),
(13211, 5594, 4, 'Mostrar Receta NPI'),
(13212, 5595, 4, 'Mostrar Receta Estado Lic.#'),
(13213, 5596, 4, 'Margen superior Receta (px)'),
(13214, 5598, 4, 'Recetario (RxNorm)'),
(13215, 5599, 4, 'Base de datos RxNorm'),
(13216, 5600, 4, 'S'),
(13217, 5601, 4, 'S.S.'),
(13218, 5602, 4, 'S3:'),
(13219, 5603, 4, 'S4:'),
(13220, 5604, 4, 'SA ** para leer la licencia por favor lea la documentoss/licencia.texto o visite * http://www.gnu.org/copyleft/gpl.html * * / / / ========================================================================= / / '),
(13221, 5605, 4, 'Venta'),
(13222, 5606, 4, 'Ventas'),
(13223, 5607, 4, 'Ventas por artículo'),
(13224, 5608, 4, 'Informe de ventas por producto'),
(13225, 5609, 4, 'Saliva'),
(13226, 5610, 4, 'Mismo Día'),
(13227, 5611, 4, 'Samoano'),
(13228, 5612, 4, 'Muestra'),
(13229, 5613, 4, 'Tipo de sanción'),
(13230, 5617, 4, 'Sabado'),
(13231, 5618, 4, 'Sábado y Domingo'),
(13232, 5619, 4, 'Sabado'),
(13233, 5620, 4, 'Guardar'),
(13234, 5621, 4, 'SALVAR'),
(13235, 5622, 4, 'Guardar y Cerrar'),
(13236, 5624, 4, 'Guardar y Distribuir'),
(13237, 5626, 4, 'Guardar como Nuevo'),
(13238, 5627, 4, 'Guardar como nota nueva'),
(13239, 5628, 4, 'Guardar configuración del certificado'),
(13240, 5629, 4, 'Guardar Cambios'),
(13241, 5630, 4, 'Guardar Formulario'),
(13242, 5631, 4, 'Guardar Inmunización'),
(13243, 5632, 4, 'Guardar Nuevo Campo'),
(13244, 5633, 4, 'Guardar Nuevo Grupo'),
(13245, 5634, 4, 'Guardar Nueva Lista'),
(13246, 5635, 4, 'Guardar la nueva plantilla'),
(13247, 5637, 4, 'Guardar Demograficas de Paciente'),
(13248, 5638, 4, 'Guardar Exitoso para el gráfico identificación'),
(13249, 5639, 4, 'Guardar ITransacción'),
(13250, 5641, 4, 'Escaneados'),
(13251, 5642, 4, 'Nota Escaneada de visita'),
(13252, 5643, 4, 'Directorio del escáner'),
(13253, 5644, 4, 'Escáner En'),
(13254, 5645, 4, 'Horario'),
(13255, 5646, 4, 'Calendario de Centros'),
(13256, 5647, 4, 'Nota Escolar'),
(13257, 5648, 4, 'Escoliosis'),
(13258, 5651, 4, 'SE'),
(13259, 5652, 4, 'SE Dirección'),
(13260, 5653, 4, 'SE Ciudad'),
(13261, 5654, 4, 'SE Pais'),
(13262, 5655, 4, 'SE Localidad'),
(13263, 5656, 4, 'SE Código Postal'),
(13264, 5657, 4, 'SE Estado'),
(13265, 5658, 4, 'SE Código Postal'),
(13266, 5659, 4, 'Búsqueda'),
(13267, 5661, 4, 'búsqueda'),
(13268, 5662, 4, 'Búsqar Nuevamente'),
(13269, 5663, 4, 'Buscar en todas las columnas'),
(13270, 5664, 4, 'Búscar por:'),
(13271, 5665, 4, 'Buscar por'),
(13272, 5666, 4, 'Búscar para:'),
(13273, 5668, 4, 'Buscar en'),
(13274, 5669, 4, 'Buscar o Añadir Paciente'),
(13275, 5670, 4, 'Buscar Pago'),
(13276, 5671, 4, 'Resultados de búsqueda'),
(13277, 5672, 4, 'Resultados de la Búsqueda:'),
(13278, 5673, 4, 'Buscar seleccionados'),
(13279, 5674, 4, 'Cadena buscada no coincide con la lista de la base de datos'),
(13280, 5675, 4, 'Cadena buscada debe tener al menos tres caracteres'),
(13281, 5676, 4, 'Buscar Texto'),
(13282, 5677, 4, 'Búsqueda de eventos'),
(13283, 5678, 4, 'Buscar/añadir'),
(13284, 5679, 4, 'Buscar / Añadir Asegurador'),
(13285, 5680, 4, 'Buscando las citas'),
(13286, 5681, 4, 'Buscando'),
(13287, 5682, 4, 'Uso de cinturón de seguridad'),
(13288, 5683, 4, 'Uso de cinturón de seguridad'),
(13289, 5684, 4, 'Segundo'),
(13290, 5687, 4, 'Secundaria'),
(13291, 5688, 4, 'Seguro Secundario'),
(13292, 5689, 4, 'Datos de Seguro Secundario'),
(13293, 5690, 4, 'Proveedor de Seguro Secundario'),
(13294, 5691, 4, 'Tipo secundario de Medicare'),
(13295, 5698, 4, 'Seguridad'),
(13296, 5699, 4, 'Ver Todo'),
(13297, 5700, 4, 'Ver Autorizaciones'),
(13298, 5701, 4, 'Véase el Gráfico de Crecimiento'),
(13299, 5702, 4, 'Ver los mensajes de la última serie de reclamos generados'),
(13300, 5704, 4, 'Visto en'),
(13301, 5707, 4, 'Convulsiones'),
(13302, 5708, 4, 'Seleción'),
(13303, 5709, 4, 'Seleción'),
(13304, 5710, 4, 'seleccionar'),
(13305, 5712, 4, 'Seleccionar un contexto'),
(13306, 5714, 4, 'Seleccione un intervalo de tiempo'),
(13307, 5715, 4, 'Seleccionar un usuario'),
(13308, 5716, 4, 'Seleccionar Todos'),
(13310, 5720, 4, 'Seleccionar una categoría'),
(13311, 5722, 4, 'Seleccionar las casillas correspondientes para borrar'),
(13312, 5723, 4, 'Seleccionar el criterio para eliminar'),
(13313, 5725, 4, 'Seleccione datos requeridos para De-Identificación'),
(13314, 5726, 4, 'Seleccione datos para incluir en los datos de De-Identificación'),
(13315, 5727, 4, 'Elegir fecha'),
(13316, 5728, 4, 'Seleccione plantilla deseada'),
(13317, 5729, 4, 'Seleccione diagnóstico'),
(13318, 5730, 4, 'Seleccione diagnóstico para pedido de de-identificación'),
(13319, 5731, 4, 'Seleccione Medicamento'),
(13320, 5732, 4, 'Seleccione Medicamentos'),
(13321, 5733, 4, 'Seleccione los medicamentos para la solicitud de de-identificación'),
(13322, 5734, 4, 'Seleccione fichero EDI-271'),
(13323, 5736, 4, 'Elegir campo'),
(13324, 5737, 4, 'Seleccione Sector'),
(13325, 5738, 4, 'Seleccionar para Imprimir'),
(13326, 5739, 4, 'Seleccione vacunas'),
(13327, 5740, 4, 'Seleccione las vacunas para la solicitud anónima'),
(13328, 5741, 4, 'Seleccionar Seguro, escribiendo'),
(13329, 5742, 4, 'Seleccione Incidencia'),
(13330, 5744, 4, 'Seleccionar idioma'),
(13331, 5746, 4, 'Seleccione uno o más códigos de diagnóstico para justificar el servicio'),
(13332, 5754, 4, 'Elija los items de configuración para exportar'),
(13333, 5755, 4, 'Elija el asunto primario responsable por eventos fallidos este dia'),
(13334, 5759, 4, 'Seleccionar usuario'),
(13335, 5760, 4, 'Seleccionar usuarios de la lista desplegable'),
(13336, 5761, 4, 'Seleccionar que idiomas, si los hay, pueden ser elegidos al inicio de sesión. (solo si arriba todos los idiomas permitidos está desactivados)'),
(13337, 5762, 4, 'Seleccione Sí para confirmar la eliminación del grupo'),
(13338, 5765, 4, 'Seleccionado'),
(13339, 5766, 4, 'Visita seleccionada'),
(13340, 5767, 4, 'Seleccionando esto se creará un mensaje que necesita ser procesado por cada receptor individualmente (esto no es una tarea de grupo)'),
(13341, 5768, 4, 'Uno Mismo'),
(13342, 5769, 4, 'Paga del uno mismo'),
(13343, 5771, 4, 'Enviar'),
(13344, 5772, 4, 'Enviar recordatorio con fecha'),
(13345, 5773, 4, 'Enviar un Recordatorio'),
(13346, 5774, 4, 'Envíe en curso'),
(13347, 5775, 4, 'enviar mensaje'),
(13348, 5776, 4, 'Batch de Envío de Recordatorios'),
(13349, 5777, 4, 'Enviar recordatorios a pacientes que lo han solicitado, para cuidado preventivo o seguimiento'),
(13350, 5778, 4, 'Enviar resúmenes con derivaciones'),
(13351, 5779, 4, 'Enviar este file'),
(13352, 5780, 4, 'Enviar este mensaje'),
(13353, 5781, 4, 'Enviar a'),
(13354, 5784, 4, 'Enviar a todos'),
(13355, 5788, 4, 'Remitente'),
(13356, 5789, 4, 'Identificación del Remitente'),
(13357, 5790, 4, 'Remitente ID (ISA06)'),
(13358, 5791, 4, 'Calificador del remitente ID (ISA05)'),
(13359, 5794, 4, 'Sensibilidades'),
(13360, 5795, 4, 'Sensibilidad:'),
(13361, 5796, 4, 'Examen sensorial normal'),
(13362, 5799, 4, 'Enviado por, dejar en blanco para todos'),
(13363, 5801, 4, 'Fecha de envio'),
(13364, 5802, 4, 'Incidencias Enviadas'),
(13365, 5803, 4, '¿Enviar Registros Médicos?'),
(13366, 5804, 4, 'Enviado con éxito'),
(13367, 5807, 4, 'Enviado a Impresora'),
(13368, 5808, 4, 'Enviado a, dejar en blanco para todos'),
(13369, 5812, 4, 'Sep'),
(13370, 5813, 4, 'Separado'),
(13371, 5814, 4, 'Septiembre'),
(13372, 5816, 4, 'Secuencia'),
(13373, 5821, 4, 'Servicio'),
(13374, 5822, 4, 'Categoría de Servicio'),
(13375, 5823, 4, 'Código Servicio'),
(13376, 5824, 4, 'Informe de códigos de servicio Financiero'),
(13377, 5825, 4, 'Códigos Servicio'),
(13378, 5826, 4, 'Fecha de Servicio'),
(13379, 5827, 4, 'Fecha de Servicio:'),
(13380, 5829, 4, 'Centro de servicio'),
(13381, 5831, 4, 'Servicio prestado por el especialista'),
(13382, 5832, 4, 'Informe de servicio'),
(13383, 5833, 4, 'Sólo inf. de serv.'),
(13384, 5834, 4, 'Servicios'),
(13385, 5835, 4, 'Servicios por Categoría'),
(13386, 5836, 4, 'Servicios prestados'),
(13387, 5837, 4, 'Servicios proporcionados'),
(13388, 5838, 4, 'Servicios/Productos'),
(13389, 5839, 4, 'Tipo Sesión'),
(13390, 5840, 4, 'Set'),
(13391, 5841, 4, 'Habilitar cookie para recordar el centro seleccionado entre sesiones.'),
(13392, 5842, 4, 'Definir como terminado'),
(13393, 5845, 4, 'Asignar esto para la ruta absoluta. Para crear certificados clientes SSL para HTTPPS.'),
(13394, 5846, 4, 'Ajustar a'),
(13395, 5847, 4, 'Ajustar por defecto'),
(13396, 5848, 4, 'Ajustar el número de versión en la base de datos...'),
(13397, 5849, 4, 'Ajustes'),
(13398, 5851, 4, 'Migraña Grave'),
(13399, 5853, 4, 'Severidad del dolor'),
(13400, 5854, 4, 'Severidad del dolor'),
(13401, 5855, 4, 'Sexo'),
(13402, 5856, 4, 'Enfermedades de Transmisión Sexual'),
(13403, 5859, 4, 'Conpartir'),
(13404, 5860, 4, 'Intérprete de comandos para imprimir desde el servidor'),
(13405, 5864, 4, 'Falta de aire al respirar'),
(13406, 5865, 4, 'Falta de Aliento'),
(13407, 5866, 4, 'Falta de Aliento 2'),
(13408, 5867, 4, 'Registro de Tiro'),
(13409, 5868, 4, 'Fecha de Expediente de Tiro:'),
(13410, 5870, 4, 'debe ser como nnnnn-nnnn-nn'),
(13411, 5871, 4, 'Deben ser dos letras'),
(13412, 5872, 4, 'Debe contener 10 dígitos'),
(13413, 5873, 4, 'Debe contener sólo 10 dígitos'),
(13414, 5874, 4, 'Hombro'),
(13415, 5875, 4, 'Hombro + Clavicula'),
(13416, 5876, 4, 'Prob. de Hombro'),
(13417, 5877, 4, 'Presente'),
(13418, 5878, 4, 'Mostrar Activo'),
(13419, 5880, 4, 'Mostrar Act+Inact'),
(13420, 5881, 4, 'Mostrar todos los procedimientos'),
(13421, 5883, 4, 'Mostrar Todas las Transacciones'),
(13422, 5884, 4, 'Ocupado'),
(13423, 5885, 4, 'Mostrar Sólo Autorizado'),
(13424, 5886, 4, 'Mostrar Horas Disponibles'),
(13425, 5887, 4, 'Mostrar ambos US y métrica (unidad principal es métrica)'),
(13426, 5888, 4, 'Mostrar ambos US y métrica (unidad principal es US)'),
(13427, 5889, 4, 'Mostrar Detalles'),
(13428, 5891, 4, 'Mostrar Gráfico'),
(13429, 5892, 4, '¿Demuestre el texto de cernido del acontecimiento en mouseover?'),
(13430, 5893, 4, 'Mostrar el número de eventos en las páginas de administrador?'),
(13431, 5894, 4, 'Mostrar Inactivo'),
(13432, 5896, 4, 'Mostrar Menú'),
(13433, 5897, 4, 'Mostrar sólo métrica'),
(13434, 5898, 4, 'Cuantos eventos mostrar en paginas de admin'),
(13435, 5901, 4, 'Mostrar notas de pacientes'),
(13436, 5902, 4, 'Mostrar  libras y onzas'),
(13437, 5903, 4, 'Mostrar libras como valor decimal'),
(13438, 5904, 4, 'Mostrar primario completo'),
(13439, 5905, 4, 'Mostrar recordatorios'),
(13440, 5906, 4, 'Mostrar Informe'),
(13441, 5907, 4, 'Mostrar búsqueda y presentar los enlaces en el bloque?'),
(13442, 5910, 4, 'Mostrar el formulario de estado personalizado para agregar a lista de widget (preguntará por el título y la abreviatura).'),
(13443, 5913, 4, 'Mostrar sólo no facturados'),
(13444, 5914, 4, 'Mostrar solo USA'),
(13445, 5915, 4, 'Mostrando'),
(13446, 5920, 4, 'Hermanos'),
(13447, 5921, 4, 'Célula de hoz (falciforme)'),
(13448, 5922, 4, 'Sig'),
(13449, 5923, 4, 'Sigmoide/Colonoscopia'),
(13450, 5925, 4, 'Firma resultados laboratorio (escribir, opcional sólo añadir)'),
(13451, 5926, 4, 'Firmar Resultados'),
(13452, 5927, 4, 'Firma'),
(13453, 5929, 4, 'Firma:'),
(13454, 5930, 4, 'Receta firmada'),
(13455, 5932, 4, 'Hinchazón Significativa:'),
(13456, 5934, 4, 'Co-Pago Simplificado'),
(13457, 5935, 4, 'Demográficos Simplificados'),
(13458, 5936, 4, 'Prescripciones Simplificadas'),
(13459, 5937, 4, 'Desde'),
(13460, 5938, 4, 'Sinceramente,'),
(13461, 5940, 4, 'Soltero'),
(13462, 5941, 4, 'Lista selección única'),
(13463, 5942, 4, 'Lista de selección única con posibilidad de añadir a la lista'),
(13464, 5946, 4, 'Problemas del Seno'),
(13465, 5947, 4, 'Cirugía de Seno'),
(13466, 5948, 4, 'SENSIBILIDAD DE SENO:'),
(13467, 5949, 4, 'Sinusitis'),
(13468, 5951, 4, 'Nº Identificación'),
(13469, 5953, 4, 'Nº Identificación para soporte LibreEHR del Servicio Intercambio Laboratorio LLC.'),
(13470, 5956, 4, 'Tamaño'),
(13471, 5957, 4, 'El tamaño debe ser un número entre 1 y 999'),
(13472, 5958, 4, 'Tamaño/Lista'),
(13473, 5959, 4, 'Piel'),
(13474, 5960, 4, 'Cáncer de Piel'),
(13475, 5961, 4, 'Enfermedad de Piel'),
(13476, 5962, 4, 'Otra Piel'),
(13477, 5963, 4, 'Saltar autorización de Notas de paciente'),
(13478, 5964, 4, 'Saltar sección'),
(13479, 5965, 4, 'Saltarse SQL-Ledger dump - no se han aplicado para el servidor de Windows'),
(13480, 5967, 4, 'Patrones de Sueño'),
(13481, 5968, 4, 'Patrones de Sueño'),
(13482, 5969, 4, 'Durmiendo'),
(13483, 5970, 4, 'Eslovaco'),
(13484, 5972, 4, 'La deuda de SM sin'),
(13485, 5973, 4, 'Smarty caché ha sido borrada'),
(13486, 5974, 4, 'Fumador, estado actual desconocido'),
(13487, 5976, 4, 'Tabaquismo'),
(13488, 5977, 4, 'SMS Autorización'),
(13489, 5978, 4, 'Puerta de enlace SMS'),
(13490, 5979, 4, 'Clave API puerta enlace SMS'),
(13491, 5980, 4, 'Clave API puerta enlace SMS'),
(13492, 5981, 4, 'Contraseña puerta de enlace SMS'),
(13493, 5982, 4, 'Usuario puerta de enlace SMS'),
(13494, 5983, 4, 'Notificación de SMS'),
(13495, 5984, 4, 'Horario Notificación SMS'),
(13496, 5985, 4, 'SMS antes enviado'),
(13497, 5986, 4, 'SMS Enviado'),
(13498, 5987, 4, 'SMS de texto, Etiqueta Utilizable: ***NOMBRE *** *** PROVEEDOR, *** *** FECHA *** *** HORA DE COMIENZO*** , *** HORA DE SALIDA *** *** <br> i.e. Estimado ***NOMBRE ***'),
(13499, 5988, 4, 'SMS/CORREO ELECTRONICO Ajustes Alerta'),
(13500, 5989, 4, 'Contraseña para Autenticación SMTP'),
(13501, 5992, 4, 'SMTP Nombre servidor Host'),
(13502, 5993, 4, 'SMTP Puerto servidor'),
(13503, 5994, 4, 'SMTP Usuario para Autenticación'),
(13504, 5995, 4, 'SNOMED'),
(13505, 5997, 4, 'Diagnóstico SNOMED (RF1)'),
(13506, 5999, 4, 'Diagnóstico SNOMED (RF2)'),
(13507, 6001, 4, 'Base de datos SNOMED'),
(13508, 6002, 4, 'Diagnóstico SNOMED'),
(13509, 6004, 4, 'Ronquidos'),
(13510, 6005, 4, 'SOEP'),
(13511, 6006, 4, 'Dificultades Sociales'),
(13512, 6009, 4, 'Historia'),
(13513, 6010, 4, 'Número de Seguridad Social'),
(13514, 6011, 4, 'solución'),
(13515, 6013, 4, 'Contexto Somático'),
(13516, 6014, 4, 'Algunas autorizaciones no fueron exhibidas. Clic aquí para ver todas'),
(13517, 6015, 4, 'Algunos códigos no fueron exhibidos.'),
(13518, 6016, 4, 'Algunas visitas no fueron mostradas. Click aquí para ver todas.'),
(13519, 6017, 4, 'Se han producido algunos errores en el proceso de De Identificación'),
(13520, 6018, 4, 'Algunas notas no fueron mostradas.'),
(13521, 6020, 4, 'algunas palabras'),
(13522, 6023, 4, 'Algo salió mal. Por favor inténtelo de nuevo.'),
(13523, 6024, 4, 'Intervalo para Vencimiento Próximo (Recordatorios clínicos)'),
(13524, 6025, 4, 'Intervalo vencimiento próximo (Recordatorios paciente)'),
(13525, 6026, 4, 'Dolor de Garganta'),
(13526, 6027, 4, 'Lo siento no se ha fijado una cita'),
(13527, 6028, 4, 'Lo sentimos, hubo un problema subiendo su fichero'),
(13528, 6029, 4, 'Organizado por'),
(13529, 6030, 4, 'Orden por'),
(13530, 6031, 4, 'Organizar por checksum'),
(13531, 6032, 4, 'Ordenar por Comentarios'),
(13532, 6033, 4, 'Ordenar por usuario de Crt'),
(13533, 6034, 4, 'Ordenar por fecha'),
(13534, 6035, 4, 'Ordenar por fecha / hora'),
(13535, 6036, 4, 'Ordenar por Evento'),
(13536, 6037, 4, 'Ordenar por Grupo'),
(13537, 6040, 4, 'Ordenar por pacienteID'),
(13538, 6041, 4, 'ordenar por exito'),
(13539, 6043, 4, 'Ordenar por Usuario'),
(13540, 6044, 4, 'Ordenar por vacuna'),
(13541, 6045, 4, 'Orden descendente'),
(13542, 6046, 4, 'Ordenar resultado por'),
(13543, 6047, 4, 'Orden ascendente'),
(13544, 6048, 4, 'Fuente'),
(13545, 6049, 4, 'Fichero fuente'),
(13546, 6050, 4, 'Ruta fichero fuente'),
(13547, 6051, 4, 'Fuente falta de código '),
(13548, 6052, 4, 'Lote de fuente'),
(13549, 6057, 4, 'Fuente:'),
(13550, 6060, 4, 'Espacio'),
(13551, 6061, 4, 'ESPACIO'),
(13552, 6062, 4, 'Español'),
(13553, 6063, 4, 'Español (Latín América)'),
(13554, 6064, 4, 'Español (España)'),
(13555, 6068, 4, 'Especialista'),
(13556, 6069, 4, 'Nombre y firma del especialista'),
(13557, 6071, 4, 'Especialidad'),
(13558, 6072, 4, 'Sistemas de la especialidad'),
(13559, 6073, 4, 'Especialidad:'),
(13560, 6074, 4, 'Específico'),
(13561, 6075, 4, 'Aplicación específica'),
(13562, 6076, 4, 'Servicio específico anticonceptivo'),
(13563, 6077, 4, 'Resultado especifico'),
(13564, 6078, 4, 'Servicio Específico'),
(13565, 6079, 4, 'Especificado'),
(13566, 6080, 4, 'Formato específico para códigos.#=dígito, *=cualquier caracter. Vacío si no se usa.'),
(13567, 6081, 4, 'Formato específico para códigos.#=dígito, @=alfabético, *=cualquier caracter. Vacío si no se usa.'),
(13568, 6082, 4, 'Formato específico para número de referencia de facturas.#=dígito, *=cualquier caracter. Vacío si no se usa.'),
(13569, 6083, 4, 'Formato específico para número de referencia de facturas.#=dígito, @=alfabético, *=cualquier caracter. Vacío si no se usa.'),
(13570, 6084, 4, 'Formato producto campos NCD. #=dígito, *=cualquier carácter. Vacío si no se usa.'),
(13571, 6085, 4, 'Formato producto campos NCD. #=dígito, @=alfabético, *=cualquier carácter. Vacío si no se usa.'),
(13572, 6086, 4, 'Formato ID paciente externo.#=dígito,*=cualquier carácter. Vacío si no se usa.'),
(13573, 6087, 4, 'Formato ID paciente externo.#=dígito, @=Alfabético, *=cualquier carácter. Vacío si no se usa.'),
(13574, 6088, 4, 'Especimen'),
(13575, 6089, 4, 'Especimen numero/Identificador'),
(13576, 6090, 4, 'Tipo de especimen'),
(13577, 6092, 4, 'Dictado'),
(13578, 6093, 4, 'Espermicidas'),
(13579, 6094, 4, 'Esplenectomía'),
(13580, 6095, 4, 'Esposa'),
(13581, 6097, 4, 'Esputo'),
(13582, 6098, 4, 'Esputo:'),
(13583, 6099, 4, 'SQ'),
(13584, 6102, 4, 'Equipo'),
(13585, 6103, 4, 'Miembro de Equipo'),
(13586, 6104, 4, 'Equipos'),
(13587, 6105, 4, 'SRH'),
(13588, 6106, 4, 'SRH - Planificación de la Familia'),
(13589, 6107, 4, 'SRH no de Planificación de la Familia'),
(13590, 6108, 4, 'SRH Referencias'),
(13591, 6109, 4, 'formulario de la visita del SRH'),
(13592, 6110, 4, 'Fecha servicio'),
(13593, 6111, 4, 'SS'),
(13594, 6112, 4, 'Certificado de Administracion SSL'),
(13595, 6113, 4, 'Nº SS'),
(13596, 6114, 4, 'comienzo'),
(13597, 6115, 4, 'Versiones preparadas'),
(13598, 6116, 4, 'Estándar'),
(13599, 6117, 4, 'Codigo usual'),
(13600, 6118, 4, 'Medidas estándar'),
(13601, 6122, 4, 'Nombre estándar'),
(13602, 6124, 4, 'Comienzo'),
(13603, 6125, 4, 'Comienzo (aaaa-mm-dd): '),
(13604, 6128, 4, 'Fecha de Comienzo:'),
(13605, 6129, 4, 'Fecha de inicio en esta clínica'),
(13606, 6130, 4, 'Fecha de inicio no debe ser mayor que la fecha final'),
(13607, 6131, 4, 'Fecha de comienzo:'),
(13608, 6132, 4, 'Fecha de Comienzo:'),
(13609, 6133, 4, 'Hora de Comienzo'),
(13610, 6134, 4, 'Fecha de comienzo'),
(13611, 6135, 4, 'Estado'),
(13612, 6136, 4, 'Estado'),
(13613, 6137, 4, 'Tipo de datos estado'),
(13614, 6138, 4, 'Nro. licencia estatal'),
(13615, 6139, 4, 'Nro. licencia estatal'),
(13616, 6140, 4, 'Lista estados'),
(13617, 6141, 4, 'Lista de estados (escriba, sólo añadir opcional)'),
(13618, 6142, 4, 'Lista de estados de los campos Widget personalizados'),
(13619, 6143, 4, 'Estado o Provincia'),
(13620, 6144, 4, 'Estado/lugar'),
(13621, 6145, 4, 'Estado/Parroquia'),
(13622, 6146, 4, 'RESUMEN SUMARIO'),
(13623, 6147, 4, 'extractos y facturas de actualización.'),
(13624, 6148, 4, 'Declaraciones enviadas:n'),
(13625, 6149, 4, 'extractos, facturas no seran actualizadas'),
(13626, 6150, 4, 'Texto estático'),
(13627, 6151, 4, 'Estadísticas'),
(13628, 6152, 4, 'Estados'),
(13629, 6153, 4, 'Estado'),
(13630, 6156, 4, 'Estable'),
(13631, 6158, 4, 'Asesoramiento de ETS/SIDA'),
(13632, 6159, 4, 'Fuerza y Acondicionamiento');
INSERT INTO `lang_definitions` VALUES
(13633, 6164, 4, 'Pasos para instalar la bbdd DSM IV'),
(13634, 6165, 4, 'Pasos para instalar la bbdd ICD 10'),
(13635, 6166, 4, 'Pasos para instalar la bbdd ICD 9'),
(13636, 6167, 4, 'Pasos para instalar la bbdd RxNorm'),
(13637, 6168, 4, 'Pasos para instalar la bbdd Snomed'),
(13638, 6169, 4, 'Coyunturas Tiesas'),
(13639, 6170, 4, 'Tiesura'),
(13640, 6171, 4, 'Meses de Reservas'),
(13641, 6172, 4, 'Dolores de Estómago'),
(13642, 6174, 4, 'Hash almacenado'),
(13643, 6175, 4, 'Tensión del músculo'),
(13644, 6176, 4, 'Corriente'),
(13645, 6177, 4, 'Calle'),
(13646, 6178, 4, 'Calle de direccion'),
(13647, 6179, 4, 'Calle y Número'),
(13648, 6180, 4, 'Fuerza'),
(13649, 6182, 4, 'Estrep Garganta'),
(13650, 6183, 4, 'Fractura de Estrés'),
(13651, 6184, 4, 'Prueba de Estrés'),
(13652, 6185, 4, 'Derrame Cerebral'),
(13653, 6186, 4, 'Contraseña segura significa al menos 8 caracteres, y que al menos tres sean: un número, una minúscula, una mayúscula, un carácter especial.'),
(13654, 6188, 4, 'Estilo del formulario usado para añadir nuevos pacientes'),
(13655, 6189, 4, 'Sub-categoría'),
(13656, 6190, 4, 'Sub-Total'),
(13657, 6191, 4, 'Subcategoria'),
(13658, 6192, 4, 'subcategoria'),
(13659, 6193, 4, 'Subcutáneo'),
(13660, 6194, 4, 'Asunto'),
(13661, 6195, 4, 'Subjetivo'),
(13662, 6196, 4, 'Sublingual'),
(13663, 6197, 4, 'sublingual'),
(13664, 6198, 4, 'Enviar'),
(13665, 6199, 4, 'Enviar'),
(13666, 6200, 4, 'Enviar todo el contenido'),
(13667, 6202, 4, 'Enviar Evento'),
(13668, 6203, 4, 'Enviar Formulario'),
(13669, 6204, 4, 'Enviar contenido elegido'),
(13670, 6205, 4, 'Enviado'),
(13671, 6206, 4, 'Sometido por'),
(13672, 6207, 4, 'Numero de acceso EDI del Enviador (PER06)'),
(13673, 6208, 4, 'Suscriptor'),
(13674, 6209, 4, 'Dirección del Suscriptor'),
(13675, 6213, 4, 'empleador suscriptor'),
(13676, 6214, 4, 'empleador suscriptor (SE)'),
(13677, 6215, 4, 'Dirección del empleador suscriptor'),
(13678, 6216, 4, 'Ciudad del empleador suscriptor'),
(13679, 6217, 4, 'País del empleador suscriptor'),
(13680, 6218, 4, 'Estado del empleador suscriptor'),
(13681, 6221, 4, 'Código postal del empleador suscriptor'),
(13682, 6225, 4, 'Teléfono de Suscriptor'),
(13683, 6226, 4, 'Relación con el Suscriptor'),
(13684, 6227, 4, '¡La relación del suscriptor no con sí mismo pero el nombre es igual! ¿Es esto realmente ACEPTABLE?'),
(13685, 6228, 4, '¡La relación del suscriptor no es con sí mismo pero el número de SS es igual!'),
(13686, 6229, 4, '¡La relación del suscriptor es con sí mismo pero el nombre es diferente! ¿Es esto realmente ACEPTABLE?'),
(13687, 6230, 4, '¡La relación del suscriptor es con sí mismo pero el número de SS es diferente!'),
(13688, 6231, 4, 'Sexo de Suscriptor'),
(13689, 6237, 4, 'Sustituto'),
(13690, 6238, 4, 'sustituto permitido'),
(13691, 6240, 4, 'Exito'),
(13692, 6241, 4, 'éxito'),
(13693, 6242, 4, 'Confirmación de la recepción de resultados del laboratorio'),
(13694, 6243, 4, 'Confirmación obtención resultados de laboratorio'),
(13695, 6244, 4, 'Éxito obteniendo los resultados de la Red de Intercambio del Laboratorio'),
(13696, 6246, 4, 'Categoría añadida correctamente'),
(13697, 6247, 4, 'agregado con éxito a la categoría,'),
(13698, 6248, 4, 'Borrado completado'),
(13699, 6250, 4, 'Instalado en Base Datos completado'),
(13700, 6251, 4, 'La siguiente bbdd ha sido instalada correctamente'),
(13701, 6252, 4, 'Modificación Completada'),
(13702, 6253, 4, 'Correctamente salvado. ¿Le gustaría asignarlo?'),
(13703, 6254, 4, 'Correctamente salvado. ¿Le gustaría distribuir?'),
(13704, 6256, 4, 'almacenado con éxito.'),
(13705, 6257, 4, 'Base de datos actualizada correctamente.'),
(13706, 6258, 4, 'La siguiente bbdd ha sido actualizada correctamente'),
(13707, 6259, 4, 'con éxito.'),
(13708, 6260, 4, 'Suicidio'),
(13709, 6261, 4, 'Resumen'),
(13710, 6262, 4, 'Sumario de'),
(13711, 6265, 4, 'Domingo'),
(13712, 6267, 4, 'Domingo'),
(13713, 6268, 4, 'Supercuenta'),
(13714, 6269, 4, 'Códigos de supercuenta'),
(13715, 6270, 4, 'Administración de códigos de supercuenta'),
(13716, 6271, 4, 'Reportes de supercuenta'),
(13717, 6272, 4, 'Supercuenta/Hoja de precios'),
(13718, 6273, 4, 'Supercuentas'),
(13719, 6274, 4, 'Supercuentas, llamado a veces Formularios de Encuentros u hojas de ruta, son una parte esencial en la mayoría de los centros médicos.'),
(13720, 6275, 4, 'Superusuario'),
(13721, 6276, 4, 'Supervisando'),
(13722, 6278, 4, 'Dr.Supervisor DEA'),
(13723, 6279, 4, 'Primer Nombre Doctor Supervisor'),
(13724, 6280, 4, 'Apellido Doctor Supervisor'),
(13725, 6281, 4, 'Dr.Supervisor NPI'),
(13726, 6282, 4, 'Dr.Supervisor UPIN'),
(13727, 6283, 4, 'Nombre del centro proveedor'),
(13728, 6284, 4, 'Soporte de los eventos de calendario que se aplican a múltiples facultativos'),
(13729, 6285, 4, 'Soporte configuración de datos de importación/exportación a través de la página de backup'),
(13730, 6286, 4, 'Soporte eventos multi-facultativo'),
(13731, 6288, 4, 'Soporta sólo enciptación/desencriptación TripleDES'),
(13732, 6289, 4, 'Tipo de Superficie'),
(13733, 6290, 4, 'Cirugías'),
(13734, 6291, 4, 'Cirugía'),
(13735, 6293, 4, 'Suspendido'),
(13736, 6294, 4, 'suspensión'),
(13737, 6295, 4, 'Svc Fecha'),
(13738, 6296, 4, 'Svc Fecha:'),
(13739, 6299, 4, 'Sudoración:'),
(13740, 6300, 4, 'Sueco'),
(13741, 6301, 4, 'Hinchazón'),
(13742, 6302, 4, 'Hinchazón a la Derecha'),
(13743, 6303, 4, 'Articulaciones Inflamadas'),
(13744, 6304, 4, 'Inflamación de los ganglios linfáticos'),
(13745, 6305, 4, 'Símbolo usado como punto decimal para moneda. No usado si los decimales son 0.'),
(13746, 6306, 4, 'Símbolo usado para separar miles en moneda.'),
(13747, 6307, 4, 'Síntomas'),
(13748, 6308, 4, 'Sincronizar'),
(13749, 6309, 4, 'Sincronizar traducción con la tabla de idioma del cliente'),
(13750, 6310, 4, 'Sincronizado constante de nuevo cliente:'),
(13751, 6311, 4, 'Sincronizar nuevo idioma cliente'),
(13752, 6312, 4, 'Sincronizado nueva definición (Idioma, Constante, Definición):'),
(13753, 6313, 4, 'Síncope'),
(13754, 6314, 4, 'Vigilancia de Síndrome'),
(13755, 6315, 4, 'Vigilancia síndrome - Sin problemas notificados'),
(13756, 6316, 4, 'Reporte de vigilancia de Sindromes'),
(13757, 6317, 4, 'Sinovitis, pinzamiento, bursitis'),
(13758, 6318, 4, 'Sistema'),
(13759, 6322, 4, 'T'),
(13760, 6323, 4, 't.i.d.'),
(13761, 6324, 4, 'T.V.'),
(13762, 6325, 4, 'Tabla'),
(13763, 6327, 4, 'La creación de la tabla falló'),
(13764, 6328, 4, 'La actualización de la tabla falló'),
(13765, 6330, 4, 'tableta'),
(13766, 6332, 4, 'Tagalog'),
(13767, 6335, 4, 'Tomar'),
(13768, 6336, 4, 'Escoger seguro, en el desplegable'),
(13769, 6337, 4, 'Escoger forma de pago, en el desplegable'),
(13770, 6338, 4, 'Recogida'),
(13771, 6339, 4, 'Toma tiempo'),
(13772, 6340, 4, 'Altura del área de navegación'),
(13773, 6347, 4, 'Fecha límite'),
(13774, 6351, 4, 'Objetivo/Grupos de Acción'),
(13775, 6354, 4, 'N.I.F./C.I.F.'),
(13776, 6355, 4, 'Tasa de Impuestos'),
(13777, 6356, 4, 'Impuestos'),
(13778, 6357, 4, 'Taxonomía'),
(13779, 6358, 4, 'TD'),
(13780, 6359, 4, 'Descripción de lesión del equipo'),
(13781, 6360, 4, 'Lista del Equipo'),
(13782, 6361, 4, 'Ver Lista de Equipo'),
(13783, 6362, 4, 'Equipo/Plantilla'),
(13784, 6363, 4, 'Tel'),
(13785, 6364, 4, 'Código País telefónico'),
(13786, 6366, 4, 'Temp'),
(13787, 6367, 4, 'Localización de la toma de temperat.'),
(13788, 6368, 4, 'Método para Temperat.'),
(13789, 6369, 4, 'Temperatura'),
(13790, 6370, 4, 'Plantilla'),
(13791, 6371, 4, 'Nombre de Plantilla'),
(13792, 6372, 4, 'Los nombres de la plantilla no pueden comenzar con números.'),
(13793, 6373, 4, 'Plantilla:'),
(13794, 6374, 4, 'Pantillas'),
(13795, 6375, 4, 'Arteria Temporal'),
(13796, 6376, 4, 'Daño al tendón'),
(13797, 6377, 4, 'Tendonitis / osis / bursitis'),
(13798, 6378, 4, 'Nºreferencia factura provisional'),
(13799, 6379, 4, 'Terciario'),
(13800, 6380, 4, 'Seguro Terciario'),
(13801, 6381, 4, 'Datos terciarios del seguro'),
(13802, 6382, 4, 'Proveedor terciario del seguro'),
(13803, 6383, 4, 'Programación de Prueba'),
(13804, 6384, 4, 'Sistema de Prueba'),
(13805, 6385, 4, 'Texto'),
(13806, 6386, 4, 'Texto Diagnóstico'),
(13807, 6387, 4, 'campo texto'),
(13808, 6393, 4, 'Fecha del texto'),
(13809, 6394, 4, 'texto actualizado'),
(13810, 6395, 4, 'Area de texto'),
(13811, 6396, 4, 'erea de texto'),
(13812, 6397, 4, 'Cuadro de texto'),
(13813, 6398, 4, 'caja de texto'),
(13814, 6399, 4, 'Lista del cuadro de texto'),
(13815, 6400, 4, 'lista de texto'),
(13816, 6401, 4, 'Tailandés'),
(13817, 6402, 4, 'Gracias'),
(13818, 6403, 4, 'Gracias por elegir'),
(13819, 6404, 4, 'El botón ''Limpiar'' eliminará todas las anotaciones.'),
(13820, 6405, 4, 'Falló la declaración anterior'),
(13821, 6406, 4, 'Llave publica y Certificado del Servidor Apache SSL'),
(13822, 6407, 4, 'El certificado de Autoridad Certificada'),
(13823, 6408, 4, 'El fichero de ación: '),
(13824, 6410, 4, 'La llave privada correspondiente'),
(13825, 6413, 4, 'El código de denegación es'),
(13826, 6414, 4, 'El código del grupo denegación es'),
(13827, 6415, 4, 'El formulario de destino está cerrado'),
(13828, 6416, 4, 'El formulario de destino estaba cerrado. No puedo actuar en su selección.'),
(13829, 6422, 4, 'El evento(s) han sido aprobadas.'),
(13830, 6423, 4, 'Se han ocultado el evento(s).'),
(13831, 6424, 4, 'Los datos exportados aparece en el área de texto a continuación. Puede copiarla y pegarla en un mensaje de correo electrónico o cualquier otro destino.'),
(13832, 6426, 4, 'Los datos exportados aparece en el área de texto a continuación. Puede copiarla y pegarla en un mensaje de correo electrónico o cualquier otro destino.'),
(13833, 6427, 4, 'Los datos exportados aparecen en el área de texto de abajo. Puede copiar y pegar en el mail o cualquier otro destino deseado.'),
(13834, 6428, 4, 'El no puede salvarse en CouchDB.'),
(13835, 6429, 4, 'El fichero puede no estar correctamente renombrado, este error está normalmente relacionado con problemas de permiso en el sistema de almacenamiento.'),
(13836, 6430, 4, 'El fichero no ha sido archivado correctamente'),
(13837, 6433, 4, 'El primer paso es abrir una cuenta en el sitio web Unified Medical Language System'),
(13838, 6434, 4, 'Los siguientes eventos del calendario, se ha añadido:'),
(13839, 6435, 4, 'Los siguientes eventos del calendario ha sido modificada:'),
(13840, 6436, 4, 'Las siguentes categorías serán eliminadas de su lista de categorías'),
(13841, 6437, 4, 'La siguiente versión de la base de datos está actualmente instalada'),
(13842, 6439, 4, 'El siguiente fichero EDI ha sido subido'),
(13843, 6440, 4, 'El inicio sesión de usuario de emergencia siguiente esta activado:'),
(13844, 6441, 4, 'Los errores siguientes ocurrieron'),
(13845, 6444, 4, 'Los campos soguientes son requeridos'),
(13846, 6446, 4, 'Los siguientes campos tienen que estar rellenos para enviar la solicitud.'),
(13847, 6449, 4, 'Nombre del Host de la máquina repositoria auditoría ATNA'),
(13848, 6450, 4, 'La pantalla inicial es la página de búsqueda de la factura. En la parte superior puede introducir un dato (ej. número de cheque), fecha de pago e importe del cheque. El motivo del dato y la fecha de pago es para que no tenga que introducir una y otra vez para cada reclamo. La cantidad que usted introduzca será disminuido por cada factura que tenga pago parcial, y se espera que acabará en cero cuando haya terminado.'),
(13849, 6451, 4, 'Se necesita crear directorio de instalacion'),
(13850, 6454, 4, 'La versión instalada y los ficheros preparados son iguales.'),
(13851, 6455, 4, 'La versión instalada es más reciente que los ficheros preparados.'),
(13852, 6456, 4, 'La etiqueta que se muestra al usuario en el formulario'),
(13853, 6457, 4, 'La longitud no debe exceder el siguiente número de caracteres'),
(13854, 6460, 4, 'La nueva categoría será una subcategoría de '),
(13855, 6461, 4, 'La nueva contraseña no puede ser la misma que la actual.'),
(13856, 6462, 4, 'Las contraseñas no son iguales'),
(13857, 6464, 4, 'El número de ficheros preparados es incorrecto. Sólo coloque los ficheros que quiera instalar/actualizar.'),
(13858, 6465, 4, 'La página será redirigida a demográficos. Puede editar el campo de país y click a través de NewCrop de nuevo.'),
(13859, 6466, 4, 'La contraseña debe tener al menos ocho caracteres, y debe'),
(13860, 6468, 4, 'La solicitud de registro del paciente ha sido registrada.'),
(13861, 6469, 4, 'Los recordatorios del paciente han sido enviados'),
(13862, 6470, 4, 'Los recordatorios del paciente han sido actualizados'),
(13863, 6472, 4, 'Los pagos enviados no pueden ser antes de esta fecha. Esto asegura que después del informe final nadie puede enviar fechas anteriores.'),
(13864, 6474, 4, 'Los datos crudos pueden obtenerse de:'),
(13865, 6475, 4, 'La información restante abajo se aplica solamente si usted está fijando manualmente, o si usted está haciendo correcciones manuales.'),
(13866, 6477, 4, 'El documento solicitado no está presente en el lugar previsto en el sistema de ficheros o no hay suficientes permisos para acceder a ella.'),
(13867, 6480, 4, 'Las columnas de la fuente y de fecha se copian de la primera página, por lo que normalmente no será necesario que los toque. Usted puede poner una cantidad del pago en la columna de pagos, una cantidad de ajuste en la columna de ajuste, o ambas. Puede también hacer clic en " W" a la derecha de computar automáticamente un ajuste valorar que escriba del resto de la carga para esa línea artículo.'),
(13868, 6481, 4, 'La versión de todos los ficheros preparados no es la misma.'),
(13869, 6482, 4, 'La revisión de todos los ficheros preparados no es la misma.'),
(13870, 6484, 4, 'La división temporal del calendario y el menor intervalo en minutos para una ranura de cita.'),
(13871, 6485, 4, 'La etiqueta traducida que aparecerá en la forma en lengua actual'),
(13872, 6486, 4, 'El título traducido que aparecerá en lengua actual'),
(13873, 6487, 4, 'La traducción de descripción en lengua actual'),
(13874, 6488, 4, 'La tabla de traducción está sincronizada'),
(13875, 6489, 4, 'Tipo de esta entidad'),
(13876, 6490, 4, 'El código de identificación específico del proveedor de este procedimiento o el resultado'),
(13877, 6491, 4, 'Los ficheros X12, así como la salida de informes HTML resultantes son archivados en el subdirectorio -era- del directorio principal de la instalación de LibreEHR. Si quiere hacer referencia a estos ficheros de vez en cuando. La URL es'),
(13878, 6492, 4, 'El file comprimido ha de contener los siguientes items'),
(13879, 6493, 4, 'Tema'),
(13880, 6495, 4, 'Inyecciones Terapéuticas'),
(13881, 6496, 4, 'Existen'),
(13882, 6497, 4, 'Actualmente no hay recetas'),
(13883, 6498, 4, 'Hay errores con su sumisión. estos se contornean abajo.'),
(13884, 6500, 4, 'No hay registros sacados'),
(13885, 6501, 4, 'No hay revelaciones de info grabadas para este paciente.'),
(13886, 6502, 4, 'No hay nuevas sumisiones'),
(13887, 6503, 4, 'No hay notas en el file para este paciente'),
(13888, 6504, 4, 'No hay transacciones archivadas para ese paciente'),
(13889, 6505, 4, 'Se ha producido un error al enviar correo a'),
(13890, 6506, 4, 'Ya existe una categoria nombrada'),
(13891, 6507, 4, 'Ya existe una subcategoria nombrada'),
(13892, 6508, 4, 'Ya existe un item nombrado'),
(13893, 6509, 4, 'Ya está abierto el registro de paciente solicitado.'),
(13894, 6510, 4, 'No hay entrada de COA para la cuenta de AR '),
(13895, 6511, 4, 'No hay entrada de COA para la cuenta de efectivo '),
(13896, 6512, 4, 'No hay entrada de COA para la cuenta de ingresos '),
(13897, 6513, 4, 'El paciente actual no existe'),
(13898, 6515, 4, 'No hay identificacion igual de la factura'),
(13899, 6516, 4, 'No hay identificacion igual de la factura = '),
(13900, 6517, 4, 'No hay partes de entrada para los servicios de identificación '),
(13901, 6520, 4, 'Se ha producido un error mientras se procesaba su solicitud.'),
(13902, 6522, 4, 'Estos son los enlaces de 2012'),
(13903, 6523, 4, 'Espesado a la derecha:'),
(13904, 6524, 4, 'Muslo'),
(13905, 6525, 4, 'Muslo + tendón de la corva'),
(13906, 6527, 4, 'Cosas que la oficina trasera puede leer y entrar pero no modificar'),
(13907, 6528, 4, 'Things that back office can read and modify'),
(13908, 6531, 4, 'Cosas que los clínicos pueden leer y entrar pero no modificar'),
(13909, 6532, 4, 'Cosas que los clinicos pueden leer y modificar'),
(13910, 6535, 4, 'Cosas que la oficina central puede leer y entrar pero no modificar'),
(13911, 6536, 4, 'Cosas que la oficina central puede leer y modificar'),
(13912, 6539, 4, 'Cosas que los médicos pueden entrar y leer pero no modificar'),
(13913, 6540, 4, 'Cosas que los médicos pueden leer y modificar'),
(13914, 6542, 4, 'Tercera'),
(13915, 6544, 4, 'Esta acción NO SE PUEDE deshacer.'),
(13916, 6545, 4, 'Esta acción no se puede deshacer.'),
(13917, 6547, 4, 'Esta acción se registrará'),
(13918, 6549, 4, 'El espacio para la cita está ocupado, ¿usarlo de todas formas?'),
(13919, 6550, 4, 'Este espacio para cita no está disponible, por favor elegir otro.'),
(13920, 6551, 4, 'Este año de calendario'),
(13921, 6552, 4, 'Este reclamo ha sido cancelado.'),
(13922, 6553, 4, 'La reclamación ha sido cerrada.'),
(13923, 6554, 4, 'La reclamación ha sido denegada. Razón:-'),
(13924, 6555, 4, 'La reclamación ha sido enviada a otro nivel'),
(13925, 6556, 4, 'Este tipo de código no acepta las relaciones.'),
(13926, 6557, 4, 'Este contexto contiene categorias, las cuales serán borradas. ¿Quiere continuar?'),
(13927, 6558, 4, 'Esto determina como se visualizarán las citas en el calendario.'),
(13928, 6559, 4, 'Esto determina como será el esquema de color usado para las citas'),
(13929, 6561, 4, 'Esta Visita'),
(13930, 6562, 4, 'Esta visita ha sido facturada. Si necesita cambiarlo, debe ser re-abierta.'),
(13931, 6564, 4, 'Esta caracteristica ya no está disponible'),
(13932, 6565, 4, 'Este atributo es experimental y no probado. Use a riesgo propio.'),
(13933, 6566, 4, 'Este número de factura se ha cambiado a '),
(13934, 6572, 4, 'esta ubicación'),
(13935, 6575, 4, 'Este módulo está en modo de prueba. La base de datos no será cambiada.'),
(13936, 6576, 4, 'Este módulo promueve la entrada eficiente de los datos de EOB.'),
(13937, 6577, 4, 'Este mes a fecha'),
(13938, 6579, 4, 'Esta página le permite revisar cada uno de los dataloads externos compatibles que puede instalar y actualizar. Cada sección de abajo se puede ampliar haciendo clic en la cabecera de sección para revisar el estado de interés de la bbdd.'),
(13939, 6581, 4, 'En esta página se incluye en línea la página de inicio de sesión, de modo que no tenemos que hacer clic en iniciar la sesión cada vez.'),
(13940, 6582, 4, 'Este paciente no tiene ninguna actividad.'),
(13941, 6583, 4, 'Este Nº Identificación de paciente ya está en uso!'),
(13942, 6584, 4, 'Este producto solo permite un lote por deposito'),
(13943, 6586, 4, 'Este informe actualmente sólo funciona para códigos ICD9.'),
(13944, 6591, 4, 'Este paso generará un fichero el cual salvará para uso futuro. El fichero no se puede generar de nuevo. ¿Quiere proceder?'),
(13945, 6592, 4, 'Este usuario no es miembro de ningún grupo'),
(13946, 6595, 4, 'Esta visita comienza nuevo uso anticonceptivo'),
(13947, 6596, 4, 'Esta visita necesitará un formulario GCAC, derivación o procedimiento de servicio.'),
(13948, 6597, 4, 'Esta fue la métrica más antigua de formularios de constantes vitales, ahora en desuso.'),
(13949, 6598, 4, 'Esta semana a fecha'),
(13950, 6600, 4, 'Esto activará informes CCR(Continuity of Care Record) y CCD(Continuity of Care Document)'),
(13951, 6602, 4, 'Esto permitirá la selección de la depuración (''dummy'') de idioma.'),
(13952, 6606, 4, 'Esto creará un backup en formato tar y luego lo envia a su navegador web para que lo pueda guardar'),
(13953, 6607, 4, 'Esto desactivará las características de encriptación/desencriptación del documento, y lo ocultará en el UI.'),
(13954, 6613, 4, 'Esto forzará el widget de facturación en la pantalla resumen del paciente para que se abra siempre.'),
(13955, 6617, 4, 'Esto no le impiderá ir al sitio de recetas electrónicas.'),
(13956, 6619, 4, 'Esto usará la lista de vacunación personalizada en lugar de la lista de vacunación estándar CVX.'),
(13957, 6622, 4, 'Espina dorsal torácica'),
(13958, 6623, 4, 'Miles/CU.MM'),
(13959, 6625, 4, 'Garganta'),
(13960, 6626, 4, 'Cáncer de Garganta'),
(13961, 6627, 4, 'Cirugía del Cáncer de Garganta'),
(13962, 6628, 4, 'Trombosis/Derrame Cerebral'),
(13963, 6629, 4, 'Jueves'),
(13964, 6630, 4, 'Jueves'),
(13965, 6631, 4, 'Jueves'),
(13966, 6632, 4, 'Tiroides normal'),
(13967, 6633, 4, 'Problemas de la Tiroides'),
(13968, 6634, 4, 'TIA'),
(13969, 6638, 4, 'Hora'),
(13970, 6639, 4, 'Formato visualización de hora'),
(13971, 6640, 4, 'Incremento de tiempo para agregar (minutos 1-60)'),
(13972, 6641, 4, 'Seleccion de tiempo'),
(13973, 6642, 4, 'La ventana de tiempo está abierta, salvando evento'),
(13974, 6647, 4, 'Evento con horario'),
(13975, 6648, 4, 'Matriz tiempos (NO APLICABLE)'),
(13976, 6649, 4, 'Reloj fechador y texto'),
(13977, 6650, 4, 'TIN'),
(13978, 6651, 4, 'Tinnitus'),
(13979, 6652, 4, 'Titulo'),
(13980, 6653, 4, 'Titulo V'),
(13981, 6654, 4, 'Cols título debe ser un número entre 1 y 999'),
(13982, 6655, 4, 'Títulos'),
(13983, 6656, 4, 'TM''S:'),
(13984, 6657, 4, 'TMs/EAMs/EE, ext nariz'),
(13985, 6658, 4, 'Para'),
(13986, 6659, 4, 'PARA'),
(13987, 6660, 4, 'para'),
(13988, 6661, 4, 'Hacia la ruta absoluta del file'),
(13989, 6662, 4, 'Favor Selecciona para agregar notas '),
(13990, 6663, 4, 'Para añadir notas, por favor haga click aquí'),
(13991, 6664, 4, 'Área afectada'),
(13992, 6665, 4, 'área afectada'),
(13993, 6666, 4, 'Para abrir automáticamente el formulario específico. Algunos equipos deportivos usan aquí auditoria de fútbol.'),
(13994, 6667, 4, 'Ver facturación'),
(13995, 6668, 4, 'a la categoría'),
(13996, 6669, 4, 'Ver Clínica'),
(13997, 6670, 4, 'De copago'),
(13998, 6672, 4, 'Para ded''ble'),
(13999, 6673, 4, 'Ir Demograf.'),
(14000, 6674, 4, 'Para deshabilitar certificado del cliente SSL, comente en lineas de arriba en la configuracion del file Apache y configurar'),
(14001, 6675, 4, 'Para deshabilitar HTTPS, comente en lineas de arriba en el file de configuracion de Apache y reiniciar el servidor Apache'),
(14002, 6676, 4, 'Para habilitar lado del cliente certificados SSL'),
(14003, 6677, 4, 'Para habilitar lado del cliente con certificados de Autenticacion SSL, debe habilitarse HTTPS'),
(14004, 6678, 4, 'Para solo habilitar HTTPS, ejecute los cambios mencionados y reinicie el servidor Apache'),
(14005, 6679, 4, 'Para Enctr'),
(14006, 6680, 4, 'Para filtrar por sexo'),
(14007, 6681, 4, 'La Historia'),
(14008, 6682, 4, 'Para cuestiones'),
(14009, 6683, 4, 'Para ligar este encuentro/consulta a un asunto existente, pinche el '),
(14010, 6684, 4, 'Para enlazar este encuentro / consultar a un problema, haga clic en el tema de arriba para destacar y, a continuación, haga clic en [Guardar]. Mantenga pulsada la tecla [Ctrl] para seleccionar múltiples cuestiones.'),
(14011, 6685, 4, 'volver a iniciar sesión'),
(14012, 6686, 4, 'Para grabar revelaciones de info, por favor click'),
(14013, 6687, 4, 'Para Ejecutar'),
(14014, 6688, 4, 'Para configurar el acceso https con autenticación de certificados de cliente, haga lo siguiente'),
(14015, 6689, 4, 'Para la piel'),
(14016, 6690, 4, 'para la piel'),
(14017, 6691, 4, '¿a esta visita?'),
(14018, 6693, 4, 'Hasta:'),
(14019, 6694, 4, 'Hasta: '),
(14020, 6695, 4, 'PARA_CIUDAD'),
(14021, 6696, 4, 'PARA_FAX'),
(14022, 6697, 4, 'PARA_NOMBRE'),
(14023, 6698, 4, 'PARA_APELLIDO'),
(14024, 6699, 4, 'PARA_SEGUNDONOMBRE'),
(14025, 6700, 4, 'PARA_ORGANIZACIÓN'),
(14026, 6703, 4, 'PARA_POSTAL'),
(14027, 6704, 4, 'PARA_ESTADO'),
(14028, 6705, 4, 'PARA_CALLE'),
(14029, 6706, 4, 'PARA_TÍTULO'),
(14030, 6707, 4, 'PARA_DESPEDIDA'),
(14031, 6708, 4, 'Tabaco'),
(14032, 6709, 4, 'Intervención para dejar el tabaco'),
(14033, 6710, 4, 'Intervención para dejar el tabaco (GCC)'),
(14034, 6712, 4, 'Consumo de tabaco'),
(14035, 6713, 4, 'Evaluación consumo tabaco'),
(14036, 6714, 4, 'Evaluación consumo tabaco (GCC)'),
(14037, 6715, 4, 'Hoy'),
(14038, 6716, 4, 'HOY'),
(14039, 6717, 4, 'hoy'),
(14040, 6718, 4, 'Balance actual'),
(14041, 6719, 4, 'Cargos actuales'),
(14042, 6720, 4, 'Fecha de Hoy'),
(14043, 6721, 4, 'Eventos de Hoy'),
(14044, 6726, 4, 'Tonsilectomía'),
(14045, 6728, 4, 'Superior'),
(14046, 6730, 4, 'Tema'),
(14047, 6731, 4, 'Total'),
(14048, 6732, 4, 'total'),
(14049, 6733, 4, 'Total acciones activas'),
(14050, 6734, 4, 'Total recordatorios activos después de actualizar'),
(14051, 6735, 4, 'Total recordatorios activos antes de actualizar'),
(14052, 6737, 4, 'Total de cantidad adeudada'),
(14053, 6738, 4, 'Cantidad total pagada'),
(14054, 6740, 4, 'Total carga'),
(14055, 6741, 4, 'Total de cargos'),
(14056, 6742, 4, 'Total de Clientes'),
(14057, 6743, 4, 'Costo total'),
(14058, 6744, 4, 'La distribución total para los siguientes números de cheque es incompleta'),
(14059, 6745, 4, 'total entradas'),
(14060, 6746, 4, 'Total recordatorios enviados vía email fallidos'),
(14061, 6747, 4, 'Total recordatorios enviados vía teléfono fallidos'),
(14062, 6748, 4, 'Total para'),
(14063, 6749, 4, 'Total para '),
(14064, 6750, 4, 'Total para la categoría'),
(14065, 6751, 4, 'Total recordatorios inactivos'),
(14066, 6752, 4, 'Total nuevos recordatorios'),
(14067, 6753, 4, 'Número total de citas'),
(14068, 6755, 4, 'NºTotal de vacunas'),
(14069, 6756, 4, 'NºTotal de incidencias'),
(14070, 6758, 4, 'Total número de pacientes'),
(14071, 6760, 4, 'Saldo total de pacientes'),
(14072, 6761, 4, 'Total Pacientes'),
(14073, 6764, 4, 'Total Registros Encontrados'),
(14074, 6765, 4, 'Total SRH & Planificación Familiar'),
(14075, 6766, 4, 'Total recordatorios enviados via email correctos'),
(14076, 6767, 4, 'Total recordatorios enviados via teléfono correctos'),
(14077, 6770, 4, 'Total de recordatorios sin cambios'),
(14078, 6771, 4, 'Total recordatorios no enviados después del proceso de envío'),
(14079, 6772, 4, 'Total recordatorios no enviados después de actualizar'),
(14080, 6773, 4, 'Total recordatorios no enviados antes del proceso de envío'),
(14081, 6774, 4, 'Total recordatorios no enviados antes de actualizar'),
(14082, 6775, 4, 'Total recordatorios actualizados'),
(14083, 6776, 4, 'Total'),
(14084, 6777, 4, 'Total para'),
(14085, 6778, 4, 'Total para '),
(14086, 6780, 4, 'para{{rango}}'),
(14087, 6785, 4, 'Tipo de Entrenamiento'),
(14088, 6786, 4, 'Tramite'),
(14089, 6787, 4, 'Transacción'),
(14090, 6788, 4, 'transacción'),
(14091, 6789, 4, 'Transaccion fallida, cantidad insuficiente en lote de destino'),
(14092, 6790, 4, 'Transaccion fallida, cantidad es menor de cero'),
(14093, 6791, 4, 'Tipo de Transacción'),
(14094, 6792, 4, 'transacciones'),
(14095, 6793, 4, 'Transacción'),
(14096, 6794, 4, 'Transacciones (escriba opcional)'),
(14097, 6795, 4, 'Transacciones/Derivados'),
(14098, 6797, 4, 'Transferir'),
(14099, 6798, 4, 'Fecha de transferencia'),
(14100, 6799, 4, 'Transferencia fallida, cantidad insuficiebnte el el lote de fuente'),
(14101, 6800, 4, 'Sumario de transferencia'),
(14102, 6801, 4, 'Transferir a'),
(14103, 6804, 4, 'Transferencias'),
(14104, 6806, 4, '¿Transición/Transferencia de cuidados?'),
(14105, 6807, 4, 'Traducir Grupos de Control de Acceso'),
(14106, 6808, 4, 'Traducir Categorías de Citas'),
(14107, 6809, 4, 'Traducir Categorías de Documento'),
(14108, 6810, 4, 'Traducir Diseños'),
(14109, 6811, 4, 'Traducir Listas'),
(14110, 6812, 4, 'Traducir título de notas de paciente'),
(14111, 6813, 4, 'traducir este'),
(14112, 6814, 4, 'Traducción'),
(14113, 6815, 4, 'Traducciones'),
(14114, 6816, 4, 'Trasmisión'),
(14115, 6817, 4, 'Trasmisión fallada'),
(14116, 6818, 4, 'Trasmitir órdenes seleccionadas'),
(14117, 6819, 4, 'Trauma'),
(14118, 6820, 4, 'Tratamiento'),
(14119, 6822, 4, 'Objetivos de Tratamiento'),
(14120, 6823, 4, 'Plan de Tratamiento'),
(14121, 6826, 4, 'Tratamiento:'),
(14122, 6827, 4, 'Tratamiento: '),
(14123, 6828, 4, 'Tendencia'),
(14124, 6829, 4, 'trftime ($ mes_formato, mkhora(0, 0, 0, $i, 1, 2000))); $ mes_valor'),
(14125, 6830, 4, 'Punto de activación / síndrome compartimental / DOM / calambres'),
(14126, 6831, 4, 'Trimalleolar'),
(14127, 6832, 4, 'Tronco y abdomen'),
(14128, 6837, 4, 'tsp'),
(14129, 6839, 4, 'TTS'),
(14130, 6840, 4, 'Tuberculosis'),
(14131, 6841, 4, 'Martes'),
(14132, 6842, 4, 'Martes y Jueves'),
(14133, 6843, 4, 'Martes'),
(14134, 6844, 4, 'Tumor'),
(14135, 6845, 4, 'Turco'),
(14136, 6848, 4, 'Dos veses al dia'),
(14137, 6850, 4, 'Membrana Timpánica'),
(14138, 6851, 4, 'Tipo'),
(14139, 6852, 4, 'Teclee ID o nombre. Mínimo 3 caracteres (incluyendo espacios).'),
(14140, 6853, 4, 'Teclee columnas mostradas en los resultados de búsqueda de pacientes'),
(14141, 6854, 4, 'Tipos de revelación de info'),
(14142, 6855, 4, 'Tipo de Eventos'),
(14143, 6856, 4, 'Tipo de diseño de pantalla'),
(14144, 6857, 4, 'Tipee o escanee el identificador del paciente aquí'),
(14145, 6858, 4, 'Teclee su mensaje aquí'),
(14146, 6859, 4, 'Tipo de orden y resultados'),
(14147, 6864, 4, 'Códigos UCSMC provistos por el centro de Medicina del Deporte de la Universidad de Calgary'),
(14148, 6865, 4, 'Ucraniano'),
(14149, 6866, 4, 'Ulceraciones'),
(14150, 6867, 4, 'Colitis ulcerosa'),
(14151, 6868, 4, 'Úlceras:'),
(14152, 6871, 4, 'No se puede crear'),
(14153, 6876, 4, 'No aplicado'),
(14154, 6877, 4, 'No asign.'),
(14155, 6878, 4, 'No autorizado'),
(14156, 6879, 4, 'Acceso no autorizado a ePrescripción'),
(14157, 6880, 4, 'Acceso no autorizado.'),
(14158, 6881, 4, 'No facturado'),
(14159, 6882, 4, 'no facturado solamente'),
(14160, 6884, 4, 'debajo de la lengüeta'),
(14161, 6885, 4, 'De peso insuficiente'),
(14162, 6886, 4, 'Sin diagnosticar'),
(14163, 6887, 4, 'SIN DISTRIBUIR'),
(14164, 6888, 4, 'Sin distribuir'),
(14165, 6889, 4, 'No es distribuido'),
(14166, 6890, 4, 'Deshacer liquidación'),
(14167, 6892, 4, 'Clientes únicos'),
(14168, 6893, 4, 'Identificador para este tipo sólo legible por humanos'),
(14169, 6894, 4, 'Nuevos Clientes Distintos'),
(14170, 6895, 4, 'Identificador para este tipo sólo numérico'),
(14171, 6896, 4, 'Unicos Pacientes Vistos'),
(14172, 6897, 4, 'Informe de unicos pacientes vistos'),
(14173, 6898, 4, 'Pactes.únicos vistos'),
(14174, 6899, 4, 'Unidad'),
(14175, 6900, 4, 'Unidades'),
(14176, 6901, 4, 'unidades'),
(14177, 6903, 4, 'Unidades de formularios de visita'),
(14178, 6904, 4, 'Unidades deben ser un numero'),
(14179, 6905, 4, 'Unidades no definidas'),
(14180, 6906, 4, 'Unidades/L'),
(14181, 6907, 4, 'Desconocido'),
(14182, 6910, 4, 'Desconoce si ha fumado alguna vez'),
(14183, 6911, 4, 'Desconocidos o N/A'),
(14184, 6913, 4, 'Desvincular paciente'),
(14185, 6914, 4, 'Sociedad Médica sin nombre'),
(14186, 6915, 4, 'No registrado'),
(14187, 6918, 4, 'Desmarcar todos'),
(14188, 6919, 4, 'Desmarcado'),
(14189, 6920, 4, 'Sin especificar'),
(14190, 6921, 4, 'no estructurado'),
(14191, 6922, 4, 'Fichero de carga NO SOPORTADO por la bbdd'),
(14192, 6924, 4, 'Hasta'),
(14193, 6925, 4, 'Presentación extemporánea'),
(14194, 6926, 4, 'No utilizados'),
(14195, 6927, 4, 'UOR'),
(14196, 6928, 4, 'Hasta'),
(14197, 6929, 4, 'Próximas Citas'),
(14198, 6930, 4, 'Próximos Eventos'),
(14199, 6931, 4, 'Actualizar'),
(14200, 6932, 4, 'actualizar'),
(14201, 6933, 4, 'Actualizacion activa'),
(14202, 6934, 4, 'Actualizar archivos'),
(14203, 6935, 4, 'Actualizar Informacion'),
(14204, 6936, 4, 'Actualizar lista'),
(14205, 6937, 4, 'Actualizar numero de proveedor'),
(14206, 6938, 4, 'Actualizar items seleccionados'),
(14207, 6939, 4, 'Actualizar las siguientes variables en el file'),
(14208, 6940, 4, 'Actualizar informacion de usuario'),
(14209, 6942, 4, 'Updating demographics is not authorized.'),
(14210, 6943, 4, 'Actualizando la configuración global predeterminada'),
(14211, 6944, 4, 'Actualizando indicadores de versión'),
(14212, 6945, 4, 'ACTUALIZACIÓN'),
(14213, 6946, 4, 'Actualizar'),
(14214, 6947, 4, 'Actualizar BBDD'),
(14215, 6948, 4, 'Actualización de base de datos LibreEHR para incluir procedimientos, funciones y tablas necesarias para el proceso de De-identificación.'),
(14216, 6949, 4, 'la actualización continuará'),
(14217, 6950, 4, 'UPIN'),
(14218, 6951, 4, 'Subir'),
(14219, 6954, 4, 'Cargar configuracion de datos'),
(14220, 6955, 4, 'Subir Documento'),
(14221, 6956, 4, 'Carga del documento fallo'),
(14222, 6957, 4, 'Adjuntar imagen a'),
(14223, 6958, 4, 'Subrir archivo de importación:'),
(14224, 6961, 4, 'Upload Report'),
(14225, 6963, 4, 'Subir este archivo:'),
(14226, 6964, 4, 'Al hacer clic en un número de factura el "manual de desplazamiento ventana" aparece. Aquí puede cambiar la fecha de vencimiento y toma nota de la factura, para seleccionar la parte a quien se le envío por correo, y seleccione los seguros para que todos esperemos los pagos se han recibidos. Lo que es más importante, para cada código de facturación para los que fue acusado una cantidad, puede introducir la información de pago y el ajuste.'),
(14227, 6965, 4, 'Tras la búsqueda se le presenta con una lista de las facturas. Puede hacer clic en uno de los números de la factura para abrir una segunda ventana, que es la página de entrada de datos manual de desplazamiento. También puede hacer clic sobre el nombre de un paciente si desea escribir una nota que la oficina de personal se verá cuando el paciente en los controles, y usted puede seleccionar que aparezca en las facturas del paciente declaraciones e imprimir esas declaraciones.'),
(14228, 6966, 4, 'Parte superior del brazo'),
(14229, 6968, 4, 'Urgencia'),
(14230, 6970, 4, 'Orina'),
(14231, 6971, 4, 'Goteo de Orina'),
(14232, 6972, 4, 'Frecuencia de la Orina'),
(14233, 6973, 4, 'Vacilación de la Orina'),
(14234, 6974, 4, 'Microalbúmina de la orina'),
(14235, 6975, 4, 'Flujo de Orina'),
(14236, 6976, 4, 'Urgencia de la Orina'),
(14237, 6977, 4, 'URL'),
(14238, 6979, 4, 'URL para soporte LibreEHR'),
(14239, 6981, 4, 'URL para puerta de enlace telefónico. Servicio automático de VOIP desarrollado por Maviq. Por favor visite http://signup.maviq.com para más información.'),
(14240, 6986, 4, 'Indicador de uso (ISA15)'),
(14241, 6987, 4, 'Use % solo en un campo para ordenar por esa columna'),
(14242, 6988, 4, 'Utilice el formato de 24 horas?'),
(14243, 6991, 4, 'Usar panel de cargos'),
(14244, 6997, 4, 'Usar lista personalizada de vacunación'),
(14245, 6999, 4, 'Utilice Rango de Fechas'),
(14246, 7000, 4, 'Use opciones por defecto'),
(14247, 7001, 4, 'Utilice la Opción Borrar para Eliminar.'),
(14248, 7002, 4, '¿Utilice el estilo internacional de la fecha?'),
(14249, 7003, 4, 'Utilice nombre de fichero fuente'),
(14250, 7004, 4, 'Use los cambpos abajo para una adquisicion o transferencia'),
(14251, 7005, 4, 'Utilice esta función sólo con los sitios nuevos instalados, '),
(14252, 7006, 4, 'Usar temas?'),
(14253, 7007, 4, 'Usar'),
(14254, 7009, 4, 'Usuarios/Grupos'),
(14255, 7010, 4, 'Usar Administración'),
(14256, 7011, 4, 'Administración de usuarios y Centros'),
(14257, 7012, 4, 'Administración de usuarios y grupos'),
(14258, 7014, 4, 'Certificado de Autenticacion del usuario esta deshabilitado'),
(14259, 7015, 4, 'Definido por el usuario'),
(14260, 7016, 4, 'Definido por el usuario Zona 11'),
(14261, 7017, 4, 'Definido por el usuario Zona 12'),
(14262, 7018, 4, 'Campo definido por el usario'),
(14263, 7019, 4, 'Definido por el usuario Lista 1'),
(14264, 7020, 4, 'Definido por el usuario Lista 2'),
(14265, 7021, 4, 'Definido por el usuario Lista 3'),
(14266, 7022, 4, 'Definido por el usuario Lista 4'),
(14267, 7023, 4, 'Definido por el usuario Lista 5'),
(14268, 7024, 4, 'Definido por el usuario Lista 6'),
(14269, 7025, 4, 'Definido por el usuario Lista 7'),
(14270, 7026, 4, 'Definido por el usuario Texto 1'),
(14271, 7027, 4, 'Definido por el usuario Texto 2'),
(14272, 7028, 4, 'Definido por el usuario Texto 3'),
(14273, 7029, 4, 'Definido por el usuario Texto 4'),
(14274, 7030, 4, 'Definido por el usuario Texto 5'),
(14275, 7031, 4, 'Definido por el usuario Texto 6'),
(14276, 7032, 4, 'Definido por el usuario Texto 7'),
(14277, 7033, 4, 'Definido por el usuario Texto 8'),
(14278, 7034, 4, 'Usuario Nombre'),
(14279, 7037, 4, 'Ingreso de usuario (Si dice arriba 03 , sino deje espacios) (ISA02)'),
(14280, 7038, 4, 'User logon Required Indicator (ISA01~ use 00 or 03)'),
(14281, 7039, 4, 'Manual de Uso'),
(14282, 7040, 4, 'Permisos de usuarios'),
(14283, 7041, 4, 'Apellido de usuario'),
(14284, 7042, 4, 'Nombre del Usuario o Huesped no pueden estar vacios'),
(14285, 7043, 4, 'Nombre del Usuario o Huesped'),
(14286, 7044, 4, 'User Password (ISA04~ if 01 above, else leave spaces)'),
(14287, 7045, 4, 'User password required Indicator (ISA03~ use 00 or 01)'),
(14288, 7046, 4, 'Ajustes de Usuario'),
(14289, 7047, 4, 'Ajuste Específico de usuario'),
(14290, 7049, 4, 'Nombre de usuario'),
(14291, 7051, 4, 'Usuario para puerta de enlace telefónico. Servicio automático de VOIP desarrollado por Maviq. Por favor visite http://signup.maviq.com para más información.'),
(14292, 7052, 4, 'Nombre de usuario para la entrada de SMS'),
(14293, 7053, 4, 'Usuario para puerta de enlace SMS'),
(14294, 7054, 4, 'Nombre de usuario para conectar con CouchDB'),
(14295, 7055, 4, 'Nombre de usuario:'),
(14296, 7056, 4, 'Usuarios'),
(14297, 7057, 4, 'Usuarios / Grupos / Administración de Registros'),
(14298, 7058, 4, 'usar php <a href="http://php.net/strftime">strfhora</a> formato'),
(14299, 7059, 4, 'Infec. tracto urinario'),
(14300, 7062, 4, 'VACACIONES'),
(14301, 7063, 4, 'Vacaciones'),
(14302, 7064, 4, 'Vacuna'),
(14303, 7065, 4, 'Anillo Vaginal'),
(14304, 7066, 4, 'Despedida'),
(14305, 7067, 4, 'Validar'),
(14306, 7068, 4, 'Valor'),
(14307, 7069, 4, 'Valor 1'),
(14308, 7070, 4, 'Valor 2'),
(14309, 7072, 4, 'El valor debe ser Numérico'),
(14310, 7073, 4, 'Var1'),
(14311, 7074, 4, 'Var2'),
(14312, 7075, 4, 'variable a uno para ejecutar script de actualización des-identificación'),
(14313, 7076, 4, 'Varicela 1'),
(14314, 7077, 4, 'Varicela 2'),
(14315, 7078, 4, 'Venas varicosas'),
(14316, 7079, 4, 'Condición vascular'),
(14317, 7080, 4, 'Lesión vascular'),
(14318, 7081, 4, 'Cirugía Vascular'),
(14319, 7083, 4, 'Vendedor'),
(14320, 7084, 4, 'Versión'),
(14321, 7085, 4, 'Vértigo'),
(14322, 7086, 4, 'Administración de Veteranos'),
(14323, 7087, 4, 'Plan de Administración de veteranos'),
(14324, 7088, 4, 'VFC'),
(14325, 7089, 4, 'Vietnamita'),
(14326, 7090, 4, 'ver'),
(14327, 7091, 4, 'Ver'),
(14328, 7092, 4, 'Ver Alergias'),
(14329, 7097, 4, 'Ver Informe comprensiva del paciente'),
(14330, 7100, 4, 'Ver documento'),
(14331, 7101, 4, 'Ver encuentro'),
(14332, 7103, 4, 'Ver los eventos en una ventana móvil?'),
(14333, 7104, 4, 'Ver información de usuario en el centro especificado'),
(14334, 7107, 4, 'Ver Registro'),
(14335, 7108, 4, 'Ver Página 1'),
(14336, 7109, 4, 'Ver Página 2'),
(14337, 7110, 4, 'Ver recordatorios pasados y futuros'),
(14338, 7111, 4, 'Ver Paciente'),
(14339, 7116, 4, 'Ver visitas relacionadas'),
(14340, 7121, 4, 'Ver/Editar Alergias'),
(14341, 7122, 4, 'Ver/Editar incidencia'),
(14342, 7123, 4, 'Ver/Imprimir'),
(14343, 7124, 4, 'Ver:'),
(14344, 7125, 4, 'VISA'),
(14345, 7126, 4, 'VISA/MasterCard/AMEREXPRESS/Discovery'),
(14346, 7127, 4, 'Daño viscerales/trauma/cirugía'),
(14347, 7133, 4, 'Categoría de Visita:'),
(14348, 7134, 4, 'Fecha de Visita'),
(14349, 7135, 4, 'Fecha visita'),
(14350, 7137, 4, 'Formularios de visita'),
(14351, 7138, 4, 'Histórico de Visitas'),
(14352, 7140, 4, 'Visitas'),
(14353, 7141, 4, 'Visitas De'),
(14354, 7142, 4, 'Signos Vitales'),
(14355, 7143, 4, 'Vitales'),
(14356, 7144, 4, 'Vitales (Métrico)'),
(14357, 7146, 4, 'Voz'),
(14358, 7147, 4, 'Voz Enviada'),
(14359, 7149, 4, 'Vómitos'),
(14360, 7151, 4, 'W'),
(14361, 7152, 4, 'Circ cintura'),
(14362, 7153, 4, 'Circunferencia de la Cintura'),
(14363, 7154, 4, 'Espera'),
(14364, 7155, 4, 'Entrar'),
(14365, 7157, 4, 'Walt Pennington'),
(14366, 7158, 4, 'Tienda de deposito'),
(14367, 7159, 4, 'Almacén máximo, 0 si no es aplicable'),
(14368, 7160, 4, 'Almacén mínimo, 0 si no es aplicable'),
(14369, 7161, 4, 'Tiendas de deposito'),
(14370, 7162, 4, 'Cálido'),
(14371, 7163, 4, 'Aviso'),
(14372, 7164, 4, 'AVISO'),
(14373, 7166, 4, 'Aviso, número de cheque ya existe en la base de datos'),
(14374, 7168, 4, 'Aviso: ya hay una cita para este paciente hoy!'),
(14375, 7170, 4, 'Aviso: Nº Identificación del paciente no es único!'),
(14376, 7171, 4, 'AVISO: Esto sobreescribirá la información de configuración con los datos del fichero adjunto!'),
(14377, 7173, 4, 'Avisos'),
(14378, 7175, 4, 'ya se ha subido'),
(14379, 7177, 4, 'Agradecemos su pago a tiempo del balance debido'),
(14380, 7178, 4, 'hemos visto por encima de su paciente para la evaluación y tratamiento en nuestra clínica de consulta externa de psiquiatría. Gracias por esta referencia.'),
(14381, 7179, 4, 'Debilidad'),
(14382, 7181, 4, 'Búsqueda web'),
(14383, 7182, 4, 'Sitio Web'),
(14384, 7183, 4, 'Vínculo sitio web para el Portal del Paciente interno'),
(14385, 7184, 4, 'Miércoles'),
(14386, 7185, 4, 'Miércoles'),
(14387, 7186, 4, 'Semana'),
(14388, 7187, 4, 'semana'),
(14389, 7188, 4, 'Ver Semana'),
(14390, 7189, 4, 'Semana(s)'),
(14391, 7190, 4, 'Exposicion semanal'),
(14392, 7192, 4, 'Semanas'),
(14393, 7193, 4, 'Peso'),
(14394, 7194, 4, 'Evaluación de peso y Orientación para Niños y Adolescentes'),
(14395, 7195, 4, 'Peso evaluación y orientación para niños y adolescentes (GCC)'),
(14396, 7196, 4, 'Cambio de peso'),
(14397, 7197, 4, 'Perdida de Peso'),
(14398, 7198, 4, 'Clínica de Adelgazamiento'),
(14399, 7199, 4, 'Bienvenido'),
(14400, 7202, 4, '¿Cuál debe ser contado?'),
(14401, 7203, 4, 'Los Resuellos:'),
(14402, 7204, 4, 'Sibilancia'),
(14403, 7205, 4, 'Resollando:'),
(14404, 7208, 4, '¿Donde puede los documentos explorados o de papel relacionados que se encontrarán?'),
(14405, 7209, 4, 'Asegurado'),
(14406, 7211, 4, 'Trallazo'),
(14407, 7212, 4, 'Blanco'),
(14408, 7213, 4, 'Quién'),
(14409, 7214, 4, '¿Quién respondió?'),
(14410, 7215, 4, 'Viudo'),
(14411, 7216, 4, 'Ancho'),
(14412, 7217, 4, 'Ancho en píxeles de la barra de navegación izquierda.'),
(14413, 7221, 4, 'Con el seleccionado'),
(14414, 7222, 4, 'con el viejo nombre'),
(14415, 7224, 4, '¿Con quién podemos dejar un mensaje?'),
(14416, 7225, 4, 'Retenido'),
(14417, 7226, 4, 'dentro de horas'),
(14418, 7227, 4, 'dentro de horas:'),
(14419, 7228, 4, 'dentro de minutos'),
(14420, 7229, 4, 'dentro de minutos:'),
(14421, 7230, 4, 'sin centro'),
(14422, 7231, 4, 'sin proveedor'),
(14423, 7232, 4, 'Sin Actualización'),
(14424, 7233, 4, 'Testigo'),
(14425, 7234, 4, 'Semana'),
(14426, 7235, 4, 'WNL'),
(14427, 7237, 4, 'Mujer'),
(14428, 7238, 4, 'Sólo las Mujeres'),
(14429, 7240, 4, 'Trabajo'),
(14430, 7241, 4, 'NOTA DE TRABAJO'),
(14431, 7242, 4, 'Teléfono de Trabajo'),
(14432, 7243, 4, 'Número de Teléfono de Trabajo'),
(14433, 7244, 4, 'Relacionados con el trabajo?'),
(14434, 7245, 4, 'Trabajo / Educación / aficiones'),
(14435, 7246, 4, 'Nota de Trabajo/Escuela'),
(14436, 7247, 4, 'día de trabajo'),
(14437, 7248, 4, 'Compensación al Trabajador'),
(14438, 7249, 4, 'Indemnización de los trabajadores del Plan de Salud'),
(14439, 7250, 4, 'Beneficiario de edad trabajando o esposa con el Plan de Grupo de Salud Empleador'),
(14440, 7251, 4, 'Trabajando - espere'),
(14441, 7252, 4, 'Peor'),
(14442, 7253, 4, '¿Quieres que el saldo se aplique a la cuanta global?'),
(14443, 7254, 4, 'quiere marcarlo como borrado.'),
(14444, 7255, 4, '¿Quiere asignarlo?'),
(14445, 7256, 4, '¿Quiere Cancelar la distribución para este paciente?'),
(14446, 7257, 4, '¿Quiere borrar la distribución de pago?'),
(14447, 7258, 4, '¿Quiere borrar los pagos?'),
(14448, 7259, 4, '¿Quiere modificar y terminar los pagos?'),
(14449, 7260, 4, '¿Quiere modificar los pagos?'),
(14450, 7261, 4, '¿Quiere enviar y terminar los pagos?'),
(14451, 7262, 4, '¿Quiere enviar los pagos?'),
(14452, 7263, 4, '¿Quiere salvar?'),
(14453, 7264, 4, 'Muñeca'),
(14454, 7265, 4, 'Muñeca y mano'),
(14455, 7266, 4, 'Problemas de Mano'),
(14456, 7267, 4, 'escribir'),
(14457, 7268, 4, 'Borrar cuenta'),
(14458, 7269, 4, 'Escribir una vez'),
(14459, 7270, 4, 'con algunos'),
(14460, 7271, 4, 'peso'),
(14461, 7273, 4, 'x Cancelado'),
(14462, 7274, 4, 'x Cancelado'),
(14463, 7275, 4, 'Rayos X'),
(14464, 7276, 4, 'Interpretación de RAYOS X:'),
(14465, 7277, 4, 'Interpretación de Rayos X:'),
(14466, 7278, 4, 'X12 solamente: Demanda de reemplazo '),
(14467, 7279, 4, 'X12 Socio'),
(14468, 7280, 4, 'X12 Socios'),
(14469, 7284, 4, 'A'),
(14470, 7285, 4, 'Año'),
(14471, 7286, 4, 'Año'),
(14472, 7287, 4, 'Ver año'),
(14473, 7288, 4, 'Año(s)'),
(14474, 7289, 4, 'Años'),
(14475, 7292, 4, 'SI'),
(14476, 7293, 4, 'Si'),
(14477, 7294, 4, 'si'),
(14478, 7295, 4, 'SI!'),
(14479, 7296, 4, 'Sí, Borrar y Registros'),
(14480, 7298, 4, 'Si/No'),
(14481, 7299, 4, 'Si:'),
(14482, 7300, 4, 'Ídish'),
(14483, 7303, 4, 'Estás a punto de reemplazar permanentemente la plantilla existente. ¿Estás seguro de que desea continuar?'),
(14484, 7304, 4, 'Ud esta en el periodo de entrar gratis. Cambie su palabra clave antes'),
(14485, 7305, 4, 'No está permitido eliminar este evento'),
(14486, 7306, 4, 'No está permitido a editar este evento'),
(14487, 7307, 4, 'Usted no está autorizado para esto.'),
(14488, 7308, 4, 'Usted no está autorizado para acceder a esta escuadra.'),
(14489, 7309, 4, 'No está autorizado para añadir/editar incidencias'),
(14490, 7310, 4, 'No está autorizado a programar citas'),
(14491, 7311, 4, 'Usted no está autorizado para ver este encuentro.'),
(14492, 7312, 4, 'Está Ud. publicando para un encuentro viejo?'),
(14493, 7313, 4, 'No se puede acceder a esta función directamente.'),
(14494, 7314, 4, 'No se puede acceder a esta página directamente.'),
(14495, 7315, 4, 'Ud no puede añadir un valor en blanco para una categoria!'),
(14496, 7316, 4, 'Ud no puede añadir un valor en blanco para una subcategoria!'),
(14497, 7317, 4, 'Ud. no puede añadir un valor en blanco para un item!'),
(14498, 7318, 4, 'No puede poner una fecha futura, con un valor completo de SI.'),
(14499, 7319, 4, 'Usted no escogió ninguna acción.'),
(14500, 7320, 4, 'Usted no tiene acceso para ver o editar esta nota'),
(14501, 7321, 4, 'Ud. ha tratado de alterar contenido que está cerrado. Remueva el cierre si desea hacer esta accion. Para abrir, remueva la linea, ·/*lock::*/'),
(14502, 7322, 4, 'Desconectado'),
(14503, 7323, 4, 'Sólo puede actualizar ficheros .txt'),
(14504, 7325, 4, 'Puede poner el texto aquí como queja por defecto en el formulario de visita de nuevo paciente.'),
(14505, 7326, 4, 'Debe introducir la frase clave para encriptar el documento'),
(14506, 7329, 4, 'Primero debe seleccionar o agregar un paciente.'),
(14507, 7330, 4, 'Primero debe seleccionar o crear un encuentro.'),
(14508, 7331, 4, 'Debe seleccionar una categoría de visita'),
(14509, 7332, 4, 'Ud. debe seleccionar una categoria para la visita'),
(14510, 7333, 4, 'Debe seleccionar algunos campos para continuar.'),
(14511, 7334, 4, 'Usted debería estar ejecutando esta prueba si este reclamo parece generarse con éxito, pero los datos no están completos. Esto esevidente con reclamos HCFA porque son legibles a simple vista, pero es más difícil saberlo con reclamos X12.'),
(14512, 7335, 4, 'Debe seleccionar al menos un contexto'),
(14513, 7336, 4, 'Debe seleccionar al menos un Facultativo'),
(14514, 7339, 4, 'Su fecha de finalización no es válida'),
(14515, 7340, 4, 'Su evento ha sido suprimido'),
(14516, 7341, 4, 'Su evento ha sido modificado'),
(14517, 7342, 4, 'Su evento ha sido aceptado'),
(14518, 7343, 4, 'El fichero es demasiado grande'),
(14519, 7345, 4, 'Su nombre de la lista se ha cambiado para resolver el nombramiento de requisitos.'),
(14520, 7347, 4, 'Su nombre para esta categoria, procedmiento o resultado'),
(14521, 7349, 4, 'Su Palabra Clave ha expirado. Favor de cambiar su palabra clave.'),
(14522, 7350, 4, 'Su Palabra Clave expira en'),
(14523, 7351, 4, 'Su Palabra Clave expira hoy. Favor de cambiar su palabra clave.'),
(14524, 7353, 4, 'Su configuración de PosteCalendario se ha reajustado a los defectos del uso.'),
(14525, 7354, 4, 'Se ha puesto al día su configuración de PosteCalendario.'),
(14526, 7355, 4, 'Su frecuencia de repetición debe ser un número entero.'),
(14527, 7356, 4, 'Su frecuencia de repetición debe ser por lo menos 1.'),
(14528, 7357, 4, 'Su fecha de inicio es mayor que su fecha de finalización'),
(14529, 7358, 4, 'Su fecha de inicio no es válido'),
(14530, 7359, 4, 'Su sumisión falló.'),
(14531, 7360, 4, 'aaaa-mm-dd'),
(14532, 7361, 4, 'AAAA-MM-DD'),
(14533, 7362, 4, 'aaaa-mm-dd fecha asociada con este documento'),
(14534, 7363, 4, 'aaaa-mm-dd fecha destruido'),
(14535, 7364, 4, 'aaaa-mm-dd F.Nacim.'),
(14536, 7365, 4, 'aaaa-mm-dd F.Nacim.'),
(14537, 7366, 4, 'aaaa-mm-dd fecha de expiración'),
(14538, 7367, 4, 'aaaa-mm-dd Fecha de inicio o de hospitalización'),
(14539, 7368, 4, 'aaaa-mm-dd fecha de inicio, cirugía o comienzo de la medicación'),
(14540, 7369, 4, 'aaaa-mm-dd fecha de adquisicion o transferencia'),
(14541, 7370, 4, 'aaaa-mm-dd fecha de recuperación o al final de la medicación'),
(14542, 7371, 4, 'aaaa-mm-dd Fecha de volver a jugar'),
(14543, 7372, 4, 'aaaa-mm-dd Fecha de servicios'),
(14544, 7373, 4, 'aaaa-mm-dd fecha de esta carta'),
(14545, 7374, 4, 'aaaa-mm-dd fecha que volvió a jugar'),
(14546, 7375, 4, 'aaaa-mm-dd fecha del documento'),
(14547, 7376, 4, 'aaaa-mm-dd fecha de evento o fecha de inicio'),
(14548, 7381, 4, 'aaaa-mm-dd hh:mm:ss'),
(14549, 7383, 4, 'aaaa-mm-dd última fecha de este evento'),
(14550, 7387, 4, 'Cero'),
(14551, 7389, 4, 'Postal'),
(14552, 7390, 4, 'Código postal'),
(14553, 7391, 4, 'Postal/Pais'),
(14554, 7392, 4, 'Zulú'),
(14555, 7393, 4, ' pero ha sido '),
(14556, 7394, 4, ' no se ha podido acceder.'),
(14557, 7395, 4, 'Seguro que quiere borrar'),
(14558, 7396, 4, 'Medicamento'),
(14559, 7397, 4, 'correos no mandados'),
(14560, 7398, 4, 'de'),
(14561, 7399, 4, 'ha sido creado '),
(14562, 7400, 4, 'ha sido abierto de nuevo.'),
(14563, 7401, 4, 'Historial'),
(14564, 7402, 4, 'no es un número'),
(14565, 7403, 4, 'listo para refacturar'),
(14566, 7404, 4, 'LLL:'),
(14567, 7405, 4, 'Lote'),
(14568, 7406, 4, 'Nº de Referencia original de Medicaid '),
(14569, 7407, 4, 'min'),
(14570, 7408, 4, 'no encontrado!'),
(14571, 7409, 4, 'Peculiaridades en varios exploradores pueden causar que la información abajo aparece bruscamente, y ocurren pausas extensas que aparentan que el sistema se ha dañado. Este no es el caso, y eventualmente verá información desplegada línea por línea. Podrían aparecer números secuenciales para indicar que aunque no aparezca nada más, el sistema tiene actividad. Estos números serán entremezclados con el contenido de la facturación, y es normal.'),
(14572, 7410, 4, 'la receta ha alcanzado el límite de'),
(14573, 7411, 4, 'hasta'),
(14574, 7412, 4, '¿falló la actualización, no está en la base de datos?'),
(14575, 7413, 4, 'marcado como solo facturado.'),
(14576, 7414, 4, 'puesto en cola.'),
(14577, 7415, 4, '! se retiró sin consulta'),
(14578, 7416, 4, '" para código'),
(14579, 7417, 4, '" está marcado en el seting the PostCalendar');
INSERT INTO `lang_definitions` VALUES
(14580, 7418, 4, '# asunto de seguro o financiero'),
(14581, 7419, 4, '# número de tabletas:'),
(14582, 7420, 4, '$'),
(14583, 7421, 4, '$ Codificado'),
(14584, 7422, 4, '$etiqueta (yyyy-mm-dd) '),
(14585, 7423, 4, '%'),
(14586, 7424, 4, '% Cancelado <24 hrs'),
(14587, 7425, 4, '% Cancelado < 24 hrs '),
(14588, 7426, 4, 'debería, pero no existe'),
(14589, 7427, 4, '(% Coincide con cualquier cadena, _ Coincide con cualquier carácter)'),
(14590, 7428, 4, '([ctrl] + click para seleccionar múltiples destinatarios)'),
(14591, 7429, 4, '(Volver)'),
(14592, 7430, 4, '(Haga clic para editar)'),
(14593, 7431, 4, '(el email tiene entrega inmediata, mientras que el mensaje de VOIP es enviado al proveedor del servicio para su proceso futuro)'),
(14594, 7432, 4, '(Mas)'),
(14595, 7433, 4, '(Paciente Nuevo)'),
(14596, 7434, 4, '(Notas y Autorizaciones)'),
(14597, 7435, 4, 'Notas del Paciente'),
(14598, 7436, 4, '(Seleccione una de estas, o escriba su propio título)'),
(14599, 7437, 4, '(Shift-) Selecciona o arrastrar para cambiar valor'),
(14600, 7438, 4, '* Recordatorio hecho'),
(14601, 7439, 4, '** Por Favor mover cirugías a incidencias'),
(14602, 7440, 4, '* Requerido'),
(14603, 7441, 4, 'Historia Clínica retirada'),
(14604, 7442, 4, '-Ninguno'),
(14605, 7445, 4, '.'),
(14606, 7446, 4, '0'),
(14607, 7447, 4, '0-10'),
(14608, 7448, 4, '0-24'),
(14609, 7451, 4, '1'),
(14610, 7452, 4, '1=Norteamerica. Ver http://www.wtng.info/ para lista de códigos de otros países.'),
(14611, 7453, 4, '1 dia a partir de ahora'),
(14612, 7454, 4, '1 mes a partir de ahora'),
(14613, 7455, 4, '1 semana a partir de ahora'),
(14614, 7456, 4, '1 año a partir de ahora'),
(14615, 7457, 4, '1. Descanso 2. Hielo por dos días 3. Compresión, dejar el vendaje en su lugar a menos que el pie presente hormigueo o color pálido 4. Elevar la pierna y el pie'),
(14616, 7458, 4, '11-14'),
(14617, 7459, 4, '12 hr'),
(14618, 7460, 4, '15-19'),
(14619, 7462, 4, '2'),
(14620, 7463, 4, '2 dias a partir de ahora'),
(14621, 7464, 4, '2 meses a partir de ahora'),
(14622, 7465, 4, '2 semanas a partir de ahora'),
(14623, 7466, 4, '2 años a partir de ahora'),
(14624, 7468, 4, '20-24'),
(14625, 7477, 4, '2111-13'),
(14626, 7478, 4, '24 hr'),
(14627, 7479, 4, '25+'),
(14628, 7480, 4, '25-29'),
(14629, 7481, 4, '2da'),
(14630, 7482, 4, '3 dias a partir de ahora'),
(14631, 7483, 4, '3 meses'),
(14632, 7484, 4, '3 meses a partir de ahora'),
(14633, 7485, 4, '3 veces al día'),
(14634, 7486, 4, '3 semanas a partir de ahora'),
(14635, 7487, 4, '30-34'),
(14636, 7488, 4, '35-39'),
(14637, 7489, 4, '3era'),
(14638, 7490, 4, '4 dias a partir de ahora'),
(14639, 7491, 4, '4 meses'),
(14640, 7492, 4, '4 meses a partir de ahora'),
(14641, 7493, 4, '4 veces al día'),
(14642, 7494, 4, '4 semanas a partir de ahora'),
(14643, 7495, 4, '40-44'),
(14644, 7496, 4, '45+'),
(14645, 7497, 4, '465,9, URI'),
(14646, 7498, 4, '466.0, Bronquitis, Aguda'),
(14647, 7499, 4, '486.0, Neumonía, Aguda'),
(14648, 7500, 4, '491.21 Agravación de Enfermedad Pulmonar Obstructiva Crónica'),
(14649, 7501, 4, '491.8, Bronquitis, Crónica'),
(14650, 7502, 4, '493.92, Asma, Aguda'),
(14651, 7503, 4, '496.0 Enfermedad Pulmonar Obstructiva Crónica'),
(14652, 7504, 4, '4ta'),
(14653, 7505, 4, '5 dias a partir de hoy'),
(14654, 7506, 4, '5 meses a partir de ahora'),
(14655, 7507, 4, '5 semanas a partir de ahora'),
(14656, 7508, 4, '519.7, Broncoespasmo'),
(14657, 7509, 4, '5ta'),
(14658, 7510, 4, '6 dias a partir de ahora'),
(14659, 7511, 4, '6 meses'),
(14660, 7512, 4, '6 meses a partir de ahora'),
(14661, 7513, 4, '6 semanas a partir de ahora'),
(14662, 7514, 4, '6ta'),
(14663, 7515, 4, '7 meses a partir de ahora'),
(14664, 7516, 4, '8 meses a partir de ahora'),
(14665, 7517, 4, '824.0 Fractura, maléolo intermedio, cerrado'),
(14666, 7518, 4, '824.2 Fractura, maléolo lateral, cerrado'),
(14667, 7519, 4, '824,6 Fractura, Trimalleolar, cerrado'),
(14668, 7520, 4, '825.32 Fractura de navicular (tobillo)'),
(14669, 7521, 4, '825,35 Fractura, Base de la quinta (5 ª) metatarsianas'),
(14670, 7522, 4, '845,00 torcedura del tobillo NOS'),
(14671, 7523, 4, '845,01 Esquince ligamento tibial (Deltoides).'),
(14672, 7524, 4, '845,02 Torcedura, fibular Calcánea'),
(14673, 7525, 4, '9 meses a partir de ahora'),
(14674, 7526, 4, 'Establecido 99212 - sin complicaciones'),
(14675, 7527, 4, 'Establecido 99213 - Baja Complejidad'),
(14676, 7528, 4, '< en consultorio'),
(14677, 7529, 4, '> De Alta / Salida'),
(14678, 7531, 4, '? ausente'),
(14679, 7532, 4, '@ llegado'),
(14680, 7533, 4, '[cambiar vista]'),
(14681, 7534, 4, '[Fecha de último encuentro]'),
(14682, 7535, 4, '[Días desde último encuentro]'),
(14683, 7536, 4, '[EDB]'),
(14684, 7537, 4, '[Exportar OFX]'),
(14685, 7538, 4, '[no recomendado]'),
(14686, 7539, 4, '[Número de encuentros]'),
(14687, 7540, 4, '[Informes]'),
(14688, 7541, 4, '[Seleccionar todos]'),
(14689, 7542, 4, '[SQL-Ledger]'),
(14690, 7543, 4, '[Procesar masivamente]'),
(14691, 7544, 4, '[Visualizar registro]'),
(14692, 7545, 4, '[Ver reporte imprimible]'),
(14693, 7546, 4, '_PC_DUR_HORAS'),
(14694, 7547, 4, '_PC_DUR_MINUTOS'),
(14695, 7548, 4, '_PC_LOCALE'),
(14696, 7549, 4, '~ Llegó tarde'),
(14697, 1, 5, 'Ein'),
(14698, 2, 5, 'Schecknummer oder Reklamationsnummer ist erforderlich, um Zahlung zu identifizieren'),
(14699, 3, 5, 'Klienten Zertifikat für Administrator'),
(14700, 4, 5, 'Ein klinisches Dokument befindet sich im Anhang.'),
(14701, 5, 5, 'Ein klinisches Dokument befindet sich im Anhang.'),
(14702, 7, 5, 'Einen Verteiler ist notwendig'),
(14703, 8, 5, 'Ein GCAC Konsultationsformular sollte angefügt werden'),
(14704, 9, 5, 'Ein Losnummer ist notwendig!'),
(14705, 10, 5, 'Ein Losnummer ist notwendig!'),
(14706, 11, 5, 'Kleinbuchstabe'),
(14707, 12, 5, 'Nummer'),
(14708, 14, 5, 'Ein Patient mit dieser ID existiert bereits'),
(14709, 15, 5, 'Ein Patient mit diesem Namen existiert bereits'),
(14710, 16, 5, 'Ein Patient mit dieser SozVersNr existiert bereits'),
(14711, 18, 5, 'eine positive Zahl in einem Fenster im Zusammenfassungbild der Akte zeigt wieviele Vorstellungen erfolgten'),
(14712, 19, 5, 'Überweisungsquelle kann bei jeder Vorstellung neu definiert werden'),
(14713, 20, 5, 'Ein verknüpfter IPPF Code ist erforderlich!'),
(14714, 21, 5, 'Sonderzeichen'),
(14715, 22, 5, 'Ein eindeutiger Wert um das Feld zu identifizieren, nicht sichtbar für Benutzer'),
(14716, 23, 5, 'Für diesen Patienten existiert für heute schon ein Besuch. Abbrechen um den aktuellen zu öffnen oder OK um einen neuen anzulegen.'),
(14717, 24, 5, 'präprandial'),
(14718, 25, 5, 'morgens'),
(14719, 26, 5, 'Luft-Flüssigkeit-Ebene rechts'),
(14720, 27, 5, 'AB'),
(14721, 28, 5, 'Abkürzung'),
(14722, 29, 5, 'Abszess:'),
(14723, 30, 5, 'Abdominal'),
(14724, 31, 5, 'Kann Gewicht heben in vier (4) Schritten:'),
(14725, 32, 5, 'Abn'),
(14726, 33, 5, 'ABN1'),
(14727, 34, 5, 'auffällig'),
(14728, 35, 5, 'auffälliger Bluttest'),
(14729, 36, 5, 'auffälliges Haarwachstum'),
(14730, 37, 5, 'auffälliges Mammogramm'),
(14731, 39, 5, 'Abort'),
(14732, 40, 5, 'Abort Probleme'),
(14733, 41, 5, 'Abtreibungsmethode'),
(14734, 42, 5, 'Abtreibungs-Kategorien'),
(14735, 43, 5, 'Aborte'),
(14736, 44, 5, 'Über den Kalender'),
(14737, 46, 5, 'Fehlen der Diagnose'),
(14738, 47, 5, 'Überweisung zustimmen'),
(14739, 48, 5, 'Bezahlung akzeptieren für'),
(14740, 49, 5, 'Bezahlung akzeptieren für '),
(14741, 50, 5, 'Überweisung zugestimmt'),
(14742, 51, 5, 'Zugangskontrolle'),
(14743, 52, 5, 'Verwaltung der Zugangskontrolllisten'),
(14744, 53, 5, 'Zugriffsdatum'),
(14745, 54, 5, 'Zugang nicht erlaubt'),
(14746, 55, 5, 'Zugang nicht genehmigt'),
(14747, 56, 5, 'Zugang zum Patientenportal'),
(14748, 57, 5, 'Unfall'),
(14749, 59, 5, 'Benutzername'),
(14750, 62, 5, 'Abrechnung'),
(14751, 64, 5, 'Beschwerden'),
(14752, 65, 5, 'Bestätigung angefordert (ISA14)'),
(14753, 66, 5, 'Bestätigungen, Genehmigungen und Befunde'),
(14754, 67, 5, 'Zugangskontrollliste'),
(14755, 68, 5, 'Verwaltung der Zugangskontrollliste'),
(14756, 69, 5, 'Zugriff auf Zugangskontrollliste verweigert'),
(14757, 70, 5, 'Zugangskontrollliste erfolgreich geändert'),
(14758, 71, 5, 'Akne'),
(14759, 72, 5, 'Behandlung'),
(14760, 73, 5, 'Behandlungsdatum'),
(14761, 74, 5, 'Aktion'),
(14762, 75, 5, 'Aktionen'),
(14763, 77, 5, 'CCR/CCD Bericht aktivieren'),
(14764, 78, 5, 'Aktiv'),
(14765, 79, 5, 'Aktiver Alarm'),
(14766, 80, 5, 'Regeln für aktiven Alarm'),
(14767, 81, 5, 'Aktive Alarme/Erinerungen'),
(14768, 82, 5, 'Ausgewählter Fall'),
(14769, 84, 5, 'Ausgewählte Liste'),
(14770, 85, 5, 'Ausgewählter Patient'),
(14771, 86, 5, 'Aktive Planungen'),
(14772, 87, 5, 'Aktivität'),
(14773, 88, 5, 'Aktivitätstyp'),
(14774, 90, 5, 'Überdosis/ Entzug'),
(14775, 91, 5, 'Akute Manifestation eines chronischen Zustands'),
(14776, 92, 5, 'akut exazerbierte chronische'),
(14777, 93, 5, 'hinzufügen'),
(14778, 94, 5, 'Hinzufügen'),
(14779, 95, 5, 'Hinzufügen'),
(14780, 96, 5, 'Firma hinzufügen'),
(14781, 98, 5, 'Apotheke hinzufügen'),
(14782, 100, 5, 'Ereignis hinzufügen für '),
(14783, 101, 5, 'Als neue Bemerkung hinzufügen'),
(14784, 102, 5, 'Neu hinzufügen'),
(14785, 104, 5, 'Schaltflächen hinzufügen'),
(14786, 105, 5, 'Schaltflächen hinzufügen für spezielle Buchstaben und Texte die oberhalb des Editors angezeigt werden und mit denen Text hinzugefügt werden kann'),
(14787, 106, 5, 'Kategorie hinzufügen'),
(14788, 107, 5, 'Konstante hinzufügen'),
(14789, 108, 5, 'Kontext hinzufügen'),
(14790, 109, 5, 'Eigenleistung hinzufügen'),
(14791, 110, 5, 'Kriterium hinzufügen'),
(14792, 111, 5, 'Benutzerdefinierte Schaltfläche hinzufügen'),
(14793, 112, 5, 'Diagnose hinzufügen'),
(14794, 113, 5, 'Medikament hinzufügen'),
(14795, 114, 5, 'Kontakt hinzufügen'),
(14796, 115, 5, 'Besuchnotizen hinzufügen'),
(14797, 116, 5, 'Standort hinzufügen'),
(14798, 117, 5, 'Feld hinzufügen'),
(14799, 118, 5, 'Folgende Zeilen zur Apache Konfigurationsdatei hinzufügen'),
(14800, 119, 5, 'Gruppe hinzufügen'),
(14801, 120, 5, 'ICD-Code hinzufügen'),
(14802, 121, 5, 'Impfung hinzufügen'),
(14803, 122, 5, 'Hinzufügen ist nicht erlaubt!'),
(14804, 123, 5, 'Problem hinzufügen'),
(14805, 124, 5, 'Punkt zur Verfolgung hinzufügen'),
(14806, 125, 5, 'Sprache hinzufügen'),
(14807, 126, 5, 'Neu hinzufügen'),
(14808, 127, 5, 'Neu hinzufügen'),
(14809, 128, 5, 'Neue Kategorie hinzufügen: '),
(14810, 129, 5, 'Neues Zertifikat zur Apache Konfigurationsdatei hinzufügen'),
(14811, 130, 5, 'Neue Komponente hinzufügen'),
(14812, 131, 5, 'Neue Komponenten hinzufügen'),
(14813, 132, 5, 'Neue Gruppe hinzufügen'),
(14814, 133, 5, 'Neues Problem hinzufügen'),
(14815, 134, 5, 'Neues Los und Transaktion hinzufügen'),
(14816, 135, 5, 'Neue Bemerkung hinzufügen'),
(14817, 136, 5, 'Neue Bemerkung hinzufügen'),
(14818, 137, 5, 'Neuen Partner hinzufügen'),
(14819, 138, 5, 'Neuen Patienten hinzufügen'),
(14820, 140, 5, 'Bemerkung hinzufügen'),
(14821, 141, 5, 'Patientendatensatz hinzufügen'),
(14822, 142, 5, 'Rezept hinzufügen'),
(14823, 143, 5, 'Eingriff hinzufügen'),
(14824, 144, 5, 'Anbieternummer hinzufügen'),
(14825, 145, 5, 'Reha hinzufügen'),
(14826, 146, 5, 'Regel hinzufügen'),
(14827, 147, 5, 'Hinzufügen zu'),
(14828, 148, 5, 'Zur Liste der Medikamente hinzufügen'),
(14829, 149, 5, 'Top Level hinzufügen'),
(14830, 150, 5, 'Transaktion hinzufügen'),
(14831, 151, 5, 'Benutzer hinzufügen'),
(14832, 152, 5, 'Benutzer zur Gruppe hinzufügen'),
(14833, 153, 5, 'eRx hinzufügen / anpassen'),
(14834, 154, 5, 'Patienten-Transaktion hinzufügen/bearbeiten'),
(14835, 155, 5, 'hinzugefügt'),
(14836, 156, 5, 'Hinzufügen demographischer Daten nicht gestattet.'),
(14837, 157, 5, 'Hinzufügen des zu verfolgenden Punktes gescheitert'),
(14838, 158, 5, 'Addison Syndrom'),
(14839, 159, 5, 'Addison Syndrom'),
(14840, 160, 5, 'Zusätzliche Attribute'),
(14841, 161, 5, 'Weitere Diagnosen:'),
(14842, 162, 5, 'Weitere Vorgeschichte'),
(14843, 163, 5, 'Weitere Bemerkungen zur Vorgeschichte'),
(14844, 164, 5, 'Weitere Informationen'),
(14845, 165, 5, 'Weitere Laborbefunde'),
(14846, 166, 5, 'Weitere Bemerkungen'),
(14847, 167, 5, 'zusätzliche Bemerkungen für diesen Befund oder Empfehlung'),
(14848, 168, 5, 'Weitere Bemerkungen:'),
(14849, 169, 5, 'Weitere Bemerkungen: '),
(14850, 170, 5, 'Weitere Bemerkungen zu Röntgenuntersuchungen:'),
(14851, 171, 5, 'zusätzlich kann das korrespondierende US-amerikanische Extensionspaket nach Installation der internationalen englischen Version importiert werden'),
(14852, 172, 5, 'nur hinzufügen'),
(14853, 173, 5, 'Adressbuch'),
(14854, 174, 5, 'Adressbuch'),
(14855, 175, 5, 'Adresse'),
(14856, 178, 5, 'Adressbuch'),
(14857, 179, 5, 'Adressbucheintrag der ausführenden Firma'),
(14858, 180, 5, 'Adressbucheintrag der Verteilerfirma'),
(14859, 181, 5, 'Adressbucheintrag des Anbieters'),
(14860, 182, 5, 'Adressbuchtypen'),
(14861, 183, 5, 'Typ der Adresse'),
(14862, 187, 5, 'Adresse1'),
(14863, 188, 5, 'Adresse2'),
(14864, 189, 5, 'Empfänger'),
(14865, 190, 5, 'Anp.'),
(14866, 191, 5, 'Angep. Betrag'),
(14867, 192, 5, 'Anpassen'),
(14868, 193, 5, 'Anpassung'),
(14869, 194, 5, 'Anpassungsbetrag'),
(14870, 195, 5, 'Gründe für Anpassung'),
(14871, 196, 5, 'Anpassungswert für Code '),
(14872, 197, 5, 'Anpassungen'),
(14873, 198, 5, 'Admin. Anpassung'),
(14874, 199, 5, 'Admin'),
(14875, 200, 5, 'Email-Adresse des Administrators'),
(14876, 201, 5, 'Administrieren über'),
(14877, 202, 5, 'Administriert'),
(14878, 203, 5, 'Administriert durch'),
(14879, 204, 5, 'Administriert am'),
(14880, 205, 5, 'administrierte Seite'),
(14881, 206, 5, 'Administration'),
(14882, 207, 5, 'Ort der Administration'),
(14883, 208, 5, 'Administratoren'),
(14884, 209, 5, 'Administratoren haben vollen Zugriff'),
(14885, 210, 5, 'Aufnahmedatum'),
(14886, 212, 5, 'Gewichts-Screening (Erwachsene) und Follow-up'),
(14887, 213, 5, 'Gewichts-Screening (Erwachsene) und Follow-up (CQM)'),
(14888, 214, 5, 'Spezielle Richtlinie'),
(14889, 215, 5, 'Spezielle Richtlinien'),
(14890, 216, 5, 'Warnung spezielle Richtlinien'),
(14891, 218, 5, 'Fortgeschritten'),
(14892, 219, 5, 'Ratschlag'),
(14893, 221, 5, 'Affekt unauffällig'),
(14894, 223, 5, 'Anruf nach Sprechzeit'),
(14895, 224, 5, 'Nach dem Umzug von der alten Passworteingabeart (Passwörter in einer Benutzertabelle ohne Salt) sollte diese Warnung auf falsch gesetzt werden, damit eine Authentifizierung nur noch durch die neue Methode möglich ist'),
(14896, 225, 5, 'Nach Ausführen oben stehender Konfigurationen, importieren Sie das Admin Klientszertifikat in den Browser und starten Sie den Apache Server neu (leeres Passwort)'),
(14897, 226, 5, 'Nach Speicherung als PDF [View log] klicken zur Fehlersuche.'),
(14898, 227, 5, 'Nach Speicherung als TEXT [View log] klicken zur Fehlersuche.'),
(14899, 228, 5, 'Nach Speicherung der Stapeldatei [View log] klicken zur Fehlersuche.'),
(14900, 229, 5, 'Danach zeigt die Ergebnisspalte die ausgewählte Patienten-ID oder 0 um einen neuen Patientendatensatz zu erzeugen'),
(14901, 230, 5, 'Nachdem die Daten korrekt eingegeben sind, bitte Speichern klicken.'),
(14902, 231, 5, 'Nach dem Upload bitte "Import" klicken.'),
(14903, 232, 5, 'Nachsorge-Plannung'),
(14904, 233, 5, 'Wieder'),
(14905, 234, 5, 'Alter'),
(14906, 235, 5, 'Alter nach'),
(14907, 236, 5, 'Altersstufe'),
(14908, 237, 5, 'Altersangabe ungültig.'),
(14909, 238, 5, 'Alter-Anzeigeformat'),
(14910, 239, 5, '"Alter von" ist ungültig'),
(14911, 240, 5, '"Alter bis" ist ungültig'),
(14912, 241, 5, 'Alter von'),
(14913, 242, 5, 'Alter in Jahren für Zeigeformat ändern'),
(14914, 243, 5, 'Maximales Alter'),
(14915, 244, 5, 'Minimales Alter'),
(14916, 245, 5, 'Altersspanne'),
(14917, 247, 5, 'Alters Spalten:'),
(14918, 249, 5, 'Albaner'),
(14919, 250, 5, 'Alkohol'),
(14920, 251, 5, 'Alkoholkonsum'),
(14921, 252, 5, 'Alkoholgebrauch'),
(14922, 253, 5, 'Anzahl der Alarme'),
(14923, 255, 5, 'Alarme'),
(14924, 258, 5, 'ALEUT'),
(14925, 259, 5, 'Alle'),
(14926, 260, 5, 'ALLE'),
(14927, 261, 5, 'Alle (Kollationiert Format A)'),
(14928, 262, 5, 'Alle (Kollationiert Format B)'),
(14929, 263, 5, 'Alle (kumulativ)'),
(14930, 265, 5, 'Alle automatischen Messwertberechnungen (AMC)'),
(14931, 266, 5, 'Alle Kategorien'),
(14932, 267, 5, 'Alle klinischen Qualitätswerte (CQM)'),
(14933, 268, 5, 'Alle Code'),
(14934, 269, 5, 'Ganztags'),
(14935, 270, 5, 'Ganztägiges Ereignis'),
(14936, 271, 5, 'Alle demografischen Felder, mit Suche und Überprüfung auf Dopplungen'),
(14937, 272, 5, 'Alle Einrichtungen'),
(14938, 273, 5, 'Alle Verletzungen/Probleme'),
(14939, 274, 5, 'Jede Sprache erlaubt'),
(14940, 276, 5, 'Vollständiger Vorname'),
(14941, 277, 5, 'Vollständiger Familienname'),
(14942, 278, 5, 'Alle oder Teil der Organisation'),
(14943, 279, 5, 'Alle Patienten'),
(14944, 280, 5, 'Alle Produkte'),
(14945, 281, 5, 'Alle Anbieter'),
(14946, 282, 5, 'Alle überprüft und negativ'),
(14947, 283, 5, 'Alle Themen'),
(14948, 284, 5, 'Alle Benutzer'),
(14949, 285, 5, 'Allergisch'),
(14950, 286, 5, 'Allergien'),
(14951, 287, 5, 'Allergien:'),
(14952, 288, 5, 'Allergie'),
(14953, 289, 5, 'Importieren von Allergien erfolgreich abgeschlossen'),
(14954, 290, 5, 'Allergische Vorfälle'),
(14955, 291, 5, 'Allergische Reaktion'),
(14956, 294, 5, 'Zuweisen'),
(14957, 295, 5, 'Ermöglichen'),
(14958, 296, 5, 'Jede verfügbare Sprache wählbar bei Login.'),
(14959, 297, 5, 'Ansprüche mit Diagnosen aber ohne Prozedur oder Kosten ermöglichen. Meistens nicht gewünscht.'),
(14960, 298, 5, 'Debugging-Sprache erlauben'),
(14961, 299, 5, 'E-Mail erlauben'),
(14962, 300, 5, 'E-Mail-Nachrichten erlauben?'),
(14963, 301, 5, 'E-Mail erlauben?'),
(14964, 302, 5, 'Visiteansprüche erlauben'),
(14965, 303, 5, 'Gesundheitsinformationaustausch erlauben'),
(14966, 304, 5, 'Immunisierungsinformationsaustausch erlauben'),
(14967, 305, 5, 'Immunisierungsregistrierung erlauben'),
(14968, 306, 5, 'E-Mail-Nachricht erlauben?'),
(14969, 308, 5, 'Patientenportal erlauben'),
(14970, 309, 5, 'SMS (Text-Nachricht) erlauben'),
(14971, 310, 5, 'SMS (Text-Nachricht) erlauben?'),
(14972, 311, 5, 'Sofortige Aktivierung von gesendeten Ereignissen erlauben?'),
(14973, 312, 5, 'Telefonnachrichten erlauben?'),
(14974, 313, 5, 'Benutzern die Veröffentlichung von globalen Ereignissen erlauben?'),
(14975, 314, 5, 'Benutzern die Veröffentlichung von persönlichen Terminlisten erlauben?'),
(14976, 315, 5, 'Sprachnachrichten erlauben?'),
(14977, 316, 5, 'Erlaubt'),
(14978, 317, 5, 'Erlaubte Sprachen'),
(14979, 318, 5, 'Erlaubt'),
(14980, 319, 5, 'E-Signatur eines kompletten Besuches erlaubt'),
(14981, 320, 5, 'E-Signatur eines individuelle Formulars erlaubt'),
(14982, 321, 5, 'Erlaubt Mail'),
(14983, 322, 5, 'Erlaubt Sprachnachrichten'),
(14984, 323, 5, 'existiert bereits'),
(14985, 324, 5, 'existiert bereits.'),
(14986, 325, 5, 'Wird bereits verwendet, bitte anderen Identifier wählen'),
(14987, 326, 5, 'Wird bereits verwendet, bitte anderen Titel wählen'),
(14988, 327, 5, 'Alternative Adresse'),
(14989, 328, 5, 'Ändern'),
(14990, 329, 5, 'Alternativ können Sie auch die Suchseite verwenden um eine elektronische Überweisungsdatei (X12 835), die Sie von ihrem Kostenträger oder ihrer Bank bekommen haben, hochzuladen. Durch klicken von "Auswählen" kann eine Datei selektiert werden und durch Drücken von "Suchen" hochgeladen und eine Ansicht der entsprechenden Rechnungen erhalten werden. In diesen Fall sind die oben stehenden Parameter nicht von Bedeutung und werden ignoriert. Beim Hochladen wird die Datei gespeichert aber nicht weiter verarbeitet -- dieses wird separat durchgeführt wie weiter unten beschrieben.'),
(14991, 330, 5, 'AM'),
(14992, 331, 5, 'AM Programm'),
(14993, 332, 5, 'AMC'),
(14994, 333, 5, 'AMC Verfolgung'),
(14995, 334, 5, 'AMC-2011'),
(14996, 335, 5, 'AMC-2014'),
(14997, 338, 5, 'Bestehende Notiz anpassen'),
(14998, 339, 5, 'Anpassungsformular'),
(14999, 340, 5, 'Anpassungsstatus'),
(15000, 341, 5, 'Anpassungen'),
(15001, 342, 5, 'Anpassungen für'),
(15002, 343, 5, 'Amerikanische Indianer'),
(15003, 344, 5, 'Amerikanische Indianer oder Alaska Eingeborene(r)'),
(15004, 345, 5, 'AMEX'),
(15005, 346, 5, 'Amharisch'),
(15006, 347, 5, 'Betrag'),
(15007, 348, 5, 'applizierte Menge'),
(15008, 349, 5, 'Berechneter Betrag'),
(15009, 350, 5, 'Betrag für vorherige Bilanz'),
(15010, 351, 5, 'Betrag für diese Konsultation'),
(15011, 352, 5, 'Bezahlter Betrag'),
(15012, 353, 5, 'Menge:'),
(15013, 354, 5, 'Betrag bezahlt'),
(15014, 355, 5, 'Für sich wiederholende Ereignisse muss Enddatum nach dem Startdatum sein!'),
(15015, 356, 5, 'Beim Signieren des Formulars ist ein Fehler aufgetreten'),
(15016, 357, 5, 'Beim Dump des LibreEHR Web-Verzeichnisbaums ist ein Fehler aufgetreten'),
(15017, 358, 5, 'Ein Fehler trat auf beim Dump des phpGACL Web-Verzeichnisbaums'),
(15018, 359, 5, 'Ein Fehler trat auf beim Dump des SQL-Ledger Web-Verzeichnisbaums'),
(15019, 360, 5, 'Ein unvollständiges GCAC Problem ist erstellt und verlinkt worden. Es sollte später vervollständigt werden'),
(15020, 362, 5, 'Ein unerwarteter Fehler ist aufgetreten'),
(15021, 363, 5, 'Einen Großbuchstabe'),
(15022, 365, 5, 'Und'),
(15023, 366, 5, 'UND'),
(15024, 367, 5, 'und'),
(15025, 368, 5, 'und '),
(15026, 369, 5, 'und alle unterliegenden Daten? Diese Aktion wird im Logfile verzeichnet'),
(15027, 370, 5, 'und Modifikator'),
(15028, 371, 5, 'und verarbeitet'),
(15029, 372, 5, 'und Apache-Server später neu starten'),
(15030, 373, 5, 'und der Grund ist'),
(15031, 374, 5, 'Anämie'),
(15032, 375, 5, 'Sprunggelenk'),
(15033, 376, 5, 'Sprunggelenk + Ferse'),
(15034, 377, 5, 'Sprunggelenk Evaluationsfragebogen'),
(15035, 378, 5, 'Sprunggelenk Probleme'),
(15036, 379, 5, 'Ankylosierende Spondylitis'),
(15037, 380, 5, 'Ankylosierende Spondylitis'),
(15038, 381, 5, 'Anorexia'),
(15039, 382, 5, 'Eine weitere Möglichkeit im Sendefenster ist die Beantragung einer erneuten Rechnungsstellung. Wenn Sie diese Auswahlbox vor dem Speichern wählen, wird die originale Rechnung erneut geöffnet und auf der Abrechnungsseite eingestellt und beim nächsten Rechnungslauf abgearbeitet.'),
(15040, 383, 5, 'vor'),
(15041, 384, 5, 'Anus normal, keine rectale Weichheit/Masse'),
(15042, 385, 5, 'Angst'),
(15043, 386, 5, 'Beliebig'),
(15044, 387, 5, 'Beliebige Kategorie'),
(15045, 388, 5, 'Beliebiger Teil eines ausgewählten Codes oder dessen Beschreibung'),
(15046, 389, 5, 'Beliebiger Teil der gewünschte Spezialität'),
(15047, 390, 5, 'Beliebiger Teil der Medikament-ID oder des Medikamentennamen'),
(15048, 391, 5, 'Beliebiger Teil der Impfungs-ID oder des Impfungsnamen'),
(15049, 392, 5, 'Beliebiger Teil des Patientennamens, oder "Familienname,Vorname" oder "X-Y"'),
(15050, 393, 5, 'Sonstige relevante Informationen'),
(15051, 394, 5, 'API Schlüssel für SMS-Gateway'),
(15052, 395, 5, 'Apnoe'),
(15053, 396, 5, 'Erscheinungsbild'),
(15054, 397, 5, 'Erscheinungsbild:'),
(15055, 398, 5, 'Diese Notiz hinzufügen'),
(15056, 399, 5, 'An existierende Notiz anhängen'),
(15057, 400, 5, 'An diese Notiz anhängen'),
(15058, 401, 5, 'An diese Notiz anhängen'),
(15059, 402, 5, 'Appendektomie'),
(15060, 403, 5, 'Appendektomie'),
(15061, 404, 5, 'Anwendbare Patienten'),
(15062, 405, 5, 'Anwendung'),
(15063, 406, 5, 'Applikationsname für Anmeldungsseite und Titel des Hauptfensters'),
(15064, 407, 5, 'Applikations Empfänger Kode (GS03- wenn leer wird ISA08 eingefügt)'),
(15065, 408, 5, 'Applikations Absenderkode (GS02)'),
(15066, 409, 5, 'Applikationstitel'),
(15067, 410, 5, 'Gilt für das Vitaldatenformular und Wachstumskarte'),
(15068, 411, 5, 'Gilt für das Vitaldatenformular'),
(15069, 412, 5, 'Die Änderungen nur auf aktuelles Ereignis anwenden, auf dieses und alle zukünftige Ereignisse oder auf alle Ereignisse?'),
(15070, 413, 5, 'Auf betroffenen Bereich anwenden'),
(15071, 414, 5, 'Auf der Haut anwenden'),
(15072, 415, 5, 'Anwenden'),
(15073, 416, 5, 'Verband an der Stelle anwenden'),
(15074, 417, 5, 'Termin'),
(15075, 418, 5, 'Datum des Termins'),
(15076, 419, 5, 'Terminanzeigestil'),
(15077, 420, 5, 'Termin Erinnerungsregel'),
(15078, 421, 5, 'Termin Status'),
(15079, 422, 5, 'Termin Status'),
(15080, 423, 5, 'Termin innerhalb'),
(15081, 424, 5, 'Termin/Besuch Farbe'),
(15082, 425, 5, 'Termine'),
(15083, 426, 5, 'Termine (schreiben optional)'),
(15084, 427, 5, 'Termine (schreiben, einige optional)'),
(15085, 430, 5, 'Termine und Besuche'),
(15086, 431, 5, 'Terminbericht'),
(15087, 432, 5, 'Termin-Visitenbericht'),
(15088, 434, 5, 'Bewilligen'),
(15089, 435, 5, 'Akzeptiere den Patienten von Patient/Client->Import->fehlende Bewilligung'),
(15090, 436, 5, 'Bewilligt'),
(15091, 437, 5, 'Administration bewilligter Ereignisse'),
(15092, 438, 5, 'erfolgreich akzeptiert'),
(15093, 440, 5, 'Besuch-Begegnung'),
(15094, 441, 5, 'Termine'),
(15095, 442, 5, 'Apr'),
(15096, 443, 5, 'April'),
(15097, 444, 5, 'Arabisch'),
(15098, 446, 5, 'Archiv'),
(15099, 447, 5, 'Sollen Zugangskontrollgruppen-Namen übersetzt werden?'),
(15100, 448, 5, 'Sollen Terminkategorie-Namen übersetzt werden?'),
(15101, 449, 5, 'Sollen Dokumentkategorie-Namen übersetzt werden?'),
(15102, 450, 5, 'Sind Kosten für diesen Typ anzurechnen?'),
(15103, 451, 5, 'Sollen Titel der Patientnotizen übersetzt werden?'),
(15104, 452, 5, 'Sind die Codes in externen SQL-Tabellen gespeichert (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2) ?'),
(15105, 453, 5, 'Sind Sie bereit ein neues GCAC-Problem für diese Visite auszufüllen?'),
(15106, 454, 5, 'Sind Sie sicher, dass Sie für heute senden möchten?'),
(15107, 455, 5, 'Sind Sie sicher, dass Sie diese Ereignisse bewilligen möchten?'),
(15108, 457, 5, 'Sind Sie sicher, dass Sie diesen Formular vollständig entfernen möchten?'),
(15109, 458, 5, 'Sind Sie sicher, dass Sie löschen möchten'),
(15110, 459, 5, 'Sind Sie sicher, dass Sie diese Bekanntgabe entfernen möchten?'),
(15111, 460, 5, 'Sind Sie sicher dass Sie diesen Ereignis entfernen möchten?'),
(15112, 461, 5, 'Sind Sie sicher, dass Sie diesen Punkt aus der Datenbank entfernen möchten?'),
(15113, 462, 5, 'Sind Sie sicher dass, Sie diese Notiz entfernen möchten?'),
(15114, 464, 5, 'Sind Sie sicher, dass Sie diese Ereignisse bearbeiten möchten?'),
(15115, 465, 5, 'Sind Sie sicher, dass Sie diese Ereignisse verbergen möchten?'),
(15116, 466, 5, 'Sind Sie sicher, dass Sie erneut übertragen möchten?'),
(15117, 467, 5, 'Sind Sie sicher, dass Sie diese Ereignisse sichtbar machen möchten?'),
(15118, 468, 5, 'Sind Sie sicher, dass Sie die gesamte genannte Gruppe entfernen möchten?'),
(15119, 469, 5, 'Sind Sie sicher, dass Sie die gesamte Liste entfernen möchten?'),
(15120, 470, 5, 'Sind Sie sicher, dass Sie das Feld entfernen möchten?'),
(15121, 471, 5, 'Sind Sie sicher, dass Sie die ausgewählten Felder entfernen möchten?'),
(15122, 472, 5, 'Sind Sie sicher, dass Sie diese Aktionen weiterführen möchten?'),
(15123, 473, 5, 'Gebiet nicht spezifiziert'),
(15124, 474, 5, 'Arm'),
(15125, 475, 5, 'Armenisch'),
(15126, 477, 5, 'Arrhythmie'),
(15127, 478, 5, 'Arthritis'),
(15128, 479, 5, 'Arthritis / degenerative Gelenkkrankheit'),
(15129, 480, 5, 'Arthritis / degenerative Gelenkkrankheit'),
(15130, 481, 5, 'wie'),
(15131, 482, 5, 'ab'),
(15132, 483, 5, 'ASC'),
(15133, 484, 5, 'Asiatisch'),
(15134, 487, 5, 'Beurteilung'),
(15135, 488, 5, 'Zugewiesen an'),
(15136, 489, 5, 'Assistent'),
(15137, 490, 5, 'Asthma'),
(15138, 491, 5, 'bei'),
(15139, 492, 5, 'Mindestens ein Suchparameter ist notwendig wenn Sie ''Alle'' selektieren'),
(15140, 493, 5, 'Am naviculare'),
(15141, 494, 5, 'Am naviculare:'),
(15142, 495, 5, 'Leichtathletikgruppe'),
(15143, 496, 5, 'Leichtathletikgruppe'),
(15144, 497, 5, 'Sportverletzung'),
(15145, 498, 5, 'ATNA Audit CA Zertifikat'),
(15146, 499, 5, 'ATNA Audit Host'),
(15147, 500, 5, 'ATNA Audit lokales Zertifikat'),
(15148, 501, 5, 'ATNA Audit Port'),
(15149, 503, 5, 'Achtung'),
(15150, 504, 5, 'zu Händen'),
(15151, 506, 5, 'Audit CDR Einrichtung Anfragen'),
(15152, 509, 5, 'Audit Logging Backups'),
(15153, 510, 5, 'Audit Logging Verschiedene'),
(15154, 511, 5, 'Audit Logging Order'),
(15155, 512, 5, 'Audit Logging Patientenakte'),
(15156, 513, 5, 'Audit Logging Planung'),
(15157, 514, 5, 'Audit Logging Sicherheitsadministration'),
(15158, 515, 5, 'Audit Logging SELECT Abfrage'),
(15159, 516, 5, 'Aug'),
(15160, 517, 5, 'August'),
(15161, 519, 5, 'Auth'),
(15162, 520, 5, 'Auth/Notizen'),
(15163, 523, 5, 'Genehmigungsgruppe'),
(15164, 524, 5, 'Genehmigungsstatus'),
(15165, 525, 5, 'Genehmigungen'),
(15166, 526, 5, 'Genehmigen'),
(15167, 527, 5, 'Jeden Termin genehmigen'),
(15168, 528, 5, 'Meine Termine genehmigen'),
(15169, 529, 5, 'Authorize.net'),
(15170, 530, 5, 'Genehmigt'),
(15171, 531, 5, 'Nur Genehmigte'),
(15172, 532, 5, 'Automatisch absenden'),
(15173, 535, 5, 'Neuen Termin automatisch anlegen'),
(15174, 536, 5, 'Automatisch generiert'),
(15175, 537, 5, 'Automatisierte Messberechnungen (AMC)'),
(15176, 538, 5, 'Automatisierte Messberechnungen (AMC) - 2011'),
(15177, 539, 5, 'Automatisierte Messberechnungen (AMC) - 2014'),
(15178, 542, 5, 'Automatisierte Messberechnungen (AMC) Nachverfolgung'),
(15179, 543, 5, 'Automatisierte Messungen'),
(15180, 544, 5, 'Automatisch'),
(15181, 546, 5, 'Automatisch eine neue Begegnung kreieren wenn Terminsstatus auf "@" (angekommen) gesetzt worden ist.'),
(15182, 549, 5, 'Automobile Medical'),
(15183, 550, 5, 'automatisch gespeichert'),
(15184, 551, 5, 'Verfügbare Kategorien'),
(15185, 552, 5, 'Verfügbare Zeiten'),
(15186, 553, 5, 'Verfügbare Pfade'),
(15187, 557, 5, 'Monatsmittel'),
(15188, 558, 5, 'Avulsion / Avulsionsbruch'),
(15189, 559, 5, 'Avulsion laterale Malleolus'),
(15190, 560, 5, 'Avulsion mediale Malleolus '),
(15191, 561, 5, 'Auf Basis von Wahrnehmung'),
(15192, 562, 5, 'Axillair'),
(15193, 565, 5, 'zweimal am Tag'),
(15194, 566, 5, 'Zurück'),
(15195, 567, 5, 'zurück'),
(15196, 568, 5, 'Acht Termine zurück'),
(15197, 569, 5, 'Elf Termine zurück'),
(15198, 570, 5, 'Fünf Termine zurück'),
(15199, 571, 5, 'Vier Termine zurück'),
(15200, 572, 5, 'Neun Termine zurück'),
(15201, 573, 5, 'Einen Termin zurück'),
(15202, 574, 5, 'Rückenschmerzen'),
(15203, 575, 5, 'Rückenbeschwerden'),
(15204, 576, 5, 'Sieben Termine zurück'),
(15205, 577, 5, 'Sechs Termine zurück'),
(15206, 578, 5, 'Rücken-OP'),
(15207, 579, 5, 'Zehn Termine zurück'),
(15208, 580, 5, 'Drei Termine zurück'),
(15209, 581, 5, 'Zurück zur Admin-Seite'),
(15210, 584, 5, 'Zurück zu Patient'),
(15211, 585, 5, 'Zurück zu Benutzern'),
(15212, 586, 5, 'Zurück zur Anzeige'),
(15213, 587, 5, 'Zwölf Besuche zurück'),
(15214, 588, 5, 'Zwei Termine zurück'),
(15215, 589, 5, 'Hintergrund Dienst'),
(15216, 590, 5, 'Backup'),
(15217, 591, 5, 'Backupdatei wurde erstellt. Download beginnt.'),
(15218, 593, 5, 'Backup erfolgreich erfolgt in'),
(15219, 594, 5, 'Ungedeckter Scheck'),
(15220, 595, 5, 'uneinbringliche Forderungen'),
(15221, 596, 5, 'Bahasa Indonesia'),
(15222, 597, 5, 'Bal'),
(15223, 598, 5, 'Saldo'),
(15224, 599, 5, 'saldo'),
(15225, 600, 5, 'Saldo Betrag'),
(15226, 601, 5, 'Restbetrag'),
(15227, 603, 5, 'Bankwechsel'),
(15228, 607, 5, 'Basis 5. Mittelfußknochen'),
(15229, 608, 5, 'Basis 5. Mittelfußknochen:'),
(15230, 611, 5, 'Batch Anforderung'),
(15231, 612, 5, 'Batch Kommunikations Tool'),
(15232, 613, 5, 'Sammelzahlungseintrag'),
(15233, 614, 5, 'Sammelzahlung'),
(15234, 615, 5, 'Verarbeitung gestartet. Dies kann einen Moment dauern.'),
(15235, 616, 5, 'Sammelergebnisse'),
(15236, 617, 5, 'BatchCom'),
(15237, 619, 5, 'weil diese ID nicht existiert'),
(15238, 620, 5, 'Start'),
(15239, 621, 5, 'Startdatum'),
(15240, 623, 5, 'Service Startdatum - JJJJ-MM-DD'),
(15241, 624, 5, 'Startstunde für Kalender Ereignisse'),
(15242, 626, 5, 'Aufstoßen'),
(15243, 628, 5, 'Bengali'),
(15244, 630, 5, 'zwischen'),
(15245, 633, 5, 'Bilateral'),
(15246, 634, 5, 'Bilateral:'),
(15247, 636, 5, 'Rechnungsdatum:'),
(15248, 637, 5, 'Rechnung'),
(15249, 638, 5, 'Berechnet'),
(15250, 640, 5, 'Rechnung'),
(15251, 641, 5, 'Rechnug (optional)'),
(15252, 642, 5, 'Rechnung z. Hd.'),
(15253, 644, 5, 'Rechnungscode für angeforderte Leistung'),
(15254, 645, 5, 'Rechnungscode'),
(15255, 646, 5, 'Rechnungsdaten'),
(15256, 647, 5, 'Rechnungsabteilung'),
(15257, 648, 5, 'Rechnungssteller'),
(15258, 649, 5, 'Rechnungsinformation'),
(15259, 650, 5, 'Rechnungslokalität'),
(15260, 655, 5, 'Rechnungsverwaltung'),
(15261, 656, 5, 'Rechnungsbemerkung'),
(15262, 657, 5, 'Rechnungsbemerkung für '),
(15263, 658, 5, 'Rechnungsbemerkung:'),
(15264, 659, 5, 'Rechnung Warteliste Ergebnisse:'),
(15265, 660, 5, 'Rechnungsbericht'),
(15266, 661, 5, 'Rechnungsstatus'),
(15267, 662, 5, 'Rechnungsstatus = Unbezahlt'),
(15268, 663, 5, 'Rechnung an '),
(15269, 665, 5, 'Biopsie'),
(15270, 666, 5, 'Geburtsdatum'),
(15271, 667, 5, 'Geb., 0 bis 24 Monate'),
(15272, 669, 5, 'Schwarz'),
(15273, 670, 5, 'Schwarze Lunge'),
(15274, 671, 5, 'Afrikaner oder Amerikaner'),
(15275, 672, 5, 'Blasencarcinom'),
(15276, 673, 5, 'Blasenentzündung'),
(15277, 674, 5, 'Formularvorlage'),
(15278, 675, 5, 'Probleme mit Blutungen'),
(15279, 676, 5, 'Blinde Flecken'),
(15280, 677, 5, 'Blähungen'),
(15281, 678, 5, 'Geblockt'),
(15282, 679, 5, 'Blut'),
(15283, 680, 5, 'Blutdruck'),
(15284, 681, 5, 'Blutdruck'),
(15285, 682, 5, 'Blutige Nase'),
(15286, 683, 5, 'Blaues kreuz blaues Schield'),
(15287, 684, 5, 'Blaue Linien in diesem Bericht sind informationell. Schwarze Linien zeigen bereits vorhandene Informationen. Grüne Linien zeigen Veränderungen, die erfolgreich angewendet wurden. Rote Linien weisen auf Fehler hin oder auf nicht übernommene Änderungen.'),
(15288, 685, 5, 'Sehstörungen'),
(15289, 686, 5, 'BMI'),
(15290, 687, 5, 'BMI Status'),
(15291, 689, 5, 'Körperbereich'),
(15292, 690, 5, 'Körperstelle'),
(15293, 691, 5, 'Körperstelle (gegebenfalls)'),
(15294, 692, 5, 'Knochenspannung'),
(15295, 693, 5, 'Knochenspannung: Medial Malleolus'),
(15296, 694, 5, 'Boolsch'),
(15297, 696, 5, 'Unten'),
(15298, 697, 5, 'Beide Ohren'),
(15299, 698, 5, 'beide Ohren'),
(15300, 699, 5, 'Unten'),
(15301, 701, 5, 'Fach 10 A Arbeitsunfall '),
(15302, 702, 5, 'Fach 10 B Autounfall '),
(15303, 703, 5, 'Fach 10 C andere Unfälle '),
(15304, 706, 5, 'Fach 15. Datum der gleichen oder ähnlichen Erkrankung (JJJJ-MM-TT)'),
(15305, 708, 5, 'Fach 16. Arbeitsunfähigkeit seit (JJJJ-MM-TT)'),
(15306, 709, 5, 'Fach 16. Arbeitsunfähigkeit bis (JJJJ-MM-TT)'),
(15307, 710, 5, 'Fach 18. Krankenhausaufenthalt seit (JJ-MM-TT) '),
(15308, 711, 5, 'Fach 18. Krankenhausaufenthalt bis (JJ-MM-TT) '),
(15309, 712, 5, 'Fach 20: wurde ein Auswärtslabor beauftragt?'),
(15310, 713, 5, 'Fach 22. Medicaid Wiedereinreichungskode ICD-9 '),
(15311, 714, 5, 'Fach 23. vorheriger AuthorizierungsNummer '),
(15312, 715, 5, 'Blutdruck'),
(15313, 716, 5, 'Blutdruck diastolisch'),
(15314, 717, 5, 'Blutdruck systolisch'),
(15315, 719, 5, 'BP diast.'),
(15316, 721, 5, 'BP syst.'),
(15317, 722, 5, 'Brasilianisches Portugiesisch'),
(15318, 723, 5, 'Brüste'),
(15319, 724, 5, 'Brust-Biopsie'),
(15320, 725, 5, 'Brustverkleinerung'),
(15321, 726, 5, 'Brusterkrankung'),
(15322, 727, 5, 'Brustuntersuchung'),
(15323, 728, 5, 'Brustmasse'),
(15324, 730, 5, 'Atemgeräusch:'),
(15325, 732, 5, 'Gebrochene Knochen'),
(15326, 734, 5, 'Bronchitis Art'),
(15327, 735, 5, 'Suchen'),
(15328, 736, 5, 'Suche nach Einträgen'),
(15329, 737, 5, 'Hämatome'),
(15330, 739, 5, 'Beule rechts:'),
(15331, 741, 5, 'Brennen beim Wasserlassen'),
(15332, 742, 5, 'Brennen beim Wasserlassen'),
(15333, 744, 5, 'Beschäftigt'),
(15334, 745, 5, 'aber noch nicht verarbeitet.'),
(15335, 746, 5, 'Gesäßhälfte'),
(15336, 747, 5, 'Gesäßhälfte + S.I.'),
(15337, 748, 5, 'bei'),
(15338, 749, 5, 'Bei'),
(15339, 750, 5, 'oral'),
(15340, 751, 5, 'Durch/Ursprung'),
(15341, 752, 5, 'Bei:'),
(15342, 753, 5, 'C'),
(15343, 754, 5, 'CA Certificate zur Identifizierung des RFC 5425 TLS syslog servers.'),
(15344, 755, 5, 'Cache Zeit (in Sekunden)'),
(15345, 756, 5, 'Cache Vorlage Ausgabe?'),
(15346, 757, 5, 'Kaffeekonsum'),
(15347, 758, 5, 'Kalender'),
(15348, 759, 5, 'Kalender Endstunde'),
(15349, 760, 5, 'Kalenderinterval'),
(15350, 761, 5, 'Kalender-Anzeige'),
(15351, 762, 5, 'Kalendereinstellungen'),
(15352, 763, 5, 'Kalender Startstunde'),
(15353, 764, 5, 'Kalender UI'),
(15354, 765, 5, 'Kalenderanzeige'),
(15355, 766, 5, 'Aufruf von addForm() kommt hierhin.<br>'),
(15356, 767, 5, 'Kalorien'),
(15357, 768, 5, 'Kambodschanisch'),
(15359, 774, 5, 'Abbrechen'),
(15360, 775, 5, 'Änderungen verwerfen'),
(15361, 776, 5, 'Abgebrochen'),
(15362, 777, 5, 'Krebs'),
(15363, 778, 5, 'Krebsuntersuchung: Darm-Krebsuntersuchung'),
(15364, 779, 5, 'Krebsuntersuchung: Mammographie'),
(15365, 780, 5, 'Krebsuntersuchung: PAP-Abstrich'),
(15366, 781, 5, 'Krebsuntersuchung: Prostata-Krebsuntersuchung'),
(15367, 782, 5, 'Kann diesen Eintrag nicht hinzufügen, da er bereits existiert!'),
(15368, 783, 5, 'Kann diesen Eintrag nicht hinzufügen/aktualisieren, da er bereits existiert!'),
(15369, 784, 5, 'kann nicht archiviert werden, nicht durchgeführt'),
(15370, 785, 5, 'kann nicht zu JPEG umgewandelt werden. Vielleicht ist ImageMagick nicht installiert?'),
(15371, 786, 5, 'kann nicht gelöscht werden, nicht durchgeführt'),
(15372, 787, 5, 'kann nicht dargestellt werden, da der Browser es nicht unterstützt.'),
(15373, 788, 5, 'kann nicht dargestellt werden, da der Browser es nicht unterstützt.'),
(15374, 789, 5, 'kann nicht dargestellt werden, da der Browser es nicht unterstützt.'),
(15375, 790, 5, 'Anlage nicht möglich'),
(15376, 795, 5, 'Suche ohne Ergebnis '),
(15377, 796, 5, 'Ziel-Dateiname nicht gefunden'),
(15378, 799, 5, 'Kann Klienten im SQL-Ledger customer id nicht finden'),
(15379, 800, 5, 'Kann Postcript Dokument referenz nicht finden '),
(15380, 801, 5, 'kann Leistungserbringer in SQL-Ledger angestellter nicht finden= '),
(15381, 803, 5, 'Öffnen nicht möglich '),
(15382, 804, 5, 'keine Forderung bei Versicherung. Kostenübernahme durch Patient'),
(15383, 805, 5, 'keine Forderung beim Patient. Kostenübernahme durch Versicherung'),
(15384, 806, 5, 'keine Fordeung möglich. Summe negativ.'),
(15385, 807, 5, 'Lesen nicht möglich'),
(15386, 808, 5, 'Verzeichnis kann nicht gelesen werden'),
(15387, 809, 5, 'Aktualisierung nicht möglich, da neuer Datensatz!'),
(15388, 810, 5, 'Hochgestellt'),
(15389, 812, 5, 'Kapsel'),
(15390, 813, 5, 'Karte'),
(15391, 814, 5, 'Herz-Katheterisierung'),
(15392, 815, 5, 'Herz Ultraschall'),
(15393, 816, 5, 'kardiovaskulär'),
(15394, 821, 5, 'Knorpelschaden'),
(15395, 822, 5, 'Knorpelverletzung'),
(15396, 823, 5, 'Carotis pulse normal, Fuß pulse normal'),
(15397, 824, 5, 'bar'),
(15398, 825, 5, 'Bar'),
(15399, 826, 5, 'nur in Bar'),
(15400, 827, 5, 'Quittung durch Behandler'),
(15401, 829, 5, 'Grauer Star Operation'),
(15402, 830, 5, 'Katarakte'),
(15403, 831, 5, 'Kategorien'),
(15404, 832, 5, 'Kategorien für'),
(15405, 833, 5, 'Kategorien'),
(15406, 834, 5, 'Kategorie'),
(15407, 835, 5, 'Kategorie '),
(15408, 836, 5, 'Kategoriedetails'),
(15409, 837, 5, 'Kategorielimits'),
(15410, 838, 5, 'Kategoriename'),
(15411, 839, 5, 'Kategoriename ist leer'),
(15412, 840, 5, 'Kategorie/Titel'),
(15413, 841, 5, 'Kaukasier'),
(15414, 842, 5, 'sorgt für Ausdruck des Leistungserbringer-Info'),
(15415, 850, 5, 'CDR'),
(15416, 851, 5, 'CDR Bericht Verarbeitungs Priorität'),
(15417, 852, 5, 'Zelle'),
(15418, 853, 5, 'Mobiltelefon'),
(15419, 854, 5, 'Mobiltelefonnummer'),
(15420, 855, 5, 'Mobiltelefonnummer'),
(15421, 856, 5, 'Zentrale Zertifizierung'),
(15422, 857, 5, 'Zentral/Südamerika'),
(15423, 858, 5, 'Certificate Authority CRT-Datei Speicherort kann nicht leer sein'),
(15424, 859, 5, 'Certificate Authority key-Datei Speicherort kann nicht leer sein'),
(15425, 860, 5, 'Zertifikat, das zum RFC 5425 TLS Syslog Server gesendet werden soll'),
(15426, 861, 5, 'Zertifizierter Benutzer'),
(15427, 862, 5, 'Zertifikate'),
(15428, 864, 5, 'ChampUS'),
(15429, 865, 5, 'ChampUSVA'),
(15430, 866, 5, 'ändern'),
(15431, 867, 5, 'Änderung'),
(15432, 868, 5, 'Änderungsaktivität'),
(15433, 869, 5, 'Wechsel fehlgeschlagen! Couch DB Verbindungsfehler?'),
(15434, 870, 5, 'Veränderung in Aussehen'),
(15435, 871, 5, 'Veränderung in Aussehen'),
(15436, 872, 5, 'Passwort ändern'),
(15437, 874, 5, 'Geändert'),
(15438, 875, 5, 'Veränderter Darm'),
(15439, 876, 5, 'Ändern der Patienten ID für Dokument'),
(15440, 877, 5, 'Besonderheiten'),
(15441, 878, 5, 'Zeichen übrig'),
(15442, 879, 5, 'Berechnen'),
(15443, 880, 5, 'Rechnungsanpassung'),
(15444, 881, 5, 'Honorar Code'),
(15445, 882, 5, 'Kosten'),
(15446, 883, 5, 'Diagramm'),
(15447, 884, 5, 'Diagramm Aktivität'),
(15448, 885, 5, 'Status IN/OUT Aktivitätsbericht'),
(15449, 886, 5, 'Akten-ID-nummer'),
(15450, 887, 5, 'Akten-ID-nummer'),
(15451, 889, 5, 'Akten Aktivitätsposition'),
(15452, 890, 5, 'Akteneintrag'),
(15453, 891, 5, 'Aktennummer'),
(15454, 892, 5, 'Akten Speicher positionen'),
(15455, 893, 5, 'Akten Lokalisierung'),
(15456, 894, 5, 'Akten Trk'),
(15457, 895, 5, 'Akten ausgesandt'),
(15458, 896, 5, 'Akten weg'),
(15459, 898, 5, 'Prüfung'),
(15460, 899, 5, 'prüfen'),
(15461, 900, 5, 'Alles prüfen'),
(15462, 902, 5, 'Kontroll Betrag'),
(15463, 903, 5, 'Kontroll Datum'),
(15464, 904, 5, 'Prüfe auf Differenzen mit benutzerdefinierten Sprachtabelle'),
(15465, 907, 5, 'Eingaben Prüfen'),
(15466, 909, 5, 'Laborbefund prüfen'),
(15467, 910, 5, 'checkmarke bedeutet geprüft'),
(15468, 911, 5, 'Kontroll Nr.'),
(15469, 912, 5, 'Nummer Prüfen'),
(15470, 915, 5, 'Scheckzahlung'),
(15471, 916, 5, 'Box aktivieren, wenn Datei verschlüsselt'),
(15472, 917, 5, 'Aktivieren, wenn Leistungserbringer alle Termine sehen sollen und nicht nur ihre eigenen'),
(15473, 918, 5, 'aktivieren um problem von Diagnose zu machen'),
(15474, 919, 5, 'Check/EOB Datum:'),
(15475, 920, 5, 'Check/EOB No.:'),
(15476, 921, 5, 'Check/Ref. Nummer'),
(15477, 922, 5, 'Check/Referenz Nummer'),
(15478, 923, 5, 'Checkbox Liste'),
(15479, 924, 5, 'checkbox Liste'),
(15480, 925, 5, 'checkbox mit Text'),
(15481, 926, 5, 'Checkbox mit Text'),
(15482, 928, 5, 'Angeklickt'),
(15483, 929, 5, 'Angeklickt = Ja, leer = Nein'),
(15484, 932, 5, 'Abmeldung'),
(15485, 933, 5, 'Kontrollsumme'),
(15486, 934, 5, 'Brust'),
(15487, 935, 5, 'Thorax CTAB'),
(15488, 936, 5, 'Thoraxbeschwerden'),
(15489, 937, 5, 'Thoraxbeschwerden:'),
(15490, 938, 5, 'Thoraxschmerz'),
(15491, 940, 5, 'Chg'),
(15492, 942, 5, 'Hauptbeschwerde'),
(15493, 943, 5, 'Kind'),
(15494, 945, 5, 'Kindheit Impfstatus'),
(15495, 946, 5, 'Schüttelfrost'),
(15496, 947, 5, 'Chinesisch'),
(15497, 948, 5, 'Chinesisch (vereinfacht)'),
(15498, 949, 5, 'Chinesisch (traditionel)'),
(15499, 951, 5, 'Optionen'),
(15500, 952, 5, 'Cholecystektomie'),
(15501, 954, 5, 'Cholecystektomie'),
(15502, 955, 5, 'Auswählen'),
(15503, 956, 5, 'klicke einen Artikel in einer Sektion, dann werden die korrespondierende artikel in der anderen Sektion markiert. Durch anklicken dieser Artikel kann man die Beziehung bestättigen oder aufheben.'),
(15504, 957, 5, 'Kriterium auswählen'),
(15505, 959, 5, 'Datei wählen'),
(15506, 960, 5, 'Von Liste wählen'),
(15507, 962, 5, 'Auswahlliste'),
(15508, 965, 5, 'Druckvormat für Besuch-Bericht wählen'),
(15509, 967, 5, 'Chronische Bronchitis'),
(15510, 968, 5, 'Chronische Gelenkbeschwerden'),
(15511, 969, 5, 'Chronische Nierenerkrankung'),
(15512, 970, 5, 'Chronische Synovitis / Gelenkschmerzen'),
(15513, 971, 5, 'Chronisch/Wiederkehrend'),
(15514, 973, 5, 'Leberzirrhose'),
(15515, 974, 5, 'Leberzirrhose'),
(15516, 975, 5, 'Stadt'),
(15517, 976, 5, 'Stadt'),
(15518, 977, 5, 'Stadt, Land'),
(15519, 978, 5, 'Stadt, Land, Postleitzahl'),
(15520, 979, 5, 'Stadt/Land'),
(15521, 980, 5, 'Antrag'),
(15522, 981, 5, 'Antrag '),
(15523, 982, 5, 'Antrag Status'),
(15524, 983, 5, 'Antrag-Test komplett durchgeführt'),
(15525, 984, 5, 'Antrag Art'),
(15526, 985, 5, 'Antrag in Datei geschrieben'),
(15527, 986, 5, 'Antrag in Datei geschrieben '),
(15528, 987, 5, 'Anträge'),
(15529, 988, 5, 'Einstufung'),
(15530, 989, 5, 'Löschen'),
(15531, 990, 5, 'LÖSCHE AKTIVEN PATIENT'),
(15532, 991, 5, 'Alles löschen'),
(15533, 992, 5, 'Lösche HL7 Daten'),
(15534, 993, 5, 'Lösche Begründung'),
(15535, 994, 5, 'Lösche Smarty Cache'),
(15536, 995, 5, 'Clearinghouse info nötig für EDI 270 Batchherstellung'),
(15537, 996, 5, 'CLIA-Nummer'),
(15538, 997, 5, 'Klick'),
(15539, 998, 5, '"export" anklicken um deine Kategorie, Unterkategorie, Artikel, Inhaltsdaten in eine Textdatei zu exportieren.'),
(15540, 999, 5, 'Klicke einen Punkt auf der Grafik um einen neue Anmerkung hinzuzufügen, klicke nochmal, um ihn zu entfernen'),
(15541, 1000, 5, 'Klicke Zertifikat herunterladen, um die Zertifikate als ZIP-Datei herunterzuladen'),
(15542, 1001, 5, 'Klick für weiter'),
(15543, 1002, 5, 'Klick für weitere Details'),
(15544, 1003, 5, 'Klick für Bestellübersicht'),
(15545, 1004, 5, 'Klick für Ergebnisse'),
(15546, 1005, 5, 'Hier klicken'),
(15547, 1006, 5, 'Hier klicken um neuen Klienten anzulegen'),
(15548, 1007, 5, 'Hier klicken um Unfallstatusveränderungen einzufügen und bearbeite tgl. Aktivität'),
(15549, 1008, 5, 'Hier klicken, um ein Datum zu wählen'),
(15550, 1009, 5, 'Hier klicken, um Datum und Zeit zu wählen'),
(15551, 1010, 5, 'Hier klicken, um Startzeit zu wählen'),
(15552, 1020, 5, 'Hier klicken, um zu suchen'),
(15553, 1021, 5, 'Hier klicken, um Priorität, Kategorie und Nickname zu aktualisieren'),
(15554, 1022, 5, 'Hier klicken, um alles zu sehen'),
(15555, 1023, 5, 'Hier klicken, um Graphen zu zeigen'),
(15556, 1025, 5, 'Hier klicken, um alle Vitalwerte anzuzeigen.'),
(15557, 1026, 5, 'Hier klicken, um Patientendetails zu sehen'),
(15558, 1027, 5, 'Hier klicken, um alle zu sehen.'),
(15559, 1028, 5, 'Hier klicken um weitere Details anzuzeigen/ändern'),
(15560, 1029, 5, 'Installieren-Schaltfläche klicken, um Datenbank-Release vom folgenden Datum zu installieren'),
(15561, 1030, 5, 'Klicken auf jeweiligen Zeitabschnitt um es zu erhöhen'),
(15562, 1031, 5, 'Patienten-Name anklicken, um Patientenakte zu öffnen'),
(15563, 1032, 5, 'Auf Aktualisieren klicken, um alle Ergebnisse zu sehen; oder oben Suchkriterium eingeben, um Ergebnisse einzuschränken'),
(15564, 1033, 5, 'Klicken, um eine Diagnose hinzuzufügen'),
(15565, 1034, 5, 'Klicken, um neue Komponenten hinzuzufügen'),
(15566, 1035, 5, 'Klicken, um neue Konsultationen hinzuzufügen'),
(15567, 1037, 5, 'Klicken zum Download'),
(15568, 1038, 5, 'Klicken zum Bearbeiten'),
(15569, 1039, 5, 'Klicken, um Beschreibung zu ändern'),
(15570, 1040, 5, 'Klicken, um Ereignis zu editieren'),
(15571, 1041, 5, 'Klicken, um Bericht zu generieren'),
(15572, 1043, 5, 'Klicken, um zu Drucken'),
(15573, 1044, 5, 'Klicken, um neues Los hinzuzufügen'),
(15574, 1045, 5, 'Klicken zum selektieren'),
(15575, 1046, 5, 'Klicken zum Selektieren'),
(15576, 1047, 5, 'Klicken, um einen Industrie-Standard Code hinzuzufügen für diesen Vorgang'),
(15577, 1048, 5, 'Klicken, um optionalen Vorgangs-Code auszuwählen'),
(15578, 1050, 5, 'Klicken, um CVX-Code auszuwählen oder zu ändern'),
(15579, 1051, 5, 'Klicken, um Diagnose zu selektieren/ändern'),
(15580, 1052, 5, 'Klicken, um Service-Codes auszuwählen oder zu ündern'),
(15581, 1053, 5, 'Klicken, um Patient auszuwählen'),
(15582, 1054, 5, 'Klicken, um zugehörigen Code auszuwählen'),
(15583, 1055, 5, 'Klicken, um Leistungen auszuwählen im Falle eines auffälligen Befundes'),
(15584, 1056, 5, 'Klicken, um die gewünschte Behandlung auszuwählen'),
(15585, 1057, 5, 'Klicken, um zu sortieren'),
(15586, 1058, 5, 'Klicken zum Betrachten'),
(15587, 1059, 5, 'Klicken zum Betrachten oder Bearbeiten'),
(15588, 1060, 5, 'Klicken zum Betrachten/Bearbeiten'),
(15589, 1061, 5, 'Auf Upgrade klicken, um Datenbank-Release des folgenden Datums einzuspielen'),
(15590, 1063, 5, 'Klicken:'),
(15591, 1064, 5, 'Gültigkeit des Client-Zertifikats'),
(15592, 1065, 5, 'Validierungszeitraum des Client-Zertifikats'),
(15593, 1066, 5, 'Validität des Client-Zertifikats muss eine Zahl sein.'),
(15594, 1067, 5, 'Klientenkopie'),
(15595, 1069, 5, 'Zusammenfassung der Anamnese'),
(15596, 1070, 5, 'Klient Name'),
(15597, 1071, 5, 'Klient Nummer'),
(15598, 1072, 5, 'Klienten Profil - neuer Klient'),
(15599, 1073, 5, 'Klienten Profil - spezifischer Klient'),
(15600, 1074, 5, 'Klienten'),
(15601, 1075, 5, 'Klinik'),
(15602, 1076, 5, 'Klinik Kopie'),
(15603, 1077, 5, 'Täglicher Klinik-Bericht'),
(15604, 1078, 5, 'Klinik-ID'),
(15605, 1079, 5, 'Klinisch'),
(15606, 1080, 5, 'Klinische Entscheidungs-Regel Alarm-Manager'),
(15607, 1081, 5, 'Klinischer Verlauf'),
(15608, 1083, 5, 'klinische Pläne'),
(15609, 1084, 5, 'Klinische Qualitätskriterien (CQM)'),
(15610, 1087, 5, 'Klinische Erinnerungen'),
(15611, 1088, 5, 'Klinische Berichte'),
(15612, 1089, 5, 'Klinische Regeln Aktionskategorie'),
(15613, 1090, 5, 'Klinische Regeln Einzelaktion'),
(15614, 1091, 5, 'Klinische Regeln Filtermethoden'),
(15615, 1092, 5, 'Klinische Regeln Zielmethoden'),
(15616, 1093, 5, 'Klinische Regeln'),
(15617, 1094, 5, 'Klinische Regeln Altersintervalle'),
(15618, 1095, 5, 'Klinische Regeln Vergleiche'),
(15619, 1096, 5, 'Klinische Regeln Besuchs-Typen'),
(15620, 1097, 5, 'Klinische Regeln Erinnerungs-Optionen'),
(15621, 1098, 5, 'Klinische Regeln Erinnerungs-Deaktivierungsoptionen'),
(15622, 1099, 5, 'Klinische Regeln Erinnerungsintervalle'),
(15623, 1100, 5, 'Klinische Regeln Erinnerungsmethoden'),
(15624, 1101, 5, 'Klinische Regeln Zielintervalle'),
(15625, 1102, 5, 'Klinische Zielwerte'),
(15626, 1103, 5, 'Klinische Bedingung'),
(15627, 1104, 5, 'Klinische Bedingung Code(s)'),
(15628, 1106, 5, 'Kliniker'),
(15629, 1107, 5, 'Kopieren'),
(15630, 1108, 5, 'Kopiere lezte Konsultation'),
(15631, 1109, 5, 'Schließen'),
(15632, 1111, 5, 'Fenster schließen'),
(15633, 1112, 5, 'Geschlossen'),
(15634, 1113, 5, 'cm'),
(15635, 1114, 5, 'CMS 1500 kantlijn'),
(15636, 1118, 5, 'CMS-ID'),
(15637, 1127, 5, 'CN2-12 intact'),
(15638, 1128, 5, 'Zuzahlung'),
(15639, 1129, 5, 'Zuzahlung bezahlt'),
(15640, 1130, 5, 'Zuzahlung'),
(15641, 1131, 5, 'Code'),
(15642, 1132, 5, 'code'),
(15643, 1133, 5, 'Code Finder'),
(15644, 1134, 5, 'Code muss 2 buchstaben kleingeschrieben sein'),
(15645, 1135, 5, 'Code oder Symbol für die Währung'),
(15646, 1136, 5, 'Code Text'),
(15647, 1138, 5, 'Code Typ'),
(15648, 1141, 5, 'Code Typen'),
(15649, 1142, 5, 'Code(s)'),
(15650, 1143, 5, 'Codiert'),
(15651, 1144, 5, 'Code'),
(15652, 1145, 5, 'Schlüssel'),
(15653, 1147, 5, 'Kodieren-beliebige Erreignisse'),
(15654, 1148, 5, 'Kodieren-meine Erreignise'),
(15655, 1149, 5, 'nicht autorisierter Kode'),
(15656, 1150, 5, 'Kaffee'),
(15657, 1152, 5, 'Mitversicherung'),
(15658, 1153, 5, 'Coll w/o'),
(15659, 1154, 5, 'Ausblenden'),
(15660, 1155, 5, 'ausblenden'),
(15661, 1156, 5, 'Alle Ausblenden'),
(15662, 1157, 5, 'Alle ausblenden'),
(15663, 1158, 5, 'alle ausblenden'),
(15664, 1160, 5, 'Erfassung Datum'),
(15665, 1161, 5, 'Bestände'),
(15666, 1162, 5, 'Bestandsbericht'),
(15667, 1163, 5, 'Kolon-Carcinom'),
(15668, 1164, 5, 'Kolon-Carcinom Screening'),
(15669, 1165, 5, 'Kolon-Caricinom-Chirurgie'),
(15670, 1166, 5, 'Koloskopie'),
(15671, 1167, 5, 'Koloskopie'),
(15672, 1168, 5, 'Farbe'),
(15673, 1169, 5, 'Farbe:Abbr'),
(15674, 1170, 5, 'Spalte'),
(15675, 1171, 5, 'Spalten'),
(15676, 1172, 5, 'kombinierbare positionen'),
(15677, 1173, 5, 'Komma'),
(15678, 1174, 5, 'Kommentar'),
(15679, 1175, 5, 'Kommentare'),
(15680, 1176, 5, 'Kommentare / Empfehlungen zu diesem Ergebnis'),
(15681, 1177, 5, 'private Versicherungsanstalt'),
(15682, 1178, 5, 'Änderungen eintragen'),
(15683, 1180, 5, 'Kommunikationen'),
(15684, 1182, 5, 'Firma'),
(15685, 1183, 5, 'Firmenname'),
(15686, 1184, 5, 'Fertig'),
(15687, 1186, 5, 'Fertiggestellt'),
(15688, 1188, 5, 'Fertig?'),
(15689, 1190, 5, 'Komplikationen durch Leistungserbringer'),
(15690, 1191, 5, 'Komplikationen durch Abort'),
(15691, 1192, 5, 'Komponenten'),
(15692, 1193, 5, 'Computergestütztes medizinisches Bestellsystem'),
(15693, 1194, 5, 'Schlußfolgerungen');
INSERT INTO `lang_definitions` VALUES
(15694, 1199, 5, 'Konfiguration'),
(15695, 1200, 5, 'Export/Import konfigurieren'),
(15696, 1202, 5, 'Apache und LibreEHR konfigurieren, um clientseitige SSL-Zertifikate zu verwenden'),
(15697, 1203, 5, 'Apache konfigurieren, um clientseitige SSL-Zertifikate zu verwenden'),
(15698, 1204, 5, 'Apache konfigurieren, um HTTPS zu verwenden'),
(15699, 1205, 5, 'LibreEHR konfigurieren, um clientseitige SSL-Zertifikate zu verwenden'),
(15700, 1208, 5, 'Neuen Patient jetzt anlegen'),
(15701, 1209, 5, 'Bestätige neues Passwort'),
(15702, 1210, 5, 'Bestätige Zahlung'),
(15703, 1214, 5, 'kongenital'),
(15704, 1215, 5, 'Konjunktiva, Pupillen'),
(15705, 1217, 5, 'Konnektoren'),
(15706, 1218, 5, 'Konstante'),
(15707, 1219, 5, 'Konstantenname'),
(15708, 1220, 5, 'Konstantenname ist leer'),
(15709, 1221, 5, 'Konstanten'),
(15710, 1222, 5, 'Obstipation'),
(15711, 1223, 5, 'Konstitutionell'),
(15712, 1226, 5, 'Kurzbeschreibung der Konsultation'),
(15713, 1227, 5, 'Kontakt'),
(15714, 1228, 5, 'Email-Kontakt'),
(15715, 1229, 5, 'Email-Kontaktadresse'),
(15716, 1230, 5, 'Kontaktiere EMR Direct um phiMail Direct messaging zu abonieren'),
(15717, 1231, 5, 'Kontaktinformation'),
(15718, 1232, 5, 'Kontaktlinsen'),
(15719, 1233, 5, 'Kontaktiere EDV Abteilung für Laboranbindung'),
(15720, 1234, 5, 'Kontaktiere EDV Abteilung'),
(15721, 1236, 5, 'Kontaktname'),
(15722, 1237, 5, 'Kontaktperson'),
(15723, 1239, 5, 'Kontakttelefonnummer'),
(15724, 1240, 5, 'Kontaktiere ZMG, LLC (zmghealth@gmail.com), um Dich für den eRx-Service zu registrieren'),
(15725, 1241, 5, 'enthalten mindestens drei der vier folgenden Dinge:'),
(15726, 1242, 5, 'Kontainer Gruppenname'),
(15727, 1243, 5, 'Inhalt'),
(15728, 1244, 5, 'Inhalt'),
(15729, 1245, 5, 'Kontext'),
(15730, 1246, 5, 'Kontext-Name darf nicht leer sein'),
(15731, 1247, 5, 'Weiter'),
(15732, 1248, 5, 'Continuity of Care Document (CCD)'),
(15733, 1249, 5, 'Continuity of Care Record (CCR)'),
(15734, 1250, 5, 'Kontra Klienten'),
(15735, 1251, 5, 'Empfängnisverhütung'),
(15736, 1252, 5, 'Probleme mit Empfängnisverhütung'),
(15737, 1253, 5, 'Probleme mit Empfängnisverhütung (spezifiziert)'),
(15738, 1254, 5, 'Verhütungsmethode'),
(15739, 1255, 5, 'Verhütungsmittel'),
(15740, 1256, 5, 'Verhütungsmassnahme bereits eingesetzt'),
(15741, 1257, 5, 'Beginn Verhütung'),
(15742, 1258, 5, 'Kontroll ID'),
(15743, 1259, 5, 'Kontroll Nr.'),
(15744, 1261, 5, 'Zuzahlung'),
(15745, 1262, 5, 'Zuzahlung'),
(15746, 1263, 5, 'Zuzahlung'),
(15747, 1264, 5, 'Zuzahlung nicht möglich'),
(15748, 1266, 5, 'Zuzahlungen'),
(15749, 1267, 5, 'COPD'),
(15750, 1268, 5, 'Seiten zum Patienten-Diagramm kopieren'),
(15751, 1269, 5, 'Werte kopieren'),
(15752, 1270, 5, 'Kopiere die Datenbank. Dies wird eine Weile dauern...'),
(15753, 1271, 5, 'Lizenzbestimmungen'),
(15754, 1273, 5, 'Koronalarterieller Bypass'),
(15755, 1274, 5, 'Koronalarterieller Bypass Transplantat'),
(15756, 1275, 5, 'Korrigiert'),
(15757, 1277, 5, 'CouchDB'),
(15758, 1278, 5, 'CouchDB-Verbindung fehlgeschlagen'),
(15759, 1279, 5, 'CouchDB-Datenbank'),
(15760, 1280, 5, 'CouchDB Datenbankname'),
(15761, 1281, 5, 'CouchDB Host'),
(15762, 1282, 5, 'CouchDB HostName'),
(15763, 1283, 5, 'CouchDB Log aktiviert'),
(15764, 1284, 5, 'CouchDB Passwort'),
(15765, 1285, 5, 'CouchDB Port'),
(15766, 1286, 5, 'CouchDB Port'),
(15767, 1288, 5, 'CouchDB Nutzername'),
(15768, 1289, 5, 'Husten'),
(15769, 1290, 5, 'Husten:'),
(15770, 1294, 5, 'Datei kann nicht gelesen werden'),
(15771, 1296, 5, 'Konnte E-Mail wegen Server-Problemen nicht senden, '),
(15772, 1297, 5, 'Konnte E-Mail wegen Server-Problemen nicht senden, '),
(15773, 1298, 5, 'Konnte Backup-Verzeichnis nicht erstellen'),
(15774, 1299, 5, 'Konnte Verzeichnis nicht löschen:'),
(15775, 1300, 5, 'Konnte alte Backup-Datei nicht löschen:'),
(15776, 1301, 5, 'Konnte alte Export-Datei nicht löschen'),
(15777, 1302, 5, 'INR-Kontrolle'),
(15778, 1303, 5, 'Beratung nach Methode'),
(15779, 1304, 5, 'Beratung'),
(15780, 1305, 5, 'Beratungsaktivitäten'),
(15781, 1306, 5, 'Rücküberweisung Form'),
(15782, 1307, 5, 'Rücküberweisung'),
(15783, 1308, 5, 'Land'),
(15784, 1309, 5, 'Länder Datentyp'),
(15785, 1310, 5, 'Länderliste'),
(15786, 1311, 5, 'Länderliste (schreiben, hinzufügen optional)'),
(15787, 1312, 5, 'Zweistelliger Ländercode (z.B. USA = US)'),
(15788, 1313, 5, 'Bezirk'),
(15789, 1315, 5, 'Coupon'),
(15790, 1318, 5, 'CPT'),
(15791, 1319, 5, 'CPT-Code'),
(15792, 1320, 5, 'CPT-Codes'),
(15793, 1321, 5, 'CPT4-Behandlung'),
(15794, 1322, 5, 'CPTII Performance Messung'),
(15795, 1323, 5, 'CQM'),
(15796, 1324, 5, 'Rasselgeräusch:'),
(15797, 1325, 5, 'Sahne'),
(15798, 1326, 5, 'Erstelle ein clientseitiges SSL-Zertifikat für jeden Benutzer oder jeden Client-Rechner'),
(15799, 1327, 5, 'Erstelle ein clientseitiges SSL-Zertifikat für entweder einen Benutzer oder einen Client-Hostname'),
(15800, 1329, 5, 'Ereignis erstellen'),
(15801, 1330, 5, 'Vollbackup erstellung und herunterladen'),
(15802, 1332, 5, 'Backup erstellen'),
(15803, 1333, 5, 'Stapel erstellen'),
(15804, 1334, 5, 'Client-Zertifikat erstellen'),
(15805, 1335, 5, 'Clientseitige SSL-Zertifikate erstellen'),
(15806, 1336, 5, 'Erzeuge Duplikat'),
(15807, 1338, 5, 'Erzeuge Ereignis-Log Backup'),
(15808, 1339, 5, 'Erzeuge neuen Fall'),
(15809, 1340, 5, 'Neuen Patienten anlegen'),
(15810, 1342, 5, 'Erstelle Zugangsdaten für Offsite-Patientenportal'),
(15811, 1343, 5, 'Erstelle Zugangsdaten für Onsite-Patientenportal'),
(15812, 1344, 5, 'Patientennotiz erstellen'),
(15813, 1345, 5, 'Erstelle SSL-Zertifikat-Authority und Server-Zertifikate'),
(15814, 1346, 5, 'Neue Konsultation'),
(15815, 1347, 5, 'Angelegt'),
(15816, 1348, 5, 'Datei exportieren'),
(15817, 1350, 5, 'Fehler beim erstellen dieser Datei auf dem Remote-Host'),
(15818, 1351, 5, 'Ersteller'),
(15819, 1352, 5, 'Kredit'),
(15820, 1353, 5, 'Kreditkarte'),
(15821, 1354, 5, 'Kredite'),
(15822, 1356, 5, 'Kriterium'),
(15823, 1358, 5, 'Morbus Crohn'),
(15824, 1359, 5, 'Morbus Crohn'),
(15825, 1360, 5, 'CSV Export'),
(15826, 1361, 5, 'CSV-Datei'),
(15827, 1362, 5, 'CSV-Tabelle'),
(15828, 1363, 5, 'CU MM'),
(15829, 1364, 5, 'Kubaner'),
(15830, 1365, 5, 'Aktuelle Währung Dezimalstellen'),
(15831, 1366, 5, 'Aktuelles Dezialpunkt Symbol'),
(15832, 1367, 5, 'Aktuelle Währung Kennung'),
(15833, 1368, 5, 'Aktueller Tausender-Trenner'),
(15834, 1369, 5, 'Aktuell'),
(15835, 1370, 5, 'Aktueller Alkoholkonsum'),
(15836, 1371, 5, 'Aktuelle Konsultation'),
(15837, 1372, 5, 'Aktuelles Kriterium'),
(15838, 1373, 5, 'Aktuelle Tag-Markierung Farbe'),
(15839, 1374, 5, 'Aktuell Raucher täglich'),
(15840, 1375, 5, 'Aktuelle Datei wurde geändert zu'),
(15841, 1376, 5, 'aktueller Hash'),
(15842, 1377, 5, 'Aktueller Standort'),
(15843, 1378, 5, 'Aktuelle Medikamente'),
(15844, 1379, 5, 'Aktuelles Passwort'),
(15845, 1380, 5, 'Aktueller Patient'),
(15846, 1382, 5, 'Aktuelle Freizeitdrogen'),
(15847, 1383, 5, 'Aktuell Raucher gelegentlich'),
(15848, 1386, 5, 'Aktiv'),
(15849, 1387, 5, 'Aktiv'),
(15850, 1388, 5, 'Aktuell keine Standorte vorhanden.'),
(15851, 1389, 5, 'Cushing-Syndrom'),
(15852, 1390, 5, 'Cushing-Syndrom'),
(15853, 1392, 5, 'Angepasst'),
(15854, 1393, 5, 'Benutzerdefinierte eingabe?'),
(15855, 1394, 5, 'Benutzerdefinierte Tabelle'),
(15856, 1396, 5, 'CVX-Code'),
(15857, 1397, 5, 'CVX-Code Mapping'),
(15858, 1398, 5, 'CVX-Impfung'),
(15859, 1399, 5, 'Zyklus'),
(15860, 1400, 5, 'CYP'),
(15861, 1401, 5, 'CYP-Faktor'),
(15862, 1402, 5, 'CYP-Bericht'),
(15863, 1403, 5, 'Tschechisch'),
(15864, 1404, 5, 'D'),
(15865, 1405, 5, 'D&C'),
(15866, 1406, 5, 'D&E'),
(15867, 1407, 5, 'Geb'),
(15868, 1408, 5, 'täglich'),
(15869, 1409, 5, 'Tägliche Aufzeichnung'),
(15870, 1410, 5, 'Dänisch'),
(15871, 1411, 5, 'Ähnliche Daten bereits in der Datenbank, bitte ändere Code und/oder Beschreibung'),
(15872, 1412, 5, 'Ähnliche Daten bereits in der Datenbank, bitte ändere den Konstantennamen'),
(15873, 1413, 5, 'Daten-Spalten'),
(15874, 1416, 5, 'Daten-Fehler'),
(15875, 1420, 5, 'Datentyp'),
(15876, 1421, 5, 'Datenbank'),
(15877, 1422, 5, 'Datenbank ist nicht installiert.'),
(15878, 1423, 5, 'Datenbank-Patch'),
(15879, 1424, 5, 'Datenbank-Berichtswesen'),
(15880, 1425, 5, 'Datenbankaktualisierung beendet'),
(15881, 1426, 5, 'Datenspalten muss zwischen 1 und 999 liegen'),
(15882, 1427, 5, 'Datum'),
(15883, 1428, 5, 'DATUM'),
(15884, 1429, 5, 'Datum & Zeit Verabreichung'),
(15885, 1431, 5, 'Datum der Verabreichung'),
(15886, 1432, 5, 'Datum und Uhrzeit der Probeentnahme'),
(15887, 1433, 5, 'Datum und Uhrzeit dieser Beobachtung'),
(15888, 1435, 5, 'Datum und Uhrzeit der Probeentnahme'),
(15889, 1436, 5, 'Datum kann nicht größer als "heute" sein'),
(15890, 1437, 5, 'Datum des Beginns der Verhütungsmaßnahme'),
(15891, 1438, 5, 'Erstellungsdatum'),
(15892, 1439, 5, 'Datum Verstorben'),
(15893, 1440, 5, 'Datum zerstört'),
(15894, 1441, 5, 'Datumsanzeige-Format'),
(15895, 1442, 5, 'Datumsformat für "Termin Ende" ungültig'),
(15896, 1443, 5, 'Datumsformat für "Termin Start" ungültig'),
(15897, 1444, 5, 'Datumsformat für "nächster Termin" ungültig'),
(15898, 1445, 5, 'Datumsformat für "nicht gesehen seit" ungültig'),
(15899, 1446, 5, 'Datumsformat für "gesehen seit" ungültig'),
(15900, 1447, 5, 'Datum der Impungs Information'),
(15901, 1448, 5, 'Datum für Code fehlt '),
(15902, 1449, 5, 'Datum Haupt Kriterium'),
(15903, 1450, 5, 'Datum der Bankeinzahlung jjjj-mm-tt'),
(15904, 1451, 5, 'Datum der Rechnungsstellung'),
(15905, 1452, 5, 'Geburtsdatum'),
(15906, 1453, 5, 'Geburtsdatum'),
(15907, 1454, 5, 'Geburtsdatum'),
(15908, 1455, 5, 'Datum der Eintragung'),
(15909, 1456, 5, 'Unfallzeitpunkt'),
(15910, 1458, 5, 'Datum der Bezahlung jjjj-mm-tt'),
(15911, 1459, 5, 'Datum der Überweisung'),
(15912, 1460, 5, 'Datum der Antwort'),
(15913, 1461, 5, 'Datum des Berichts'),
(15914, 1462, 5, 'Datum der Dienstleistung'),
(15915, 1463, 5, 'Datum der Dienstleistung'),
(15916, 1464, 5, 'Datum der Dienstleistung = Heute'),
(15917, 1465, 5, 'Datum der Dienstleistung mm/tt/jjjj'),
(15918, 1466, 5, 'Datum der Dienstleistung:'),
(15919, 1467, 5, 'Datum der Unterschrift'),
(15920, 1468, 5, 'Datum der Status Änderung'),
(15921, 1469, 5, 'Datum dieser Bestellung'),
(15922, 1470, 5, 'Datum dieses Berichts'),
(15923, 1471, 5, 'Datum der VIS Information'),
(15924, 1472, 5, 'Bestelldatum'),
(15925, 1475, 5, 'Datumsauswahl'),
(15926, 1476, 5, 'Datum der Übermittlung'),
(15927, 1477, 5, 'Datum an der die Nachricht versendet wurde.'),
(15928, 1479, 5, 'Datum darf nicht leer sein.'),
(15929, 1480, 5, 'Datum/Appt'),
(15930, 1481, 5, 'Datum/Bemerkung'),
(15931, 1482, 5, 'Datum/letzte Bemerkung'),
(15932, 1483, 5, 'Datum/Zeit'),
(15933, 1484, 5, 'Datum:'),
(15934, 1485, 5, 'Datiertes Nachrichtenprotokoll'),
(15935, 1486, 5, 'Tag'),
(15936, 1487, 5, 'Tag'),
(15937, 1489, 5, 'Tagesansicht'),
(15938, 1490, 5, 'Tag(e)'),
(15939, 1491, 5, 'Werktag(e)'),
(15940, 1492, 5, 'Tage'),
(15941, 1493, 5, 'Tage'),
(15942, 1494, 5, 'Tagen'),
(15943, 1495, 5, 'verpasste Tage und Spiele'),
(15944, 1496, 5, 'Tage seit letztem Fall'),
(15945, 1497, 5, 'Tage versäumt'),
(15946, 1498, 5, 'Tage pro Spalte'),
(15947, 1500, 5, 'Tage/Col:'),
(15948, 1501, 5, 'Datenbank installiert'),
(15949, 1502, 5, 'TT/MM/JJJJ'),
(15950, 1503, 5, 'De Identifizierung'),
(15951, 1504, 5, 'De Identifizierungsprozess abgeschlossen'),
(15952, 1505, 5, 'De Identifizierungsprozess ist im Gange'),
(15953, 1506, 5, 'De Identifizierungsprozess wurde gestartet und läuft im Hintergrund'),
(15954, 1507, 5, 'De Identifizierungsdaten sind möglicherweise nicht komplett'),
(15955, 1508, 5, 'De Identifizierungsdateien werden gespeichert in'),
(15956, 1509, 5, 'DEA'),
(15957, 1511, 5, 'Taub'),
(15958, 1512, 5, 'Debug-Information'),
(15959, 1514, 5, 'Debugging'),
(15960, 1515, 5, 'Dez'),
(15961, 1516, 5, 'VERSTORBEN'),
(15962, 1517, 5, 'Dezember'),
(15963, 1518, 5, 'dezimal pfund oder pfund und onze getrennt durch # (z.B. 5#4)'),
(15964, 1520, 5, 'absetzbar'),
(15965, 1521, 5, 'Selbstbehalt Met'),
(15966, 1522, 5, 'Standard'),
(15967, 1523, 5, 'Standard Kalenderansicht'),
(15968, 1524, 5, 'Standard Termin Formular ID'),
(15969, 1526, 5, 'Standard Einrichtung'),
(15970, 1527, 5, 'Standard Sprache'),
(15971, 1528, 5, 'Standard-Sprache, wenn keine anderen erlaubt oder gewählt.'),
(15972, 1529, 5, 'Voreingestellte Liste (schreibbar, optional nur hinzufügen erlaubt)'),
(15973, 1530, 5, 'Standard Methode'),
(15974, 1531, 5, 'Standard Passwort Verfall Tage'),
(15975, 1532, 5, 'Standard Passwort Gültigkeits Zeitspanne in Tagen. 0 = Funktion ist deaktiviert.'),
(15976, 1533, 5, 'Standard Patienten Land'),
(15977, 1535, 5, 'Standard Priorität'),
(15978, 1536, 5, 'Voreingestellter Zulieferer'),
(15979, 1537, 5, 'Standard Bereich'),
(15980, 1538, 5, 'Standard Grund für Konsultation'),
(15981, 1540, 5, 'Standard Einstellung'),
(15982, 1541, 5, 'Standard der Neues-Fenster-Checkbox in der Patientenliste'),
(15983, 1542, 5, 'Standard Vorlage'),
(15984, 1546, 5, 'Standardeinheit'),
(15985, 1547, 5, 'Voreingestellter Wert'),
(15986, 1548, 5, 'Standard Lager'),
(15987, 1549, 5, 'Voreingestellter X12-Partner'),
(15988, 1550, 5, 'Voreingestellt/Global'),
(15989, 1551, 5, 'Entf'),
(15990, 1552, 5, 'entf'),
(15991, 1553, 5, 'Spätrezidiv (>12 Monate)'),
(15992, 1554, 5, 'Entfernen'),
(15993, 1555, 5, 'entfernen'),
(15994, 1556, 5, 'Lösche Kategorien mit ID(s): '),
(15995, 1557, 5, 'Lösche Kategorie'),
(15996, 1559, 5, 'Löschen fehlgeschlagen!'),
(15997, 1560, 5, 'Lösche Gruppe'),
(15998, 1561, 5, 'Liste entfernen'),
(15999, 1562, 5, 'Seiten entfernen'),
(16000, 1563, 5, 'Lösche Patient, Fall, Formular, Problem, Dokument, Zahlungsvorgang, Berechung, Transaktion'),
(16001, 1565, 5, 'Lösche Reihe'),
(16002, 1566, 5, 'Lösche selektiertes Element'),
(16003, 1568, 5, 'Löschen erfolgreich'),
(16004, 1569, 5, 'Lösche dieses Dokument'),
(16005, 1570, 5, 'Lösche dieses Formular'),
(16006, 1571, 5, 'Lösche diese Anmerkung'),
(16007, 1573, 5, 'Erfogreich gelöscht.'),
(16008, 1574, 5, 'Löschen'),
(16009, 1575, 5, 'Das Löschen dieses Ereignis kann nicht rückgängig gemacht werden. Dieses Ereignis wirklich löschen?'),
(16010, 1576, 5, 'Zustellung bestätigt'),
(16011, 1578, 5, 'Direkte Zustellung an die angegebene Adresse ist zu Zeit nicht erlaubt'),
(16012, 1580, 5, 'Versenden des beigefügten klinischen Dokumentes war vom Patienten angefordert'),
(16013, 1581, 5, 'Demenz'),
(16014, 1582, 5, 'Persönliche Daten'),
(16015, 1583, 5, 'Personliche Daten (schreibbar, optional nur hinzufügen erlaubt)'),
(16016, 1585, 5, 'Filter für persönliche Daten'),
(16017, 1586, 5, 'Persönliche Daten nicht erlaubt'),
(16018, 1587, 5, 'Persönliche Daten nicht erlaubt.'),
(16019, 1588, 5, 'Verweigert'),
(16020, 1589, 5, 'Nenner'),
(16021, 1590, 5, 'Zähne betreffend(e)'),
(16022, 1591, 5, 'Zahnbeschwerden Liste'),
(16023, 1592, 5, 'Zahnbeschwerden'),
(16024, 1595, 5, 'je nach Type Rechnung , den du testest, siehst du HCFA-ähnlichen Ergebniss auf leeren blatt'),
(16025, 1596, 5, 'Datum Einzahlung'),
(16026, 1597, 5, 'Einzahl-Datum kann nicht später als heute sein'),
(16027, 1598, 5, 'Datum Einzahlung:'),
(16028, 1599, 5, 'deprimiert'),
(16029, 1600, 5, 'Depression'),
(16030, 1602, 5, 'Beschreibung'),
(16031, 1603, 5, 'Beschreibung'),
(16032, 1605, 5, 'Beschreibung der Mitteilung'),
(16033, 1606, 5, 'Beschreibung dieses Verfahrens oder Ergebnis-Code'),
(16034, 1607, 5, 'Übersetzung der Beschreibung'),
(16035, 1609, 5, 'Ziel'),
(16036, 1610, 5, 'Ziel Dateiname'),
(16037, 1611, 5, 'Nummer verwerfen'),
(16038, 1612, 5, 'Verwerfen...'),
(16039, 1613, 5, 'Verworfen'),
(16040, 1614, 5, 'Medikamente verwerfen'),
(16041, 1615, 5, 'Bericht über verworfene Medikamente'),
(16042, 1616, 5, 'Detail'),
(16043, 1617, 5, 'Details'),
(16044, 1619, 5, 'Entwicklungsstörung'),
(16045, 1620, 5, 'Diabetes'),
(16046, 1621, 5, 'Diabetes Mellitus'),
(16047, 1622, 5, 'Diabetes: Blutdruck Management'),
(16048, 1623, 5, 'Diabetes: Augenuntersuchung'),
(16049, 1624, 5, 'Diabetes: Augenuntersuchung (CQM)'),
(16050, 1625, 5, 'Diabetes: Fußuntersuchung'),
(16051, 1626, 5, 'Diabetes: Fußuntersuchung (CQM)'),
(16052, 1627, 5, 'Diabetes: HbA1c Kontrolle'),
(16053, 1628, 5, 'Diabetes: HbA1c'),
(16054, 1629, 5, 'Diabetes: LDL-Einstellung & Kontrolle (CQM)'),
(16055, 1630, 5, 'Diabetes: Urin Microalbumin'),
(16056, 1631, 5, 'Diag'),
(16057, 1632, 5, 'Diagnose'),
(16058, 1633, 5, 'Diagnose'),
(16059, 1634, 5, 'Diagnose Code'),
(16060, 1636, 5, 'Diagnose Datum'),
(16061, 1637, 5, 'Diagnose muß in einem verknüpften Fall kodiert werden'),
(16062, 1638, 5, 'Diagnose Name'),
(16063, 1639, 5, 'Diagnose Bericht'),
(16064, 1640, 5, 'Diagnose Berichterstattung'),
(16065, 1641, 5, 'Diagnose Berichterstattung alleine'),
(16066, 1642, 5, 'Diagnose Titel'),
(16067, 1643, 5, 'Diagnose:'),
(16068, 1644, 5, 'Diagnose: '),
(16069, 1645, 5, 'Diagnostischer Test:'),
(16070, 1646, 5, 'Skalen'),
(16071, 1647, 5, 'Diaphragmen / Caps'),
(16072, 1648, 5, 'Diarrhoe'),
(16073, 1650, 5, 'Diktat'),
(16074, 1651, 5, 'Diktat: '),
(16075, 1652, 5, 'Haben Sie eine Kopie der HIPAA-Hinweise erhalten?'),
(16076, 1653, 5, 'Diffuse:'),
(16077, 1654, 5, 'Digital Signiert'),
(16078, 1657, 5, 'Direkte Mail'),
(16079, 1658, 5, 'Direktnachrichten Log'),
(16080, 1659, 5, 'Direktnachrichten erhalten.'),
(16081, 1660, 5, 'Direktnachrichten zur Zeit nicht verfügbar.'),
(16082, 1661, 5, 'Senden der Direktnachrichten fehlgeschlagen.'),
(16083, 1663, 5, 'Direktor Name'),
(16084, 1664, 5, 'Verzeichniss löschen fehlgeschlagen; fortsetzen.'),
(16085, 1665, 5, 'Behinderung'),
(16086, 1667, 5, 'Deaktiviere Kalender'),
(16087, 1668, 5, 'Deaktiviere Größentabelle Tracker'),
(16088, 1669, 5, 'Deaktiviere Impfungen'),
(16089, 1670, 5, 'Deaktiviere Old Metric Vitalfunktionen Formular'),
(16090, 1672, 5, 'Deaktiviere "phpMyAdmin"'),
(16091, 1673, 5, 'Deaktiviere Rezepte'),
(16092, 1674, 5, 'Deaktiviere Anwender Gruppen'),
(16093, 1675, 5, 'deaktiviert'),
(16094, 1676, 5, 'Deaktiviert'),
(16095, 1677, 5, 'behinderte Begünstigte unter 65j. mit Large Group Health plan'),
(16096, 1678, 5, 'DISC'),
(16097, 1681, 5, 'Ausscheidung'),
(16098, 1682, 5, 'Ausscheidung aus Urethra'),
(16099, 1684, 5, 'Entlassungsrrecht'),
(16100, 1685, 5, 'Entlassungsrechts'),
(16101, 1688, 5, 'Entlassung'),
(16102, 1689, 5, 'Mitteilung Info'),
(16103, 1690, 5, 'Mitteilung Type'),
(16104, 1691, 5, 'Mitteilung Typen'),
(16105, 1692, 5, 'Mitteilung'),
(16106, 1694, 5, 'Rabatt'),
(16107, 1695, 5, 'Rabatt Betrag'),
(16108, 1696, 5, 'Rabattstufen'),
(16109, 1697, 5, 'Rabatt Prozent'),
(16110, 1698, 5, 'Rabatte als Geldbetrag'),
(16111, 1699, 5, 'Ermäßigung auf Checkout Zeit wird als geld menge eingegeben und nicht in prozent'),
(16112, 1700, 5, 'Diskretes Ergebnis'),
(16113, 1701, 5, 'Erkrankung'),
(16114, 1702, 5, 'Dislokation'),
(16115, 1703, 5, 'Disloz. #'),
(16116, 1704, 5, 'Versand'),
(16117, 1705, 5, 'Versandort Dokument'),
(16118, 1706, 5, 'verzichtet'),
(16119, 1707, 5, 'Anzeige Patientenverfügungen in der Patientendaten-Seite.'),
(16120, 1709, 5, 'Ereignisdaten im Block anzeigen?'),
(16121, 1710, 5, 'Anzeigeformat für US Gewichte'),
(16122, 1711, 5, 'Anzahl der Ereignisse anzeigen?'),
(16123, 1713, 5, 'Ort in Großbuchstaben darstellen'),
(16124, 1714, 5, 'Zeige Name'),
(16125, 1715, 5, 'Zeige Kalender?'),
(16126, 1718, 5, 'Heutige Ereignisse im Block anzeigen'),
(16127, 1719, 5, 'Thema im Blick anzeigen?'),
(16128, 1720, 5, 'Zukünftige Ereignisse im Block anzeigen'),
(16129, 1721, 5, 'Angezeigte Spalten'),
(16130, 1722, 5, 'Zeige folgende zahl von Entlassungen'),
(16131, 1723, 5, 'Zeige die folgende Anzahl von jüngsten Notizen'),
(16132, 1724, 5, 'Zeige die folgende Anzahl von jüngsten Notizen:'),
(16133, 1725, 5, 'Verteilung'),
(16134, 1726, 5, 'Verteilungen'),
(16135, 1727, 5, 'Verteiler'),
(16136, 1729, 5, 'Divertikulitis'),
(16137, 1730, 5, 'Divertikulitis-Chirurgie'),
(16138, 1731, 5, 'Divertikulitis'),
(16139, 1732, 5, 'Divertikulitis-Chirurgie'),
(16140, 1733, 5, 'Geschieden'),
(16141, 1734, 5, 'Schwindel'),
(16142, 1735, 5, 'Nicht verändern'),
(16143, 1737, 5, 'Allergie nicht zeigen wenn aufgeladen in NewCrop'),
(16144, 1739, 5, 'Medikamente nicht zeigen wenn aufgeladen in NewCrop'),
(16145, 1742, 5, 'Kalender nicht zeigen'),
(16146, 1744, 5, 'keine Inventur durchführen oder Produkte verkaufen'),
(16147, 1745, 5, 'Benötige keine Patienten Notizen zum Autorisieren'),
(16148, 1746, 5, 'Anordnung zum Verzicht auf Wiederbelebung'),
(16149, 1747, 5, 'nicht speichern'),
(16150, 1748, 5, 'nicht ersetzen'),
(16151, 1749, 5, 'tue nichts'),
(16152, 1751, 5, 'Wollen Sie wirklich löschen'),
(16153, 1752, 5, 'Wollen Sie wirklich die selektierte löschen?'),
(16154, 1753, 5, 'Wollen Sie wirklich diese Gruppe löschen?'),
(16155, 1755, 5, 'Wollen Sie forfahren?'),
(16156, 1756, 5, 'Wollen Sie das löschen?'),
(16157, 1757, 5, 'Wollen Sie löschen?'),
(16158, 1758, 5, 'Diese Aufzeichnung entfernen?'),
(16159, 1759, 5, 'Willst Du fortfahren, den Patienten hinzuzufügen?'),
(16160, 1760, 5, 'Willst Du mit dem neuen Namen fortfahren?'),
(16161, 1761, 5, 'Willst Du den Impf-Eintrag endgültig löschen?'),
(16162, 1762, 5, 'Geburtstag'),
(16163, 1763, 5, 'Geburtstag fehlt, bitte eingeben'),
(16164, 1764, 5, 'Docs'),
(16165, 1765, 5, 'Arzt'),
(16166, 1766, 5, 'Arzt:'),
(16167, 1767, 5, 'Name und Unterschrift des Arztes'),
(16168, 1768, 5, 'Dokument'),
(16169, 1769, 5, 'Dokument'),
(16170, 1770, 5, 'Dokumenten-Kategorie'),
(16171, 1775, 5, 'Dokument kann nicht verschoben werden zu Patienten id'),
(16172, 1777, 5, 'Dokument Datum'),
(16173, 1778, 5, 'Dokumentendatum und Problem erfolgreich geändert'),
(16174, 1779, 5, 'Dokument ID'),
(16175, 1780, 5, 'Dokument verschoben in neue Kategorie'),
(16176, 1781, 5, 'Dokument verschoben zu Patien id'),
(16177, 1783, 5, 'Dokument Integritätstest erfolgreich.'),
(16178, 1784, 5, 'Dokument Speichermethode'),
(16179, 1785, 5, 'Dokument erfolgreich umbenannt.'),
(16180, 1790, 5, 'Dokumente/Bilder Speicher'),
(16181, 1791, 5, 'Dokumente'),
(16182, 1792, 5, 'Dokumente (schreiben, nur hinzufügen optional)'),
(16183, 1794, 5, 'DOE'),
(16184, 1796, 5, 'passt nicht PV1 encounter nummer'),
(16185, 1797, 5, 'sieht ungültig aus'),
(16186, 1798, 5, 'erlaubt der type relationale Kodes?'),
(16187, 1799, 5, 'Lebenspartner'),
(16188, 1800, 5, 'Nicht speichern'),
(16189, 1801, 5, 'Nicht speichern'),
(16190, 1802, 5, 'Änderungen nicht speichern'),
(16191, 1803, 5, 'Fertig'),
(16192, 1804, 5, 'Fertig mit:'),
(16193, 1805, 5, 'Fertig. Download erfolgt jetzt.'),
(16194, 1806, 5, 'Tag der Leistung'),
(16195, 1807, 5, 'Dosierung'),
(16196, 1809, 5, 'Doppelclick, um zu editieren'),
(16197, 1810, 5, 'Doppeltsehen'),
(16198, 1811, 5, 'Download'),
(16199, 1814, 5, 'Download trotzdem starten'),
(16200, 1815, 5, 'download rechnung, verschicke zu finanzabteilung und markiere als erstellt'),
(16201, 1817, 5, 'Zertifikat herunterladen'),
(16202, 1818, 5, 'Konfigurationsdaten herunterladen'),
(16203, 1820, 5, 'Download Verschlusselte Datei'),
(16204, 1825, 5, 'Download PDF'),
(16205, 1827, 5, 'Download ausgewählter Statements'),
(16206, 1828, 5, 'Arzt Kontrolle'),
(16207, 1829, 5, 'Arzt Visite'),
(16208, 1830, 5, 'Dr.'),
(16209, 1831, 5, 'Ziehen zum bewegen'),
(16210, 1832, 5, 'tröpfeln'),
(16211, 1833, 5, 'Führerschein oder Ausweis'),
(16212, 1834, 5, 'Medikament'),
(16213, 1835, 5, 'Medikamenten Suche'),
(16214, 1836, 5, 'Medikamenten Formular'),
(16215, 1837, 5, 'Medikamenten ID fehlt!'),
(16216, 1838, 5, 'Medikament Abstände'),
(16217, 1839, 5, 'Medikament Bestand'),
(16218, 1840, 5, 'Medikament Name'),
(16219, 1841, 5, 'medikamentenverwaltung'),
(16220, 1845, 5, 'Medikament Einheit'),
(16221, 1846, 5, 'Medikamente'),
(16222, 1847, 5, 'Medikamente und Produkte'),
(16223, 1848, 5, 'Trockener Mund'),
(16224, 1849, 5, 'DSM IV Disgnosen'),
(16225, 1850, 5, 'DT 1'),
(16226, 1851, 5, 'DT 2'),
(16227, 1852, 5, 'DT 3'),
(16228, 1853, 5, 'DT 4'),
(16229, 1854, 5, 'DT 5'),
(16230, 1855, 5, 'DTaP 1'),
(16231, 1856, 5, 'DTaP 2'),
(16232, 1857, 5, 'DTaP 3'),
(16233, 1858, 5, 'DTaP 4'),
(16234, 1859, 5, 'DTaP 5'),
(16235, 1860, 5, 'Fällig'),
(16236, 1861, 5, 'Fälligkeitsdatum'),
(16237, 1862, 5, 'Fälligkeitsdatum mm/tt/jjjj oder jjjj-mm-tt'),
(16238, 1863, 5, 'Fälligkeitsdatum:'),
(16239, 1864, 5, 'aufgrund Ins'),
(16240, 1865, 5, 'aufgrund Pt'),
(16241, 1866, 5, 'Bald fällig'),
(16242, 1867, 5, 'Fälligkeitsstatus'),
(16243, 1868, 5, 'Fälligkeitsstatus Update'),
(16244, 1869, 5, 'Erstelle Dump der LibreEHR database'),
(16245, 1870, 5, 'Erstelle Dump des Web-Verzeichnis-Baumes'),
(16246, 1871, 5, 'Erstelle Dump der phpGACL-Datenbank'),
(16247, 1872, 5, 'Erstelle Dump des phpGACL-Web-Verzeichnis-Baumes'),
(16248, 1873, 5, 'Erstelle Dump der SQL-Ledger-Datenbank'),
(16249, 1874, 5, 'Erstelle Dump des SQL-Ledger-Web-Verzeichnis-Baumes'),
(16250, 1875, 5, 'Überprüfung auf Duplikate'),
(16251, 1876, 5, 'Doppelte ID in Zeile'),
(16252, 1877, 5, 'Doppelter Name in Zeile'),
(16253, 1878, 5, 'DUPLIKATS-WARNUNG'),
(16254, 1879, 5, 'Dauerhafte Vollmacht'),
(16255, 1880, 5, 'Dauer'),
(16256, 1881, 5, 'Dauer'),
(16257, 1882, 5, 'Niederländisch'),
(16258, 1884, 5, 'Dysphagie'),
(16259, 1885, 5, 'Dyspnoe:'),
(16260, 1886, 5, 'Dysurie'),
(16261, 1889, 5, 'E-Bericht'),
(16262, 1890, 5, 'e-Rx'),
(16263, 1892, 5, 'e-Rx erneuern'),
(16264, 1893, 5, 'jeder Empfänger muss eigene Nachrichten als vollständig setzen'),
(16265, 1894, 5, 'Frühes Wiederauftreten (<2 Monate)'),
(16266, 1895, 5, 'Ohren'),
(16267, 1896, 5, 'EKG'),
(16268, 1897, 5, 'eClaims'),
(16269, 1898, 5, 'Oedem'),
(16270, 1899, 5, 'edi geschichte'),
(16271, 1900, 5, 'Edi Geschichte'),
(16272, 1901, 5, 'Edi Geschichte (kostenpflichtig) für Speicherung und Beurteilung von Antworten zu EDI Erstattung'),
(16273, 1902, 5, 'EDI-271 Datei-Upload'),
(16274, 1903, 5, 'EDI-271 Antwort-Datei-Upload'),
(16275, 1904, 5, 'Bearbeiten'),
(16276, 1905, 5, 'bearbeiten'),
(16277, 1906, 5, 'Allergien bearbeiten'),
(16278, 1907, 5, 'Kategorien bearbeiten'),
(16279, 1908, 5, 'Definitionen bearbeiten'),
(16280, 1909, 5, 'Definitionen bearbeiten'),
(16281, 1910, 5, 'Diagnosen bearbeiten'),
(16282, 1911, 5, 'Bekanntgabe bearbeiten'),
(16283, 1912, 5, 'Einrichtungen bearbeiten'),
(16284, 1913, 5, 'Einrichtungen bearbeiten'),
(16285, 1914, 5, 'Informationen über Einrichtung bearbeiten'),
(16286, 1915, 5, 'Bearbeiten von Standort Spezifischen Anwender Informationen'),
(16287, 1916, 5, 'Bearbeite Datei in'),
(16288, 1917, 5, 'Formular bearbeiten'),
(16289, 1918, 5, 'Globale Einstellungen bearbeiten'),
(16290, 1919, 5, 'Bearbeiten ist nicht erlaubt!'),
(16291, 1920, 5, 'Layout bearbeiten'),
(16292, 1921, 5, 'Liste bearbeiten'),
(16293, 1922, 5, 'Zahlung bearbeiten'),
(16294, 1923, 5, 'Struktur Anpassen'),
(16295, 1924, 5, 'Benutzer bearbeiten'),
(16296, 1925, 5, 'Benutzer Einstellungen ändern'),
(16297, 1928, 5, 'Aufklärung'),
(16298, 1929, 5, 'Aufklärungsdatum'),
(16299, 1931, 5, 'ee * GNU General Public License für nähere Angaben. ** Sie sollten bereits eine Kopie von GNU mit dem Programm bekommen haben, wenn nicht schreiben Sie GNU an. '),
(16300, 1932, 5, 'Effektives Datum'),
(16301, 1934, 5, 'Effektivität'),
(16302, 1935, 5, 'EIN'),
(16303, 1936, 5, 'Ejakulationen'),
(16304, 1937, 5, 'Ellbogen'),
(16305, 1938, 5, 'Ellbogen-Beschwerden'),
(16306, 1939, 5, 'Elektronisch'),
(16307, 1942, 5, 'Elektronisch Zuständigkeit'),
(16308, 1943, 5, 'Elektronisch Bericht'),
(16309, 1944, 5, 'Berechtigung'),
(16310, 1945, 5, 'Berechtigung für Auskunftstapel 270'),
(16311, 1946, 5, 'Berechtigung Antwort'),
(16312, 1947, 5, 'Berechtigungstatus des Vaccines als Kindervaccine'),
(16313, 1948, 5, 'berechtigt'),
(16314, 1949, 5, 'Email'),
(16315, 1951, 5, 'Email Adresse'),
(16316, 1953, 5, 'E-Mail-Adresse des Absenders der Patienten-Erinnerungen. Antworten auf Patienten-Erinnerungen werden zu dieser Adresse gesendet. Nutze eine Absender-Adresse Deiner Klinik/Praxis-Domain, damit die Erinnerungen nicht als Junk eingestuft werden.'),
(16317, 1954, 5, 'Email Adresse, um administrative Berichte zu bekommen'),
(16318, 1955, 5, 'E-Mail-Adresse, wenn bekannt, um Notfall-Login Aktivierungs-Nachrichten zu erhalten'),
(16319, 1956, 5, 'E-Mail Auth'),
(16320, 1957, 5, 'Nachricht per email'),
(16321, 1958, 5, 'E-Mail-Benachrichtigung'),
(16322, 1959, 5, 'E-Mail-Benachrichtigung Stunde'),
(16323, 1960, 5, 'E-Mail-Benachrichtigung Bericht'),
(16324, 1961, 5, 'E-Mail senden vor'),
(16325, 1962, 5, 'E-Mail-Absender'),
(16326, 1963, 5, 'E-Mail gesendet'),
(16327, 1964, 5, 'E-Mail gesendet an'),
(16328, 1965, 5, 'E-Mail Betreff'),
(16329, 1966, 5, 'email text, brauchbare Tags: ***NAME***, i.e. Dear ***NAME***'),
(16330, 1967, 5, 'email text, brauchbare Tags: ***NAME***, i.e. Dear ***NAME***'),
(16331, 1968, 5, 'E-Mail Transport Methode'),
(16332, 1969, 5, 'E-Mail wurde an folgende Adresse gesendet werden'),
(16333, 1971, 5, 'Kontakt für Notfälle'),
(16334, 1972, 5, 'Notfall Kontaktperson'),
(16335, 1973, 5, 'Notfall Telefonnummer'),
(16336, 1974, 5, 'Notfall Empfängnisverhütung'),
(16337, 1975, 5, 'Notfall Login'),
(16338, 1978, 5, 'Notfall e-mail Adresse'),
(16339, 1979, 5, 'Notfall Login'),
(16340, 1980, 5, 'Telefonkontakt für Notfälle'),
(16341, 1981, 5, 'Emotionale / Verhalten Muster und Komplikationen'),
(16342, 1982, 5, 'Emphysem'),
(16343, 1983, 5, 'Arbeitnehmer'),
(16344, 1984, 5, 'Arbeitgeber'),
(16345, 1985, 5, 'Anschrift des Arbeitgebers'),
(16346, 1986, 5, 'Daten des Arbeitgebers'),
(16347, 1987, 5, 'Name des Arbeitgebers'),
(16348, 1988, 5, 'LEER'),
(16349, 1989, 5, 'Leer'),
(16350, 1990, 5, 'Leeres Passwort nicht erlaubt'),
(16351, 1991, 5, 'Kein Wert in "Email Stunden"'),
(16352, 1992, 5, 'Kein Wert in "Email Sender"'),
(16353, 1993, 5, 'Kein Wert in "Email Betreff"'),
(16354, 1994, 5, 'Kein Wert in "Email Text"'),
(16355, 1995, 5, 'Kein Wert in "Name Provider"'),
(16356, 1996, 5, 'Kein Wert in "Passwort"'),
(16357, 1997, 5, 'Kein Wert in "SMS Hour"'),
(16358, 1998, 5, 'Kein Wert in "SMS Text"'),
(16359, 1999, 5, 'Kein Wert in "Username"'),
(16360, 2006, 5, 'AMC-Prompting aktivieren'),
(16361, 2008, 5, 'AMC-Berichtswesen aktivieren'),
(16362, 2009, 5, 'AMC-Tracking aktivieren'),
(16363, 2011, 5, 'ATNA-Auditierung aktivieren'),
(16364, 2013, 5, 'Audit-Logging aktivieren'),
(16365, 2014, 5, 'Audit Trail and Node Authentication (ATNA) aktivieren'),
(16366, 2015, 5, 'Automated Measure Calculations (AMC) Berichtswesen aktivieren'),
(16367, 2016, 5, 'Client-SSL aktivieren'),
(16368, 2017, 5, 'Authentifizierung per Client-SSL-Zertifikat aktivieren'),
(16369, 2019, 5, 'Clinical Decision Rules (CDR) aktiveren'),
(16370, 2022, 5, 'Clinical Quality Measure (CQM) aktivieren'),
(16371, 2023, 5, 'Klinische Erinnerung (Pop-Up) aktivieren'),
(16372, 2024, 5, 'Klinisches Erinnerungs-Widget aktivieren'),
(16373, 2027, 5, 'CQM-Berichtswesen aktivieren'),
(16374, 2028, 5, 'Aktiviere EDI Verlauf im linken Menü'),
(16375, 2030, 5, 'Aktiviere Gebühren im linken Menü'),
(16376, 2031, 5, 'Hylafax-Unterstützung aktivieren'),
(16377, 2033, 5, 'Aktiviere Import STatus für NewCrop erx'),
(16378, 2037, 5, 'Labordatenaustausch aktivieren'),
(16379, 2039, 5, 'Logging für Dokument upload/download zu CouchDB aktivieren'),
(16380, 2040, 5, 'Logging für alle SQL SELECT queries aktivieren'),
(16381, 2041, 5, 'Logging für Backup-Aktivitäten aktivieren'),
(16382, 2042, 5, 'Logging für CDR Einrichtung-Anforderung aktivieren'),
(16383, 2043, 5, 'Logging für sonstige Aktivitäten aktivieren'),
(16384, 2044, 5, 'Logging für Bestell-Aktivitäten aktivieren'),
(16385, 2045, 5, 'Logging für Änderungen an Patientenakten aktivieren'),
(16386, 2046, 5, 'Logging für Termin-Aktivitäten aktivieren'),
(16387, 2047, 5, 'Logging für Sicherheits- und Administrationsaktivitäten aktivieren'),
(16388, 2049, 5, 'NewCrop eRx-Service aktivieren'),
(16389, 2051, 5, 'Offsite-Patientenportal aktivieren'),
(16390, 2052, 5, 'Offsite-Patientenportal aktivieren'),
(16391, 2053, 5, 'Onsite-Patientenportal aktivieren'),
(16392, 2055, 5, 'Onsite-Patientenportal aktivieren'),
(16393, 2056, 5, 'Patienten Erinnerungs-Widget aktivieren'),
(16394, 2057, 5, 'Aktiviere phiMail Direknachrichten Dienst'),
(16395, 2058, 5, 'Abfrage für AMC-Daten aktivieren'),
(16396, 2060, 5, 'Berichtswesen für Verfolgungsdaten des AMC aktivieren'),
(16397, 2061, 5, 'Scanner-Unterstützung aktivieren'),
(16398, 2064, 5, 'aktiviere Medical Information Integration, LLC Lab Exchange Service.'),
(16399, 2065, 5, 'LibreEHR Support LLC Lab Exchange Service aktivieren'),
(16400, 2066, 5, 'Nutzer-Zertifikats-Authentifizierung aktivieren'),
(16401, 2067, 5, 'ZMG, LLC eRx-Service aktivieren'),
(16402, 2068, 5, 'aktiviert'),
(16403, 2070, 5, 'Aktiviert das alte Honorar-Panel, um Abrechnungscodes und Zahlungen einzugeben. Nicht empfohlen, verwenden Sie das Honorar Blatt stattdessen.'),
(16404, 2071, 5, 'Besuch'),
(16405, 2072, 5, 'Besuch'),
(16406, 2073, 5, 'Besuch'),
(16407, 2074, 5, 'besuch'),
(16408, 2075, 5, 'Besuch '),
(16409, 2076, 5, 'Besuch akuter stationär oder ED'),
(16410, 2081, 5, 'Besuch Datum'),
(16411, 2084, 5, 'Besuch EDI Aufzeichnung'),
(16412, 2086, 5, 'Besuch Formulare'),
(16413, 2087, 5, 'Besuch Gesundheit und Verhaltens Beurteilung'),
(16414, 2088, 5, 'Besuch Verlauf'),
(16415, 2089, 5, 'Besuch ID'),
(16416, 2090, 5, 'Besuch Grippe'),
(16417, 2091, 5, 'Besuch Nummer'),
(16418, 2095, 5, 'Besuch Berufsbedingte Therapie'),
(16419, 2096, 5, 'Ordination Praxistermin'),
(16420, 2097, 5, 'Ordination Ambulanztermin'),
(16421, 2098, 5, 'Ordination Ambulanztermin mit PCP & Gyn'),
(16422, 2099, 5, 'Anzahl Visiten je Seite'),
(16423, 2100, 5, 'Besuch Zahlung'),
(16424, 2101, 5, 'Besuch Schwangerschaft'),
(16425, 2102, 5, 'Besuch Vorsorgemedizin - individual Besuch'),
(16426, 2103, 5, 'Besuch Vorsorgemedizin 40 und älter'),
(16427, 2104, 5, 'Besuch Vorsorgemedizin Gruppen Besuch'),
(16428, 2105, 5, 'Besuch Vorsorgemedizin andere Dienste'),
(16429, 2106, 5, 'Besuch Vorsorgemedizin 18 und älter'),
(16430, 2107, 5, 'besuche psychiatrisch & psychologisch'),
(16431, 2108, 5, 'Besuch Statistik'),
(16432, 2109, 5, 'Besuch Zusammenfassung'),
(16433, 2110, 5, 'Besuch wurde kodiert'),
(16434, 2111, 5, 'Besuch:'),
(16435, 2112, 5, 'Besuch: besuch Elektive stationär, ambulant, oder Ophthalmologie'),
(16436, 2113, 5, 'Besuche'),
(16437, 2114, 5, 'Besuche & Formulare'),
(16438, 2115, 5, 'Besuche &amp; Formulare'),
(16439, 2116, 5, 'Besuche nicht genehmigt'),
(16440, 2117, 5, 'Besuche Bericht'),
(16441, 2118, 5, 'Besuche Sektion'),
(16442, 2120, 5, 'Verschlüsselung'),
(16443, 2121, 5, 'Ende'),
(16444, 2122, 5, 'Ende (tt.mm.jjjj) '),
(16445, 2123, 5, 'Enddatum'),
(16446, 2124, 5, 'Enddatum'),
(16447, 2126, 5, 'Enddatum muss größer sein als Startdatum'),
(16448, 2127, 5, 'Enddatum'),
(16449, 2131, 5, 'Endzeit'),
(16450, 2132, 5, 'End Stadium Niereninsuffizienz begünstigt in MCP mit ANgestellten Gruppenplan'),
(16451, 2133, 5, 'Enddatum der Leistung (jjjj-mm-tt)'),
(16452, 2134, 5, 'Enddatum der Leistung (jjjj-mm-tt) wenn ein Zeitrahmen eintrag'),
(16453, 2135, 5, 'Endstunde für Kalender Ereignisse'),
(16454, 2136, 5, 'Innere abnormale Blutung'),
(16455, 2137, 5, 'Endokrin'),
(16456, 2138, 5, 'Endoskopie'),
(16457, 2141, 5, 'Englisch'),
(16458, 2142, 5, 'Englisch '),
(16459, 2143, 5, 'Englisch (Indisch)'),
(16460, 2144, 5, 'Englisch (Standard)'),
(16461, 2145, 5, 'Enskript kommando gebraucht bei Hylafax'),
(16462, 2146, 5, 'LibreEHR muß Schreibrechte im Verzeichnis haben'),
(16463, 2147, 5, 'HNO Sekretion'),
(16464, 2148, 5, 'HNO Schmerz'),
(16465, 2149, 5, 'Diagnosekode eingeben , um alle Rechnung ohne diese Diagnose auszuschliessen'),
(16466, 2151, 5, 'Breifkopf hier eingeben'),
(16467, 2152, 5, 'Datenbank Root Passwort'),
(16468, 2153, 5, 'Datenbank Root Username'),
(16469, 2154, 5, 'Diagnose erfassen'),
(16470, 2155, 5, 'Medikamente erfassen'),
(16471, 2156, 5, 'Besuch erfassen'),
(16472, 2157, 5, 'Besuch Nummer eingeben'),
(16473, 2158, 5, 'Eingabe Impfungen'),
(16474, 2159, 5, 'Enter-Taste'),
(16475, 2161, 5, 'Neuen Status erfassen'),
(16476, 2162, 5, 'Empfänger Adresse eingeben'),
(16477, 2164, 5, 'Re-Identifikations-Code erfassen'),
(16478, 2165, 5, 'Gib Deine Suchbegriffe oben ein'),
(16479, 2166, 5, 'falscher Eintrag'),
(16480, 2167, 5, 'Einträge'),
(16481, 2168, 5, 'Umgebung'),
(16482, 2169, 5, 'EOB Dateneingabe'),
(16483, 2170, 5, 'EOB Zustellung - Elektronische Rechnung'),
(16484, 2171, 5, 'EOB Zustellung -Instruktionen'),
(16485, 2172, 5, 'EOB Zustellung - Rechnung'),
(16486, 2173, 5, 'EOB Zustellung - Patientenakte'),
(16487, 2174, 5, 'EOB Zustellung - Suche'),
(16488, 2176, 5, 'Epilepsie'),
(16489, 2178, 5, 'ERA'),
(16490, 2179, 5, 'ERA Files'),
(16491, 2180, 5, 'ERA Zustellung'),
(16492, 2181, 5, 'Löschen'),
(16493, 2182, 5, 'Errektionen'),
(16494, 2183, 5, 'Fehler'),
(16495, 2185, 5, 'Fehler bei der Bestätigung des Erhalts der Laborbefunde'),
(16496, 2187, 5, 'Fehler bei der Übernahme der Laborbefunde vom Lab Exchange Network'),
(16497, 2188, 5, 'Fehler in der Geschlechtsauswahl'),
(16498, 2189, 5, 'Fehler bei der HIPAA-Auswahl'),
(16499, 2190, 5, 'Fehler bei der Verarbeitungs-Auswahl'),
(16500, 2191, 5, 'Fehler bei der Auswahl des SMS-Gateways'),
(16501, 2192, 5, 'Fehler bei der Auswahl des Sortierkriteriums'),
(16502, 2193, 5, 'Fehler in der GZIP-Kompression der Datei: '),
(16503, 2194, 5, 'Fehler bei JA/NEIN-Auswahl'),
(16504, 2195, 5, 'Fehler beim Öffnen der hochgeladenen Datei'),
(16505, 2196, 5, 'Fehler beim verarbeiten der Datei'),
(16506, 2197, 5, 'Fehler beim Upload'),
(16507, 2198, 5, 'Fehler beim Löschen der Nachricht'),
(16508, 2199, 5, 'Fehler beim Abrufen der Befunde vom Lab Exchange Network'),
(16509, 2200, 5, 'Fehler beim Abrufen der Werte.'),
(16510, 2202, 5, 'Fehler bei der Gewähung des File-Privilegs für den LibreEHR Nutzer'),
(16511, 2205, 5, 'Fehler bei der Registrierung des Formulars!'),
(16512, 2206, 5, 'Fehler beim Speichern'),
(16513, 2208, 5, 'Fehler beim Schreiben der Daten'),
(16514, 2209, 5, 'Fehler gefunden in neuen Ergebnissen'),
(16515, 2210, 5, 'Fehler: Datei existiert nicht'),
(16516, 2211, 5, 'Fehler: Daten können nicht vom Server abgerufen werden'),
(16517, 2212, 5, 'Fehler: Client-Zertifikat kann nicht erstellt werden'),
(16518, 2213, 5, 'Fehler: admin.p12-Zertifikat kann nicht erstellt werden'),
(16519, 2214, 5, 'Fehler: Certificate Authority Zertifikat kann nicht erstellt werden'),
(16520, 2215, 5, 'Fehler: Server-Zertifikat kann nicht erstellt werden'),
(16521, 2216, 5, 'Fehler: Datei kann nicht geöffnet werden'),
(16522, 2217, 5, 'Fehler: Authentifizierung mittels Nutzer-Zertifikat ist nicht aktiviert in LibreEHR'),
(16523, 2218, 5, 'Fehler: Du musst das Archive/Tar.php-Modul installieren'),
(16524, 2219, 5, 'Fehler: Die Datei table.sql konnte nicht geöffnet werden.'),
(16525, 2220, 5, 'FEHLER: Doppelte ID in Zeile'),
(16526, 2221, 5, 'FEHLER: Doppelter Namen in Zeile'),
(16527, 2222, 5, 'FEHLER: Feld'),
(16528, 2223, 5, 'FEHLER: PHP Modul für ZIP-Archive fehlt'),
(16529, 2224, 5, 'FEHLER: Kein ICD Import-Verzeichnis'),
(16530, 2225, 5, 'FEHLER: Falsches Passwort. Tippfehler?'),
(16531, 2226, 5, 'FEHLER: Falsches Passwort. Tippfehler?'),
(16532, 2227, 5, 'FEHLER: Die Datei existiert nicht.'),
(16533, 2228, 5, 'FEHLER: Die folgenden Variablen beinhalten ungültige Zeichen.'),
(16534, 2229, 5, 'FEHLER: Datei kann nicht kopiert werden.'),
(16535, 2230, 5, 'FEHLER: Downloadbares Archiv kann nicht erzeugt werden.'),
(16536, 2231, 5, 'FEHLER: ZIP-Archiv kann nicht erzeugt werden.'),
(16537, 2232, 5, 'FEHLER: Datei kann nicht entpackt werden.'),
(16538, 2233, 5, 'FEHLER: Datei kann nicht in die Datenbank geschrieben werden.'),
(16539, 2234, 5, 'FEHLER: Versionsnummer kann nicht gesetzt werden.'),
(16540, 2235, 5, 'Fehler'),
(16541, 2236, 5, 'eRx Konto-Status'),
(16542, 2237, 5, 'eRx Logs'),
(16543, 2238, 5, 'ERX Name'),
(16544, 2239, 5, 'ERX Passwort'),
(16545, 2240, 5, 'ERX Rolle'),
(16546, 2241, 5, 'ERX Nutzer'),
(16547, 2242, 5, 'Erythem:'),
(16548, 2245, 5, 'Eskimo'),
(16549, 2247, 5, 'Bekannter Patient'),
(16550, 2248, 5, 'Estland'),
(16551, 2249, 5, 'Volkszugehörigkeit'),
(16552, 2250, 5, 'Ethnie oder Rasse'),
(16553, 2251, 5, 'Ethnien/Rassen-Liste (schreiben, hinzufügen optional)'),
(16554, 2252, 5, 'ETIN'),
(16555, 2253, 5, 'Ereignis'),
(16556, 2254, 5, 'Ereignis beginnt'),
(16557, 2255, 5, 'Ereignis-Kategorie'),
(16558, 2256, 5, 'Ereignisdatum'),
(16559, 2257, 5, 'Ereignisbeschreibung'),
(16560, 2258, 5, 'Ereignis Details'),
(16561, 2259, 5, 'Ereignis wiederholt sich nicht'),
(16562, 2260, 5, 'Ereignis Dauer'),
(16563, 2261, 5, 'Ereignis Dauer in Minuten'),
(16564, 2262, 5, 'Teilnahmegebühr'),
(16565, 2263, 5, 'Veranstaltungsort'),
(16566, 2264, 5, 'Ereignis wiederholt sich alle'),
(16567, 2265, 5, 'Ereignis wiederholt am'),
(16568, 2266, 5, 'Ereignis Startzeit'),
(16569, 2267, 5, 'Ereignis titel'),
(16570, 2268, 5, 'Ereignis Titel'),
(16571, 2269, 5, 'Ereignis Webseite'),
(16572, 2270, 5, 'Ereignis für'),
(16573, 2271, 5, 'Ereignis für'),
(16574, 2272, 5, 'Ereignisse in neuem Fenster öffnen'),
(16575, 2273, 5, 'jede'),
(16576, 2274, 5, 'Jede'),
(16577, 2275, 5, 'alle 3 Stunden'),
(16578, 2276, 5, 'alle 4 Stunden'),
(16579, 2277, 5, 'alle 5 Stunden'),
(16580, 2278, 5, 'alle 6 Stunden'),
(16581, 2279, 5, 'alle 8 Stunden'),
(16582, 2280, 5, 'jeder vierte'),
(16583, 2281, 5, 'jeder zweite'),
(16584, 2282, 5, 'jeder dritte'),
(16585, 2283, 5, 'jeder, jeder zweite, jeder dritte, etc.'),
(16586, 2285, 5, 'Untersuchung und Ergebnisse'),
(16587, 2286, 5, 'Untersuchungsergebnis'),
(16588, 2289, 5, 'Untersuchung'),
(16589, 2290, 5, 'Untersuchungsdatum'),
(16590, 2291, 5, 'Beispiel'),
(16591, 2292, 5, 'Beispiele'),
(16592, 2293, 5, 'Untersuchungen'),
(16593, 2294, 5, 'ausgenommen'),
(16594, 2295, 5, 'ausgeprägte Abnutzung'),
(16595, 2296, 5, 'ausgeschlossen Patienten'),
(16596, 2297, 5, 'Ausschluss'),
(16597, 2298, 5, 'Exklusive Organisation von Leistungserbringern (EPO)'),
(16598, 2299, 5, 'Executive (papiergröße)'),
(16599, 2300, 5, 'Übungen'),
(16600, 2301, 5, 'Übungs Vorlagen'),
(16601, 2302, 5, 'Übungs Vorlagen'),
(16602, 2303, 5, 'Existiert'),
(16603, 2304, 5, 'Ausstieg aus Verwaltung'),
(16604, 2305, 5, 'Erweitern'),
(16605, 2306, 5, 'Einblenden'),
(16606, 2307, 5, 'einblenden'),
(16607, 2308, 5, 'Alle Einblenden'),
(16608, 2311, 5, 'Erweiterte Ansicht'),
(16609, 2312, 5, 'Erwarte form_encounter.pid als '),
(16610, 2313, 5, 'Verfallen'),
(16611, 2314, 5, 'Verfalldatum'),
(16612, 2315, 5, 'Verfällt'),
(16613, 2316, 5, 'verfällt in'),
(16614, 2317, 5, 'Exportieren'),
(16615, 2318, 5, 'Exportieren als CSV'),
(16616, 2319, 5, 'Exportieren der Konfiguration'),
(16617, 2322, 5, 'Exportiere persönliche Patientendaten'),
(16618, 2323, 5, 'Exportiere PQRI Bericht'),
(16619, 2325, 5, 'Ausgewählte als CSV exportieren'),
(16620, 2326, 5, 'Ausgewählte zu Sammlungen exportieren'),
(16621, 2327, 5, 'Zu CSV exportieren'),
(16622, 2328, 5, 'In externes Abrechnungssystem exportieren'),
(16623, 2329, 5, 'im Ausland gewesen'),
(16624, 2330, 5, 'im Ausland gewesen'),
(16625, 2332, 5, 'Extern'),
(16626, 2334, 5, 'Externe Daten laden/aktualisieren'),
(16627, 2335, 5, 'Externe Datenbank importieren'),
(16628, 2336, 5, 'Externe ID'),
(16629, 2337, 5, 'Externe id'),
(16630, 2338, 5, 'externe Kennung'),
(16631, 2346, 5, 'ZIP-Datei entpacken'),
(16632, 2347, 5, 'Entpacke Datei. Dies wird eine Weile dauern...'),
(16633, 2348, 5, 'Ausschwitzung'),
(16634, 2349, 5, 'Augen-Irritation'),
(16635, 2350, 5, 'Augen-Schmerzen'),
(16636, 2351, 5, 'Augenrötung'),
(16637, 2352, 5, 'Augen'),
(16638, 2353, 5, 'F'),
(16639, 2354, 5, 'F/H Blutprobleme'),
(16640, 2356, 5, 'Standorte'),
(16641, 2357, 5, 'Standort'),
(16642, 2358, 5, 'standort'),
(16643, 2359, 5, 'Standort Verwaltung'),
(16644, 2360, 5, 'Standort Stadt'),
(16645, 2361, 5, 'Standort Code'),
(16646, 2362, 5, 'Standort Länder Code'),
(16647, 2363, 5, 'Standort Fax'),
(16648, 2364, 5, 'Standort Name'),
(16649, 2365, 5, 'Standort NPI'),
(16650, 2366, 5, 'Standort Telefon'),
(16651, 2367, 5, 'Standort spezifische Information'),
(16652, 2368, 5, 'Standort Staat'),
(16653, 2369, 5, 'Standort Straße'),
(16654, 2370, 5, 'Standort PLZ'),
(16655, 2372, 5, 'Standort:'),
(16656, 2373, 5, 'FEHLER'),
(16657, 2374, 5, 'fehlgeschlagen'),
(16658, 2375, 5, 'Fehlgeschlagen'),
(16659, 2380, 5, 'Anlegen des temporären Verzeichnis. CouchDB ist nicht einsatzbereit.'),
(16660, 2382, 5, 'Fehlgeschlagen.'),
(16661, 2383, 5, 'Fehler'),
(16662, 2390, 5, 'Familiäre Anamnese'),
(16663, 2391, 5, 'Familienanamnese bzgl. Glaukom'),
(16664, 2392, 5, 'Familiärer Hintergrund'),
(16665, 2394, 5, 'Familiengeld'),
(16666, 2395, 5, 'Größe der Familie'),
(16667, 2396, 5, 'Phantasie'),
(16668, 2398, 5, 'Farsi'),
(16669, 2400, 5, 'Vater'),
(16670, 2402, 5, 'Müdigkeit'),
(16671, 2403, 5, 'Müde'),
(16672, 2404, 5, 'Fax'),
(16673, 2405, 5, 'Fax Zähler'),
(16674, 2406, 5, 'Faxnummer'),
(16675, 2408, 5, 'Fax/Scanner'),
(16676, 2409, 5, 'Fax-Eingang'),
(16677, 2410, 5, 'Fax-Ausgang'),
(16678, 2411, 5, 'Funktion'),
(16679, 2412, 5, 'Feb'),
(16680, 2413, 5, 'Februar'),
(16681, 2414, 5, 'FECA'),
(16682, 2415, 5, 'Medikament-ID'),
(16683, 2416, 5, 'Medikament EIN'),
(16684, 2417, 5, 'Steuernummer'),
(16685, 2418, 5, 'Gebühr'),
(16686, 2419, 5, 'Gebühr'),
(16687, 2420, 5, 'Honorar ist nicht erlaubt'),
(16688, 2421, 5, 'Honorar Formular'),
(16689, 2422, 5, 'Option für Honorar Formular'),
(16690, 2423, 5, 'Honorare'),
(16691, 2424, 5, 'Weiblich'),
(16692, 2426, 5, 'Frauenkondom'),
(16693, 2430, 5, 'Frauen Syntome'),
(16694, 2434, 5, 'Fieber'),
(16695, 2435, 5, 'Fieber:'),
(16696, 2436, 5, 'FH Blut Probleme'),
(16697, 2437, 5, 'Myome'),
(16698, 2443, 5, 'Felder fehlen!'),
(16699, 2447, 5, 'Datei'),
(16700, 2448, 5, 'Datei im Dokumentations-Verzeichnis, das zeigt, wie der Log-Backups automatisch erstellt werden können'),
(16701, 2449, 5, 'Datei Ort'),
(16702, 2450, 5, 'Dateiverwaltung'),
(16703, 2453, 5, 'File-Privileg dem LibreEHR-Nutzer gewährt'),
(16704, 2454, 5, 'Datei-Abruf von CouchDB fehlgeschlagen'),
(16705, 2455, 5, 'Aktenraum'),
(16706, 2456, 5, 'Datei für den Upload'),
(16707, 2457, 5, 'Datei für den Upload'),
(16708, 2458, 5, 'Datei mit dem selben Namen existiert bereits unter:'),
(16709, 2459, 5, 'Dateiname'),
(16710, 2461, 5, 'Dateien'),
(16711, 2462, 5, 'Philipino'),
(16712, 2463, 5, 'Fülle eine der unten stehenden Zeilen aus'),
(16713, 2464, 5, 'nur ausfüllen, wenn der Patient mit email benachrichtigt werden soll'),
(16714, 2465, 5, 'Die Werte unten eintragen'),
(16715, 2467, 5, 'Füllen Sie die Zeile'),
(16716, 2468, 5, 'Filter'),
(16717, 2469, 5, 'Filter für Konstanten'),
(16718, 2470, 5, 'Filter für Definitionen'),
(16719, 2471, 5, 'gefiltert von'),
(16720, 2472, 5, 'filtert'),
(16721, 2473, 5, 'Filter'),
(16722, 2474, 5, 'Abschluß'),
(16723, 2475, 5, 'Schlußdiagnose'),
(16724, 2476, 5, 'Schlußdiagnose durch Facharzt'),
(16725, 2478, 5, 'Finanz'),
(16726, 2480, 5, 'Finanzbericht - alle'),
(16727, 2481, 5, 'Finanzbericht - meine Fälle'),
(16728, 2482, 5, 'Finanz Bericht Datum'),
(16729, 2484, 5, 'Finden'),
(16730, 2485, 5, 'Verfügbare finden'),
(16731, 2486, 5, 'Freie Termine finden'),
(16732, 2487, 5, 'Patienten finden'),
(16733, 2488, 5, 'Finden Patientenaufklärung Materialien'),
(16734, 2489, 5, 'Befunde'),
(16735, 2490, 5, 'Befunde von Spezialisten'),
(16736, 2491, 5, 'Fein'),
(16737, 2492, 5, 'Erledigte Zahlungen'),
(16738, 2493, 5, 'fertig'),
(16739, 2495, 5, 'Erster'),
(16740, 2497, 5, 'Erster Tag der Woche'),
(16741, 2498, 5, 'Vorname'),
(16742, 2499, 5, 'Vorname'),
(16743, 2500, 5, 'Vorname:'),
(16744, 2503, 5, 'Fitness'),
(16745, 2504, 5, 'Fitness Level'),
(16746, 2505, 5, 'Fitness Level des spielers an diesem Tag'),
(16747, 2507, 5, 'Fitness, um zu spielen'),
(16748, 2508, 5, 'Fixes Besuch Datum - beliebige Besuche'),
(16749, 2509, 5, 'Beheben'),
(16750, 2510, 5, 'FL'),
(16751, 2511, 5, 'Flatulenz'),
(16752, 2512, 5, 'Fluß'),
(16753, 2514, 5, 'Grippesaison'),
(16754, 2515, 5, 'Grippesaison'),
(16755, 2516, 5, 'Grippe-Impfung'),
(16756, 2517, 5, 'Flüssigkeits- und Elektrolytstörung'),
(16757, 2518, 5, 'FMS'),
(16758, 2519, 5, 'Folio Papierformat'),
(16759, 2520, 5, 'Manuell folgen'),
(16760, 2521, 5, 'Befolgen Sie diese Anweisungen zum Installieren oder Aktualisieren der folgenden Datenbank'),
(16761, 2522, 5, 'Nachgehen'),
(16762, 2524, 5, 'Verfolge Grund'),
(16763, 2525, 5, 'Nachfolgend eine neue Kunden Konstante:'),
(16764, 2526, 5, 'Nachfolgend eine neue Kunden Sprache:'),
(16765, 2527, 5, 'Nachfolgend eine neue Definition (Sprache, Konstante, Definition):'),
(16766, 2529, 5, 'Follow up Service'),
(16767, 2530, 5, 'Folgetermine angewiesen'),
(16768, 2531, 5, 'Nahrungsmittelunverträglichkeit'),
(16769, 2532, 5, 'Fuß'),
(16770, 2533, 5, 'Fuß-Beschwerden'),
(16771, 2534, 5, 'Fuß:'),
(16772, 2535, 5, 'Fussball-Verletzungen'),
(16773, 2536, 5, 'Fussball-Verletzung'),
(16774, 2537, 5, 'Fußballverletzungsbericht'),
(16775, 2538, 5, 'Schuh Typ'),
(16776, 2539, 5, 'für'),
(16777, 2540, 5, 'Für'),
(16778, 2541, 5, 'Für Code'),
(16779, 2543, 5, 'Für Kunden Reklamationen'),
(16780, 2544, 5, 'z.B.:'),
(16781, 2547, 5, 'für die Rechnung'),
(16782, 2553, 5, 'Für die Vergangenheit'),
(16783, 2554, 5, 'für Variablen'),
(16784, 2555, 5, 'für:'),
(16785, 2557, 5, 'Anlegen von neuem Patienten erzwingen'),
(16786, 2559, 5, 'Unterarm'),
(16787, 2560, 5, 'Formular'),
(16788, 2561, 5, 'gestalten'),
(16789, 2564, 5, 'Format'),
(16790, 2565, 5, 'formatieren'),
(16791, 2566, 5, 'Format für Alter Anzeige'),
(16792, 2567, 5, 'Format für NDC falsch'),
(16793, 2568, 5, 'Format um die meisten Daten anzuzeigen'),
(16794, 2569, 5, 'Format um die meisten Daten anzuzeigen'),
(16795, 2570, 5, 'formatierter Bericht'),
(16796, 2571, 5, 'ehemalige Raucher'),
(16797, 2572, 5, 'Formulare'),
(16798, 2573, 5, 'Administrationsformulare'),
(16799, 2575, 5, 'Vorwärts'),
(16800, 2576, 5, 'Seiten via Fax weiterleiten'),
(16801, 2577, 5, 'weitergeleitet'),
(16802, 2579, 5, 'Vierte'),
(16803, 2581, 5, 'Fraktur'),
(16804, 2582, 5, 'Bruch an der Navicula'),
(16805, 2583, 5, 'Fracture Außenknöchel'),
(16806, 2584, 5, 'Fracture Innenknöchel'),
(16807, 2585, 5, 'Fracture, Basis des fünften (5.) Mittelfußknochen'),
(16808, 2587, 5, 'Französisch'),
(16809, 2588, 5, 'Französisch (Kanada)'),
(16810, 2589, 5, 'Französisch (Standard)'),
(16811, 2590, 5, 'Frequenz'),
(16812, 2591, 5, 'Häufig erkältet'),
(16813, 2592, 5, 'Häufig krank'),
(16814, 2593, 5, 'Fr'),
(16815, 2594, 5, 'Freitag'),
(16816, 2595, 5, 'von'),
(16817, 2596, 5, 'VON'),
(16818, 2597, 5, 'von'),
(16819, 2598, 5, '"Von" Datum darf nicht größer sein als "bis" Datum.'),
(16820, 2599, 5, 'Von:'),
(16821, 2600, 5, 'Von: '),
(16822, 2601, 5, 'VON_STADT'),
(16823, 2603, 5, 'VON_VNAME'),
(16824, 2604, 5, 'VON_NNAME'),
(16825, 2605, 5, 'VON_MNAME'),
(16826, 2607, 5, 'VON_MOBILTEL'),
(16827, 2608, 5, 'VON_PLZ'),
(16828, 2609, 5, 'VON_REGION'),
(16829, 2610, 5, 'VON_STRASSE'),
(16830, 2611, 5, 'VON_TITEL'),
(16831, 2612, 5, 'VON_VALEDICTORY'),
(16832, 2613, 5, 'Empfang'),
(16833, 2614, 5, 'Einnahmen durch Empfang'),
(16834, 2615, 5, 'Einnahmenbericht von Empfang'),
(16835, 2616, 5, 'Empfangsbereich'),
(16836, 2617, 5, 'Frontal Rechts:'),
(16837, 2619, 5, 'Vollständiger Name'),
(16838, 2620, 5, 'Vollständiger Pfad zu MySQL Programmdatei'),
(16839, 2621, 5, 'Vollständiger Pfad zu Perl Programmdatei'),
(16840, 2622, 5, 'Vollständiger Pfad für Termin log Backup'),
(16841, 2623, 5, 'Vollständiger Pfad für temporäre Dateien'),
(16842, 2624, 5, 'Vollständig Spielberechtigt'),
(16843, 2625, 5, 'Vollständig Trainingsberechtigt'),
(16844, 2626, 5, 'Vollständig Bezahlt'),
(16845, 2633, 5, 'G'),
(16846, 2634, 5, 'G/DL'),
(16847, 2636, 5, 'Gallenblase Zustand'),
(16848, 2637, 5, 'Gallensteine'),
(16849, 2638, 5, 'Spieldauer'),
(16850, 2639, 5, 'Spiele'),
(16851, 2640, 5, 'Spiele versäumt'),
(16852, 2641, 5, 'Spiele / Termine'),
(16853, 2642, 5, 'Spiele / Termine versäumt'),
(16854, 2644, 5, 'Gastritis'),
(16855, 2645, 5, 'Gastro Schmerz'),
(16856, 2646, 5, 'Magen-Darm-'),
(16857, 2647, 5, 'GCAC Statistik Bericht'),
(16858, 2648, 5, 'GCAC Statistik');
INSERT INTO `lang_definitions` VALUES
(16859, 2649, 5, 'GCAC Konsultation Formular fehlt'),
(16860, 2650, 5, 'Geschlecht'),
(16861, 2651, 5, 'Geschlecht '),
(16862, 2652, 5, 'Allgemein'),
(16863, 2653, 5, 'Allgemeine Probleme Liste'),
(16864, 2655, 5, 'Allgemeine Service Kategorie'),
(16865, 2659, 5, 'Erstelle und lade X12 batch herunter'),
(16866, 2664, 5, 'Erstelle CMS 1500'),
(16867, 2665, 5, 'Erstelle CMS 1500 PDF'),
(16868, 2666, 5, 'Erstelle CMS 1500 TEXT'),
(16869, 2667, 5, 'Erstelle HCFA'),
(16870, 2668, 5, 'Rechnung generieren'),
(16871, 2669, 5, 'Brief generieren'),
(16872, 2670, 5, 'Erzeuge Brief bezüglich '),
(16873, 2671, 5, 'Erstelle PQRI-Bericht (Methode A)'),
(16874, 2673, 5, 'Erstelle PQRI-Bericht (Methode E)'),
(16875, 2677, 5, 'Bericht generieren'),
(16876, 2678, 5, 'Erzeugen Benutzername und Passwort für'),
(16877, 2679, 5, 'X12 generieren'),
(16878, 2680, 5, 'X12 Besuch generieren'),
(16879, 2682, 5, 'Generiert am'),
(16880, 2683, 5, 'erzeugt'),
(16881, 2684, 5, 'Urogenital'),
(16882, 2687, 5, 'Deutsch'),
(16883, 2691, 5, 'HL7 anfordern'),
(16884, 2692, 5, 'Glaukom'),
(16885, 2693, 5, 'Glaukom Familiengeschichte'),
(16886, 2694, 5, 'Global'),
(16887, 2696, 5, 'Globale ID'),
(16888, 2697, 5, 'Globale Einstellungen'),
(16889, 2698, 5, 'Globale'),
(16890, 2699, 5, 'GM/DL'),
(16891, 2700, 5, 'gehe'),
(16892, 2701, 5, 'Gehe'),
(16893, 2704, 5, 'Gehe zu'),
(16894, 2705, 5, 'Gehe zur Woche von'),
(16895, 2706, 5, 'Gehe zu Heute'),
(16896, 2707, 5, 'Ziel A'),
(16897, 2708, 5, 'Ziele und Methoden'),
(16898, 2709, 5, 'Ziel B'),
(16899, 2710, 5, 'Ziel C'),
(16900, 2711, 5, 'Grad der Verletzung'),
(16901, 2712, 5, 'Grad:'),
(16902, 2713, 5, 'Gramm'),
(16903, 2714, 5, 'Total Gesamt'),
(16904, 2715, 5, 'Totale Gesamt'),
(16905, 2718, 5, 'Grafisch anzeigbar'),
(16906, 2720, 5, 'größer als'),
(16907, 2721, 5, 'größer oder gleich als'),
(16908, 2722, 5, 'Griechisch'),
(16909, 2724, 5, 'Gruppe'),
(16910, 2725, 5, 'Gruppenname'),
(16911, 2726, 5, 'Gruppenname kann nicht leer sein.'),
(16912, 2727, 5, 'Gruppenname kann nicht mit einer Zahl oder Leerzeichen beginnen.'),
(16913, 2728, 5, 'Gruppenname kann nicht mit Leerzeichen beginnen.'),
(16914, 2729, 5, 'Gruppennummer'),
(16915, 2730, 5, 'Gruppe Zahlung'),
(16916, 2731, 5, 'Gruppe:'),
(16917, 2732, 5, 'Gruppenname'),
(16918, 2733, 5, 'Gruppen und Zugriffskontrolle'),
(16919, 2734, 5, 'Wachstumskurve'),
(16920, 2735, 5, 'Wachstumskurve'),
(16921, 2736, 5, 'Tropfen'),
(16922, 2737, 5, 'Erziehungsberechtigter'),
(16923, 2739, 5, 'Erziehungsberechtigter Name'),
(16924, 2741, 5, 'gynäkologische Untersuchung'),
(16925, 2742, 5, 'h.'),
(16926, 2743, 5, 'h.s.'),
(16927, 2744, 5, 'HO Hepatitis'),
(16928, 2745, 5, 'wurde erfolgreich gelöscht. Jede Unterkategorie wurde nach unten verschoben.'),
(16929, 2746, 5, 'Hämatome / Prellungen'),
(16930, 2747, 5, 'HAI Status'),
(16931, 2750, 5, 'Hand und Finger'),
(16932, 2751, 5, 'Probleme mit der Hand'),
(16933, 2752, 5, 'Festplatte'),
(16934, 2753, 5, 'Härtefall'),
(16935, 2754, 5, 'wurde mit Konsultation verknüpft'),
(16936, 2755, 5, 'ist abgelaufen'),
(16937, 2756, 5, 'Hasch'),
(16938, 2757, 5, 'Hash für diese Datei nicht vorhanden. Eine neue Hash erzeugt wurde.'),
(16939, 2758, 5, 'Hash stimmt nicht. Datenintegrität ist gefährdet.'),
(16940, 2760, 5, 'Hawaiianisch'),
(16941, 2761, 5, 'Gefährliche Tätigkeiten'),
(16942, 2762, 5, 'Gefährliche Tätigkeiten'),
(16943, 2767, 5, 'he PostCalendar '),
(16944, 2768, 5, 'Kopf'),
(16945, 2769, 5, 'Kopfumfang'),
(16946, 2770, 5, 'Kopfumfang'),
(16947, 2771, 5, 'Kopfschmerz'),
(16948, 2772, 5, 'Kopfschmerzen'),
(16949, 2773, 5, 'Gesundheitsversorgung Operationen'),
(16950, 2774, 5, 'Gesundheitsversorgung Operationen'),
(16951, 2775, 5, 'Gesundheitszentrum / Klinik'),
(16952, 2776, 5, 'Gesundheitsvorsorge Organisation'),
(16953, 2777, 5, 'Gesundheitsvorsorge Organisation'),
(16954, 2778, 5, 'Gehörverlust'),
(16955, 2779, 5, 'Herzinfarkt'),
(16956, 2780, 5, 'Herzerkrankung'),
(16957, 2781, 5, 'Herzversagen'),
(16958, 2782, 5, 'Herzproblem'),
(16959, 2783, 5, 'Herzprobleme'),
(16960, 2784, 5, 'Kardiochirurgie'),
(16961, 2785, 5, 'Herztransplantation'),
(16962, 2786, 5, 'Herz:'),
(16963, 2787, 5, 'Sodbrennen'),
(16964, 2788, 5, 'Hitze oder Kälte'),
(16965, 2789, 5, 'Hitze oder Kälte'),
(16966, 2790, 5, 'startker Raucher'),
(16967, 2791, 5, 'Hebräisch'),
(16968, 2794, 5, 'Körpergröße'),
(16969, 2796, 5, 'Hilfe'),
(16970, 2797, 5, 'Hilfe'),
(16971, 2798, 5, 'Hämatemesis'),
(16972, 2799, 5, 'Blutstuhl'),
(16973, 2800, 5, 'hämatologische'),
(16974, 2801, 5, 'Hämaturie'),
(16975, 2802, 5, 'Hämoglobin'),
(16976, 2803, 5, 'Hämoglobin A1C'),
(16977, 2804, 5, 'Hämoptoe'),
(16978, 2805, 5, 'Hepatitis'),
(16979, 2806, 5, 'Hepatitis A 1'),
(16980, 2807, 5, 'Hepatitis A 2'),
(16981, 2808, 5, 'Hepatitis B 1'),
(16982, 2809, 5, 'Hepatitis B 2'),
(16983, 2810, 5, 'Hepatitis B 3'),
(16984, 2811, 5, 'hier'),
(16985, 2813, 5, 'Hernienversorgung'),
(16986, 2814, 5, 'Bandscheibenvorfall'),
(16987, 2815, 5, 'Herpes'),
(16988, 2816, 5, 'Unschlüssig'),
(16989, 2817, 5, 'heyho. Sie wahren hier für '),
(16990, 2818, 5, 'HIB 1'),
(16991, 2819, 5, 'HIB 2'),
(16992, 2820, 5, 'HIB 3'),
(16993, 2821, 5, 'HIB 4'),
(16994, 2822, 5, 'Ausgeblendet'),
(16995, 2823, 5, 'Versteckte Termine administrieren'),
(16996, 2824, 5, 'Ausblenden'),
(16997, 2825, 5, 'Details ausblenden'),
(16998, 2827, 5, 'Ausblenden von Verschlüsseln/Entschlüsseln Optionen in Dokumenten Verwaltung'),
(16999, 2828, 5, 'Menü verbergen'),
(17000, 2830, 5, 'Erinnerungen Ausblenden'),
(17001, 2831, 5, 'Spalten aus-/einblenden'),
(17002, 2833, 5, 'Hoch'),
(17003, 2834, 5, 'Bluthochdruck'),
(17004, 2835, 5, 'Hindu'),
(17005, 2836, 5, 'Hüft + Leistengegend'),
(17006, 2837, 5, 'Hüft und in der Leistengegend'),
(17007, 2838, 5, 'Hüft Probleme'),
(17008, 2839, 5, 'Hüftprothese'),
(17009, 2840, 5, 'HIPAA Mitteilung erhalten'),
(17010, 2843, 5, 'spanisch'),
(17011, 2844, 5, 'Hispanic - Andere (Geboren in US)'),
(17012, 2845, 5, 'Hispanic - Andere (Geboren nicht in US)'),
(17013, 2846, 5, 'Spanier oder Latino'),
(17014, 2847, 5, 'Verlauf'),
(17015, 2848, 5, 'Verlaufsdaten'),
(17016, 2849, 5, 'Verlaufsdatum'),
(17017, 2851, 5, 'Geräuschverlauf'),
(17018, 2852, 5, 'Nicht für Verlauf berechtigt'),
(17019, 2853, 5, 'Herzgeräuschverlauf'),
(17020, 2854, 5, 'Treffer'),
(17021, 2855, 5, 'HIV'),
(17022, 2858, 5, 'HL7 Viewer'),
(17023, 2860, 5, 'HMOL/L'),
(17024, 2861, 5, 'Hmong'),
(17025, 2862, 5, '[STRG] halten um mehrere Einträge zu selektieren'),
(17026, 2863, 5, '[STRG] halten um mehrere Einträge zu selektieren'),
(17027, 2864, 5, '[STRG] halten um mehrere Einträge zu selektieren'),
(17028, 2865, 5, 'Hauptansicht'),
(17029, 2866, 5, 'Tel. privat'),
(17030, 2867, 5, 'Tel. privat'),
(17031, 2868, 5, 'Obdachlos oder vergleichbar'),
(17032, 2869, 5, 'Obdachlos, etc.'),
(17033, 2870, 5, 'Obdachlos, etc.'),
(17034, 2872, 5, 'Host Name'),
(17035, 2873, 5, 'Host Name kann nicht leer sein'),
(17036, 2875, 5, 'Stunden'),
(17037, 2876, 5, 'Stunden'),
(17038, 2878, 5, 'Verletzungsursache?'),
(17039, 2879, 5, 'Verletzungsursache? :'),
(17040, 2880, 5, 'Wie haben Sie von uns erfahren'),
(17041, 2881, 5, 'Welchen Vorlauf für die Nachfrage von Folgeterminen?'),
(17042, 2882, 5, 'HPI:'),
(17043, 2883, 5, 'HT'),
(17044, 2884, 5, 'HTML'),
(17045, 2885, 5, 'HTML Ausgabe?'),
(17046, 2886, 5, 'Https link for the LibreEHR Support LLC Lab Exchange Service.'),
(17047, 2887, 5, 'Ungarn'),
(17048, 2888, 5, 'Hylafax Verzeichnis'),
(17049, 2889, 5, 'Hylafax Enscript Command'),
(17050, 2890, 5, 'Hylafax Server'),
(17051, 2891, 5, 'Hylafax Server Hostname.'),
(17052, 2892, 5, 'Hyperaktiv'),
(17053, 2893, 5, 'Bluthochdruck'),
(17054, 2894, 5, 'Hypertonie: Blutdruckmessung'),
(17055, 2895, 5, 'Hypertonie: Blutdruckmessung'),
(17056, 2896, 5, 'Schilddrüsenüberfunktion'),
(17057, 2897, 5, 'Schilddrüsenunterfunktion'),
(17058, 2898, 5, 'Gebärmutterentfernung'),
(17059, 2899, 5, 'I'),
(17060, 2900, 5, 'Ich bin derzeit beschäftigt.'),
(17061, 2901, 5, 'Ich habe keine Leserechte '),
(17062, 2902, 5, 'ICD'),
(17063, 2903, 5, 'ICD10 Diagnose'),
(17064, 2904, 5, 'ICD10 Behandlung/Leistung'),
(17065, 2905, 5, 'ICD9'),
(17066, 2906, 5, 'IDC9 Diagnose'),
(17067, 2907, 5, 'ICD9 Behandlung/Leistung'),
(17068, 2909, 5, 'ID'),
(17069, 2910, 5, 'Id'),
(17070, 2911, 5, 'ID kann nicht leer sein'),
(17071, 2912, 5, 'ID Card'),
(17072, 2913, 5, 'IDays'),
(17073, 2914, 5, 'identifiziert als'),
(17074, 2915, 5, 'Identbegriff (ein Wort)'),
(17075, 2916, 5, 'Identifizierungs Code'),
(17076, 2917, 5, 'Idle Session Timeout in Sekunden'),
(17077, 2919, 5, 'Wenn alle Daten aller Spalten nur für dieses Formular sind'),
(17078, 2920, 5, 'Wenn Abrechnung Begründung verwendet wird, muss der Name des Diagnose-Code-Typ angegeben werden.'),
(17079, 2921, 5, 'falls eingegeben, wählen Sie nur diejenigen, die hatten diesen Service haben'),
(17080, 2922, 5, 'Wenn Name ein Teil des Vor- oder Nachnamen ist'),
(17081, 2923, 5, 'Wenn bezahlt von'),
(17082, 2924, 5, 'Wenn die Person verstorben ist, dann Datum des Todes angeben.'),
(17083, 2925, 5, 'If SMTP is used, the server`s hostname or IP address.'),
(17084, 2926, 5, 'If SMTP is used, the server`s TCP port number (usually 25).'),
(17085, 2927, 5, 'Wenn arbeitslos, Student eingeben'),
(17086, 2932, 5, 'Wenn Sie ein Pay Datum in der Suchseite eingegeben haben, wird diese das Buchungsdatum der Zahlungen und Anpassungen überschreiben, welch sonst aus der X12-Datei übernommen werden. Dies kann für die Berichterstattung nützlich sein , wenn Sie Ihre Einnahmen Berichterstattung an Ihren Buchungsdatum anstatt die Versicherung ''s Bearbeitungsdatum verwenden möchten. Beachten Sie, dass dies auch Auswirkungen auf Termin vor Zahlungen und Anpassungen, die in Nebenforderungen gesetzt werden.'),
(17087, 2933, 5, 'Wenn Sie Datentypen oder Zeilen/Spalten einfügen wollen'),
(17088, 2934, 5, 'Wenn Sie die Datenbank aktualisieren möchten, dann legen Sie die Datenbank zip-Datei im folgenden Verzeichnis'),
(17089, 2936, 5, 'Ignorieren'),
(17090, 2937, 5, 'Krankheit'),
(17091, 2938, 5, 'IM'),
(17092, 2941, 5, 'Bilddienstleister'),
(17093, 2942, 5, 'Impfung'),
(17094, 2943, 5, 'Impfstoff Code'),
(17095, 2945, 5, 'Impfungsdatum'),
(17096, 2946, 5, 'Impfstopp Verfall Datum'),
(17097, 2947, 5, 'Impfstoff Chargen Nummer'),
(17098, 2948, 5, 'Impfstoff Hersteller'),
(17099, 2949, 5, 'Impfstoff Registrierung'),
(17100, 2951, 5, 'Impfstoff Service'),
(17101, 2952, 5, 'Impstoff Titel'),
(17102, 2953, 5, 'Impfungen'),
(17103, 2954, 5, 'Impfen'),
(17104, 2955, 5, 'Immun'),
(17105, 2956, 5, 'Implantate'),
(17106, 2957, 5, 'Importieren'),
(17107, 2961, 5, 'Importiere Zertifikat zu Browser'),
(17108, 2962, 5, 'Konfiguration importieren'),
(17109, 2964, 5, 'Patient importieren'),
(17110, 2965, 5, 'Importieren Patientendaten'),
(17111, 2966, 5, 'wichtige Codes'),
(17112, 2969, 5, 'Importiert aus Buchhaltung'),
(17113, 2972, 5, 'Verbessert'),
(17114, 2973, 5, 'in'),
(17115, 2974, 5, 'IN'),
(17116, 2975, 5, 'in beiden Augen'),
(17117, 2976, 5, 'im linken Auge'),
(17118, 2977, 5, 'in Nasenloch'),
(17119, 2978, 5, 'Im Büro'),
(17120, 2979, 5, 'im rechten Auge'),
(17121, 2980, 5, 'intern'),
(17122, 2981, 5, 'Inaktiv'),
(17123, 2982, 5, 'Inaktive Tage'),
(17124, 2983, 5, 'Posteingang'),
(17125, 2986, 5, 'Prüfsumme einfügen'),
(17126, 2987, 5, 'Fertig eingefügt'),
(17127, 2988, 5, 'Beinhaltet inaktive Benutzer'),
(17128, 2989, 5, 'Einbeziehen Kategorielos'),
(17129, 2990, 5, 'Einbeziehen unstrukturierter Daten'),
(17130, 2991, 5, 'Einbeziehen der Vitalität'),
(17131, 2992, 5, 'Einbeziehen der Vital Daten?'),
(17132, 2993, 5, 'Aufnahme'),
(17133, 2994, 5, 'Einkommen'),
(17134, 2996, 5, 'Unvollständig'),
(17135, 2997, 5, 'Unvollständige Abtreibung Behandlung'),
(17136, 2998, 5, 'Inkontinenz'),
(17137, 2999, 5, 'Integrieren klinischer Labor-Testergebnisse in zertifizierte EHR-Technologie als strukturierte Daten.'),
(17138, 3000, 5, 'Falsches Passwort!'),
(17139, 3001, 5, 'Gesteigert:'),
(17140, 3002, 5, 'Haftpflichtversicherung'),
(17141, 3003, 5, 'unbestimmt'),
(17142, 3004, 5, 'Inder'),
(17143, 3005, 5, 'Zeigt Abnormität'),
(17144, 3006, 5, 'Zeigt an, ob dieses Problem gerade aktiv ist'),
(17145, 3008, 5, 'Indikator für spezielle Nutzung'),
(17146, 3009, 5, 'Bedürftigen Patienten Berichten'),
(17147, 3010, 5, 'Bedürftigen Patienten Berichten'),
(17148, 3011, 5, 'Bestandteile'),
(17149, 3014, 5, 'Abtreibung'),
(17150, 3016, 5, 'untauglich'),
(17151, 3017, 5, 'Infektion / Abzess'),
(17152, 3018, 5, 'Infektionen'),
(17153, 3020, 5, 'Unfruchtbarkeit'),
(17154, 3021, 5, 'Influenza 1'),
(17155, 3022, 5, 'Influenza 2'),
(17156, 3023, 5, 'Grippeimpfung für Patienten älter 50 Jahre'),
(17157, 3024, 5, 'Grippeimpfung für Patienten>= 50 Jahre'),
(17158, 3025, 5, 'Grippeimpfstoff'),
(17159, 3026, 5, 'Info'),
(17160, 3027, 5, 'Info test 1'),
(17161, 3028, 5, 'Info test 2'),
(17162, 3029, 5, 'Info test 3'),
(17163, 3030, 5, 'Info test 4'),
(17164, 3031, 5, 'Info test 5'),
(17165, 3032, 5, 'Info test 6'),
(17166, 3034, 5, 'Inhalationen'),
(17167, 3035, 5, 'Inhalationen'),
(17168, 3037, 5, 'Erstbenutzer'),
(17169, 3039, 5, 'injizierbare'),
(17170, 3040, 5, 'Injektion'),
(17171, 3041, 5, 'Verletztes Körperteil'),
(17172, 3043, 5, 'Verletzung'),
(17173, 3044, 5, 'Verletzungs Mechanismus'),
(17174, 3045, 5, 'Verletzungs Übersicht Bericht'),
(17175, 3046, 5, 'Verletzungs Beobachten'),
(17176, 3047, 5, 'Verletzungs Type'),
(17177, 3048, 5, 'Verletzungs- oder krankheitsbezogen'),
(17178, 3051, 5, 'Eingabefelder'),
(17179, 3064, 5, 'In Summe'),
(17180, 3065, 5, 'INS1'),
(17181, 3066, 5, 'INS2'),
(17182, 3067, 5, 'INS3'),
(17183, 3069, 5, 'Eifügen fehlgeschlagen: '),
(17184, 3070, 5, 'Alte Ereignisse in Tabellen speichern'),
(17185, 3072, 5, 'Schlaflosigkeit'),
(17186, 3073, 5, 'Log kontrollieren'),
(17187, 3074, 5, 'Inspektion'),
(17188, 3075, 5, 'Instabilität / Subluxation'),
(17189, 3076, 5, 'INSTALLIERE'),
(17190, 3077, 5, 'Installiere'),
(17191, 3079, 5, 'installiere DB'),
(17192, 3080, 5, 'Installierte Version'),
(17193, 3081, 5, 'angewiesen'),
(17194, 3082, 5, 'Anweisung'),
(17195, 3084, 5, 'Anweisungen:'),
(17196, 3085, 5, 'Zu wenig Lagerbestand für die Produkt-ID'),
(17197, 3086, 5, 'Insulin Abhängige Diabetes'),
(17198, 3087, 5, 'Versicherung'),
(17199, 3088, 5, 'Versicherung'),
(17200, 3091, 5, 'Versicherungs Restbetrag'),
(17201, 3092, 5, 'Offener Betrag Versicherung'),
(17202, 3093, 5, 'Versicherungunternehmen'),
(17203, 3094, 5, 'Versicherungunternehmen'),
(17204, 3095, 5, 'Versicherungunternehmen'),
(17205, 3096, 5, 'Versicherungunternehmen suchen/hinzufügen'),
(17206, 3098, 5, 'Versicherungsdaten'),
(17207, 3099, 5, 'Versicherungs Informationen in Datei'),
(17208, 3100, 5, 'Versicherungsnummer'),
(17209, 3101, 5, 'Versicherungs Zahlung'),
(17210, 3103, 5, 'Versicherungs Anbieter'),
(17211, 3106, 5, 'Versichert'),
(17212, 3107, 5, 'Intake Schlussfolgerung'),
(17213, 3108, 5, 'Schlussfolgerung Datum'),
(17214, 3109, 5, 'Geistiger Verfall'),
(17215, 3113, 5, 'Internal error - no pages were selected!'),
(17216, 3114, 5, 'Internal error - patient ID was not provided!'),
(17217, 3115, 5, 'Internal error accessing uploaded file!'),
(17218, 3116, 5, 'Internal error!'),
(17219, 3117, 5, 'Internal error, no drug ID specified!'),
(17220, 3119, 5, 'Internal error: claim '),
(17221, 3120, 5, 'Internal error: encounter '''),
(17222, 3121, 5, 'Internal error: pid or encounter is missing.'),
(17223, 3122, 5, 'Interner Fehler: Es scheint keine Konsultation aktiv zu sein'),
(17224, 3123, 5, 'Interne ID (pid)'),
(17225, 3126, 5, 'Interne Verweise'),
(17226, 3127, 5, 'Interne Zeit summe'),
(17227, 3128, 5, 'internationale Pflicht'),
(17228, 3129, 5, 'Dolmetscher'),
(17229, 3130, 5, 'Dolmetscher benötigt?'),
(17230, 3131, 5, 'Interstitielle Lung Krankheit'),
(17231, 3132, 5, 'Intervall'),
(17232, 3135, 5, 'Intervention'),
(17233, 3137, 5, 'Intoleranz'),
(17234, 3139, 5, 'Intramuskulär'),
(17235, 3140, 5, 'Intravenös'),
(17236, 3141, 5, 'Einführung'),
(17237, 3144, 5, 'Ungültiges Zeichen in'),
(17238, 3147, 5, 'Ungültige Länge füt'),
(17239, 3148, 5, 'Ungültiges "Nicht-Numerisches" Zeichen in'),
(17240, 3149, 5, 'Unwirksame oder fehlender Zahler in Quelle für Code '),
(17241, 3150, 5, 'Ungülige Empfänger Adresse. Bitte erneut versuchen.'),
(17242, 3151, 5, 'Ungültige Service Codes'),
(17243, 3152, 5, 'Ungültige Quelle Bezeichnung "'),
(17244, 3153, 5, 'Ungültiger Benutzername oder Passwort'),
(17245, 3154, 5, 'InvAmt'),
(17246, 3155, 5, 'Bestand'),
(17247, 3156, 5, 'Bestand Aktivitäten'),
(17248, 3159, 5, 'Inventar ist nicht für diesen Auftrag verfügbar.'),
(17249, 3160, 5, 'Inventar Liste'),
(17250, 3161, 5, 'Bestandstransaktionen'),
(17251, 3162, 5, 'Rechnung'),
(17252, 3163, 5, 'rechnung'),
(17253, 3164, 5, 'Rechnung Bilanz'),
(17254, 3165, 5, 'Rechnung Bilanz kann nicht gebucht werden. Kein Fall wird erstellt.'),
(17255, 3166, 5, 'Rechnungsdatum'),
(17256, 3167, 5, 'Rechnung hat kein Datum!'),
(17257, 3168, 5, 'Rechnung Nummer'),
(17258, 3169, 5, 'Rechnungsreferenznummer'),
(17259, 3170, 5, 'Rechnungsreferenznummernpool, falls benutzt'),
(17260, 3171, 5, 'Rechnungsreferenznummernpool'),
(17261, 3172, 5, 'Rechnungsrefnr. Pool'),
(17262, 3173, 5, 'Rechnung:'),
(17263, 3180, 5, 'IPV 1'),
(17264, 3181, 5, 'IPV 2'),
(17265, 3182, 5, 'IPV 3'),
(17266, 3183, 5, 'IPV 4'),
(17267, 3185, 5, 'Unregelmäßiger Herzschlag'),
(17268, 3186, 5, 'Reizbarkeit'),
(17269, 3187, 5, 'Reizung'),
(17270, 3190, 5, 'ist eine neuere Version der folgenden Datenbank'),
(17271, 3191, 5, 'ist Pflicht Feld.'),
(17272, 3192, 5, 'ist ein Root-Knoten und kann nicht gelöscht werden.'),
(17273, 3193, 5, 'ist eine erweiterung der folgenden Datenbank'),
(17274, 3195, 5, 'ist unangebracht oder falsch'),
(17275, 3197, 5, 'ist nicht gültig (Dezimalbrüche sind OK).'),
(17276, 3198, 5, 'Verwendet PHP "Safe Mode"?'),
(17277, 3200, 5, 'Soll Text von Formular-Layouts übersetzt werden?'),
(17278, 3201, 5, 'Soll Text in Listen übersetzt werden?'),
(17279, 3202, 5, 'Ist die Datei Verschlusselt?'),
(17280, 3204, 5, 'Ist das eine Diagnose Typ?'),
(17281, 3207, 5, 'Ist das eine Prozedur / Service-Typ?'),
(17282, 3208, 5, 'Ist dies Aktiv?'),
(17283, 3209, 5, 'Ist dieser COde Type aktiv?'),
(17284, 3210, 5, 'Ist dieser Code in den Ansprüchen verwendet?'),
(17285, 3212, 5, 'Ist diese Art im Honorar Blatt versteckt?'),
(17286, 3213, 5, 'Wird eine externe SQL-Tabelle verwendet? Wenn Ja, dann Format wählen.'),
(17287, 3214, 5, 'ist zu lang'),
(17288, 3216, 5, 'Problem'),
(17289, 3217, 5, 'problem'),
(17290, 3218, 5, 'Problem Datum'),
(17291, 3219, 5, 'Problem ID'),
(17292, 3220, 5, 'Problem Titel'),
(17293, 3221, 5, 'Problem Art'),
(17294, 3222, 5, 'Problem Arten'),
(17295, 3223, 5, 'Probleme'),
(17296, 3224, 5, 'Probleme (Verletzungen, Medizinisch, Allergien)'),
(17297, 3225, 5, 'Probleme (Verletzungen, Medizinisch, Allergien):'),
(17298, 3226, 5, 'Probleme und Kontakte'),
(17299, 3227, 5, 'Probleme und Kontakte für'),
(17300, 3228, 5, 'Problem nicht berechtigt'),
(17301, 3229, 5, 'Problem Bereich'),
(17302, 3230, 5, 'Italienisch'),
(17303, 3231, 5, 'Artikel'),
(17304, 3232, 5, 'artikel'),
(17305, 3233, 5, 'artikel'),
(17306, 3234, 5, 'Artikel laden fehlgeschlagen'),
(17307, 3235, 5, 'IU/L'),
(17308, 3236, 5, 'IUD'),
(17309, 3237, 5, 'IV'),
(17310, 3238, 5, 'Jan'),
(17311, 3239, 5, 'Januar'),
(17312, 3240, 5, 'Japaner'),
(17313, 3241, 5, 'Gelbsucht'),
(17314, 3243, 5, 'Job Beschreibung'),
(17315, 3244, 5, 'Job ID'),
(17316, 3245, 5, 'gemeinsame Versetzungen'),
(17317, 3246, 5, 'Gelenkschmerzen'),
(17318, 3247, 5, 'Gelenkverstauchungen'),
(17319, 3248, 5, 'Jul'),
(17320, 3249, 5, 'Juli'),
(17321, 3250, 5, 'Jun'),
(17322, 3251, 5, 'Juni'),
(17323, 3252, 5, 'Knapp unterhalb der Scheck Informationen ist eine blaue Fläche, wo Sie in Ihre Suchparameter setzen. Sie können nach Name des Patienten, Chart-Nummer, Fall Nummer oder Datum der Zustellung oder eine beliebige Kombination von diesen zu suchen. Sie können auch wählen, ob Sie alle Rechnungen, offene Rechnungen oder nur Rechnungen, die fällig (durch den Patienten) sind sehen. Klicken Sie auf die Schaltfläche Suchen, um die Suche durchzuführen.'),
(17324, 3253, 5, 'Nur Meins'),
(17325, 3255, 5, 'Rechtfertigen'),
(17326, 3256, 5, 'Rechtfertigen/Speichern'),
(17327, 3258, 5, 'k, hier ist der rest'),
(17328, 3264, 5, 'Schlüssel'),
(17329, 3265, 5, 'Schlüsselwörter'),
(17330, 3266, 5, 'kg'),
(17331, 3267, 5, 'kg/m^2'),
(17332, 3269, 5, 'Nierenkrebs'),
(17333, 3270, 5, 'Nierenversagen'),
(17334, 3271, 5, 'Nieren Infektion'),
(17335, 3272, 5, 'Nieren Steine'),
(17336, 3273, 5, 'Nieren Transplantation'),
(17337, 3277, 5, 'Knie'),
(17338, 3278, 5, 'Knieprobleme'),
(17339, 3279, 5, 'Knieprothese'),
(17340, 3282, 5, 'Koreanisch'),
(17341, 3286, 5, 'Labor'),
(17342, 3288, 5, 'Labor-Übertragung Adresse'),
(17343, 3289, 5, 'Labor-Übertragung ID'),
(17344, 3290, 5, 'Labor-Übertragung Token-ID'),
(17345, 3294, 5, 'Labor-Abfrage Status'),
(17346, 3295, 5, 'Laborbericht'),
(17347, 3296, 5, 'Laborbefund'),
(17348, 3297, 5, 'Laborbefunde'),
(17349, 3299, 5, 'Laborbefunde Bericht'),
(17350, 3300, 5, 'Labor Service'),
(17351, 3301, 5, 'Labor Testergebnisse'),
(17352, 3303, 5, 'Etikett'),
(17353, 3304, 5, 'Etikett darf nicht leer sein'),
(17354, 3305, 5, 'Etikettenspalten'),
(17355, 3306, 5, 'Etikett für diesen Type'),
(17356, 3307, 5, 'Label-Spalten muss eine Zahl zwischen 1 und 999 sein'),
(17357, 3308, 5, 'Etiketten'),
(17358, 3311, 5, 'Labore'),
(17359, 3312, 5, 'Platzwunde / Hautproblem'),
(17360, 3313, 5, 'Platzwunde / Schürfwunde'),
(17361, 3316, 5, 'Sprache'),
(17362, 3317, 5, 'Sprachcode'),
(17363, 3318, 5, 'Sprachdefinition hinzugefügt'),
(17364, 3319, 5, 'Sprach-Schnittstellen-Tool'),
(17365, 3320, 5, 'Sprachliste (schreiben, hinzufügen optional)'),
(17366, 3321, 5, 'Sprachenname'),
(17367, 3322, 5, 'Sprache:'),
(17368, 3324, 5, 'Laotisch'),
(17369, 3325, 5, 'Letzte'),
(17370, 3326, 5, 'Letztes Aktivitätendatum'),
(17371, 3328, 5, 'Letztes Rechnungsdatum:'),
(17372, 3330, 5, 'Letztes Kalenderjahr'),
(17373, 3333, 5, 'Lezter Besuch'),
(17374, 3343, 5, 'Letzter Monat'),
(17375, 3344, 5, 'Nachname'),
(17376, 3345, 5, 'Nachname'),
(17377, 3346, 5, 'Nachname'),
(17378, 3350, 5, 'Zuletzt bearbeitet'),
(17379, 3351, 5, 'Letzte Ausführung am'),
(17380, 3352, 5, 'Zuletzt gespeichert'),
(17381, 3356, 5, 'Letztes Update von'),
(17382, 3357, 5, 'Letzte Kontrolle am'),
(17383, 3358, 5, 'Letzte Konsultation'),
(17384, 3360, 5, 'Letzte Wiedererkrankung (2-12 Monate)'),
(17385, 3361, 5, 'Außenknöchel'),
(17386, 3362, 5, 'Außenknöchel:'),
(17387, 3373, 5, 'Layout-basiert'),
(17388, 3374, 5, 'Layout-Editor'),
(17389, 3375, 5, 'Layoutgruppen'),
(17390, 3376, 5, 'Layout-Stil'),
(17391, 3378, 5, 'Layout-basierte Formulare'),
(17392, 3379, 5, 'Layouts'),
(17393, 3380, 5, 'lb'),
(17394, 3381, 5, 'lbs'),
(17395, 3382, 5, 'LDL'),
(17396, 3383, 5, 'freilassen, wenn noch aktiv'),
(17397, 3384, 5, 'Leer lassen - Dateiname bleibt unverändert'),
(17398, 3385, 5, 'Leer lassen - Passwort bleibt unverändert'),
(17399, 3386, 5, 'Nachricht hinterlassen mit'),
(17400, 3387, 5, 'Feld verlassen'),
(17401, 3388, 5, 'Ist das Pass Phrase Feld leer, so wird das Dokument nicht verschlüsselt'),
(17402, 3390, 5, 'Links'),
(17403, 3391, 5, 'Linkes Ohr'),
(17404, 3392, 5, 'linkes Ohr'),
(17405, 3394, 5, 'Links:'),
(17406, 3395, 5, 'Links: '),
(17407, 3396, 5, 'Bein / Krämpfe'),
(17408, 3397, 5, 'Legal'),
(17409, 3399, 5, 'Norm Papier Format'),
(17410, 3400, 5, 'Legende:'),
(17411, 3401, 5, 'Länge'),
(17412, 3403, 5, 'Kleiner als'),
(17413, 3404, 5, 'kleiner als oder gleich'),
(17414, 3405, 5, 'Weniger private Informationen (Schreiben, nur hinzufügen optional)'),
(17415, 3406, 5, 'Brief'),
(17416, 3407, 5, 'Brief Generator'),
(17417, 3408, 5, 'Briefpapier Größe'),
(17418, 3409, 5, 'Briefkopf, welcher Arzt signiert'),
(17419, 3410, 5, 'Briefkopf, welcher Patient signiert'),
(17420, 3411, 5, 'Dringlichkeit'),
(17421, 3412, 5, 'Haftung'),
(17422, 3413, 5, 'Medizinische Haftung'),
(17423, 3414, 5, 'Lizenz/ID'),
(17424, 3419, 5, 'Lizenzierter verschreibender Nachname'),
(17425, 3420, 5, 'Lizenzierter verschreibender Arzt NPI'),
(17426, 3421, 5, 'Lizenzierter verschreibender Arzt UPIN'),
(17427, 3423, 5, 'Lebensstil'),
(17428, 3424, 5, 'Lebensstil'),
(17429, 3425, 5, 'Bänderriss oder Verstauchung'),
(17430, 3426, 5, 'leichter Raucher'),
(17431, 3428, 5, 'Limit der Ereignisse'),
(17432, 3429, 5, 'Limits'),
(17433, 3431, 5, 'Link'),
(17434, 3432, 5, 'Link zum Patienten'),
(17435, 3433, 5, 'Verbunden'),
(17436, 3436, 5, 'verbunde mit Dokument'),
(17437, 3438, 5, 'Liste'),
(17438, 3439, 5, 'Listenfeld'),
(17439, 3440, 5, 'listenfeld'),
(17440, 3443, 5, 'Listen Editor'),
(17441, 3444, 5, 'Liste Besuche'),
(17442, 3445, 5, 'Liste Gruppen'),
(17443, 3446, 5, 'Liste Versicherungs Gesellschaften'),
(17444, 3448, 5, 'Listeneinträge können nicht mit einer Zahl beginnen'),
(17445, 3449, 5, 'Listeneinträge enthalten ungültige Zeichen'),
(17446, 3451, 5, 'Listen anzeigen'),
(17447, 3452, 5, 'Liste Name'),
(17448, 3453, 5, 'Listennamen können nicht mit einer Zahl beginnen.'),
(17449, 3454, 5, 'Liste Rezepte'),
(17450, 3458, 5, 'Listen'),
(17451, 3460, 5, 'Testament'),
(17452, 3461, 5, 'LLL:'),
(17453, 3462, 5, 'LMP'),
(17454, 3464, 5, 'Lade Definitionen'),
(17455, 3470, 5, 'LADEN'),
(17456, 3471, 5, 'Laden der Dateien in die Datenbank. Dies wird einige Zeit dauern ...'),
(17457, 3472, 5, 'Lok'),
(17458, 3473, 5, 'Lokal'),
(17459, 3476, 5, 'Lokal'),
(17460, 3477, 5, 'Örtlichkeit'),
(17461, 3478, 5, 'Ort'),
(17462, 3479, 5, 'Die Lage des LibreEHR Servers und dessen Inhalt können sensible Daten enthalten, so ist es empfehlenswert, diese Dateien, nach ihrer Verwendung, manuell zu löschen.'),
(17463, 3480, 5, 'Ort dieser Charge'),
(17464, 3481, 5, 'Ort unbekannt'),
(17465, 3482, 5, 'Ort, an dem Hylafax Faxe gespeichert werden.'),
(17466, 3483, 5, 'Ort, an dem Scans gespeichert werden.'),
(17467, 3484, 5, 'Ort:'),
(17468, 3485, 5, 'Gesperrt'),
(17469, 3492, 5, 'Anmelden'),
(17470, 3493, 5, 'Anmelden'),
(17471, 3494, 5, 'Abmelden'),
(17472, 3495, 5, 'Angemeldet'),
(17473, 3496, 5, 'Angemeldet als'),
(17474, 3497, 5, 'Angemeldet als: '),
(17475, 3498, 5, 'Abgemeldet.'),
(17476, 3499, 5, 'Logging'),
(17477, 3500, 5, 'Anmelden'),
(17478, 3501, 5, 'anmelden'),
(17479, 3503, 5, 'Auf Remote Host anmelden'),
(17480, 3504, 5, 'Auf Remote Host anmelden, fehlgeschlagen'),
(17481, 3505, 5, 'Abmelden'),
(17482, 3506, 5, 'abmelden'),
(17483, 3507, 5, 'Logs'),
(17484, 3508, 5, 'Logviewer'),
(17485, 3510, 5, 'Nachschlagen'),
(17486, 3511, 5, 'Charge'),
(17487, 3512, 5, 'Chargen ID fehlt!'),
(17488, 3513, 5, 'Chargen-Nummer'),
(17489, 3514, 5, 'Niedrig'),
(17490, 3515, 5, 'Niedrige Priorität'),
(17491, 3516, 5, 'Unterschenkel'),
(17492, 3517, 5, 'Niedrigste Priorität'),
(17493, 3519, 5, 'Lendenwirbelsäule'),
(17494, 3520, 5, 'Mittagessen'),
(17495, 3521, 5, 'Mittagessen'),
(17496, 3522, 5, 'Lungenkrebs'),
(17497, 3523, 5, 'Thoraxchirurgie bei Lungenkrebs'),
(17498, 3524, 5, 'Lungen:'),
(17499, 3525, 5, 'Lungen:'),
(17500, 3526, 5, 'Lupus'),
(17501, 3528, 5, 'M'),
(17502, 3529, 5, 'MA Kategorie'),
(17503, 3530, 5, 'MA-Client akzeptiert Abtreibung'),
(17504, 3531, 5, 'MA Status'),
(17505, 3533, 5, 'Mail gesendet'),
(17506, 3534, 5, 'Haupt'),
(17507, 3535, 5, 'Hauptadresse'),
(17508, 3536, 5, 'Hauptansicht'),
(17509, 3537, 5, 'Pflegen aktiven Medikamenten-Allergie-Liste.'),
(17510, 3538, 5, 'Pflege aktive Medikamenten Liste.'),
(17511, 3539, 5, 'Pflegen Sie eine up-to-date Problem Liste der aktuellen und aktiven Diagnosen.'),
(17512, 3540, 5, 'Änderungen an aktuellen Kategorien.'),
(17513, 3541, 5, 'Neuen Termin für'),
(17514, 3542, 5, 'Verichern'),
(17515, 3543, 5, 'Erstellen Batch-Text-Dateien für den Upload auf Clearing House und markieren als abgerechnet'),
(17516, 3548, 5, 'Männlich'),
(17517, 3549, 5, 'Männer Kondome'),
(17518, 3552, 5, 'Mammogramm'),
(17519, 3553, 5, 'Verwalten'),
(17520, 3556, 5, 'Verwalte Übersetzungen'),
(17521, 3557, 5, 'Management'),
(17522, 3558, 5, 'Erforderliche und spezielle Felder'),
(17523, 3559, 5, 'Nur obligatorische oder bestimmte Felder, Duplikat Scheck, keine Suche'),
(17524, 3560, 5, 'Nur obligatorische oder bestimmte Felder, Duplikat Scheck, keine Suche'),
(17525, 3561, 5, 'Handbuch'),
(17526, 3562, 5, 'Manuelle Buchung'),
(17527, 3563, 5, 'Hersteller'),
(17528, 3565, 5, 'Mär.'),
(17529, 3568, 5, 'März'),
(17530, 3569, 5, 'Familienstand'),
(17531, 3571, 5, 'Markiert als bezahlt aber überspringe Abrechnung'),
(17532, 3572, 5, 'Markiert als gelöscht'),
(17533, 3573, 5, 'Markiert als nicht bezahlt'),
(17534, 3574, 5, 'Berichte als kontrolliert markieren'),
(17535, 3575, 5, 'Markiert als gelöscht'),
(17536, 3576, 5, 'Verheiratet'),
(17537, 3578, 5, 'Maske'),
(17538, 3579, 5, 'Maske für Rechnungsnummern'),
(17539, 3580, 5, 'Maske für Patienten IDs'),
(17540, 3581, 5, 'Maske für Produkt IDs'),
(17541, 3582, 5, 'Entsprechen'),
(17542, 3591, 5, 'Max.'),
(17543, 3594, 5, 'Oberkiefer rechts:'),
(17544, 3595, 5, 'Maximales Alter'),
(17545, 3596, 5, 'Maximale Zeichen'),
(17546, 3597, 5, 'Maximale Wartezeit in Sekunden, vorm ausloggen. Der Standardwert ist 7200 (2 Stunden).'),
(17547, 3600, 5, 'Maximal sinnvolle Bestandsaufnahme, 0 falls nicht zutreffend'),
(17548, 3601, 5, 'Maximale Größe'),
(17549, 3602, 5, 'Maximale Größe (0= beliebige Größe)'),
(17550, 3603, 5, 'Mai'),
(17551, 3604, 5, 'MC'),
(17552, 3605, 5, 'µg'),
(17553, 3607, 5, 'Keine der letzten drei Passwörter sind zulässig, wenn dieses geändert wird.'),
(17554, 3609, 5, 'Messung Gruppe Code'),
(17555, 3611, 5, 'Messung'),
(17556, 3612, 5, 'Malleolus medialis:'),
(17557, 3613, 5, 'Gesundheitsdienst'),
(17558, 3614, 5, 'Medizinisch'),
(17559, 3615, 5, 'Medizinische Abtreibung'),
(17560, 3616, 5, 'Medizinische Verwaltung'),
(17561, 3617, 5, 'Medizinischer Verlauf'),
(17562, 3618, 5, 'Medizinisches Problem'),
(17563, 3619, 5, 'Medizinisches Problem'),
(17564, 3620, 5, 'Medizinisches problem'),
(17565, 3621, 5, 'Medizinisches Problem'),
(17566, 3622, 5, 'Medizinisches problem Liste'),
(17567, 3623, 5, 'Medizinische Probleme'),
(17568, 3624, 5, 'Medizinische Aufzeichnung'),
(17569, 3625, 5, 'Medizinische Aufzeichnung #'),
(17570, 3626, 5, 'Medizinische Aufzeichnungen'),
(17571, 3627, 5, 'Medizinische Aufzeichnung gesendet'),
(17572, 3629, 5, 'Medizinische Zusammenfassung Aufgrund'),
(17573, 3630, 5, 'Medizinisches System'),
(17574, 3631, 5, 'Medizinischer Type'),
(17575, 3632, 5, 'Medizinischer Verlauf (schreiben, nur hinzufügen optional)'),
(17576, 3635, 5, 'Medikamente'),
(17577, 3636, 5, 'Liste allerischer Medikamente'),
(17578, 3637, 5, 'Medikamente Problem Liste'),
(17579, 3638, 5, 'Medikamenten Liste'),
(17580, 3639, 5, 'Medikamente Abstimmung durchgeführt?'),
(17581, 3640, 5, 'Medikamente'),
(17582, 3641, 5, 'Medikamente:'),
(17583, 3642, 5, 'Medizin Einheiten'),
(17584, 3643, 5, 'mittel'),
(17585, 3645, 5, 'Mitgliedsverband Statistik Bericht'),
(17586, 3646, 5, 'Speicherprobleme'),
(17587, 3647, 5, 'Männer'),
(17588, 3648, 5, 'Männer und Frauen'),
(17589, 3649, 5, 'Nur Männer'),
(17590, 3650, 5, 'Menstruation'),
(17591, 3651, 5, 'Menopause'),
(17592, 3652, 5, 'Menstruation'),
(17593, 3653, 5, 'Menstruationszyklus Häufigkeit'),
(17594, 3654, 5, 'Menstruationskrankheit'),
(17595, 3657, 5, 'Susammenfügen'),
(17596, 3658, 5, 'Susammenfügen beendet.'),
(17597, 3659, 5, 'Patienten Zusammenfügen'),
(17598, 3661, 5, 'Nachricht'),
(17599, 3662, 5, 'Nachrichtenzentrale'),
(17600, 3665, 5, 'Nachricht gesendet'),
(17601, 3666, 5, 'Nachrichtenstatus'),
(17602, 3669, 5, 'Nachrichten Art'),
(17603, 3670, 5, 'Nachricht:'),
(17604, 3671, 5, 'Nachrichten'),
(17605, 3672, 5, 'Nachrichten die heute gesendet wurden'),
(17606, 3673, 5, 'Methode'),
(17607, 3674, 5, 'Methode und Spezifisches Produkt'),
(17608, 3675, 5, 'Methode für ausgehende e-mail'),
(17609, 3676, 5, 'Methode der Zerstörung'),
(17610, 3679, 5, 'mg'),
(17611, 3680, 5, 'mg/1ml'),
(17612, 3681, 5, 'mg/2ml'),
(17613, 3682, 5, 'mg/3ml'),
(17614, 3683, 5, 'mg/4ml'),
(17615, 3684, 5, 'mg/5ml'),
(17616, 3685, 5, 'mg/dl'),
(17617, 3686, 5, 'Mitte'),
(17618, 3687, 5, '2. Vorname'),
(17619, 3688, 5, '2. Vorname'),
(17620, 3690, 5, 'DEA einfache überweisende Person'),
(17621, 3691, 5, 'Vorname einfache überweisende Person'),
(17622, 3692, 5, 'Nachname einfache überweisende Person'),
(17623, 3693, 5, 'Titel einfache überweisende Person'),
(17624, 3694, 5, 'UPIN einfache überweisende Person'),
(17625, 3695, 5, 'Miene'),
(17626, 3696, 5, 'Migranten oder Saisonarbeiter?'),
(17627, 3697, 5, 'Migrant / Seasonal'),
(17628, 3698, 5, 'Mil/CU.MM'),
(17629, 3702, 5, 'Mime type'),
(17630, 3703, 5, 'Min'),
(17631, 3704, 5, 'min'),
(17632, 3705, 5, 'Mindestalter'),
(17633, 3706, 5, 'Zerrung +/- synovitis'),
(17634, 3708, 5, 'Minuten'),
(17635, 3709, 5, 'Minuten'),
(17636, 3710, 5, 'Minuten'),
(17637, 3712, 5, 'Sonstiges'),
(17638, 3713, 5, 'Sonstiges Rechnungs Optionen'),
(17639, 3714, 5, 'Sonstiges Rechnungs Optionen HFCA-1500'),
(17640, 3715, 5, 'Sonstiges Rechnungs Optionen HFCA'),
(17641, 3716, 5, 'Diverses'),
(17642, 3717, 5, 'Verfehlt'),
(17643, 3718, 5, 'fehlend'),
(17644, 3719, 5, 'Ein benötigtes Feld fehlt'),
(17645, 3720, 5, 'Fehlende Gebühr'),
(17646, 3721, 5, 'Nur fehlende Mods'),
(17647, 3722, 5, 'Fehlender oder ungültiger'),
(17648, 3723, 5, 'Fehlende PID'),
(17649, 3724, 5, 'Fehlender Berichtsdatum'),
(17650, 3725, 5, 'Missing slash after payer in source for code '),
(17651, 3726, 5, 'Gemischt'),
(17652, 3727, 5, 'ml'),
(17653, 3728, 5, 'MM/TT/JJJJ'),
(17654, 3729, 5, 'mm/Hg'),
(17655, 3730, 5, 'mmHg'),
(17656, 3731, 5, 'MMR 1'),
(17657, 3732, 5, 'MMR 2'),
(17658, 3733, 5, 'Mobil'),
(17659, 3734, 5, 'Mobiltelefon'),
(17660, 3735, 5, 'Modifizierer'),
(17661, 3738, 5, 'Mittlere Priorität'),
(17662, 3740, 5, 'Mittlere/niedrige Priorität'),
(17663, 3741, 5, 'Modifizierer'),
(17664, 3742, 5, 'Modifizierer'),
(17665, 3743, 5, 'Anpassen'),
(17666, 3745, 5, 'Zahlungen anpassen'),
(17667, 3746, 5, 'Mod-Länge'),
(17668, 3753, 5, 'Mo'),
(17669, 3754, 5, 'Mo bis Fr'),
(17670, 3755, 5, 'Mo, Mi &amp; Fr'),
(17671, 3756, 5, 'Montag'),
(17672, 3758, 5, 'Monat'),
(17673, 3759, 5, 'Monat'),
(17674, 3760, 5, 'Monatsansicht'),
(17675, 3761, 5, 'Monat(e)'),
(17676, 3762, 5, 'Monatseinkommen'),
(17677, 3763, 5, 'Monate'),
(17678, 3765, 5, 'Mehr als 100 Treffer, genauer suchen.'),
(17679, 3766, 5, 'Mehr als 50 Treffer, genauer suchen.'),
(17680, 3767, 5, 'Einige Spaltenköpfe können angeklickt werden, um die Sortierung zu ändern'),
(17681, 3768, 5, 'Neueste von'),
(17682, 3770, 5, 'Jüngste Vitaldaten vom:'),
(17683, 3771, 5, 'Mutter'),
(17684, 3772, 5, 'Name Mutter'),
(17685, 3774, 5, 'Mund'),
(17686, 3775, 5, 'Bewegen'),
(17687, 3776, 5, 'Dokumentenkategorie verschieben:'),
(17688, 3777, 5, 'Herunterschieben'),
(17689, 3779, 5, 'Zu Patienten verschieben'),
(17690, 3780, 5, 'Hochschieben...'),
(17691, 3781, 5, 'Hochschieben'),
(17692, 3782, 5, 'sich bewegend'),
(17693, 3783, 5, 'Hr.'),
(17694, 3784, 5, 'MRN (pid)'),
(17695, 3785, 5, 'Fr.'),
(17696, 3786, 5, 'Fr.'),
(17697, 3787, 5, 'MSH-11'),
(17698, 3788, 5, 'MSH-3.1'),
(17699, 3789, 5, 'MSH-4.1'),
(17700, 3790, 5, 'MSH-5.1'),
(17701, 3791, 5, 'MSH-6.1'),
(17702, 3794, 5, 'MSP Code'),
(17703, 3795, 5, 'MSP wiederhol Code'),
(17704, 3796, 5, 'Mehrsprachen-Tool'),
(17705, 3797, 5, 'Viele Felder'),
(17706, 3798, 5, 'Mehrere Dokumente können hochgeladen werden durch CTRL+Click or SHIFT+Click.'),
(17707, 3799, 5, 'Mehrere Portionen'),
(17708, 3800, 5, 'Multiple Modifikatoren können getrennt werden durch Leerräume, maximal 4 (M1:M2:M3:M4)'),
(17709, 3802, 5, 'gemischtrassig'),
(17710, 3803, 5, 'Geräusch:'),
(17711, 3804, 5, 'Muskelschmerz'),
(17712, 3805, 5, 'Muskelschmerz'),
(17713, 3806, 5, 'Muskelrötung'),
(17714, 3807, 5, 'Muskelsteifheit'),
(17715, 3808, 5, 'Muskelschwellung'),
(17716, 3809, 5, 'Muskelwärme'),
(17717, 3810, 5, 'Muskel'),
(17718, 3811, 5, 'Muskelverletzung'),
(17719, 3812, 5, 'Muskuloskeletal'),
(17720, 3813, 5, 'Muss leer bleiben, wenn SMTP-Authentifizierung nicht verwendet wird.'),
(17721, 3814, 5, 'gemeinsam definiert'),
(17722, 3815, 5, 'MVA'),
(17723, 3818, 5, 'Ich'),
(17724, 3821, 5, 'Fehlt'),
(17725, 3822, 5, 'Fehlt'),
(17726, 3823, 5, 'Name'),
(17727, 3825, 5, 'Name (klick für mehr)'),
(17728, 3826, 5, 'Name 1'),
(17729, 3827, 5, 'Name 2'),
(17730, 3828, 5, 'Name und Bezeichnung des Impfstoffherstellers'),
(17731, 3831, 5, 'Name der Ereignisse'),
(17732, 3832, 5, 'Name der Versicherungsgesellschaft'),
(17733, 3833, 5, 'Name des Behandlers'),
(17734, 3834, 5, 'Name des Absenders für Patienten Erinnerung'),
(17735, 3835, 5, 'Namen Übersetzung'),
(17736, 3836, 5, 'Name/Wert'),
(17737, 3837, 5, 'Name:'),
(17738, 3838, 5, 'Nasenlöcher:'),
(17739, 3839, 5, 'Nasenlöcher: Normal Rechts'),
(17740, 3840, 5, 'Nasenschleimhaut rosa, septum mittellinig'),
(17741, 3841, 5, 'Nation Notizen'),
(17742, 3842, 5, 'konfiguriere Nation notizen'),
(17743, 3843, 5, 'Nation Notizen ersatz buttons'),
(17744, 3844, 5, 'Nationalität'),
(17745, 3845, 5, 'Nation Notizen'),
(17746, 3847, 5, 'Hawai-Ursprünglich oder Pacific region'),
(17747, 3852, 5, 'Erbrechen'),
(17748, 3854, 5, 'Navigation'),
(17749, 3855, 5, 'Navigationsbereich beinhaltet Besuch Formular'),
(17750, 3866, 5, 'Nacken'),
(17751, 3867, 5, 'Nackenprobleme'),
(17752, 3868, 5, 'Nacken geschmeidig'),
(17753, 3869, 5, 'Beschreibung muss eingegeben werden'),
(17754, 3870, 5, 'Rückgabewerte muss eingegeben werden'),
(17755, 3871, 5, 'Identifier muss eingegeben werden'),
(17756, 3872, 5, 'Titel muss eingegeben werden'),
(17757, 3873, 5, 'Autentifizierung erforderlich'),
(17758, 3876, 5, 'Negativ'),
(17759, 3877, 5, 'Negatives'),
(17760, 3880, 5, 'Nervenverletzung'),
(17761, 3882, 5, 'neurologisches Taubheitsgefühl'),
(17762, 3883, 5, 'neurologisches Schwäche'),
(17763, 3884, 5, 'Neurologisch'),
(17764, 3885, 5, 'Nie'),
(17765, 3886, 5, 'Nie Alkohol'),
(17766, 3887, 5, 'Nie Raucher'),
(17767, 3888, 5, 'Neu'),
(17768, 3889, 5, 'Neu =>'),
(17769, 3892, 5, 'Neue Allergien'),
(17770, 3894, 5, 'Neue Termine'),
(17771, 3895, 5, 'Neue Kategorien'),
(17772, 3896, 5, 'Neue Kategorie'),
(17773, 3897, 5, 'Neue Klienten'),
(17774, 3898, 5, 'Neue Konsultation'),
(17775, 3900, 5, 'Neue Definitionen hinzugefügt'),
(17776, 3901, 5, 'Neues Dokument'),
(17777, 3902, 5, 'Neuee Dokumente'),
(17778, 3904, 5, 'Neuer Fall'),
(17779, 3905, 5, 'Neuer Fall mit ID'),
(17780, 3906, 5, 'Neue Visite erfassen'),
(17781, 3907, 5, 'Neue Fälle nicht erlaubt'),
(17782, 3908, 5, 'Neuer Fall'),
(17783, 3909, 5, 'Informationen zu neuen Standort'),
(17784, 3910, 5, 'Neue Datei'),
(17785, 3911, 5, 'Neue Dateien'),
(17786, 3912, 5, 'Neue Gruppe'),
(17787, 3913, 5, 'Informationen zu neuer Gruppe'),
(17788, 3916, 5, 'Neues Limit für Ereignisse'),
(17789, 3917, 5, 'Neue Liste'),
(17790, 3918, 5, 'Neue'),
(17791, 3919, 5, 'neuer Absatz'),
(17792, 3920, 5, 'Neues Passwort'),
(17793, 3921, 5, 'Neuer Patient'),
(17794, 3922, 5, 'Neuer Patient'),
(17795, 3923, 5, 'Neues Patienten-Fallformular'),
(17796, 3924, 5, 'Neuer Patient Formular'),
(17797, 3925, 5, 'Neue Patienten-ID'),
(17798, 3926, 5, 'Neue Zahlart'),
(17799, 3928, 5, 'Neuer Patient'),
(17800, 3929, 5, 'Neue Ergebnisse aus Labor Austausch'),
(17801, 3930, 5, 'Neue Suche'),
(17802, 3932, 5, 'Neuer Benutzer'),
(17803, 3934, 5, 'Neue Termine'),
(17804, 3935, 5, 'Neu/Suche'),
(17805, 3961, 5, 'Zeitung'),
(17806, 3962, 5, 'Weiter'),
(17807, 3964, 5, 'Nächster Tag'),
(17808, 3965, 5, 'Nächster Monat'),
(17809, 3966, 5, 'Nächster Monat (gedrückt halten für Menü)'),
(17810, 3968, 5, 'Nächste Woche'),
(17811, 3969, 5, 'Nächstes Jahr (gedrückt halten für Menü)'),
(17812, 3971, 5, 'Spitzname'),
(17813, 3973, 5, 'Nächtliches Schwitzen'),
(17814, 3974, 5, 'Unauffälliges äußeres Genitale, vaginale Mukosa, Zervix'),
(17815, 3975, 5, 'Nein'),
(17816, 3976, 5, 'Nein'),
(17817, 3977, 5, 'Kein Zugriff'),
(17818, 3978, 5, 'Keine aktiven Patienten Erinnerungen.'),
(17819, 3983, 5, 'Keine Termine'),
(17820, 3992, 5, 'Keine Diagnose'),
(17821, 3993, 5, 'keine Dokumente gefunden'),
(17822, 3995, 5, 'Kein Enddatum'),
(17823, 3996, 5, 'Keine Einträge gefunden, Formular unten zum Hinzufügen verwenden.'),
(17824, 3997, 5, 'keine Fehler gefunden'),
(17825, 3998, 5, 'Keine Ereignisse'),
(17826, 4000, 5, 'Keine Dateien für eine Installation vorgesehen'),
(17827, 4001, 5, 'Keine Gruppe ausgewählt'),
(17828, 4002, 5, 'Keine Hernie'),
(17829, 4005, 5, 'Keine Verletzung/Erkrankung'),
(17830, 4006, 5, 'Keine Versicherungsgesellschaft gefunden'),
(17831, 4007, 5, 'keine Probleme'),
(17832, 4009, 5, 'Keine Einträge in dieser Kategorie'),
(17833, 4010, 5, 'Keine Auswahl getroffen!'),
(17834, 4025, 5, 'Für das ausgewählte Datum ist keine Log-Datei vorhanden'),
(17835, 4028, 5, 'Keine Patientenakte zum angegebenen Re-Identifikations-Code gefunden'),
(17836, 4029, 5, 'Keine Übereinstimmungen gefunden. Suche wiederholen.'),
(17837, 4030, 5, 'Keine Übereinstimmungen gefunden.'),
(17838, 4031, 5, 'Keine Übereinstimmungen gefunden. Neuen Patienten jetzt anlegen?'),
(17839, 4032, 5, 'Keine übereinstimmende Aufzeichnungen gefunden'),
(17840, 4033, 5, 'Keine neuen Ergebnisse gefunden'),
(17841, 4034, 5, 'Keine Bemerkungen'),
(17842, 4035, 5, 'Keine Organomegalie'),
(17843, 4037, 5, 'Keine anderen Telefonnummern geführt'),
(17844, 4039, 5, 'Keine Partner gefunden'),
(17845, 4040, 5, 'Keine Patientenakte für die Auswahlkriterien gefunden'),
(17846, 4041, 5, 'Keine Patientenakte zum angegebenen Re-Identifikations-Code gefunden'),
(17847, 4042, 5, 'Keine peripheren Ödeme'),
(17848, 4043, 5, 'Keine Apotheken gefunden'),
(17849, 4044, 5, 'Keine Verschreibungen gefunden'),
(17850, 4045, 5, 'Keine Angabe von Erkrankung/Verletzung'),
(17851, 4046, 5, 'Keine älteren Einträge.'),
(17852, 4051, 5, 'Keine Zulieferer gefunden'),
(17853, 4053, 5, 'Keine Aufzeichnungen gefunden'),
(17854, 4055, 5, 'Keine Einträge gefunden. Suche weiter formulieren.'),
(17855, 4056, 5, 'Keine Erinnerungen'),
(17856, 4057, 5, 'Keine Ergebnisse für die gewählten Suchkriterien gefunden'),
(17857, 4058, 5, 'Keine Treffer'),
(17858, 4060, 5, 'Keine Treffer für die Suche gefunden'),
(17859, 4061, 5, 'Keine Treffer gefunden, bitte wiederholen.'),
(17860, 4062, 5, 'Keine Treffer, nochmal versuchen.'),
(17861, 4063, 5, 'Keine Treffer, nochmal versuchen.'),
(17862, 4065, 5, 'Keine Anzeige'),
(17863, 4075, 5, 'Keie Konsultation'),
(17864, 4076, 5, 'Keine Vitalitäten dokumentiert'),
(17865, 4077, 5, 'Nein, abbrechen'),
(17866, 4079, 5, 'Nein:'),
(17867, 4081, 5, 'Nicht Bezahlt'),
(17868, 4083, 5, 'Unbestimmte Verletzung'),
(17869, 4084, 5, 'Nicht-elektronisch'),
(17870, 4085, 5, 'Nicht Insulin bedingter Diabetes'),
(17871, 4086, 5, 'Nicht Versichert'),
(17872, 4089, 5, 'Keine'),
(17873, 4090, 5, 'keine'),
(17874, 4091, 5, 'Nichts definiert'),
(17875, 4092, 5, 'Nichts wurde dokumentiert'),
(17876, 4093, 5, 'Keiner der oben genannten'),
(17877, 4095, 5, 'Nicht Insulin bedingter Diabetes'),
(17878, 4096, 5, 'noch'),
(17879, 4097, 5, 'Unauffällig'),
(17880, 4105, 5, 'Normal Rechts'),
(17881, 4106, 5, 'Normal Rechts:'),
(17882, 4107, 5, 'Normale Ansicht'),
(17883, 4108, 5, 'normal:'),
(17884, 4112, 5, 'Norwegisch'),
(17885, 4115, 5, 'Nase'),
(17886, 4116, 5, 'Nasenbluten'),
(17887, 4117, 5, 'kein Buchstabe und keine Zahl'),
(17888, 4119, 5, 'Nicht alle Felder sind für alle Codes oder Code-Arten erforderlich'),
(17889, 4120, 5, 'Nicht erlaubt'),
(17890, 4121, 5, 'Administrator-Gruppe kann nicht gelöscht werden'),
(17891, 4122, 5, 'Kann nicht editiert werden'),
(17892, 4123, 5, 'Alles Sicherheitsobjekte können nicht deaktiviert werden'),
(17893, 4125, 5, 'Der Administrator kann nicht aus der Administratoren-Gruppe entfernt werden'),
(17894, 4126, 5, 'Dieser Nutzer kann nicht aus der Administratoren-Gruppe entfernt werden'),
(17895, 4128, 5, 'Keine Rechte um PostCalendar-Modul zu bearbeiten'),
(17896, 4129, 5, 'Nicht berechtigt'),
(17897, 4130, 5, 'Nicht Berechtigt'),
(17898, 4135, 5, 'Nicht verfügbar'),
(17899, 4137, 5, 'Nicht bezahlt'),
(17900, 4138, 5, 'Nicht Überprüft'),
(17901, 4139, 5, 'Nicht ausgecheckt'),
(17902, 4140, 5, 'Nicht codiert'),
(17903, 4141, 5, 'nicht Aufgrund'),
(17904, 4143, 5, 'Nicht Untersucht'),
(17905, 4144, 5, 'Nicht Untersucht:'),
(17906, 4145, 5, 'Nicht Untersucht: '),
(17907, 4146, 5, 'nicht gefunden'),
(17908, 4148, 5, 'nicht gefunden!'),
(17909, 4149, 5, 'Kein Hispanic oder Latino'),
(17910, 4150, 5, 'Nicht installiert'),
(17911, 4152, 5, 'Nicht gesehen seit'),
(17912, 4154, 5, 'Noch nicht gesendet'),
(17913, 4156, 5, 'Nicht spezifiziert'),
(17914, 4157, 5, 'Notiz'),
(17915, 4159, 5, 'Es wird 5-10 Minuten dauern, nachdem Du auf Installieren geklickt hast'),
(17916, 4160, 5, 'Es wird 5-10 Minuten dauern, nachdem Du auf Upgrade geklickt hast'),
(17917, 4161, 5, 'Das Audit-Logging muss oben aktiviert werden'),
(17918, 4163, 5, 'Anmerkung: 12:00 Mittag ist PM, nicht AM'),
(17919, 4170, 5, 'HINWEIS: Doppelt hochgeladene Dateinamen werden automatisch umbenannt.(z. B. file.jpg wird file.1.jpg). Dateinamen Einmalig pro Patient und nicht pro Kategorie.'),
(17920, 4171, 5, 'HINWEIS: Doppelt hochgeladene Dateinamen werden automatisch umbenannt.(z. B. ''<i>file.jpg</i>'' wird zu ''<i>file.jpg.1</i>''). Dateinamen Einmalig pro Patient und nicht pro Kategorie.'),
(17921, 4172, 5, 'Notizen'),
(17922, 4175, 5, 'Notizen nicht authorisiert'),
(17923, 4177, 5, 'Nicht Aufgezeichnet'),
(17924, 4179, 5, 'Nichts zu importieren für die Allergie'),
(17925, 4180, 5, 'Nichts zu importieren für das Rezept'),
(17926, 4181, 5, 'nicht zum Anzeigen verfügbar'),
(17927, 4182, 5, 'nichts ausgewählt'),
(17928, 4185, 5, 'Benachrichtigung'),
(17929, 4186, 5, 'Benachrichtigungs Email Adresse'),
(17930, 4188, 5, 'Benachrichtigungen'),
(17931, 4189, 5, 'Administrator über die Ereignis-Änderung informieren?'),
(17932, 4190, 5, 'Nov'),
(17933, 4191, 5, 'November'),
(17934, 4192, 5, 'Jetzt Beitrag für:'),
(17935, 4193, 5, 'druckt'),
(17936, 4194, 5, 'Drucke $stmt_count Erklärungen und aktualisiere Visiten.'),
(17937, 4195, 5, 'Drucke $stmt_count Erklärungen und aktualisiere Rechnungen'),
(17938, 4196, 5, 'Drucke $stmt_count Erklärungen; Visiten werden nicht aktualisiert.'),
(17939, 4197, 5, 'Drucke $stmt_count Erklärungen; Rechnungen werden nicht aktualisiert'),
(17940, 4199, 5, 'NQF'),
(17941, 4200, 5, 'Nummer'),
(17942, 4201, 5, 'Anzahl Labors'),
(17943, 4204, 5, 'Anzahl der Spalten in der Jahresansicht'),
(17944, 4211, 5, 'Anzahl der Tage für die das Client-Zertifikat gültig ist.'),
(17945, 4213, 5, 'Anzahl der Nachkommastellen für Währung; gewöhnlich 0 oder 2'),
(17946, 4214, 5, 'Anzahl von Visiten pro Seite'),
(17947, 4215, 5, 'Anzahl der verpassten Ereignisse, wenn vorhanden'),
(17948, 4216, 5, 'Wieviel Stunden vorher sollen E-Mail-Benachrichtigungen gesendet werden?'),
(17949, 4217, 5, 'Wieviel Stunden vorher sollen telefonische Benachrichtigungen übermittelt werden?'),
(17950, 4218, 5, 'Wieviel Stunden vorher sollen SMS-Benachrichtigungen gesendet werden?'),
(17951, 4221, 5, 'Anzahl der History-Spalten'),
(17952, 4222, 5, 'Anzahl der Patienten pro Seite in der Patientenliste'),
(17953, 4223, 5, 'Taubheit'),
(17954, 4224, 5, 'Zähler'),
(17955, 4225, 5, 'Numerische Anzeigereihenfolge'),
(17956, 4227, 5, 'Ernährung'),
(17957, 4229, 5, 'O.A.F.V.'),
(17958, 4230, 5, 'O2 Sat'),
(17959, 4231, 5, 'Adipositas 1'),
(17960, 4232, 5, 'Adipositas 2'),
(17961, 4233, 5, 'Adipositas 3'),
(17962, 4234, 5, 'Ziel'),
(17963, 4237, 5, 'Beruf'),
(17964, 4239, 5, 'EreignisEintritt'),
(17965, 4240, 5, 'Okt'),
(17966, 4241, 5, 'Oktober'),
(17967, 4242, 5, 'OD'),
(17968, 4243, 5, 'von'),
(17969, 4244, 5, 'Quantität'),
(17970, 4245, 5, 'von Tabletten'),
(17971, 4246, 5, 'des Monats jeden'),
(17972, 4248, 5, 'Aus'),
(17973, 4249, 5, 'Büro Notizen'),
(17974, 4250, 5, 'Arztbesuch'),
(17975, 4251, 5, 'Offizielle CQM-Messgruppen'),
(17976, 4252, 5, 'HTTPS-Link für das Offsite-Patientenportal'),
(17977, 4253, 5, 'HTTPS-Link für das Onsite-Patientenportal (Patienten-Link)'),
(17978, 4254, 5, 'Passwort für das Offsite-Patientenportal'),
(17979, 4255, 5, 'Passwort für das Offsite-Patientenportal (Leer lassen, wenn noch nicht registriert)'),
(17980, 4258, 5, 'Adresse für das Offsite-Patientenportal'),
(17981, 4259, 5, 'Adresse für das Offsite-Patientenportal (Patienten-Link)'),
(17982, 4260, 5, 'Nutzername für das Offsite-Patientenportal'),
(17983, 4261, 5, 'Nutzername für das Offsite-Patientenportal (Leer lassen, wenn noch nicht registriert)'),
(17984, 4263, 5, 'Nachwuchs'),
(17985, 4265, 5, 'Salbe'),
(17986, 4267, 5, 'OK'),
(17987, 4270, 5, 'Alt'),
(17988, 4272, 5, 'Alte Klienten'),
(17989, 4273, 5, 'Alte Fraktur -keine Fehlstellung'),
(17990, 4274, 5, 'Altes Layout ohne linkes Menü'),
(17991, 4275, 5, 'Altes statisches Formular ohne Suche oder Duplikats-Check'),
(17992, 4279, 5, 'Arbeitgeber-Informationen in Patientendaten auslassen'),
(17993, 4280, 5, 'Arbeitgeber auslassen'),
(17994, 4282, 5, 'Versicherung und einige andere Dinge vom Demographie-Formular auslassen'),
(17995, 4284, 5, 'Zahlmethode vom co-pay-Panel auslassen'),
(17996, 4286, 5, 'an'),
(17997, 4287, 5, 'An'),
(17998, 4288, 5, 'am Hand'),
(17999, 4289, 5, 'auf Bestellung'),
(18000, 4292, 5, 'Wenn das Passwort geändert wurde ist eine Neuanmeldung erforderlich.'),
(18001, 4297, 5, 'Online Support'),
(18002, 4298, 5, 'Online Support Link'),
(18003, 4299, 5, 'Nur Aktive'),
(18004, 4302, 5, 'Nur wenn Rechnungs-Location'),
(18005, 4303, 5, 'Nur Inaktive'),
(18006, 4304, 5, 'Nur Eigene'),
(18007, 4305, 5, 'Zeige nur Diagnose-Berichtscodes'),
(18008, 4307, 5, 'Lade nur aktive Rezepte'),
(18009, 4315, 5, 'Ups!'),
(18010, 4316, 5, 'Öffnen'),
(18011, 4318, 5, 'in neuen Fenster öffnen'),
(18012, 4321, 5, 'Heutige Visite öffnent'),
(18013, 4322, 5, 'Für LibreEHR wurde bereits eine Zertifikats-Authorität konfiguriert'),
(18014, 4324, 5, 'LibreEHR Datenbank Update'),
(18015, 4327, 5, 'LibreEHR muss für die Verwendung von Zertifikaten konfiguriert sein, bevor Client-Zertifikate erstellt werden können.'),
(18016, 4328, 5, 'LibreEHR erfordert Javascript, um den Nutzer authentifizieren zu können.'),
(18017, 4329, 5, 'LibreEHR Anwender'),
(18018, 4332, 5, 'ophthalmologisch'),
(18019, 4333, 5, 'Option'),
(18020, 4342, 5, 'Optionaler Ziel-Name'),
(18021, 4343, 5, 'Optionaler Medikamenten-Name; verwende % als Platzhalter'),
(18022, 4345, 5, 'Optionale Informationen zu diesem Ereignis'),
(18023, 4346, 5, 'Optionale Losnummer; verwende % als Platzhalte'),
(18024, 4347, 5, 'Optional numerische Patienten-ID'),
(18025, 4348, 5, 'Optionaler Behandlungs-Code'),
(18026, 4349, 5, 'Optionaler Behandlungs/Leistungs-Code'),
(18027, 4350, 5, 'Optionen'),
(18028, 4351, 5, 'Oder'),
(18029, 4352, 5, 'ODER'),
(18030, 4353, 5, 'oder wählen SIe'),
(18031, 4354, 5, 'oder klicke und ziehe für eine schnellere Auswahl'),
(18032, 4358, 5, 'oder Shift-Klick zum verringern'),
(18033, 4359, 5, 'Oder lade ERA-Datei hoch:'),
(18034, 4360, 5, 'Oral'),
(18035, 4362, 5, 'Reihenfolge'),
(18036, 4363, 5, 'Bestellung und Ergebnis Typen'),
(18037, 4364, 5, 'Bestell-Katalog'),
(18038, 4365, 5, 'Bestelldatum'),
(18039, 4367, 5, 'Bestellung vom'),
(18040, 4369, 5, 'Reihenfolge muss eine Zahl zwischen 1 und 999 sein'),
(18041, 4370, 5, 'Bestellname'),
(18042, 4371, 5, 'Bestell Priorität'),
(18043, 4372, 5, 'Bestell-Bearbeiter'),
(18044, 4375, 5, 'Bestell Status'),
(18045, 4378, 5, 'Bestell Type'),
(18046, 4380, 5, 'Bestell/Ergebnis Type'),
(18047, 4381, 5, 'Bestellt'),
(18048, 4386, 5, 'Organverletzung'),
(18049, 4387, 5, 'Organisation'),
(18050, 4388, 5, 'Organisation Name'),
(18051, 4389, 5, 'Name der Organisationseinheit'),
(18052, 4390, 5, 'Organisationen'),
(18053, 4392, 5, 'Original'),
(18054, 4398, 5, 'OS'),
(18055, 4402, 5, 'Andere'),
(18056, 4403, 5, 'andere'),
(18057, 4404, 5, 'Andere (spezifizieren)'),
(18058, 4405, 5, 'Andere - Spezifiziert'),
(18059, 4406, 5, 'Anderes Bundesprogramm'),
(18060, 4407, 5, 'Andere HCFA'),
(18061, 4410, 5, 'anderer Monat'),
(18062, 4411, 5, 'Andere nicht-föderale Programme'),
(18063, 4412, 5, 'andere Notizen');
INSERT INTO `lang_definitions` VALUES
(18064, 4417, 5, 'Andere chirurgische'),
(18065, 4420, 5, 'Andere'),
(18066, 4425, 5, 'Nicht im Büro'),
(18067, 4426, 5, 'ausgehende Überweisung'),
(18068, 4427, 5, 'Resultat'),
(18069, 4428, 5, 'Outlook'),
(18070, 4431, 5, 'ÜBERFÄLLIG'),
(18071, 4432, 5, 'übermäßiger Gebrauch'),
(18072, 4433, 5, 'Übersicht'),
(18073, 4434, 5, 'Übergewicht'),
(18074, 4435, 5, 'Überschreibe HIPAA-Auswahl'),
(18075, 4437, 5, 'Sauerstoff Sättigung'),
(18076, 4439, 5, 'Postprandial'),
(18077, 4440, 5, 'postprandial'),
(18078, 4441, 5, 'nachmittags'),
(18079, 4443, 5, 'Bewohner der Pazif. Inseln'),
(18080, 4444, 5, 'Pädiatrisch'),
(18081, 4445, 5, 'Seite'),
(18082, 4446, 5, 'Seiten'),
(18083, 4447, 5, 'Bezahlt'),
(18084, 4449, 5, 'Bezahlter Betrag'),
(18085, 4450, 5, 'Bezahlt per'),
(18086, 4451, 5, 'Schmerz'),
(18087, 4453, 5, 'Herzklopfen'),
(18088, 4455, 5, 'Pap-Abstrich'),
(18089, 4456, 5, 'Papier'),
(18090, 4457, 5, 'Papier Größe'),
(18091, 4458, 5, 'Lähmung'),
(18092, 4461, 5, 'HL7 analysieren'),
(18093, 4463, 5, 'Partner'),
(18094, 4464, 5, 'Partner Name'),
(18095, 4467, 5, 'Pass Phrase'),
(18096, 4468, 5, 'Pass-Phrase zur Verschlüsselung des Dokuments'),
(18097, 4469, 5, 'übergebene Patienten'),
(18098, 4470, 5, 'Passiver Alarm'),
(18099, 4471, 5, 'Passiver Alarm Regeln'),
(18100, 4472, 5, 'Kennwort'),
(18101, 4473, 5, 'Kennwortänderung'),
(18102, 4475, 5, 'Kennwortänderung erfolgreich'),
(18103, 4480, 5, 'Kennwort für SMS Gateway'),
(18104, 4481, 5, 'Kennwort für SMS Gateway'),
(18105, 4483, 5, 'Passwort-Sicherheit wurde kürzlich aktualisiert.'),
(18106, 4484, 5, 'Passwort für die Verbindung zu CouchDB'),
(18107, 4486, 5, 'Passwort:'),
(18108, 4490, 5, 'überfällig'),
(18109, 4491, 5, 'überfällig'),
(18110, 4492, 5, 'überfällig Intervall (klinische Erinnerungen)'),
(18111, 4493, 5, 'überfällig Intervall (Patienten Erinnerung)'),
(18112, 4494, 5, 'Frühere Fälle Liste'),
(18113, 4495, 5, 'Frühere Fälle'),
(18114, 4496, 5, 'Frühere Fälle und Dokumente'),
(18115, 4497, 5, 'Frühere Fälle für'),
(18116, 4498, 5, 'Einfügen HL7 Daten'),
(18117, 4499, 5, 'Füge die Daten in die Text-Box unten ein:'),
(18118, 4508, 5, 'Pfad zum Ereignis-Log Backup'),
(18119, 4509, 5, 'Pfad zur CA-Zertifikats-Datei'),
(18120, 4510, 5, 'Pfad zur CA-Schlüsseldatei'),
(18121, 4511, 5, 'Pfad zu den MySQL bin'),
(18122, 4512, 5, 'Pfad zu Perl bin'),
(18123, 4513, 5, 'Pfad zu temporären Dateien'),
(18124, 4514, 5, 'Patient'),
(18125, 4515, 5, 'Patient'),
(18126, 4516, 5, 'Patient'),
(18127, 4517, 5, 'Patient Adresse'),
(18128, 4518, 5, 'Patient Adresse fehlt'),
(18129, 4521, 5, 'Patient allergien'),
(18130, 4522, 5, 'Patient Allergien'),
(18131, 4523, 5, 'Patient Termin'),
(18132, 4524, 5, 'Restbetrag Patient'),
(18133, 4525, 5, 'Offener Betrag Patient'),
(18134, 4531, 5, 'Patient Wohnort'),
(18135, 4532, 5, 'Patient Wohnort fehlt'),
(18136, 4535, 5, 'Patient Land'),
(18137, 4536, 5, 'Patient Land fehlt. Außerdem wurde kein Standard-Wert für das Land in den globalen Einstellungen vorgegeben'),
(18138, 4539, 5, 'Patient Daten'),
(18139, 4541, 5, 'Patient Geburtsdatum fehlt'),
(18140, 4542, 5, 'Patient Details'),
(18141, 4543, 5, 'Patient Geburtstag'),
(18142, 4544, 5, 'Patient Dokument'),
(18143, 4545, 5, 'Patient Bildung'),
(18144, 4546, 5, 'Patienten-Unterweisungsmaterial'),
(18145, 4547, 5, 'Patient Besuch'),
(18146, 4548, 5, 'Patient Besuch Formular'),
(18147, 4549, 5, 'Patient Besuche'),
(18148, 4550, 5, 'Patient Suche'),
(18149, 4551, 5, 'Patienten Vorname'),
(18150, 4553, 5, 'Patienten Vornahme Fehlt'),
(18151, 4558, 5, 'Patienten Geschlecht'),
(18152, 4559, 5, 'Patienten Geschlecht fehlt'),
(18153, 4560, 5, 'Patient hat keine Berechtigung für das Patientenportal'),
(18154, 4561, 5, 'Patienten Übersicht'),
(18155, 4562, 5, 'Anamnese / Lebensstil'),
(18156, 4563, 5, 'Patient Telefon zu Hause'),
(18157, 4564, 5, 'Patienten ID'),
(18158, 4565, 5, 'Patienten Id'),
(18159, 4566, 5, 'Patienten Ausweis'),
(18160, 4567, 5, 'Patienten Ausweis Kategorie Name'),
(18161, 4568, 5, 'Patienten Impfungen'),
(18162, 4569, 5, 'Patienten Information'),
(18163, 4570, 5, 'Patienten Anweisungen'),
(18164, 4573, 5, 'Patienten Beschwerden'),
(18165, 4575, 5, 'Patienten Nachname'),
(18166, 4577, 5, 'Patienten Nachname fehlt'),
(18167, 4581, 5, 'Patientenübersicht'),
(18168, 4582, 5, 'Patienten Liste Spalte'),
(18169, 4584, 5, 'Patienten Liste neues Fenster'),
(18170, 4585, 5, 'Patienten Liste Seitengröße'),
(18171, 4586, 5, 'Patienten Suche Fehler'),
(18172, 4587, 5, 'Patient medizinische Probleme'),
(18173, 4588, 5, 'Patienten Medikation'),
(18174, 4589, 5, 'Patienten Name'),
(18175, 4590, 5, 'Patienten Name & Anschrift'),
(18176, 4593, 5, 'Patienten Name Erforderlich'),
(18177, 4595, 5, 'Patienten Notiz'),
(18178, 4596, 5, 'Patienten Notiz Type'),
(18179, 4597, 5, 'Patienten Notiz'),
(18180, 4598, 5, 'Patienten Notizen (schreiben, hinzufügen optional)'),
(18181, 4599, 5, 'Patientennummer'),
(18182, 4600, 5, 'Patienten Zahlung'),
(18183, 4602, 5, 'Patienten Photo Kategoriename'),
(18184, 4603, 5, 'Patientenportal'),
(18185, 4605, 5, 'Patientenportal ist deaktiviert'),
(18186, 4606, 5, 'Patientenportal Login'),
(18187, 4607, 5, 'Patientenportal Web Adresse'),
(18188, 4608, 5, 'Patient Gedruckter Bericht'),
(18189, 4609, 5, 'Patientenakte Bericht'),
(18190, 4610, 5, 'Patientenakte Anfrage'),
(18191, 4611, 5, 'Patientenakten Anfrage'),
(18192, 4613, 5, 'Patient Erinnerung'),
(18193, 4614, 5, 'Patient Erinnerung Stapelverarbeitung'),
(18194, 4616, 5, 'Patienten Erinnerungen Regeln'),
(18195, 4617, 5, 'Patienten Erinnerungen Absender Email'),
(18196, 4618, 5, 'Patienten Erinnerungen Absender Name'),
(18197, 4619, 5, 'Patient Erinnerungen'),
(18198, 4620, 5, 'Patientenbericht'),
(18199, 4621, 5, 'Patienten Anfrage'),
(18200, 4622, 5, 'Patient wünschte medizinischen Aufzeichnungen'),
(18201, 4623, 5, 'Patientenergebnisse'),
(18202, 4624, 5, 'Patient Stil der Suchergebnisse'),
(18203, 4625, 5, 'Patient Suche/Ergänze Bildschirm'),
(18204, 4626, 5, 'Patienten Einstellungen'),
(18205, 4627, 5, 'Patienten Status'),
(18206, 4629, 5, 'Patienten Zusammenfassung'),
(18207, 4630, 5, 'Patienten Überweisung'),
(18208, 4631, 5, 'Patient PLZ'),
(18209, 4632, 5, 'Patienten in der Datenbank, die mit den eingegebenen demographischen Informationen übereinstimmen'),
(18210, 4633, 5, 'Patient'),
(18211, 4634, 5, 'Patient:'),
(18212, 4635, 5, 'Patient ID'),
(18213, 4636, 5, 'Patienten'),
(18214, 4638, 5, 'Bezahlen'),
(18215, 4640, 5, 'Bezahl Datum:'),
(18216, 4641, 5, 'Bezahl Status'),
(18217, 4642, 5, 'Name des Zahlungsempfängers'),
(18218, 4643, 5, 'Zahler'),
(18219, 4644, 5, 'Zahler Type'),
(18220, 4645, 5, 'Bezahlen'),
(18221, 4646, 5, 'Zahlende Stelle'),
(18222, 4647, 5, 'Zahlung'),
(18223, 4648, 5, 'zahlung'),
(18224, 4651, 5, 'Zahlungsbetrag'),
(18225, 4652, 5, 'Zahlungsbetrag muss numerisch sein'),
(18226, 4653, 5, 'Zahlungsmethoden Kategorie'),
(18227, 4654, 5, 'Zahlungsdatum'),
(18228, 4655, 5, 'Zahlung eingegangen am'),
(18229, 4656, 5, 'Zahlung von'),
(18230, 4660, 5, 'Zahlungsart'),
(18231, 4661, 5, 'Zahlungsmethoden Sortieren nach'),
(18232, 4662, 5, 'Zahlung Status'),
(18233, 4663, 5, 'Zahlung Type'),
(18234, 4665, 5, 'Zahlungen'),
(18235, 4667, 5, 'PCP'),
(18236, 4669, 5, 'PDF'),
(18237, 4670, 5, 'PDF Download Ausgewählte Statements'),
(18238, 4672, 5, 'Becken und Gesäßhälfte'),
(18239, 4673, 5, 'Pemphigus'),
(18240, 4674, 5, 'Anstehend'),
(18241, 4677, 5, 'Weiterhin beobachten'),
(18242, 4679, 5, 'Offene Bestellungen'),
(18243, 4680, 5, 'Offene Res'),
(18244, 4681, 5, 'Review offen'),
(18245, 4687, 5, 'pro Min'),
(18246, 4688, 5, 'Per Nasenloch'),
(18247, 4689, 5, 'per pasenloch'),
(18248, 4690, 5, 'Oral'),
(18249, 4691, 5, 'oral'),
(18250, 4692, 5, 'Rektal'),
(18251, 4693, 5, 'rektal'),
(18252, 4694, 5, 'Prozent'),
(18253, 4697, 5, 'Perzentil'),
(18254, 4699, 5, 'Starte Suche'),
(18255, 4700, 5, 'Starte diese Aktion'),
(18256, 4703, 5, 'Ausführendes Labor'),
(18257, 4705, 5, 'Periode'),
(18258, 4706, 5, 'Anzahl an Tagen, für die ein Nutzer sich mit einem abgelaufenen Passwort anmelden kann'),
(18259, 4708, 5, 'Peripher'),
(18260, 4712, 5, 'Person'),
(18261, 4713, 5, 'Personalisieren'),
(18262, 4714, 5, 'PG'),
(18263, 4715, 5, 'Apoth'),
(18264, 4717, 5, 'Apotheken'),
(18265, 4718, 5, 'Apotheken'),
(18266, 4719, 5, 'Apotheke Ambulanz'),
(18267, 4720, 5, 'Pheumothorax'),
(18268, 4729, 5, 'Telefon'),
(18269, 4730, 5, 'Telefon Anrufliste'),
(18270, 4731, 5, 'Telefon Anruflisten Bericht'),
(18271, 4733, 5, 'Telefon Gateway Passwort'),
(18272, 4734, 5, 'Telefon Gateway URL'),
(18273, 4735, 5, 'Telefon Gateway Username'),
(18274, 4737, 5, 'Telefon Benachrichtigungs Stunde'),
(18275, 4738, 5, 'Telefonnummer'),
(18276, 4740, 5, 'Lichtempfindlichkeit'),
(18277, 4741, 5, 'Fotos'),
(18278, 4742, 5, 'PHP komprimiert'),
(18279, 4743, 5, 'PHP CURL-Modul sollte für den Server aktiviert sein'),
(18280, 4744, 5, 'PHP extrahiert'),
(18281, 4745, 5, 'php-GACL Zugangskontrolle ist ausgeschaltet'),
(18282, 4746, 5, 'PHP-gacl ist nicht installiert'),
(18283, 4747, 5, 'körperliche Untersuchung'),
(18284, 4749, 5, 'Physio Anfrage'),
(18285, 4750, 5, 'Physio Unterschrift'),
(18286, 4752, 5, 'Ärzte'),
(18287, 4753, 5, 'wählen'),
(18288, 4754, 5, 'Wählen'),
(18289, 4755, 5, 'CSS-Theme wählen'),
(18290, 4756, 5, 'PID'),
(18291, 4757, 5, 'PID (Entzündliche Erkrankungen des Beckens)'),
(18292, 4758, 5, 'Tabletten Größe'),
(18293, 4759, 5, 'Tabletten'),
(18294, 4760, 5, 'Lege die ZIP-Datei der Datenbank in das folgende Verzeichnis'),
(18295, 4761, 5, 'Lege die heruntergeladene ICD10 Datenbank-ZIP-Datei in das folgende Verzeichnis'),
(18296, 4762, 5, 'Lege die heruntergeladene ICD9 Datenbank-ZIP-Datei in das folgende Verzeichnis'),
(18297, 4763, 5, 'Lege die heruntergeladene RxNorm-Datenbank-ZIP-Datei in das folgende Verzeichnis'),
(18298, 4764, 5, 'Lege die heruntergeladene Snomed-Datenbank-ZIP-Datei in das folgende Verzeichnis'),
(18299, 4765, 5, 'Platzhalter'),
(18300, 4766, 5, 'Platzhalter (Maintains empty ACLs)'),
(18301, 4767, 5, 'Klartext'),
(18302, 4768, 5, 'Plan'),
(18303, 4771, 5, 'Plan Name'),
(18304, 4775, 5, 'Plan Set'),
(18305, 4779, 5, 'Plan:'),
(18306, 4782, 5, 'Planen'),
(18307, 4784, 5, 'Player'),
(18308, 4785, 5, 'Player Position'),
(18309, 4786, 5, 'Bitte rufen Sie an, wenn die oben aufgeführten Daten inkorrekt sind.'),
(18310, 4787, 5, 'Bitte Passwort ändern.'),
(18311, 4788, 5, 'Bitte Datei wählen'),
(18312, 4789, 5, 'Bitte einen Patienten wählen'),
(18313, 4790, 5, 'Bitte einen gültigen Eintrag aus der Liste wählen.'),
(18314, 4791, 5, 'Bitte einen gültigen Eintrag wählen.'),
(18315, 4792, 5, 'Bitte einen Wert für'),
(18316, 4793, 5, 'Bitte wähle oben einen Datumsbereich aus und klicke auf "Aktualisieren", um die Ergebnisse zu sehen'),
(18317, 4794, 5, 'Bitte wähle eine korrekt formatierte EDI-271-Datei aus'),
(18318, 4795, 5, 'Klicke auf "Herunterladen", um die De-Identified-Daten herunterzuladen'),
(18319, 4796, 5, 'Klicke auf "Herunterladen", um die Re-Identified-Daten herunterzuladen'),
(18320, 4797, 5, 'Schließe dieses Fenster.'),
(18321, 4798, 5, 'Vergleiche den neuen Namen'),
(18322, 4801, 5, 'Erstelle das folgende Verzeichnis bevor du weiter machst'),
(18323, 4802, 5, 'Bitte akzeptieren Sie diese Verschreibung nicht, ohne das dazugehörige Fax erhalten zu haben.'),
(18324, 4803, 5, 'Bitte akzeptieren Sie diese Verschreibung nicht, ohne das dazugehörige Fax erhalten zu haben.'),
(18325, 4804, 5, 'Nicht auf "Aktualisieren" oder "Abbrechen" im Browserfenster klicken, bevor nicht 10 Minuten vergangen sind.'),
(18326, 4805, 5, 'AKTIVIERE CURL-ERWEITERUNG'),
(18327, 4806, 5, 'AKTIVIERE OPENSSL-ERWEITERUNG'),
(18328, 4807, 5, 'AKTIVIERE SOAP-ERWEITERUNG'),
(18329, 4808, 5, 'AKTIVIERE XML-ERWEITERUNG'),
(18330, 4809, 5, 'Gib ein Datum für den letzten Review ein.'),
(18331, 4810, 5, 'Bitte Datum eingeben.'),
(18332, 4811, 5, 'Bitte Fälligkeitsdatum eingeben'),
(18333, 4812, 5, 'Bitte Nachricht eingeben'),
(18334, 4813, 5, 'Gib einen Geldbetrag ein, der ausschließlich aus Ziffern und dem Dezimaltrennzeichen besteht.'),
(18335, 4814, 5, 'Neues Passwort eingeben'),
(18336, 4815, 5, 'Titel eingeben'),
(18337, 4819, 5, 'Gib einen korrekten Re-Identification Code'),
(18338, 4821, 5, 'Bitte neue Suchzeichenfolge eingeben'),
(18339, 4822, 5, 'Gib einen korrekten Re-Idendification Code ein'),
(18340, 4823, 5, 'Neues Passwort eingeben'),
(18341, 4824, 5, 'Gib eine Cheque-Nummer an'),
(18342, 4825, 5, 'Gib eine Cheque/Ref-Nummer an'),
(18343, 4826, 5, 'Gib ein Datum an'),
(18344, 4827, 5, 'Gib einen Zahlbetrag an'),
(18345, 4828, 5, 'Gib eine Zahlungskategorie an'),
(18346, 4829, 5, '"Zahlung von" angeben'),
(18347, 4831, 5, 'Bitte ausfüllen.'),
(18348, 4832, 5, 'Gib einen Grund für diese Visite an'),
(18349, 4834, 5, 'Gib oben Suchkriterien an und klicke auf "Absenden", um Ergebnisse zu sehen'),
(18350, 4835, 5, 'Gib oben Suchkriterien an und klicke auf "Absenden", um Ergebnisse zu sehen (Ergebnisse erscheinen in einem neuen Fenster)'),
(18351, 4836, 5, 'Bitte nochmal anmelden.'),
(18352, 4837, 5, 'Beachte, dass dieser Vorgang sehr lange dauern kann und der Browser in dieser Zeit nicht reagieren kann.'),
(18353, 4838, 5, 'Bitte beachten: Bei Konstanten wird zwischen Groß- und Kleinschreibung unterschieden, jede Zeichenkette ist erlaubt.'),
(18354, 4839, 5, 'Verwende nur Buchstaben'),
(18355, 4840, 5, 'Verwende nur Buchstaben und keine Leerzeichen'),
(18356, 4841, 5, 'Bitte diesen Betrag zahlen'),
(18357, 4842, 5, 'Bitte plazieren Sie die Installations-Dateien in folgenden Ordner'),
(18358, 4844, 5, 'Passwort zurücksetzen'),
(18359, 4845, 5, 'Starte den Apache-Server neu, bevor Du de-Identification ausprobierst'),
(18360, 4847, 5, 'Bitte wählen'),
(18361, 4849, 5, 'Bitte eine Sprachen wählen'),
(18362, 4850, 5, 'Bitte einen Patienten wählen'),
(18363, 4854, 5, 'Bitte ein Rezept wählen'),
(18364, 4855, 5, 'Wähle ein Startdatum und ein Enddatum'),
(18365, 4856, 5, 'Wähle einen gültigen Empfänger'),
(18366, 4859, 5, 'Wähle ein Ereignis'),
(18367, 4860, 5, 'Wähle eine Suchoption'),
(18368, 4863, 5, 'Wähle mindestens eine Verschreibung'),
(18369, 4865, 5, 'Wähle die Seiten zum Kopieren oder Weiterleiten aus:'),
(18370, 4866, 5, 'Bitte wählen Sie die Zahlungsart'),
(18371, 4867, 5, 'Bitte Art der Zahlung wählen.'),
(18372, 4869, 5, 'Wähle X12-Partner; erforderlich, um den 270 batch zu erstellen'),
(18373, 4870, 5, 'Wähle'),
(18374, 4871, 5, 'Setze de_identification_config-Variable zurück auf null.'),
(18375, 4873, 5, 'Starte einen neuen De-Identifikationsprozess'),
(18376, 4874, 5, 'Aktualisiere die LibreEHR-Datenbank, um De-Identifikation nutzen zu können'),
(18377, 4875, 5, 'Schaue in die De-Identification Log-Tabelle für Details'),
(18378, 4876, 5, 'Besuche den De-Identification-Screen nach einiger Zeit'),
(18379, 4877, 5, 'Besuche den Re-Identification-Screen nach einiger Zeit'),
(18380, 4878, 5, 'Besuche diesen Screen nach einiger Zeit'),
(18381, 4882, 5, 'PM'),
(18382, 4883, 5, 'PM Programm'),
(18383, 4884, 5, 'Zahlungsart'),
(18384, 4896, 5, 'Point of Service (POS)'),
(18385, 4897, 5, 'Police'),
(18386, 4898, 5, 'Police-Nr.'),
(18387, 4899, 5, 'Police-Nummer'),
(18388, 4900, 5, 'Polnisch'),
(18389, 4901, 5, 'Polydipsie'),
(18390, 4902, 5, 'Polypen'),
(18391, 4903, 5, 'Polyurie'),
(18392, 4904, 5, 'Wenig Appetit'),
(18393, 4906, 5, 'Verminderte Hörfähigkeit'),
(18394, 4907, 5, 'Pop-Ups müssen aktiviert sein, um diesen Bericht zu sehen'),
(18395, 4908, 5, 'Soll die Jahresansicht mit Ereignissen gefüllt werden?'),
(18396, 4909, 5, 'Popups'),
(18397, 4910, 5, 'Portal'),
(18398, 4911, 5, 'Portal Aktivitäten'),
(18399, 4917, 5, 'Portugiesisch'),
(18400, 4918, 5, 'Portugiesisch (Brasilien)'),
(18401, 4919, 5, 'Portugiesisch (Europa)'),
(18402, 4920, 5, 'POS-Code'),
(18403, 4922, 5, 'Positiv'),
(18404, 4923, 5, 'Positives'),
(18405, 4925, 5, 'Beitrag For'),
(18406, 4928, 5, 'Nach OP'),
(18407, 4937, 5, 'Per Post'),
(18408, 4938, 5, 'PLZ'),
(18409, 4939, 5, 'PLZ'),
(18410, 4948, 5, 'Präsentiert von'),
(18411, 4953, 5, 'Praxis'),
(18412, 4954, 5, 'Praxis Voreinstellungen'),
(18413, 4955, 5, 'Einstellungen für die Praxis'),
(18414, 4956, 5, 'Behandler'),
(18415, 4958, 5, 'Vorauskasse'),
(18416, 4959, 5, 'Vorauszahlung'),
(18417, 4964, 5, 'Einstellungen'),
(18418, 4965, 5, 'Bevorzugte Ereignis Kategorie'),
(18419, 4966, 5, 'Bevorzugte Sprache'),
(18420, 4967, 5, 'Bevorzugte Apotheke'),
(18421, 4969, 5, 'Schwangerschaftstest'),
(18422, 4970, 5, 'Vorläufig'),
(18423, 4972, 5, 'Vorauskasse'),
(18424, 4973, 5, 'Rezepte'),
(18425, 4974, 5, 'Verschreibung hat Grenze erreicht von'),
(18426, 4975, 5, 'Verschreibungs-Historie'),
(18427, 4976, 5, 'Verschreibungs-Historie erfolgreich importiert'),
(18428, 4977, 5, 'Rezept Label'),
(18429, 4978, 5, 'Rezept Bericht'),
(18430, 4979, 5, 'Rezepte'),
(18431, 4983, 5, 'Rezepte Bericht'),
(18432, 4985, 5, 'Anwesend'),
(18433, 4991, 5, 'Vorherig'),
(18434, 4993, 5, 'Vorheriger Monat (gedrückt halten für Menü)'),
(18435, 4994, 5, 'Vorheriges Jahr (gedrückt halten für Menü)'),
(18436, 4995, 5, 'Vorsorge Check'),
(18437, 4998, 5, 'Ereignis Vorschau'),
(18438, 5000, 5, 'Vorschau von'),
(18439, 5001, 5, 'Vorherige'),
(18440, 5002, 5, 'Vorherige Konsultationen'),
(18441, 5003, 5, 'Vorheriger Tag'),
(18442, 5004, 5, 'Vorherige Historie/Screening'),
(18443, 5005, 5, 'Vorheriger Monat'),
(18444, 5006, 5, 'Vorherige Woche'),
(18445, 5007, 5, 'Preis'),
(18446, 5009, 5, 'Preis Niveau'),
(18447, 5010, 5, 'Preis Niveau:'),
(18448, 5011, 5, 'Preise'),
(18449, 5012, 5, 'Erste'),
(18450, 5022, 5, 'Erstversicherung'),
(18451, 5023, 5, 'Erstversicherung'),
(18452, 5024, 5, 'Erstversicherung Daten'),
(18453, 5025, 5, 'Erstversicherung Anbieter'),
(18454, 5026, 5, 'Erster Anbieter'),
(18455, 5027, 5, 'Drucken'),
(18456, 5028, 5, 'Drucken (HTML)'),
(18457, 5029, 5, 'Drucken (PDF)'),
(18458, 5032, 5, 'Drucke leeres Überweisungsformular'),
(18459, 5033, 5, 'Druckbefehl'),
(18460, 5039, 5, 'Druck Format'),
(18461, 5042, 5, 'Druck nachricht'),
(18462, 5043, 5, 'Drucke mehrere'),
(18463, 5046, 5, 'Drucke Notizen'),
(18464, 5047, 5, 'Drucke Seite 1'),
(18465, 5048, 5, 'Drucke Seite 1'),
(18466, 5052, 5, 'Drucke Aufzeichnung'),
(18467, 5053, 5, 'Drucke ausgewählte Aussagen'),
(18468, 5056, 5, 'Drucke diese Visite'),
(18469, 5057, 5, 'Drucke diese notiz'),
(18470, 5058, 5, 'Drucke diese Notiz'),
(18471, 5060, 5, 'Drucke nach Fax'),
(18472, 5061, 5, 'Drucke Ansicht'),
(18473, 5062, 5, 'druckbar'),
(18474, 5063, 5, 'Druckbare Version'),
(18475, 5064, 5, 'Gedruckt'),
(18476, 5066, 5, 'Drucke Ergebnisse:'),
(18477, 5067, 5, 'Druck ausgelassen; Test-Ausgabe in'),
(18478, 5068, 5, 'Druck ausgelassen; Test-Ausgabe in '),
(18479, 5072, 5, 'Priorität'),
(18480, 5073, 5, 'Priorität '),
(18481, 5074, 5, 'Privat'),
(18482, 5075, 5, 'Problem'),
(18483, 5076, 5, 'Problem DX'),
(18484, 5077, 5, 'Problem Liste'),
(18485, 5079, 5, 'Probleme/Punkte'),
(18486, 5114, 5, 'Leistungen'),
(18487, 5115, 5, 'Verarbeitung'),
(18488, 5117, 5, 'Verarbeite ERA-Datei'),
(18489, 5120, 5, 'Verarbeitung benötigt etwas Zeit'),
(18490, 5121, 5, 'Verarbeitet'),
(18491, 5122, 5, 'Verarbeitet durch'),
(18492, 5123, 5, 'Verarbeitet Datum'),
(18493, 5125, 5, 'Verarbeite'),
(18494, 5129, 5, 'Prodikt'),
(18495, 5136, 5, 'Prostata-Krebs'),
(18496, 5137, 5, 'Screening auf Prostata-Krebs'),
(18497, 5138, 5, 'Prostata-Untersuchung'),
(18498, 5139, 5, 'Prostata-Probleme'),
(18499, 5142, 5, 'Gib den absoluten Pfad an'),
(18500, 5143, 5, 'Gib den absoluten Pfad der Datei an'),
(18501, 5152, 5, 'Behandler'),
(18502, 5154, 5, 'Behandler ID'),
(18503, 5155, 5, 'Behandler ID @ spezifizierten Standort'),
(18504, 5159, 5, 'Behandler Nummer'),
(18505, 5162, 5, 'Behandler:'),
(18506, 5163, 5, 'Behandler'),
(18507, 5164, 5, 'Behandler NPI'),
(18508, 5165, 5, 'Behandler sieht gesamten Kalender'),
(18509, 5208, 5, 'Kaufen'),
(18510, 5209, 5, 'Kaufen/Return'),
(18511, 5210, 5, 'Käufe'),
(18512, 5222, 5, 'Menge'),
(18513, 5223, 5, 'MENGE'),
(18514, 5224, 5, 'Qualität'),
(18515, 5226, 5, 'Quantität'),
(18516, 5231, 5, 'Fragezeichen'),
(18517, 5236, 5, 'Warteschlange'),
(18518, 5248, 5, 'Radio'),
(18519, 5249, 5, 'Auswahlknöpfe'),
(18520, 5251, 5, 'Bereich'),
(18521, 5252, 5, 'Hautausschläge'),
(18522, 5253, 5, 'Tarif'),
(18523, 5254, 5, 'Verhältnis'),
(18524, 5255, 5, 'Roh Bericht'),
(18525, 5263, 5, 'Reaktion'),
(18526, 5264, 5, 'Reaktionen'),
(18527, 5265, 5, 'Lesen'),
(18528, 5268, 5, 'Echter Name'),
(18529, 5269, 5, 'wirklich löschen'),
(18530, 5270, 5, 'Begründung'),
(18531, 5271, 5, 'Grund Verstorben'),
(18532, 5272, 5, 'Grund für Tod'),
(18533, 5274, 5, 'Grund für die Überweisung'),
(18534, 5275, 5, 'Grund für die Konsultation'),
(18535, 5277, 5, 'Quittung'),
(18536, 5278, 5, 'Zahlungsbestätigung'),
(18537, 5279, 5, 'Beleg generiert'),
(18538, 5281, 5, 'Beleg Übersicht'),
(18539, 5282, 5, 'Erhalten'),
(18540, 5283, 5, 'Entgegengenommen durch'),
(18541, 5284, 5, 'Erhaltene Faxe'),
(18542, 5285, 5, 'Erhalten, nicht kontrolliert'),
(18543, 5287, 5, 'Empfänger'),
(18544, 5288, 5, 'Empfänger ID'),
(18545, 5289, 5, 'Empfänger ID (ISA08)'),
(18546, 5293, 5, 'Empfänger'),
(18547, 5294, 5, 'Empfänger Liste ist leer'),
(18548, 5295, 5, 'Empfänger Name'),
(18549, 5298, 5, 'Empfehlung'),
(18550, 5300, 5, 'Empfehlungen'),
(18551, 5301, 5, 'Empfehlungen und Behandlung'),
(18552, 5302, 5, 'Empfehlungen von Spezialisten'),
(18553, 5303, 5, 'Aufzeichnung'),
(18554, 5304, 5, 'Aufzeichnung bereits vorhanden'),
(18555, 5313, 5, 'Aufzeichnungen der Fitnes'),
(18556, 5317, 5, 'Aufzeichnungen'),
(18557, 5318, 5, 'Aufzeichnungen gefunden'),
(18558, 5319, 5, 'Aufzeichnungen gefunden'),
(18559, 5322, 5, 'Rektal'),
(18560, 5323, 5, 'rektale Untersuchung'),
(18561, 5324, 5, 'rektal'),
(18562, 5325, 5, 'Weiterleitung'),
(18563, 5326, 5, 'Rötung'),
(18564, 5337, 5, 'Überweisung'),
(18565, 5338, 5, 'Überwiesen durch'),
(18566, 5339, 5, 'Überweisungskarte'),
(18567, 5340, 5, 'Überweisungsdatum'),
(18568, 5341, 5, 'Überweisungsformular'),
(18569, 5342, 5, 'ÜBERWEISUNGSFORMULAR'),
(18570, 5343, 5, 'Überweisungs ID'),
(18571, 5347, 5, 'Überweisung zu'),
(18572, 5348, 5, 'Überweisungen'),
(18573, 5349, 5, 'Überweisungs Berichte'),
(18574, 5350, 5, 'Empfohlen durch'),
(18575, 5351, 5, 'Empfohlen Durch'),
(18576, 5352, 5, 'Empfohlen an'),
(18577, 5353, 5, 'Verweiser'),
(18578, 5355, 5, 'Verweiser Diagnose'),
(18579, 5356, 5, 'Verweiser DIagnose'),
(18580, 5358, 5, 'Überwiesen von'),
(18581, 5359, 5, 'Nachfüllungen'),
(18582, 5360, 5, 'Nachfüllungen'),
(18583, 5361, 5, 'Nachfüllungen'),
(18584, 5362, 5, 'Normale Reflexen'),
(18585, 5363, 5, 'Aktualisieren'),
(18586, 5365, 5, 'Erinnerungen aktualisieren'),
(18587, 5381, 5, 'beziehen sich auf'),
(18588, 5409, 5, 'Erinnerung'),
(18589, 5410, 5, 'Erinnerungsintervall'),
(18590, 5411, 5, 'Erinnerung nicht definiert'),
(18591, 5412, 5, 'Erinnerung gesetzt auf'),
(18592, 5413, 5, 'Erinnerungen'),
(18593, 5416, 5, 'Entfernen'),
(18594, 5419, 5, 'Entferne Gruppe'),
(18595, 5420, 5, 'Entferne Gruppen Formular'),
(18596, 5440, 5, 'Wiederholungen'),
(18597, 5444, 5, 'Antwort Datum'),
(18598, 5445, 5, 'Antwort von'),
(18599, 5446, 5, 'Bericht'),
(18600, 5447, 5, 'Klinischer Bericht'),
(18601, 5449, 5, 'Bericht von'),
(18602, 5457, 5, 'Bericht Status'),
(18603, 5458, 5, 'Vollständiger Bericht'),
(18604, 5459, 5, 'Report/Formular'),
(18605, 5461, 5, 'Berichtet'),
(18606, 5462, 5, 'Bericht Datum'),
(18607, 5463, 5, 'Berichte'),
(18608, 5477, 5, 'Erforderlich'),
(18609, 5483, 5, 'Erforderliche Felder'),
(18610, 5484, 5, 'Anforderungen'),
(18611, 5485, 5, 'Reserviert'),
(18612, 5486, 5, 'Reserviert'),
(18613, 5491, 5, 'Zurücksetzen'),
(18614, 5492, 5, 'Zurücksetzen der "Offsite Portal" Zugangsdaten'),
(18615, 5493, 5, 'Zurücksetzen der "Onsite Portal" Zugangsdaten'),
(18616, 5496, 5, 'Gelöst'),
(18617, 5504, 5, 'Ergebnis'),
(18618, 5506, 5, 'Ergebnis Status'),
(18619, 5510, 5, 'Ergebnisse und'),
(18620, 5511, 5, 'Ergebnis gefünden für'),
(18621, 5512, 5, 'Ergebnis Gruppe'),
(18622, 5515, 5, 'Ergebnisse pro Seite'),
(18623, 5516, 5, 'Ergebnisse/Details'),
(18624, 5527, 5, 'Rückgabewert'),
(18625, 5538, 5, 'Revision'),
(18626, 5541, 5, 'Rechts'),
(18627, 5542, 5, 'Rechtes Ohr'),
(18628, 5543, 5, 'rechtes Ohr'),
(18629, 5545, 5, 'Rechts:'),
(18630, 5549, 5, 'Risikofaktor'),
(18631, 5550, 5, 'Risikolevel'),
(18632, 5564, 5, 'Reihen'),
(18633, 5568, 5, 'Regel'),
(18634, 5569, 5, 'Regeln Hinzufügen'),
(18635, 5570, 5, 'Regeln Detail'),
(18636, 5572, 5, 'Regeln Ändern'),
(18637, 5575, 5, 'Regeln setzen'),
(18638, 5578, 5, 'Regeln'),
(18639, 5580, 5, 'Regeln Konfiguration'),
(18640, 5601, 5, 'SV-Nummer'),
(18641, 5605, 5, 'Verkauf'),
(18642, 5606, 5, 'Verkäufe'),
(18643, 5607, 5, 'Umsatz nach Artikel'),
(18644, 5609, 5, 'Speichel'),
(18645, 5610, 5, 'selben Tag'),
(18646, 5612, 5, 'Probe'),
(18647, 5617, 5, 'Sa'),
(18648, 5618, 5, 'Sa &amp; So'),
(18649, 5619, 5, 'Samstag'),
(18650, 5620, 5, 'Speichern'),
(18651, 5621, 5, 'SPEICHERN'),
(18652, 5622, 5, 'Speichern und Schließen'),
(18653, 5624, 5, 'Speichern und Dispense'),
(18654, 5626, 5, 'Speichern als Neu'),
(18655, 5627, 5, 'Speichern als neue Notiz'),
(18656, 5628, 5, 'Speichern Gutachten Einstellungen'),
(18657, 5629, 5, 'Speichere Änderungen'),
(18658, 5630, 5, 'Speichere Formular'),
(18659, 5631, 5, 'Speichere Impfungen'),
(18660, 5632, 5, 'Speichere neues Feld'),
(18661, 5633, 5, 'Speichere neue Gruppe'),
(18662, 5634, 5, 'Speichere neue Liste'),
(18663, 5635, 5, 'Speichere neue Vorlage'),
(18664, 5637, 5, 'Speichere Patienten Daten'),
(18665, 5639, 5, 'Speichere Transaktion'),
(18666, 5641, 5, 'Gescannt'),
(18667, 5643, 5, 'Scanner Verzeichnis'),
(18668, 5644, 5, 'Scanner in'),
(18669, 5645, 5, 'Planen'),
(18670, 5646, 5, 'Plane Standort:'),
(18671, 5647, 5, 'Schul Notiz'),
(18672, 5648, 5, 'Skoliose'),
(18673, 5659, 5, 'Suchen'),
(18674, 5661, 5, 'suchen'),
(18675, 5662, 5, 'nochmals suchen'),
(18676, 5663, 5, 'Suche alle Spalten'),
(18677, 5664, 5, 'Suchen von:'),
(18678, 5665, 5, 'Suchen nach'),
(18679, 5666, 5, 'Suchen nach:'),
(18680, 5668, 5, 'Suchen in'),
(18681, 5669, 5, 'Suche / Hinzufügen Patient'),
(18682, 5670, 5, 'Suche Zahlung'),
(18683, 5671, 5, 'Suchresultate'),
(18684, 5672, 5, 'Suchresultate:'),
(18685, 5673, 5, 'Suche Ausgewählt'),
(18686, 5674, 5, 'Such Zeichenfolge stimmt nicht mit der Datenbank Liste überein'),
(18687, 5675, 5, 'Suchbegriff muss mindestens drei Zeichen haben'),
(18688, 5676, 5, 'Suche Text'),
(18689, 5677, 5, 'Such das Ereignis'),
(18690, 5678, 5, 'Suchen/Hinzufügen'),
(18691, 5679, 5, 'Suche/Hinzufügen Versicherer'),
(18692, 5680, 5, 'Suche nach Tremine'),
(18693, 5681, 5, 'Suchen ...'),
(18694, 5682, 5, 'Sicherheitsgurt Verwendung'),
(18695, 5683, 5, 'Sicherheitsgurt Verwendung'),
(18696, 5684, 5, 'Zweite'),
(18697, 5687, 5, 'Zweite'),
(18698, 5688, 5, 'Zweite Versicherung'),
(18699, 5689, 5, 'Zweite Versicherung Daten'),
(18700, 5690, 5, 'Zweite Versicherung Anbieter'),
(18701, 5698, 5, 'Sicherheit'),
(18702, 5699, 5, 'Zeige alle'),
(18703, 5700, 5, 'Zeige Autorisierungen'),
(18704, 5704, 5, 'gesehen, seit'),
(18705, 5707, 5, 'Anfälle'),
(18706, 5708, 5, 'Sel'),
(18707, 5709, 5, 'Wählen'),
(18708, 5710, 5, 'wählen'),
(18709, 5712, 5, 'Wählen Sie einen Context'),
(18710, 5714, 5, 'Wählen Sie eine Zeitspanne'),
(18711, 5715, 5, 'Anwender wählen'),
(18712, 5716, 5, 'alle selektieren'),
(18713, 5720, 5, 'Kategorie wählen'),
(18714, 5722, 5, 'Das entsprechenden Kontrollkästchen wählen um zu löschen'),
(18715, 5723, 5, 'Kriterium zum Löschen Wählen'),
(18716, 5727, 5, 'Datum Wählen'),
(18717, 5728, 5, 'Gewünschten Kader wählen'),
(18718, 5729, 5, 'Diagnose wählen'),
(18719, 5731, 5, 'Medikament wählen'),
(18720, 5732, 5, 'Medikamente wählen'),
(18721, 5736, 5, 'feld wählen'),
(18722, 5737, 5, 'Feld wählen'),
(18723, 5738, 5, 'Wählen zum Drücken'),
(18724, 5739, 5, 'Wähle Impfung'),
(18725, 5742, 5, 'Problem'),
(18726, 5744, 5, 'Wähle Sprache'),
(18727, 5745, 5, 'Auswählen'),
(18728, 5759, 5, 'Wähle Anwender'),
(18729, 5760, 5, 'Wähle Anwender von Dropdown-Liste'),
(18730, 5765, 5, 'Selektiert'),
(18731, 5768, 5, 'Selbst'),
(18732, 5769, 5, 'Selbstzahler'),
(18733, 5771, 5, 'Senden'),
(18734, 5772, 5, 'Sende eine Datum-Erinnerung'),
(18735, 5773, 5, 'Sende eine Erinnerung'),
(18736, 5774, 5, 'Wird gesendet'),
(18737, 5775, 5, 'Nachricht senden'),
(18738, 5779, 5, 'Datei senden'),
(18739, 5781, 5, 'Senden an'),
(18740, 5784, 5, 'Senden an alle'),
(18741, 5788, 5, 'Absender'),
(18742, 5789, 5, 'Absender ID'),
(18743, 5790, 5, 'Absender ID (ISA06)'),
(18744, 5791, 5, 'Absender ID (ISA05)'),
(18745, 5794, 5, 'Befindlichkeiten'),
(18746, 5795, 5, 'Sensibilität:'),
(18747, 5796, 5, 'Sensorische Untersuchung Normal'),
(18748, 5799, 5, 'Gesendet durch (leer für alle)'),
(18749, 5801, 5, 'Absendedatum'),
(18750, 5802, 5, 'Gesendete Elemente'),
(18751, 5803, 5, 'Gesendete medizinische Aufzeichnungen'),
(18752, 5804, 5, 'Erfolgreich gesendet'),
(18753, 5807, 5, 'Drucken'),
(18754, 5808, 5, 'Gesendet An (leer für alle)'),
(18755, 5812, 5, 'Sep.'),
(18756, 5813, 5, 'Getrennt'),
(18757, 5814, 5, 'September'),
(18758, 5815, 5, 'Seq'),
(18759, 5816, 5, 'Sequenz'),
(18760, 5821, 5, 'Service'),
(18761, 5822, 5, 'Service Kategorie'),
(18762, 5823, 5, 'Service Code'),
(18763, 5825, 5, 'Service Codes'),
(18764, 5826, 5, 'Service Datum'),
(18765, 5827, 5, 'Service Datum:'),
(18766, 5829, 5, 'Service Ort'),
(18767, 5849, 5, 'Einstellungen'),
(18768, 5855, 5, 'Geschl.'),
(18769, 5856, 5, 'Sexuell übertragbare Krankheiten'),
(18770, 5859, 5, 'Teilen'),
(18771, 5864, 5, 'Kurzatmigkeit'),
(18772, 5865, 5, 'Kurzatmigkeit'),
(18773, 5866, 5, 'Kurzatmigkeit'),
(18774, 5872, 5, 'sollte 10 Ziffern enthalten'),
(18775, 5873, 5, 'sollte nur 10 Ziffern enthalten'),
(18776, 5874, 5, 'Schulter'),
(18777, 5875, 5, 'Schulter + Schlüsselbein'),
(18778, 5876, 5, 'Schulter Probleme'),
(18779, 5877, 5, 'Zeige'),
(18780, 5878, 5, 'Zeige Aktive'),
(18781, 5880, 5, 'Zeige alle Transaktionen'),
(18782, 5883, 5, 'Zeige alle Transaktionen'),
(18783, 5884, 5, 'Belegt'),
(18784, 5885, 5, 'Zeige nur Berechtigte'),
(18785, 5886, 5, 'Zeige verfügbare Zeiten'),
(18786, 5887, 5, 'Zeige sowohl US als auch metrische Einheiten (Standard ist metrisch)'),
(18787, 5888, 5, 'Zeige sowohl US als auch metrische Einheiten (Standard ist US)'),
(18788, 5889, 5, 'Details zeigen'),
(18789, 5891, 5, 'Grafik zeigen'),
(18790, 5894, 5, 'Zeige inaktive'),
(18791, 5896, 5, 'Zeige Menü'),
(18792, 5897, 5, 'Zeige nur metrische Einheiten'),
(18793, 5898, 5, 'Notizen zeigen'),
(18794, 5901, 5, 'Patienten Notizen zeigen'),
(18795, 5905, 5, 'Zeige Erinnerungen'),
(18796, 5906, 5, 'Bericht zeigen'),
(18797, 5913, 5, 'Zeige nur unbezahlte'),
(18798, 5915, 5, 'Zeige'),
(18799, 5920, 5, 'Geschwister'),
(18800, 5921, 5, 'Sichelzellenanämie'),
(18801, 5927, 5, 'Unterschrift'),
(18802, 5929, 5, 'Unterschrift:'),
(18803, 5937, 5, 'Seit'),
(18804, 5946, 5, 'Probleme mit den Nebenhöhlen'),
(18805, 5947, 5, 'Stirnhöhlenoperation'),
(18806, 5949, 5, 'Nebenhöhlenentzündung'),
(18807, 5951, 5, 'Seiten ID'),
(18808, 5956, 5, 'Größe'),
(18809, 5957, 5, 'Nummer muss zwischen 1 und 999 sein'),
(18810, 5959, 5, 'Haut'),
(18811, 5960, 5, 'Hautkrebs'),
(18812, 5961, 5, 'Hautkrankheit'),
(18813, 5962, 5, 'Haut Andere'),
(18814, 5967, 5, 'Schlaf-Muster'),
(18815, 5968, 5, 'Schlaf-Muster'),
(18816, 5969, 5, 'schlafend'),
(18817, 5976, 5, 'Raucher-Status'),
(18818, 5977, 5, 'SMS-Auth.'),
(18819, 5978, 5, 'SMS-Gateway'),
(18820, 5979, 5, 'SMS-Gateway API-Schlüssel'),
(18821, 5980, 5, 'SMS-Gateway API-Schlüssel'),
(18822, 5981, 5, 'SMS-Gateway Passwort'),
(18823, 5982, 5, 'SMS-Gateway Nutzername'),
(18824, 5983, 5, 'SMS-Benachrichtigung'),
(18825, 5984, 5, 'SMS-Benachrichtigungsstunden'),
(18826, 5985, 5, 'Sende SMS vor'),
(18827, 5986, 5, 'SMS gesendet'),
(18828, 6023, 5, 'Etwas ist schiefgelaufen. Bitte versuchen Sie es erneut.'),
(18829, 6031, 5, 'Sortieren nach Checksumme'),
(18830, 6032, 5, 'Sortieren nach Kommentare'),
(18831, 6033, 5, 'Sortieren nach Crt Anwender'),
(18832, 6034, 5, 'Sortieren nach Datum'),
(18833, 6035, 5, 'Sortieren nach Datum/Zeit'),
(18834, 6036, 5, 'Sortieren nach Ereignis'),
(18835, 6037, 5, 'Sortieren nach'),
(18836, 6040, 5, 'Sortieren nach PatientenID'),
(18837, 6041, 5, 'Sortieren nach Erfolgreich'),
(18838, 6043, 5, 'Sortieren nach Anwender'),
(18839, 6044, 5, 'Sortieren nach Impfstoff'),
(18840, 6045, 5, 'Absteigend sortieren'),
(18841, 6046, 5, 'Ergebnisse sortieren nach'),
(18842, 6047, 5, 'Aufsteigend sortieren'),
(18843, 6048, 5, 'Quelle'),
(18844, 6049, 5, 'Source File'),
(18845, 6050, 5, 'Source File Pfad'),
(18846, 6114, 5, 'Stabilität'),
(18847, 6116, 5, 'Standard'),
(18848, 6117, 5, 'Standard Code'),
(18849, 6124, 5, 'Start'),
(18850, 6125, 5, 'Start (jjjj-mm-tt) '),
(18851, 6128, 5, 'Startdatum'),
(18852, 6130, 5, 'Startdatum muss kleiner als Enddatum sein'),
(18853, 6131, 5, 'Startdatum:'),
(18854, 6132, 5, 'Startdatum:'),
(18855, 6133, 5, 'Sartzeit'),
(18856, 6134, 5, 'Startdatum:'),
(18857, 6136, 5, 'Bundesland/Region'),
(18858, 6143, 5, 'Bundesland/Region'),
(18859, 6150, 5, 'Statischer Text'),
(18860, 6151, 5, 'Statistiken'),
(18861, 6153, 5, 'Status'),
(18862, 6156, 5, 'Status Quo'),
(18863, 6177, 5, 'Straße'),
(18864, 6178, 5, 'Straßenname'),
(18865, 6179, 5, 'Straße und Nummer'),
(18866, 6180, 5, 'Kraft'),
(18867, 6189, 5, 'Unter-Kategorie'),
(18868, 6191, 5, 'Unterkategorie'),
(18869, 6192, 5, 'untergategorie'),
(18870, 6198, 5, 'Übernehmen'),
(18871, 6199, 5, 'übernehmen'),
(18872, 6200, 5, 'übernehme alle Inhalte'),
(18873, 6202, 5, 'übernehme Ereignis'),
(18874, 6203, 5, 'übernehme Formular'),
(18875, 6204, 5, 'Übernehme ausgewählte Inhalte'),
(18876, 6205, 5, 'übernommen'),
(18877, 6206, 5, 'übernommen durch'),
(18878, 6247, 5, 'Kategorie erfolgreich hinzugefügt'),
(18879, 6256, 5, 'Erfolgreich gespeichert'),
(18880, 6259, 5, 'Erfolgreich'),
(18881, 6260, 5, 'Selbstmord'),
(18882, 6261, 5, 'Zusammenfassung'),
(18883, 6265, 5, 'So'),
(18884, 6267, 5, 'Sonntag'),
(18885, 6351, 5, 'Ziel/Ereignis Gruppen'),
(18886, 6366, 5, 'Temp'),
(18887, 6379, 5, 'Dritte'),
(18888, 6380, 5, 'Dritte Versicherung'),
(18889, 6381, 5, 'Dritte Versicherung Daten'),
(18890, 6382, 5, 'Dritte Versicherung Anbieter'),
(18891, 6387, 5, 'Text Feld'),
(18892, 6393, 5, 'Text Datum'),
(18893, 6394, 5, 'text datum'),
(18894, 6395, 5, 'Textbereich'),
(18895, 6396, 5, 'textbereich'),
(18896, 6397, 5, 'Textbox'),
(18897, 6398, 5, 'textbox'),
(18898, 6399, 5, 'Textbox Liste'),
(18899, 6400, 5, 'Textbox liste'),
(18900, 6402, 5, 'Vielen Dank'),
(18901, 6441, 5, 'Die folgenden Fehler sind aufgetreten'),
(18902, 6444, 5, 'Die folgenden Felder müssen ausgefüllt werden'),
(18903, 6446, 5, 'Die folgenden Felder müssen ausgefüllt werden, um die Anfrage zu senden.'),
(18904, 6542, 5, 'Dritte'),
(18905, 6544, 5, 'Diese Aktion KANN NICHT RÜCKGÄNGIG gemacht werden.'),
(18906, 6545, 5, 'Diese Aktion kann nicht rückgängig gemacht werden.'),
(18907, 6547, 5, 'Diese Aktion wird geloggt.'),
(18908, 6549, 5, 'Dieser Termin-Zeitbereich ist bereits in Verwendung. Trotzdem verwenden?'),
(18909, 6550, 5, 'Dieser Termin-Zeitbereich ist bereits in Verwendung, bitte einen anderen verwenden?'),
(18910, 6551, 5, 'Dieses Kalenderjahr'),
(18911, 6552, 5, 'Dieser Anspruch wurde zurückgezogen.'),
(18912, 6553, 5, 'Dieser Anspruch wurde geschlossen.'),
(18913, 6561, 5, 'Dieser Fall'),
(18914, 6562, 5, 'Dieser Fall wurde bezahlt. Für Änderungen muss dieser neu geöffnent werden.'),
(18915, 6564, 5, 'Diese Funktion ist noch nicht verfügbar'),
(18916, 6565, 5, 'Diese Funktion ist sehr experimentell und nicht vollständig getestet. Benutzung auf eigene Gefahr!'),
(18917, 6566, 5, 'Diese Rechnungsnummer wurde geändert in '),
(18918, 6572, 5, 'dieser Standort'),
(18919, 6575, 5, 'Dieses Modul befindet sich im Testmodus. Die Datenbank wird nicht verändert.'),
(18920, 6582, 5, 'Dieser Patient hat keine Aktivität.'),
(18921, 6583, 5, 'Diese Patienten ID ist bereits in Verwendung!'),
(18922, 6586, 5, 'Dieser Bericht funktioniert derzeit nur für ICD9-Codierungen'),
(18923, 6591, 5, 'In diesem Schritt wird eine Datei erzeugt, die für den späteren Gebrauch gespeichert wird. Diese Datei kann nicht erneut erstellt werden. Willst Du fortfahren?'),
(18924, 6592, 5, 'Diese Anwender gehört keiner Gruppe an.'),
(18925, 6597, 5, 'Dies war das alte Vitaldaten-Formular, das jetzt nicht mehr gültig ist.'),
(18926, 6598, 5, 'Diese Woche bis Datum'),
(18927, 6602, 5, 'Dies erlaubt die Auswahl der Debugging (Dummy-) Sprache'),
(18928, 6619, 5, 'Es wird die benutzerspezifische Impfungsliste verwendet im Gegensatz zur Standard CVX-Impfungsliste'),
(18929, 6622, 5, 'Brustwirbelsäule'),
(18930, 6625, 5, 'Kehle'),
(18931, 6626, 5, 'Kehlkopfkrebs'),
(18932, 6627, 5, 'Kehlkopfkrebs Eingriff'),
(18933, 6628, 5, 'Thrombose / Schlaganfall'),
(18934, 6629, 5, 'Do'),
(18935, 6630, 5, 'Donnerstag'),
(18936, 6631, 5, 'Donnerstag'),
(18937, 6632, 5, 'Schilddrüse Normal'),
(18938, 6633, 5, 'Schilddrüsenprobleme'),
(18939, 6634, 5, 'TIA'),
(18940, 6636, 5, 'TID'),
(18941, 6638, 5, 'Zeit'),
(18942, 6639, 5, 'Zeit Anzeige Format'),
(18943, 6640, 5, 'Zeitspanne zum Hinzufügen (1-60 Minuten)'),
(18944, 6641, 5, 'Zeit Auswahl'),
(18945, 6642, 5, 'Zeitfenster vorhanden, Event speichern'),
(18946, 6647, 5, 'Geplantes Ereignis'),
(18947, 6649, 5, 'Zeitstempel und Text'),
(18948, 6650, 5, 'TINnitus'),
(18949, 6651, 5, 'Tinnitus'),
(18950, 6652, 5, 'Titel'),
(18951, 6653, 5, 'Titel V'),
(18952, 6654, 5, 'TitleSpalten muss eine Zahl zwischen 1 und 999 sein'),
(18953, 6655, 5, 'Titeln'),
(18954, 6658, 5, 'bis'),
(18955, 6659, 5, 'BIS'),
(18956, 6660, 5, 'bis'),
(18957, 6661, 5, 'absoluter Dateipfad'),
(18958, 6662, 5, 'Um Bemerkungen hinzuzufügen, hier klicken '),
(18959, 6664, 5, 'Um betroffene Gebiet'),
(18960, 6665, 5, 'um betroffene gebiet'),
(18961, 6667, 5, 'Zur Rechnungsansicht'),
(18962, 6668, 5, 'in Kategorie'),
(18963, 6669, 5, 'Zur Klinischen Ansicht'),
(18964, 6679, 5, 'Zu Besuch'),
(18965, 6680, 5, 'Filtern nach Geschlecht'),
(18966, 6681, 5, 'Zu History'),
(18967, 6682, 5, 'Zu Problem'),
(18968, 6685, 5, 'zur nochmaligen Anmeldung'),
(18969, 6688, 5, 'Zur Einrichtung von https mit Client-Zertifikat-Authentifikation folgendes tun'),
(18970, 6689, 5, 'Auf die Haut'),
(18971, 6690, 5, 'auf die Haut'),
(18972, 6691, 5, 'zu dieser Visite?'),
(18973, 6693, 5, 'An:'),
(18974, 6694, 5, 'An: '),
(18975, 6695, 5, 'TO_CITY'),
(18976, 6696, 5, 'TO_FAX'),
(18977, 6697, 5, 'TO_FNAME'),
(18978, 6698, 5, 'TO_LNAME'),
(18979, 6699, 5, 'TO_MNAME'),
(18980, 6700, 5, 'TO_ORGANIZATION'),
(18981, 6703, 5, 'TO_POSTAL'),
(18982, 6704, 5, 'TO_STATE'),
(18983, 6705, 5, 'TO_STREET'),
(18984, 6706, 5, 'TO_TITLE'),
(18985, 6707, 5, 'TO_VALEDICTORY'),
(18986, 6708, 5, 'Tabak'),
(18987, 6709, 5, 'Tabakentwöhnung Intervention'),
(18988, 6710, 5, 'Tabakentwöhnung Intervention(CQM)'),
(18989, 6712, 5, 'Tabakkonsum'),
(18990, 6713, 5, 'Tabakkonsum Beurteilung'),
(18991, 6714, 5, 'Tabakkonsum Beurteilung (CQM)'),
(18992, 6715, 5, 'Heute'),
(18993, 6716, 5, 'HEUTE'),
(18994, 6717, 5, 'heute'),
(18995, 6720, 5, 'Heutiges Datum'),
(18996, 6721, 5, 'Heutige Ereignisse'),
(18997, 6726, 5, 'Mandeloperation'),
(18998, 6728, 5, 'Oben'),
(18999, 6730, 5, 'Thema'),
(19000, 6731, 5, 'Total'),
(19001, 6732, 5, 'total'),
(19002, 6733, 5, 'Anzahl aktiver Aktionen'),
(19003, 6734, 5, 'Anzahl aktiver Erinnerungen nach Update'),
(19004, 6735, 5, 'Anzahl aktiver Erinnerungen vor Update'),
(19005, 6737, 5, 'Gesamtbetrag fällig'),
(19006, 6738, 5, 'Gesamt bezahlt'),
(19007, 6739, 5, 'Offener Betrag Total'),
(19008, 6742, 5, 'Anzahl Patienten'),
(19009, 6743, 5, 'Gesamtkosten'),
(19010, 6745, 5, 'Einträge insgesamt'),
(19011, 6748, 5, 'Summe für'),
(19012, 6749, 5, 'Summe für '),
(19013, 6750, 5, 'Summe für Kategorie'),
(19014, 6751, 5, 'Summe für inaktive Erinnerungen'),
(19015, 6752, 5, 'Summe für Erinnerungen'),
(19016, 6755, 5, 'Gesamtzahl der Impfungen'),
(19017, 6756, 5, 'Gesamtzahl der Probleme'),
(19018, 6758, 5, 'Gesamtzahl der Patienten'),
(19019, 6761, 5, 'Summe Patienten'),
(19020, 6764, 5, 'Anzahl gefundener Einträge'),
(19021, 6766, 5, 'Anzahl erfolgreich gesendeter Erinnerungen per E-Mail'),
(19022, 6767, 5, 'Anzahl erfolgreich gesendeter Erinnerungen per Telefon'),
(19023, 6770, 5, 'Anzahl unveränderter Erinnerungen'),
(19024, 6771, 5, 'Anzahl ungesendeter Erinnerungen vor Sendeprozess'),
(19025, 6772, 5, 'Anzahl ungesendeter Erinnerungen nach Update'),
(19026, 6773, 5, 'Anzahl ungesendeter Erinnerungen vor Sendeprozess'),
(19027, 6774, 5, 'Anzahl ungesendeter Erinnerungen vor Update'),
(19028, 6775, 5, 'Anzahl aktualisierter Erinnerungen'),
(19029, 6776, 5, 'Summen'),
(19030, 6777, 5, 'Summen für'),
(19031, 6778, 5, 'Summen für '),
(19032, 6780, 5, 'bis{{Bereich}}'),
(19033, 6785, 5, 'Trainingsart'),
(19034, 6787, 5, 'Transaktion'),
(19035, 6788, 5, 'Transaktion'),
(19036, 6789, 5, 'Transaktion fehlgeschlagen, Menge in Ziellos nicht ausreichend'),
(19037, 6790, 5, 'Transaktion fehlgeschlagen, Menge ist kleiner Null.'),
(19038, 6791, 5, 'Art der Transaktion'),
(19039, 6792, 5, 'Transaktionen'),
(19040, 6793, 5, 'Transaktionen'),
(19041, 6794, 5, 'Transaktionen (schreiben optional)'),
(19042, 6795, 5, 'Transaktionen / Überweisungen'),
(19043, 6797, 5, 'Transfer'),
(19044, 6804, 5, 'Transfers'),
(19045, 6807, 5, 'Übersetze ACL-Listen'),
(19046, 6808, 5, 'Übersetze Terminkategorien'),
(19047, 6809, 5, 'Übersetze Dokumentkategorien'),
(19048, 6810, 5, 'Übersetze Layouts'),
(19049, 6811, 5, 'Übersetze Listen'),
(19050, 6812, 5, 'Übersetze Titel der Patientennotizen'),
(19051, 6813, 5, 'Dies übersetzen'),
(19052, 6814, 5, 'Übersetzung'),
(19053, 6815, 5, 'Übersetzungen'),
(19054, 6819, 5, 'Trauma'),
(19055, 6820, 5, 'Behandlung'),
(19056, 6822, 5, 'Behandlungsziele'),
(19057, 6823, 5, 'Behandlungsplan'),
(19058, 6826, 5, 'Behandlung:'),
(19059, 6827, 5, 'Behandlung: '),
(19060, 6828, 5, 'Tendenz'),
(19061, 6832, 5, 'Rumpf und Bauch'),
(19062, 6839, 5, 'TTS'),
(19063, 6840, 5, 'Tuberkulose'),
(19064, 6841, 5, 'Di'),
(19065, 6842, 5, 'Di - Do'),
(19066, 6843, 5, 'Dienstag'),
(19067, 6844, 5, 'Tumor'),
(19068, 6845, 5, 'Türkisch'),
(19069, 6848, 5, 'zweimal täglich'),
(19070, 6850, 5, 'Trommelfell'),
(19071, 6851, 5, 'Art'),
(19072, 6852, 5, 'ID oder Namen eingeben, mind. 3 Zeichen'),
(19073, 6853, 5, 'Spalten, die für die Ergebnisanzeige der Patientensuche angezeigt werden'),
(19074, 6855, 5, 'Art der Ereignisse'),
(19075, 6856, 5, 'Art des Screen-Layouts'),
(19076, 6857, 5, 'Trage die Patient-ID hier ein (oder Scan)'),
(19077, 6858, 5, 'Nachricht hier eingeben'),
(19078, 6859, 5, 'Arten der Aufträge und Ergebnisse'),
(19079, 6865, 5, 'Ukrainisch'),
(19080, 6866, 5, 'Ulzerationen'),
(19081, 6867, 5, 'Colitis ulcerosa'),
(19082, 6868, 5, 'Geschwüre:'),
(19083, 6871, 5, 'Kann nicht erstellt werden'),
(19084, 6876, 5, 'Nicht zugeordnet'),
(19085, 6877, 5, 'Unbestimmt'),
(19086, 6878, 5, 'Unbefugt'),
(19087, 6879, 5, 'Kein Zugriff zu ePrescription erlaubt'),
(19088, 6880, 5, 'Unbefugter Zugriff.'),
(19089, 6881, 5, 'Nicht Bezahlt'),
(19090, 6882, 5, 'nur unbezahlt'),
(19091, 6884, 5, 'unter der Zunge'),
(19092, 6885, 5, 'Untergewicht'),
(19093, 6886, 5, 'Nicht Diagnostiziert'),
(19094, 6890, 5, 'Checkout rückgängig machen'),
(19095, 6892, 5, 'Einmahlige Patienten'),
(19096, 6893, 5, 'Eindeutige, leicht zu merkende ID für diesen Typ'),
(19097, 6894, 5, 'Eindeutige neue Patienten'),
(19098, 6895, 5, 'Eindeutige numerische ID für diesen Typ'),
(19099, 6896, 5, 'Einmahlig "gesehene" Patienten'),
(19100, 6897, 5, 'Einmahlig "gesehene" Patienten - Bericht'),
(19101, 6898, 5, 'Einmahlig "gesehene" Patienten'),
(19102, 6899, 5, 'Einheit'),
(19103, 6900, 5, 'Einheiten'),
(19104, 6901, 5, 'einheiten'),
(19105, 6903, 5, 'Einheiten für Konsultation Formular'),
(19106, 6904, 5, 'Einheiten müssen Nummern sein'),
(19107, 6905, 5, 'Einheit nicht definiert'),
(19108, 6906, 5, 'Einheiten/L'),
(19109, 6907, 5, 'Unbekannt'),
(19110, 6910, 5, 'Unbekannt, wenn jemals geraucht'),
(19111, 6911, 5, 'Unbekannt oder N/A'),
(19112, 6913, 5, 'Aufheben der Patienten-Verknüpfung'),
(19113, 6914, 5, 'Nicht näher bezeichnete Versicherung'),
(19114, 6915, 5, 'Nicht registriert'),
(19115, 6918, 5, 'Alle deselektieren'),
(19116, 6919, 5, 'Nicht selektiert'),
(19117, 6920, 5, 'Nicht spezifiziert'),
(19118, 6921, 5, 'Nicht strukturiert'),
(19119, 6924, 5, 'bis'),
(19120, 6926, 5, 'Unbenutzt'),
(19121, 6927, 5, 'UOR'),
(19122, 6928, 5, 'Bis zu'),
(19123, 6929, 5, 'Bevorstehende Termine'),
(19124, 6930, 5, 'Bevorstehende Ereignisse'),
(19125, 6931, 5, 'Aktualisieren'),
(19126, 6932, 5, 'aktualisieren'),
(19127, 6933, 5, 'Aktive aktualisieren'),
(19128, 6934, 5, 'Datei aktualisieren'),
(19129, 6935, 5, 'Info aktualisieren'),
(19130, 6936, 5, 'Liste aktualisieren'),
(19131, 6937, 5, 'Aktualisieren Behandler Nummer'),
(19132, 6938, 5, 'Ausgewählte Inhalte aktualisieren'),
(19133, 6939, 5, 'Aktualisiere der folgenden Variablen in der Datei'),
(19134, 6940, 5, 'Anwender Informationen aktualisieren'),
(19135, 6942, 5, 'Akualisieren der persönlichen Daten ist nicht erlaubt.'),
(19136, 6943, 5, 'Aktualisieren der globalen Standard Konfiguration'),
(19137, 6944, 5, 'Aktualisiere Versionsindikatoren'),
(19138, 6945, 5, 'UPGRADE'),
(19139, 6946, 5, 'Upgrade'),
(19140, 6947, 5, 'Datenbank aktualisieren'),
(19141, 6948, 5, 'Aktualisiert die LibreEHR-Datenbank für Verfahren, Funktionen und Tabellen, die für De-identification gebraucht werden'),
(19142, 6949, 5, 'Aktualisieren wird fortgesetzt'),
(19143, 6950, 5, 'UPIN'),
(19144, 6951, 5, 'Upload'),
(19145, 6954, 5, 'Configurationsdaten uploaden'),
(19146, 6955, 5, 'Dokument uploaden'),
(19147, 6956, 5, 'Upload fehlgeschlagen!'),
(19148, 6957, 5, 'Bild uploaden zu'),
(19149, 6958, 5, 'Hochladen Import Datei:'),
(19150, 6961, 5, 'Bericht uploaden'),
(19151, 6963, 5, 'Diese Datei uploaden:'),
(19152, 6966, 5, 'Oberarm'),
(19153, 6968, 5, 'Dringlichkeit'),
(19154, 6970, 5, 'Urin'),
(19155, 6971, 5, 'Urinverlust'),
(19156, 6972, 5, 'Urin Häufigkeit'),
(19157, 6973, 5, 'Probleme beim Harnlassen'),
(19158, 6974, 5, 'Urin Mikroalbumin'),
(19159, 6975, 5, 'Urinstrahl'),
(19160, 6976, 5, 'Urin Drang'),
(19161, 6977, 5, 'URL'),
(19162, 6979, 5, 'URL für LibreEHR support.'),
(19163, 6986, 5, 'Gebrauchsindikator (ISA15)'),
(19164, 6997, 5, 'Benutzerdefinierte Impfung Liste'),
(19165, 6999, 5, 'Verwende Datumsbereich'),
(19166, 7000, 5, 'Verwende standard'),
(19167, 7001, 5, 'Verwende Löschen-Option zum Entfernen.'),
(19168, 7002, 5, 'Verwende internationalen Datum-Stil'),
(19169, 7003, 5, 'Verwende Source-Dateiname'),
(19170, 7004, 5, 'Nutze die Felder unten für einen Kauf oder eine Überweisung'),
(19171, 7005, 5, 'Nutze dieses Feature nur für neu installierte Orte, '),
(19172, 7006, 5, 'Themen Verwenden?'),
(19173, 7007, 5, 'Benutzer'),
(19174, 7009, 5, 'Benutzer / Gruppen'),
(19175, 7010, 5, 'Benutzer Verwaltung'),
(19176, 7011, 5, 'Benutzer und Standort Verwaltung'),
(19177, 7012, 5, 'Benutzer und Gruppen Verwaltung'),
(19178, 7014, 5, 'Benutzer-Zertifikat-Authentifizierung deaktiviert'),
(19179, 7015, 5, 'Benutzerdefiniert'),
(19180, 7016, 5, 'Benutzerdefiniertes Zone 11'),
(19181, 7017, 5, 'Benutzerdefiniertes Zone 12'),
(19182, 7018, 5, 'Benutzerdefiniertes Feld'),
(19183, 7019, 5, 'Benutzerdefinierte Liste 1'),
(19184, 7020, 5, 'Benutzerdefinierte Liste 2'),
(19185, 7021, 5, 'Benutzerdefinierte Liste 3'),
(19186, 7022, 5, 'Benutzerdefinierte Liste 4'),
(19187, 7023, 5, 'Benutzerdefinierte Liste 5'),
(19188, 7024, 5, 'Benutzerdefinierte Liste 6'),
(19189, 7025, 5, 'Benutzerdefinierte Liste 7'),
(19190, 7026, 5, 'Benutzerdefinierter Text 1'),
(19191, 7027, 5, 'Benutzerdefinierter Text 2'),
(19192, 7028, 5, 'Benutzerdefinierter Text 3'),
(19193, 7029, 5, 'Benutzerdefinierter Text 4'),
(19194, 7030, 5, 'Benutzerdefinierter Text 5'),
(19195, 7031, 5, 'Benutzerdefinierter Text 6'),
(19196, 7032, 5, 'Benutzerdefinierter Text 7'),
(19197, 7033, 5, 'Benutzerdefinierter Text 8'),
(19198, 7034, 5, 'Anwender Vorname'),
(19199, 7039, 5, 'Benutzerhandbuch'),
(19200, 7040, 5, 'Benutzername'),
(19201, 7041, 5, 'Anwender Name'),
(19202, 7042, 5, 'Anwendername oder Hostname dürfen nicht leer sein'),
(19203, 7043, 5, 'Anwender oder Hostname'),
(19204, 7046, 5, 'Anwender Einstellungen'),
(19205, 7047, 5, 'Anwender spezifische Einstellungen'),
(19206, 7049, 5, 'Anwendername'),
(19207, 7052, 5, 'Username für SMS Gateway'),
(19208, 7053, 5, 'Username für SMS Gateway.'),
(19209, 7054, 5, 'Username für CouchDB Verbindung'),
(19210, 7055, 5, 'Anwendername:'),
(19211, 7056, 5, 'Anwender'),
(19212, 7057, 5, 'Anwender/Gruppen/Logs Verwaltung'),
(19213, 7058, 5, 'verwendet php <a href="http://php.net/strftime">strftime</a> Format'),
(19214, 7059, 5, 'Urinweg Infektionen'),
(19215, 7062, 5, 'URLAUB'),
(19216, 7063, 5, 'Urlaub'),
(19217, 7064, 5, 'Impfstoff'),
(19218, 7065, 5, 'Vaginal-Ring'),
(19219, 7066, 5, 'Abschiedsrede'),
(19220, 7067, 5, 'bestätigen'),
(19221, 7068, 5, 'Wert'),
(19222, 7069, 5, 'Wert 1'),
(19223, 7070, 5, 'Wert 2'),
(19224, 7072, 5, 'Wert muss numerisch sein'),
(19225, 7073, 5, 'Var1'),
(19226, 7074, 5, 'Var2'),
(19227, 7076, 5, 'Windpocken 1'),
(19228, 7077, 5, 'Windpocken 1'),
(19229, 7078, 5, 'Krampfadern'),
(19230, 7079, 5, 'Gefäßzustand'),
(19231, 7080, 5, 'Gefäßverletzung'),
(19232, 7081, 5, 'Gefäßchirurgie'),
(19233, 7083, 5, 'Hersteller'),
(19234, 7084, 5, 'Version'),
(19235, 7085, 5, 'Schwindel'),
(19236, 7088, 5, 'VFC'),
(19237, 7089, 5, 'Vietnamesisch'),
(19238, 7090, 5, 'zeigen'),
(19239, 7091, 5, 'Zeigen'),
(19240, 7092, 5, 'zeige Allergien'),
(19241, 7097, 5, 'Zeige umfassenden Patienten Bericht'),
(19242, 7100, 5, 'Zeige Dokument'),
(19243, 7101, 5, 'Zeige Fall'),
(19244, 7103, 5, 'Ereignis in einem Popup Fenster Zeigen?'),
(19245, 7104, 5, 'Anzeigen der Standort spezifischen Anwender Informationen'),
(19246, 7107, 5, 'Zeige Log'),
(19247, 7108, 5, 'Zeige Seite 1'),
(19248, 7109, 5, 'Zeige Seite 1'),
(19249, 7110, 5, 'Zeige Vergangene und kommende Erinnerungen'),
(19250, 7111, 5, 'Zeige Patient'),
(19251, 7116, 5, 'Anzeigen zugeordnete Fälle'),
(19252, 7121, 5, 'Zeige/Ändere Allergien'),
(19253, 7122, 5, 'Zeige/Bearbeite Fall'),
(19254, 7123, 5, 'Zeige/Drucken'),
(19255, 7124, 5, 'Zeige:'),
(19256, 7125, 5, 'VISA'),
(19257, 7126, 5, 'VISA/MC/AMEX/Dis'),
(19258, 7133, 5, 'Konsultation Kategorie'),
(19259, 7134, 5, 'Konsultation Datum'),
(19260, 7135, 5, 'Konsultation datum'),
(19261, 7137, 5, 'Konsultation Formular'),
(19262, 7138, 5, 'Konsultation Verlauf'),
(19263, 7140, 5, 'Konsultation'),
(19264, 7141, 5, 'Konsultation von'),
(19265, 7142, 5, 'Vitalparameter'),
(19266, 7143, 5, 'Vitalwerte'),
(19267, 7144, 5, 'Vitalwerte'),
(19268, 7146, 5, 'Stimme'),
(19269, 7147, 5, 'Sprachbericht gesendet'),
(19270, 7149, 5, 'Erbrechen'),
(19271, 7151, 5, 'W'),
(19272, 7152, 5, 'Taillenumfang'),
(19273, 7153, 5, 'Taillenumfang'),
(19274, 7154, 5, 'Warten'),
(19275, 7157, 5, 'Walt Pennington'),
(19276, 7158, 5, 'Warenhaus'),
(19277, 7159, 5, 'Warenhaus Maximum,0 falls nicht zutreffend'),
(19278, 7160, 5, 'Warenhaus Minimum, 0 falls nicht zutreffend'),
(19279, 7161, 5, 'Warenhaus'),
(19280, 7162, 5, 'Warm'),
(19281, 7163, 5, 'Warnung'),
(19282, 7164, 5, 'WARNUNG'),
(19283, 7166, 5, 'Warnung, Kontrollnummer in der Datenbank bereits vorhanden'),
(19284, 7168, 5, 'Warnung: Für diesen Patienten wurde heute bereits eine Konsultation erzeugt!'),
(19285, 7170, 5, 'Warnung: Patient ID ist nicht einzigartig!'),
(19286, 7171, 5, 'WARNUNG: Konfigurationsdaten werden mit den Daten von der hochgeladenen Datei überschrieben.'),
(19287, 7173, 5, 'Warnungen'),
(19288, 7175, 5, 'wurde bereits upgeloadet'),
(19289, 7177, 5, 'Wir erwarten die prompte Bezahlung des Restbetrages'),
(19290, 7178, 5, 'Ihr obiger Patient war bei uns in der ambulanten psychiatrischen Klinik für die Begutachtung und Behandlung. Vielen Dank für diese Empfehlung.'),
(19291, 7179, 5, 'Schwäche'),
(19292, 7181, 5, 'Websuche'),
(19293, 7182, 5, 'Webseite'),
(19294, 7183, 5, 'Webadresse für das Patienten Portal.');
INSERT INTO `lang_definitions` VALUES
(19295, 7184, 5, 'Mi'),
(19296, 7185, 5, 'Mittwoch'),
(19297, 7186, 5, 'Woche'),
(19298, 7187, 5, 'woche'),
(19299, 7188, 5, 'Wochenansicht'),
(19300, 7189, 5, 'Woche(n)'),
(19301, 7192, 5, 'Wochen'),
(19302, 7193, 5, 'Gewicht'),
(19303, 7194, 5, 'Gewicht Bewertung und Beratung für Kinder und Jugendliche'),
(19304, 7195, 5, 'Gewicht Bewertung und Beratung für Kinder und Jugendliche (CQM)'),
(19305, 7196, 5, 'Gewichtsänderung'),
(19306, 7197, 5, 'Gewichtsverlust'),
(19307, 7198, 5, 'Schlankheitsinstitut'),
(19308, 7199, 5, 'Willkommen'),
(19309, 7202, 5, 'Was ist zu rechnen?'),
(19310, 7203, 5, 'keucht'),
(19311, 7204, 5, 'Keuchen'),
(19312, 7205, 5, 'Keuchen:'),
(19313, 7208, 5, 'Wo können gescannte oder Papier-Dokumente gefunden werden?'),
(19314, 7209, 5, 'ob Versicherte'),
(19315, 7211, 5, 'Schleudertrauma'),
(19316, 7212, 5, 'Weiß'),
(19317, 7213, 5, 'Wer'),
(19318, 7214, 5, 'Wer antwortet?'),
(19319, 7215, 5, 'Verwitwet'),
(19320, 7216, 5, 'Breite'),
(19321, 7217, 5, 'Breite in Pixel der linken Navigationsleiste.'),
(19322, 7222, 5, 'mit alten Namen'),
(19323, 7224, 5, 'An wem können wir eine Nachricht hinterlassen?'),
(19324, 7225, 5, 'Unterdrückt'),
(19325, 7226, 5, 'binnen Stunden'),
(19326, 7227, 5, 'binnen Stunden:'),
(19327, 7228, 5, 'binnen Minuten'),
(19328, 7229, 5, 'binnen Minuten:'),
(19329, 7232, 5, 'Ohne Update'),
(19330, 7233, 5, 'Zeuge'),
(19331, 7237, 5, 'Frau'),
(19332, 7238, 5, 'Nur Frauen'),
(19333, 7240, 5, 'Arbeit'),
(19334, 7241, 5, 'Arbeitsnotiz'),
(19335, 7242, 5, 'Arbeit Telefon'),
(19336, 7243, 5, 'Telefonnummer Arbeit'),
(19337, 7244, 5, 'Arbeitsbezogen?'),
(19338, 7245, 5, 'Arbeit/Ausbildung/Hobbies'),
(19339, 7246, 5, 'Arbeit/Schul Bemerkung'),
(19340, 7247, 5, 'Arbeitstag'),
(19341, 7252, 5, 'Schlimmer'),
(19342, 7254, 5, 'Sollen sie als geklärt gekennzeichnet werden?'),
(19343, 7255, 5, 'Möchten Sie reservieren?'),
(19344, 7258, 5, 'Willst Du Zahlungen löschen?'),
(19345, 7259, 5, 'Willst Du Bezahlungen verändern und beenden?'),
(19346, 7260, 5, 'WIllst Du Bezahlungen verändern?'),
(19347, 7261, 5, 'Willst Du Bezahlungen zuweisen und beenden?'),
(19348, 7262, 5, 'Willst Du Bezahlungen zuweisen?'),
(19349, 7263, 5, 'Willst Du speichern?'),
(19350, 7264, 5, 'Handgelenk'),
(19351, 7265, 5, 'Handgelenk und Hand'),
(19352, 7266, 5, 'Handgelenk Probleme'),
(19353, 7267, 5, 'schreiben'),
(19354, 7268, 5, 'abschreiben'),
(19355, 7271, 5, 'WT'),
(19356, 7273, 5, 'x Abgebrochen'),
(19357, 7274, 5, 'x Abgebrochen'),
(19358, 7275, 5, 'Röntgen'),
(19359, 7276, 5, 'Röntgen-Interpretation:'),
(19360, 7277, 5, 'Röntgen-Interpretation:'),
(19361, 7278, 5, 'Nur X12: Ersatz-Anspruch '),
(19362, 7279, 5, 'X12 Partner'),
(19363, 7280, 5, 'X12 Partner'),
(19364, 7284, 5, 'J'),
(19365, 7285, 5, 'Jahr'),
(19366, 7286, 5, 'Jahr'),
(19367, 7287, 5, 'Jahresansicht'),
(19368, 7288, 5, 'Jahr(e)'),
(19369, 7289, 5, 'Jahre'),
(19370, 7292, 5, 'JA'),
(19371, 7293, 5, 'Ja'),
(19372, 7294, 5, 'ja'),
(19373, 7295, 5, 'JA!'),
(19374, 7296, 5, 'Ja, entfernen und aufzeichnen'),
(19375, 7298, 5, 'Ja/Nein'),
(19376, 7299, 5, 'Ja:'),
(19377, 7300, 5, 'Yiddish'),
(19378, 7303, 5, 'Sie sind dabei die Vorlage dauerhaft zu verändern. Sind Sie sicher, dass Sie den Vorgang fortsetzen?'),
(19379, 7304, 5, 'Du bist in der Grace-Login-Zeit. Ändere Dein Passwort vor dem'),
(19380, 7305, 5, 'Sie sind nicht berechtigt, dieses Ereignis löschen'),
(19381, 7306, 5, 'Sie sind nicht berechtigt, dieses Ereignis zu ändern'),
(19382, 7307, 5, 'Sie haben für das keine Berechtigung.'),
(19383, 7309, 5, 'Sie haben keine Rechte, Problemstellungen zu bearbeiten.'),
(19384, 7310, 5, 'Sie haben keine Rechte, um Termine zu vergeben.'),
(19385, 7311, 5, 'Sie haben keine Rechte, diese Visite einzusehen.'),
(19386, 7312, 5, 'Sie verändern eine alte Visite. Ist das korrekt?'),
(19387, 7313, 5, 'Kein direkter Zugriff auf diese Funktion erlaubt.'),
(19388, 7314, 5, 'Kein direkter Zugriff auf diese Seite erlaubt.'),
(19389, 7315, 5, 'Kategorie darf nicht leer sein!'),
(19390, 7316, 5, 'Unterkategorie darf nicht leer sein!'),
(19391, 7317, 5, 'Item darf nicht leer sein!'),
(19392, 7318, 5, 'Du kannst kein Datum auswählen, das in der Zukunft liegt, wenn der Vollständigkeitsstatus auf Ja gesetzt ist'),
(19393, 7319, 5, 'Du hast keine Aktionen ausgewählt.'),
(19394, 7320, 5, 'Du hast keine Rechte, um diese Notiz zu sehen oder zu bearbeiten'),
(19395, 7321, 5, 'Du versuchst Inhalte zu ändern, die gesperrt sind. Entferne die Sperre, um dies zu tun: Entferne die Zeile ''/*lock::*/'''),
(19396, 7322, 5, 'Du bist jetzt abgemeldet.'),
(19397, 7323, 5, 'Du kannst .txt-Dateien hochladen'),
(19398, 7325, 5, 'Hier kann Text eingefügt werden, der als Standard-Beschwerde im Formular für eine neue Visite verwendet wird.'),
(19399, 7326, 5, 'Gib ein Passwort ein, um dieses Dokument zu verschlüsseln'),
(19400, 7329, 5, 'Erst Patient wählen oder hinzufügen'),
(19401, 7330, 5, 'Erstelle zuerst eine Visite.'),
(19402, 7331, 5, 'Wähle eine Kategorie für diese Visite'),
(19403, 7332, 5, 'Wähle eine Kategorie für diese Visite.'),
(19404, 7333, 5, 'Felder auswählen, um fortzufahren.'),
(19405, 7335, 5, 'Wähle mindestens einen Kontext'),
(19406, 7336, 5, 'Wähle mindestens einen Provider'),
(19407, 7339, 5, 'Enddatum ungültig'),
(19408, 7340, 5, 'Termin gelöscht'),
(19409, 7341, 5, 'Termin geändert'),
(19410, 7342, 5, 'Termin übertragen'),
(19411, 7343, 5, 'Die Datei ist zu groß'),
(19412, 7345, 5, 'Der Listenname wurde geändert, um den Namensvorschriften zu genügen.'),
(19413, 7347, 5, 'Dein Name für diese Kategorie, dieses Verfahren oder Ergebnis'),
(19414, 7349, 5, 'Passwort läuft ab. Bitte Passwort ändern.'),
(19415, 7350, 5, 'Passwort läuft ab am'),
(19416, 7351, 5, 'Passwort läuft heute ab. Bitte Passwort ändern.'),
(19417, 7353, 5, 'Deine PostCalendar-Konfiguration wurde auf die Standardwerte zurückgesetzt.'),
(19418, 7354, 5, 'Deine PostCalendar-Konfiguration wurde aktualisiert.'),
(19419, 7355, 5, 'Wiederholfrequenz muss Datentyp "Integer" sein'),
(19420, 7356, 5, 'Wiederholfrequenz muss größer eins sein.'),
(19421, 7357, 5, 'Startdatum ist größer als Enddatum'),
(19422, 7358, 5, 'Startdatum ist ungültig'),
(19423, 7359, 5, 'Übertragung fehlgeschlagen.'),
(19424, 7360, 5, 'jjjj-mm-tt'),
(19425, 7361, 5, 'JJJJ-MM-DD'),
(19426, 7362, 5, 'jjjj-mm-tt Datum zugehörig zu diesem Dokument'),
(19427, 7363, 5, 'jjjj-mm-tt Datum zerstört'),
(19428, 7364, 5, 'jjjj-mm-tt Geburtstag'),
(19429, 7365, 5, 'jjjj-mm-tt Geburtstag'),
(19430, 7366, 5, 'jjjj-mm-tt Ablaufdatum'),
(19431, 7367, 5, 'jjjj-mm-tt Datum des Ausbruchs der Krankheit oder der Hospitalisierung'),
(19432, 7368, 5, 'jjjj-mm-tt Datum des Ausbruchs der Krankheit, der OP oder Start der Medikation'),
(19433, 7369, 5, 'jjjj-mm-tt Datum des Kaufs oder der Überweisung'),
(19434, 7370, 5, 'jjjj-mm-tt Datum der Genesung oder Ende der Medikation'),
(19435, 7371, 5, 'jjjj-mm-tt Datum der Rückkehr zum Spiel'),
(19436, 7372, 5, 'jjjj-mm-tt Datum der Leistung'),
(19437, 7373, 5, 'jjjj-mm-tt Datum dieses Briefes'),
(19438, 7374, 5, 'jjjj-mm-tt Datum zurückgekehrt zum Spiel'),
(19439, 7375, 5, 'jjjj-mm-tt Dokumentdatum'),
(19440, 7376, 5, 'jjjj-mm-tt Ereignisdatum oder Startdatum'),
(19441, 7381, 5, 'jjjj-mm-tt hh:mm:ss'),
(19442, 7383, 5, 'jjjj-mm-tt letztes Datum dieses Ereignisses'),
(19443, 7387, 5, 'Null'),
(19444, 7389, 5, 'PLZ'),
(19445, 7390, 5, 'PLZ'),
(19446, 7391, 5, 'PLZ/Land'),
(19447, 7392, 5, 'Zulu'),
(19448, 7393, 5, ' but aber es war '),
(19449, 7394, 5, ' nicht zugegriffen'),
(19450, 7395, 5, 'wollen Sie wirklich löschen'),
(19451, 7396, 5, 'Medikament'),
(19452, 7397, 5, 'emails nicht versendet'),
(19453, 7398, 5, 'von'),
(19454, 7399, 5, 'wurde erzeugt. '),
(19455, 7400, 5, 'wurde wieder geöffnet.'),
(19456, 7401, 5, 'Geschichte'),
(19457, 7402, 5, 'ist keine Nummer'),
(19458, 7403, 5, 'bereit zur Wiederberechnung'),
(19459, 7404, 5, 'LLL:'),
(19460, 7405, 5, 'Los'),
(19461, 7407, 5, 'min'),
(19462, 7408, 5, 'nicht gefunden'),
(19463, 7410, 5, 'Verschreibung hat Grenze erreicht von'),
(19464, 7411, 5, 'bis'),
(19465, 7412, 5, 'aktualisieren fehlgeschlagen, nicht in Datenbank?'),
(19466, 7413, 5, 'wurde als "nur abgerechnet" markiert.'),
(19467, 7414, 5, 'wurde erfolgreich eingereiht.'),
(19468, 7415, 5, '! Gegangen ohne Visite'),
(19469, 7416, 5, '" für Code'),
(19470, 7418, 5, '# Versicherungs-/Finanzierungsproblem'),
(19471, 7419, 5, 'Anzahl Tabletten'),
(19472, 7420, 5, '$'),
(19473, 7421, 5, '$ Kodierung fertig'),
(19474, 7422, 5, '$label (jjjj-mm-tt) '),
(19475, 7423, 5, '%'),
(19476, 7424, 5, '% Abgesagt < 24h'),
(19477, 7425, 5, '% Abgesagt < 24h '),
(19478, 7426, 5, 'sollte vorhanden sein, ist es aber nicht'),
(19479, 7427, 5, '(% steht für mehrere beliebige Zeichen, _ für genau ein beliebiges Zeichen)'),
(19480, 7428, 5, '([Ctrl] + Klick, um mehrere Empfänger auszuwählen)'),
(19481, 7429, 5, '(Zurück)'),
(19482, 7430, 5, '(Klicken zum Editieren)'),
(19483, 7431, 5, '(E-Mail wird unverzüglich zugestellt, VOIP wird dem Service Provider übermittelt zur weiteren Bearbeitung)'),
(19484, 7432, 5, '(Mehr)'),
(19485, 7433, 5, '(Neuer Patient)'),
(19486, 7434, 5, '(Notizen und Genehmigungen)'),
(19487, 7435, 5, '(Patientennotizen)'),
(19488, 7436, 5, '(Wähle einen von diesen, oder schreibe einen eigenen Titel)'),
(19489, 7437, 5, '(Shift-)Klick oder ziehen um Wert zu ändern'),
(19490, 7438, 5, '* Erinnerung erfolgt'),
(19491, 7439, 5, '** Bitte Operationen in Probleme verschieben!'),
(19492, 7440, 5, '* Benötigt'),
(19493, 7441, 5, '+ Karte rausgesucht'),
(19494, 7442, 5, '- kein'),
(19495, 7443, 5, '-- Alle --'),
(19496, 7444, 5, '-- Rolle auswählen --'),
(19497, 7445, 5, '.'),
(19498, 7446, 5, '0'),
(19499, 7447, 5, '0-10'),
(19500, 7448, 5, '0-24'),
(19501, 7451, 5, '1'),
(19502, 7452, 5, '1 = Nord Amerika. Siehe http://www.wtng.info/ für eine Liste anderer Ländercodes.'),
(19503, 7453, 5, '1 Tag ab jetzt'),
(19504, 7454, 5, '1 Monat ab jetzt'),
(19505, 7455, 5, '1 Woche ab jetzt'),
(19506, 7456, 5, '1 Jahr ab jetzt'),
(19507, 7458, 5, '11-14'),
(19508, 7459, 5, '12 h'),
(19509, 7460, 5, '15-19'),
(19510, 7461, 5, '1'),
(19511, 7462, 5, '2'),
(19512, 7463, 5, '2 Tage ab jetzt'),
(19513, 7464, 5, '2 Monate ab jetzt'),
(19514, 7465, 5, '2 Wochen ab jetzt'),
(19515, 7466, 5, '2 Jahre ab jetzt'),
(19516, 7468, 5, '20-24'),
(19517, 7477, 5, '2111-13'),
(19518, 7478, 5, '24 h'),
(19519, 7479, 5, '25+'),
(19520, 7480, 5, '25-29'),
(19521, 7481, 5, '2'),
(19522, 7482, 5, '3 Tage ab jetzt'),
(19523, 7483, 5, '3 Monate'),
(19524, 7484, 5, '3 Monate ab jetzt'),
(19525, 7485, 5, '3 mal täglich'),
(19526, 7486, 5, '3 Wochen ab jetzt'),
(19527, 7487, 5, '30-34'),
(19528, 7488, 5, '35-39'),
(19529, 7489, 5, '3'),
(19530, 7490, 5, '4 Tage ab jetzt'),
(19531, 7491, 5, '4 Monate'),
(19532, 7492, 5, '4 Monate ab jetzt'),
(19533, 7493, 5, '4 mal täglich'),
(19534, 7494, 5, '4 Wochen ab jetzt'),
(19535, 7495, 5, '40-44'),
(19536, 7496, 5, '45+'),
(19537, 7497, 5, '465.9, URI'),
(19538, 7498, 5, '466.0, Bronchitis, Akut (oNA)'),
(19539, 7499, 5, '486.0. Pneumonie, Akut'),
(19540, 7500, 5, '491.21, COPD Exacerbation'),
(19541, 7501, 5, '491.8, Chronische Bronchitis'),
(19542, 7502, 5, '493.92, Asthma, akut exacerb.'),
(19543, 7503, 5, '496.0, COPD'),
(19544, 7504, 5, '4'),
(19545, 7505, 5, '5 Tage ab jetzt'),
(19546, 7506, 5, '5 Monate ab jetzt'),
(19547, 7507, 5, '5 Wochen ab jetzt'),
(19548, 7508, 5, '519.7, Bronchospasmus'),
(19549, 7509, 5, '5'),
(19550, 7510, 5, '6 Tage ab jetzt'),
(19551, 7511, 5, '6 Monate'),
(19552, 7512, 5, '6 Monate ab jetzt'),
(19553, 7513, 5, '6 Wochen ab jetzt'),
(19554, 7514, 5, '6te'),
(19555, 7515, 5, '7 Monate ab jetzt'),
(19556, 7516, 5, '8 Monate ab jetzt'),
(19557, 7517, 5, '824.0 Fraktur, med. malleolus, geschlossen'),
(19558, 7518, 5, '824.2 Fraktur, lat. malleolus, geschlossen'),
(19559, 7519, 5, '824.6 Fraktur, trimalleolär, geschlossen'),
(19560, 7520, 5, '825.32 Fraktur, os navikulare (Sprunggelenk)'),
(19561, 7521, 5, '825.35 Fraktur, Basis fünfte (5.) Metatarsale'),
(19562, 7522, 5, '845.0 Verstauchung Sprunggelenk (oNA)'),
(19563, 7523, 5, '845.01 Verstauchung mediales (deltoid) Lig.'),
(19564, 7524, 5, '845.02 Verstauchung calcaneal fibular'),
(19565, 7525, 5, '9 Monate ab jetzt'),
(19566, 7526, 5, '99212 festgestellt - unkompliziert'),
(19567, 7527, 5, '99213 festgestellt - leicht kompliziert'),
(19568, 7528, 5, '< Im Untersuchungsraum'),
(19569, 7529, 5, '> Gegangen'),
(19570, 7530, 5, '?'),
(19571, 7531, 5, '? Nicht erschienen'),
(19572, 7532, 5, '@ Angekommen'),
(19573, 7533, 5, '[Ansicht ändern]'),
(19574, 7534, 5, '[Tag des letzten Termins]'),
(19575, 7535, 5, '[Tage seit letztem Termin]'),
(19576, 7536, 5, '[EOBs]'),
(19577, 7537, 5, '[Export OFX]'),
(19578, 7538, 5, '[nicht empfohlen]'),
(19579, 7539, 5, '[Anzahl Fälle]'),
(19580, 7540, 5, '[Berichte]'),
(19581, 7541, 5, '[Alles auswählen]'),
(19582, 7542, 5, '[SQL-Ledger]'),
(19583, 7543, 5, '[Starten der Batch-Bearbeitung]'),
(19584, 7544, 5, '[Log anzeigen]'),
(19585, 7545, 5, '[Druckbaren Bericht anzeigen]'),
(19586, 7546, 5, '_PC_DUR_HOURS'),
(19587, 7547, 5, '_PC_DUR_MINUTES'),
(19588, 7548, 5, '_PC_LOCALE'),
(19589, 7549, 5, '~ Zu spät gekommen'),
(19590, 1, 6, 'A'),
(19591, 2, 6, 'Chequenummer of claimnummer om betaling te identificeren'),
(19592, 3, 6, 'Een certificaat voor de ADMIN gebruiker'),
(19593, 4, 6, 'Een klinisch document is bijgevoegd'),
(19594, 5, 6, 'Een klinisch document is bijgevoegd.'),
(19595, 7, 6, 'Hiervoor is een distributeur nodig'),
(19596, 8, 6, 'Een CGAC visite formulier hoort bij dit bezoek.'),
(19597, 9, 6, 'Een lot # is vereist'),
(19598, 10, 6, 'Een lot # is vereist!'),
(19599, 11, 6, 'Kleine letter'),
(19600, 12, 6, 'Numeriek'),
(19601, 14, 6, 'Een client met deze ID is al geregistreed'),
(19602, 15, 6, 'Een client met deze naam bestaat al'),
(19603, 16, 6, 'Een client met deze Soc.Sec. bestaat al'),
(19604, 17, 6, 'Een positief getal laat dat aantal afspraken zien in een Widget een samenvat scherm van de patient (Een negatief nummer laat de vergelopen afspraken zien in een aflopende volgorde)'),
(19605, 18, 6, 'Een positief nummer geeft aan dat er afspraken in verleden geweest zijn in het WIDGET-scherm van de patient'),
(19606, 19, 6, 'Aanmaken van verwijs bron kan bij ieder bezoek'),
(19607, 20, 6, 'Een overeenkomstige IPPF code is noodzakelijk!'),
(19608, 21, 6, 'Een speciaal karakter'),
(19609, 22, 6, 'Een unieke waarde om dit veld te identificeren, onzichtbaar voor de gebruiker'),
(19610, 23, 6, 'Vandaag een reeds aangemaakt bezoek voor deze client. Klik op Cancel om het te openen, of op OK om door te gaan en maak een nieuwe.'),
(19611, 24, 6, 'voor ontbijt'),
(19612, 25, 6, 'in de morgen'),
(19613, 26, 6, 'A/F Niveau rechts:'),
(19614, 27, 6, 'AB'),
(19615, 28, 6, 'Afkorting'),
(19616, 29, 6, 'Abces'),
(19617, 30, 6, 'Abdominaal'),
(19618, 31, 6, 'Vier stappenplan voor toename gewichtsbelasting:'),
(19619, 32, 6, 'Abn'),
(19620, 33, 6, 'Abn.1'),
(19621, 34, 6, 'Abnormaal'),
(19622, 35, 6, 'Abnormale bloedtest'),
(19623, 36, 6, 'Abnormale haargroei'),
(19624, 37, 6, 'Abnormaal mammogram'),
(19625, 39, 6, 'Abortus'),
(19626, 40, 6, 'Abortusproblematiek'),
(19627, 41, 6, 'Abortusmethode'),
(19628, 42, 6, 'Abortus gerelateerde categorieen'),
(19629, 43, 6, 'Abortussen'),
(19630, 44, 6, 'Over de kalender'),
(19631, 46, 6, 'Diagnose met absences'),
(19632, 47, 6, 'Aanstelling accepteren'),
(19633, 48, 6, 'Accepteer betaling voor'),
(19634, 49, 6, 'Accepteer betaling voor '),
(19635, 50, 6, 'Accepteert opdracht'),
(19636, 51, 6, 'Bevoegd als'),
(19637, 52, 6, 'Toegangscontrolelijsten administratie'),
(19638, 53, 6, 'Datum van toegang'),
(19639, 54, 6, 'Toegang niet toegestaan'),
(19640, 55, 6, 'Toegang niet geautoriseerd'),
(19641, 56, 6, 'Naar eigen Patienten toegang'),
(19642, 57, 6, 'Ongeval'),
(19643, 59, 6, 'Account naam'),
(19644, 62, 6, 'Boekhouding'),
(19645, 64, 6, 'Pijn'),
(19646, 65, 6, 'Erkenning gevraagde (ISA14)'),
(19647, 66, 6, 'Namen, licentie en certificering'),
(19648, 67, 6, 'ACL'),
(19649, 68, 6, 'ACL administratie'),
(19650, 69, 6, 'ACL administratie. Niet toegestaan'),
(19651, 70, 6, 'ACL Met succes vernieuwd'),
(19652, 71, 6, 'Acne'),
(19653, 72, 6, 'Act'),
(19654, 73, 6, 'Act datum'),
(19655, 74, 6, 'Actie'),
(19656, 75, 6, 'Acties'),
(19657, 77, 6, 'Activeren van CCR/CCD rapportage'),
(19658, 78, 6, 'Actief'),
(19659, 79, 6, 'Actief alarm'),
(19660, 80, 6, 'Regels voor actief alarm'),
(19661, 81, 6, 'Actieve Alertering/Herinneringen'),
(19662, 82, 6, 'Huidige bezoek'),
(19663, 84, 6, 'Actieve lijst'),
(19664, 85, 6, 'Client in focus:'),
(19665, 86, 6, 'Actieve plannen'),
(19666, 87, 6, 'Activiteit'),
(19667, 88, 6, 'Soort activiteit'),
(19668, 90, 6, 'Acute vergiftiging/Onttrekkings Sx'),
(19669, 91, 6, 'ACutre manifestatie van een chronische conditie'),
(19670, 92, 6, 'Acuut op chronisch beloop'),
(19671, 93, 6, 'toevoegen'),
(19672, 94, 6, 'Toevoegen'),
(19673, 95, 6, 'ADD'),
(19674, 96, 6, 'Bedrijf toevoegen'),
(19675, 98, 6, 'Apotheek toevoegen'),
(19676, 100, 6, 'gebeurtenis toevoegen voor '),
(19677, 101, 6, 'Bewaar als nieuwe notitie'),
(19678, 102, 6, 'Bewaar als nieuw'),
(19679, 104, 6, 'Knoppen toevoegen'),
(19680, 105, 6, 'Knoppen toevoegen voor Speciale karakters om aan bovenzijde van de Editor te tonen om bij de tekst te voegen dmv Click'),
(19681, 106, 6, 'Categorie toevoegen'),
(19682, 107, 6, 'Constante toevoegen'),
(19683, 108, 6, 'Contekst toevoegen'),
(19684, 109, 6, 'Eigen bijdrage toevoegen'),
(19685, 110, 6, 'Criterium toevoegen'),
(19686, 111, 6, 'Custom knop toevoegen'),
(19687, 112, 6, 'Dx toevoegen'),
(19688, 113, 6, 'Rx toevoegen'),
(19689, 114, 6, 'Contact toevoegen'),
(19690, 115, 6, 'Toevoegen van bezoek notities'),
(19691, 116, 6, 'Locatie toevoegen'),
(19692, 117, 6, 'Veld toevoegen'),
(19693, 118, 6, 'Voeg de volgende regels toe aan het Apache-configuratiebestand'),
(19694, 119, 6, 'Groep toevoegen'),
(19695, 120, 6, 'ICD Code toevoegen'),
(19696, 121, 6, 'Vaccinatie toevoegen'),
(19697, 122, 6, 'Toevoegen niet geautoriseerd'),
(19698, 123, 6, 'Probleem toevoegen'),
(19699, 124, 6, 'Item toevoegen om te vervolgen'),
(19700, 125, 6, 'Taal toevoegen'),
(19701, 126, 6, 'Nieuwe toevoegen'),
(19702, 127, 6, 'Nieuwe toevoegen'),
(19703, 128, 6, 'Nieuwe categorie toevoegen '),
(19704, 129, 6, 'Voeg nieuwe certificaten aan het Apache-configuratiebestand'),
(19705, 130, 6, 'Nieuwe component toevoegen'),
(19706, 131, 6, 'Nieuwe componenten toevoegen'),
(19707, 132, 6, 'Nieuwe groep toevoegen'),
(19708, 133, 6, 'Nieuwe Issue toevoegen'),
(19709, 134, 6, 'Voeg nieuw lot en transactie toe'),
(19710, 135, 6, 'Voeg nieuwe notitie toe'),
(19711, 136, 6, 'Voeg nieuwe notitie toe'),
(19712, 137, 6, 'Nieuwe partner toevoegen'),
(19713, 138, 6, 'Nieuwe Patient toevoegen'),
(19714, 140, 6, 'Voeg notitie toe'),
(19715, 141, 6, 'Status aanmaken'),
(19716, 142, 6, 'Recept toevoegen'),
(19717, 143, 6, 'Procedure toevoegen'),
(19718, 144, 6, 'Voeg de provider naam toe'),
(19719, 145, 6, 'Rehab toevoegen'),
(19720, 146, 6, 'Regels toevoegen'),
(19721, 147, 6, 'Toevoegen bij'),
(19722, 148, 6, 'Aan medicatielijst toevoegen'),
(19723, 149, 6, 'Aan top level toevoegen'),
(19724, 150, 6, 'Verklaring aanmaken'),
(19725, 151, 6, 'Voeg gebruiker toe'),
(19726, 152, 6, 'Gebruiker aan groep toevoegen'),
(19727, 153, 6, 'Toevoegen/aanpassen eRx'),
(19728, 154, 6, 'toevoegen/bewerken van client transactie'),
(19729, 155, 6, 'toegevoegd'),
(19730, 156, 6, 'Toevoegen persoonsgeg.niet geautoriseerd'),
(19731, 157, 6, 'Toevoegen van volgen van een item is mislukt'),
(19732, 158, 6, 'Addison Syndroom'),
(19733, 159, 6, 'Addison Syndroom'),
(19734, 160, 6, 'Extra attributen'),
(19735, 161, 6, 'Aanvullende diagnose:'),
(19736, 162, 6, 'Aanvullende voorgeschiedenis'),
(19737, 163, 6, 'Extra voorgeschiedenis notities'),
(19738, 164, 6, 'Extra info'),
(19739, 165, 6, 'Extra labonderzoeken'),
(19740, 166, 6, 'Extra notities'),
(19741, 167, 6, 'Extra notities voor deze uitslag of aanbeveling'),
(19742, 168, 6, 'Extra notities'),
(19743, 169, 6, 'Extra notities: '),
(19744, 170, 6, 'Extra rontgenfoto notities:'),
(19745, 171, 6, 'Let op: de overeenkomstige versie van US Snomed Extensie Pakket, kan apart geimporteerd worden na installatie van de Internationale (Engelse versie) versie van Snomed.'),
(19746, 172, 6, 'Alleen toevoegen'),
(19747, 173, 6, 'Adresboek'),
(19748, 174, 6, 'Adresboek'),
(19749, 175, 6, 'Adres'),
(19750, 178, 6, 'Adresboek'),
(19751, 179, 6, 'Gegevensinvoer in adresboek van het bedrijf dat deze procedure uitvoert'),
(19752, 180, 6, 'Adresboekgegevens voor de distributeur'),
(19753, 181, 6, 'Adresboekgegevens van de verkoper'),
(19754, 182, 6, 'Type adresboek'),
(19755, 183, 6, 'Adres label'),
(19756, 187, 6, 'Adres1'),
(19757, 188, 6, 'Adres2'),
(19758, 189, 6, 'Geadresseerde'),
(19759, 190, 6, 'Aanp.'),
(19760, 191, 6, 'Aanp. bedrag'),
(19761, 192, 6, 'Aanpassen'),
(19762, 193, 6, 'Aanpassing'),
(19763, 194, 6, 'Aanpassing bedrag'),
(19764, 195, 6, 'Reden voor aanpassingen'),
(19765, 196, 6, 'Verandering waarde voor code '),
(19766, 197, 6, 'Aanpassing'),
(19767, 198, 6, 'Adm aanpassing'),
(19768, 199, 6, 'Administratie'),
(19769, 200, 6, 'Administratie e-mailadres'),
(19770, 201, 6, 'Administreren via'),
(19771, 202, 6, 'Vastgelegd door'),
(19772, 203, 6, 'Geadministreerd door'),
(19773, 204, 6, 'Geadministreerde datum'),
(19774, 205, 6, 'Gadministreerde Site'),
(19775, 206, 6, 'Administratie'),
(19776, 207, 6, 'Site voor Administratie'),
(19777, 208, 6, 'Beheerders'),
(19778, 209, 6, 'Beheerders kunnen alles doen'),
(19779, 210, 6, 'Datum toevoeging'),
(19780, 212, 6, 'Volwassene gewichts screening met follow-up'),
(19781, 213, 6, 'Volwassene gewichts screening met follow-up (CQM)'),
(19782, 214, 6, 'Speciale richtlijn'),
(19783, 215, 6, 'Speciale richtlijnen'),
(19784, 216, 6, 'Speciale richtlijnen waarschuwing'),
(19785, 218, 6, 'Geavanceerd'),
(19786, 219, 6, 'Advies'),
(19787, 220, 6, 'Afar'),
(19788, 221, 6, 'Normaal effect'),
(19789, 222, 6, 'Afrikaans'),
(19790, 223, 6, 'Oproep na spreekuur'),
(19791, 224, 6, 'Nadat er is overgegaan van de administratie systematiek van het oude Paswoord waar het oude PW in de Usere Tabel is opgeslagen zonder `salt`en afgerond is, moet deze FLAG op FALSE gezet worden zodat alleen via authenticatie nieuwe systeem mogelijk is.'),
(19792, 225, 6, 'Na de bovenvermelde configuratie uitgevoerd te hebben, importeer het clientcertificaat in de browser en start Apache opnieuw (leeg paswoord)'),
(19793, 226, 6, 'Na bewaren via PDF, klik op [view log] om op fouten te controlen.'),
(19794, 227, 6, 'Na het bewaren van het tekstbestand(en), klik op [view log] om te controleren op fouten'),
(19795, 228, 6, 'Na bewaren van batch, klik op [view log] om op fouten te controleren.'),
(19796, 229, 6, 'Daarna laat de Match Kolom het ID van de patient zien, of ) om aan te maken.'),
(19797, 230, 6, 'Klik op de Bewaren knop, nadat de informatie juist is ingevoerd'),
(19798, 231, 6, 'Na Uploaden klik op de knop "Importeren"'),
(19799, 232, 6, 'Planning nazorg'),
(19800, 233, 6, 'Opnieuw'),
(19801, 234, 6, 'Lft'),
(19802, 235, 6, 'Gesorteerd op'),
(19803, 236, 6, 'Lft.categorie'),
(19804, 237, 6, 'Leeftijd datum valt buiten gebied.'),
(19805, 238, 6, 'Format met leeftijd-tonen'),
(19806, 239, 6, 'Leeftijd "format" is niet juist'),
(19807, 240, 6, 'Leeftijd "format" is niet juist'),
(19808, 241, 6, 'Lft vanaf'),
(19809, 242, 6, 'Leeftijd in jaren voor "Tonen formaat verandering"'),
(19810, 243, 6, 'Max leeftijd'),
(19811, 244, 6, 'Min leeftijd'),
(19812, 245, 6, 'Leeftijd spreiding'),
(19813, 247, 6, 'Aging Columns:'),
(19814, 248, 6, 'Akan'),
(19815, 249, 6, 'Albaans'),
(19816, 250, 6, 'Alcohol'),
(19817, 251, 6, 'Alcoholconsumptie'),
(19818, 252, 6, 'Alcohol gebruik'),
(19819, 253, 6, 'Alerts totalen'),
(19820, 255, 6, 'Waarschuwingen'),
(19821, 258, 6, 'ALEUT'),
(19822, 259, 6, 'Allemaal'),
(19823, 260, 6, 'ALLEN'),
(19824, 261, 6, 'Allen (overgenomen van format A)'),
(19825, 262, 6, 'Allen (overgenomen van format B)'),
(19826, 263, 6, 'Allen (Cumulatief)'),
(19827, 265, 6, 'Alle Automated Measure Calculations (AMC)'),
(19828, 266, 6, 'Alle categorieen'),
(19829, 267, 6, 'Alle Clinical Qualiry Measures (CQM)'),
(19830, 268, 6, 'Alle codes'),
(19831, 269, 6, 'Gehele dag'),
(19832, 270, 6, 'Gebeurtenis voor hele dag'),
(19833, 271, 6, 'Alle demografie velden, met zoeken en controle'),
(19834, 272, 6, 'Alle Klinieken'),
(19835, 273, 6, 'Alle ongevallen/problemen/issues'),
(19836, 274, 6, 'Alle talen toegestaan'),
(19837, 275, 6, 'Alle groepen voor offilciele Cinical Quality Measures (CQM)'),
(19838, 276, 6, 'Alles of gedeelte van voornaam'),
(19839, 277, 6, 'Alles of gedeelte van achternaam'),
(19840, 278, 6, 'Allemaal of een gedeelte van de organisatie'),
(19841, 279, 6, 'Alle patienten'),
(19842, 280, 6, 'Alle producten'),
(19843, 281, 6, 'Alle zorgverleners'),
(19844, 282, 6, 'Alles nagekeken en negatief:'),
(19845, 283, 6, 'Alle onderwerpen'),
(19846, 284, 6, 'Alle gebruikers'),
(19847, 285, 6, 'Allergisch'),
(19848, 286, 6, 'Allergieen'),
(19849, 287, 6, 'Allergieen:'),
(19850, 288, 6, 'Allergie'),
(19851, 289, 6, 'Importeren van allergie is goed gegaan'),
(19852, 290, 6, 'Allergie probleem lijst'),
(19853, 291, 6, 'Allergische reactie'),
(19854, 294, 6, 'Toewijzen'),
(19855, 295, 6, 'Toestaan'),
(19856, 296, 6, 'Toestaan van alle beschikbare talen als keuze voor login menu toe'),
(19857, 297, 6, 'Toestaan van claims met diagnose maar niet met procdures of extra kosten. Meestal niet gewenst.'),
(19858, 298, 6, 'Toestaan van dummy taal'),
(19859, 299, 6, 'E-mail toestaan'),
(19860, 300, 6, 'E-mailberichten toestaan?'),
(19861, 301, 6, 'E-mail toestaan?'),
(19862, 302, 6, 'Claims tijdens encounters toestaan'),
(19863, 303, 6, 'Health Information Exchange toestaan'),
(19864, 304, 6, 'Immunisatie Info Sharing toestaan'),
(19865, 305, 6, 'Immunisatie reg. toestaan.'),
(19866, 306, 6, 'Brieven toestaan'),
(19867, 308, 6, 'Patient portal toestaan'),
(19868, 309, 6, 'SMS toestaan'),
(19869, 310, 6, 'SMS (tekstberichten) toestaan?'),
(19870, 311, 6, 'Toestaan om gebeurtenissen meteen actief te maken?'),
(19871, 312, 6, 'Telefoonberichten toestaan?'),
(19872, 313, 6, 'Gebruikers toestaan om algemene gebeurtenissen te publiceren'),
(19873, 314, 6, 'Gebruikers toestaan om prive-agenda´s te publiceren'),
(19874, 315, 6, 'Voicemail toestaan'),
(19875, 316, 6, 'Toegestaan'),
(19876, 317, 6, 'Talen toestaan'),
(19877, 318, 6, 'Toegestaan(c)'),
(19878, 319, 6, 'E-Sign toestaan op gehele bezoek'),
(19879, 320, 6, 'E-Sign toestaan op Formulieren sec'),
(19880, 321, 6, 'Toestaan e-mail'),
(19881, 322, 6, 'Toestaan voice berichten'),
(19882, 323, 6, 'bestaat al'),
(19883, 324, 6, 'bestaat al.'),
(19884, 325, 6, 'Reeds gebruikt, kies andere id-code'),
(19885, 326, 6, 'Reeds in gebruik kies een andere titel'),
(19886, 327, 6, 'Alternatief adres'),
(19887, 328, 6, 'veranderen'),
(19888, 329, 6, 'Je zou ook de SEARCH pagina kunnen gebruiken om een electronisch overschrijvingsbestand (X12 835) te uploaden van de betalende instantie. Je kunt dit doen door op de BROWSE knop te drukken en het juiste bestand te selecteren om te uploaden. Dan op SEARCH klikken om dit te effectueren en de daarbij behorende invoices te laten zien op het scherm. In dit geval zijn bovenstaande parameters niet nodig en worden genegeerd. Uploaden SAVE-s het bestand maar verwerkt de inhoud niet- dit wordt apart uitgevoerd zoals hier beneden beschreven'),
(19889, 330, 6, 'AM'),
(19890, 331, 6, 'AM programma'),
(19891, 332, 6, 'AMC'),
(19892, 333, 6, 'AMC vervolgen'),
(19893, 334, 6, 'AMC-2011'),
(19894, 335, 6, 'AMC-2014'),
(19895, 338, 6, 'Pas de bestaande notitie aan'),
(19896, 339, 6, 'Aanpassingen From'),
(19897, 340, 6, 'Aanpassing Status'),
(19898, 341, 6, 'Aanpassingen'),
(19899, 342, 6, 'Aanpassingen voor'),
(19900, 343, 6, 'Amerikaans Indiaan'),
(19901, 344, 6, 'Amerikaanse indiaan of Alaska geboren'),
(19902, 345, 6, 'AMEX'),
(19903, 346, 6, 'Amharic'),
(19904, 347, 6, 'Bedrag'),
(19905, 348, 6, 'Geadministreerd bedrag'),
(19906, 349, 6, 'Verschuldigd bedrag'),
(19907, 350, 6, 'Bedrag voor vorige balans'),
(19908, 351, 6, 'Bedrag voor dit bezoek'),
(19909, 352, 6, 'Bedrag betaald.'),
(19910, 353, 6, 'Aantal/Bedrag'),
(19911, 354, 6, 'Bedrag in rekening gebracht'),
(19912, 355, 6, 'Eind datum moet later zijn dan start datum om herhaling van events!'),
(19913, 356, 6, 'Ondertekenen van formulier mislukt'),
(19914, 357, 6, 'Een fout opgetreden bij dumpen LibreEHR web directorie structuur'),
(19915, 358, 6, 'Een fout opgetreden tijdens dumpen phpGACL web directorie structuur'),
(19916, 359, 6, 'Een fout opgetreden bij dumpen SQL-Ledger web directorie structuur'),
(19917, 360, 6, 'Een onvolledig GCAC "iets" is aangemaakt met een link. Moet nog later afgemaakt worden. Onvolledig.'),
(19918, 362, 6, 'Een overwachte error'),
(19919, 363, 6, 'Een hoofdletter'),
(19920, 365, 6, 'en'),
(19921, 366, 6, 'EN'),
(19922, 367, 6, 'en'),
(19923, 368, 6, 'en '),
(19924, 369, 6, 'en alle onderliggende data? Deze actie wordt vastgelegd'),
(19925, 370, 6, 'en modifier'),
(19926, 371, 6, 'en verwerkt'),
(19927, 372, 6, 'en herstart Apache-server'),
(19928, 373, 6, 'en de reden is'),
(19929, 374, 6, 'Anemie'),
(19930, 375, 6, 'Enkel'),
(19931, 376, 6, 'Enkel + hiel'),
(19932, 377, 6, 'Enkelletsel evaluatie formulier'),
(19933, 378, 6, 'Enkelproblemen'),
(19934, 379, 6, 'Ankylosis Spondilitica'),
(19935, 380, 6, 'Ankylosis Spondilitica'),
(19936, 381, 6, 'Anorexia'),
(19937, 382, 6, 'Iets anders wat je kan doen in de PostingWindow is verzoeken om een rekening op tweede niveau. Als je dit SELECTEERT voordat je opslaat, dan wordt de originele claim opnieuw geopend en als lijst op de rekeningpagina getoond en wordt deze tijdens de volgende ronde in rekening gebracht.'),
(19938, 383, 6, 'voor'),
(19939, 384, 6, 'Anus normaal, geen rectale gevoeligheid/zwelling'),
(19940, 385, 6, 'Opwinding'),
(19941, 386, 6, 'Alles'),
(19942, 387, 6, 'Welke categorie'),
(19943, 388, 6, 'Gedeelte van gewenste code of omschrijving'),
(19944, 389, 6, 'Gedeelte van gewenste specialisatie'),
(19945, 390, 6, 'Een gedeelte van medicatie ID of naam medicijn'),
(19946, 391, 6, 'Een gedeelte van vaccinatie ID of naam vaccin'),
(19947, 392, 6, 'Gedeelte naam patient of "achternm, voorn), of "X-Y"'),
(19948, 393, 6, 'Alle andere relevante informatie'),
(19949, 394, 6, 'API sleutel voor SMS toegang'),
(19950, 395, 6, 'Apnea'),
(19951, 396, 6, 'Weergave'),
(19952, 397, 6, 'Weergave:'),
(19953, 398, 6, 'Deze notitie toevoegen'),
(19954, 399, 6, 'Toevoegen aan bestaande notitie'),
(19955, 400, 6, 'Toevoegen aan deze notitie'),
(19956, 401, 6, 'Deze notitie toevoegen'),
(19957, 402, 6, 'Appendectomie'),
(19958, 404, 6, 'Toepasbaar op patienten'),
(19959, 405, 6, 'Applicatie'),
(19960, 406, 6, 'Naam van applicatie voor de login pagina an hoofd scherm titel'),
(19961, 407, 6, 'Toepassing ontvanger Code (GS03 - Indien blanco dan zal ISA08 gebruikt worden)'),
(19962, 408, 6, 'Toepassing Code afzender (GS02)'),
(19963, 409, 6, 'Naam applicatie'),
(19964, 410, 6, 'Is onderdeel van Vitals formulier en Groei-grafiek'),
(19965, 411, 6, 'Van toepassing op Vitals formulier'),
(19966, 412, 6, 'Alleen gebruiken voor deze gebeurtenis, Alleen deze EN Alle volgende gebeurtenissen, of Alle gebeurtenissen'),
(19967, 413, 6, 'Op betroffen gebied aanbrengen'),
(19968, 414, 6, 'Op de huid smeren'),
(19969, 415, 6, 'wordt toegepast'),
(19970, 416, 6, 'Patch wordt uitgevoerd op de site'),
(19971, 417, 6, 'Afspraak'),
(19972, 418, 6, 'Datum afspraak'),
(19973, 419, 6, 'Manier afsprakente tonen'),
(19974, 420, 6, 'Herinnerings afspraak regels'),
(19975, 421, 6, 'Status van afspraak'),
(19976, 422, 6, 'Status van afspraken'),
(19977, 423, 6, 'Afspraak tussen'),
(19978, 424, 6, 'Kleur voor afspraak/gebeurtenis'),
(19979, 425, 6, 'Afspraken'),
(19980, 426, 6, 'Afspraken (schrijven optioneel)'),
(19981, 427, 6, 'Afsraken (schrijven, wsome optioneel)'),
(19982, 430, 6, 'Afspraken en contacten'),
(19983, 431, 6, 'Rapport afspraken'),
(19984, 432, 6, 'Rapport afspraken-contacten'),
(19985, 434, 6, 'Accepteren Patien/Client->Import->Wacht op goedkeuring'),
(19986, 435, 6, 'Accepteren Patien/Client->Import->Wacht op goedkeuring'),
(19987, 436, 6, 'Geaccepteerd'),
(19988, 437, 6, 'Administratie van toegestane gebeurtenis(sen)'),
(19989, 438, 6, 'Met succes geaccepteerd'),
(19990, 440, 6, 'Afspr.-Cont.'),
(19991, 441, 6, 'Afspr.'),
(19992, 442, 6, 'Apr'),
(19993, 443, 6, 'April'),
(19994, 444, 6, 'Arabisch'),
(19995, 445, 6, 'Aragonees'),
(19996, 446, 6, 'Archief'),
(19997, 447, 6, 'Moeten de toegangs controle groeps namen worden vertaald?'),
(19998, 448, 6, 'Moeten de afspraak categorie namen worden vertaald?'),
(19999, 449, 6, 'Moeten de document categorie namen worden vertaald?'),
(20000, 450, 6, 'Is type in rekening gebracht?'),
(20001, 451, 6, 'Moeten de patient notities titels worden vertaald?'),
(20002, 452, 6, 'Zijn de codes opgeslagen in een externe sql tabellen (0-Nee, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2))?'),
(20003, 453, 6, 'Bent u voorbereid om een nieuwe GCAC issue voor dit bezoek af te maken?'),
(20004, 454, 6, 'Bent u er zeker van het voor vandaag te posten?'),
(20005, 455, 6, 'WIlt u zeker deze gebeurtenis goedkeuren?'),
(20006, 457, 6, 'Bent u er zeker van dit Formulier definitief te verwijderen?'),
(20007, 458, 6, 'Bent u er zeker van dit te verwijdern'),
(20008, 459, 6, 'Bent U er zeker van om deze disclosure te verwijderen'),
(20009, 460, 6, 'Zeker deze gebeurtenis verwijderen?'),
(20010, 461, 6, 'Weet u zeker dat u dit item wilt verwijderen uit de database?'),
(20011, 462, 6, 'Bent u er zeker van deze notitie te verwijderen?'),
(20012, 464, 6, 'Zeker deze gebeurtenis aanpassen?'),
(20013, 465, 6, 'Zeker deze gebeurtenissen verbergen?'),
(20014, 466, 6, 'Wilt u dit opnieuw verzenden?'),
(20015, 467, 6, 'Zeker deze gebeurtenis(sen) inzien?'),
(20016, 468, 6, 'Gaat u de hele groep verwijderen met de volgende naam'),
(20017, 469, 6, 'Weet u zeker dat u de gehele lijst wilt verwijderen'),
(20018, 470, 6, 'Weet u zeker dat u het veld wilt verwijderen in'),
(20019, 471, 6, 'Wilt u zeker de geselecteerde velden verwijderen?'),
(20020, 472, 6, 'Weet u zeker dat u met deze acties wilt doorgaan?'),
(20021, 473, 6, 'Gebied niet nader gespecificeerd'),
(20022, 474, 6, 'Arm'),
(20023, 475, 6, 'Armeens'),
(20024, 477, 6, 'Arytmie'),
(20025, 478, 6, 'Artritis'),
(20026, 479, 6, 'Artritis/degeneratieve gewr. aandoening'),
(20027, 480, 6, 'Artritis/degeneratieve gewr. aandoening'),
(20028, 481, 6, 'als'),
(20029, 482, 6, 'vanaf'),
(20030, 483, 6, 'ASC'),
(20031, 484, 6, 'Aziatisch'),
(20032, 485, 6, 'Assamese'),
(20033, 487, 6, 'Evaluatie'),
(20034, 488, 6, 'Toegewezen aan'),
(20035, 489, 6, 'Assistent'),
(20036, 490, 6, 'Astma'),
(20037, 491, 6, 'bij'),
(20038, 492, 6, 'U moet er minstens eentje kiezen als u "ALL" kiest'),
(20039, 493, 6, 'Bij de naviculare'),
(20040, 494, 6, 'Bij de naviculare:'),
(20041, 495, 6, 'Atletiek team'),
(20042, 496, 6, 'Atletiek team'),
(20043, 497, 6, 'Sportblessure'),
(20044, 498, 6, 'ATNA audit CA certificaat'),
(20045, 499, 6, 'ATNA audit host'),
(20046, 500, 6, 'ATNA audit voor lokaal certificaat'),
(20047, 501, 6, 'ATNA audit poort'),
(20048, 503, 6, 'Attentie'),
(20049, 504, 6, 'Attn'),
(20050, 506, 6, 'Audit CDR Engine Queries'),
(20051, 507, 6, 'Gerommel met de Audit log'),
(20052, 508, 6, 'Rapport van gerommel met Audit log'),
(20053, 509, 6, 'Audit log Backups'),
(20054, 510, 6, 'Audit log Diversen'),
(20055, 511, 6, 'Audit log orde'),
(20056, 512, 6, 'Audit log Pt.status'),
(20057, 513, 6, 'Audit log schema'),
(20058, 514, 6, 'Audit log veiligheid administratie'),
(20059, 515, 6, 'Audit log SELECT query'),
(20060, 516, 6, 'Aug'),
(20061, 517, 6, 'Augustus'),
(20062, 519, 6, 'Aut'),
(20063, 520, 6, 'Aut/Notities'),
(20064, 523, 6, 'Autorisatie groep'),
(20065, 524, 6, 'Status betreffende autorisatie'),
(20066, 525, 6, 'Autorisatie'),
(20067, 526, 6, 'Autoriseer'),
(20068, 527, 6, 'Autoriseer - consult naar keuze'),
(20069, 528, 6, 'Autoriseer - consulten alleen van mij'),
(20070, 529, 6, 'Authorize.net'),
(20071, 530, 6, 'Geautoriseerd'),
(20072, 531, 6, 'Alleen geautoriseerd'),
(20073, 532, 6, 'Direct zenden'),
(20074, 535, 6, 'Nieuwe encounters automatisch aanmaken'),
(20075, 536, 6, 'Zelf gegenereerd'),
(20076, 537, 6, 'Automatische meetgegevens en berekingnen (AMC)'),
(20077, 538, 6, 'Automatische meetgegevens en berekingnen (AMC) - 2011'),
(20078, 539, 6, 'Automatische meetgegevens en berekingnen (AMC) - 2014'),
(20079, 542, 6, 'Automatische meetgegevens en berekingnen (AMC) vervolgen'),
(20080, 543, 6, 'Automatische meetgegevens (AMC)'),
(20081, 544, 6, 'Automatisch'),
(20082, 546, 6, 'Maak automatisch een nieuwe afspraak als de indicator op "@" (aangekomen is gezet)'),
(20083, 549, 6, 'Automobiel medisch'),
(20084, 550, 6, 'autosaved'),
(20085, 551, 6, 'Beschikbare categorieen'),
(20086, 552, 6, 'Beschikbare tijden'),
(20087, 553, 6, 'Beschikbare te volgen paden'),
(20088, 554, 6, 'Avarisch'),
(20089, 555, 6, 'Avery Label type om patienten lagbels te printen van Pop-ups in het linker navigatie scherm'),
(20090, 556, 6, 'Avestaans'),
(20091, 557, 6, 'Maandgemiddelde'),
(20092, 558, 6, 'Avulsie / avulsie fractuur'),
(20093, 559, 6, 'Avulsie laterale malleolus'),
(20094, 560, 6, 'Avulsie mediale malleolus '),
(20095, 561, 6, 'Op basis van waarneming'),
(20096, 562, 6, 'Axillair'),
(20097, 563, 6, 'Aymaraans'),
(20098, 564, 6, 'Azerbaadjaans'),
(20099, 565, 6, '2 x daags'),
(20100, 566, 6, 'Terug'),
(20101, 567, 6, 'terug'),
(20102, 568, 6, 'Acht consultaties terug'),
(20103, 569, 6, 'Elf consutaties terug'),
(20104, 570, 6, 'Vijf consultaties terug'),
(20105, 571, 6, 'Vier consultaties terug'),
(20106, 572, 6, 'Negen consultaties terug'),
(20107, 573, 6, 'Eén consultatie terug'),
(20108, 574, 6, 'Rug pijn'),
(20109, 575, 6, 'Rugproblemen'),
(20110, 576, 6, 'Zeven consutaties terug'),
(20111, 577, 6, 'Zes consultaties terug'),
(20112, 578, 6, 'Rug chirurgie'),
(20113, 579, 6, 'Tien consultaties terug'),
(20114, 580, 6, 'Drie consultaties terug'),
(20115, 581, 6, 'Terug naar Admin pagina'),
(20116, 582, 6, 'Terug naar encounter'),
(20117, 583, 6, 'Terug naar patient'),
(20118, 584, 6, 'Terug naar patient'),
(20119, 585, 6, 'Terug naar Users'),
(20120, 586, 6, 'Terug naar weergave'),
(20121, 587, 6, 'Twaalf consultaties terug'),
(20122, 588, 6, 'Twee bezoeken terug'),
(20123, 589, 6, 'Background Services'),
(20124, 590, 6, 'Back-up'),
(20125, 591, 6, 'Backupbestand is aangemaakt. Downloaden begint.'),
(20126, 592, 6, 'Backup lijst'),
(20127, 593, 6, 'Backup is met succes binnen gekomen'),
(20128, 594, 6, 'Ongedekte cheque'),
(20129, 595, 6, 'Achterstallige schulden'),
(20130, 596, 6, 'Bahasa Indonesisch'),
(20131, 597, 6, 'Bal'),
(20132, 598, 6, 'Balans'),
(20133, 599, 6, 'Uitstaande schuld'),
(20134, 600, 6, 'Balans van te betalen'),
(20135, 601, 6, 'Te betalen'),
(20136, 602, 6, 'Bambaraans'),
(20137, 603, 6, 'Bank-wissel'),
(20138, 604, 6, 'Barcode Label'),
(20139, 605, 6, 'Barcode label type'),
(20140, 606, 6, 'Barcode type om barcode labels te printen van linker menu scherm'),
(20141, 607, 6, 'Basis metatarsale 5'),
(20142, 608, 6, 'Basis metatarsale 5:'),
(20143, 609, 6, 'Bashkir'),
(20144, 610, 6, 'Baskisch'),
(20145, 611, 6, 'Batch Claim'),
(20146, 612, 6, 'Gereedschap voor batch-communicatie'),
(20147, 613, 6, 'Betalingen invoer dmv groepen'),
(20148, 614, 6, 'Overzicht betalingen'),
(20149, 615, 6, 'Batch-verwerking begonnen, kan even duren'),
(20150, 616, 6, 'Batch-resultaten'),
(20151, 617, 6, 'BatchCom'),
(20152, 618, 6, 'Geduld het kan enkele minuten duren om sommige files te verwerken!'),
(20153, 619, 6, 'omdat dat ID niet bestaat.'),
(20154, 620, 6, 'Start'),
(20155, 621, 6, 'Startdatum'),
(20156, 623, 6, 'Begindatum Service jjjj-mm-dd'),
(20157, 624, 6, 'Start uur voor begin dv/d dag voor de kalender.'),
(20158, 625, 6, 'Belarusisch'),
(20159, 626, 6, 'Oprispingen'),
(20160, 628, 6, 'Bengaals'),
(20161, 629, 6, 'Bengali - Bangla'),
(20162, 630, 6, 'tussen'),
(20163, 631, 6, 'In beide richtingen'),
(20164, 632, 6, 'Bihari'),
(20165, 633, 6, 'Beide kanten'),
(20166, 634, 6, 'Beide kanten:'),
(20167, 636, 6, 'Datum rekening:'),
(20168, 637, 6, 'Rekening/Innen'),
(20169, 638, 6, 'In rekening gebracht'),
(20170, 640, 6, 'Rekening aanmaken'),
(20171, 641, 6, 'In rekening brengen (met schrijf optie)'),
(20172, 642, 6, 'Rekening t.a.v.'),
(20173, 644, 6, 'Rekening code voor aangevraagde Service'),
(20174, 645, 6, 'Codering voor rekeningen'),
(20175, 646, 6, 'Datum versturen rekeningen'),
(20176, 647, 6, 'Financiele administratie'),
(20177, 648, 6, 'Kliniek om rekeningen aan te maken'),
(20178, 649, 6, 'Rekeninginformatie'),
(20179, 650, 6, 'Rekeninglokatie'),
(20180, 655, 6, 'Rekeningen Manager'),
(20181, 656, 6, 'Rekeningnotitie'),
(20182, 657, 6, 'Rekeningnotitie voor '),
(20183, 658, 6, 'Rekeningnotitie:'),
(20184, 659, 6, 'Rekeningwachtrij resultaat:'),
(20185, 660, 6, 'Rekeningenscherm'),
(20186, 661, 6, 'Rekeningen status'),
(20187, 662, 6, 'Rekening status = niet aangemaakt'),
(20188, 663, 6, 'Rekening voor '),
(20189, 665, 6, 'Biopsie'),
(20190, 666, 6, 'Geb. datum'),
(20191, 667, 6, 'Geb, 0 tot 24 maanden'),
(20192, 668, 6, 'Bislama'),
(20193, 669, 6, 'Negroide'),
(20194, 670, 6, 'Zwarte long'),
(20195, 671, 6, 'African Amrerican'),
(20196, 672, 6, 'Blaaskanker'),
(20197, 673, 6, 'Blaasinfectie'),
(20198, 674, 6, 'Lege formulieren'),
(20199, 675, 6, 'Problemen met bloedingen'),
(20200, 676, 6, 'Blinde vlekken'),
(20201, 677, 6, 'Opzwellen'),
(20202, 678, 6, 'Geblokkeerd'),
(20203, 679, 6, 'Bloed'),
(20204, 680, 6, 'Bloeddruk'),
(20205, 681, 6, 'Bloeddruk'),
(20206, 682, 6, 'Bloedneus'),
(20207, 683, 6, 'Blue Cross Blue Shield'),
(20208, 684, 6, 'Blauwe lijnen in dit verslag zijn informeel. Zwarte lijnen tonen vooraf bestaande informatie. Groene lijnen tonen veranderingen die met succes werden doorgevoerd. Rode lijnen tonen fouten of veranderingen die niet doorgevoerd werden; deze moeten handmatig doorgevoerd worden. De afgewezen claims en teruggevorderd geld worden niet automatisch verwerkt en worden in rood getoond.'),
(20209, 685, 6, 'Wazig zien'),
(20210, 686, 6, 'BMI'),
(20211, 687, 6, 'BMI-waarde'),
(20212, 689, 6, 'Gebied van het lichaam'),
(20213, 690, 6, 'Kant van lichaam'),
(20214, 691, 6, 'Kant van lichaam, indien van toepassing'),
(20215, 692, 6, 'Botpijn'),
(20216, 693, 6, 'Botpijn: mediale malleolus'),
(20217, 694, 6, 'Boolean'),
(20218, 695, 6, 'Bosnisch'),
(20219, 696, 6, 'Laag'),
(20220, 697, 6, 'Beide oren'),
(20221, 698, 6, 'beide oren'),
(20222, 699, 6, 'Laag'),
(20223, 700, 6, 'Kantlijn onderkant (px)'),
(20224, 701, 6, 'Box 10 A Werk gerelateerd '),
(20225, 702, 6, 'Box 10 B Auto ongeval '),
(20226, 703, 6, 'Box 10 C Ander ongeval '),
(20227, 704, 6, 'BOX 14 qualifier'),
(20228, 705, 6, 'BOX 15 Andere datum Qualifier'),
(20229, 706, 6, 'Box 15. Datum van zelfde of vergelijkbare ziekte (jjjj-mm-dd):'),
(20230, 707, 6, 'BOX 15. Datum van zelfde of vergelijkbare ziekte/of andere datum (jjjj-mm-dd):'),
(20231, 708, 6, 'Box 16 Begindatum arbeidsongeschiktheid (jjjj-mm-dd):'),
(20232, 709, 6, 'Box 16 Datum AO tot (jjjj-mm-dd):'),
(20233, 710, 6, 'Box 18 Opname in hospitaal (jjjj-mm-dd): '),
(20234, 711, 6, 'Box 18 Laatste dag in hospitaal (jjjj-mm-dd) '),
(20235, 712, 6, 'Box 20 Extern Laboratorium gebruikt?'),
(20236, 713, 6, 'Box 22 Medicaide Code om opnieuw te sturen (ICD-9) '),
(20237, 714, 6, 'Box 23 Vorige autorisatienummer '),
(20238, 715, 6, 'RR'),
(20239, 716, 6, 'Diastolische RR'),
(20240, 717, 6, 'Systolische RR'),
(20241, 719, 6, 'RR-D'),
(20242, 721, 6, 'RR-S'),
(20243, 722, 6, 'Braziliaans-Portugees'),
(20244, 723, 6, 'Mamma'),
(20245, 724, 6, 'Biopsie van mamma'),
(20246, 725, 6, 'Afscheiding mamma'),
(20247, 726, 6, 'Ziekte van de mammae'),
(20248, 727, 6, 'Borstonderzoek'),
(20249, 728, 6, 'Massa in mamma'),
(20250, 730, 6, 'Ademgeluiden:'),
(20251, 731, 6, 'Bretons'),
(20252, 732, 6, 'Gebroken botten'),
(20253, 733, 6, 'niet functionerend formulier'),
(20254, 734, 6, 'Bronchitis formulier'),
(20255, 735, 6, 'Doorzoeken'),
(20256, 736, 6, 'Zoek naar status'),
(20257, 737, 6, 'Kneuzing/Hematoom'),
(20258, 738, 6, 'Bulgaars'),
(20259, 739, 6, 'Uitpuilend rechts:'),
(20260, 740, 6, 'Birmanees'),
(20261, 741, 6, 'Brandende mictie'),
(20262, 742, 6, 'Brandende mictie'),
(20263, 743, 6, 'Kantoor telefoon'),
(20264, 744, 6, 'Bezig'),
(20265, 745, 6, 'maar nog niet verwerkt.'),
(20266, 746, 6, 'Zitvlak'),
(20267, 747, 6, 'Zitvlak + S.I.'),
(20268, 748, 6, 'dmv'),
(20269, 749, 6, 'Door'),
(20270, 750, 6, 'Oraal'),
(20271, 751, 6, 'Door/Oorsprong'),
(20272, 752, 6, 'Door:'),
(20273, 753, 6, 'C'),
(20274, 754, 6, 'CA certificaat om RFC 5425 TLS syslog te controleren.'),
(20275, 755, 6, 'Cache duur (in seconden)'),
(20276, 756, 6, 'Cache template output?'),
(20277, 757, 6, 'Cafeineconsumptie'),
(20278, 758, 6, 'Agenda'),
(20279, 759, 6, 'Uur voor beeindigen van kalender afspraken'),
(20280, 760, 6, 'Interval voor kalender'),
(20281, 761, 6, 'Kalender scherm'),
(20282, 762, 6, 'Agenda-instellingen'),
(20283, 763, 6, 'Begin uur van kalender'),
(20284, 764, 6, 'Agenda-UI'),
(20285, 765, 6, 'Agendaweergave'),
(20286, 766, 6, 'Oproepen van addForm() komt hier terecht'),
(20287, 767, 6, 'Calorien'),
(20288, 768, 6, 'Cambodja'),
(20290, 774, 6, 'Annuleren'),
(20291, 775, 6, 'Niet opslaan'),
(20292, 776, 6, 'Geannuleerd'),
(20293, 777, 6, 'Kanker'),
(20294, 778, 6, 'Ca screening: Colon screening'),
(20295, 779, 6, 'Ca screening: Mammogram'),
(20296, 780, 6, 'Ca screening: Pap smear'),
(20297, 781, 6, 'Ca screening: Prostaat'),
(20298, 782, 6, 'Kan deze invoer niet toevoegen, omdat hij reeds bestaat!'),
(20299, 783, 6, 'Kan deze invoer niet toevoegen/updaten omdat er al een duplicaat bestaat!'),
(20300, 784, 6, 'kan niet gearchiveerd worden, niets gedaan'),
(20301, 785, 6, 'kan niet naar JPEG omgezet worden. Is ImageMagick wel geinstalleerd?'),
(20302, 786, 6, 'kan niet verwijdert worden, niets gedaan'),
(20303, 787, 6, 'kan niet inline getoond worden, dit type wordt niet ondersteund door BROWSER'),
(20304, 788, 6, 'kan niet inline getoond worden, dit type wordt niet ondersteund door BROWSER'),
(20305, 789, 6, 'kan niet inline getoond worden, dit type wordt niet ondersteund door BROWSER.'),
(20306, 790, 6, 'Aanmaken mislukt'),
(20307, 791, 6, 'Kan de file niet aanmaken'),
(20308, 792, 6, 'Kan de file niet verwijderen (van de SMTP server)'),
(20309, 793, 6, 'Kan de file niet deleten'),
(20310, 794, 6, 'Kan de doel file niet localiseren'),
(20311, 795, 6, 'Zoeken mislukt '),
(20312, 796, 6, 'Kan geen bestemmings file naam vinden'),
(20313, 799, 6, 'Patient kan niet gevonden worden in SQL-boekhouding via Klant ID'),
(20314, 800, 6, 'Postscript documentreferentie niet gevonden in '),
(20315, 801, 6, 'Behandelaar kan niet gevonden worden in werknemers SQL boekhouding '),
(20316, 802, 6, 'Kan betalingen niet veranderen. Niet utigewerkt is Negatief.'),
(20317, 803, 6, 'Openen mislukt '),
(20318, 804, 6, 'Kan niet toewijzen aan Verzekering. De geselecteerde instantie instantie waarvoor u koos is patient.'),
(20319, 805, 6, 'Kan niet toewijzen aan patient. De geselecteerde instantie is Verzekering'),
(20320, 806, 6, 'Kan geen betalingen toewijzen. Niet toegewezen is Negatief'),
(20321, 807, 6, 'Kan niet lezen'),
(20322, 808, 6, 'Kan DIRECTORY niet lezen'),
(20323, 809, 6, 'Updaten mislukt omdat er geen bestaande entiteit wordt bewerkt'),
(20324, 810, 6, 'Hoofdletters maken'),
(20325, 811, 6, 'Allemaal hoofdletters'),
(20326, 812, 6, 'capsule'),
(20327, 813, 6, 'Kaart'),
(20328, 814, 6, 'Hartcatheterisatie'),
(20329, 815, 6, 'Echo van het hart'),
(20330, 816, 6, 'Cardiovasculair'),
(20331, 821, 6, 'Kraakbeen/chondraal/beschadiging tussenwervelschijf'),
(20332, 822, 6, 'Kraakbeenbeschadiging'),
(20333, 823, 6, 'Carotiden puls. normaal, voetrug puls. normaal'),
(20334, 824, 6, 'contant'),
(20335, 825, 6, 'Contant'),
(20336, 826, 6, 'Per Kas ontv.'),
(20337, 827, 6, 'Kwitanties per behandelaar'),
(20338, 828, 6, 'Caqtalaans - Valenciaans'),
(20339, 829, 6, 'Cataractoperatie'),
(20340, 830, 6, 'Cataracten'),
(20341, 831, 6, 'Categorieen'),
(20342, 832, 6, 'Categorieen voor'),
(20343, 833, 6, 'Categorie'),
(20344, 834, 6, 'categorie'),
(20345, 835, 6, 'Categorie '),
(20346, 836, 6, 'Categorie details'),
(20347, 837, 6, 'Categorie limieten'),
(20348, 838, 6, 'Categorie naam'),
(20349, 839, 6, 'Categorie naam niet ingevuld'),
(20350, 840, 6, 'Categorie/Titel'),
(20351, 841, 6, 'Caucasisch'),
(20352, 842, 6, 'Zorgt voor printen van Encounter/Eerste Provider informatie'),
(20353, 846, 6, 'CCR- goedkeuren'),
(20354, 847, 6, 'CCR Patient review'),
(20355, 848, 6, 'CCR Review en goedkeuren'),
(20356, 850, 6, 'CDR'),
(20357, 851, 6, 'CDR rapport verwerkings voorkeur'),
(20358, 852, 6, 'Mobiel nummer'),
(20359, 853, 6, 'Mobiel nummer'),
(20360, 854, 6, 'Mobiel nummer'),
(20361, 855, 6, 'Mobiel nummer'),
(20362, 856, 6, 'Centrale Certificering'),
(20363, 857, 6, 'Centraal/Zuid Amerikaan'),
(20364, 858, 6, 'Certificate Authority crt file locatie kan niet leeg zijn'),
(20365, 859, 6, 'Locatie sleutelbestand van autorisatiecertificaat mag niet leeg zijn'),
(20366, 860, 6, 'Certificaat om naar RFC 5425 TLS syslog server te sturen'),
(20367, 861, 6, 'Certificaat gebruiker'),
(20368, 862, 6, 'Certificaat'),
(20369, 863, 6, 'Chamorro'),
(20370, 864, 6, 'ChampUS'),
(20371, 865, 6, 'ChampUSVA'),
(20372, 866, 6, 'wijzig'),
(20373, 867, 6, 'Verandering'),
(20374, 868, 6, 'Wijzig activiteit'),
(20375, 869, 6, 'Verandering mislukt! Is er een Couch DB connectie fout?'),
(20376, 870, 6, 'Verandering in visus'),
(20377, 871, 6, 'Verandering visus'),
(20378, 872, 6, 'Paswoord veranderen'),
(20379, 874, 6, 'Gewijzigd'),
(20380, 875, 6, 'Veranderd def patroon'),
(20381, 876, 6, 'Verandering van Patient ID voor dit document'),
(20382, 877, 6, 'Karakteristieken'),
(20383, 878, 6, 'Resterend aantal karakters'),
(20384, 879, 6, 'In rekening brengen'),
(20385, 880, 6, 'Breng aanpassing in rekening'),
(20386, 881, 6, 'Tarief gecodeerd'),
(20387, 882, 6, 'Kosten'),
(20388, 883, 6, 'Kaart'),
(20389, 884, 6, 'Status activiteit'),
(20390, 885, 6, 'Status IN/OUT activiteit rapport'),
(20391, 886, 6, 'Statusnummer'),
(20392, 887, 6, 'Statusnummer:'),
(20393, 888, 6, 'Kaart label'),
(20394, 889, 6, 'Status locatie'),
(20395, 890, 6, 'Notitie voor status'),
(20396, 891, 6, 'Kaart nummer'),
(20397, 892, 6, 'Plaats van status'),
(20398, 893, 6, 'Lokatie v/d status'),
(20399, 894, 6, 'Kaart trk'),
(20400, 895, 6, 'Kaarten uitgechecked'),
(20401, 896, 6, 'Kaarten uit'),
(20402, 897, 6, 'Controleren'),
(20403, 898, 6, 'Controle'),
(20404, 899, 6, 'controle'),
(20405, 900, 6, 'Alles selecteren'),
(20406, 902, 6, 'Controleer bedrag'),
(20407, 903, 6, 'Datum van check'),
(20408, 904, 6, 'Controleer verschillen met de eigen taaltabel'),
(20409, 906, 6, 'Nieuwe locatie'),
(20410, 907, 6, 'Check ingevoerde data'),
(20411, 908, 6, 'Vink de onderdelen aan om te volgen'),
(20412, 909, 6, 'Controleer de LAB resutaten'),
(20413, 910, 6, 'Met aanvinken is gecontroleerd'),
(20414, 911, 6, 'Check No.'),
(20415, 912, 6, 'Chequenummer'),
(20416, 915, 6, 'Controleer betaling'),
(20417, 916, 6, 'Box vinken indine de file gecodeerd is'),
(20418, 917, 6, 'Check hier om afspraken van alle behandelaars tegelijk te zien en niet alleen eigen afspraken'),
(20419, 918, 6, 'Aanvinken om probleem van de diagnose aan te maken'),
(20420, 919, 6, 'Check/EOB Datum:'),
(20421, 920, 6, 'Check/EOB No.:'),
(20422, 921, 6, 'Check/Ref.nummer'),
(20423, 922, 6, 'Check/Referentienummer'),
(20424, 923, 6, 'Checkbox lijst'),
(20425, 924, 6, 'checkbox lijst'),
(20426, 925, 6, 'checkbox met tekst'),
(20427, 926, 6, 'Checkbox met tekst'),
(20428, 927, 6, 'Vink blok aan om HL7 file te verwerpen en te verwijderen'),
(20429, 928, 6, 'Gecontroleerd'),
(20430, 929, 6, 'Aangevinkte box=ja, leeg=nee'),
(20431, 931, 6, 'Aanvinken van het lock vakje verhindert verdere aanpassingen van ieder formulier voor deze encopunter');
INSERT INTO `lang_definitions` VALUES
(20432, 932, 6, 'Vertrek'),
(20433, 933, 6, 'Controlecijfer'),
(20434, 934, 6, 'Thorax'),
(20435, 935, 6, 'Thorax CTAB'),
(20436, 936, 6, 'Pijn in thorax'),
(20437, 937, 6, 'Pijn in thorax'),
(20438, 938, 6, 'Pijn in thorax'),
(20439, 940, 6, 'Chg'),
(20440, 941, 6, 'Chichewa-Chewa-Nyanja'),
(20441, 942, 6, 'Hoofd klacht'),
(20442, 943, 6, 'Kind'),
(20443, 945, 6, 'Immunisatie status van kinderen (CQM)'),
(20444, 946, 6, 'Rillingen'),
(20445, 947, 6, 'Chinees'),
(20446, 948, 6, 'Chinese (vereenvoudigd)'),
(20447, 949, 6, 'Chinese (traditioneel)'),
(20448, 950, 6, 'Chiropractisch'),
(20449, 951, 6, 'Keuzes'),
(20450, 952, 6, 'Cholecystectomie'),
(20451, 953, 6, 'cholecystectomie'),
(20452, 954, 6, 'Cholecystectomie'),
(20453, 955, 6, 'Kies'),
(20454, 956, 6, 'Maak een keuze en KLIK op het onderdeel, in de andere sectie zie je de gerelateerde zaken en kan in dat deel KLIKKEN voor relaties toevoegen of verwijderen'),
(20455, 957, 6, 'Kies LIJST'),
(20456, 958, 6, 'Kies downloaden of Inline tonen'),
(20457, 959, 6, 'Kies file'),
(20458, 960, 6, 'Kies van de lijst'),
(20459, 961, 6, 'Kies de layout richting'),
(20460, 962, 6, 'Kies een lijst'),
(20461, 963, 6, 'Kiez papier maat'),
(20462, 964, 6, 'Kies PDF taal voorkeur'),
(20463, 965, 6, 'Kies Print format voor verslag van deze encounter.'),
(20464, 967, 6, 'Chronische bronchitis'),
(20465, 968, 6, 'Chronische gewrichts pijn'),
(20466, 969, 6, 'Chronische nier ziekte (CKD)'),
(20467, 970, 6, 'Chronische synovitis / opzwellen / gewrichtspijn / jicht'),
(20468, 971, 6, 'Chronisch/Recidiverend'),
(20469, 972, 6, 'Chuvash'),
(20470, 973, 6, 'Levercirrose'),
(20471, 974, 6, 'Levercirrose'),
(20472, 975, 6, 'Stad'),
(20473, 976, 6, 'Naam vd stad'),
(20474, 977, 6, 'Stad, Staat'),
(20475, 978, 6, 'Stad, Zip code'),
(20476, 979, 6, 'Stad/Staat'),
(20477, 980, 6, 'Tegoed'),
(20478, 981, 6, 'Tegoed '),
(20479, 982, 6, 'Claim status'),
(20480, 983, 6, 'Tegoed test is aangemaakt en klaar'),
(20481, 984, 6, 'Soort claim'),
(20482, 985, 6, 'Claim werd aangemaakt in file'),
(20483, 986, 6, 'Claim werd aangemaakt in file '),
(20484, 987, 6, 'Claims'),
(20485, 988, 6, 'Classificatie'),
(20486, 989, 6, 'Schonen'),
(20487, 990, 6, 'Actieve patient schonen'),
(20488, 991, 6, 'Alles verwijderen'),
(20489, 992, 6, 'HL7-data verwijderen'),
(20490, 993, 6, 'Justify verwijderen'),
(20491, 994, 6, 'Smarty Cache schonen'),
(20492, 995, 6, 'Clearinghouse info nodig om EDI 270 batch aan te maken'),
(20493, 996, 6, 'CLIA-nummer'),
(20494, 997, 6, 'Klik'),
(20495, 998, 6, 'Klik op "Exporteren" om uw categorie, subcategorie, punt, Inhoud gegevens naar een tekstbestand te exporteren. Elke gelijkenis van dit bestand naar een XML-bestand is louter toevallig. Het openen en sluiten van tags moeten op dezelfde lijn, zij worden kleine letters zonder spaties. Om te importeren, blader naar een bestand en klik op ''import'' Als de gegevens volledig anders zijn, worden ze samengevoegd met uw bestaande gegevens. Als er soortgelijk artikel namen zijn, worden de oude behouden en de nieuwe opgeslagen met een nummer toegevoegd aan het einde.'),
(20496, 999, 6, 'Klik op regio van de tekening om pijn aan te geven. Klik op zelfde plek om te verwijderen, of op nieuwe regio om nieuwe plek aan te geven.'),
(20497, 1000, 6, 'Klik op Certificaten downloaden om de certificaten in het ssl.zip-bestand te downloaden'),
(20498, 1001, 6, 'klik voor meer'),
(20499, 1002, 6, 'Klik voor meer details'),
(20500, 1003, 6, 'Klik voor samenvattting bestalling'),
(20501, 1004, 6, 'klik voor resultaten'),
(20502, 1005, 6, 'Klik hier'),
(20503, 1006, 6, 'Klik hier om nieuwe client toe te voegen.'),
(20504, 1007, 6, 'Klik hier om nieuw ongeval veranderingen te melden en dagelijkse activiteiten aan te passen'),
(20505, 1008, 6, 'Klik hier om datum te kiezen'),
(20506, 1009, 6, 'Klik hier om datum en tijd te kiezen'),
(20507, 1010, 6, 'Klik hier om startdatum te kiezen'),
(20508, 1011, 6, 'Klik hier om datum tijd te kiezen'),
(20509, 1012, 6, 'Klik hier om datum tijd te kiezen van'),
(20510, 1013, 6, 'Klik hier om datum tijd te kiezen voor'),
(20511, 1014, 6, 'Klik hier om deze module aan te passen'),
(20512, 1016, 6, 'Klik hier om deze module te inactiveren'),
(20513, 1018, 6, 'klik hier om deze module te activeren'),
(20514, 1019, 6, 'Klik hier om deze module te installeren'),
(20515, 1020, 6, 'Klik hier om te zoeken'),
(20516, 1021, 6, 'Klik hier voor aanpassing van Belangrijkheid, Categorie en getoonde veldnamen'),
(20517, 1022, 6, 'Klik hier om alles te zien'),
(20518, 1023, 6, 'Klik hier om grafiek te zien'),
(20519, 1024, 6, 'Klik hier om alle Labdata te zien en in grafieken te tonen'),
(20520, 1025, 6, 'Klik hier om all Vitals in grafiek te zetten'),
(20521, 1026, 6, 'Klik hier om patient details te zien'),
(20522, 1027, 6, 'Klik hier om ze allemaal te zien'),
(20523, 1028, 6, 'Klik om details: te zien/aan te passen'),
(20524, 1029, 6, 'Klik Install buttom om de database van de volgende datum te installeren'),
(20525, 1030, 6, 'Klik op tijdgedeelte om het te vergroten'),
(20526, 1031, 6, 'Klik op patientnaam om file te openen'),
(20527, 1032, 6, 'Klik vernieuwen om alle resultaten te zien, of voer nieuwe zoek criteria in om specifieke resultaten te zien.'),
(20528, 1033, 6, 'Klik om diagnose aan te maken'),
(20529, 1034, 6, 'Klik om nieuwe componenten aan te maken'),
(20530, 1035, 6, 'Klik om nieuw const aan te maken'),
(20531, 1036, 6, 'Klik om een keuze te maken om Diagnoses to `justify`'),
(20532, 1037, 6, 'Klik om te downloaden'),
(20533, 1038, 6, 'Klik om aan te passen'),
(20534, 1039, 6, 'Klik om omschrijving aan te passen'),
(20535, 1040, 6, 'Klik om deze gebeurtenis aan te passen'),
(20536, 1041, 6, 'Klik om rapport te maken'),
(20537, 1042, 6, 'Klik om een patient te matchen'),
(20538, 1043, 6, 'Klik om af te drukken'),
(20539, 1044, 6, 'Kilk om een nieuwe voorraad te ontvangen/toe te voegen'),
(20540, 1045, 6, 'Klik om te selecteren'),
(20541, 1046, 6, 'Klik om te selecteren'),
(20542, 1047, 6, 'Klik om een standaard industriecode voor deze procedure te selecteren'),
(20543, 1048, 6, 'Klik om optimale procedure code te selecteren'),
(20544, 1049, 6, 'Klik  om verandering in Procedure codering te selecteren.'),
(20545, 1050, 6, 'Klik om de CVX code te selecteren of te veranderen'),
(20546, 1051, 6, 'Klik om te selecteren of de diagnose te veranderen'),
(20547, 1052, 6, 'Klik om service code te selecteren of te veranderen'),
(20548, 1053, 6, 'Klik om patient te selecteren'),
(20549, 1054, 6, 'Klik om de gerelateerde code te selecteren'),
(20550, 1055, 6, 'Klik om services kiezen als het resultaat abnormaal is'),
(20551, 1056, 6, 'Klik om de gewenste procedure te selecteren'),
(20552, 1057, 6, 'Klik om te sorteren'),
(20553, 1058, 6, 'Klik om te kijken'),
(20554, 1059, 6, 'Klik om te bekijken of aan te passen'),
(20555, 1060, 6, 'Klik om te bekijken/veranderen'),
(20556, 1061, 6, 'Klik op upgrade button om de databse van de volgende datum op te waarderen'),
(20557, 1062, 6, 'Klik waar aangegeven wordt om de patient te matchen.'),
(20558, 1063, 6, 'Klik:'),
(20559, 1064, 6, 'Client Certificaat Expiratietijd in dgn'),
(20560, 1065, 6, 'Validatieperiode voor Client Certificaat'),
(20561, 1066, 6, 'Validatie voor Client Certificaat moet een geldig getal zijn.'),
(20562, 1067, 6, 'Copie voor client'),
(20563, 1069, 6, 'Samenvatting med. historie client'),
(20564, 1070, 6, 'Naam van Client'),
(20565, 1071, 6, 'Nummer van Client'),
(20566, 1072, 6, 'Cliëntprofiel - Nieuwe clienten'),
(20567, 1073, 6, 'Cliëntprofiel - Unieke clienten'),
(20568, 1074, 6, 'Cliënten'),
(20569, 1075, 6, 'Kliniek'),
(20570, 1076, 6, 'Copie voor Kliniek'),
(20571, 1077, 6, 'Dagoverzicht kliniek'),
(20572, 1078, 6, 'ID van Locatie'),
(20573, 1079, 6, 'Klinisch'),
(20574, 1080, 6, 'Regels voor beslissingen via de alert manager'),
(20575, 1081, 6, 'Klinische historie'),
(20576, 1083, 6, 'Plannen voor klinische veranderingen'),
(20577, 1084, 6, 'Meting van veranderingen in kwaliteits metingen (CQM)'),
(20578, 1085, 6, 'Meting van veranderingen in kwaliteits metingen (CQM) - 2011'),
(20579, 1086, 6, 'Meting van veranderingen in kwaliteits metingen (CQM) - 2014'),
(20580, 1087, 6, 'Klinische reminders'),
(20581, 1088, 6, 'Klinische rapportage'),
(20582, 1089, 6, 'Categorie voor klinische Rule Action'),
(20583, 1090, 6, 'Klinische regels Actie onderdeel'),
(20584, 1091, 6, 'Filter methode voor Klinische regels'),
(20585, 1092, 6, 'Doel gerichte methode voor Klinische regels'),
(20586, 1093, 6, 'Klinische regels'),
(20587, 1094, 6, 'Klinische leeftijds interval regels'),
(20588, 1095, 6, 'Klinische regel vergelijkingen'),
(20589, 1096, 6, 'Klinishe regels voor encounter types'),
(20590, 1097, 6, 'Klinische regels voor reminder opties'),
(20591, 1098, 6, 'Klinische regels voor inactivatie mogelijkheden'),
(20592, 1099, 6, 'Klinische regels voor oproep intervallen'),
(20593, 1100, 6, 'Klinische regels voor oproep methoden'),
(20594, 1101, 6, 'Klinische regels voor interval doelstellingen'),
(20595, 1102, 6, 'Klinische doelstellingen'),
(20596, 1103, 6, 'Klinische voorwaarde'),
(20597, 1104, 6, 'Code(s) voor klinische voorwaarden'),
(20598, 1106, 6, 'Kliniekmedewerkers'),
(20599, 1107, 6, 'Copieer'),
(20600, 1108, 6, 'Copieren vorige consult'),
(20601, 1109, 6, 'Sluit'),
(20602, 1110, 6, 'Venster sluiten'),
(20603, 1111, 6, 'sluit venster'),
(20604, 1112, 6, 'Gesloten'),
(20605, 1113, 6, 'cm'),
(20606, 1114, 6, 'CMS 1500 kantlijnen'),
(20607, 1115, 6, 'CMS 1500 Papier soort formaat'),
(20608, 1116, 6, 'CMS 1500 Box 31 formaat'),
(20609, 1117, 6, 'CMS 1500 Datum in box 31 (Handtekening)'),
(20610, 1118, 6, 'CMS-ID'),
(20611, 1119, 6, 'CMS toegang'),
(20612, 1120, 6, 'CMS toegang Login'),
(20613, 1121, 6, 'CMS toegang Login ID'),
(20614, 1122, 6, 'CMS toegang niet geinstalleerd!'),
(20615, 1123, 6, 'CMS toegang´s paswoord'),
(20616, 1124, 6, 'CMS toegnag´s verzoek'),
(20617, 1125, 6, 'CMS toegang´s SITE adres'),
(20618, 1126, 6, 'CMS toegang´s Gebruikersnaam'),
(20619, 1127, 6, 'CN2-12 intact'),
(20620, 1128, 6, 'Bij betaling'),
(20621, 1129, 6, 'Bijbetaling geregeld'),
(20622, 1130, 6, 'Extra betalingen'),
(20623, 1131, 6, 'Code'),
(20624, 1132, 6, 'code'),
(20625, 1133, 6, 'Zoek code'),
(20626, 1134, 6, 'Code moeten twee kleine letters zijn'),
(20627, 1135, 6, 'Code lokale valuta anders dan $ symbool'),
(20628, 1136, 6, 'Code tekst'),
(20629, 1137, 6, 'Type code'),
(20630, 1138, 6, 'Type code'),
(20631, 1139, 6, 'Type code wordt niet herkend'),
(20632, 1140, 6, 'Type code is nog niet gedefinieerd'),
(20633, 1141, 6, 'Type Codes'),
(20634, 1142, 6, 'Code(s)'),
(20635, 1143, 6, 'Gecodeerd'),
(20636, 1144, 6, 'Codering'),
(20637, 1145, 6, 'Coderen niet toegestaan'),
(20638, 1146, 6, 'Codering (klik om te leren)'),
(20639, 1147, 6, 'Coderen - contact naar keuze (schrijven, met sommige optioneel)'),
(20640, 1148, 6, 'Coderen - mijn (schrijven, met sommige optioneel)'),
(20641, 1149, 6, 'Niet geautoriseerde codering'),
(20642, 1150, 6, 'Koffie'),
(20643, 1151, 6, 'Koffie gebruik'),
(20644, 1152, 6, 'Extra verzekering'),
(20645, 1153, 6, 'Coll w/o'),
(20646, 1154, 6, 'Inklappen'),
(20647, 1155, 6, 'inklappen'),
(20648, 1156, 6, 'Alles inklappen'),
(20649, 1157, 6, 'Alles inklappen'),
(20650, 1158, 6, 'alles inklappen'),
(20651, 1160, 6, 'Verzamel datum'),
(20652, 1161, 6, 'Verzamelingen'),
(20653, 1162, 6, 'Ontvangen bedragen rapport'),
(20654, 1163, 6, 'Colonkanker'),
(20655, 1164, 6, 'Colon-Ca screening'),
(20656, 1165, 6, 'Colon-Ca chirurgie'),
(20657, 1166, 6, 'Coloscopie'),
(20658, 1167, 6, 'coloscopie'),
(20659, 1168, 6, 'Kleur'),
(20660, 1169, 6, 'Kleur:Abbr'),
(20661, 1170, 6, 'Kolom'),
(20662, 1171, 6, 'Kolommen'),
(20663, 1172, 6, 'Voorraaden samenvoegen'),
(20664, 1173, 6, 'Komma'),
(20665, 1174, 6, 'Commentaar'),
(20666, 1175, 6, 'Commentaren'),
(20667, 1176, 6, 'Commentaar of aanbeveling voor dit resultaat'),
(20668, 1177, 6, 'Commerciele verzekeringsmij.'),
(20669, 1178, 6, 'Wijzigingen doorvoeren'),
(20670, 1179, 6, 'Communicaties'),
(20671, 1180, 6, 'Communicaties'),
(20672, 1182, 6, 'Bedrijf'),
(20673, 1183, 6, 'Naam bedrijf'),
(20674, 1184, 6, 'Afronden'),
(20675, 1186, 6, 'Afgerond'),
(20676, 1188, 6, 'Afgerond?'),
(20677, 1190, 6, 'Complicaties bij Service gevende'),
(20678, 1191, 6, 'Complicaties van abortus'),
(20679, 1192, 6, 'Componenten'),
(20680, 1193, 6, 'Computergestuurd ordersysteem'),
(20681, 1194, 6, 'Conclusies'),
(20682, 1198, 6, 'onfig'),
(20683, 1199, 6, 'Configuratie'),
(20684, 1200, 6, 'Configuratie im-/ex-port'),
(20685, 1201, 6, 'Configuratie met succes bewaard'),
(20686, 1202, 6, 'Apache en LibreEHR instellen om SSL-clientcertificaten te gebruiken'),
(20687, 1203, 6, 'Apache instellen om SSL-clientcertificaten te gebruiken'),
(20688, 1204, 6, 'Apache instellen om HTTPS te gebruiken.'),
(20689, 1205, 6, 'LibreEHR instellen om SSL-clientcertificaten te gebruiken'),
(20690, 1206, 6, 'Tracks configureren'),
(20691, 1207, 6, 'Tracks configureren'),
(20692, 1208, 6, 'Bevestig aanmaken nieuwe patient'),
(20693, 1209, 6, 'Nieuwe paswoord confirmeren'),
(20694, 1210, 6, 'Bevestig betaling'),
(20695, 1214, 6, 'Aangeboren'),
(20696, 1215, 6, 'Conjunctiva, pupillen'),
(20697, 1216, 6, 'Verbindings fout'),
(20698, 1217, 6, 'Verbindingen'),
(20699, 1218, 6, 'Constante'),
(20700, 1219, 6, 'naam van constante'),
(20701, 1220, 6, 'Naam van Constante is leeg'),
(20702, 1221, 6, 'Constanten'),
(20703, 1222, 6, 'Obstipatie'),
(20704, 1223, 6, 'Constitutie'),
(20705, 1226, 6, 'Korte omschrijving consult'),
(20706, 1227, 6, 'Contact'),
(20707, 1228, 6, 'Contact e-mail'),
(20708, 1229, 6, 'Contact e-mail adres'),
(20709, 1230, 6, 'Neem contact op met EMR Direct om abb, te nemen abb. te nemen op phiMail Direect messaging sercvice'),
(20710, 1231, 6, 'Contact info'),
(20711, 1232, 6, 'Contact lenzen'),
(20712, 1233, 6, 'Neem contact op kmet Medical Information Intergration, LLC via http://mi-squared.com om Lab exchange Service te activeren.'),
(20713, 1234, 6, 'Neem contact op met Medical Information Integration, LLC via http://mi-squared.com of ZH Healthcare via http://zhservices.com voor abb. op eRx service'),
(20714, 1236, 6, 'Naam contact'),
(20715, 1237, 6, 'Contactpersoon'),
(20716, 1238, 6, 'Contact tel.'),
(20717, 1239, 6, 'Telefoon contactpersoon'),
(20718, 1240, 6, 'Maak contact met ZMG. LLC(zmghealth@gmail.com) om eRx service abbonement aan te maken'),
(20719, 1241, 6, 'bevat minstens drie van de vier volgende items'),
(20720, 1242, 6, 'Groepsnaam van container'),
(20721, 1243, 6, 'Inhoud'),
(20722, 1244, 6, 'inhoud'),
(20723, 1245, 6, 'Contekst'),
(20724, 1246, 6, 'Contekt naam kan niet leeg zijn'),
(20725, 1247, 6, 'Doorgaan'),
(20726, 1248, 6, 'Voortgangs document voor verzorging (CCD)'),
(20727, 1249, 6, 'Voortgang zorg verslag (CCR)'),
(20728, 1250, 6, 'Contra clienten'),
(20729, 1251, 6, 'Anticonceptie'),
(20730, 1252, 6, 'Anticonceptie problematiek'),
(20731, 1253, 6, 'Anticonceptie complicatie (specificeren)'),
(20732, 1254, 6, 'Anticonceptie methode'),
(20733, 1255, 6, 'Anticoceptie producten'),
(20734, 1256, 6, 'Vorige anticonceptiemethode'),
(20735, 1257, 6, 'Begin anticonceptie'),
(20736, 1258, 6, 'Controle ID'),
(20737, 1259, 6, 'Controle nummer'),
(20738, 1261, 6, 'Eigen bijdrage'),
(20739, 1262, 6, 'Eigen bijdrage'),
(20740, 1263, 6, 'Eigen bijdrage'),
(20741, 1264, 6, 'Eigen bijdrage moet pos zijn'),
(20742, 1265, 6, 'Co/pay betaald'),
(20743, 1266, 6, 'Eigen Bijdragen'),
(20744, 1267, 6, 'COPD'),
(20745, 1268, 6, 'Kopieer blz naar kaart van pt'),
(20746, 1269, 6, 'Waarden kopieren'),
(20747, 1270, 6, 'Database wordt gecopieerd. Dit kost wat tijd...'),
(20748, 1271, 6, 'Copyright'),
(20749, 1272, 6, 'Cornish'),
(20750, 1273, 6, 'Coronaire Ateriele Bypass'),
(20751, 1274, 6, 'Coronaire Arteriele Bypass Graft (CABG)'),
(20752, 1275, 6, 'Gecorrigeerd'),
(20753, 1276, 6, 'Corsicaans'),
(20754, 1277, 6, 'CouchDB'),
(20755, 1278, 6, 'CouchDB verbinding mislukt.'),
(20756, 1279, 6, 'CouchDB Database'),
(20757, 1280, 6, 'CouchDB database naam'),
(20758, 1281, 6, 'CouchDB host'),
(20759, 1282, 6, 'CouchDB Hostnaam'),
(20760, 1283, 6, 'CouchDB log aan'),
(20761, 1284, 6, 'CouchDB paswoord'),
(20762, 1285, 6, 'CouchDB poort'),
(20763, 1286, 6, 'CouchDB poort'),
(20764, 1287, 6, 'CouchDB save mislukt'),
(20765, 1288, 6, 'CouchDB Usernaam'),
(20766, 1289, 6, 'Hoest'),
(20767, 1290, 6, 'Hoest:'),
(20768, 1291, 6, 'kon niet met de serververbinden'),
(20769, 1293, 6, 'kon de tabel niet openen'),
(20770, 1294, 6, 'Kon bestand niet lezen'),
(20771, 1295, 6, 'Kon de file niet inlezen'),
(20772, 1296, 6, 'E-mail werd niet verzonden door serverprobleem, '),
(20773, 1297, 6, 'E-mail werd niet verzonden door server probleem. '),
(20774, 1298, 6, 'Kon geen backup Dir maken:'),
(20775, 1299, 6, 'Kon volgende Dir niet verwijderen:'),
(20776, 1300, 6, 'Kon deze oude backupfile niet verwijderen:'),
(20777, 1301, 6, 'Kon deze oude exportfile niet verwijderen'),
(20778, 1302, 6, 'Antistollingscontrole; INR controle'),
(20779, 1303, 6, 'Begeleiding dmv methode'),
(20780, 1304, 6, 'Begeleiding'),
(20781, 1305, 6, 'Begeleidingsactiviteiten'),
(20782, 1306, 6, 'Terug verwijsbrief'),
(20783, 1307, 6, 'Terug verwijzing'),
(20784, 1308, 6, 'Land'),
(20785, 1309, 6, 'Landspecifieke Data Type'),
(20786, 1310, 6, 'Namenlijst van landen'),
(20787, 1311, 6, 'Landenlijst (schrijven,toevoegen optioneel)'),
(20788, 1312, 6, 'Landnaam moet uit twee letters bestaan (bijvoorbeeld: Verenigde staten is US)'),
(20789, 1313, 6, 'regio'),
(20790, 1315, 6, 'Coupon'),
(20791, 1318, 6, 'CPT'),
(20792, 1319, 6, 'CPT-Code'),
(20793, 1320, 6, 'CPT-Codes'),
(20794, 1321, 6, 'CPT4-Procedure/Service'),
(20795, 1322, 6, 'CPTII Perfomance Meetingen'),
(20796, 1323, 6, 'CQM'),
(20797, 1324, 6, 'Knisperend:'),
(20798, 1325, 6, 'creme'),
(20799, 1326, 6, 'Maak een SSL-clientcertificaat aan voor elke gebruiker of clientmachine.'),
(20800, 1327, 6, 'Maak een SSL-clientcertificaat aan voor ofwel een gebruiker ofwel een clientcomputer.'),
(20801, 1328, 6, 'een nieuwe track aanmaken'),
(20802, 1329, 6, 'Maak gebeurtenis aan'),
(20803, 1330, 6, 'Maak en download een totale backup'),
(20804, 1331, 6, 'Maak en verander de tracks'),
(20805, 1332, 6, 'Maak backup'),
(20806, 1333, 6, 'Maak verzameling'),
(20807, 1334, 6, 'Maak een clientcertificaat aan'),
(20808, 1335, 6, 'Maak een SSL-clientcertificaat aan'),
(20809, 1336, 6, 'Dupliceren'),
(20810, 1337, 6, 'Encounter aanmaken'),
(20811, 1338, 6, 'Backup van gebeurtenislog aanmaken'),
(20812, 1339, 6, 'Nieuwe issue maken'),
(20813, 1340, 6, 'Nieuwe client registreren'),
(20814, 1341, 6, 'Nieuwe track aanmaken'),
(20815, 1342, 6, 'Maak Offsite Portal credentials aan'),
(20816, 1343, 6, 'Maak onsite Portal credentials aan'),
(20817, 1344, 6, 'Maak notitie voor patient'),
(20818, 1345, 6, 'Maak autorisatie aan voor de SSL-clientcertificaat en servercertificaten'),
(20819, 1346, 6, 'Maak visite aan'),
(20820, 1347, 6, 'Aangemaakt'),
(20821, 1348, 6, 'Aanmaken exportbestand'),
(20822, 1349, 6, 'Aanmaken nieuwe track mislukt'),
(20823, 1350, 6, 'Om deze file bij Remote Host aan te maken is mislukt'),
(20824, 1351, 6, 'Maker van'),
(20825, 1352, 6, 'krediet'),
(20826, 1353, 6, 'Credit Card'),
(20827, 1354, 6, 'Kredieten'),
(20828, 1355, 6, 'Cree'),
(20829, 1356, 6, 'Criteria'),
(20830, 1357, 6, 'Kroatisch'),
(20831, 1358, 6, 'Ziekte van Crohn'),
(20832, 1359, 6, 'Ziekte van Crohn'),
(20833, 1360, 6, 'CSV-export'),
(20834, 1361, 6, 'CSV-bestand'),
(20835, 1362, 6, 'CSV tabellen'),
(20836, 1363, 6, 'CU.MM'),
(20837, 1364, 6, 'Cubaans'),
(20838, 1365, 6, 'Aantal decimalen valuta'),
(20839, 1366, 6, 'Valuta decimaal punt symbool'),
(20840, 1367, 6, 'Valuta symbool'),
(20841, 1368, 6, 'Valuta duizendtallen symbool'),
(20842, 1369, 6, 'Actief'),
(20843, 1370, 6, 'Huidig alcohol gebruik'),
(20844, 1371, 6, 'Lopende consultatie'),
(20845, 1372, 6, 'Huidige criteria'),
(20846, 1373, 6, 'Kleur van lopende dag'),
(20847, 1374, 6, 'Huidig dagelijks roken'),
(20848, 1375, 6, 'De actieve bestandsnaam is veranderd in'),
(20849, 1376, 6, 'Huidige Hash'),
(20850, 1377, 6, 'Huidige locatie'),
(20851, 1378, 6, 'Lopende medicaties'),
(20852, 1379, 6, 'Geldig Paswoord'),
(20853, 1380, 6, 'Nu aanwezige patient'),
(20854, 1381, 6, 'Alleen huidige patient'),
(20855, 1382, 6, 'Huidig recreatief drug gebruik'),
(20856, 1383, 6, 'Rook gedrag gedurende enkele dagen'),
(20857, 1385, 6, 'Lopende waarde'),
(20858, 1386, 6, 'Nu actief'),
(20859, 1387, 6, 'Is nu bezig'),
(20860, 1388, 6, 'Er zijn geen facilities aanwezig'),
(20861, 1389, 6, 'Cushing syndroom'),
(20862, 1390, 6, 'Cushing syndroom'),
(20863, 1392, 6, 'Gewoonte'),
(20864, 1393, 6, 'Gebruikers input?'),
(20865, 1394, 6, 'Gebruikers tabel'),
(20866, 1396, 6, 'CVX code'),
(20867, 1397, 6, 'CVX code mapping'),
(20868, 1398, 6, 'CVX Immunisatie'),
(20869, 1399, 6, 'Cyclus'),
(20870, 1400, 6, 'CYP'),
(20871, 1401, 6, 'CYP-factor'),
(20872, 1402, 6, 'CYP-verslag'),
(20873, 1403, 6, 'Tsechisch'),
(20874, 1404, 6, 'D'),
(20875, 1405, 6, 'D&C'),
(20876, 1406, 6, 'D&E'),
(20877, 1407, 6, 'Geb'),
(20878, 1408, 6, 'dagelijks'),
(20879, 1409, 6, 'Dagelijks vastleggen'),
(20880, 1410, 6, 'Deens'),
(20881, 1411, 6, 'Soortgelijke data zit al in databank, wijzig de code en/of omschrijving'),
(20882, 1412, 6, 'Soortgelijke data zit al in databank, verander de naam van de constante'),
(20883, 1413, 6, 'Gegevens Cols'),
(20884, 1416, 6, 'Fout in data'),
(20885, 1417, 6, 'Data formulier'),
(20886, 1419, 6, 'data voor alle Encounters tot nu toe'),
(20887, 1420, 6, 'Gegevenstype'),
(20888, 1421, 6, 'Databank'),
(20889, 1422, 6, 'Database is niet geinstalleerd'),
(20890, 1423, 6, 'Database aanpassing'),
(20891, 1424, 6, 'Databank rapportage'),
(20892, 1425, 6, 'DB upgrade is beeindigd'),
(20893, 1426, 6, 'Data kolommen moeten nummer hebben tussen 1 en 999'),
(20894, 1427, 6, 'Datum'),
(20895, 1428, 6, 'DATUM'),
(20896, 1429, 6, 'Datum en tijd van toedienen'),
(20897, 1431, 6, 'Geadministreerde datum'),
(20898, 1432, 6, 'Datum en tijd van afname sampel'),
(20899, 1433, 6, 'Datum en tijd van deze waarneming'),
(20900, 1435, 6, 'Datum en tijd dat sampel is verzameld'),
(20901, 1436, 6, 'Datum kan niet voorbij vandaag liggen'),
(20902, 1437, 6, 'Aanvankelijke begindatum anticonceptie'),
(20903, 1438, 6, 'Datum van aanmaken'),
(20904, 1439, 6, 'Datum overlijden'),
(20905, 1440, 6, 'Datum vernietigd'),
(20906, 1441, 6, 'Format voor datum invoer'),
(20907, 1442, 6, 'Datum voor "einde afspraak" is ongeldig'),
(20908, 1443, 6, 'Datum van begin afspraak is ongeldig'),
(20909, 1444, 6, 'Datum format voor "volgende afspraak is ongeldig'),
(20910, 1445, 6, 'Datum voor "niet gezien sinds" is ongeldig'),
(20911, 1446, 6, 'Datum voor "geziens sinds" is ongeldig'),
(20912, 1447, 6, 'Info verstrekking over vaccinatie gegeven'),
(20913, 1448, 6, 'Dag voor deze code is niet ingevuld '),
(20914, 1449, 6, 'Datum Master criteria'),
(20915, 1450, 6, 'Datum bankdeposito jjjj-mm-dd'),
(20916, 1451, 6, 'Datum rekening verstuurd'),
(20917, 1452, 6, 'Geboortedatum'),
(20918, 1453, 6, 'Geboortedatum'),
(20919, 1454, 6, 'Geboorte datum'),
(20920, 1455, 6, 'Datum invoer'),
(20921, 1456, 6, 'Datum van letsel'),
(20922, 1458, 6, 'Datum van betaling jjjj-mm-dd'),
(20923, 1459, 6, 'Datum van verwijzing'),
(20924, 1460, 6, 'Datum van antwoord'),
(20925, 1461, 6, 'Datum rapport'),
(20926, 1462, 6, 'Datum dienstverlening'),
(20927, 1463, 6, 'Datum dienstverlening'),
(20928, 1464, 6, 'Datum van Service = vandaag'),
(20929, 1465, 6, 'Datum dienstverlening mm/dd/jjjj'),
(20930, 1466, 6, 'Datum van dienstverlening'),
(20931, 1467, 6, 'Datum van handtekening'),
(20932, 1468, 6, 'Datum ondertekening'),
(20933, 1469, 6, 'Datum van deze bestelling'),
(20934, 1470, 6, 'Datum van dit rapport'),
(20935, 1471, 6, 'Datum VIS verklaring'),
(20936, 1472, 6, 'Besteldatum'),
(20937, 1474, 6, 'Datum kiezer'),
(20938, 1475, 6, 'Datum kiezer'),
(20939, 1476, 6, 'Datum verzending'),
(20940, 1477, 6, 'Datum dat bericht verstuurd werd'),
(20941, 1478, 6, 'Datum tijd'),
(20942, 1479, 6, 'Datum waarden kunnen niet blanco zijn'),
(20943, 1480, 6, 'Datum/Bez.'),
(20944, 1481, 6, 'Datum/Notitie'),
(20945, 1482, 6, 'Datum/Notitie van laatste'),
(20946, 1483, 6, 'Datum/Tijd'),
(20947, 1484, 6, 'Datum:'),
(20948, 1485, 6, 'Gedateerde berichten log'),
(20949, 1486, 6, 'Dag'),
(20950, 1487, 6, 'dag'),
(20951, 1489, 6, 'Dagoverzicht'),
(20952, 1490, 6, 'Dag(en)'),
(20953, 1491, 6, 'Dag(en) Ma - Vr'),
(20954, 1492, 6, 'dagen'),
(20955, 1493, 6, 'Dagen'),
(20956, 1494, 6, 'dagen geleden'),
(20957, 1495, 6, 'Dagen en spelen gemist'),
(20958, 1496, 6, 'Dagen vanaf laatste contact'),
(20959, 1497, 6, 'Gemiste dagen'),
(20960, 1498, 6, 'Dagen per kolom:'),
(20961, 1500, 6, 'Dagen/Col:'),
(20962, 1501, 6, 'DB geinstalleerd'),
(20963, 1502, 6, 'dd/mm/jjjj'),
(20964, 1503, 6, 'De Identificatie'),
(20965, 1504, 6, 'De Identificatie Proces beeindigd'),
(20966, 1505, 6, 'De Identificatie Proces is bezig.....'),
(20967, 1506, 6, 'De Identificatie Proces is begonnen en draait op achtergrond'),
(20968, 1507, 6, 'De Identificatie Proces'),
(20969, 1508, 6, 'De Identificatie bestand worden opgeslagen in'),
(20970, 1509, 6, 'DEA'),
(20971, 1511, 6, 'Doof'),
(20972, 1512, 6, 'Informatie om fout te zoeken'),
(20973, 1514, 6, 'Bezig fouten te zoeken'),
(20974, 1515, 6, 'Dec'),
(20975, 1516, 6, 'Overleden'),
(20976, 1517, 6, 'December'),
(20977, 1518, 6, 'Decimaal pounden, of pounden en ounces gescheiden met #(e.g. 5#4)'),
(20978, 1519, 6, 'Niet nader specificeren'),
(20979, 1520, 6, 'Aftrekbaar'),
(20980, 1521, 6, 'Aftrekbaar Met'),
(20981, 1522, 6, 'Standaard'),
(20982, 1523, 6, 'Standaard agendaweergave'),
(20983, 1524, 6, 'Standaard Encounter Formulier ID'),
(20984, 1526, 6, 'Voorkeurs Kliniek'),
(20985, 1527, 6, 'Voorkeurs taal'),
(20986, 1528, 6, 'Standaard taal indien geen andere is toegestaan of is gekozen'),
(20987, 1529, 6, 'Standaardlijst (schrijven,toevoegen optioneel)'),
(20988, 1530, 6, 'Standaardmethode'),
(20989, 1531, 6, 'Standaard aantal dagen tot Paswoord verloopt'),
(20990, 1532, 6, 'Verloop tijd in dagen voor paswoord. 0 betekent deze keuze wordt NIET geactivceerd.'),
(20991, 1533, 6, 'Voorkeur Land van Patient'),
(20992, 1535, 6, 'Voorkeursprioriteit'),
(20993, 1536, 6, 'Voorkeursbehandelaar'),
(20994, 1537, 6, 'Standaardrange'),
(20995, 1538, 6, 'Voorkeurstekst voor reden bezoek'),
(20996, 1540, 6, 'Default setting'),
(20997, 1541, 6, 'Voorkeurs status Nieuw Window checkbox in de patienten lijst.'),
(20998, 1542, 6, 'Standaardsjabloon'),
(20999, 1546, 6, 'Standaardunits'),
(21000, 1547, 6, 'Standaardwaarde'),
(21001, 1548, 6, 'Standaarwarenhuis'),
(21002, 1549, 6, 'Standaard X12 partner'),
(21003, 1550, 6, 'Standaard/Algemeen'),
(21004, 1551, 6, 'Del'),
(21005, 1552, 6, 'del'),
(21006, 1553, 6, 'Verlaat recidief (>12 mndn)'),
(21007, 1554, 6, 'Verwijder'),
(21008, 1555, 6, 'verwijder'),
(21009, 1556, 6, 'Verwijder categorieen met ID(s): '),
(21010, 1557, 6, 'Verwijder categorie'),
(21011, 1559, 6, 'Verwijdering mislukt'),
(21012, 1560, 6, 'Verwijder groep'),
(21013, 1561, 6, 'Verwijder lijst'),
(21014, 1562, 6, 'Verwijder pagina´s'),
(21015, 1563, 6, 'Verwijder patient, contact, formulier, probleem, document, betaling, rekening of verklaring'),
(21016, 1565, 6, 'Rij deleten'),
(21017, 1566, 6, 'Verwijder geselecteerde Items'),
(21018, 1567, 6, 'verwijder geselecteerde verzoeken'),
(21019, 1568, 6, 'Verwijderen gelukt.'),
(21020, 1569, 6, 'Verwijder dit document'),
(21021, 1570, 6, 'Verwijder dit formulier'),
(21022, 1571, 6, 'Verwijder deze notitie'),
(21023, 1572, 6, 'Met succes verwijderd'),
(21024, 1573, 6, 'Met succes verwijderd.'),
(21025, 1574, 6, 'Bezig te verwijderen'),
(21026, 1575, 6, 'Verwijderen van de Event kan niet ongedaan gemaakt worden. Kan ook niet opneiuw terug gehaald worden. Echt helemaal zeker om te verwijderen?'),
(21027, 1576, 6, 'Afleveren bevestigd'),
(21028, 1577, 6, 'Aflevering is niet toegstaan op gespecificeerde adres.'),
(21029, 1578, 6, 'Versturen naar het specificeerde adres is nu niet toegestaan.'),
(21030, 1579, 6, 'Op verzoek van de patient is het aangehechte klinische document gestuurd'),
(21031, 1580, 6, 'Versturen van het bijgevoegde klinische document werd op verzoek van de patient gedaan.'),
(21032, 1581, 6, 'Dementie'),
(21033, 1582, 6, 'Persoonsgegevens'),
(21034, 1583, 6, 'Persoonsgegevens (schrijven,toevoegen optioneel)'),
(21035, 1585, 6, 'Filter voor Demografische gegevens'),
(21036, 1586, 6, 'Persoonsgegevens niet geautoriseerd'),
(21037, 1587, 6, 'Persoonsgegevens nog niet geautoriseerd'),
(21038, 1588, 6, 'Niet toegestaan'),
(21039, 1589, 6, 'Denominator'),
(21040, 1590, 6, 'Gebit'),
(21041, 1591, 6, 'Lijst gebits problemen'),
(21042, 1592, 6, 'Gebitsproblemen'),
(21043, 1593, 6, 'Afhankelijke Modules'),
(21044, 1594, 6, 'Afhankelijke problemen'),
(21045, 1595, 6, 'Afhankelijk van het type rekening dat u test, ziet u HCFA gelijkende output op een lege pagina voor HCFA rekeningen, u zult vele regels van enigszins verdraaide tekst en informatie zien, als u een X12 claim test. Deze verdraaide tekst is in het X12 EDI 4010A format. Soms zult u eigenaardige tekens zien die op dominostenen of nonsens lijken, dan zijn dit controletekens zoals nieuwe pagina beginnen en zijn normaal.'),
(21046, 1596, 6, 'Datum storting'),
(21047, 1597, 6, 'Datum van storting kan niet na vandaag liggen'),
(21048, 1598, 6, 'Datum deposito'),
(21049, 1599, 6, 'Depressief'),
(21050, 1600, 6, 'Depressie'),
(21051, 1601, 6, 'DESC'),
(21052, 1602, 6, 'Commentaar'),
(21053, 1603, 6, 'commentaar'),
(21054, 1604, 6, 'Omschrijving is de default tekst'),
(21055, 1605, 6, 'Omschrijving van commentaar'),
(21056, 1606, 6, 'Beschrijving van deze procedure of code van resultaat'),
(21057, 1607, 6, 'Omschrijving vertaling'),
(21058, 1608, 6, 'gewenste File naamj'),
(21059, 1609, 6, 'Doel'),
(21060, 1610, 6, 'Naam voor de te maken file'),
(21061, 1611, 6, 'Vernietig Lot'),
(21062, 1612, 6, 'Vernietigen...'),
(21063, 1613, 6, 'Vernietigd'),
(21064, 1614, 6, 'Vernietigde medicijnen'),
(21065, 1615, 6, 'Vernietigde medicijnrapport'),
(21066, 1616, 6, 'Detail'),
(21067, 1617, 6, 'Details'),
(21068, 1619, 6, 'Ontwikkelings abnormaliteit'),
(21069, 1620, 6, 'Diabetes'),
(21070, 1621, 6, 'Diabetes Mellitus'),
(21071, 1622, 6, 'Diabetes: Bloeddruk management (CQM)'),
(21072, 1623, 6, 'Diabetes: Oog fundus onderzoek'),
(21073, 1624, 6, 'Diabetes: Oog fundus onderzoek (CQM)'),
(21074, 1625, 6, 'Diabetes: Voet onderzoek'),
(21075, 1626, 6, 'Diabetes: Voet onderzoek (CQM)'),
(21076, 1627, 6, 'Diabetes: HbA1c Controle (CQM)'),
(21077, 1628, 6, 'Diabetes: HbA1c'),
(21078, 1629, 6, 'Diabetes: LDL management en controle (CQM)'),
(21079, 1630, 6, 'Diabetes: Urine microalbuminurie'),
(21080, 1631, 6, 'Diag'),
(21081, 1632, 6, 'Diagnoses'),
(21082, 1633, 6, 'Diagnose'),
(21083, 1634, 6, 'Code voor diagnose'),
(21084, 1635, 6, 'Diagnose codes'),
(21085, 1636, 6, 'Datum diagnose'),
(21086, 1637, 6, 'Diagnose moet aan code verbonden zijn'),
(21087, 1638, 6, 'Naam van Diagnose'),
(21088, 1639, 6, 'Rapport van Diagnose'),
(21089, 1640, 6, 'Diagnoses verslag geving'),
(21090, 1641, 6, 'Alleen diagnoses verslag geving'),
(21091, 1642, 6, 'Titel van Diagnose'),
(21092, 1643, 6, 'Diagnose:'),
(21093, 1644, 6, 'Diagnose: '),
(21094, 1645, 6, 'Diagnostische testen'),
(21095, 1646, 6, 'Dials'),
(21096, 1647, 6, 'Diafragma/Caps'),
(21097, 1648, 6, 'Diarree'),
(21098, 1650, 6, 'Dictaat'),
(21099, 1651, 6, 'Ingesproken tekst '),
(21100, 1652, 6, 'Heeft u een kopie gekregen van de HIPAA Notitie'),
(21101, 1653, 6, 'Diffuus:'),
(21102, 1654, 6, 'Met digitale handtekening'),
(21103, 1657, 6, 'Direct mail'),
(21104, 1658, 6, 'Direct message log'),
(21105, 1659, 6, 'Direct messages ontvangen'),
(21106, 1660, 6, 'Direct messaging is nu niet beschikbaar'),
(21107, 1661, 6, 'Direect message verstuurd is mislukt'),
(21108, 1663, 6, 'Direct mail'),
(21109, 1664, 6, 'Directory verwijderen is mislukt; doorgaan.'),
(21110, 1665, 6, 'Handicap'),
(21111, 1666, 6, 'Onbruikbaar maken'),
(21112, 1667, 6, 'Kalender niet activeren'),
(21113, 1668, 6, 'Status tracker niet activeren'),
(21114, 1669, 6, 'Vaccinatie niet activeren'),
(21115, 1670, 6, 'Oud metrieke Vitals-formulier niet activeren'),
(21116, 1672, 6, 'phpMyAdmin niet activeren'),
(21117, 1673, 6, 'Recepten niet activeren'),
(21118, 1674, 6, 'Gebruikers groepen niet activeren'),
(21119, 1675, 6, 'inactief'),
(21120, 1676, 6, 'Invalide'),
(21121, 1677, 6, 'Invalide begunstigde onder de leeftijd van 65 jaar met een large group health plan (LGHP)'),
(21122, 1678, 6, 'DISC'),
(21123, 1679, 6, 'Verwijderen'),
(21124, 1680, 6, 'Verwijderd'),
(21125, 1681, 6, 'Afscheiding'),
(21126, 1682, 6, 'Afscheiding urethra'),
(21127, 1684, 6, 'Afscheiding rechts'),
(21128, 1685, 6, 'Afscheiding rechts:'),
(21129, 1688, 6, 'Ontslagen'),
(21130, 1689, 6, 'Vrijgeven Info'),
(21131, 1690, 6, 'Vrijgeven type'),
(21132, 1691, 6, 'Vrijgeven types'),
(21133, 1692, 6, 'Vrijgegeven'),
(21134, 1694, 6, 'Korting'),
(21135, 1695, 6, 'Kortingsbedrag'),
(21136, 1696, 6, 'Kortingsniveau'),
(21137, 1697, 6, 'Percentage korting'),
(21138, 1698, 6, 'Korting in geldwaarde'),
(21139, 1699, 6, 'Kortingen gegeven bij uitchecken worden genoteerd als geldswaarde, i.t.t. percentages.'),
(21140, 1700, 6, 'Discreet resultaat'),
(21141, 1701, 6, 'Ziekte'),
(21142, 1702, 6, 'Dislocatie'),
(21143, 1703, 6, 'Dtd. #'),
(21144, 1704, 6, 'Lever af'),
(21145, 1705, 6, 'Lever ontvangen document af'),
(21146, 1706, 6, 'Afgegeven'),
(21147, 1707, 6, 'Toon advance directives in de Demografische Pagina.'),
(21148, 1708, 6, 'Documenten tonen'),
(21149, 1709, 6, 'Data gebeurtenissen in blok tonen?'),
(21150, 1710, 6, 'Toon format voor US gewichten'),
(21151, 1711, 6, 'Hoeveelheid gebeurtenissen tonen?'),
(21152, 1713, 6, 'Locatie in blok tonen?'),
(21153, 1714, 6, 'Naam tonen'),
(21154, 1715, 6, 'De agenda tonen?'),
(21155, 1718, 6, 'Gebeurtenissen van vandaag in blok tonen?'),
(21156, 1719, 6, 'Onderwerp in blok tonen?'),
(21157, 1720, 6, 'Komende gebeurtenissen in blok tonen?'),
(21158, 1721, 6, 'Weergegeven kolommen'),
(21159, 1722, 6, 'De meest recente disclosures worden getoond'),
(21160, 1723, 6, 'Toon het volgende nummer van recente notities'),
(21161, 1724, 6, 'Toon het vervolg nummer van recente notes'),
(21162, 1725, 6, 'Verdeling'),
(21163, 1726, 6, 'Verdeling'),
(21164, 1727, 6, 'Distributeur'),
(21165, 1728, 6, 'Divehi- Dhivehi- Maldivian-'),
(21166, 1729, 6, 'Diverticulitis'),
(21167, 1730, 6, 'Diverticulitis chirurgie'),
(21168, 1731, 6, 'Diverticulitis'),
(21169, 1732, 6, 'Diverticulitis chirurgie'),
(21170, 1733, 6, 'Gescheiden'),
(21171, 1734, 6, 'Duizeligheid'),
(21172, 1735, 6, 'Niet veranderen'),
(21173, 1737, 6, 'Allergie niet tonen bij uploaden naar NewCrop'),
(21174, 1739, 6, 'Medicatie niet tonen bij uploaden naar NewCrop'),
(21175, 1742, 6, 'Kalender niet tonen'),
(21176, 1744, 6, 'Geen inventaris en verkoop van andere producten'),
(21177, 1745, 6, 'Het is niet nodig dat Patient aantekeningen geautoriseerd worden'),
(21178, 1746, 6, 'Uitdrukkelijke wens GEEN REANIMATIE'),
(21179, 1747, 6, 'annuleren'),
(21180, 1748, 6, 'niet vervangen'),
(21181, 1749, 6, 'doe niets'),
(21182, 1751, 6, 'Wilt u dit echt veerwijderen'),
(21183, 1752, 6, 'Wilt u zeker deze selectie verwijderen?'),
(21184, 1753, 6, 'Wilt u zeker deze groep verwijderen?'),
(21185, 1754, 6, 'Wilt u het zeker verwijderen?'),
(21186, 1755, 6, 'Wilt U doorgaan?'),
(21187, 1756, 6, 'Wilt U dit verwijderen?'),
(21188, 1757, 6, 'Verwijderen?'),
(21189, 1758, 6, 'Wil je deze status verwijderen?'),
(21190, 1759, 6, 'Wilt u doorgaan met deze nieuwe client toe te voegen?'),
(21191, 1760, 6, 'Wilt u verder gaan met de nieuwe naam?'),
(21192, 1761, 6, 'WIlt u dit immunisatie verslag PERMANENT verwijderen?'),
(21193, 1762, 6, 'GEB'),
(21194, 1763, 6, 'Geb datum niet ingevuld'),
(21195, 1764, 6, 'Docs'),
(21196, 1765, 6, 'Dokter'),
(21197, 1766, 6, 'Dr:'),
(21198, 1767, 6, 'Naam en handtekening Arts'),
(21199, 1768, 6, 'Document'),
(21200, 1769, 6, 'document'),
(21201, 1770, 6, 'Document categorieen'),
(21202, 1771, 6, 'Document cathegorie voor lab resultaten bestaat niet'),
(21203, 1772, 6, 'Document categorie naam voor electronisch opslaan van ontvangen lab resultaten.'),
(21204, 1774, 6, 'Documetn Categorie of verwijderen'),
(21205, 1775, 6, 'Document kon niet naar Client ID verplaatst worden'),
(21206, 1777, 6, 'Datum van document'),
(21207, 1778, 6, 'Datum van document en klachten aangepast'),
(21208, 1779, 6, 'DocumentID'),
(21209, 1780, 6, 'Ducument verzet naar nieuwe categorie'),
(21210, 1781, 6, 'Dokument verzet naar patient ID'),
(21211, 1783, 6, 'Document is geaccepteerd door security check'),
(21212, 1784, 6, 'Manier om documenten op te slaan'),
(21213, 1785, 6, 'Document met succes van naam veranderd'),
(21214, 1786, 6, 'Document is met succes verbonden aan de Encounter'),
(21215, 1787, 6, 'Document Template management'),
(21216, 1788, 6, 'Document Templates'),
(21217, 1789, 6, 'Document(en)'),
(21218, 1790, 6, 'Bewaarplaats van document/afbeelding'),
(21219, 1791, 6, 'Documenten'),
(21220, 1792, 6, 'Documenten (schrijven,toevoegen optioneel)'),
(21221, 1794, 6, 'DOE'),
(21222, 1796, 6, 'er is geen vergelijk met PV1 encounter gevonden'),
(21223, 1797, 6, 'lijkt niet valide te zijn'),
(21224, 1798, 6, 'Zijn er gerelateerde codes voor dit type toegestaan?'),
(21225, 1799, 6, 'Samenwonend'),
(21226, 1800, 6, 'Annuleren'),
(21227, 1801, 6, 'Annuleren'),
(21228, 1802, 6, 'Wijzigingen annuleren'),
(21229, 1803, 6, 'Klaar'),
(21230, 1804, 6, 'Gedaan met:'),
(21231, 1805, 6, 'Klaar. Download wordt verstuurd'),
(21232, 1806, 6, 'DOS'),
(21233, 1807, 6, 'Dosering'),
(21234, 1809, 6, 'Dubbel klikken om te veranderen'),
(21235, 1810, 6, 'Dubbel zien'),
(21236, 1811, 6, 'Downloaden'),
(21237, 1814, 6, 'Toch downloaden'),
(21238, 1815, 6, 'Download factureringsbestand, verstuur naar boekhouding en markeer als gefactureerd'),
(21239, 1817, 6, 'Certificaten downloaden'),
(21240, 1818, 6, 'Download configuratie data'),
(21241, 1819, 6, 'Downloaden van document template voor deze patient en dit bezoek'),
(21242, 1820, 6, 'Downloaden van versleutelde file'),
(21243, 1823, 6, 'Downloaden van Offsite Portaal Verbindings Files'),
(21244, 1824, 6, 'Downloaden of een Template verwijderen'),
(21245, 1825, 6, 'Download PDF'),
(21246, 1827, 6, 'Download geselecteerde Statements'),
(21247, 1828, 6, 'Dr Controle'),
(21248, 1829, 6, 'Dr Bezoek'),
(21249, 1830, 6, 'Dr.'),
(21250, 1831, 6, 'Versleep om te verplaatsen'),
(21251, 1832, 6, 'Druppelen'),
(21252, 1833, 6, 'Rijbewijs of BSN'),
(21253, 1834, 6, 'Medicatie'),
(21254, 1835, 6, 'Opzoeken Medicatie'),
(21255, 1836, 6, 'Medicatie vorm'),
(21256, 1837, 6, 'Medicatie ID afwezig!'),
(21257, 1838, 6, 'Medicatie-intervallen'),
(21258, 1839, 6, 'Medicijnen voorraadbeheer'),
(21259, 1840, 6, 'Naam medicatie'),
(21260, 1841, 6, 'Wijze van toedienen'),
(21261, 1845, 6, 'Medicatie-eenheden'),
(21262, 1846, 6, 'Medicijnen'),
(21263, 1847, 6, 'Medicijnen en Producten'),
(21264, 1848, 6, 'Droge mond'),
(21265, 1849, 6, 'DSM IV Diagnosen'),
(21266, 1850, 6, 'DT1'),
(21267, 1851, 6, 'DT2'),
(21268, 1852, 6, 'DT3'),
(21269, 1853, 6, 'DT4'),
(21270, 1854, 6, 'DT5'),
(21271, 1855, 6, 'DTaP1'),
(21272, 1856, 6, 'DTaP2'),
(21273, 1857, 6, 'DTaP3'),
(21274, 1858, 6, 'DTaP4'),
(21275, 1859, 6, 'DTaP5'),
(21276, 1860, 6, 'Verschuldigd'),
(21277, 1861, 6, 'Datum bevalling'),
(21278, 1862, 6, 'Datum bev. mm/dd/jjjj of jjjj-mm-dd'),
(21279, 1863, 6, 'Datum bevalling:'),
(21280, 1864, 6, 'Vanwege Ins'),
(21281, 1865, 6, 'Vanwege Pt'),
(21282, 1866, 6, 'Binnenkort aan de beurt'),
(21283, 1867, 6, 'Datum bevalling'),
(21284, 1868, 6, 'Update aanpasing datum'),
(21285, 1869, 6, 'Dumping LibreEHR database'),
(21286, 1870, 6, 'Dumping LibreEHR web directory tree'),
(21287, 1871, 6, 'Dumping phpGACL database'),
(21288, 1872, 6, 'Dumping phpGACL web directory tree'),
(21289, 1873, 6, 'Dumping SQL-Ledger database'),
(21290, 1874, 6, 'Dumping SQL-Ledger web directory tree'),
(21291, 1875, 6, 'Dup Check'),
(21292, 1876, 6, 'Dubbele ID op lijn'),
(21293, 1877, 6, 'Dubbele NAAM op lijn'),
(21294, 1878, 6, 'Waarschuwing tegen duplicatie'),
(21295, 1879, 6, 'Duurzame volmacht'),
(21296, 1880, 6, 'duur'),
(21297, 1881, 6, 'Duur'),
(21298, 1882, 6, 'Nederlands'),
(21299, 1883, 6, 'Dx Rep'),
(21300, 1884, 6, 'Dysfagie'),
(21301, 1885, 6, 'Dyspnoe'),
(21302, 1886, 6, 'Dysurie'),
(21303, 1887, 6, 'Dzongkha'),
(21304, 1888, 6, 'e-Recept?'),
(21305, 1889, 6, 'e-Rapport(en)'),
(21306, 1890, 6, 'e-Rx'),
(21307, 1892, 6, 'e-Rx vernieuwing'),
(21308, 1893, 6, 'Iedere ontvanger moet hun eigen berichten op afgemaakt zetten.'),
(21309, 1894, 6, 'Vroeg recidief (<2mnd)'),
(21310, 1895, 6, 'Oren'),
(21311, 1896, 6, 'ECG'),
(21312, 1897, 6, 'eClaims'),
(21313, 1898, 6, 'Oedeem'),
(21314, 1899, 6, 'edi geschiedenis'),
(21315, 1900, 6, 'EDI Geschiedenis'),
(21316, 1901, 6, 'EDI Geschiedenis (onder bedragen) om te verzamelen en interpreteren van terug ontvangen EDI files'),
(21317, 1902, 6, 'EDI-271 File upload'),
(21318, 1903, 6, 'EDI-271 Respons file upload'),
(21319, 1904, 6, 'Aanpassen'),
(21320, 1905, 6, 'aanpassen'),
(21321, 1906, 6, 'Allergien aanpassen'),
(21322, 1907, 6, 'Categorieen aanpassen'),
(21323, 1908, 6, 'Definities aanpassen'),
(21324, 1909, 6, 'Definities aanpassen'),
(21325, 1910, 6, 'Diagnoses aanpassen voor'),
(21326, 1911, 6, 'Diagnose aanpassen'),
(21327, 1912, 6, 'Locatie aanpassen'),
(21328, 1913, 6, 'Bewerken faciliteit'),
(21329, 1914, 6, 'Locatie-informatie aanpassen'),
(21330, 1915, 6, 'Aanpassen specifieke User informatie'),
(21331, 1916, 6, 'Aanpassen van file in'),
(21332, 1917, 6, 'Pas formulier aan'),
(21333, 1918, 6, 'Basis controles aanpassen'),
(21334, 1919, 6, 'Aanpassen in niet toegestaan!'),
(21335, 1920, 6, 'Pas weergave aan'),
(21336, 1921, 6, 'Pas lijst aan'),
(21337, 1922, 6, 'Betaling aanpassen'),
(21338, 1923, 6, 'Structuur aanpassen'),
(21339, 1924, 6, 'Pas gebruiker aan'),
(21340, 1925, 6, 'User settings aanpassen'),
(21341, 1926, 6, 'Aanpassen van de door u ingevoerde data'),
(21342, 1927, 6, 'Veranderen mislukt'),
(21343, 1928, 6, 'Educatie'),
(21344, 1929, 6, 'Datum info aan pt'),
(21345, 1930, 6, 'Opvoedende materialen voor'),
(21346, 1931, 6, 'ee * Licentie voor algemeen gebruik onder GNU voorwaarden, voor meer details. * * U zou een exemplaar van de LicentieVergunning voor algemeen gebruik van GNU voorwaarden* samen met dit programma ontvangen moeten hebben; indien niet onvangen, schrijf naar Vrije '),
(21347, 1932, 6, 'Eind datum'),
(21348, 1934, 6, 'Effectiviteit'),
(21349, 1935, 6, 'EIN'),
(21350, 1936, 6, 'Ejaculaties'),
(21351, 1937, 6, 'Elleboog'),
(21352, 1938, 6, 'Problemen met elleboog'),
(21353, 1939, 6, 'Electronisch'),
(21354, 1942, 6, 'Electronische overschrijvingen'),
(21355, 1943, 6, 'Electronische rapporten'),
(21356, 1944, 6, 'In aanmerking komen'),
(21357, 1945, 6, 'In aanmerking komen voor 270 Batch informatie'),
(21358, 1946, 6, 'Eligibility respons'),
(21359, 1947, 6, 'Komt in aanmerking voor Vaccinatie voor kinderen'),
(21360, 1948, 6, 'In aanmerking komen'),
(21361, 1949, 6, 'E-mail'),
(21362, 1950, 6, 'E-mail'),
(21363, 1951, 6, 'E-mail adres'),
(21364, 1952, 6, 'E-mail adres is niet ingevuld'),
(21365, 1953, 6, 'E-mail adres verzender van patient reminders. Patient reminders die worden beantwoord worden naar dit adres doorgestuurd. Het is belangrijk om een een adres van het domein van de kliniek te gebruiken om patient reminders niet in de junk mail folders te laten belanden.'),
(21366, 1954, 6, 'E-mailadres, voor administratieve berichten.'),
(21367, 1955, 6, 'E-mailadres, indien bekend, om EMERGENCY gebruikers login om berichten te activeren.'),
(21368, 1956, 6, 'E-Mail auteur'),
(21369, 1957, 6, 'Berichtgeving per e-mail'),
(21370, 1958, 6, 'E-mail aanmelding'),
(21371, 1959, 6, 'E-mail notificatie uren'),
(21372, 1960, 6, 'E-mail notificatie rapport'),
(21373, 1961, 6, 'E-mal eerder verzonden'),
(21374, 1962, 6, 'E-mail afzender'),
(21375, 1963, 6, 'E-mail verzonden'),
(21376, 1964, 6, 'E-mail verzonden aan'),
(21377, 1965, 6, 'E-mail onderwerp'),
(21378, 1966, 6, 'E-mailadres: Tekst, Bruikbare Tag: *** *** NAAM, dwz Geachte NAAM *** ***'),
(21379, 1967, 6, 'E-mail Tekst, Bruikbare Tag: ***NAME*** ,b.v. Beste ***NAME***{{Niet vertalen ***NAME*** onderdelen van deze constant.}}'),
(21380, 1968, 6, 'E-mail verzend methode'),
(21381, 1969, 6, 'E-mail werd verzonden naar dit adres'),
(21382, 1971, 6, 'Spoedconsult'),
(21383, 1972, 6, 'Contactpersoon igv SPOED'),
(21384, 1973, 6, 'Bij SPOED bel:'),
(21385, 1974, 6, 'Nood contraceptie'),
(21386, 1975, 6, 'Spoed Login'),
(21387, 1976, 6, 'Spoed Login ACL is gekozen. The user is still in active state, please de-activate the user and activate the same when required during emergency situations. Visit Administration->Users for activation or de-activation.'),
(21388, 1977, 6, 'Spoed Login geactiveerd email will be circulated only if following settings in the interface/globals.php file are configured:'),
(21389, 1978, 6, 'EMERGENCY login e-mailadres'),
(21390, 1979, 6, 'Spoed Login gebruiker kan alles doen'),
(21391, 1980, 6, 'Noodtelefoonnr'),
(21392, 1981, 6, 'Emotionele / gedrags condities en complicaties'),
(21393, 1982, 6, 'Emfyseem'),
(21394, 1983, 6, 'Werknemer'),
(21395, 1984, 6, 'Werkgever'),
(21396, 1985, 6, 'Adres werkgever'),
(21397, 1986, 6, 'Gegevens werkgever'),
(21398, 1987, 6, 'Naam werkgever'),
(21399, 1988, 6, 'LEEG'),
(21400, 1989, 6, 'Leeg'),
(21401, 1990, 6, 'Leeg Paswoord is niet toegestaan'),
(21402, 1991, 6, 'Lege waarde "E-mail uren"'),
(21403, 1992, 6, 'Lege waarde "E-mail afzender"'),
(21404, 1993, 6, 'Lege waarde "E-mail onderwerp"'),
(21405, 1994, 6, 'Lege waarde "E-mail tekst"'),
(21406, 1995, 6, 'Lege waarde "Naam behandelaar"'),
(21407, 1996, 6, 'Lege waarde "Wachtwoord"'),
(21408, 1997, 6, 'Lege waarde "SMS uren"'),
(21409, 1998, 6, 'Lege waarde "SMS tekst'),
(21410, 1999, 6, 'Lege waarde "Gebruikersnaam"'),
(21411, 2001, 6, 'Toestaan'),
(21412, 2006, 6, 'Toestaan van AMC prompting'),
(21413, 2007, 6, 'Toestaan van AMC rapport geitimized'),
(21414, 2008, 6, 'Toestaan van AMC Reporting'),
(21415, 2009, 6, 'Toestaan AMC tracking'),
(21416, 2010, 6, 'Toestaan van aanpassingen mogelijkheid'),
(21417, 2011, 6, 'ATNA Auditing toestaan'),
(21418, 2012, 6, 'Toestaan van Audit log encryptie'),
(21419, 2013, 6, 'ATNA Auditing log aanmaken'),
(21420, 2014, 6, 'Sta Audit trail en Node Audentificatie toe (ATNA)'),
(21421, 2015, 6, 'Sta automatische meeting berekening verslaglegging toe ()AMC)'),
(21422, 2016, 6, 'Activeren client SSL'),
(21423, 2017, 6, 'Activeren cient SSL Certificaat Authentificatie'),
(21424, 2019, 6, 'Toestaan van Klinische Besluit regels (CDR)'),
(21425, 2022, 6, 'Toestaan Klinische kwaliteits metingen (CRD)'),
(21426, 2023, 6, 'Toestaan van Klinische reminder Popup'),
(21427, 2024, 6, 'Toestaan Klinische reminder widget'),
(21428, 2025, 6, 'CMS portaaal toestaan'),
(21429, 2026, 6, 'CQM Rapport voor Itemisatie teostaan'),
(21430, 2027, 6, 'Toestaan CQM verslaglegging'),
(21431, 2028, 6, 'Toestaan EDI geschiedenis in Linker Menu'),
(21432, 2030, 6, 'Linker menu gebruiken voor Honorarium saldi'),
(21433, 2031, 6, 'Hylafax ondersteuning toestaan'),
(21434, 2033, 6, 'Toestaan van import bericht voor NewCrop erx'),
(21435, 2034, 6, 'Toestaan van Itemisatie van AMC rapporten'),
(21436, 2035, 6, 'Toestaan van Itemisatie van CQM rappoerten'),
(21437, 2036, 6, 'Toestaan van standaard klinische regels rapoorten'),
(21438, 2037, 6, 'Lab uitwisseling toestaan'),
(21439, 2038, 6, 'Wisselen van slot toestaan'),
(21440, 2039, 6, 'Toestaan aanmaken van log voor documenten mbv CouchDB'),
(21441, 2040, 6, 'Vastleggen in log van al SQL SELECT queries toestaan'),
(21442, 2041, 6, 'Backup gebonden activiteiten toetstaan'),
(21443, 2042, 6, 'Toestaan vastleggen van CDR engine queries'),
(21444, 2043, 6, 'Toestaan van vastleggen diverse activiteiten'),
(21445, 2044, 6, 'Toestaan de volgorde vast te leggen en te veranderen'),
(21446, 2045, 6, 'Toestaan van vastleggen patient status veranderingen'),
(21447, 2046, 6, 'Toestaan van vastleggen van scheduling activiteiten'),
(21448, 2047, 6, 'Toestaan van veiligheid en administratie activiteiten'),
(21449, 2049, 6, 'Toestaan van NewCrop eRx Service'),
(21450, 2051, 6, 'Toestaan van Offsite patient portal'),
(21451, 2052, 6, 'Toestaan van Offsite patient portal.'),
(21452, 2053, 6, 'Toestaan onsite Patienten toegang'),
(21453, 2055, 6, 'Toestaan Onsite Patienten toegang.'),
(21454, 2056, 6, 'Toestaan Patienten Reminder widget'),
(21455, 2057, 6, 'Toestaan phiMail direct messaging Service'),
(21456, 2058, 6, 'Toestaan automatische meet berekeningen(AMC) noodzakelijke data'),
(21457, 2060, 6, 'Toestaan rapporteren van data tracking voor geautomatiseerde meet calculaties (AMC)'),
(21458, 2061, 6, 'Toestaan van ondersteuning met Scanner'),
(21459, 2062, 6, 'Aanmaken van standaard Rapport per item'),
(21460, 2063, 6, 'Aanmaken van WordPress ondersteuning door Sunset systems'),
(21461, 2064, 6, 'Toestaan van Medical Information Integration, LLC Lab uitwisseling Service.'),
(21462, 2065, 6, 'Toestaan van LibreEHR Ondersteuning LLC lab uitwisseling'),
(21463, 2066, 6, 'Activeer User Certificaat Authenticatie'),
(21464, 2067, 6, 'Toestaan ZMO LLC eRx service'),
(21465, 2068, 6, 'geactiveerd'),
(21466, 2070, 6, 'Activeert de oude manier van rekeningen sturen. Advies is echter gebruik de huidige Fee Sheet methode'),
(21467, 2071, 6, 'Enc'),
(21468, 2072, 6, 'Encounter'),
(21469, 2073, 6, 'Encounter'),
(21470, 2074, 6, 'encounter'),
(21471, 2075, 6, 'Encounter '),
(21472, 2076, 6, 'encounter acute inpatient of ED'),
(21473, 2080, 6, 'Encounter datum'),
(21474, 2081, 6, 'Encounter datum'),
(21475, 2084, 6, 'Encounter EDI record'),
(21476, 2086, 6, 'Encounter Formulier'),
(21477, 2087, 6, 'Evaluatie-encounter voor gezondheid en gedrag'),
(21478, 2088, 6, 'Encounter historie'),
(21479, 2089, 6, 'Encounter ID'),
(21480, 2090, 6, 'enounter voor influenza'),
(21481, 2091, 6, 'Episode nummer'),
(21482, 2093, 6, 'encounter verpleeg ontslag'),
(21483, 2094, 6, 'encounter verpleeghuis'),
(21484, 2095, 6, 'encounter'),
(21485, 2096, 6, 'encounter kantoor bezoek'),
(21486, 2097, 6, 'encounter outpatient'),
(21487, 2098, 6, 'encounter outpatient met/PCP & Ostetrie'),
(21488, 2099, 6, 'Encounter pagina afmetingen'),
(21489, 2100, 6, 'Encounter betaling'),
(21490, 2101, 6, 'encounter zwangerschap'),
(21491, 2102, 6, 'encounter preventief medisch- individuele counseling'),
(21492, 2103, 6, 'encounter preventief medisch 40 jaar en ouder'),
(21493, 2104, 6, 'encounter preventief medische groeps counseling'),
(21494, 2105, 6, 'encounter preventief medische en andere services'),
(21495, 2106, 6, 'encounter preventieve medische service 18 jaar en ouder'),
(21496, 2107, 6, 'encounter psychiatrie en psychologie'),
(21497, 2108, 6, 'Episode statistiek'),
(21498, 2109, 6, 'Episode samenvatting'),
(21499, 2110, 6, 'Episode werd gecodeerd'),
(21500, 2111, 6, 'Episode:'),
(21501, 2112, 6, 'Episode: episode niet acute inpatient, outpatient, of ophthalmologie'),
(21502, 2113, 6, 'Episoden'),
(21503, 2114, 6, 'Episoden en Formulieren'),
(21504, 2115, 6, 'Episoden & Formulieren'),
(21505, 2116, 6, 'Episoden niet geautoriseerd'),
(21506, 2117, 6, 'Episoden rapportage'),
(21507, 2118, 6, 'Episoden sectie'),
(21508, 2120, 6, 'Versleuteling'),
(21509, 2121, 6, 'Einde'),
(21510, 2122, 6, 'Eind (jjjj-mm-dd): '),
(21511, 2123, 6, 'Einddatum'),
(21512, 2124, 6, 'Einddatum'),
(21513, 2126, 6, 'Einddatum moet later dan begindatum vallen'),
(21514, 2127, 6, 'Einddatum:'),
(21515, 2130, 6, 'Einde van het rapport'),
(21516, 2131, 6, 'Eindtijd'),
(21517, 2132, 6, 'Eind stadium nierziekte begunstigde in MCP met werkgevers-groep-plan'),
(21518, 2133, 6, 'Datum einde van Service jjjj-mm-dd'),
(21519, 2134, 6, 'Einddatum DOS mm/dd/jjjj als u een periode wilt invullen'),
(21520, 2135, 6, 'Einde in uur notatie van de dag voor kalenderactiviteit'),
(21521, 2136, 6, 'Inwendig abnormaal bloedverlies');
INSERT INTO `lang_definitions` VALUES
(21522, 2137, 6, 'Endocrien'),
(21523, 2138, 6, 'Endoscopie'),
(21524, 2141, 6, 'Engels'),
(21525, 2142, 6, 'Engels '),
(21526, 2143, 6, 'Engels (India)'),
(21527, 2144, 6, 'Engels (Standaard)'),
(21528, 2145, 6, 'Enscript commandos gebruikt door Hylafax'),
(21529, 2146, 6, 'Zorg ervoor dat LibreEHR schrijf privileges heeft'),
(21530, 2147, 6, 'KNO afscheiding'),
(21531, 2148, 6, 'KNO pijn'),
(21532, 2149, 6, 'Voer diagnosecode in om alle facturen uit te sluiten die het NIET bevatten'),
(21533, 2150, 6, 'Een aanpassing aanbrengen'),
(21534, 2151, 6, 'Hier de BODY van brief invullen'),
(21535, 2152, 6, 'Invullen ROOT Paswoord voor DB'),
(21536, 2153, 6, 'Invullen ROOT Gebruikersnaam voor DB'),
(21537, 2154, 6, 'Invullen Diagnose'),
(21538, 2155, 6, 'Invullen Medicatie'),
(21539, 2156, 6, 'Enter Encounter'),
(21540, 2157, 6, 'Enter Encounter nummer'),
(21541, 2158, 6, 'Invullen Vaccinatie'),
(21542, 2159, 6, 'Enter key'),
(21543, 2160, 6, 'Nieuwe data invullen'),
(21544, 2161, 6, 'Nieuwe provincie/eiland toevoegen'),
(21545, 2162, 6, 'Enter Ontvanger''s adres'),
(21546, 2163, 6, 'Hier de LOINC codes voor Procedure invullen'),
(21547, 2164, 6, 'Invullen Re Identificatie code'),
(21548, 2165, 6, 'Vul uw zoek criteria hierboven in'),
(21549, 2166, 6, 'Enter is FOUT'),
(21550, 2167, 6, 'van zoekopdracht'),
(21551, 2168, 6, 'Omgeving gebonden'),
(21552, 2169, 6, 'EOB Data Invoer'),
(21553, 2170, 6, 'EOB Detachering - Elektronische geldovermakingen'),
(21554, 2171, 6, 'EOB Detachering - Instructies'),
(21555, 2172, 6, 'EOB Detachering - Factuur'),
(21556, 2173, 6, 'EOB Detachering - Patient opmerking'),
(21557, 2174, 6, 'EOB Detachering - Zoeken'),
(21558, 2176, 6, 'Epilepsie'),
(21559, 2178, 6, 'ERA'),
(21560, 2179, 6, 'ERA Files'),
(21561, 2180, 6, 'ERA vastleggen'),
(21562, 2181, 6, 'Verwijder'),
(21563, 2182, 6, 'Erecties'),
(21564, 2183, 6, 'FOUT'),
(21565, 2184, 6, 'FOUT'),
(21566, 2185, 6, 'FOUT bij bevestiging RX of Lab resultaat'),
(21567, 2187, 6, 'FOUT Geen Lab resultaten te krijgen van Lab Exchange netwerk'),
(21568, 2188, 6, 'FOUT in keuze geslacht'),
(21569, 2189, 6, 'FOUT in HIPAA selectie'),
(21570, 2190, 6, 'FOUT in Verwerking keuze'),
(21571, 2191, 6, 'FOUT bij het SMS Gateway selectie'),
(21572, 2192, 6, 'FOUT in "Sorteren op" keuze'),
(21573, 2193, 6, 'FOUT in gzip gecomprimeerde file '),
(21574, 2194, 6, 'FOUT in JA of NEE keuze'),
(21575, 2195, 6, 'FOUT bij lezen tijdens openen van ge-uploadde file'),
(21576, 2196, 6, 'FOUT bij verwerken van File'),
(21577, 2197, 6, 'FOUT bij Upload verwerking'),
(21578, 2198, 6, 'FOUT bij verwijderen bericht'),
(21579, 2199, 6, 'FOUT bij ophalen van Lab Uitwisselings Netwerk'),
(21580, 2200, 6, 'FOUT bij ophalen van waarden'),
(21581, 2201, 6, 'FOUT bij bewaren van het Document'),
(21582, 2202, 6, 'FOUT bij toekennen bestandprivileges aan LibreEHR gebruiker'),
(21583, 2205, 6, 'FOUT tijdens registreren van formulier'),
(21584, 2206, 6, 'FOUT tijdens bewaren van bestand opgetreden'),
(21585, 2208, 6, 'FOUT tijdens schrijven naar bestand'),
(21586, 2209, 6, 'FOUT gevonden bij nieuwe resultaten'),
(21587, 2210, 6, 'FOUT: het bestand bestaat niet'),
(21588, 2211, 6, 'FOUT: kon geen data van server ophalen'),
(21589, 2212, 6, 'FOUT: kan geen client certificaat aanmaken'),
(21590, 2213, 6, 'FOUT: kan geen admin.p12 certificaat aanmaken'),
(21591, 2214, 6, 'FOUT: kan geen Certificaat Ahtorithy certificaat aanmaken'),
(21592, 2215, 6, 'FOUT: Kan geen Server Certificaat aanmaken'),
(21593, 2216, 6, 'FOUT: kon bestand niet openen'),
(21594, 2217, 6, 'FOUT: User Certificaat Atuhenticatie is niet geactiveerd'),
(21595, 2218, 6, 'FOUT. Je moet de Archive/Tar.php php-module installeren.'),
(21596, 2219, 6, 'FOUT: kon tabel.sql niet openen, gebroken form?'),
(21597, 2220, 6, 'FOUT: Dubbele ID op lijn'),
(21598, 2221, 6, 'FOUT: Dubbele naam op lijn'),
(21599, 2222, 6, 'FOUT: Veld'),
(21600, 2223, 6, 'FOUT: ZipArchive PHP module niet gevonden'),
(21601, 2224, 6, 'FOUT: Geen ICD import folder.'),
(21602, 2225, 6, 'FOUT: wachtwoord komt niet overeen. Controleer op typfouten'),
(21603, 2226, 6, 'FOUT: wachtwoord komt niet overeen. Controleer op typfouten'),
(21604, 2227, 6, 'FOUT: het bestand bestaat niet'),
(21605, 2228, 6, 'FOUT: De volgende variabele bevat ongeldige tekens'),
(21606, 2229, 6, 'FOUT kan file niet copieeren'),
(21607, 2230, 6, 'FOUT: Het is niet mogelijk download-bare archief te creëren'),
(21608, 2231, 6, 'FOUT: Niet mogelijk een Zip Archief te maken'),
(21609, 2232, 6, 'FOUT: Niet mogelijk de file te extraheren'),
(21610, 2233, 6, 'FOUT: Niet mogelijk de file te laden naar de Database'),
(21611, 2234, 6, 'FOUT: Versie nummer niet mogelijk aan te maken.'),
(21612, 2235, 6, 'FOUTEN'),
(21613, 2236, 6, 'eRx Account status'),
(21614, 2237, 6, 'eRX Rekening status'),
(21615, 2238, 6, 'ERX Naam'),
(21616, 2239, 6, 'ERX Passwoord'),
(21617, 2240, 6, 'ERX rol'),
(21618, 2241, 6, 'ERX User'),
(21619, 2242, 6, 'Erytheem:'),
(21620, 2243, 6, 'electronisch tekeken'),
(21621, 2244, 6, 'Log voor electronisch tekenen'),
(21622, 2245, 6, 'Eskimo'),
(21623, 2246, 6, 'Esperanto'),
(21624, 2247, 6, 'Bekende patient'),
(21625, 2248, 6, 'Estland'),
(21626, 2249, 6, 'Etniciteit'),
(21627, 2250, 6, 'Ras of afkomst'),
(21628, 2251, 6, 'Afkomst-Ras lijst (schrijven,toevoegen optioneel)'),
(21629, 2252, 6, 'ETIN'),
(21630, 2253, 6, 'Gebeurtenis'),
(21631, 2254, 6, 'Start gebeurtenis'),
(21632, 2255, 6, 'Gebeurtenis categorie'),
(21633, 2256, 6, 'Gebeurtenis datum'),
(21634, 2257, 6, 'Gebeurtenis omschrijving'),
(21635, 2258, 6, 'Gebeurtenis details'),
(21636, 2259, 6, 'Gebeurtenis zonder herhaling'),
(21637, 2260, 6, 'Duur van gebeurtenis'),
(21638, 2261, 6, 'Duur gebeurtenis in minuten'),
(21639, 2262, 6, 'Bedrag van gebeurtenis'),
(21640, 2263, 6, 'Locatie gebeurtenis'),
(21641, 2264, 6, 'Gebeurtenis herhaalt zich iedere'),
(21642, 2265, 6, 'Gebeurtenius herhaalt zich op'),
(21643, 2266, 6, 'Gebeurtenis startdatum'),
(21644, 2267, 6, 'Gebeurtenis titel'),
(21645, 2268, 6, 'Gebeurtenis titel'),
(21646, 2269, 6, 'Website gebeurtenis'),
(21647, 2270, 6, 'Gebeurtenissen in blok laten zien'),
(21648, 2271, 6, 'Gebeurtenissen voor'),
(21649, 2272, 6, 'Gebeurtenis opent nieuw venster'),
(21650, 2273, 6, 'iedere'),
(21651, 2274, 6, 'Iedere'),
(21652, 2275, 6, 'iedere 3 uur'),
(21653, 2276, 6, 'iedere 4 uur'),
(21654, 2277, 6, 'iedere 5 uur'),
(21655, 2278, 6, 'iedere 6 uur'),
(21656, 2279, 6, 'iedere 8 uur'),
(21657, 2280, 6, 'Iedere vierde'),
(21658, 2281, 6, 'Ieder ander'),
(21659, 2282, 6, 'Iedere derde'),
(21660, 2283, 6, 'Iedere, om de, iedere 3e, etc.'),
(21661, 2284, 6, 'Ewe'),
(21662, 2285, 6, 'Onderzoeks- en testresultaten'),
(21663, 2286, 6, 'Onderzoeksresultaten'),
(21664, 2289, 6, 'Onderzoek'),
(21665, 2290, 6, 'Datum onderzoek'),
(21666, 2291, 6, 'Voorbeeld'),
(21667, 2292, 6, 'Voorbeelden'),
(21668, 2293, 6, 'Onderzoek en lab.testen'),
(21669, 2294, 6, 'Uitgezonderd'),
(21670, 2295, 6, 'Buitengewoon scheuren'),
(21671, 2296, 6, 'Patienten eitgezonderd'),
(21672, 2297, 6, 'Uitzonderingen'),
(21673, 2298, 6, 'Exclusieve Organisatie van behandelaar (EPO)'),
(21674, 2299, 6, 'Executive (maat voor papier)'),
(21675, 2300, 6, 'Oefenen'),
(21676, 2301, 6, 'Soort oefeningen'),
(21677, 2302, 6, 'Soort oefeningen'),
(21678, 2303, 6, 'Bestaat'),
(21679, 2304, 6, 'Uit Admin weggaan'),
(21680, 2305, 6, 'Exp'),
(21681, 2306, 6, 'Uitvouwen'),
(21682, 2307, 6, 'uitvouwen'),
(21683, 2308, 6, 'Alles uitvouwen'),
(21684, 2311, 6, 'Uitgevouwen scherm'),
(21685, 2312, 6, 'Verwacht formulier_ontmoeting. pid om te zijn '),
(21686, 2313, 6, 'Verloopdatum'),
(21687, 2314, 6, 'Vervaldatum'),
(21688, 2315, 6, 'Verloopt'),
(21689, 2316, 6, 'verloopt in'),
(21690, 2317, 6, 'Exporteren'),
(21691, 2318, 6, 'Exporteren als CSV'),
(21692, 2319, 6, 'Configuratie exporteren'),
(21693, 2322, 6, 'Exporteer patientpersoonsgegevens'),
(21694, 2323, 6, 'Exporteren PQRI rapport'),
(21695, 2325, 6, 'Exporteer geselecteerde als CSV'),
(21696, 2326, 6, 'Exporteer geselecteerde naar Verzamelingen'),
(21697, 2327, 6, 'Exporteren naar CSV'),
(21698, 2328, 6, 'Exporteren naar extern factureringssysteem'),
(21699, 2329, 6, 'Is in buitenland geweest'),
(21700, 2330, 6, 'Komt recent uit buitenland'),
(21701, 2331, 6, 'Ext. tijd verzameld'),
(21702, 2332, 6, 'Uitwendig'),
(21703, 2334, 6, 'Externe data Loads'),
(21704, 2335, 6, 'Extras d.m.v. externe-Database imports'),
(21705, 2336, 6, 'Extern-ID'),
(21706, 2337, 6, 'Extern ID'),
(21707, 2338, 6, 'Extern-ID'),
(21708, 2339, 6, 'Niet medewerkers'),
(21709, 2342, 6, 'Verwijzing naar'),
(21710, 2343, 6, 'Verwijzing naar elders, follow-ups'),
(21711, 2344, 6, 'Verwijzing naar elders?'),
(21712, 2345, 6, 'Externe verwijzingen'),
(21713, 2346, 6, 'Zip file extraheren'),
(21714, 2347, 6, 'File extraheren. Dit kost even tijd.....'),
(21715, 2348, 6, 'Exudaat:'),
(21716, 2349, 6, 'Oogirritatie'),
(21717, 2350, 6, 'Oogpijn'),
(21718, 2351, 6, 'Roodheid oog'),
(21719, 2352, 6, 'Ogen'),
(21720, 2353, 6, 'F'),
(21721, 2354, 6, 'FH Bloedproblemen'),
(21722, 2355, 6, 'FH Vrouw Hirsutisme/Striea'),
(21723, 2356, 6, 'Locaties'),
(21724, 2357, 6, 'Locatie'),
(21725, 2358, 6, 'locatie'),
(21726, 2359, 6, 'Administratie locatie'),
(21727, 2360, 6, 'Stad van Faciliteit'),
(21728, 2361, 6, 'Lokatie-Code'),
(21729, 2362, 6, 'Faciliteit landen code'),
(21730, 2363, 6, 'Faciliteit Fax'),
(21731, 2364, 6, 'Naam Locatie'),
(21732, 2365, 6, 'Registr.# van Locatie'),
(21733, 2366, 6, 'Faciliteit telefoon'),
(21734, 2367, 6, 'Faciliteit specifieke User informatie'),
(21735, 2368, 6, 'Faciliteit staat'),
(21736, 2369, 6, 'Faciliteit straat'),
(21737, 2370, 6, 'Faciliteit Zip'),
(21738, 2372, 6, 'Locatie:'),
(21739, 2373, 6, 'MISLUKT'),
(21740, 2374, 6, 'mislukt'),
(21741, 2375, 6, 'Mislukt'),
(21742, 2376, 6, 'Mislukte patienten'),
(21743, 2377, 6, 'Niet gelukt om patient aan Portaal toe te voegen'),
(21744, 2378, 6, 'Niet gelukt een unieke file naam te geven'),
(21745, 2379, 6, 'Niet gelukt om aan te maken'),
(21746, 2380, 6, 'Aanmaken tijdelijke folder mislukt. CouchDB zal niet werken'),
(21747, 2382, 6, 'Mislukt.'),
(21748, 2383, 6, 'mislukking'),
(21749, 2384, 6, 'Mislukking'),
(21750, 2385, 6, 'Notitie van mislukking: Directe boodschap sturen is mislukt.'),
(21751, 2390, 6, 'Familiegeschiedenis'),
(21752, 2391, 6, 'Familiaire belasting Glaucoma'),
(21753, 2392, 6, 'Familiaire belasting:'),
(21754, 2394, 6, 'Betaling voor familie'),
(21755, 2395, 6, 'Familiegrootte'),
(21756, 2396, 6, 'Fancy'),
(21757, 2397, 6, 'Faroese'),
(21758, 2398, 6, 'Farsi'),
(21759, 2400, 6, 'VaderHistorie van vader'),
(21760, 2401, 6, 'Vermoeid'),
(21761, 2402, 6, 'Vermoeidheid'),
(21762, 2403, 6, 'Vermoeid'),
(21763, 2404, 6, 'Fax'),
(21764, 2405, 6, 'Totaal faxen'),
(21765, 2406, 6, 'Faxnummer'),
(21766, 2408, 6, 'Fax/Scan'),
(21767, 2409, 6, 'Fax ingekomen'),
(21768, 2410, 6, 'Fax uitgegaan'),
(21769, 2411, 6, 'Mogelijkheden'),
(21770, 2412, 6, 'Feb'),
(21771, 2413, 6, 'Februari'),
(21772, 2414, 6, 'FECA'),
(21773, 2415, 6, 'Medicijn ID-nummer overheid'),
(21774, 2416, 6, 'Federale EIN'),
(21775, 2417, 6, 'CRIB nummer'),
(21776, 2418, 6, 'Tarief'),
(21777, 2419, 6, 'tarief'),
(21778, 2420, 6, 'Kan niet in rekening gebracht worden'),
(21779, 2421, 6, 'Financieel werkblad'),
(21780, 2422, 6, 'Optie voor Honorarium formulier'),
(21781, 2423, 6, 'Financieel'),
(21782, 2424, 6, 'Vrouw'),
(21783, 2425, 6, 'Vrouw AP (Abortus Provocatus)'),
(21784, 2426, 6, 'Vrouwencondoom'),
(21785, 2427, 6, 'Vrouw G (Gravida)'),
(21786, 2428, 6, 'Vrouw LC (Living Children)'),
(21787, 2429, 6, 'Vrouw P (Partus)'),
(21788, 2430, 6, 'Symptomen vrouw'),
(21789, 2431, 6, 'Vrouw VSC'),
(21790, 2432, 6, 'Opzoeken'),
(21791, 2433, 6, 'De volgende file opzoeken via de Portaal'),
(21792, 2434, 6, 'Koorts'),
(21793, 2435, 6, 'Koorts:'),
(21794, 2436, 6, 'FH Bloedproblemen'),
(21795, 2437, 6, 'Fibroiden'),
(21796, 2438, 6, 'Veld'),
(21797, 2439, 6, 'Veld ''naam'' kan niet NULL zijn'),
(21798, 2441, 6, 'Veldtype te gebruiken voor werkgever of ingeschrevene als Land in Demografie'),
(21799, 2442, 6, 'Veldtype te gebruiken voor werkgever of ingeschrevene als Staat in Demografie'),
(21800, 2443, 6, 'Veld(en) niet aangemaakt'),
(21801, 2446, 6, 'Fijan'),
(21802, 2447, 6, 'Bestand'),
(21803, 2448, 6, 'bestand in de Documentatie-map om te leren hoe automatische backups van log te maken'),
(21804, 2449, 6, 'Bestandslocatie'),
(21805, 2450, 6, 'FIle management'),
(21806, 2453, 6, 'File pivilege toegekend aan LibreEHR gebruiker'),
(21807, 2454, 6, 'Oproepen van File uit CouchDB mislukt'),
(21808, 2455, 6, 'Archiefruimte'),
(21809, 2456, 6, 'File om te uploaden'),
(21810, 2457, 6, 'File om te uploaden'),
(21811, 2458, 6, 'Bestand met dezelfde naam bestaat reeds op locatie:'),
(21812, 2459, 6, 'Bestandsnaam'),
(21813, 2460, 6, 'Naam van de file moet eindigen op ".pdf"'),
(21814, 2461, 6, 'Files'),
(21815, 2462, 6, 'Filipijn'),
(21816, 2463, 6, 'Vul een of meer van de vakken in onderstaande RIJ'),
(21817, 2464, 6, 'Dit alleen invullen als de patient een e-mail bericht krijgt'),
(21818, 2465, 6, 'Waarden hier beneden invullen'),
(21819, 2467, 6, 'Vul de RIJ'),
(21820, 2468, 6, 'Filter'),
(21821, 2469, 6, 'Filter voor Constanten'),
(21822, 2470, 6, 'Filter voor Definities'),
(21823, 2471, 6, 'gefilterd uit'),
(21824, 2472, 6, 'filters'),
(21825, 2473, 6, 'Filters'),
(21826, 2474, 6, 'Eind'),
(21827, 2475, 6, 'Einddiagnose'),
(21828, 2476, 6, 'Einddiagnose volgens specialist'),
(21829, 2478, 6, 'Financieel'),
(21830, 2479, 6, 'Financiele sluitings datum (jjjj-mm-dd)'),
(21831, 2480, 6, 'Financieel overzicht - alles'),
(21832, 2481, 6, 'Financieel overzicht - mijn contacten'),
(21833, 2482, 6, 'Datum financiele aanpassingen'),
(21834, 2483, 6, 'Financiele samenvatting op Service Code'),
(21835, 2484, 6, 'Zoek'),
(21836, 2485, 6, 'Zoek beschikbaar'),
(21837, 2486, 6, 'Zoek beschikbare afspraaktijden'),
(21838, 2487, 6, 'Zoek pt'),
(21839, 2488, 6, 'Zoek naar Patienten voorlichtingsmateriaal'),
(21840, 2489, 6, 'Evaluatie'),
(21841, 2490, 6, 'Evaluatie gegevens specialist'),
(21842, 2491, 6, 'Boete'),
(21843, 2492, 6, 'Afronden betalingen'),
(21844, 2493, 6, 'beeindigd'),
(21845, 2494, 6, 'Eind'),
(21846, 2495, 6, 'Eerste'),
(21847, 2497, 6, 'Eerste weekdag'),
(21848, 2498, 6, 'Voornaam'),
(21849, 2499, 6, 'Voornaam'),
(21850, 2500, 6, 'Voornaam:'),
(21851, 2501, 6, 'Eerste bezoek of consultatie'),
(21852, 2502, 6, 'Voornaam Achternaam'),
(21853, 2503, 6, 'Recreatie Sporten'),
(21854, 2504, 6, 'Mate van Fitness'),
(21855, 2505, 6, 'Mate van Fitness voor deze speler voor deze dag'),
(21856, 2506, 6, 'Tesste van conditie'),
(21857, 2507, 6, 'Gezond om te spelen'),
(21858, 2508, 6, 'Herstel contactdatums- maak een keuze'),
(21859, 2509, 6, 'Corrigeer dit'),
(21860, 2510, 6, 'FL'),
(21861, 2511, 6, 'Flatulentie'),
(21862, 2512, 6, 'Stroom'),
(21863, 2514, 6, 'Influenza seizoen'),
(21864, 2515, 6, 'Influenza seizoen'),
(21865, 2516, 6, 'Griepprik'),
(21866, 2517, 6, 'Probleem met vloeistof en electrolyten'),
(21867, 2518, 6, 'FMS'),
(21868, 2519, 6, 'Folio (papier maat)'),
(21869, 2520, 6, 'Handmatig controleren'),
(21870, 2521, 6, 'Volg deze instructies voor installeren en upgrading van de database'),
(21871, 2522, 6, 'Follow up'),
(21872, 2524, 6, 'Follow up Reden'),
(21873, 2525, 6, 'Volgende is een nieuwe zelf aangemaakte constante'),
(21874, 2526, 6, 'Volgende is een nieuwe zelf aangemaakte taal:'),
(21875, 2527, 6, 'Volgende is een nieuwe definitie (Taal, Constante, Definitie):'),
(21876, 2528, 6, 'De volgende regels van de AUDIT log zijn aangepast'),
(21877, 2529, 6, 'Follow up Services'),
(21878, 2530, 6, 'Follow up geindiceerd'),
(21879, 2531, 6, 'Voedselintolerantie'),
(21880, 2532, 6, 'Voet'),
(21881, 2533, 6, 'Voetproblemen'),
(21882, 2534, 6, 'Voet:'),
(21883, 2535, 6, 'Voetbalblessures'),
(21884, 2536, 6, 'Voetbalblessure'),
(21885, 2537, 6, 'Voetbalblessure rapport'),
(21886, 2538, 6, 'Soort schoeisel'),
(21887, 2539, 6, 'voor'),
(21888, 2540, 6, 'Voor'),
(21889, 2541, 6, 'Voor Code'),
(21890, 2543, 6, 'Voor Encounter Claims'),
(21891, 2544, 6, 'Bijvoorbeeld:'),
(21892, 2545, 6, 'Voor HCFA 02/12 Box 15 is Andere Datum een kwalifier om te specificeren welke datum bedoeld wordt'),
(21893, 2546, 6, 'Voor HCFA 02/12 Begin Datum gespecificeerd op het Encounter formulier moet een kwalifier hebben'),
(21894, 2547, 6, 'voor invoice'),
(21895, 2548, 6, 'Alleen voor Medicare, hierdoor is de verwijzende zorgaanbieder dezelfde als de dienstverlenende zorgaanbieder.'),
(21896, 2549, 6, 'voor OBR plaats bestel nummer'),
(21897, 2550, 6, 'voor patient'),
(21898, 2552, 6, 'Voor de dienstverlenende zorgaanbieder/behandelaar'),
(21899, 2553, 6, 'Voor voorgaande'),
(21900, 2554, 6, 'Voor variabelen'),
(21901, 2555, 6, 'voor:'),
(21902, 2556, 6, 'Force openen van -In Rekening Bengen- Widget'),
(21903, 2557, 6, 'Aanmaken nieuwe patient forceren'),
(21904, 2558, 6, 'Forceer laten zien'),
(21905, 2559, 6, 'Onderarm'),
(21906, 2560, 6, 'Formulier'),
(21907, 2561, 6, 'formulier'),
(21908, 2562, 6, 'Formulier element niet gevonden'),
(21909, 2563, 6, 'Formulier is met succes getekend'),
(21910, 2564, 6, 'Vormgeving'),
(21911, 2565, 6, 'format'),
(21912, 2566, 6, 'Format voor leeftijd tonen'),
(21913, 2567, 6, 'Format ongeschikt voor Med Code'),
(21914, 2568, 6, 'Het format om de meeste datums te tonen'),
(21915, 2569, 6, 'Het format om de tijd merendeels te tonen'),
(21916, 2570, 6, 'Geformatteerd rapport'),
(21917, 2571, 6, 'Was roker'),
(21918, 2572, 6, 'Formulieren'),
(21919, 2573, 6, 'Administratie van formulieren'),
(21920, 2575, 6, 'Voorwaarts'),
(21921, 2576, 6, 'Stuur pagina''s door met Fax'),
(21922, 2577, 6, 'Ge-forward'),
(21923, 2579, 6, 'Vierde'),
(21924, 2581, 6, 'Fractuur'),
(21925, 2582, 6, 'Fractuur os naviculare'),
(21926, 2583, 6, 'Fractuur malleolus lat.'),
(21927, 2584, 6, 'Fractuur malleolus med.'),
(21928, 2585, 6, 'Fractuur basis metatarsale 5'),
(21929, 2586, 6, 'Frame ondersteuning verplicht'),
(21930, 2587, 6, 'Frans'),
(21931, 2588, 6, 'Frans (Canadees)'),
(21932, 2589, 6, 'Frans (Standaard)'),
(21933, 2590, 6, 'Frequentie'),
(21934, 2591, 6, 'Frequentie verkoudheid'),
(21935, 2592, 6, 'Frequente ziekte'),
(21936, 2593, 6, 'Vrij'),
(21937, 2594, 6, 'Vrijdag'),
(21938, 2595, 6, 'Van'),
(21939, 2596, 6, 'VAN'),
(21940, 2597, 6, 'van'),
(21941, 2598, 6, 'Vanaf datum kan niet later vallen dan heden'),
(21942, 2599, 6, 'Van:'),
(21943, 2600, 6, 'Van: '),
(21944, 2601, 6, 'VAN_STAD'),
(21945, 2602, 6, 'VAN_EMAIL'),
(21946, 2603, 6, 'VAN_VNAAM'),
(21947, 2604, 6, 'VAN_LNAAM'),
(21948, 2605, 6, 'VAN_MNAAM'),
(21949, 2606, 6, 'VAN_TELEFOON'),
(21950, 2607, 6, 'VAN_MOBIELTEL'),
(21951, 2608, 6, 'VAN_POSTCODE'),
(21952, 2609, 6, 'VAN_STAAT'),
(21953, 2610, 6, 'VAN_STRAAT'),
(21954, 2611, 6, 'VAN_TITEL'),
(21955, 2612, 6, 'VAN_VALEDICTORY'),
(21956, 2613, 6, 'Balie'),
(21957, 2614, 6, 'Front Office kwitantie'),
(21958, 2615, 6, 'Samenvatting Baliekwitanties'),
(21959, 2616, 6, 'Kwitantie balie'),
(21960, 2617, 6, 'Frontaal rechts'),
(21961, 2618, 6, 'Fula-Fulah-Pulaar-Pular'),
(21962, 2619, 6, 'Volledige naam'),
(21963, 2620, 6, 'Volledige pad naar de folder met de MySQL executables.'),
(21964, 2621, 6, 'Volledige pad naar de folder met de Perl executables'),
(21965, 2622, 6, 'Volledige pad naar de folder voor de log backup'),
(21966, 2623, 6, 'Volledige pad naar de folder gebrukit voor tijdelijke bestanden'),
(21967, 2624, 6, 'Volledige spelen'),
(21968, 2625, 6, 'Volledige training'),
(21969, 2626, 6, 'Volledig betaald'),
(21970, 2631, 6, 'Toekomst'),
(21971, 2633, 6, 'G'),
(21972, 2634, 6, 'G/DL'),
(21973, 2635, 6, 'Galicisch'),
(21974, 2636, 6, 'Galblaasconditie'),
(21975, 2637, 6, 'Galstenen'),
(21976, 2638, 6, 'Wedstrijdduur'),
(21977, 2639, 6, 'Spellen'),
(21978, 2640, 6, 'Gemiste spelen'),
(21979, 2641, 6, 'Spelen/Gebeurtenissen'),
(21980, 2642, 6, 'Spelen/Gemiste gebeurtenissen'),
(21981, 2643, 6, 'Ganda'),
(21982, 2644, 6, 'Gastritis'),
(21983, 2645, 6, 'Maagpijn'),
(21984, 2646, 6, 'Gastro-Intestinaal'),
(21985, 2647, 6, 'GCAC Statistiek verslag'),
(21986, 2648, 6, 'GCAC Statistiek'),
(21987, 2649, 6, 'GCAC bezoek formulier afwezig'),
(21988, 2650, 6, 'Geslacht'),
(21989, 2651, 6, 'Geslacht '),
(21990, 2652, 6, 'Algemeen'),
(21991, 2653, 6, 'Algemene probleem lijst'),
(21992, 2655, 6, 'Categorie voor Algemene Service'),
(21993, 2656, 6, 'Aanmaken'),
(21994, 2657, 6, 'Schriftelijk Claimformulier HCFA 1500 aanmaken en downloaden'),
(21995, 2658, 6, 'Schriftelijk Claimformulier HCFA 1500 aanmaken en downloaden'),
(21996, 2659, 6, 'Aanmaken en downloaden X12 batch'),
(21997, 2660, 6, 'Genereren en downloaden van X12 consultatie claim batchj'),
(21998, 2663, 6, 'Aanmaken en electronisch versturen van toegestaande voorschriften.'),
(21999, 2664, 6, 'CMS 1500 aanmaken'),
(22000, 2665, 6, 'CMS 1500 PDF aanmaken'),
(22001, 2666, 6, 'CMS 1500 TEKST aanmaken'),
(22002, 2667, 6, 'HCFA aanmaken'),
(22003, 2668, 6, 'Invoice aanmaken'),
(22004, 2669, 6, 'Brief maken'),
(22005, 2670, 6, 'Brief aanmaken voor '),
(22006, 2671, 6, 'PQRI rapport aanmaken (Methode A)'),
(22007, 2672, 6, 'PQRI Rapport aanmaken (Methode A)-2011'),
(22008, 2673, 6, 'PQRI rapport aanmaken (Methode E)'),
(22009, 2674, 6, 'PQRI Rapport aanmaken (Methode E) - 2011'),
(22010, 2677, 6, 'Rapport aanmaken'),
(22011, 2678, 6, 'Maak User en Paswoord aan voor'),
(22012, 2679, 6, 'X12 aanmaken'),
(22013, 2680, 6, 'X12 Encounter aanmaken'),
(22014, 2682, 6, 'Aangemaakt op'),
(22015, 2683, 6, 'Genereren'),
(22016, 2684, 6, 'Genito-Urinair'),
(22017, 2686, 6, 'Georgisch'),
(22018, 2687, 6, 'Duits'),
(22019, 2691, 6, 'HL7 code ophalen'),
(22020, 2692, 6, 'Glaucoom'),
(22021, 2693, 6, 'Familiegeschiedenis met Glaucoom'),
(22022, 2694, 6, 'Globaal'),
(22023, 2696, 6, 'Global ID'),
(22024, 2697, 6, 'Globale sttings'),
(22025, 2698, 6, 'Algemeen'),
(22026, 2699, 6, 'GM/DL'),
(22027, 2700, 6, 'save'),
(22028, 2701, 6, 'Ga'),
(22029, 2704, 6, 'Ga naar'),
(22030, 2705, 6, 'Ga naar de week van'),
(22031, 2706, 6, 'Naar vandaag gaan'),
(22032, 2707, 6, 'Doel A'),
(22033, 2708, 6, 'Doel en Methodes'),
(22034, 2709, 6, 'Doel B'),
(22035, 2710, 6, 'Doel C'),
(22036, 2711, 6, 'Ernst van het letsel'),
(22037, 2712, 6, 'Graad:'),
(22038, 2713, 6, 'gram'),
(22039, 2714, 6, 'Totaal van alles'),
(22040, 2715, 6, 'Totalen van alles'),
(22041, 2718, 6, 'Is grafiek van te maken'),
(22042, 2720, 6, 'Groter dan'),
(22043, 2721, 6, 'Groter dan of gelijk aan'),
(22044, 2722, 6, 'Grieks'),
(22045, 2723, 6, 'Ggrieks, modern'),
(22046, 2724, 6, 'Groep'),
(22047, 2725, 6, 'Groepsnaam'),
(22048, 2726, 6, 'Groepsnamen kunnen niet blanco zijn'),
(22049, 2727, 6, 'Groepsnamen kunnen niet met nummers of spaties beginnen'),
(22050, 2728, 6, 'Groepsnamen mogen niet met cijfers beginnen.'),
(22051, 2729, 6, 'Groepsnummer'),
(22052, 2730, 6, 'Groeps betaling'),
(22053, 2731, 6, 'Groep:'),
(22054, 2732, 6, 'Groepsnaam'),
(22055, 2733, 6, 'Groeps- en toegangscontroles'),
(22056, 2734, 6, 'Groei Curves'),
(22057, 2735, 6, 'Groei Curves'),
(22058, 2736, 6, 'druppels'),
(22059, 2737, 6, 'Guamaniaan'),
(22060, 2738, 6, 'Guarani'),
(22061, 2739, 6, 'Naam voogd'),
(22062, 2740, 6, 'Gujarati'),
(22063, 2741, 6, 'Gynaecologisch onderzoek'),
(22064, 2742, 6, 'h'),
(22065, 2743, 6, 'h.s.'),
(22066, 2744, 6, 'H/O Hepatitis'),
(22067, 2745, 6, 'Succesvol verwijderd. De eventueel aanwezige subcategorieen zijn verplaatst naar onderen'),
(22068, 2746, 6, 'Hematoom/kneuzing'),
(22069, 2747, 6, 'HAI status'),
(22070, 2748, 6, 'Hatiaans - Haitiaans creools'),
(22071, 2750, 6, 'Hand en vingers'),
(22072, 2751, 6, 'Problemen van de hand'),
(22073, 2752, 6, 'Harde schijf'),
(22074, 2753, 6, 'Tegenslag met/zonder'),
(22075, 2754, 6, 'is gekoppeld aan visite'),
(22076, 2755, 6, 'is verlopen'),
(22077, 2756, 6, 'Hash'),
(22078, 2757, 6, 'Hash bestaat niet voor deze file . Een nieuwe Hash is aangemaakt.'),
(22079, 2758, 6, 'Hash is klopt niet. Data integriteit is onvolledig.'),
(22080, 2759, 6, 'Hausa'),
(22081, 2760, 6, 'Hawaiaan'),
(22082, 2761, 6, 'Gevaarlijke activiteiten'),
(22083, 2762, 6, 'Gevaarlijke activiteiten'),
(22084, 2763, 6, 'Linkermarge HCFA in punten'),
(22085, 2764, 6, 'Marges HCFA'),
(22086, 2765, 6, 'Bovenmarge in punten'),
(22087, 2766, 6, 'HCPCS Procedure-Service'),
(22088, 2767, 6, 'he PostCalendar '),
(22089, 2768, 6, 'Hoofd'),
(22090, 2769, 6, 'Hoofdomt.'),
(22091, 2770, 6, 'Hoofdomtrek'),
(22092, 2771, 6, 'Hoofdpijn'),
(22093, 2772, 6, 'Hoofdpijnen'),
(22094, 2773, 6, 'zorg interventies'),
(22095, 2774, 6, 'Zorg interventies'),
(22096, 2775, 6, 'Medisch Centrum/Kliniek'),
(22097, 2776, 6, 'Heath Maintenance Organization'),
(22098, 2777, 6, 'HMO Medicare Risicos'),
(22099, 2778, 6, 'Gehoorverlies'),
(22100, 2779, 6, 'Hartaanval'),
(22101, 2780, 6, 'Hartziekte'),
(22102, 2781, 6, 'Decompensatio Cordis'),
(22103, 2782, 6, 'Hartprobleem'),
(22104, 2783, 6, 'Hartproblemen'),
(22105, 2784, 6, 'Hartchirurgie'),
(22106, 2785, 6, 'Harttransplantatie'),
(22107, 2786, 6, 'HART:'),
(22108, 2787, 6, 'Hartbranden'),
(22109, 2788, 6, 'Warm of koud'),
(22110, 2789, 6, 'Warm of koud'),
(22111, 2790, 6, 'Zware tabak gebruiker'),
(22112, 2791, 6, 'Hebreeuws'),
(22113, 2792, 6, 'Hebreeuws - modern'),
(22114, 2793, 6, 'HEENT'),
(22115, 2794, 6, 'Lengte'),
(22116, 2795, 6, 'Hoogte/Lengte'),
(22117, 2796, 6, 'Help'),
(22118, 2797, 6, 'help'),
(22119, 2798, 6, 'Hematemesis'),
(22120, 2799, 6, 'Hematochezia'),
(22121, 2800, 6, 'Hematologisch'),
(22122, 2801, 6, 'Hematurie'),
(22123, 2802, 6, 'Hemoglobine'),
(22124, 2803, 6, 'HbA1c'),
(22125, 2804, 6, 'Bloed ophoesten'),
(22126, 2805, 6, 'Hepatitis'),
(22127, 2806, 6, 'Hepatitis A 1'),
(22128, 2807, 6, 'Hepatitis A 2'),
(22129, 2808, 6, 'Hepatitis B 1'),
(22130, 2809, 6, 'Hepatitis B 2'),
(22131, 2810, 6, 'Hepatitis B 3'),
(22132, 2811, 6, 'klik hier'),
(22133, 2812, 6, 'Herero'),
(22134, 2813, 6, 'Hernia herstel'),
(22135, 2814, 6, 'HNP'),
(22136, 2815, 6, 'Herpes'),
(22137, 2816, 6, 'Aarzelend'),
(22138, 2817, 6, 'hallo daar, je bent hier geweest voor '),
(22139, 2818, 6, 'HIB 1'),
(22140, 2819, 6, 'HIB 2'),
(22141, 2820, 6, 'HIB 3'),
(22142, 2821, 6, 'HIB 4'),
(22143, 2822, 6, 'Verborgen'),
(22144, 2823, 6, 'Verborgen gebeurtenis administratie'),
(22145, 2824, 6, 'Verbergen'),
(22146, 2825, 6, 'Verberg details'),
(22147, 2826, 6, 'Lege E-Sign logs op rapport niet tonen'),
(22148, 2827, 6, 'Verberg versleutel/ontcijfer Opties in Document Management'),
(22149, 2828, 6, 'Verberg menu'),
(22150, 2830, 6, 'Verberg reminders'),
(22151, 2831, 6, 'Verberg/Toon kolommen'),
(22152, 2833, 6, 'Hoog'),
(22153, 2834, 6, 'Hoge bloeddruk'),
(22154, 2835, 6, 'Hindi'),
(22155, 2836, 6, 'Heup en liezen'),
(22156, 2837, 6, 'Heup en liezen'),
(22157, 2838, 6, 'Heupproblemen'),
(22158, 2839, 6, 'Heupvervanging'),
(22159, 2840, 6, 'HIPAA notitie ontvangen'),
(22160, 2841, 6, 'Hiri Motu'),
(22161, 2842, 6, 'Hirsutisme/Striae'),
(22162, 2843, 6, 'Spaans'),
(22163, 2844, 6, 'Spaans - anders (geb. in USA)'),
(22164, 2845, 6, 'Spaans - anders (geb. niet USA)'),
(22165, 2846, 6, 'Spaans of Latino'),
(22166, 2847, 6, 'Historie'),
(22167, 2848, 6, 'Voorgeschiedenis(sen)'),
(22168, 2849, 6, 'Datum van historie'),
(22169, 2851, 6, 'Geruis in verleden'),
(22170, 2852, 6, 'Historie niet geauthoriseerd'),
(22171, 2853, 6, 'Hartsoufle in verleden'),
(22172, 2854, 6, 'Slagen'),
(22173, 2855, 6, 'HIV'),
(22174, 2858, 6, 'HL7 bekijken'),
(22175, 2860, 6, 'HMOL/L'),
(22176, 2861, 6, 'Hmong'),
(22177, 2862, 6, 'Druk op [Ctrl] voor meerdere keuze''s of om selectie ongedaan te maken'),
(22178, 2863, 6, 'Druk op Ctrl om meerdere items te selecteren'),
(22179, 2864, 6, 'Druk op Ctrl om meerdere groepen te selecteren'),
(22180, 2865, 6, 'Start'),
(22181, 2866, 6, 'Tel. prive'),
(22182, 2867, 6, 'Tel. prive'),
(22183, 2868, 6, 'Dakloos of vergelijkbaar'),
(22184, 2869, 6, 'Dakloos, enz'),
(22185, 2870, 6, 'Dakloos enz.'),
(22186, 2871, 6, 'Ankers'),
(22187, 2872, 6, 'Computernaam'),
(22188, 2873, 6, 'Computernaam mag niet leeg zijn'),
(22189, 2875, 6, 'Uur'),
(22190, 2876, 6, 'Uren'),
(22191, 2878, 6, 'Hoe ontstond letsel?'),
(22192, 2879, 6, 'Hoe ontstond letsel?:'),
(22193, 2880, 6, 'Hoe hebben ze over ons gehoord'),
(22194, 2881, 6, 'Hoeveel maanden wilt u vooruit zoeken voor de lopende gebeurtenissen?'),
(22195, 2882, 6, 'HPI:'),
(22196, 2883, 6, 'HT'),
(22197, 2884, 6, 'HTML'),
(22198, 2885, 6, 'HTML Output?'),
(22199, 2886, 6, 'HTTPS link voor ondersteuning van LLC Lab Exchange Service'),
(22200, 2887, 6, 'Hongaars'),
(22201, 2888, 6, 'Hyllafax directory'),
(22202, 2889, 6, 'Halafax ENscriptie commando'),
(22203, 2890, 6, 'Hylafax Server'),
(22204, 2891, 6, 'Hylafax Server Hostnaam'),
(22205, 2892, 6, 'Hyperactief'),
(22206, 2893, 6, 'Hoge bloeddruk'),
(22207, 2894, 6, 'Hypertensie: Bloeddruk meting'),
(22208, 2895, 6, 'Hypertensie: Bloeddruk meting (CQM)'),
(22209, 2896, 6, 'Hyperthyreoidie'),
(22210, 2897, 6, 'Hypothyreoidie'),
(22211, 2898, 6, 'Hysterectomie'),
(22212, 2899, 6, 'I'),
(22213, 2900, 6, 'In deze tijd ben ik bezig.'),
(22214, 2901, 6, 'Ik mag dit niet lezen '),
(22215, 2902, 6, 'ICD'),
(22216, 2903, 6, 'ICD10 Diagnoses'),
(22217, 2904, 6, 'ICD10 Procedures-Service'),
(22218, 2905, 6, 'ICD9'),
(22219, 2906, 6, 'ICD9 Diagnoses'),
(22220, 2907, 6, 'ICD9Procedures-Service'),
(22221, 2908, 6, 'Ijslands'),
(22222, 2909, 6, 'ID'),
(22223, 2910, 6, 'Id'),
(22224, 2911, 6, 'ID moet ingevuld zijn'),
(22225, 2912, 6, 'ID kaart'),
(22226, 2913, 6, 'IDagen'),
(22227, 2914, 6, 'geïdentificeerd als'),
(22228, 2915, 6, 'Identifier(een woord)'),
(22229, 2916, 6, 'Code indentificeren'),
(22230, 2917, 6, 'Timeout in seconden tijdens niet gebruik'),
(22231, 2918, 6, 'Ido'),
(22232, 2919, 6, 'Als alle gegevens voor alle kolommen volledig zijn voor dit formulier'),
(22233, 2920, 6, 'Als Billing Justificatie wordt gebruikt, vul dan de naam van de diagnose code type in'),
(22234, 2921, 6, 'Indien gevuld, kies alles zij die deze service gehad hebben'),
(22235, 2922, 6, 'Als naam, een deel van achternaam of achternaam, voornaam'),
(22236, 2923, 6, 'Als betaling is voor'),
(22237, 2924, 6, 'Als persoon overleden is dan de datum van overlijden invullen'),
(22238, 2925, 6, 'Als SMTP wordt gebrukt, de hostnaam van server of IP adres gebruiken'),
(22239, 2926, 6, 'Als SMTP wordt gebruikt, het TCO poortnummer van de server gebruiken (meestal 25)'),
(22240, 2927, 6, 'indien werkloos kies: Student'),
(22241, 2928, 6, 'Als de keuze gemaakt is voor JMD tonen, verander in alleen Jaren als de patient ouder is dan deze waare in jaren'),
(22242, 2929, 6, 'Als U eRx Role voor e-receptenwijzigd, kan het de e-Recepten workflow beinvloeden. Als je problemen ondervindt vraag advies aan de e-Recepten verkoper.'),
(22243, 2930, 6, 'Als je geen gelijke vindt wordt de patient aangemaakt.'),
(22244, 2931, 6, 'Als u heeft gekozen voor het uploaden van elektronisch afdrachten, dan zal het zoekvenster opnieuw zelf met de bijbehorende facturen van de X12-bestand invullen. U klikt op een van deze factuurnummers (zoals hieronder beschreven), indien u eventuele correcties wil maken voordat de afdracht informatie wordt toegepast Voor de toepassing van de wijzigingen, klikt u op het proces ERA File knop aan de onderkant van de pagina. Dit zal een nieuw venster met een gedetailleerd rapport tonen.'),
(22245, 2932, 6, 'Als u een Pay Datum in de zoekresultaten pagina invoert, zal dit voorrang krijgen op de terbeschikkingstelling datum van de betalingen en de aanpassingen die anders uit de X12-bestand worden opgehaald. Dit kan handig zijn voor rapportage doeleinden, als u wilt dat uw inkomsten rapportage gebruik je je posting datum eerder dan de verzekeringsmaatschappij de verwerking datum. Merk op dat dit ook invloed heeft op de data van voorafgaande betalingen en aanpassingen die in het secundaire claims zijn gedaan.'),
(22246, 2933, 6, 'Als u data types wilt wijzigen, of rijen of kolommen wilt toevoegen'),
(22247, 2934, 6, 'Indien de Database ge-upraded wordt, plaats de database zip file in de volgende map'),
(22248, 2935, 6, 'Igbo'),
(22249, 2936, 6, 'Geen aandacht geven'),
(22250, 2937, 6, 'Ziekte'),
(22251, 2938, 6, 'Intra musculair'),
(22252, 2941, 6, 'Beeldvorming Service'),
(22253, 2942, 6, 'Vaccinatie'),
(22254, 2943, 6, 'Immunisatie code'),
(22255, 2945, 6, 'Immunizatie datum'),
(22256, 2946, 6, 'Immunizatie verloop datum'),
(22257, 2947, 6, 'Lotnummer van vaccinatie'),
(22258, 2948, 6, 'Fabrikant van vaccinatie'),
(22259, 2949, 6, 'Immunisatie register'),
(22260, 2950, 6, 'Immunisatie rapport'),
(22261, 2951, 6, 'Immunizatie Service'),
(22262, 2952, 6, 'Immunisatie titel'),
(22263, 2953, 6, 'Vaccinaties'),
(22264, 2954, 6, 'Vaccineren'),
(22265, 2955, 6, 'Immunologisch'),
(22266, 2956, 6, 'Implantaties'),
(22267, 2957, 6, 'Importeren'),
(22268, 2961, 6, 'Certificaat importeren naar de browser'),
(22269, 2962, 6, 'Configuratie importeren'),
(22270, 2963, 6, 'Importeren verlegd voor de tijd-nog-actief'),
(22271, 2964, 6, 'Importeer patient'),
(22272, 2965, 6, 'Importeer persoonsgeg. van client'),
(22273, 2966, 6, 'Belangrijke Codes'),
(22274, 2967, 6, 'BELANGRIJK: This upload tool is only for uploading documents on patients that are not yet entered into the system. To upload files for patients whom already have been entered into the system, please use the upload tool linked within the Patient Summary screen.'),
(22275, 2969, 6, 'Geimporteerd van accountantrekening'),
(22276, 2972, 6, 'Verbeterd'),
(22277, 2973, 6, 'in'),
(22278, 2974, 6, 'IN'),
(22279, 2975, 6, 'in beide ogen'),
(22280, 2976, 6, 'in linker oog'),
(22281, 2977, 6, 'in neusgat'),
(22282, 2978, 6, 'Op kantoor'),
(22283, 2979, 6, 'in rechteroog'),
(22284, 2980, 6, 'op voorraad'),
(22285, 2981, 6, 'Inactief'),
(22286, 2982, 6, 'Dagen inactiviteit'),
(22287, 2983, 6, 'Inbox'),
(22288, 2986, 6, 'Controlecijfer toevoegen'),
(22289, 2987, 6, 'Toevoegen afgerond'),
(22290, 2988, 6, 'Ook de inactieve gebruikers'),
(22291, 2989, 6, 'Niet-categoriseerd toevoegen'),
(22292, 2990, 6, 'Ongestructureerde data toevoegen'),
(22293, 2991, 6, 'Voeg vitals toe'),
(22294, 2992, 6, 'Vitale data toevoegen?'),
(22295, 2993, 6, 'Inclusie'),
(22296, 2994, 6, 'Inkomsten'),
(22297, 2995, 6, 'Binnen gekomen resultaten vragen aandacht:'),
(22298, 2996, 6, 'Onvolledig'),
(22299, 2997, 6, 'Onvolledige abortusbehandeling'),
(22300, 2998, 6, 'Incontinentie'),
(22301, 2999, 6, 'Klinische lab-test resultaten toevoegen in certified EHR technologie als gestructureerde data.'),
(22302, 3000, 6, 'Onjuist paswoord'),
(22303, 3001, 6, 'Verhoogd:'),
(22304, 3002, 6, 'Vrijwaring Verzekeringen'),
(22305, 3003, 6, 'Onbepaald'),
(22306, 3004, 6, 'Indier'),
(22307, 3005, 6, 'Geeft abnormaliteit aan'),
(22308, 3006, 6, 'Geef aan of dit probleem nu actief is'),
(22309, 3008, 6, 'Indicator voor gespecialiseert gebruik'),
(22310, 3009, 6, 'Minvermogende patienten'),
(22311, 3010, 6, 'Raport minvermogende ptn'),
(22312, 3011, 6, 'Minvermogend'),
(22313, 3013, 6, 'Indonesisch'),
(22314, 3014, 6, 'Opgewekte abortus'),
(22315, 3016, 6, 'Komt er niet voor in aanmerking'),
(22316, 3017, 6, 'Infectie/Abces'),
(22317, 3018, 6, 'Infecties'),
(22318, 3019, 6, 'Couns.voor Infert'),
(22319, 3020, 6, 'Onvruchtbaar'),
(22320, 3021, 6, 'Influenza 1'),
(22321, 3022, 6, 'Influenza 2'),
(22322, 3023, 6, 'Influenza Immunisatie voor patienten vanaf 50 jaar oud'),
(22323, 3024, 6, 'Infleunza Immunisatie voor patienten vanaf 50 jaar oud (CQM)'),
(22324, 3025, 6, 'Influenza vaccin'),
(22325, 3026, 6, 'Info'),
(22326, 3027, 6, 'Info test 1'),
(22327, 3028, 6, 'Info test 2'),
(22328, 3029, 6, 'Info test 3'),
(22329, 3030, 6, 'Info test 4'),
(22330, 3031, 6, 'Info test 5'),
(22331, 3032, 6, 'Info test 6'),
(22332, 3034, 6, 'inhalaties'),
(22333, 3035, 6, 'inhilaties'),
(22334, 3036, 6, 'Begin behandeling'),
(22335, 3037, 6, 'Eerste gebruiker'),
(22336, 3038, 6, 'Inj/Rehab'),
(22337, 3039, 6, 'Injecteerbaar'),
(22338, 3040, 6, 'Injectie'),
(22339, 3041, 6, 'Verwond lichaamsdeel'),
(22340, 3042, 6, 'Gewond vertrokken'),
(22341, 3043, 6, 'Letsel'),
(22342, 3044, 6, 'Schade Mechanisme'),
(22343, 3045, 6, 'Overzicht letsel rapport'),
(22344, 3046, 6, 'Letsel surveillance'),
(22345, 3047, 6, 'Soort letsel'),
(22346, 3048, 6, 'Letsel/ziekte-gerelateerd'),
(22347, 3049, 6, 'Inlijn'),
(22348, 3050, 6, 'Input begint niet met een MSH gedeelte'),
(22349, 3051, 6, 'Invoervelden'),
(22350, 3052, 6, 'INR'),
(22351, 3053, 6, 'Ins 1'),
(22352, 3054, 6, 'Ins 2 of Ins 3'),
(22353, 3055, 6, 'Ins adres'),
(22354, 3056, 6, 'Ins aanpassen'),
(22355, 3057, 6, 'Ins bundeling'),
(22356, 3058, 6, 'Ins Code'),
(22357, 3059, 6, 'Ins Groep'),
(22358, 3060, 6, 'Ins Naam'),
(22359, 3061, 6, 'Ins te veel betaald'),
(22360, 3062, 6, 'Ins beleidslijn'),
(22361, 3063, 6, 'Ins restitutie'),
(22362, 3064, 6, 'Ins samenvatting'),
(22363, 3065, 6, 'Ins1'),
(22364, 3066, 6, 'Ins2'),
(22365, 3067, 6, 'Ins3'),
(22366, 3068, 6, 'Invoegen'),
(22367, 3069, 6, 'Invoegen mislukt: '),
(22368, 3070, 6, 'Voeg oude gebeurtenis toe aan tabel'),
(22369, 3072, 6, 'Slapeloosheid'),
(22370, 3073, 6, 'Controleer het log'),
(22371, 3074, 6, 'Inspectie'),
(22372, 3075, 6, 'Onstabiliteit/Subluxatie'),
(22373, 3076, 6, 'INSTALLEREN'),
(22374, 3077, 6, 'Installeren'),
(22375, 3078, 6, 'Code set installeren'),
(22376, 3079, 6, 'installeer DB'),
(22377, 3080, 6, 'Geinstalleerde Release'),
(22378, 3081, 6, 'Geinstrueerd'),
(22379, 3082, 6, 'Instructie'),
(22380, 3084, 6, 'Instructies:'),
(22381, 3085, 6, 'Te weinig voorraad voor product met dit ID'),
(22382, 3086, 6, 'IDDM'),
(22383, 3087, 6, 'Verzekering'),
(22384, 3088, 6, 'verzekering'),
(22385, 3091, 6, 'Verzekerings balans'),
(22386, 3092, 6, 'Verzekerings balans bedrag'),
(22387, 3093, 6, 'Verzekeringsmij.'),
(22388, 3094, 6, 'Verzekeringsmij-en'),
(22389, 3095, 6, 'Verzekeringsmij.'),
(22390, 3096, 6, 'Verzekeringsmij. zoeken/toevoegen'),
(22391, 3098, 6, 'Verzekeringsgegevens'),
(22392, 3099, 6, 'Opgeslagen Verzekerings gegevens'),
(22393, 3100, 6, 'Verzekering leverings gegevens'),
(22394, 3101, 6, 'Verzekerings betaling'),
(22395, 3103, 6, 'Betalende Instantie'),
(22396, 3104, 6, 'Type verzekeringen'),
(22397, 3105, 6, 'verzekeringen'),
(22398, 3106, 6, 'Verzekerde'),
(22399, 3107, 6, 'Intakegesprek'),
(22400, 3108, 6, 'Intakedatum'),
(22401, 3109, 6, 'Intellectuele achteruitgang'),
(22402, 3110, 6, 'Interlingua'),
(22403, 3111, 6, 'Interlingue'),
(22404, 3113, 6, 'Foutje - er werden geen paginas geselecteerd!'),
(22405, 3114, 6, 'Foutje - geen patient ID ingevoerd!'),
(22406, 3115, 6, 'Foutje- de ge-upload-de file kan niet gelezen worden'),
(22407, 3116, 6, 'Intern foutje'),
(22408, 3117, 6, 'Intern foutje, geen medicatie ID aangegeven!'),
(22409, 3118, 6, 'Foutje - geclaimde'),
(22410, 3119, 6, 'Foutje - schuld '),
(22411, 3120, 6, 'Foutje - contact '''),
(22412, 3121, 6, 'Foutje - pid of contact is kwijt.'),
(22413, 3122, 6, 'Foutje - het lijkt erop dat we werken niet in Encounter!'),
(22414, 3123, 6, 'Intern gebruikte ID (pid)'),
(22415, 3126, 6, 'Interne verwijzingen'),
(22416, 3127, 6, 'Interne tijd opgezocht'),
(22417, 3128, 6, 'Internationale Dienst'),
(22418, 3129, 6, 'Tolk'),
(22419, 3130, 6, 'Tolk nodig?'),
(22420, 3131, 6, 'Interstitiele longziekte'),
(22421, 3132, 6, 'Interval'),
(22422, 3133, 6, 'Interval (minuten)'),
(22423, 3134, 6, 'Interval tussen controle van berichten (Als dit op nul gezet wordt is alleen handmatige controle mogleijk)'),
(22424, 3135, 6, 'Interventie'),
(22425, 3136, 6, 'Interventie verstrekt'),
(22426, 3137, 6, 'Intolerantie'),
(22427, 3139, 6, 'intramusculair'),
(22428, 3140, 6, 'intraveneus'),
(22429, 3141, 6, 'Introductie'),
(22430, 3142, 6, 'Inuktitut'),
(22431, 3143, 6, 'Inupiaq'),
(22432, 3144, 6, 'Verkeerd karakter gebruikt in'),
(22433, 3146, 6, 'Ongeldige ingekapselde data type codering'),
(22434, 3147, 6, 'Niet valide lengte voor'),
(22435, 3148, 6, 'Niet geaccepteerde numerieke waarde in'),
(22436, 3149, 6, 'Ongeldige of ontbrekende betaler bron voor code '),
(22437, 3150, 6, 'Ongeldig adres van Ontvanger. Probeer opnieuw.'),
(22438, 3151, 6, 'Ongeldige Service Codes'),
(22439, 3152, 6, 'Ongeldige bron bestemming'),
(22440, 3153, 6, 'Ongeladige User-naam of Paswoord'),
(22441, 3154, 6, 'InvAmt'),
(22442, 3155, 6, 'Inventaris'),
(22443, 3156, 6, 'Inventaris activiteit'),
(22444, 3157, 6, 'Inventaris bij verkoop van medicijnen en andere niet medicijnen'),
(22445, 3158, 6, 'Inventaris en alleen verkoop van medicijnen'),
(22446, 3159, 6, 'Inventaris is niet beschikbaar voor deze bestelling.'),
(22447, 3160, 6, 'Inventarislijst'),
(22448, 3161, 6, 'Inventaris transacties'),
(22449, 3162, 6, 'Rekening'),
(22450, 3163, 6, 'rekening'),
(22451, 3164, 6, 'Invoice balans'),
(22452, 3165, 6, 'Invoice balans kan niet verwerkt worden. Geen encounter aangemaakt.'),
(22453, 3166, 6, 'Datum rekening'),
(22454, 3167, 6, 'Rekening heeft geen datum'),
(22455, 3168, 6, 'Invoice nummer'),
(22456, 3169, 6, 'Invoice referentienummer'),
(22457, 3170, 6, 'Invoice referentiegroeps nummer, indien gebruikt'),
(22458, 3171, 6, 'Invoice referentie groepsnummer'),
(22459, 3172, 6, 'Invoice Referentie No voor groep'),
(22460, 3173, 6, 'Rekening:'),
(22461, 3174, 6, 'IPPF (Int Planned Parenthood Federation)'),
(22462, 3175, 6, 'IPPF Abortus'),
(22463, 3176, 6, 'IPPF Anti-conceptie'),
(22464, 3177, 6, 'IPPF SRH Gegevens voor'),
(22465, 3178, 6, 'IPPF Overzicht met statistieken'),
(22466, 3179, 6, 'IPPF Statistiek rapport'),
(22467, 3180, 6, 'IPV 1'),
(22468, 3181, 6, 'IPV 2'),
(22469, 3182, 6, 'IPV 3'),
(22470, 3183, 6, 'IPV 4'),
(22471, 3184, 6, 'Iewrs'),
(22472, 3185, 6, 'Onregelmatige hartslag'),
(22473, 3186, 6, 'Geirriteerd'),
(22474, 3187, 6, 'Irritatie'),
(22475, 3188, 6, 'de volgende Database is van een andere language versie.'),
(22476, 3189, 6, 'de volgende Database is van een andere versie'),
(22477, 3190, 6, 'is een recentere versie van de volgende database'),
(22478, 3191, 6, 'Verplicht veld.'),
(22479, 3192, 6, 'dit is een basis node en kan niet verwijderd worden'),
(22480, 3193, 6, 'is van een extensie van de volgende Database'),
(22481, 3194, 6, 'Is het de bedoeling deze CVX codes toe te voegen aan reeds bestaande vacinaties?'),
(22482, 3195, 6, 'is verkeerd geplaatst of onbekend'),
(22483, 3197, 6, 'is niet geldig (decimale breuken OK).'),
(22484, 3198, 6, 'Werkt PHP in veilige modus?'),
(22485, 3200, 6, 'Moet de tekst van Layouts vertaald worden?'),
(22486, 3201, 6, 'Moet de tekst van lijsten vertaald worden?'),
(22487, 3202, 6, 'Is de file versleuteld?'),
(22488, 3203, 6, 'Id dit een klinische term code type?'),
(22489, 3204, 6, 'Is dit een diagnose type?'),
(22490, 3205, 6, 'Is dit een Medisch Probleem code type'),
(22491, 3206, 6, 'Is dit een soort Medicijn?'),
(22492, 3207, 6, 'Is dit een procedure-service type?'),
(22493, 3208, 6, 'Is dit actief?'),
(22494, 3209, 6, 'Is dit type code geactiveerd?'),
(22495, 3210, 6, 'Wordt deze type code gebrukt in claims?'),
(22496, 3211, 6, 'Is dit echt goed?'),
(22497, 3212, 6, 'Wordt dit type verborgen in de Honorering velden?'),
(22498, 3213, 6, 'Worden hierbij extrene sql tabellen gebruikt? Alleen dan deze format gebruiken.'),
(22499, 3214, 6, 'is te lang'),
(22500, 3215, 6, 'ISO 639-2 Code'),
(22501, 3216, 6, 'Probleem'),
(22502, 3217, 6, 'probleem'),
(22503, 3218, 6, 'Issue Datum'),
(22504, 3219, 6, 'Issue ID'),
(22505, 3220, 6, 'Issue Titel'),
(22506, 3221, 6, 'Issue type'),
(22507, 3222, 6, 'Issues Types'),
(22508, 3223, 6, 'Problemen'),
(22509, 3224, 6, 'Problemen (Letsel/Medisch/Allergie)'),
(22510, 3225, 6, 'Problemen (Letsel/Medisch/Allergie):'),
(22511, 3226, 6, 'Problemen en Contacten'),
(22512, 3227, 6, 'Problemen en Contacten voor'),
(22513, 3228, 6, 'Niet geautoriseerde problemen'),
(22514, 3229, 6, 'Problemen sectie'),
(22515, 3230, 6, 'Italiaan'),
(22516, 3231, 6, 'Item'),
(22517, 3232, 6, 'item'),
(22518, 3233, 6, 'Items'),
(22519, 3234, 6, 'Items laden is mislukt'),
(22520, 3235, 6, 'IU/L'),
(22521, 3236, 6, 'IUD'),
(22522, 3237, 6, 'Intra veneus'),
(22523, 3238, 6, 'Jan'),
(22524, 3239, 6, 'Januari'),
(22525, 3240, 6, 'Japans'),
(22526, 3241, 6, 'Icterus'),
(22527, 3242, 6, 'Javaans'),
(22528, 3243, 6, 'Functie-omschrijving'),
(22529, 3244, 6, 'Functie-ID'),
(22530, 3245, 6, 'Gewricht uit de kom geschoten'),
(22531, 3246, 6, 'Gewrichtspijn'),
(22532, 3247, 6, 'Verstuikt gewricht'),
(22533, 3248, 6, 'Jul'),
(22534, 3249, 6, 'Juli'),
(22535, 3250, 6, 'Jun'),
(22536, 3251, 6, 'Juni'),
(22537, 3252, 6, 'Net onder de controle-informatie is een blauwe zone waar je in je zoekopdracht parameters kunt invoeren. Je kunt zoeken op naam patiënt, kaart nummer, ontmoetings nummer of op datum dienstverlening, of een combinatie hiervan. Je kunt ook kiezen om u alle facturen, openstaande facturen of alleen niet op tijd betaalde facturen (door de patiënt) wilt zien. Klik op ZOEKEN om de opdracht te geven.'),
(22538, 3253, 6, 'Alleen die van mij'),
(22539, 3254, 6, 'Invullingdie geaccordeerd moeten worden'),
(22540, 3255, 6, 'Accorderen'),
(22541, 3256, 6, 'Accorderen /Opslaan'),
(22542, 3257, 6, 'J{{Jusitfy Header}}'),
(22543, 3258, 6, 'k, hier is de rest'),
(22544, 3259, 6, 'Kalaalisut, Groenlands'),
(22545, 3260, 6, 'Kannada'),
(22546, 3261, 6, 'Kanuri'),
(22547, 3262, 6, 'Kashmiri'),
(22548, 3263, 6, 'Kazakstaans'),
(22549, 3264, 6, 'Sleutel'),
(22550, 3265, 6, 'Sleutelwoorden'),
(22551, 3266, 6, 'kg'),
(22552, 3267, 6, 'kg/m^2'),
(22553, 3268, 6, 'Khmer'),
(22554, 3269, 6, 'Nierkanker'),
(22555, 3270, 6, 'Nierfalen'),
(22556, 3271, 6, 'Nierinfectie'),
(22557, 3272, 6, 'Nierstenen'),
(22558, 3273, 6, 'Niertransplantatie'),
(22559, 3274, 6, 'Kikuyu, Gikuyu'),
(22560, 3275, 6, 'Kinyarwanda'),
(22561, 3276, 6, 'Kirundi'),
(22562, 3277, 6, 'Knie'),
(22563, 3278, 6, 'Knieproblemen'),
(22564, 3279, 6, 'Knievervanging'),
(22565, 3280, 6, 'Komi'),
(22566, 3281, 6, 'Congo'),
(22567, 3282, 6, 'Koreaan'),
(22568, 3283, 6, 'Kurdisch'),
(22569, 3284, 6, 'Kwanyama, Kuanyama'),
(22570, 3285, 6, 'Kirgisisch'),
(22571, 3286, 6, 'Lab'),
(22572, 3287, 6, 'Lab documenten'),
(22573, 3288, 6, 'SIte address van Lab Uitwisseling'),
(22574, 3289, 6, 'SIte Lab Exchange ID'),
(22575, 3290, 6, 'Lab Exchange Token ID'),
(22576, 3291, 6, 'Lab aanvragen'),
(22577, 3292, 6, 'Lab overzicht'),
(22578, 3293, 6, 'Lab overzicht'),
(22579, 3294, 6, 'Lab Querry status'),
(22580, 3295, 6, 'Lab rapport'),
(22581, 3296, 6, 'Lab resulaat'),
(22582, 3297, 6, 'Lab resultaten'),
(22583, 3298, 6, 'Lab resultaten Categorie naam'),
(22584, 3299, 6, 'Lab resultaten Rapport'),
(22585, 3300, 6, 'Lab Service'),
(22586, 3301, 6, 'Lab test resultaten'),
(22587, 3302, 6, 'Lab/File'),
(22588, 3303, 6, 'Label'),
(22589, 3304, 6, 'Label mag niet leeg zijn'),
(22590, 3305, 6, 'Label Cols'),
(22591, 3306, 6, 'Label voor dit type'),
(22592, 3307, 6, 'LabelCols met een getal tussen 1 en 999 zijn'),
(22593, 3308, 6, 'Labels'),
(22594, 3311, 6, 'Labs'),
(22595, 3312, 6, 'Scheurwond/huidprobleem'),
(22596, 3313, 6, 'Scheurwond/schaafwond'),
(22597, 3315, 6, 'Landscape'),
(22598, 3316, 6, 'Taal'),
(22599, 3317, 6, 'Code vd taal'),
(22600, 3318, 6, 'Taaldefinitie toegevoegd'),
(22601, 3319, 6, 'Taalinterface gereedschap'),
(22602, 3320, 6, 'Talenlijst (schrijven,toevoegen optioneel)'),
(22603, 3321, 6, 'Naam van de taal'),
(22604, 3322, 6, 'Taal:'),
(22605, 3323, 6, 'Lao'),
(22606, 3324, 6, 'Laotiaan'),
(22607, 3325, 6, 'Laatste'),
(22608, 3326, 6, 'Laatste activiteitdatum'),
(22609, 3327, 6, 'Appendectomie gedaan op'),
(22610, 3328, 6, 'Laatste rekeningdatum'),
(22611, 3329, 6, 'Laatse borst onderzoek'),
(22612, 3330, 6, 'Laatste kalender jaar'),
(22613, 3331, 6, 'Laatste Cataract opreatie'),
(22614, 3332, 6, 'Cholecysectomie gedaan op'),
(22615, 3333, 6, 'Laatste Episode'),
(22616, 3334, 6, 'Laatste Gyn onderzoek'),
(22617, 3335, 6, 'Laatste Hart operatie'),
(22618, 3336, 6, 'Laatste Hernia operatie'),
(22619, 3337, 6, 'Laaste heup vervanging'),
(22620, 3338, 6, 'Hysterctomie gedaan op'),
(22621, 3339, 6, 'Laaste knie vervanging'),
(22622, 3340, 6, 'Laatste level in rekening gebracht'),
(22623, 3341, 6, 'Laatste Mammogram'),
(22624, 3342, 6, 'Laatste menstruatie'),
(22625, 3343, 6, 'Laatste maand'),
(22626, 3344, 6, 'Achternaam'),
(22627, 3345, 6, 'Achternaam'),
(22628, 3346, 6, 'Achternaam:'),
(22629, 3347, 6, 'Laatste algemeen lich. onderzoek'),
(22630, 3348, 6, 'Laatste prostaat onderzoek'),
(22631, 3349, 6, 'Laatste rectale onderzoek'),
(22632, 3350, 6, 'Laatst beoordeeld'),
(22633, 3351, 6, 'Laatste RUN begonnen om'),
(22634, 3352, 6, 'Laatst bewaard'),
(22635, 3353, 6, 'Laatste Sigmoid/Coloscopy ond.'),
(22636, 3355, 6, 'Tonsilectomie gedaan op'),
(22637, 3356, 6, 'Laatste update door'),
(22638, 3357, 6, 'Laatste controle aan'),
(22639, 3358, 6, 'Laatste bezoek'),
(22640, 3359, 6, 'Laatste X-ray onderzoek'),
(22641, 3360, 6, 'Laat recidief (2-12 mnd)'),
(22642, 3361, 6, 'Laterale malleolus'),
(22643, 3362, 6, 'Laterale malleolus:'),
(22644, 3363, 6, 'Laterality'),
(22645, 3364, 6, 'Laterality van deze procedure, indien toepasbaar'),
(22646, 3365, 6, 'lateraal verplaatste PMI:'),
(22647, 3367, 6, 'Laatste bezoek of consultatie'),
(22648, 3368, 6, 'Latijn'),
(22649, 3369, 6, 'Latviaans'),
(22650, 3372, 6, 'Opmaak'),
(22651, 3373, 6, 'Mijn formulieren'),
(22652, 3374, 6, 'Weergave-editor'),
(22653, 3375, 6, 'Layout groepen'),
(22654, 3376, 6, 'Layout stijl'),
(22655, 3378, 6, 'Layout gebaseerde formulieren'),
(22656, 3379, 6, 'Weergave'),
(22657, 3380, 6, 'lb'),
(22658, 3381, 6, 'lbs'),
(22659, 3382, 6, 'LDL'),
(22660, 3383, 6, 'OPEN LATEN indien nog actief'),
(22661, 3384, 6, 'Open laten om originele file naam te behouden'),
(22662, 3385, 6, 'OPEN LATEN om wachtwoord te behouden'),
(22663, 3386, 6, 'Laat bericht achter bij'),
(22664, 3387, 6, 'Stoppen'),
(22665, 3388, 6, 'Als de paswoord zin blank wordt gelaten, wordt het document niet versleuteld'),
(22666, 3390, 6, 'Links'),
(22667, 3391, 6, 'Linkeroor'),
(22668, 3392, 6, 'linkeroor'),
(22669, 3393, 6, 'Links:'),
(22670, 3394, 6, 'Links:'),
(22671, 3395, 6, 'Links: '),
(22672, 3396, 6, 'Pijn in been/Kramp'),
(22673, 3397, 6, 'Juridisch'),
(22674, 3399, 6, 'Legal (papier maat)'),
(22675, 3400, 6, 'Legenda:'),
(22676, 3401, 6, 'Lengte'),
(22677, 3402, 6, 'Lengte van de modifier of 0 als er geen is'),
(22678, 3403, 6, 'Minder dan'),
(22679, 3404, 6, 'Minder dan of gelijk met'),
(22680, 3405, 6, 'Minder prive-informatie (schrijven,toevoegen optioneel)'),
(22681, 3406, 6, 'Brief'),
(22682, 3407, 6, 'Brief aanmaken'),
(22683, 3408, 6, 'Letter (papier maat)'),
(22684, 3409, 6, 'Brief-deel voor arts ondertekening'),
(22685, 3410, 6, 'Brief-deel voor client ondertekening'),
(22686, 3411, 6, 'Hoeveel spoed'),
(22687, 3412, 6, 'Aansprakelijkheid'),
(22688, 3413, 6, 'Medische aansprakelijkheid'),
(22689, 3414, 6, 'Rijbewijs/ID'),
(22690, 3419, 6, 'Achternaam gediplomeerd voorschrijver'),
(22691, 3420, 6, 'NPI van gediplomeerd voorschrijver'),
(22692, 3421, 6, 'UPIN van gediplomeerd voorscrhijver'),
(22693, 3423, 6, 'Leefwijze'),
(22694, 3424, 6, 'Leefwijze status'),
(22695, 3425, 6, 'Ligament scheur of verzwikt'),
(22696, 3426, 6, 'Matige tabaks roker'),
(22697, 3427, 6, 'Limburgs, Limburgiaans, Limburger'),
(22698, 3428, 6, 'Maximaal aantal gebeurtenissen'),
(22699, 3429, 6, 'Limieten'),
(22700, 3430, 6, 'Lingala'),
(22701, 3431, 6, 'Link'),
(22702, 3432, 6, 'Link naar de patient'),
(22703, 3433, 6, 'Gelinked'),
(22704, 3434, 6, 'Linked document'),
(22705, 3435, 6, 'Linked procedure order'),
(22706, 3436, 6, 'Verbonden met document'),
(22707, 3437, 6, 'Linked met procedure order'),
(22708, 3438, 6, 'Lijst'),
(22709, 3439, 6, 'Lijst box'),
(22710, 3440, 6, 'box met lijst'),
(22711, 3441, 6, 'Box met lijst en toevoeg'),
(22712, 3442, 6, 'Box met lijst en toevoeg'),
(22713, 3443, 6, 'Lijsteditor'),
(22714, 3444, 6, 'Lijst van encounters'),
(22715, 3445, 6, 'Groepslijsten'),
(22716, 3446, 6, 'Lijst verzekeringsmij-en'),
(22717, 3448, 6, 'Lijst onderdelen kunnen niet met een nummer beginnen'),
(22718, 3449, 6, 'Lijst onderdelen bevat illegale letterteken(s)'),
(22719, 3451, 6, 'Lijsten tonen'),
(22720, 3452, 6, 'Lijstnaam'),
(22721, 3453, 6, 'Lijstnamen mogen niet met cijfers beginnen'),
(22722, 3454, 6, 'Lijst medicatie'),
(22723, 3455, 6, 'Lijst gebruikt bij bovenstraande Land data optie.'),
(22724, 3456, 6, 'Lijst gebruikt bij bovenstaande State type-data optie.');
INSERT INTO `lang_definitions` VALUES
(22725, 3457, 6, 'Listening port van de RFC 5425 TLS syslog server.'),
(22726, 3458, 6, 'Lijsten'),
(22727, 3459, 6, 'Litousch'),
(22728, 3460, 6, 'Testament'),
(22729, 3461, 6, 'LLL:'),
(22730, 3462, 6, 'LMP'),
(22731, 3463, 6, 'Laad het compendium'),
(22732, 3464, 6, 'Definities laden'),
(22733, 3465, 6, 'Laad de Lab configuratie'),
(22734, 3466, 6, 'Laad OE Vraag Opties'),
(22735, 3467, 6, 'Laad Order definities'),
(22736, 3468, 6, 'Laad Order Entry vragen'),
(22737, 3469, 6, 'LOAD SUCCES, Codes zijn bijgevoegd'),
(22738, 3470, 6, 'Aan het laden'),
(22739, 3471, 6, 'Files opladen naar Database. Dit duurt wel even......'),
(22740, 3472, 6, 'LOC'),
(22741, 3473, 6, 'Gebr.'),
(22742, 3474, 6, 'Lokale inhoud'),
(22743, 3475, 6, 'Lokaal file systeem'),
(22744, 3476, 6, 'Lokaal'),
(22745, 3477, 6, 'Lokatie'),
(22746, 3478, 6, 'Locatie:'),
(22747, 3479, 6, 'Lokatie van de LibreEHR machiene en kan gevoelige data bevatten, dus het is aan te bevelen om handmatig de files te dleten na gebruik'),
(22748, 3480, 6, 'Locaties van deze voorraad'),
(22749, 3481, 6, 'Locatie niet gespecificeerd'),
(22750, 3482, 6, 'Locatie waar Hylafax de fax berichten bewaard.'),
(22751, 3483, 6, 'Locatie waar de scans worden bewaard'),
(22752, 3484, 6, 'Locatie:'),
(22753, 3485, 6, 'Afsluiten'),
(22754, 3486, 6, 'Lockstand voor ieder E-signed formulier apart'),
(22755, 3487, 6, 'Lockstand voor Encounters en de formulieren'),
(22756, 3488, 6, 'Lock-stand?'),
(22757, 3489, 6, 'Ge-Locked'),
(22758, 3492, 6, 'Inloggen'),
(22759, 3493, 6, 'Inloggen'),
(22760, 3494, 6, 'Uitloggen'),
(22761, 3495, 6, 'Ingelogd'),
(22762, 3496, 6, 'Actieve gebruiker'),
(22763, 3497, 6, 'Actieve gebruiker: '),
(22764, 3498, 6, 'Afgemeld.'),
(22765, 3499, 6, 'Vastleggen'),
(22766, 3500, 6, 'Inloggen'),
(22767, 3501, 6, 'Inloggen'),
(22768, 3502, 6, 'Login naam van WordPress gebruiker om portaal te gebruiken'),
(22769, 3503, 6, 'Login bij Remote Host'),
(22770, 3504, 6, 'Login bij deze Remote Host is mislukt'),
(22771, 3505, 6, 'Logout'),
(22772, 3506, 6, 'logout'),
(22773, 3507, 6, 'Logs'),
(22774, 3508, 6, 'Logviewer'),
(22775, 3510, 6, 'Opzoeken'),
(22776, 3511, 6, 'Voorraad'),
(22777, 3512, 6, 'ID ontbreekt voor voorraad'),
(22778, 3513, 6, 'Voorraadnummer'),
(22779, 3514, 6, 'Laag'),
(22780, 3515, 6, 'Lage prioriteit'),
(22781, 3516, 6, 'OnderbeenOnderbeen'),
(22782, 3517, 6, 'Laagste prioriteit'),
(22783, 3518, 6, 'Luba-Katanga'),
(22784, 3519, 6, 'Lumbale wervelkolom'),
(22785, 3520, 6, 'LUNCH'),
(22786, 3521, 6, 'Lunch'),
(22787, 3522, 6, 'Longkanker'),
(22788, 3523, 6, 'Longkanker chirurgie'),
(22789, 3524, 6, 'Longen:'),
(22790, 3525, 6, 'Longen'),
(22791, 3526, 6, 'Lupus'),
(22792, 3527, 6, 'Luxemburgs, Letzeburgisch'),
(22793, 3528, 6, 'M'),
(22794, 3529, 6, 'Memb.Association Categorie'),
(22795, 3530, 6, 'MA client abortus toegestaan'),
(22796, 3531, 6, 'MA statistieken'),
(22797, 3532, 6, 'Macedonisch'),
(22798, 3533, 6, 'Mail verstuurd'),
(22799, 3534, 6, 'Main'),
(22800, 3535, 6, 'Hoofdadres'),
(22801, 3536, 6, 'Belangrijkste boven top Scherm'),
(22802, 3537, 6, 'Bijhouden van acieve medicatie allergie lijst'),
(22803, 3538, 6, 'Bijhouden actieve medicatie lijst'),
(22804, 3539, 6, 'Bijhouden van up-to-date lijst van problemen en actieve diagnoses.'),
(22805, 3540, 6, 'Maak aanpassingen op gebruikte categorieen'),
(22806, 3541, 6, 'Maak een nieuwe afspraak voor'),
(22807, 3542, 6, 'Verzeker je ervan "'),
(22808, 3543, 6, 'Het aanmaken van BATCH files om naar clearing huis te uploaden worden gemarkeerd als in rekening ebrachgt'),
(22809, 3544, 6, 'Malagaskisch'),
(22810, 3545, 6, 'Malaise:'),
(22811, 3546, 6, 'Maleis'),
(22812, 3547, 6, 'Malayaam'),
(22813, 3548, 6, 'Man'),
(22814, 3549, 6, 'Condoom voor man'),
(22815, 3550, 6, 'Mannelijk VSC'),
(22816, 3551, 6, 'Maltesisch'),
(22817, 3552, 6, 'Mammogram'),
(22818, 3553, 6, 'Beheren'),
(22819, 3554, 6, 'Hooks gebruiken'),
(22820, 3555, 6, 'Modules gebruiken'),
(22821, 3556, 6, 'Vertalingen beheren'),
(22822, 3557, 6, 'Bestand'),
(22823, 3558, 6, 'Verplichte en specifieke velden'),
(22824, 3559, 6, 'Alleen verplichte of alleen specifieke velden, dup check, niet voor zoeken'),
(22825, 3560, 6, 'Verplichte velden of alleen specifieke velden, zoeken en dup controle'),
(22826, 3561, 6, 'Handleiding'),
(22827, 3562, 6, 'Invoeren met de hand'),
(22828, 3563, 6, 'Fabrikant'),
(22829, 3564, 6, 'Manx'),
(22830, 3565, 6, 'Mar'),
(22831, 3567, 6, 'Marathisch (Marathi)'),
(22832, 3568, 6, 'Maart'),
(22833, 3569, 6, 'Huwelijkse staat'),
(22834, 3570, 6, 'Markeren als in rekening gebracht'),
(22835, 3571, 6, 'Aanvinken als in rekening gebracht, maar niet versturen'),
(22836, 3572, 6, 'Aanvinken als geaccepteerd'),
(22837, 3573, 6, 'Aanvinken als geen rekening gestuurd'),
(22838, 3574, 6, 'Aanvinken van deze rapporten als doorgenomen'),
(22839, 3575, 6, 'Aanvinken als geaccepteerd'),
(22840, 3576, 6, 'Gehuwd'),
(22841, 3577, 6, 'Marshallees'),
(22842, 3578, 6, 'Pre-format'),
(22843, 3579, 6, 'Pre-format voor Invoice Nummers'),
(22844, 3580, 6, 'Pre-format voor Client IDs'),
(22845, 3581, 6, 'Pre-format voor Product IDs'),
(22846, 3582, 6, 'Match'),
(22847, 3583, 6, 'Match hoofd/kleine letters'),
(22848, 3584, 6, 'Een gelijke gevonden'),
(22849, 3590, 6, 'Matrix'),
(22850, 3591, 6, 'Max'),
(22851, 3592, 6, 'max totaal files-count is bereikt-opnieuw namen hieronder uploaden'),
(22852, 3594, 6, 'Rechts maxillair'),
(22853, 3595, 6, 'Maximum leeftijd'),
(22854, 3596, 6, 'Maximum aantal karakters'),
(22855, 3597, 6, 'Maximale tijd voodat je wordt uitgelogd. Ingesteld op 7200 seconden (2 uur)'),
(22856, 3600, 6, 'Maximum voor verwachtte inventaris, 0 indien niet van toepassing'),
(22857, 3601, 6, 'Maximum maat'),
(22858, 3602, 6, 'Maximum maat (bij 0 worden alle maten geaccepteerd)'),
(22859, 3603, 6, 'Mei'),
(22860, 3604, 6, 'MC'),
(22861, 3605, 6, 'mcg'),
(22862, 3607, 6, 'Dit betekent dat geen van de laatste drie paswoorden toegestaan zijn als het paswoord veranderd wordt'),
(22863, 3609, 6, 'Meting groeps code'),
(22864, 3611, 6, 'Meting'),
(22865, 3612, 6, 'Mediale malleolus'),
(22866, 3613, 6, 'Medicaid'),
(22867, 3614, 6, 'Medisch'),
(22868, 3615, 6, 'Medische abortus'),
(22869, 3616, 6, 'Medische administratie'),
(22870, 3617, 6, 'Medische historie'),
(22871, 3618, 6, 'Medische issue'),
(22872, 3619, 6, 'Medische issue'),
(22873, 3620, 6, 'Medisch probleem'),
(22874, 3621, 6, 'Medisch probleem'),
(22875, 3622, 6, 'Medische Probleem issue lijst'),
(22876, 3623, 6, 'Medische problemen'),
(22877, 3624, 6, 'Medisch dossier'),
(22878, 3625, 6, 'Medisch dossier #'),
(22879, 3626, 6, 'Medische dossiers'),
(22880, 3627, 6, 'Medische status verstuurd'),
(22881, 3629, 6, 'Medische samenvatting afgegeven'),
(22882, 3630, 6, 'Medisch systeem'),
(22883, 3631, 6, 'Medische type'),
(22884, 3632, 6, 'Medische voorgesch. (schrijven,toevoegen optioneel)'),
(22885, 3633, 6, 'Medicare Part B'),
(22886, 3634, 6, 'Verwijzer is ook zorgverlener voor Medicare'),
(22887, 3635, 6, 'Medicijn'),
(22888, 3636, 6, 'Lijst voor medicatie allergie'),
(22889, 3637, 6, 'Medicatie Issue lijst'),
(22890, 3638, 6, 'Medicatie lijst'),
(22891, 3639, 6, 'Medicatie reconsiliatie uitgevoerd?'),
(22892, 3640, 6, 'Medicijnen'),
(22893, 3641, 6, 'Medicijnen:'),
(22894, 3642, 6, 'Medicatie eenheden'),
(22895, 3643, 6, 'Medium'),
(22896, 3644, 6, 'MedlinePlus verbinding'),
(22897, 3645, 6, 'Lidmaatschap Vereniging Statistisch verslag'),
(22898, 3646, 6, 'Geheugen stoorn.'),
(22899, 3647, 6, 'Mannen'),
(22900, 3648, 6, 'Mannen en vrouwen'),
(22901, 3649, 6, 'Alleen mannen'),
(22902, 3650, 6, 'Menarche'),
(22903, 3651, 6, 'Menopauze'),
(22904, 3652, 6, 'Menstruatie heftigheid'),
(22905, 3653, 6, 'Menstruatiecyclus'),
(22906, 3654, 6, 'Geestesziekte'),
(22907, 3655, 6, 'Menu tekst'),
(22908, 3656, 6, 'Menus'),
(22909, 3657, 6, 'Samenvoegen'),
(22910, 3658, 6, 'Samenvoegen afgerond'),
(22911, 3659, 6, 'Voeg patienten samen'),
(22912, 3661, 6, 'Boodschap'),
(22913, 3662, 6, 'Boodschap- herinnerings- oproepen'),
(22914, 3663, 6, 'De inhoud voor de Merge is niet alleen tekstdus moet het als document opgeslagen worden.'),
(22915, 3664, 6, 'Bericht van de patient'),
(22916, 3665, 6, 'Bericht verzonden'),
(22917, 3666, 6, 'Status van het bericht'),
(22918, 3667, 6, 'Titel van het bericht'),
(22919, 3668, 6, 'Bericht aan patient'),
(22920, 3669, 6, 'Boodschap type'),
(22921, 3670, 6, 'BOODSCHAP:'),
(22922, 3671, 6, 'Berichten'),
(22923, 3672, 6, 'Berichten vandaag verzonden'),
(22924, 3673, 6, 'Methode'),
(22925, 3674, 6, 'Methode en Specifiek Product'),
(22926, 3675, 6, 'Methode om uitgaande berichten te sturen'),
(22927, 3676, 6, 'Methode van vernietiging'),
(22928, 3677, 6, 'Mexicaans/MexAmer/Chicano'),
(22929, 3679, 6, 'mg'),
(22930, 3680, 6, 'mg/1ml'),
(22931, 3681, 6, 'mg/2ml'),
(22932, 3682, 6, 'mg/3ml'),
(22933, 3683, 6, 'mg/4ml'),
(22934, 3684, 6, 'mg/5ml'),
(22935, 3685, 6, 'mg/dl'),
(22936, 3686, 6, 'Midden'),
(22937, 3687, 6, 'Intialen/tussenvoegsel'),
(22938, 3688, 6, 'Initialen/tussenvoegsel'),
(22939, 3690, 6, 'DEA midlevel voorschrijver'),
(22940, 3691, 6, 'Voornaam midlevel voorschrijver'),
(22941, 3692, 6, 'Achternaam midlevel voorschrijver'),
(22942, 3693, 6, 'Titulatuur midlevel voorschrijver'),
(22943, 3694, 6, 'UPIN midlevel voorscrijver'),
(22944, 3695, 6, 'Mien'),
(22945, 3696, 6, 'Tijdelijke werkkracht?'),
(22946, 3697, 6, 'Tijdelijk verblijf'),
(22947, 3698, 6, 'Mil/CU.MM'),
(22948, 3701, 6, 'Mime type'),
(22949, 3702, 6, 'Mime type'),
(22950, 3703, 6, 'Min'),
(22951, 3704, 6, 'min'),
(22952, 3705, 6, 'Minimum leeftijd'),
(22953, 3706, 6, 'Distorsie +/- synovitis'),
(22954, 3708, 6, 'Minuut'),
(22955, 3709, 6, 'minuten'),
(22956, 3710, 6, 'Minuten'),
(22957, 3712, 6, 'Diversen'),
(22958, 3713, 6, 'Extra rekening opties'),
(22959, 3714, 6, 'Extra rekening opties voor HCFA-1500'),
(22960, 3715, 6, 'Extra rekening opties HCFA'),
(22961, 3716, 6, 'Diversen'),
(22962, 3717, 6, 'Gemist'),
(22963, 3718, 6, 'afwezig'),
(22964, 3719, 6, 'Verplicht veld ontbreekt'),
(22965, 3720, 6, 'Bedrag ontbreekt'),
(22966, 3721, 6, 'Alleen ontbrekende Mods'),
(22967, 3722, 6, 'Afwezig of ongeldig'),
(22968, 3723, 6, 'PID ontbreekt'),
(22969, 3724, 6, 'Rapportdatum ontbreekt'),
(22970, 3725, 6, 'De slash na betaler in broncode wordt gemist '),
(22971, 3726, 6, 'Gemengd'),
(22972, 3727, 6, 'ml'),
(22973, 3728, 6, 'mm/dd/jjjj'),
(22974, 3729, 6, 'mmHg'),
(22975, 3730, 6, 'mmHg'),
(22976, 3731, 6, 'MMR 1'),
(22977, 3732, 6, 'MMR 2'),
(22978, 3733, 6, 'Mobiel'),
(22979, 3734, 6, 'Mobiele telefoon'),
(22980, 3735, 6, 'Mod'),
(22981, 3738, 6, 'Matige prioriteit'),
(22982, 3740, 6, 'Matig tot lage prioriteit'),
(22983, 3741, 6, 'Modifier'),
(22984, 3742, 6, 'Modifiers'),
(22985, 3743, 6, 'Aanpassen'),
(22986, 3745, 6, 'Betalingen aanpassen'),
(22987, 3746, 6, 'Lengte van Mod'),
(22988, 3747, 6, 'Module'),
(22989, 3748, 6, 'Directorie voor Module niet gevonden'),
(22990, 3749, 6, 'Module installer'),
(22991, 3750, 6, 'Naam voor deze Module'),
(22992, 3751, 6, 'Naam voor deze Module bestaat al'),
(22993, 3752, 6, 'Modules gebruiken'),
(22994, 3753, 6, 'Ma'),
(22995, 3754, 6, 'Ma tm vrij'),
(22996, 3755, 6, 'Ma, woe, vrij'),
(22997, 3756, 6, 'Maandag'),
(22998, 3757, 6, 'Mongools'),
(22999, 3758, 6, 'Maand'),
(23000, 3759, 6, 'maand'),
(23001, 3760, 6, 'Maandoverzicht'),
(23002, 3761, 6, 'Maand(en)'),
(23003, 3762, 6, 'Maandelijks inkomen'),
(23004, 3763, 6, 'Maanden'),
(23005, 3765, 6, 'Meer dan 100 resultaten gevonden, specificeer uw zoekactie.'),
(23006, 3766, 6, 'Meer dan 50 gevonden, specificeer de zoekactie.'),
(23007, 3767, 6, 'De top van de kolom kan aangeklikt worden om de sorteer volgorde te veranderen'),
(23008, 3768, 6, 'Meest recente van'),
(23009, 3769, 6, 'Meest recente Lab data:'),
(23010, 3770, 6, 'Meest recente vitals van:'),
(23011, 3771, 6, 'Moeder'),
(23012, 3772, 6, 'Naam moeder'),
(23013, 3773, 6, 'Historie van moeder'),
(23014, 3774, 6, 'Mond'),
(23015, 3775, 6, 'Verplaats'),
(23016, 3776, 6, 'Verplaats document naar categorie:'),
(23017, 3777, 6, 'Naar beneden'),
(23018, 3778, 6, 'Verplaatsing mislukt!'),
(23019, 3779, 6, 'Ga naar patient'),
(23020, 3780, 6, 'Verplaatsen naar....'),
(23021, 3781, 6, 'Naar boven'),
(23022, 3782, 6, 'Verplaatsen'),
(23023, 3783, 6, 'Dhr.'),
(23024, 3784, 6, 'MRN (pid)'),
(23025, 3785, 6, 'Mvr.'),
(23026, 3786, 6, 'Mej.'),
(23027, 3787, 6, 'MSH-11'),
(23028, 3788, 6, 'MSH-3.1'),
(23029, 3789, 6, 'MSH-4.1'),
(23030, 3790, 6, 'MSH-5.1'),
(23031, 3791, 6, 'MSH-6.1'),
(23032, 3793, 6, 'MSH.8bericht is niet correct'),
(23033, 3794, 6, 'MSP Code'),
(23034, 3795, 6, 'MSP retour codes'),
(23035, 3796, 6, 'Vertalingaanpassing eigen lokale OEMR versie'),
(23036, 3797, 6, 'Diverse plekken'),
(23037, 3798, 6, 'Meerder files kunnen tegelijk worden upgeload door te selecteren met CTRL+Click of SHIFT+Click.'),
(23038, 3799, 6, 'Meedere partijen'),
(23039, 3800, 6, 'Meerdere modifiers kunnen dmv dubbele punt gescheiden worden, max 4 (M:1M2:M3:M4)'),
(23040, 3801, 6, 'Meer keuze selectie lijst'),
(23041, 3802, 6, 'Multi raciaal'),
(23042, 3803, 6, 'Geruis:'),
(23043, 3804, 6, 'Spierpijn'),
(23044, 3805, 6, 'Spierpijnen'),
(23045, 3806, 6, 'Roodheid spieren'),
(23046, 3807, 6, 'Stijfheid spieren'),
(23047, 3808, 6, 'Spier zwelling'),
(23048, 3809, 6, 'Warme spieren'),
(23049, 3810, 6, 'Spieren'),
(23050, 3811, 6, 'Spierkwetsuur'),
(23051, 3812, 6, 'Musculoskelatair'),
(23052, 3813, 6, 'Moet leeg zij als SMTP verificatie niet gebruikt wordt'),
(23053, 3814, 6, 'Afgesproken in samenspraak'),
(23054, 3815, 6, 'MVA'),
(23055, 3818, 6, 'Ikzelf'),
(23056, 3820, 6, 'Maori'),
(23057, 3821, 6, 'N/A'),
(23058, 3822, 6, 'n/a'),
(23059, 3823, 6, 'Naam'),
(23060, 3825, 6, 'Naam (klik voor meer)'),
(23061, 3826, 6, 'Naam 1'),
(23062, 3827, 6, 'Naam 2'),
(23063, 3828, 6, 'Vaccinatie gegeven door'),
(23064, 3829, 6, 'Naam voor het EMR'),
(23065, 3830, 6, 'Naam het principe volgen van codetype_code_langauge.pdf, b.v. icd9_274.11_en.pdf'),
(23066, 3831, 6, 'Naam van Gebeurtenissen'),
(23067, 3832, 6, 'Naam verzekeringsmij.'),
(23068, 3833, 6, 'Naam behandelaar'),
(23069, 3834, 6, 'Naam van afzender voor patient reminders'),
(23070, 3835, 6, 'Naam vertaling'),
(23071, 3836, 6, 'Naam/Waarde'),
(23072, 3837, 6, 'Naam:'),
(23073, 3838, 6, 'Neusgang:'),
(23074, 3839, 6, 'Neusgang: Normaal Rechts'),
(23075, 3840, 6, 'Neusslijmvliezen rose, septum op middenlijn'),
(23076, 3841, 6, 'Nation notities'),
(23077, 3842, 6, 'Configureer NationNotes'),
(23078, 3843, 6, 'NationNotites aanpassings button'),
(23079, 3844, 6, 'Nationaliteit'),
(23080, 3845, 6, 'NationNotes'),
(23081, 3846, 6, 'Oorspronkelijke DATA Loads'),
(23082, 3847, 6, 'Van oorsprong Hawai of andere Pacific eilandbewoner'),
(23083, 3851, 6, 'Nauru'),
(23084, 3852, 6, 'Misselijkheid'),
(23085, 3853, 6, 'Navajo, Navaho'),
(23086, 3854, 6, 'Navigatie'),
(23087, 3855, 6, 'Navigatie met encounter formulieren'),
(23088, 3856, 6, 'Navigatie vak gebruikt volledige hoogte van frameset'),
(23089, 3857, 6, 'Navigatie gebied bezoek formulieren'),
(23090, 3858, 6, 'Breedte van Navigatie-vak'),
(23091, 3859, 6, 'Navigatie menu bestaat uit paren van Radio buttons'),
(23092, 3860, 6, 'Navigatie menu is Tree format'),
(23093, 3861, 6, 'Navigatie menu met verberg optie'),
(23094, 3862, 6, 'Nat.Med.Code'),
(23095, 3863, 6, 'NDC data'),
(23096, 3864, 6, 'NDC nummer'),
(23097, 3865, 6, 'Ndonga'),
(23098, 3866, 6, 'Nek'),
(23099, 3867, 6, 'Nekproblemen'),
(23100, 3868, 6, 'Nek soepel'),
(23101, 3869, 6, 'Omschrijving moet ingevoerd worden'),
(23102, 3870, 6, 'Waarde voor terugsturen moet nog ingevuld worden'),
(23103, 3871, 6, 'Identificator moet nog ingevuld worden'),
(23104, 3872, 6, 'Titel moet nog ingevoerd worden'),
(23105, 3873, 6, 'Authorisatie verplicht'),
(23106, 3874, 6, 'Behoort bij acoorderen'),
(23107, 3875, 6, 'Moet nog extra in rekening gebracht worden'),
(23108, 3876, 6, 'Negatief'),
(23109, 3877, 6, 'Negativen'),
(23110, 3879, 6, 'Nepalees'),
(23111, 3880, 6, 'Zenuw trauma'),
(23112, 3881, 6, 'Zenuwaandoening / zenuwletsel'),
(23113, 3882, 6, 'Zenuwdoofheid'),
(23114, 3883, 6, 'Zenuwzwakte'),
(23115, 3884, 6, 'Neurologisch'),
(23116, 3885, 6, 'Nooit'),
(23117, 3886, 6, 'Nooit alcohol'),
(23118, 3887, 6, 'Nooit gerookt'),
(23119, 3888, 6, 'Nieuw'),
(23120, 3889, 6, 'Nieuw =>'),
(23121, 3890, 6, 'Nieuw geaccepteerden'),
(23122, 3892, 6, 'Nieuwe allergie'),
(23123, 3893, 6, 'Nieuw verzoek tot wijziging'),
(23124, 3894, 6, 'Nieuwe afspraak'),
(23125, 3895, 6, 'Nieuwe categorie'),
(23126, 3896, 6, 'Nieuwe categorie'),
(23127, 3897, 6, 'Nieuwe client'),
(23128, 3898, 6, 'Nieuw'),
(23129, 3899, 6, 'Nieuwe voorraad'),
(23130, 3900, 6, 'Nieuwe definitie set toegevoegd'),
(23131, 3901, 6, 'Nieuw document'),
(23132, 3902, 6, 'Nieuw documenten'),
(23133, 3904, 6, 'Nieuwe encounter'),
(23134, 3905, 6, 'Nieuwe encounter aangemaakt met ID'),
(23135, 3906, 6, 'Nieuw contact formulier'),
(23136, 3907, 6, 'Nieuw contact niet geautoriseerd'),
(23137, 3908, 6, 'Nieuw contact'),
(23138, 3909, 6, 'Informatie nieuwe locatie'),
(23139, 3910, 6, 'Nieuw file'),
(23140, 3911, 6, 'Nieuwe files'),
(23141, 3912, 6, 'Nieuwe groep'),
(23142, 3913, 6, 'Nieuwe groepsinformatie'),
(23143, 3914, 6, 'Nieuwe inj/status'),
(23144, 3916, 6, 'Nieuwe limiet voor gebeurtenissen'),
(23145, 3917, 6, 'Nieuwe lijst'),
(23146, 3918, 6, 'Nieuwe orders'),
(23147, 3919, 6, 'Nieuwe paragraaf'),
(23148, 3920, 6, 'Nieuw paswoord'),
(23149, 3921, 6, 'Nieuwe patient'),
(23150, 3922, 6, 'Nieuwe Patient'),
(23151, 3923, 6, 'Nieuw patientencontact'),
(23152, 3924, 6, 'Formulier nieuwe patient'),
(23153, 3925, 6, 'ID nieuwe patient'),
(23154, 3926, 6, 'Nieuwe betaling'),
(23155, 3927, 6, 'Nieuwe Portaal login'),
(23156, 3928, 6, 'Nieuwe pt'),
(23157, 3929, 6, 'Nieuwe resultaten van Lab uitwisseling'),
(23158, 3930, 6, 'Nieuwe zoekactie'),
(23159, 3931, 6, 'Nieuw toevoeging'),
(23160, 3932, 6, 'Nieuwe gebruiker'),
(23161, 3933, 6, 'Nieuwe waarde'),
(23162, 3934, 6, 'Nieuw consult'),
(23163, 3935, 6, 'Nieuw/Zoeken'),
(23164, 3936, 6, 'Nieuwe voorraad Account status'),
(23165, 3937, 6, 'NewCrop Admin'),
(23166, 3938, 6, 'NewCrop aanroepen mislukt'),
(23167, 3939, 6, 'NewCrop Dokter'),
(23168, 3940, 6, 'NewCrop eRx rekening Id'),
(23169, 3944, 6, 'NewCrop eRx naam'),
(23170, 3945, 6, 'NewCorp eRx Partner Naam'),
(23171, 3946, 6, 'Newcorp Paswoord'),
(23172, 3947, 6, 'NewCrop eRx rol'),
(23173, 3948, 6, 'NewCrop eRx rol'),
(23174, 3949, 6, 'NewCrop eRx Site adres'),
(23175, 3950, 6, 'NewCrop eRx SOAP verzoek voor tijd te leven voor Allergies'),
(23176, 3951, 6, 'NewCrop eRx SOAP verzoek voor tijd te leven voor Medicaties'),
(23177, 3954, 6, 'NewCrop eRx Web Service Adres'),
(23178, 3955, 6, 'NewCrop Manager'),
(23179, 3956, 6, 'NewCrop MedEntry'),
(23180, 3957, 6, 'NewCorp Midlevel voorschrijver'),
(23181, 3958, 6, 'NewCrop Midlevel Verleegkundige'),
(23182, 3959, 6, 'NewCrop Supervisor Dokter'),
(23183, 3960, 6, 'Nieuwer'),
(23184, 3961, 6, 'Krant'),
(23185, 3962, 6, 'Volgende'),
(23186, 3964, 6, 'Volgende dag'),
(23187, 3965, 6, 'Volgende maand'),
(23188, 3966, 6, 'Volgende maand (ingedrukt houden voor menu)'),
(23189, 3967, 6, 'Volgende geplande RUN'),
(23190, 3968, 6, 'Volgende week'),
(23191, 3969, 6, 'Volgend jaar (ingedrukt houden voor menu)'),
(23192, 3970, 6, 'Voorkeurs naam'),
(23193, 3971, 6, 'Alias'),
(23194, 3973, 6, 'Nacht zweten'),
(23195, 3974, 6, 'Normale ext genitalien, vag mucose, cervix'),
(23196, 3975, 6, 'Nee'),
(23197, 3976, 6, 'NEE'),
(23198, 3977, 6, 'Geen toegang'),
(23199, 3978, 6, 'Geen actieve patient reminders'),
(23200, 3979, 6, 'Geen adenopathie (2 gebieden nodig)'),
(23201, 3980, 6, 'Geen aanpssing reden gevonden voor'),
(23202, 3981, 6, 'Adnexa niet pijnlijk of palpabele massa'),
(23203, 3982, 6, 'Geen aanpssing verzoek beschikbaar'),
(23204, 3983, 6, 'Geen afspraken'),
(23205, 3984, 6, 'Er is geen aanpassing ontdekt in de audit log in de geselecteerde datum  range'),
(23206, 3985, 6, 'Er is momenteel geen factureringssysteem actief'),
(23207, 3986, 6, 'Geen rekeningen gevonden om bij OFX export in te voegen'),
(23208, 3987, 6, 'Geen rekeningen gevonden om in OFX Export bij te voegen<br>'),
(23209, 3989, 6, 'Geen code gespecificeerd'),
(23210, 3990, 6, 'Geen configuratie gemaakt voor deze Module'),
(23211, 3992, 6, 'Geen diagnose'),
(23212, 3993, 6, 'Geen documenten gevonden'),
(23213, 3994, 6, 'Er kon geen Encounter aangemaakt worden'),
(23214, 3995, 6, 'Geen einddatum'),
(23215, 3996, 6, 'Geen invoer vonden, gebruik het volgende formulier om invoer toe te voegen.'),
(23216, 3997, 6, 'Geen fouten gevonden'),
(23217, 3998, 6, 'Geen gebeurtenissen'),
(23218, 4000, 6, 'Geen files geplanned voor installatie'),
(23219, 4001, 6, 'Er is geen groep geselecteerd'),
(23220, 4002, 6, 'Geen hernia'),
(23221, 4003, 6, 'Geen aanknopings punten voor deze Module beschikbaar'),
(23222, 4004, 6, 'Geen anknopins punten voor deze Module aangemaakt'),
(23223, 4005, 6, 'Geen letsel/ziekte'),
(23224, 4006, 6, 'Geen verzekeringsmij. gevonden'),
(23225, 4007, 6, 'Geen issues'),
(23226, 4008, 6, 'Geen Issues tijdens dit bezoek'),
(23227, 4009, 6, 'Geen waarden voor geselecteerde categorie'),
(23228, 4010, 6, 'Geen items geselecteerd'),
(23229, 4024, 6, 'Geen lab data gedocumenteerd'),
(23230, 4025, 6, 'Voor de geselcteerde data bestaat geen log-file'),
(23231, 4027, 6, 'Geen zwellingen of gevoeligheid'),
(23232, 4028, 6, 'Geen patienten record voor de opgegeven Re Identificatie code'),
(23233, 4029, 6, 'Geen matches gevonden. Probeer opnieuw.'),
(23234, 4030, 6, 'Er zijn geen overeenkomstigen gevonden'),
(23235, 4031, 6, 'Niets gevonden. Nieuwe patient aanmaken?'),
(23236, 4032, 6, 'Geen van de records voldoet aan zoekopdracht'),
(23237, 4033, 6, 'Geen nieuwe resultaten gevonden'),
(23238, 4034, 6, 'Geen notities'),
(23239, 4035, 6, 'Geen organomegaly'),
(23240, 4036, 6, 'Geen vrije plaatsen gevonden voor deze periode'),
(23241, 4037, 6, 'Geen andere telefoon nummers geregistreerd'),
(23242, 4038, 6, 'Geen parameters geselecteerd'),
(23243, 4039, 6, 'Geen partners gevonden'),
(23244, 4040, 6, 'Geen patienten record gevonden voor de opgegeven Selectie'),
(23245, 4041, 6, 'Geen patienten record gevonden voor de Re-Identificatie code'),
(23246, 4042, 6, 'Geen perifeer oedeem'),
(23247, 4043, 6, 'Geen apotheken gevonden'),
(23248, 4044, 6, 'Geen recepten gevonden'),
(23249, 4045, 6, 'Geen ziekte of letsel aantoonbaar'),
(23250, 4046, 6, 'Geen eerdere vermeldingen'),
(23251, 4047, 6, 'Geen Primary Bisseness Entity geselecteerd in faciliteit lijst'),
(23252, 4048, 6, 'Geen eerdere bezoeken'),
(23253, 4049, 6, 'Geen procedures voor dit bezoek'),
(23254, 4051, 6, 'Geen behandelaars gevonden'),
(23255, 4052, 6, 'Geen uitslag of abnormale lesies'),
(23256, 4053, 6, 'Geen status gevonden'),
(23257, 4055, 6, 'Geen resultaten gevonden. Breidt uw zoekopdracht uit.'),
(23258, 4056, 6, 'Geen reminders'),
(23259, 4057, 6, 'Geen resultaten gevonden voor ingevoerde search vragen criteria'),
(23260, 4058, 6, 'Geen resultaten'),
(23261, 4059, 6, 'Geen resultaten gevonden'),
(23262, 4060, 6, 'Geen resultaten gevonden voor zoekopdracht'),
(23263, 4061, 6, 'Geen resultaten gevonden, probeer opnieuw.'),
(23264, 4062, 6, 'Geen resultaten, zoek nogmaals'),
(23265, 4063, 6, 'Geen resultaten, zoek nogmaals'),
(23266, 4064, 6, 'Geen settings beschikbaar voor dze Module'),
(23267, 4065, 6, 'Niet gekomen'),
(23268, 4066, 6, 'Geen Signature beschikbaar als File'),
(23269, 4067, 6, 'Sinus niet pijnlijk'),
(23270, 4068, 6, 'Geen huidintrekkingen of knobbels in mammae'),
(23271, 4069, 6, 'Dergelijke CONSTANTEN naam bestaat niet'),
(23272, 4070, 6, 'Geen tabel geselecteerd! Selecteer een tabel.'),
(23273, 4071, 6, 'Geen veranderd gevoel of knobbels aan testiskels'),
(23274, 4072, 6, 'Geen thrills of heaves'),
(23275, 4073, 6, 'Geen track geselecteerd'),
(23276, 4074, 6, 'Geen tracks gedocumenteerd'),
(23277, 4075, 6, 'Geen bezoek'),
(23278, 4076, 6, 'Geen vitals vastgelegd'),
(23279, 4077, 6, 'Nee, annuleren'),
(23280, 4078, 6, 'No-fault verzekering ook Auto is Primair'),
(23281, 4079, 6, 'Nee:'),
(23282, 4080, 6, 'Nycturie'),
(23283, 4081, 6, 'Niet betaald'),
(23284, 4082, 6, 'Niet aangegeven report'),
(23285, 4083, 6, 'Geen specifiek letsel'),
(23286, 4084, 6, 'Niet electronisch'),
(23287, 4085, 6, 'NIDDM'),
(23288, 4086, 6, 'Niet verzekerd'),
(23289, 4087, 6, 'Niet-SRH Medisch'),
(23290, 4088, 6, 'Niet-SRH niet-medisch'),
(23291, 4089, 6, 'Geen'),
(23292, 4090, 6, 'geen'),
(23293, 4091, 6, 'Niet gedefinieerd'),
(23294, 4092, 6, 'Geen enkele is gedocumenteerd'),
(23295, 4093, 6, 'Geen van bovenstaande'),
(23296, 4094, 6, 'Geen van de bovenste TOP regels kan leeg zijn'),
(23297, 4095, 6, 'NIDDM'),
(23298, 4096, 6, 'Nor'),
(23299, 4097, 6, 'Normaal'),
(23300, 4098, 6, 'Normale BL'),
(23301, 4099, 6, 'Normaal card. onderzoek:'),
(23302, 4100, 6, 'Normaal card. onderzoek: '),
(23303, 4101, 6, 'Normaal longonderzoek:'),
(23304, 4102, 6, 'Normaal longonderzoek: '),
(23305, 4103, 6, 'Normaal kantoorbezoek'),
(23306, 4104, 6, 'Normale oropharynx'),
(23307, 4105, 6, 'Normaal rechts'),
(23308, 4106, 6, 'Normaal rechts:'),
(23309, 4107, 6, 'Normale weergave'),
(23310, 4108, 6, 'normaal:'),
(23311, 4109, 6, 'Standaard moet dit aangevinkt zijn. Niet gebonden aan access controle'),
(23312, 4110, 6, 'Noord Ndebele'),
(23313, 4111, 6, 'Noord Sami'),
(23314, 4112, 6, 'Noors'),
(23315, 4113, 6, 'Noorweegs Bokmal'),
(23316, 4114, 6, 'Noorweegs Nynorsk'),
(23317, 4115, 6, 'Neus'),
(23318, 4116, 6, 'Bloedneus'),
(23319, 4117, 6, 'geen letter of cijfer'),
(23320, 4119, 6, 'Niet alle velden zijn noodzakelijk voor code of code type'),
(23321, 4120, 6, 'Niet toegestaan'),
(23322, 4121, 6, 'Niet toegestaan om administratiegroepen te verwijderen'),
(23323, 4122, 6, 'Mag deze niet veranderen'),
(23324, 4123, 6, 'Niet toegestaan om alle veiligheidsmaatregels te inactiveren'),
(23325, 4124, 6, 'Niet toegestaan om ook maar iets van ACL administrateurs te inactiveren'),
(23326, 4125, 6, 'Niet toegestaan om Gebruiker admin te verwijderen van de administrateursgroep'),
(23327, 4126, 6, 'Deze USER mag niet van de Administrator group verwijderd worden'),
(23328, 4127, 6, 'Niet van toepassing'),
(23329, 4128, 6, 'Geen toegang tot PostCalendar module'),
(23330, 4129, 6, 'Niet geautoriseerd'),
(23331, 4130, 6, 'Niet geautoriseerd'),
(23332, 4131, 6, 'Niet geautoriseerd voor deze ploeg!'),
(23333, 4132, 6, 'Niet geautoriseerd voor deze ploeg.'),
(23334, 4133, 6, 'Niet geautoriseerd om Users te veranderen!'),
(23335, 4134, 6, 'Niet geautoriseerd om resutaten te ondertekenen'),
(23336, 4135, 6, 'Niet beschikbaar'),
(23337, 4137, 6, 'Niet in rekening gebracht'),
(23338, 4138, 6, 'Niet gechecked'),
(23339, 4139, 6, 'Niet uitgechecked'),
(23340, 4140, 6, 'Niet gecodeerd'),
(23341, 4141, 6, 'Nog niet aan de beurt'),
(23342, 4143, 6, 'Niet onderzocht'),
(23343, 4144, 6, 'Niet onderzocht:'),
(23344, 4145, 6, 'Niet onderzocht: '),
(23345, 4146, 6, 'niet gevonden'),
(23346, 4148, 6, 'niet gevonden!'),
(23347, 4149, 6, 'Geen Spaans of Latino'),
(23348, 4150, 6, 'Niet geinstalleerd'),
(23349, 4151, 6, 'Niet geinstalleerd'),
(23350, 4152, 6, 'Niet gezien sinds'),
(23351, 4153, 6, 'Niet verzonden'),
(23352, 4154, 6, 'Nog niet verzonden'),
(23353, 4155, 6, 'Niet gespecificeerd'),
(23354, 4156, 6, 'Niet gespecificeerd'),
(23355, 4157, 6, 'Notitie'),
(23356, 4158, 6, 'Geen Codes'),
(23357, 4159, 6, 'Notitie doet er 5 -10 min over om helemaal verwerkt te worden nadat Install geklikt is'),
(23358, 4160, 6, 'Notitie doet er 5 - 10 minuten over om volledig verwerkt te worden nadat Update is aangeklikt'),
(23359, 4161, 6, 'N.B: De audit log moet hierboven geactiveerd worden'),
(23360, 4162, 6, 'Soort notitie'),
(23361, 4163, 6, 'N.B: 12:00 middag is PM en niet AM'),
(23362, 4164, 6, 'N.B: Importeren van externe data kan meer dan een uur duren afhankelijk van de soort hardware die gebruikt wordt. B.v. RxNorm bevat meer dan 6 miljoen regels.'),
(23363, 4165, 6, 'N.B: Alleen de twee jaarlijkse Internationale SnoMed release wordt ondersteund.'),
(23364, 4166, 6, 'N.B: Alleen de volledige maandelijkse RxNorm wordt nu ondersteund'),
(23365, 4168, 6, 'N.B: Deze code werd niet door een gemachtigde Gebruiker ingevoerd. Alleen geaccepteerde codes mogen naar het Open Medische Facturering Netwerk worden gestuurd voor verwerking. Indien u deze codes wilt uploaden, selecteer dan hier een gemachtigde gebruiker.'),
(23366, 4170, 6, 'N.B: Bij het uploaden van bestanden met dezelfde naam, wordt deze naam van de bestanden automatisch hernoemd (bijvoorbeeld, zal file.jpg worden file.1.jpg). Bestandsnamen zijn uniek per patiënt, niet per categorie.'),
(23367, 4171, 6, 'N.B: Geuploade bestanden met dezelfde naam worden automatisch hernoemd. Bijvoorbeeld ''<i>file.jpg</i>'' zal worden''<i>file.jpg.1</i>''. Bestandsnamen zijn per patiënt uniek, niet per categorie.'),
(23368, 4172, 6, 'Notities'),
(23369, 4173, 6, 'Notities - een contact (schrijven, toevoegen optioneel)'),
(23370, 4174, 6, 'Notities - mijn contacten (schrijven,toevoegen optioneel)'),
(23371, 4175, 6, 'Notities niet geautoriseerd'),
(23372, 4176, 6, 'Niets in wachtlijst om te accoorderen'),
(23373, 4177, 6, 'Niets geselecteerd'),
(23374, 4179, 6, 'Geen import vanuit Allergie'),
(23375, 4180, 6, 'Geen import vanuit Recepten'),
(23376, 4181, 6, 'Niets te tonen'),
(23377, 4182, 6, 'Niets geselecteerd'),
(23378, 4183, 6, 'Notitie ontvangen'),
(23379, 4184, 6, 'MEDEDELING: PostCalendar Toekennen/Wijziging'),
(23380, 4185, 6, 'Bericht'),
(23381, 4186, 6, 'E-mail adres om alert-berichten te sturen'),
(23382, 4188, 6, 'Berichten'),
(23383, 4189, 6, 'Informeer Admin over Gebeurtenis Toewijzing/Wijziging?'),
(23384, 4190, 6, 'Nov'),
(23385, 4191, 6, 'November'),
(23386, 4192, 6, 'Nu aanmelden voor:'),
(23387, 4193, 6, 'Nu aan het printen'),
(23388, 4194, 6, 'Nu afdrukken $stmt_count verklaringen en bijwerken van ontmoetingen.'),
(23389, 4195, 6, 'Printen van $stmt_count verklaringen en bijwerken van facturen.'),
(23390, 4196, 6, 'Printen van $stmt_count verklaringen en bijwerken van overzichten; ontmoetingen zullen niet worden bijgewerkt.'),
(23391, 4197, 6, 'Printen van $stmt_count verklaringen; facturen zullen niet worden bijgewerkt.'),
(23392, 4198, 6, 'BIG'),
(23393, 4199, 6, 'NQF'),
(23394, 4200, 6, 'Nr.'),
(23395, 4201, 6, 'Nr. labs'),
(23396, 4204, 6, 'Aantal kolommen in jaaroverzicht.'),
(23397, 4211, 6, 'Aantal dagen dat het Client Certificaat nog geldig is.'),
(23398, 4213, 6, 'Aantal posities achter de punt voor valuta. (meestal 0 of 2)'),
(23399, 4214, 6, 'Aantal encounters om te tonen per pagina'),
(23400, 4215, 6, 'Aantal gemiste spelen of gebeurtenissen, indien van toepassing'),
(23401, 4216, 6, 'Aantal uren vooraf alvorens e-mail bericht te sturen.'),
(23402, 4217, 6, 'Aantal uren vooruit om telefoon bericht te sturen'),
(23403, 4218, 6, 'Aantal uren vooraf alvorens SMS berichten te sturen'),
(23404, 4221, 6, 'Aantal historie kolommen uit het verleden'),
(23405, 4222, 6, 'Aantal patienten te tonen per pagina in de lijst.'),
(23406, 4223, 6, 'Doofheid'),
(23407, 4224, 6, 'Numerator'),
(23408, 4225, 6, 'Tonen van nummerieke volgorde'),
(23409, 4226, 6, 'Nuosu'),
(23410, 4227, 6, 'Voeding'),
(23411, 4228, 6, 'Voedings'),
(23412, 4229, 6, 'O.A.F.V.'),
(23413, 4230, 6, 'O2 Sat'),
(23414, 4231, 6, 'Obesitas 1'),
(23415, 4232, 6, 'Obesitas 2'),
(23416, 4233, 6, 'Obesitas 3'),
(23417, 4234, 6, 'Objectief'),
(23418, 4236, 6, 'Occitan'),
(23419, 4237, 6, 'Beroep'),
(23420, 4239, 6, 'Acuut / Chron / enz.'),
(23421, 4240, 6, 'Okt'),
(23422, 4241, 6, 'Oktober'),
(23423, 4242, 6, 'OD'),
(23424, 4243, 6, 'uit'),
(23425, 4244, 6, 'hoeveelheid'),
(23426, 4245, 6, 'tabletten'),
(23427, 4246, 6, 'van de maand ieder'),
(23428, 4247, 6, 'Reminders kantoor'),
(23429, 4248, 6, 'Uit'),
(23430, 4249, 6, 'Kantoornotities'),
(23431, 4250, 6, 'Kantoorbezoek'),
(23432, 4251, 6, 'Officieel Klinische Kwaliteit meting (CQM) Meting Groepen'),
(23433, 4252, 6, 'Offsite link voor Patienten Ingang'),
(23434, 4253, 6, 'Offsite https link voo Patienten Ingang(Patienten link)'),
(23435, 4254, 6, 'Offsite Patienten Ingang paswoord'),
(23436, 4255, 6, 'Offsite Patienten Ingang paswoord(Laat open indien nog niet geregistreerd)'),
(23437, 4256, 6, 'Offsite Patient Portal Provider ID'),
(23438, 4257, 6, 'Offsite Patient Portal Provider ID(Spatie als er geen registratie is).'),
(23439, 4258, 6, 'Offsite Patienten Ingang Site adres'),
(23440, 4259, 6, 'Offsite Patienten Ingang adres (Patienten link)'),
(23441, 4260, 6, 'Offsite Patienten Ingang Usernaam'),
(23442, 4261, 6, 'Offsite Patienten Ingang Usernaam(Laat open indien nog niet geregistreed)'),
(23443, 4262, 6, 'Offsite Portaal web Service faalt'),
(23444, 4263, 6, 'Nakomelingen'),
(23445, 4264, 6, 'Nakomelingen geschiedenis'),
(23446, 4265, 6, 'zalf'),
(23447, 4266, 6, 'Ojibwe, Ojibwa'),
(23448, 4267, 6, 'OK'),
(23449, 4268, 6, 'Is het Ok om dit pop-up scherm te sluiten?'),
(23450, 4269, 6, 'OK om de gedateerde GCAC issue te linken'),
(23451, 4270, 6, 'Oud'),
(23452, 4271, 6, 'Old Kerks Slavisch, Kerk Slavisch, Oud Bulgaars'),
(23453, 4272, 6, 'Oude clienten'),
(23454, 4273, 6, 'Oude fractuur geen/slechte botverbinding'),
(23455, 4274, 6, 'Oude stijl Layout, linker menu scherm'),
(23456, 4275, 6, 'Oude stijl statisch formulier, zonder zoek of duplicaat controle'),
(23457, 4276, 6, 'Ouder'),
(23458, 4277, 6, 'Overslaan'),
(23459, 4278, 6, 'Geen omtrekken meten'),
(23460, 4279, 6, 'Verberg werkgever informatie in Client demografische gegevens'),
(23461, 4280, 6, 'Verberg werkgever'),
(23462, 4281, 6, 'Verberg formulier, manier van innemen en interval die dan onderdeel vormen van de dosis'),
(23463, 4282, 6, 'Verberg Verzekeringen en enkele ander zaken op het demografische scherm'),
(23464, 4283, 6, 'Verberg interne gebruikers'),
(23465, 4284, 6, 'Verberg betalings methode op het extra betalings scherm'),
(23466, 4285, 6, 'Automatisch reg.nummer toekennen'),
(23467, 4286, 6, 'Aan'),
(23468, 4287, 6, 'Aan'),
(23469, 4288, 6, 'In voorraad'),
(23470, 4289, 6, 'In bestelling'),
(23471, 4290, 6, 'Aanwezig op afdeling'),
(23472, 4291, 6, 'Indien de hoofd Bussiness faciliteit is vastgelegd, niet meer veranderen. Wel veranderen zal de werking in NewCrop ePresciption beinvloeden'),
(23473, 4292, 6, 'Na wijziging wachtwoord opnieuw inloggen'),
(23474, 4297, 6, 'WEB-Support'),
(23475, 4298, 6, 'Online Support link'),
(23476, 4299, 6, 'Alleen actieven'),
(23477, 4300, 6, 'Allen van toepassing als de Provider of collated lijst hierboven werd gekozen. PRIMARY selecteerd alleen patienten als de Provider de Primary Provider is. ENCOUNT slecteerd alle patienten die door de Provider gezien zijn.'),
(23478, 4302, 6, 'alleen indien rekening locatie'),
(23479, 4303, 6, 'Alleen niet-actieven'),
(23480, 4304, 6, 'Van gebruiker'),
(23481, 4305, 6, 'Toon slechts de diagnose verslag code'),
(23482, 4306, 6, 'Toon slechts Financieel service verslag code'),
(23483, 4307, 6, 'Alleen actieve receptuur uploaden'),
(23484, 4309, 6, 'Begin van huidige symptomen of ziekte'),
(23485, 4310, 6, 'Begin ziekte:'),
(23486, 4311, 6, 'Begin ziekte: '),
(23487, 4312, 6, 'Begin zwelling:'),
(23488, 4313, 6, 'Begindatum opname:'),
(23489, 4314, 6, 'Site adres van Patient Portal'),
(23490, 4315, 6, 'Oeps!'),
(23491, 4316, 6, 'Open'),
(23492, 4318, 6, 'Openen in nieuw venster'),
(23493, 4319, 6, 'Huidige patient'),
(23494, 4321, 6, 'Maak het bezoek van vandaag open'),
(23495, 4322, 6, 'LibreEHR heef al een Certificaat Authority geconfigureerd'),
(23496, 4323, 6, 'LibreEHR Applicatie Categorie'),
(23497, 4324, 6, 'LibreEHR DB upgrade'),
(23498, 4325, 6, 'LibreEHR Database voo De-identificatie'),
(23499, 4326, 6, 'LibreEHR herkent de binnenkomende file niet in de CONTRIB directory. Dit komt waarschijnlijk doordat de release in support_external_dataloads tabel in de MySQL database geconfigureerd worden.'),
(23500, 4327, 6, 'LibreEHR moet geconfigureerd worden voordat het client certificaten kan gebruiken'),
(23501, 4328, 6, 'LibreEHR heeft Javascript nodig voor toegangscontrole.'),
(23502, 4329, 6, 'LibreEHR gebruikers'),
(23503, 4330, 6, 'Openingen'),
(23504, 4332, 6, 'Ophtalmisch'),
(23505, 4333, 6, 'Mogelijkheid'),
(23506, 4334, 6, 'Voorkeur om methode van document producten op te slaan.'),
(23507, 4335, 6, 'Optie om inventaris en producten voor verkoop te ondersteunen'),
(23508, 4336, 6, 'Keuze mogelijkheid'),
(23509, 4337, 6, 'Optionele categorie naam voor een ID kaart image die op de patient samenvattings pagina te zien is.'),
(23510, 4338, 6, 'Optionele categorie naam voor een ID kaart foto die op de patient samenvattings pagina te zien is.'),
(23511, 4339, 6, 'Categorienaam naar keuze om een document om verbinding te maken met patient gegevens samenvattings pagina. Laat u klikken op de naam van een Client om hun ID kaart te zien.'),
(23512, 4340, 6, 'Optioneel default range voor handmatige resultaten invoer'),
(23513, 4341, 6, 'Optioneel default range voor handmatig invoeren resultaten'),
(23514, 4342, 6, 'Niet verplichte bestemmingsnaam'),
(23515, 4343, 6, 'Medicatienaam optioneel, gebruik % als wildcard'),
(23516, 4344, 6, 'Immunisatie naam of code optioneel, gebruik % as wild card'),
(23517, 4345, 6, 'Mogelijkheid om informatie te geven over gebeurtenis'),
(23518, 4346, 6, 'Lotnummer optioneel, gebruik % als wildcard'),
(23519, 4347, 6, 'Numeriek client ID naar optioneel'),
(23520, 4348, 6, 'Facultatieve procedurecode'),
(23521, 4349, 6, 'Optionele procedure/service code'),
(23522, 4350, 6, 'Opties'),
(23523, 4351, 6, 'of'),
(23524, 4352, 6, 'of kies'),
(23525, 4353, 6, 'of selecteer'),
(23526, 4354, 6, 'of klik en sleep voor snellere selectie'),
(23527, 4356, 6, 'Kaart bij:'),
(23528, 4357, 6, 'of selecteer van inventarisatie'),
(23529, 4358, 6, 'of Shift-klik voor verkleinen'),
(23530, 4359, 6, 'Of upload ERA dossier:'),
(23531, 4360, 6, 'Oraal'),
(23532, 4361, 6, 'Orale mucosa is roze, keel schoon'),
(23533, 4362, 6, 'Aanvragen'),
(23534, 4363, 6, 'Bestel en Resultaat types'),
(23535, 4364, 6, 'Aanvraag opties'),
(23536, 4365, 6, 'Datum bestelling'),
(23537, 4366, 6, 'Beschrijving van orders'),
(23538, 4367, 6, 'Bestelformulier'),
(23539, 4368, 6, 'Bestel ID'),
(23540, 4369, 6, 'Bestelling moet een nummer tussen 1 en 999 zijn'),
(23541, 4370, 6, 'Naam bestelling'),
(23542, 4371, 6, 'Prioriteit van bestelling'),
(23543, 4372, 6, 'Bestellingverwerker'),
(23544, 4373, 6, 'Order resultaten'),
(23545, 4374, 6, 'Order status'),
(23546, 4375, 6, 'Status bestellingen'),
(23547, 4376, 6, 'Order samenvatting'),
(23548, 4377, 6, 'Track order'),
(23549, 4378, 6, 'Aangevraagde type'),
(23550, 4380, 6, 'Bestel/Resultaat Type'),
(23551, 4381, 6, 'Besteld'),
(23552, 4382, 6, 'Besteld door'),
(23553, 4383, 6, 'Ordered procedure'),
(23554, 4384, 6, 'Besteld door Dienstverlener:'),
(23555, 4385, 6, 'Order Path'),
(23556, 4386, 6, 'Orgaanletsel'),
(23557, 4387, 6, 'Organisatie'),
(23558, 4388, 6, 'Naam organisatie'),
(23559, 4389, 6, 'Naam Organisatie Unit'),
(23560, 4390, 6, 'Organisaties'),
(23561, 4391, 6, 'Georiënteerd tijd, persoon, plaats'),
(23562, 4392, 6, 'Origineel'),
(23563, 4393, 6, 'Originele checksom'),
(23564, 4394, 6, 'Oriya'),
(23565, 4395, 6, 'Oromo'),
(23566, 4396, 6, 'Orofarynx '),
(23567, 4397, 6, 'Ortopnea'),
(23568, 4398, 6, 'Linker oog'),
(23569, 4399, 6, 'Osteoartritis'),
(23570, 4400, 6, 'Ossetiaans, Ossetisch'),
(23571, 4401, 6, 'Osteopathie'),
(23572, 4402, 6, 'Ander'),
(23573, 4403, 6, 'ander'),
(23574, 4404, 6, 'Ander (specificeer)'),
(23575, 4405, 6, 'Anders - gespecificeerd'),
(23576, 4406, 6, 'Onder overheidsprogramma'),
(23577, 4407, 6, 'Andere HCFA'),
(23578, 4408, 6, 'Nadere kwetsuur nergens anders gespecificeerd'),
(23579, 4409, 6, 'Andere Aansprakelijkheids Verzekering is Primair'),
(23580, 4410, 6, 'andere maand'),
(23581, 4411, 6, 'Ander niet overheidsprogramma'),
(23582, 4412, 6, 'Andere notities'),
(23583, 4413, 6, 'Andere aanwezige symptomen'),
(23584, 4414, 6, 'Andere duidelijke symptomen:'),
(23585, 4415, 6, 'Andere pt resp'),
(23586, 4416, 6, 'Ander stress/overbelastings letsel'),
(23587, 4417, 6, 'Ander chirurgisch'),
(23588, 4418, 6, 'Ander/Generisch ivm abortus'),
(23589, 4420, 6, 'Anderen'),
(23590, 4421, 6, 'anders verbreekt u de connecties tussen bestaande tabellen'),
(23591, 4422, 6, 'Ottawa protocol voor enkel letsel'),
(23592, 4423, 6, 'Beide ogen'),
(23593, 4424, 6, 'UIT'),
(23594, 4425, 6, 'Kantoor verlaten'),
(23595, 4426, 6, 'Verwijzing naar elders'),
(23596, 4427, 6, 'Resultaat'),
(23597, 4428, 6, 'Outlook'),
(23598, 4429, 6, 'Soort uitvoer'),
(23599, 4430, 6, 'Alg. conditie bij ontslag'),
(23600, 4431, 6, 'Overtijd'),
(23601, 4432, 6, 'Overbelast'),
(23602, 4433, 6, 'Overzicht'),
(23603, 4434, 6, 'Overgewicht'),
(23604, 4435, 6, 'Overschrijf HIPAA keuze'),
(23605, 4437, 6, 'Zuurstof saturatie'),
(23606, 4438, 6, 'oz'),
(23607, 4439, 6, 'P'),
(23608, 4440, 6, 'p.c.'),
(23609, 4441, 6, 'p.m.'),
(23610, 4442, 6, 'zo nodig'),
(23611, 4443, 6, 'Pacific Eiland bewoner'),
(23612, 4444, 6, 'Pediatrisch'),
(23613, 4445, 6, 'Pagina'),
(23614, 4446, 6, 'Pagina´s'),
(23615, 4447, 6, 'Betaald'),
(23616, 4448, 6, 'Betaald bedrag dat u will plaatsen'),
(23617, 4449, 6, 'Betaald bedrag'),
(23618, 4450, 6, 'Betaald per'),
(23619, 4451, 6, 'Pijn'),
(23620, 4453, 6, 'Palpitatie'),
(23621, 4454, 6, 'Panjabi, Punjabi'),
(23622, 4455, 6, 'PAP smear'),
(23623, 4456, 6, 'Papier'),
(23624, 4457, 6, 'Papier maat'),
(23625, 4458, 6, 'Paralyse'),
(23626, 4459, 6, 'Ouder'),
(23627, 4461, 6, 'HL7 invoegen'),
(23628, 4463, 6, 'Partner'),
(23629, 4464, 6, 'Partner naam'),
(23630, 4466, 6, 'Pashto, Pushto'),
(23631, 4467, 6, 'Pass zin'),
(23632, 4468, 6, 'Pass zin om document te ontcijferen'),
(23633, 4469, 6, 'Gepasseerde patienten'),
(23634, 4470, 6, 'Passieve alert'),
(23635, 4471, 6, 'Passieve alert regels'),
(23636, 4472, 6, 'Wachtwoord'),
(23637, 4473, 6, 'Wachtwoord wijzigen'),
(23638, 4474, 6, 'Verandering Paswoord geslaagd'),
(23639, 4475, 6, 'Wachtwoord wijzigen gelukt.'),
(23640, 4476, 6, 'Paswoord voldoet niet aan de minimum eisen en moet minstens drie van de vier onderdelen bevatten: Een nummer, aan kleine letter, een hoofd lettereen speciaal karakter (geen letter of nummer).'),
(23641, 4477, 6, 'Tijd nog beschikbaar totdat het Paswoord verloopt'),
(23642, 4479, 6, 'Pasword voor telefoon Gateway. geautomatiseerde VOIP service verleend door Maviq. Bezoek http://signup.maviq.com voor meer informatie.'),
(23643, 4480, 6, 'Wachtwoord voor SMS Toegang'),
(23644, 4481, 6, 'Paswoord voor SMS toegang'),
(23645, 4482, 6, 'Paswoord voor voormelde gebruiker'),
(23646, 4483, 6, 'Paswoord veiligheid is kort geleden verbeterd.'),
(23647, 4484, 6, 'Paswoord om met CouchDB te verbinden'),
(23648, 4485, 6, 'Paswoord te kort, minimaal 8 karakters'),
(23649, 4486, 6, 'Wachtwoord:'),
(23650, 4487, 6, 'Wachtwoorden verschillend!'),
(23651, 4488, 6, 'Afspraken in verleden'),
(23652, 4489, 6, 'Afspraken in verleden, toon met Widget'),
(23653, 4490, 6, 'Verlopen'),
(23654, 4491, 6, 'Verlopen'),
(23655, 4492, 6, 'Verlopen interval (Klinische reminders)'),
(23656, 4493, 6, 'Verlopen interval (Patienten reminders)'),
(23657, 4494, 6, 'Patient Encounter lijst'),
(23658, 4495, 6, 'Episode geschiedenis'),
(23659, 4496, 6, 'Episode geschiedenis en Documenten'),
(23660, 4497, 6, 'Verlopen bezoek voor'),
(23661, 4498, 6, 'HL7 data invoegen'),
(23662, 4499, 6, 'Plak de te importeren data in het tekstveld hieronder:'),
(23663, 4500, 6, 'Pat'),
(23664, 4502, 6, 'Patch'),
(23665, 4508, 6, 'Pad om Event Log backup te maken'),
(23666, 4509, 6, 'Pad naar CA Certificaat bestand'),
(23667, 4510, 6, 'Pad naar CA key file'),
(23668, 4511, 6, 'Pad naar MSQL bin files'),
(23669, 4512, 6, 'Pad naar Perl Bin files'),
(23670, 4513, 6, 'Pad naar tijdelijke bestanden'),
(23671, 4514, 6, 'Patiënt'),
(23672, 4515, 6, 'patient'),
(23673, 4516, 6, 'PATIENT'),
(23674, 4517, 6, 'Adres van Patient'),
(23675, 4518, 6, 'Adres van Patient niet ingevuld'),
(23676, 4521, 6, 'Allergieen van pt'),
(23677, 4522, 6, 'Allergieen van pt'),
(23678, 4523, 6, 'Afspraak van pt'),
(23679, 4524, 6, 'Balans voor deze patient'),
(23680, 4525, 6, 'Patienten balans te betalen'),
(23681, 4528, 6, 'Patientkaart-ID'),
(23682, 4529, 6, 'Check-out patient'),
(23683, 4530, 6, 'Check-out voor patient: '),
(23684, 4531, 6, 'Woonplaats patient'),
(23685, 4532, 6, 'Woonplaats van Patient niet ingevuld'),
(23686, 4533, 6, 'Patiënt communicatie verzonden'),
(23687, 4534, 6, 'Patiënt communicatie verzonden'),
(23688, 4535, 6, 'Land van patient'),
(23689, 4536, 6, 'Land is voor patient niet ingevuld. Ook in Global sttings is het Land van patient niet ingevuld'),
(23690, 4537, 6, 'Dekking voor patient'),
(23691, 4539, 6, 'Data van patient'),
(23692, 4541, 6, 'Geboorte datum is niet ingevuld'),
(23693, 4542, 6, 'Details van patient'),
(23694, 4543, 6, 'Geb datum van patient'),
(23695, 4544, 6, 'Document van patient'),
(23696, 4545, 6, 'Patienten voorlichting'),
(23697, 4546, 6, 'Patienten voorlichtings materiaal'),
(23698, 4547, 6, 'Patientcontact(en)'),
(23699, 4548, 6, 'Patientencontactformulier'),
(23700, 4549, 6, 'Patiëntencontacten'),
(23701, 4550, 6, 'Patiënt opzoeken'),
(23702, 4551, 6, 'Voornaam patient'),
(23703, 4553, 6, 'Voornaam van patient niet ingevuld'),
(23704, 4558, 6, 'Geslacht patient'),
(23705, 4559, 6, 'Geslacht patient niet ingevuld'),
(23706, 4560, 6, 'Patient heeft nog geen toestemming gegeven voor Patient portal.'),
(23707, 4561, 6, 'Historie van patient'),
(23708, 4562, 6, 'Historie/leefwijze patient'),
(23709, 4563, 6, 'Huis tel nummer van patient'),
(23710, 4564, 6, 'Patiënt-ID'),
(23711, 4565, 6, 'Patenten ID'),
(23712, 4566, 6, 'Patient-ID kaart'),
(23713, 4567, 6, 'Patient ID Catogorie naam'),
(23714, 4568, 6, 'Vaccinatie van patient'),
(23715, 4569, 6, 'Patientinformatie'),
(23716, 4570, 6, 'Instructies aan patient'),
(23717, 4571, 6, 'Patient verdeeld naar verzekering'),
(23718, 4572, 6, 'Rapport patientverdeling per verzekering'),
(23719, 4573, 6, 'Problemen van patient'),
(23720, 4574, 6, 'Patient Label type'),
(23721, 4575, 6, 'Achtenaam patient'),
(23722, 4577, 6, 'Achternaam van patient niet ingevuld'),
(23723, 4581, 6, 'Patientenoverzicht'),
(23724, 4582, 6, 'Patient Lijst kolommen'),
(23725, 4584, 6, 'Patienten lijst nieuw venster'),
(23726, 4585, 6, 'Patienten lijst pagina afmeting'),
(23727, 4586, 6, 'Fouten tgv patient opzoeken'),
(23728, 4587, 6, 'Pt. Medische Problem(en)'),
(23729, 4588, 6, 'Medicatie patient'),
(23730, 4589, 6, 'Naam Patient'),
(23731, 4590, 6, 'Naam en adres patient'),
(23732, 4593, 6, 'Naam van de patient noodzakelijk'),
(23733, 4595, 6, 'Patientnotitie'),
(23734, 4596, 6, 'Soort patientnotitie'),
(23735, 4597, 6, 'Patientnotities'),
(23736, 4598, 6, 'Patientnotities (schrijven en toevoegen optioneel)'),
(23737, 4599, 6, 'Patientnummer'),
(23738, 4600, 6, 'Betaling door patient'),
(23739, 4602, 6, 'Patient foto categorie naam'),
(23740, 4603, 6, 'Patient ingang'),
(23741, 4604, 6, 'Patient Portaal verbindings probleem'),
(23742, 4605, 6, 'Patient toegang is uitgezet'),
(23743, 4606, 6, 'Patient toegang Login'),
(23744, 4607, 6, 'Patient toegang Web adres'),
(23745, 4608, 6, 'Afdruk van Pt rapport'),
(23746, 4609, 6, 'Overzicht van Patientgegevens'),
(23747, 4610, 6, 'Patient record verzoek'),
(23748, 4611, 6, 'Patient records verzoek'),
(23749, 4613, 6, 'Patient reminder'),
(23750, 4614, 6, 'Patient reminder Batch job'),
(23751, 4615, 6, 'Verwerk voorkeur voor anmaak Patient herinnering'),
(23752, 4616, 6, 'Patient reminder regels'),
(23753, 4617, 6, 'Patient reminder E-mails verzender'),
(23754, 4618, 6, 'Naam van verzender van Patient reminder'),
(23755, 4619, 6, 'Reminder voor pt'),
(23756, 4620, 6, 'Rapportage over patient'),
(23757, 4621, 6, 'Verzoek van patient'),
(23758, 4622, 6, 'Patient verzoek voor medische files'),
(23759, 4623, 6, 'Patient resultaat'),
(23760, 4624, 6, 'Patient zoek resultaten stijl'),
(23761, 4625, 6, 'Client zoeken/Toevoegscherm'),
(23762, 4626, 6, 'Patient setting'),
(23763, 4627, 6, 'Staat woonadres pt'),
(23764, 4629, 6, 'Samenvatting over deze patient'),
(23765, 4630, 6, 'Verklaringen voor patienten'),
(23766, 4631, 6, 'Patient ZIP'),
(23767, 4632, 6, 'patient(en) die overeenkomen met de demografische gegevens die u invoerdde.'),
(23768, 4633, 6, 'Clienten'),
(23769, 4634, 6, 'Patiënt:'),
(23770, 4635, 6, 'Patient-ID'),
(23771, 4636, 6, 'Patienten'),
(23772, 4637, 6, 'Bewerkte patienten'),
(23773, 4638, 6, 'Betalen'),
(23774, 4639, 6, 'Let extra op bij de Gedaan met keuzevakjes. Nadat de verzekeringen als compleet zijn gemarkeerd, zullen we aan de patient vragen om het openstaande bedrag te betalen; wanneer u vergeet om alle verzekeringen als compleet te markeren, dan zal het openstaande bedrag niet ontvangen worden!! Als de patient nog een restbedrag moet betalen, stel dan de vervaldatum overeenkomstig in, omdat dit gevolgen heeft voor de taal die op de patient verklaringen komen te staan.'),
(23775, 4640, 6, 'Betalingsdatum'),
(23776, 4641, 6, 'Betalings status'),
(23777, 4642, 6, 'Naam van betalende persoon'),
(23778, 4643, 6, 'Betaald door'),
(23779, 4644, 6, 'Betaler type'),
(23780, 4645, 6, 'Bataald nu'),
(23781, 4646, 6, 'Betaald door'),
(23782, 4647, 6, 'Betaling'),
(23783, 4648, 6, 'betaling'),
(23784, 4649, 6, 'Betalings aanpassing code'),
(23785, 4650, 6, 'Betaling voor tegenrekening'),
(23786, 4651, 6, 'Betaald bedrag'),
(23787, 4652, 6, 'Betaald bedrag moet numeriek zijn'),
(23788, 4653, 6, 'Betalings Categorie'),
(23789, 4654, 6, 'Datum betaling'),
(23790, 4655, 6, 'Betaling ingevoerd op'),
(23791, 4656, 6, 'Betaald door'),
(23792, 4657, 6, 'Betalings mogelijkheden'),
(23793, 4658, 6, 'Betalings Ins'),
(23794, 4659, 6, 'Betalings lijst'),
(23795, 4660, 6, 'Betalingsmethode'),
(23796, 4661, 6, 'Betaling gesorteerd op'),
(23797, 4662, 6, 'Status van betalen'),
(23798, 4663, 6, 'Betaald door'),
(23799, 4664, 6, 'Betaling waarde voor code '),
(23800, 4665, 6, 'Betalingen'),
(23801, 4667, 6, 'PCP'),
(23802, 4668, 6, 'Prcnt (%) van ROWS'),
(23803, 4669, 6, 'PDF'),
(23804, 4670, 6, 'PDF download geselecteerde statements'),
(23805, 4671, 6, 'PDF taal'),
(23806, 4672, 6, 'Bekken en billen'),
(23807, 4673, 6, 'Pemphigus'),
(23808, 4674, 6, 'Niet afgerond'),
(23809, 4675, 6, 'Wachtende op accoordering'),
(23810, 4676, 6, 'Resultaat nog niet ingevoerd'),
(23811, 4677, 6, 'Nog in ondezoek'),
(23812, 4678, 6, 'Resultaat nog niet bekend'),
(23813, 4679, 6, 'Lopende bestellingen'),
(23814, 4680, 6, 'Res volgt'),
(23815, 4681, 6, 'Review niet afgerond'),
(23816, 4682, 6, 'Rx telling pending'),
(23817, 4684, 6, 'Pennington Firm LibreEHR v'),
(23818, 4685, 6, 'Maagzweer/Ulcus Pepticum'),
(23819, 4686, 6, 'Per encounter'),
(23820, 4687, 6, 'per min'),
(23821, 4688, 6, 'Per neusgat'),
(23822, 4689, 6, 'per neusgat'),
(23823, 4690, 6, 'Oraal'),
(23824, 4691, 6, 'oraal'),
(23825, 4692, 6, 'Anaal'),
(23826, 4693, 6, 'anaal'),
(23827, 4694, 6, 'Procent'),
(23828, 4697, 6, 'Percentiel'),
(23829, 4698, 6, 'Rechts geperforeerd'),
(23830, 4699, 6, 'Begin zoekactie'),
(23831, 4700, 6, 'Deze actie uitvoeren'),
(23832, 4701, 6, 'Performance percentage'),
(23833, 4703, 6, 'Uitvoerende Lab. faciliteit'),
(23834, 4705, 6, 'Punt'),
(23835, 4706, 6, 'Periode in dagen datde gebruiker nog kan in loggen met verlopen paswoord'),
(23836, 4707, 6, 'Zorg rond operatie'),
(23837, 4708, 6, 'Perifeer'),
(23838, 4709, 6, 'Toestaan van "unsalted" paswoorden'),
(23839, 4710, 6, 'Persisch'),
(23840, 4711, 6, 'Persische(Farsi)'),
(23841, 4712, 6, 'Persoon'),
(23842, 4713, 6, 'Verpersoonlijken'),
(23843, 4714, 6, 'PG'),
(23844, 4715, 6, 'Apoth'),
(23845, 4716, 6, 'Pharm Com telling'),
(23846, 4717, 6, 'Apotheken'),
(23847, 4718, 6, 'Apotheek'),
(23848, 4719, 6, 'Apotheek Afd. Receptuur'),
(23849, 4720, 6, 'Pheumothorax'),
(23850, 4721, 6, 'phiMail CCD verzenden toegestaan'),
(23851, 4722, 6, 'phiMail mericht controle interval (minuten)'),
(23852, 4723, 6, 'phiMail boodschappen controle interval in minuten'),
(23853, 4724, 6, 'phiMal bericht aan gebruiker'),
(23854, 4725, 6, 'phiMial Paswoord'),
(23855, 4726, 6, 'phiMail Server adres'),
(23856, 4727, 6, 'phiMail Gebrukers naam'),
(23857, 4729, 6, 'Telefoon');
INSERT INTO `lang_definitions` VALUES
(23858, 4730, 6, 'Telefoon oproeplijst'),
(23859, 4731, 6, 'Rapport voor lijst telefoon gesprekken'),
(23860, 4732, 6, 'Mibiele telefoon'),
(23861, 4733, 6, 'Telefoon gateway Paswoord'),
(23862, 4734, 6, 'Telefoon gatway URL'),
(23863, 4735, 6, 'Telefoon Gateway Usernaam'),
(23864, 4736, 6, 'Huis telefoon'),
(23865, 4737, 6, 'Telefoon meldings uur'),
(23866, 4738, 6, 'Telefoon nummer'),
(23867, 4739, 6, 'Telefoon nummer'),
(23868, 4740, 6, 'Fotofobie'),
(23869, 4741, 6, 'Fotos'),
(23870, 4742, 6, 'Via PHP opgezocht'),
(23871, 4743, 6, 'PHP CURL module moet geactiveerd worden op uw Server'),
(23872, 4744, 6, 'PHP geëxtraheerd'),
(23873, 4745, 6, 'php-GACL toegangscontroles zijn uitgeschakeld'),
(23874, 4746, 6, 'PHP-gacl is niet geïnstalleerd'),
(23875, 4747, 6, 'Fysiek onderzoek'),
(23876, 4749, 6, 'Aanvraag door arts'),
(23877, 4750, 6, 'Handtekening arts'),
(23878, 4752, 6, 'Doktoren'),
(23879, 4753, 6, 'kies'),
(23880, 4754, 6, 'Kies'),
(23881, 4755, 6, 'Kies een CSS thema'),
(23882, 4756, 6, 'PID'),
(23883, 4757, 6, 'PID (Pelvic Infl. Disease)'),
(23884, 4758, 6, 'Pil grootte'),
(23885, 4759, 6, 'Pillen'),
(23886, 4760, 6, 'Plaats de database zip file in de volgende directory als deze geinstalleerd moet worden'),
(23887, 4761, 6, 'Plaats de verkregen ICD 10 database zip files in de volgende directory'),
(23888, 4762, 6, 'Plaats de verkregen ICD 10 database zip file in de volgende directory'),
(23889, 4763, 6, 'Plaats de verkregen RxNorm database zip file in de volgende directory'),
(23890, 4764, 6, 'Plaats de verkregen Snomed database zip file in de volgende directory'),
(23891, 4765, 6, 'Placeholder'),
(23892, 4766, 6, 'Placeholder (vult lege ACLs op)'),
(23893, 4767, 6, 'Vlakke tekst'),
(23894, 4768, 6, 'Plan'),
(23895, 4771, 6, 'Naam plan'),
(23896, 4775, 6, 'Plan set'),
(23897, 4779, 6, 'Plan:'),
(23898, 4782, 6, 'Plannen'),
(23899, 4784, 6, 'Speler'),
(23900, 4785, 6, 'Spel positie'),
(23901, 4786, 6, 'Voor informatie over deze rekening kunt u bellen met'),
(23902, 4787, 6, 'Verander uw paswoord'),
(23903, 4788, 6, 'File kiezen'),
(23904, 4789, 6, 'Kies een client'),
(23905, 4790, 6, 'Maak a.u.b. een geldige keuze uit de lijst'),
(23906, 4791, 6, 'Kies een valide selectie'),
(23907, 4792, 6, 'Selecteer een waarde voor'),
(23908, 4793, 6, 'Kies hierboven een datum range en klik'),
(23909, 4794, 6, 'Kies het juiste format EDI-271 file'),
(23910, 4795, 6, 'klik op "download-knop" om de ge-de-identificeerde data te downloaden'),
(23911, 4796, 6, 'Klik op "download knop" om de Re Identificatie data op te downloaden'),
(23912, 4797, 6, 'Sluit dit venster a.u.b af'),
(23913, 4798, 6, 'Vergelijk a.u.b. de nieuwe naam'),
(23914, 4800, 6, 'Eerst de waarde(n) corrigeren alvorens verder te gaan!'),
(23915, 4801, 6, 'Maak de volgende directory aan alvorens verder te gaan'),
(23916, 4802, 6, 'Accepteer dit recept a.u.b. niet, tenzij u het heeft ontvangen per fax.'),
(23917, 4803, 6, 'Accepteer dit recept a.u.b. niet, tenzij u het heeft ontvangen per fax.'),
(23918, 4804, 6, 'Maak GEEN gebruik van uw browser met de STOP of RELOAD knop terwijl deze pagina actief is, als er meer dan 10 minuten zijn verstreken, zal dit niet tot gevolg hebben dat het proces wordt gestopt op de server en onnodige resources zal gebruiken.'),
(23919, 4805, 6, 'ACTIVEER CURL Extensie'),
(23920, 4806, 6, 'ACTIVEER OEPNSSL Extensie'),
(23921, 4807, 6, 'ACTIVEER SOAP Extensie'),
(23922, 4808, 6, 'ACTIVEER XML Extensie'),
(23923, 4809, 6, 'Voer a.u.b. een datum in voor laatst beoordeeld'),
(23924, 4810, 6, 'Datum invoeren'),
(23925, 4811, 6, 'Verloop datum invullen'),
(23926, 4812, 6, 'Bericht aanmaken'),
(23927, 4813, 6, 'Voer a.u.b. een bedrag in met alleen cijfers en een punt.'),
(23928, 4814, 6, 'Nieuw paswoord invoeren'),
(23929, 4815, 6, 'Voer a.u.b. een titel in!'),
(23930, 4816, 6, 'Voer hierboven een bestaand Direct Adres in'),
(23931, 4817, 6, 'Minstens de Item naam invoeren'),
(23932, 4818, 6, 'minstens de track-naam invoeren'),
(23933, 4819, 6, 'Goede Re Identificatie code invullen'),
(23934, 4820, 6, 'Einddatum moet na de begindatum vallen!'),
(23935, 4821, 6, 'Nieuwe zoek opdracht geven'),
(23936, 4822, 6, 'De juiste Re-Identificatie code invullen'),
(23937, 4823, 6, 'Voer a.u.b. een wachtwoord in'),
(23938, 4824, 6, 'Cheque nummer invullen'),
(23939, 4825, 6, 'Ceck/Ref nummer invullen'),
(23940, 4826, 6, 'Datum invullen'),
(23941, 4827, 6, 'Betaald bedrag invullen'),
(23942, 4828, 6, 'Betaalde categorie invullen'),
(23943, 4829, 6, 'Vorm vanbetaling invullen'),
(23944, 4830, 6, 'Datum van vastleggen invullen'),
(23945, 4831, 6, 'Dit invullen voor verder te gaan'),
(23946, 4832, 6, 'Geef reden van visite aan'),
(23947, 4833, 6, 'Voer input search gegevens hierboven in en klik op verzenden om rapport te starten.'),
(23948, 4834, 6, 'Vul zoek criteria in en klik Zoek om resultaat te zien'),
(23949, 4835, 6, 'Vul zoek criteria hierboven in en klik op Zoek om resultaten te zien. (Resultaten worden getoond in een pop-up scherm)'),
(23950, 4836, 6, 'Opnieuw inloggen.'),
(23951, 4837, 6, 'Houd er rekening mee dat dit erg lang kan duren, zelfs tot enkele minuten, uw webbrowser lijkt niet erg actief in deze tijd, maar het genereren van een factuur is een ingewikkeld proces en uw webbrowser is slechts in afwachting van meer informatie.'),
(23952, 4838, 6, 'Let op: constanten zijn hoofdlettergevoelig en iedere string is toegestaan.'),
(23953, 4839, 6, 'Gebruik alleen letters'),
(23954, 4840, 6, 'Gebruik alleen letters zonder spaties'),
(23955, 4841, 6, 'Gelieve dit bedrag betalen'),
(23956, 4842, 6, 'Plaats uw installatie files in de volgende directory'),
(23957, 4843, 6, 'Verwijzing naar'),
(23958, 4844, 6, 'Paswoord wijzigen'),
(23959, 4845, 6, 'Apache Server opnieuw opstarten voor de De-Identificatie te bewerken'),
(23960, 4846, 6, 'Bekijk de bijgevoede attachment'),
(23961, 4847, 6, 'Kiezen'),
(23962, 4849, 6, 'Kies een taal'),
(23963, 4850, 6, 'Kies een patient'),
(23964, 4851, 6, 'Selecteer de Hoofd Faciliteit met TAX ID voor uw faciliteit. Voor eenmans bedrijf gebruik eigen tax id. Hiermee zoekt NewCrop naar identificatie.'),
(23965, 4853, 6, 'Graag een procedure provider selecteren'),
(23966, 4854, 6, 'Ontvanger selecteren'),
(23967, 4855, 6, 'Kies een start en eind datum'),
(23968, 4856, 6, 'Valide ontvanger selecteren'),
(23969, 4857, 6, 'Actieve groep selecteren'),
(23970, 4858, 6, 'Selecteer een reden voor aanpassing van code '),
(23971, 4859, 6, 'Selecteer gebeurtenis'),
(23972, 4860, 6, 'Zoekoptie kiezen'),
(23973, 4863, 6, 'Minstens één recept kiezen'),
(23974, 4864, 6, 'Encounter selecteren'),
(23975, 4865, 6, 'Selecteer de gewenste pagina''s om te kopiëren of door te sturen:'),
(23976, 4866, 6, 'Manier van betalen selecteren'),
(23977, 4867, 6, 'Manier van betalen selecteren.'),
(23978, 4868, 6, 'Bezoek categorie slecteren'),
(23979, 4869, 6, 'X12 partner kiezen, nodig om de 270 verzameling te verwerken'),
(23980, 4870, 6, 'Opnieuw instellen'),
(23981, 4871, 6, 'Zet de de_identification_config variabele terug op nul'),
(23982, 4873, 6, 'Opnieuwd De-Identificatie proces starten'),
(23983, 4874, 6, 'LibreEHR DB upgraden om de De-Identificatie procedure, functie, tafels toe te voegen'),
(23984, 4875, 6, 'Bekijk de De-Identificatie fout-log-tabel voor meer details'),
(23985, 4876, 6, 'Bezoek het De-Indentificatie scherm wat later'),
(23986, 4877, 6, 'Bezoek het Re-Identificatie scherm wat later'),
(23987, 4878, 6, 'Bezoek het specifieke scherm wat later'),
(23988, 4879, 6, 'Item om te plotten'),
(23989, 4880, 6, 'Geselecteerde plot items'),
(23990, 4881, 6, 'Meervoud'),
(23991, 4882, 6, 'PM'),
(23992, 4883, 6, 'PM Programma'),
(23993, 4884, 6, 'Methode van betaling'),
(23994, 4885, 6, 'PND'),
(23995, 4886, 6, 'Pneumococ Conj 1'),
(23996, 4887, 6, 'Pneumococ Conj 2'),
(23997, 4888, 6, 'Pneumococ Conj 3'),
(23998, 4889, 6, 'Pneumococ Conj 4'),
(23999, 4890, 6, 'Pneumococcen vaccin'),
(24000, 4891, 6, 'Pneumococcen vaccinatie'),
(24001, 4892, 6, 'Pneumonie vaccinatie status voor ouderen'),
(24002, 4893, 6, 'Pneumonie VaccinatiePneumococcen vaccinatie status voor ouderen (CQM)'),
(24003, 4894, 6, 'Podiatrie'),
(24004, 4895, 6, 'Podiatrie'),
(24005, 4896, 6, 'Point of Service (POS)'),
(24006, 4897, 6, 'Beleid'),
(24007, 4898, 6, 'Polis #'),
(24008, 4899, 6, 'Polis nummer'),
(24009, 4900, 6, 'Pools'),
(24010, 4901, 6, 'Polydipsie'),
(24011, 4902, 6, 'Poliepen'),
(24012, 4903, 6, 'Polyurie'),
(24013, 4904, 6, 'Slechte eetlust'),
(24014, 4905, 6, 'Slechte circulatie'),
(24015, 4906, 6, 'Verminderd gehoor'),
(24016, 4907, 6, 'Pop-ups moet toegestaan worden om deze rapporten te zien'),
(24017, 4908, 6, 'Jaaroverzicht vullen met gebeurtenissen?'),
(24018, 4909, 6, 'Overzicht'),
(24019, 4910, 6, 'Ingang'),
(24020, 4911, 6, 'Portaal activiteit'),
(24021, 4912, 6, 'Portaal ID'),
(24022, 4913, 6, 'Portaal ID komt niet overeen met het verzoek aan de portaal!'),
(24023, 4914, 6, 'Portaal paswoord wordt gemist'),
(24024, 4915, 6, 'Portaal verzoek'),
(24025, 4916, 6, 'Portret'),
(24026, 4917, 6, 'Portugees'),
(24027, 4918, 6, 'Portugees (Brazilie)'),
(24028, 4919, 6, 'Portugees (Europa)'),
(24029, 4920, 6, 'POS-code'),
(24030, 4921, 6, 'Positie'),
(24031, 4922, 6, 'Positief'),
(24032, 4923, 6, 'Positieven'),
(24033, 4925, 6, 'Vastleggen voor'),
(24034, 4926, 6, 'Post Nasal Drip'),
(24035, 4927, 6, 'Betalingen vastleggen'),
(24036, 4928, 6, 'Na chirurgische'),
(24037, 4929, 6, 'Verzenden naar de boekhouding en markeren als gefactureerd'),
(24038, 4930, 6, 'Op datum vastleggen'),
(24039, 4931, 6, 'Op datum vastleggen kan niet later zijn dan vandaag'),
(24040, 4932, 6, 'Vastleggen op datum moet groter zijn dan de Financiele sluitings dag'),
(24041, 4933, 6, 'Abortus nazorg'),
(24042, 4934, 6, 'Post-abortus anticonceptie'),
(24043, 4935, 6, 'Post-abortus begeleiding'),
(24044, 4936, 6, 'Post-abortus controle'),
(24045, 4937, 6, 'Per post'),
(24046, 4938, 6, 'Postcode'),
(24047, 4939, 6, 'Postcode'),
(24048, 4941, 6, 'PostCalendar'),
(24049, 4942, 6, 'PostCalendar administratie'),
(24050, 4943, 6, 'PostCalendar categorie-instellingen'),
(24051, 4944, 6, 'PostCalendar Global Settings'),
(24052, 4945, 6, 'Geplaatst op'),
(24053, 4946, 6, 'Datum plaatsing'),
(24054, 4947, 6, 'Pos{{Afkorting voor Positie}}'),
(24055, 4948, 6, 'Powered by'),
(24056, 4949, 6, 'PPE+Prev Med/Chir Hx'),
(24057, 4950, 6, 'PQRI'),
(24058, 4951, 6, 'PQRI geregistreerd ID'),
(24059, 4952, 6, 'PQRI Registratie naam'),
(24060, 4953, 6, 'Praktijk gerelateerd'),
(24061, 4954, 6, 'Default waarden voor Praktijk'),
(24062, 4955, 6, 'Settings voor Praktijk'),
(24063, 4956, 6, 'Behandelaar'),
(24064, 4957, 6, 'Voor-participatie evaluatie'),
(24065, 4958, 6, 'Vooruit betalen'),
(24066, 4959, 6, 'Vooruit betaling'),
(24067, 4960, 6, 'Consultatie pre-abortus'),
(24068, 4961, 6, 'Pre-abortus begeleiding'),
(24069, 4962, 6, 'Pref Cat'),
(24070, 4963, 6, 'Voorkeur'),
(24071, 4964, 6, 'Voorkeuren'),
(24072, 4965, 6, 'Voorkeurs gebeurtenissen categorie'),
(24073, 4966, 6, 'Voorkeurstaal'),
(24074, 4967, 6, 'Voorkeursapotheek'),
(24075, 4968, 6, 'Preferred Provider Organization (PPO)'),
(24076, 4969, 6, 'Zwang.test'),
(24077, 4970, 6, 'Voorlopig'),
(24078, 4971, 6, 'Voorbereiding om rapport te maken'),
(24079, 4972, 6, 'Vooruitbetalen'),
(24080, 4973, 6, 'Recept'),
(24081, 4974, 6, 'recept heeft de limiet bereikt van'),
(24082, 4975, 6, 'Voorschrijf historie'),
(24083, 4976, 6, 'Voorschrijf historie import succesvol afgerond'),
(24084, 4977, 6, 'Receptlabel'),
(24085, 4978, 6, 'Voorschrijf rapport'),
(24086, 4979, 6, 'Recepten'),
(24087, 4980, 6, 'Voorschriften en Ontheffingen'),
(24088, 4981, 6, 'Voorschriften en andere verwijzingen'),
(24089, 4982, 6, 'Voorschriften en/of verwijzing door specialist'),
(24090, 4983, 6, 'Overzicht recepten'),
(24091, 4984, 6, 'Voorschriften/Verwijzingen'),
(24092, 4985, 6, 'Aanwezig'),
(24093, 4986, 6, 'Klacht zoals gepresenteerd'),
(24094, 4987, 6, 'Toon Issue(s)'),
(24095, 4988, 6, 'Druk op Doorgaan om verder te gaan'),
(24096, 4989, 6, 'Voorlopige diagnose'),
(24097, 4990, 6, 'Vermoedelijke diagnose van specialist'),
(24098, 4991, 6, 'Terug'),
(24099, 4992, 6, 'Voorafgaande Med/Chir Historie'),
(24100, 4993, 6, 'Vorige maand (ingedrukt houden voor menu)'),
(24101, 4994, 6, 'Vorig jaar (ingedrukt houden voor menu)'),
(24102, 4995, 6, 'Preventieve zorg'),
(24103, 4996, 6, 'Rehab preventie'),
(24104, 4998, 6, 'Gebeurtenis preview'),
(24105, 5000, 6, 'Preview van'),
(24106, 5001, 6, 'Vorig'),
(24107, 5002, 6, 'Eerdere consultaties'),
(24108, 5003, 6, 'Vorige dag'),
(24109, 5004, 6, 'Vorige Historie/Controles'),
(24110, 5005, 6, 'Vorige maand'),
(24111, 5006, 6, 'Vorige week'),
(24112, 5007, 6, 'Prijs'),
(24113, 5008, 6, 'Korting'),
(24114, 5009, 6, 'Prijsniveau'),
(24115, 5010, 6, 'Prijsniveau:'),
(24116, 5011, 6, 'Bedragen'),
(24117, 5012, 6, 'Primaire'),
(24118, 5013, 6, 'Hoofd Business entiteit'),
(24119, 5014, 6, 'Hoofd BusinessEntiteit Tax ID wordt gebruikt voor NewCrop e-Prescription. Verandering van faciliteit heeft effecten op de werking van Newcrop'),
(24120, 5022, 6, 'Hoofdverz.'),
(24121, 5023, 6, 'Hoofdverzekering'),
(24122, 5024, 6, 'Data van hoofdverzekering'),
(24123, 5025, 6, 'Verstrekker hoofdverzekering'),
(24124, 5026, 6, 'Hoofd behandelaar'),
(24125, 5027, 6, 'Print'),
(24126, 5028, 6, 'Printen (HTML)'),
(24127, 5029, 6, 'Printen (PDF)'),
(24128, 5030, 6, 'Print aanpassingen'),
(24129, 5031, 6, 'Printen keuze Encounter'),
(24130, 5032, 6, 'Druk blanco verwijsbrief af'),
(24131, 5033, 6, 'Commando om te printen'),
(24132, 5034, 6, 'Datum van afdrukken'),
(24133, 5038, 6, 'Hele listing printen'),
(24134, 5039, 6, 'Afdrukformat'),
(24135, 5040, 6, 'Print vier rec. op A4'),
(24136, 5042, 6, 'Boodschap uitprinten'),
(24137, 5043, 6, 'Meerdere recepten afdrukken'),
(24138, 5044, 6, 'Meerdere afdrukken naar fax'),
(24139, 5045, 6, 'Printen van naam, handtekening en datum'),
(24140, 5046, 6, 'Printen notities'),
(24141, 5047, 6, 'Pagina 1 afdrukken'),
(24142, 5048, 6, 'Pagina 2 afdrukken'),
(24143, 5049, 6, 'Patient adres label printen'),
(24144, 5051, 6, 'Print kwitanties per aanbieder'),
(24145, 5052, 6, 'Print Status'),
(24146, 5053, 6, 'Print geselecteerde statements'),
(24147, 5054, 6, 'Print Vacc.verslag'),
(24148, 5056, 6, 'Print deze Encounter'),
(24149, 5057, 6, 'Print deze Notitie'),
(24150, 5058, 6, 'Print deze Notitie'),
(24151, 5060, 6, 'Print naar fax'),
(24152, 5061, 6, 'Print voorbeeld'),
(24153, 5062, 6, 'Afdrukbaar'),
(24154, 5063, 6, 'Afdrukbare versie'),
(24155, 5064, 6, 'Afgedrukt'),
(24156, 5066, 6, 'Afdrukresultaten:'),
(24157, 5067, 6, 'Afdrukken overgeslagen; zie testresultaat in'),
(24158, 5068, 6, 'Afdrukken overgeslagen; zie testresultaat in '),
(24159, 5069, 6, 'Eerst Auteur'),
(24160, 5070, 6, 'Vorige autorisatie formulieren'),
(24161, 5071, 6, 'Eerder bezoek'),
(24162, 5072, 6, 'Urgentie'),
(24163, 5073, 6, 'Voorkeur '),
(24164, 5074, 6, 'Prive'),
(24165, 5075, 6, 'Probleem'),
(24166, 5076, 6, 'Probleem lijst'),
(24167, 5077, 6, 'Probleemlijst'),
(24168, 5078, 6, 'Problemen'),
(24169, 5079, 6, 'Problemen/Ziekten'),
(24170, 5080, 6, 'Proc Bat'),
(24171, 5081, 6, 'Proc Cat'),
(24172, 5082, 6, 'Proc Load'),
(24173, 5083, 6, 'Proc in afwachting van review'),
(24174, 5084, 6, 'Proc prov'),
(24175, 5085, 6, 'Proc Res'),
(24176, 5086, 6, 'Verrichtingen'),
(24177, 5087, 6, 'Verrichtingen op lichaamsdeel'),
(24178, 5088, 6, 'Verrichtingen resultaat Boolean'),
(24179, 5089, 6, 'Verrichtingen Code'),
(24180, 5090, 6, 'Verrichtingen Codes'),
(24181, 5091, 6, 'Verrichtingen Links, rechts, beide'),
(24182, 5092, 6, 'Naam van de Procedure'),
(24183, 5093, 6, 'Verrichtingen aanvraag'),
(24184, 5094, 6, 'Volgorde van de procedure'),
(24185, 5095, 6, 'Verrichtingen aanvraag voor'),
(24186, 5096, 6, 'Verzoek om procedure niet gevonden'),
(24187, 5097, 6, 'verrichtingen aanvraag en rapporten'),
(24188, 5098, 6, 'Kies menu voor Procedures'),
(24189, 5099, 6, 'Verstrekker van Procedure'),
(24190, 5100, 6, 'Verstrekker van Procedure'),
(24191, 5101, 6, 'Verstrekkers van Procedure'),
(24192, 5102, 6, 'Rapport verrichtingen'),
(24193, 5103, 6, 'Verrichtingen verslag status'),
(24194, 5104, 6, 'Uitslag verrichting afwijkend'),
(24195, 5105, 6, 'Uitslag verrichting status'),
(24196, 5106, 6, 'Resultaat verrichting'),
(24197, 5107, 6, 'Verrichting Routes'),
(24198, 5108, 6, 'Verrichting Specimen type'),
(24199, 5109, 6, 'Statistisch Rapport verrichtingen'),
(24200, 5110, 6, 'Verrichtingen Type'),
(24201, 5111, 6, 'Verrichtingen Types'),
(24202, 5112, 6, 'Verrichtingen eenheid'),
(24203, 5113, 6, 'Procedure/Service'),
(24204, 5114, 6, 'Verrichtingen'),
(24205, 5115, 6, 'Verwerken'),
(24206, 5116, 6, 'Herinneringen verwerken en versturen'),
(24207, 5117, 6, 'Verwerk ERA bestand'),
(24208, 5118, 6, 'Verwerk nieuwe files voor CSV gegevens'),
(24209, 5119, 6, 'Proces herinneringen'),
(24210, 5120, 6, 'Proces neemt enige tijd'),
(24211, 5121, 6, 'Verwerkt'),
(24212, 5122, 6, 'Verwerkt door'),
(24213, 5123, 6, 'Verwerkings datum'),
(24214, 5124, 6, 'Succesvol verwerkt'),
(24215, 5125, 6, 'Verwerking'),
(24216, 5126, 6, 'Patient herinneringen verwerken en versturen'),
(24217, 5127, 6, 'Patient herinneringen verwerken'),
(24218, 5128, 6, 'verwerkings tijd'),
(24219, 5129, 6, 'Product'),
(24220, 5130, 6, 'Anticonceptie Methode'),
(24221, 5131, 6, 'Productie'),
(24222, 5132, 6, 'Producten'),
(24223, 5133, 6, 'Producten, maar geen medicijnen op voorschrift en geen templates'),
(24224, 5134, 6, 'Prof.'),
(24225, 5135, 6, 'Voortgangs notities'),
(24226, 5136, 6, 'Prostaatkanker'),
(24227, 5137, 6, 'Prostaat examen'),
(24228, 5138, 6, 'Prostaatonderzoek'),
(24229, 5139, 6, 'Prostaatproblemen'),
(24230, 5140, 6, 'Prostaat met/of vergroting, knobbels, gevoelig'),
(24231, 5141, 6, 'Protocol'),
(24232, 5142, 6, 'Absolute pad aangeven'),
(24233, 5143, 6, 'Absolute pad van File aangeven'),
(24234, 5145, 6, 'Geef klinische samnevatting van ieder praktijk bezoek'),
(24235, 5146, 6, 'Geef patienten een lectronische copie vanhet gezondheids info (Met diagnostische test resultaten, probleem lijst, medicijn lijst , medicatie allergie) op verzoek.'),
(24236, 5147, 6, 'Voorzie patienten met een tijdig electronische toegang tot hun gezondheids informatie (met lab testen, probleemlijst, medicatie lijst, aleergie voor medicijnen) binnen vier werkdagen vanaf de informatie voor het EP beschikbaar komt.'),
(24237, 5148, 6, 'Geef status aan de patient voor bezoek'),
(24238, 5149, 6, 'Geef een bestaand e-mail adres'),
(24239, 5150, 6, 'Klinische samenvatting(en) geven?'),
(24240, 5151, 6, 'Verstrek voorlichting bron(nen)?'),
(24241, 5152, 6, 'Behandelaar'),
(24242, 5153, 6, 'Behandelaar Id'),
(24243, 5154, 6, 'Behandelaar Id'),
(24244, 5155, 6, 'Behandelaar Id bij gespecificeerde Faciliteit'),
(24245, 5156, 6, 'Behandelaar Matching fouten'),
(24246, 5159, 6, 'Nummer van behandelaar'),
(24247, 5160, 6, 'Relatie tot behandelaar'),
(24248, 5162, 6, 'Behandelaar:'),
(24249, 5163, 6, 'Behandelaars'),
(24250, 5164, 6, 'Behandelaar''s NPI'),
(24251, 5165, 6, 'Zorgverleners zien de hele Kalender'),
(24252, 5166, 6, 'Beh.'),
(24253, 5167, 6, 'PSA'),
(24254, 5168, 6, 'Psoriasis'),
(24255, 5169, 6, 'Psychische diagnose'),
(24256, 5170, 6, 'Psychische medicatie'),
(24257, 5171, 6, 'Psychisch'),
(24258, 5172, 6, 'Psychische brief'),
(24259, 5173, 6, 'Psychische diagnose'),
(24260, 5174, 6, 'Psychisch onderzoek'),
(24261, 5175, 6, 'Psychische historie'),
(24262, 5176, 6, 'Psychische intake'),
(24263, 5177, 6, 'Psychische medicatie'),
(24264, 5178, 6, 'Pt %'),
(24265, 5179, 6, 'Pt.notitie'),
(24266, 5180, 6, 'Pt.notitie/autor.'),
(24267, 5181, 6, 'Pt.teveel'),
(24268, 5182, 6, 'Pt.betaald'),
(24269, 5183, 6, 'Pt verzoekt statusinfo'),
(24270, 5184, 6, 'Pt.restitutie'),
(24271, 5185, 6, 'Pt.ontslagen'),
(24272, 5186, 6, 'Rapport van patient'),
(24273, 5187, 6, 'PT Student, of leeg laten'),
(24274, 5188, 6, 'PT_CITY'),
(24275, 5189, 6, 'PT_GEB'),
(24276, 5190, 6, 'PT_EMAIL'),
(24277, 5191, 6, 'PT_VNAAM'),
(24278, 5192, 6, 'PT_ANAAM'),
(24279, 5193, 6, 'PT_MNAAM'),
(24280, 5194, 6, 'PT_PHONE_CELL'),
(24281, 5195, 6, 'PT_PHONE_HOME'),
(24282, 5196, 6, 'PT_POSTAL'),
(24283, 5197, 6, 'PT_SSN'),
(24284, 5198, 6, 'PT_STAAT'),
(24285, 5199, 6, 'PT_STRAAT'),
(24286, 5201, 6, 'Openbaar'),
(24287, 5203, 6, 'Public health Service (PHS) of andere overheids instantie'),
(24288, 5204, 6, 'Puertoricaans'),
(24289, 5205, 6, 'Pulmonale'),
(24290, 5206, 6, 'Pols'),
(24291, 5207, 6, 'Punjabi'),
(24292, 5208, 6, 'Aankoop'),
(24293, 5209, 6, 'Kopen/Retourneren'),
(24294, 5210, 6, 'Aankopen'),
(24295, 5211, 6, 'P{{Justify Header}}'),
(24296, 5212, 6, 'Pali'),
(24297, 5213, 6, 'iedere 3 uur'),
(24298, 5214, 6, 'iedere 4 uur'),
(24299, 5215, 6, 'iedere 5 uur'),
(24300, 5216, 6, 'iedere 6 uur'),
(24301, 5217, 6, 'iedere 8 uur'),
(24302, 5218, 6, 'qd'),
(24303, 5219, 6, 'qid'),
(24304, 5220, 6, 'QOH'),
(24305, 5221, 6, 'QOH is minder dan maandelijks gebruik'),
(24306, 5222, 6, 'Aant'),
(24307, 5223, 6, 'KWT'),
(24308, 5224, 6, 'Kwaliteit'),
(24309, 5225, 6, 'Qualiteit Metingen'),
(24310, 5226, 6, 'Hoeveelheid'),
(24311, 5227, 6, 'Hoeveelheid voor NDC'),
(24312, 5228, 6, 'Hoeveelheid ter beschikking'),
(24313, 5229, 6, 'hoeveelheid lijkt onbruikbaar'),
(24314, 5230, 6, 'Quechua'),
(24315, 5231, 6, 'Vraagteken'),
(24316, 5232, 6, 'Wachtrij voor HCFA batch-verwerking'),
(24317, 5233, 6, 'Wachtrij voor HCFA batch-verwerking en afdrukken'),
(24318, 5234, 6, 'Wachtrij voor de UB-92 batch-verwerking'),
(24319, 5235, 6, 'Wachtrij voor de UB-92 batch-verwerking en afdrukken'),
(24320, 5236, 6, 'In wachtrij'),
(24321, 5237, 6, 'Evenementen administratie in wachtrij'),
(24322, 5238, 6, 'Wachtrij voor'),
(24323, 5240, 6, 'In wachtrij voor toezending aan administratie'),
(24324, 5241, 6, 'Stoppen'),
(24325, 5242, 6, 'Stoppen met Alcohol'),
(24326, 5243, 6, 'R'),
(24327, 5244, 6, 'RA voor Patient, Ecounter of Tracen'),
(24328, 5245, 6, 'Ras'),
(24329, 5246, 6, 'Ras en Etniciteit'),
(24330, 5247, 6, 'Roots/Etnische achtergrond'),
(24331, 5248, 6, 'Radio'),
(24332, 5249, 6, 'Radio knoppen'),
(24333, 5251, 6, 'Bereik'),
(24334, 5252, 6, 'Huiduitslag'),
(24335, 5253, 6, 'Tarief'),
(24336, 5254, 6, 'Verhouding'),
(24337, 5255, 6, 'Voorlopig rapport'),
(24338, 5256, 6, 'Re-Identificatie'),
(24339, 5257, 6, 'Re-Identificatie proces is afgerond'),
(24340, 5258, 6, 'Re-Identificatie proces is nog aan de gang'),
(24341, 5259, 6, 'Re-Identificatie files worden bewaar in'),
(24342, 5260, 6, 'Reeds eerder opgelopen kwetsuur?'),
(24343, 5261, 6, 'Opnieuw openen'),
(24344, 5262, 6, 'Heropend'),
(24345, 5263, 6, 'Reactie'),
(24346, 5264, 6, 'Reacties'),
(24347, 5265, 6, 'Lezen'),
(24348, 5267, 6, 'Alleen uitlezen van Historie'),
(24349, 5268, 6, 'Echte naam'),
(24350, 5269, 6, 'Echt verwijderen'),
(24351, 5270, 6, 'Reden'),
(24352, 5271, 6, 'Reden van overlijden'),
(24353, 5272, 6, 'Reden van sterven'),
(24354, 5274, 6, 'Reden verwijzing'),
(24355, 5275, 6, 'Reden van bezoek'),
(24356, 5276, 6, 'Reden/Form'),
(24357, 5277, 6, 'Recu'),
(24358, 5278, 6, 'Betalingsbewijs'),
(24359, 5279, 6, 'Recu aangemaakt'),
(24360, 5280, 6, 'Wijze van betaling'),
(24361, 5281, 6, 'Samenvatting ontvangstbewijzen'),
(24362, 5282, 6, 'Ontvangen'),
(24363, 5283, 6, 'Ontvangen door'),
(24364, 5284, 6, 'Ontvangen faxen'),
(24365, 5285, 6, 'Ontvangen, niet gecontroleerd'),
(24366, 5286, 6, 'Ontvangen, niet gecontroleerd'),
(24367, 5287, 6, 'Ontvanger'),
(24368, 5288, 6, 'ID van ontvanger'),
(24369, 5289, 6, 'ID (ISA08) ontvanger'),
(24370, 5290, 6, 'ID Qualifier (ISA07) ontvanger'),
(24371, 5291, 6, 'ID van ontvanger'),
(24372, 5292, 6, 'Recente laatste drie paswoorden niet mogelijk.'),
(24373, 5293, 6, 'Ontvanger'),
(24374, 5294, 6, 'Ontvangers lijst is leeg'),
(24375, 5295, 6, 'Naam van ontvanger'),
(24376, 5296, 6, 'Ontvanger van vermelding'),
(24377, 5297, 6, 'Onvanger verplicht tenzij als afgedaan aangegeven'),
(24378, 5298, 6, 'Aanbeveling'),
(24379, 5299, 6, 'Follow-up aanbevolen'),
(24380, 5300, 6, 'Aanbevelingen'),
(24381, 5301, 6, 'Aanbevelingen en behandeling'),
(24382, 5302, 6, 'Aanbevelingen door specialist'),
(24383, 5303, 6, 'Vastleggen/Status'),
(24384, 5304, 6, 'Status bestaat reeds'),
(24385, 5310, 6, 'Veranderingen in status en vital signs'),
(24386, 5311, 6, 'Opslaan van demografische gegevens'),
(24387, 5312, 6, 'Vastleggen vermelding'),
(24388, 5313, 6, 'Vastleggen van conditie'),
(24389, 5314, 6, 'Betaling vastleggen'),
(24390, 5315, 6, 'Vastleggen verzoek datum'),
(24391, 5316, 6, 'Leg rook gewoonten voor patienten 13 jaar en ouder vast'),
(24392, 5317, 6, 'Statussen'),
(24393, 5318, 6, 'gegevens gevonden'),
(24394, 5319, 6, 'gegevens gevonden.'),
(24395, 5320, 6, 'Recreational drugs gebruik'),
(24396, 5321, 6, 'Recreatie drugs'),
(24397, 5322, 6, 'Rectaal'),
(24398, 5323, 6, 'Rectaalonderzoek'),
(24399, 5324, 6, 'rectaal'),
(24400, 5325, 6, 'Redirection'),
(24401, 5326, 6, 'Roodheid'),
(24402, 5327, 6, 'vermindert:'),
(24403, 5328, 6, 'Verwijzen'),
(24404, 5329, 6, 'Verwijzing door'),
(24405, 5330, 6, 'Datum verwijzing'),
(24406, 5331, 6, 'Verwijs naar'),
(24407, 5332, 6, 'Classificatie verwijzing (urgentie-niveau)'),
(24408, 5333, 6, 'Referentie gebied voor resultaten'),
(24409, 5334, 6, 'Reden verwijzing'),
(24410, 5335, 6, 'Verwijzer'),
(24411, 5336, 6, 'Naam en handtekening verwijzer'),
(24412, 5337, 6, 'Verwijzing'),
(24413, 5338, 6, 'Verwijzing door'),
(24414, 5339, 6, 'Verwijskaart'),
(24415, 5340, 6, 'Verwijsdatum'),
(24416, 5341, 6, 'Verwijsbrief'),
(24417, 5342, 6, 'Verwijzing'),
(24418, 5343, 6, 'ID voor verwijzing'),
(24419, 5345, 6, 'Bron aanmelding'),
(24420, 5346, 6, 'Oorsprong van verwijzing voor Encounters'),
(24421, 5347, 6, 'Verwijzing naar'),
(24422, 5348, 6, 'Verwijzingen'),
(24423, 5349, 6, 'Overzicht verwijzingen'),
(24424, 5350, 6, 'Verwezen door'),
(24425, 5351, 6, 'Verwezen door'),
(24426, 5352, 6, 'Verwezen naar'),
(24427, 5353, 6, 'Verwijzer'),
(24428, 5354, 6, 'Adres van verwijzer'),
(24429, 5355, 6, 'Diagnose van verwijzer'),
(24430, 5356, 6, 'Diagnose van verwijzer'),
(24431, 5357, 6, 'Dokter en praktijkgegevens van verwijzer'),
(24432, 5358, 6, 'Verwijzende behandelaar'),
(24433, 5359, 6, 'Herhaling'),
(24434, 5360, 6, 'Herhalingen'),
(24435, 5361, 6, 'herhalingen'),
(24436, 5362, 6, 'Normale reflexen'),
(24437, 5363, 6, 'Vernieuwen'),
(24438, 5365, 6, 'Verversen herinnerings oproepen'),
(24439, 5368, 6, 'Geweigerd verklaring af te leggen'),
(24440, 5369, 6, 'reg_re'),
(24441, 5370, 6, 'registreren'),
(24442, 5371, 6, 'Register'),
(24443, 5372, 6, 'Geregistreerd'),
(24444, 5373, 6, 'geregistreerd'),
(24445, 5374, 6, 'Geregistreerde Modules'),
(24446, 5375, 6, 'Registratiedatum'),
(24447, 5376, 6, 'Registratieformulier'),
(24448, 5377, 6, 'Herstel'),
(24449, 5379, 6, 'Niet geaccepteerd'),
(24450, 5380, 6, 'Kans om opnieuw op te spelen'),
(24451, 5381, 6, 'Gerelateerd aan'),
(24452, 5382, 6, 'Gerelateerd'),
(24453, 5383, 6, 'Gerelateerde Issue'),
(24454, 5384, 6, 'Pateint notities die gerelateerd zijn'),
(24455, 5385, 6, 'Relatie(s)/Kinderen'),
(24456, 5386, 6, 'Relaties'),
(24457, 5387, 6, 'Relatie'),
(24458, 5388, 6, 'Relatieve bestelling van deze entiteit'),
(24459, 5389, 6, 'Verwanten'),
(24460, 5390, 6, 'Bloeddruk van verwanten'),
(24461, 5391, 6, 'Kanker bij verwanten'),
(24462, 5392, 6, 'Diabetes bij verwanten'),
(24463, 5393, 6, 'Epilepsie bij verwanten'),
(24464, 5394, 6, 'Hart problemen bij verwanten'),
(24465, 5395, 6, 'Geestes ziekten bij verwanten'),
(24466, 5396, 6, 'CVA bij verwanten'),
(24467, 5397, 6, 'Zelfmoord bij verwanten'),
(24468, 5398, 6, 'Tuberculose bij verwanten'),
(24469, 5399, 6, 'Relay Health Credentials ontbreken voor deze gebruikersaccount.'),
(24470, 5400, 6, 'Relay Health ID'),
(24471, 5402, 6, 'Datum uitgave'),
(24472, 5403, 6, 'Religie'),
(24473, 5406, 6, 'Opnieuw inloggen'),
(24474, 5407, 6, 'Remdr'),
(24475, 5408, 6, 'Geselecteerde Faciliteit onthouden'),
(24476, 5409, 6, 'Herinnering'),
(24477, 5410, 6, 'Tijdval voor herinnering'),
(24478, 5411, 6, 'Nog geen reminder verzonden'),
(24479, 5412, 6, 'Reminder verzonden op'),
(24480, 5413, 6, 'Reminders verversen'),
(24481, 5414, 6, 'Overmaken naar'),
(24482, 5415, 6, 'Remote host'),
(24483, 5416, 6, 'Verwijderen'),
(24484, 5419, 6, 'Groep verwijderen'),
(24485, 5420, 6, 'Groepsformulier verwijderen'),
(24486, 5421, 6, 'Verwijder ondersteuning voor vaccinaties'),
(24487, 5422, 6, 'Verwijder ondersteuning voor phpMyAdmin'),
(24488, 5423, 6, 'Verwijder ondersteuning voor recepten'),
(24489, 5425, 6, 'Verwijder de ondersteuning voor Status volgen'),
(24490, 5426, 6, 'Nierstenen'),
(24491, 5427, 6, 'Naam aanpassen'),
(24492, 5428, 6, 'Groep hernoemen'),
(24493, 5429, 6, 'Weergavestijl'),
(24494, 5430, 6, 'Weergavestijl behandelaar'),
(24495, 5431, 6, 'Weergavestijl behandelaar nummer'),
(24496, 5432, 6, 'Bijbestellen'),
(24497, 5433, 6, 'Nabestelling bij'),
(24498, 5434, 6, 'Voorraad is laag, bijbestellen'),
(24499, 5435, 6, 'Niveau om bij e besellen, 0 indien niet van toepassing'),
(24500, 5436, 6, 'Rep'),
(24501, 5437, 6, 'Herhaal nieuwe paswoord'),
(24502, 5438, 6, 'Blijft zich herhalen'),
(24503, 5439, 6, 'Terugkerende Info:'),
(24504, 5440, 6, 'Herhalingen'),
(24505, 5441, 6, 'Vervangen'),
(24506, 5442, 6, 'Totale Code-set vervangen'),
(24507, 5443, 6, 'vervangen'),
(24508, 5444, 6, 'Antwoord datum'),
(24509, 5445, 6, 'Antwoord van'),
(24510, 5446, 6, 'Overzicht'),
(24511, 5447, 6, 'Rapport-Klinisch'),
(24512, 5449, 6, 'Rapportage door'),
(24513, 5451, 6, 'Verslag einde (Relinquished Care Date)'),
(24514, 5452, 6, 'Rapport is verzonden aan de patient'),
(24515, 5453, 6, 'Rapporteren Geschiedenis/Resultaten'),
(24516, 5454, 6, 'Resultaten rapporteren'),
(24517, 5455, 6, 'Rapporteren Resultaten/Geschiedenis'),
(24518, 5456, 6, 'Begin rapport (Veronderstelde Care datum)'),
(24519, 5457, 6, 'Rapport door'),
(24520, 5458, 6, 'Totalen rapport'),
(24521, 5459, 6, 'Rapport/Formulier'),
(24522, 5460, 6, 'Moet gerapporteerd worden'),
(24523, 5461, 6, 'Gerapporteerd'),
(24524, 5462, 6, 'Datum vastlegging'),
(24525, 5463, 6, 'Overzichten'),
(24526, 5465, 6, 'Omschrijvings verzoek'),
(24527, 5466, 6, 'ID van verzoek is niet beschikbaar!'),
(24528, 5467, 6, 'Verzoek genegeerd - schade afhandeling wordt al uitgevoerd!'),
(24529, 5469, 6, 'Verzoek status'),
(24530, 5470, 6, 'Verzoek type'),
(24531, 5471, 6, 'Verzoek type niet geactiveerd'),
(24532, 5472, 6, 'Verzocht door'),
(24533, 5473, 6, 'Verzoek datum'),
(24534, 5474, 6, 'Aangevraagde Service'),
(24535, 5475, 6, 'Sterk Paswoord noodzakelijk'),
(24536, 5476, 6, 'Uniek paswoord noodzakelijk'),
(24537, 5477, 6, 'Verplicht'),
(24538, 5478, 6, 'Verplichte bijbetaling'),
(24539, 5479, 6, 'Noodzakelijk Veld afwezig; kies de EDI-file voor uploaden'),
(24540, 5480, 6, 'Noodzakelijk veld afwezig; Voornaam invullen'),
(24541, 5481, 6, 'Noodzakelijk veld afwezig: Achternaam invullen'),
(24542, 5482, 6, 'Noodzakelijk veld afwezig: Usernaam invullen'),
(24543, 5483, 6, 'Verplichtte velden'),
(24544, 5484, 6, 'Vastgelegde vereiste'),
(24545, 5485, 6, 'GERESERVEERD'),
(24546, 5486, 6, 'Gereserveerd'),
(24547, 5487, 6, 'Gereserveerd voor vakantie'),
(24548, 5488, 6, 'Gereserveerd om voor behandelaar vast te leggen als er geen afspraken meer daarna gemaakt kunnen worden.'),
(24549, 5489, 6, 'Gereserveerd om vast te leggen dat gebeurtenis niet als verwacht gebeurde.'),
(24550, 5490, 6, 'Gereserveerd voor de behandelaar indien er nog afspraken erna gemaakt kunnen worden.'),
(24551, 5491, 6, 'Resetten'),
(24552, 5492, 6, 'Reset de Offsite portaal credentials'),
(24553, 5493, 6, 'Reset de onsite crednetials'),
(24554, 5495, 6, 'Resn'),
(24555, 5496, 6, 'Opgelost'),
(24556, 5497, 6, 'Ademhaling'),
(24557, 5498, 6, 'Ademhaling zonder inspanning'),
(24558, 5499, 6, 'Gerelateerd aan ademhaling'),
(24559, 5501, 6, 'Beperk niet geauthoriseerde gebrukers tot Schema Fascilities zoals vastgelegd in Gebruikers Administratie'),
(24560, 5502, 6, 'Beperk Gebruikers tot Faciliteiten'),
(24561, 5503, 6, 'Beperkte training'),
(24562, 5504, 6, 'Resultaten'),
(24563, 5505, 6, 'Naam van resultaat'),
(24564, 5506, 6, 'Resultaat van status'),
(24565, 5507, 6, 'Resultaat van status of abnormaliteit mist'),
(24566, 5508, 6, 'Resultaat, gebruik % als wildcard'),
(24567, 5509, 6, 'Resultaten'),
(24568, 5510, 6, 'Resultaat en'),
(24569, 5511, 6, 'Resultaten gevonden voor zoeken'),
(24570, 5512, 6, 'Groeps resultaat'),
(24571, 5513, 6, 'Alleen resultaten'),
(24572, 5514, 6, 'Path voor resultaten'),
(24573, 5515, 6, 'Resultaten per pagina'),
(24574, 5516, 6, 'Resutaten/details'),
(24575, 5517, 6, 'Onderzoek retina'),
(24576, 5518, 6, 'Ingetrokken rechts:'),
(24577, 5519, 6, 'Geef waarde weer'),
(24578, 5520, 6, 'Stuur bovenste gedeelte terug met uw betaling'),
(24579, 5521, 6, 'Terug naar kalender'),
(24580, 5522, 6, 'Terugkeren naar rapporteren Resultaten'),
(24581, 5523, 6, 'Nu terug naar ICD10 om installatie af te ronden en klik op ICD10 sectie kopje'),
(24582, 5524, 6, 'Nu terug naar ICD9 om installatie af te ronden en klik op ICD9 sectie kopje'),
(24583, 5525, 6, 'Nu terug naar RxNorm om installatie af te ronden en klik op RxNorm sectie kopje'),
(24584, 5526, 6, 'Nu terug naar SNOMED om installatie af te ronden en klik op SNOMED sectie kopje'),
(24585, 5527, 6, 'Resultaat'),
(24586, 5528, 6, 'Herhalingsconsult'),
(24587, 5529, 6, 'Terug om te spelen'),
(24588, 5530, 6, 'Herhaling van vorige drie paswoorden is niet toegstaan!'),
(24589, 5531, 6, 'Review'),
(24590, 5532, 6, 'Review en goedkeuren'),
(24591, 5534, 6, 'Herziening van de PMH:'),
(24592, 5535, 6, 'Alg. syst. onderzoek'),
(24593, 5536, 6, 'Overzicht med. afwijkingen'),
(24594, 5537, 6, 'Doorgenomen'),
(24595, 5538, 6, 'Revisie'),
(24596, 5539, 6, 'Rheumatoide Artritis'),
(24597, 5540, 6, 'Rheumatoide Artritis'),
(24598, 5541, 6, 'Recht'),
(24599, 5542, 6, 'Rechteroor'),
(24600, 5543, 6, 'rechteroor'),
(24601, 5544, 6, 'Rechter kantlijn (mm)'),
(24602, 5545, 6, 'Recht:'),
(24603, 5546, 6, 'Fluittoon in oren'),
(24604, 5547, 6, 'Fluittoon in oren'),
(24605, 5549, 6, 'Risicofactoren'),
(24606, 5550, 6, 'Inschatting urgentie'),
(24607, 5551, 6, 'RLL:'),
(24608, 5552, 6, 'ROM'),
(24609, 5553, 6, 'Roemeens'),
(24610, 5554, 6, 'Romanisch'),
(24611, 5560, 6, 'Rooster'),
(24612, 5561, 6, 'Route'),
(24613, 5562, 6, 'Weg van toediening, indien toepasbaar'),
(24614, 5563, 6, 'Onderweg'),
(24615, 5564, 6, 'Kolommen'),
(24616, 5565, 6, 'RRR zonder MOR'),
(24617, 5566, 6, 'Wrijven:'),
(24618, 5567, 6, 'Wrijven:'),
(24619, 5568, 6, 'Protocollen'),
(24620, 5569, 6, 'Protocollen toevoegen'),
(24621, 5570, 6, 'Detail van protocollen'),
(24622, 5572, 6, 'Bewerken van protocollen'),
(24623, 5575, 6, 'Protocollen set'),
(24624, 5576, 6, 'Regelset en Plan Set selecties zijn niet consistent. Corrigeer en opnieuw opsturen.'),
(24625, 5578, 6, 'Protocollen'),
(24626, 5580, 6, 'Configuratie voor protocollen'),
(24627, 5581, 6, 'Opdracht uitvoeren: '),
(24628, 5582, 6, 'Ruptuur'),
(24629, 5583, 6, 'Russisch'),
(24630, 5584, 6, 'Rx'),
(24631, 5585, 6, 'Rx'),
(24632, 5586, 6, 'Rx kantlijn onderkant (px)'),
(24633, 5587, 6, 'Rx DEA# tonen'),
(24634, 5588, 6, 'Rx NPI tonen'),
(24635, 5589, 6, 'Rx State licence # tonen'),
(24636, 5590, 6, 'Rx linker kantlijn (px)'),
(24637, 5591, 6, 'Rx Papier maat'),
(24638, 5592, 6, 'Rx rechter kantlijn (px)'),
(24639, 5593, 6, 'Rx DEA# tonen'),
(24640, 5594, 6, 'Rx NPI tonen'),
(24641, 5595, 6, 'Rx Sate Licence # tonen'),
(24642, 5596, 6, 'Rx boven kantlijn (px)'),
(24643, 5597, 6, 'RXCUI Medicatie'),
(24644, 5598, 6, 'RxNorm'),
(24645, 5599, 6, 'Database voor RxNorm'),
(24646, 5600, 6, 'S'),
(24647, 5601, 6, 'ID-NA'),
(24648, 5602, 6, 'S3:'),
(24649, 5603, 6, 'S4:'),
(24650, 5604, 6, 'SA * * Om de licentie te lezen, ga naar docs/license.txt of bezoek * http://www.gnu.org/copyleft/gpl.html * * / //============ ================================================== ===========// '),
(24651, 5605, 6, 'Verkoop'),
(24652, 5606, 6, 'Verkopen'),
(24653, 5607, 6, 'Verkoop per item'),
(24654, 5608, 6, 'Overzicht omzet per product'),
(24655, 5609, 6, 'Speeksel'),
(24656, 5610, 6, 'Zelfde dag'),
(24657, 5611, 6, 'Samoan'),
(24658, 5612, 6, 'Voorbeeld'),
(24659, 5613, 6, 'Type sanctie'),
(24660, 5614, 6, 'Sango'),
(24661, 5615, 6, 'Sanskrit (Samskrta)'),
(24662, 5616, 6, 'Sardinisch'),
(24663, 5617, 6, 'Zat'),
(24664, 5618, 6, 'Zat - Zon'),
(24665, 5619, 6, 'Zaterdag'),
(24666, 5620, 6, 'Bewaren'),
(24667, 5621, 6, 'BEWAAR'),
(24668, 5622, 6, 'Bewaren en sluiten'),
(24669, 5623, 6, 'Save en verwijder verzoek'),
(24670, 5624, 6, 'Bewaren en verstrekken'),
(24671, 5625, 6, 'Bewaren en versturen'),
(24672, 5626, 6, 'Bewaren als nieuw'),
(24673, 5627, 6, 'Bewaren als nieuwe notitie'),
(24674, 5628, 6, 'Bewaar Certificaat settings'),
(24675, 5629, 6, 'Bewaren'),
(24676, 5630, 6, 'Bewaar'),
(24677, 5631, 6, 'Bewaar'),
(24678, 5632, 6, 'Bewaar nieuw veld'),
(24679, 5633, 6, 'Bewaar nieuwe groep'),
(24680, 5634, 6, 'Bewaar nieuwe lijst'),
(24681, 5635, 6, 'Nieuw sjabloon bewaren'),
(24682, 5636, 6, 'Bewaar vergeten selecties'),
(24683, 5637, 6, 'Bewaar pers. gegevens'),
(24684, 5638, 6, 'Status-ID bewaard'),
(24685, 5639, 6, 'Verklaring bewaren'),
(24686, 5640, 6, 'Succesvol gesaved'),
(24687, 5641, 6, 'Gescand'),
(24688, 5642, 6, 'Gescande notitie dit bezoek'),
(24689, 5643, 6, 'Directory van Scanner'),
(24690, 5644, 6, 'In de scanner'),
(24691, 5645, 6, 'Schema'),
(24692, 5646, 6, 'Agenda voor Lokatie:'),
(24693, 5647, 6, 'Briefje voor school'),
(24694, 5648, 6, 'Scoliose'),
(24695, 5649, 6, 'Schots Gaelisch-Gaelisch'),
(24696, 5650, 6, 'Screening/testen te doen'),
(24697, 5651, 6, 'SE'),
(24698, 5652, 6, 'SE Adres'),
(24699, 5653, 6, 'SE Stad'),
(24700, 5654, 6, 'SE Land'),
(24701, 5655, 6, 'SE Localiteit'),
(24702, 5656, 6, 'SE Postcode'),
(24703, 5657, 6, 'SE Staat'),
(24704, 5658, 6, 'SE Postcode'),
(24705, 5659, 6, 'Zoeken'),
(24706, 5661, 6, 'zoeken'),
(24707, 5662, 6, 'opnieuw zoeken'),
(24708, 5663, 6, 'Alle kolomen doorzoeken'),
(24709, 5664, 6, 'Zoek op:'),
(24710, 5665, 6, 'Zoek naar'),
(24711, 5666, 6, 'Zoek naar:'),
(24712, 5667, 6, 'Zoek in'),
(24713, 5668, 6, 'Zoek in'),
(24714, 5669, 6, 'Pt zoeken of toevoegen'),
(24715, 5670, 6, 'Zoek de betaling'),
(24716, 5671, 6, 'Zoek Resultaten'),
(24717, 5672, 6, 'Resultaten zoekactie:'),
(24718, 5673, 6, 'Zoeken geselecteerde'),
(24719, 5674, 6, 'Zoek opdracht correspondeert niet met lijst in DB'),
(24720, 5675, 6, 'Zokeopdrachtmoet minstens drie karakters hebben'),
(24721, 5676, 6, 'Zoek tekst'),
(24722, 5677, 6, 'Gebeurtenissen zoeken'),
(24723, 5678, 6, 'Zoek/Toevoegen'),
(24724, 5679, 6, 'Verzekeraar zoeken/toevoegen'),
(24725, 5680, 6, 'Zoeken naar afspraken'),
(24726, 5681, 6, 'bezig met zoeken.....'),
(24727, 5682, 6, 'Gebruik veiligheidsgordel'),
(24728, 5683, 6, 'Gebruik veiligheidsgordel'),
(24729, 5684, 6, 'Tweede'),
(24730, 5687, 6, 'Secundair'),
(24731, 5688, 6, 'Tweede verzekering'),
(24732, 5689, 6, 'Tweede verzekeringsgegevens'),
(24733, 5690, 6, 'Tweede verzekeraar'),
(24734, 5691, 6, 'Secundair type Medicare'),
(24735, 5693, 6, 'Sectie ID'),
(24736, 5694, 6, 'Sectie ID en naam mag niet leeg zijn'),
(24737, 5695, 6, 'Sectie naam'),
(24738, 5696, 6, 'Sectie succesvol bewaard'),
(24739, 5698, 6, 'Veiligheid'),
(24740, 5699, 6, 'Bekijk alles'),
(24741, 5700, 6, 'Bekijk machtigingen'),
(24742, 5701, 6, 'Bekijk groeicurve'),
(24743, 5702, 6, 'Bekijk bericht over recentst aangemaakte rekeningen'),
(24744, 5704, 6, 'Vorige bezoek'),
(24745, 5705, 6, 'Naam van segment'),
(24746, 5706, 6, 'Batch Claim onderdelen'),
(24747, 5707, 6, 'Aanvallen'),
(24748, 5708, 6, 'Sel'),
(24749, 5709, 6, 'Selecteren'),
(24750, 5710, 6, 'selecteren'),
(24751, 5711, 6, 'Component seleceteren'),
(24752, 5712, 6, 'Selecteer contekst'),
(24753, 5713, 6, 'Selecteer een percentage van de ROWS of selecteer data'),
(24754, 5714, 6, 'Kies datum spreiding'),
(24755, 5715, 6, 'Selecteer User'),
(24756, 5716, 6, 'Kies allemaal'),
(24757, 5717, 6, 'Selecteer aanpassings datum'),
(24758, 5718, 6, 'Selecteer veranderingen om te printen'),
(24760, 5720, 6, 'Selecteer categorie'),
(24761, 5721, 6, 'Selecteerd de voorkeur communicatie'),
(24762, 5722, 6, 'Selecteer overeenkomstige checkboxen om te verwijderen'),
(24763, 5723, 6, 'Selecteer criteria om tre verwijderen'),
(24764, 5724, 6, 'Selecteer CSV tabel'),
(24765, 5725, 6, 'Data selecteren voor De-Identificatie'),
(24766, 5726, 6, 'Data selecteren om in te sluiten bij De-Identificatie'),
(24767, 5727, 6, 'Kies datum'),
(24768, 5728, 6, 'Selecteer gewesnte squad'),
(24769, 5729, 6, 'Selecteer Diagnose'),
(24770, 5730, 6, 'Selecteer Diagnose voor De-Identificatie verzoek'),
(24771, 5731, 6, 'Selecteer medicatie'),
(24772, 5732, 6, 'Selecteer medicaties'),
(24773, 5733, 6, 'Selecteer medicatie voor De-Identificatie verzoek'),
(24774, 5734, 6, 'Selecteer EDI-271 file'),
(24775, 5735, 6, 'Selecteer Encounter'),
(24776, 5736, 6, 'Kies veld'),
(24777, 5737, 6, 'Selecteer velden'),
(24778, 5738, 6, 'Selecteer voor afdrukken'),
(24779, 5739, 6, 'Selecteer Vaccinaties'),
(24780, 5740, 6, 'Selecteer Vaccinatie bij De-Identificatie verzoek'),
(24781, 5741, 6, 'Selecteer verzekering, door te typen'),
(24782, 5742, 6, 'Probleem selecteren'),
(24783, 5743, 6, 'Selecteer Items'),
(24784, 5744, 6, 'Selecteer taal'),
(24785, 5745, 6, 'Selecteer een'),
(24786, 5746, 6, 'Selecteer een of meerdere diagnose codes om de service verlening aan te geven'),
(24787, 5747, 6, 'Selecteer een of meerdere files om te uploaden'),
(24788, 5748, 6, 'Selecteer output'),
(24789, 5750, 6, 'Selecteer verzocht door'),
(24790, 5752, 6, 'Selecteer bron'),
(24791, 5753, 6, 'Selecteer template'),
(24792, 5754, 6, 'Selecteer de items voor exporteren'),
(24793, 5755, 6, 'Selecteer het probleem welke de oorzaak is voor het gemiste evenement van deze dag'),
(24794, 5756, 6, 'Selecteer patient adres labels vanuit de pop-ups in het linker NAV-scherm om te printen'),
(24795, 5757, 6, 'Selecteer track'),
(24796, 5759, 6, 'Selecteer User'),
(24797, 5760, 6, 'Selecteer Users van de dropdown lijst'),
(24798, 5761, 6, 'Selecteer welke talen, indien nodig, gekozen moet voor andere keuzes bij inloggen (Alleen van belang als ALLE TALEN hierboven is uitgezet)'),
(24799, 5762, 6, 'Kies JA voor groeps gewijs verwijderen'),
(24800, 5765, 6, 'Geselecteerd'),
(24801, 5766, 6, 'Gekozen encounter'),
(24802, 5767, 6, 'Indien dit gekozen wordt dan wordt bericht aangemaakt dat door iedere ontvanger persoonlijk verwerkt te worden (dus geen groeps taak)'),
(24803, 5768, 6, 'Zelf'),
(24804, 5769, 6, 'Betaald zelf'),
(24805, 5771, 6, 'Sturen'),
(24806, 5772, 6, 'Verstuur datum reminder'),
(24807, 5773, 6, 'Verstuur reminder'),
(24808, 5774, 6, 'Bezig met verzenden'),
(24809, 5775, 6, 'Bericht versturen'),
(24810, 5776, 6, 'Verstuur reminder batch'),
(24811, 5777, 6, 'Verstuur reminders aan patienten per patientmet voorkeur voor perventie/followup verzorging'),
(24812, 5778, 6, 'Verstuur samenvatting met verwijzingen'),
(24813, 5779, 6, 'Verstuur deze file'),
(24814, 5780, 6, 'Verstuur dit bericht'),
(24815, 5781, 6, 'Verstuur aan'),
(24816, 5784, 6, 'Verstuur aan iedereen'),
(24817, 5786, 6, 'Naar Portaal vesturen'),
(24818, 5787, 6, 'Naar Portaal vesturen'),
(24819, 5788, 6, 'Afzender'),
(24820, 5789, 6, 'ID van afzender'),
(24821, 5790, 6, 'ID (ISA06) afzender'),
(24822, 5791, 6, 'ID Qualifier (ISA05) afzender'),
(24823, 5792, 6, 'ID van Afzender'),
(24824, 5793, 6, 'Wordt verstuurd naar'),
(24825, 5794, 6, 'Gevoeligheden'),
(24826, 5795, 6, 'Urgentie'),
(24827, 5796, 6, 'Sensorisch onderzoek normaal'),
(24828, 5797, 6, 'Verzonden'),
(24829, 5798, 6, 'verzenden geconfirmeerd'),
(24830, 5799, 6, 'Verstuurd door, (openlaten om iedereen te kiezen)'),
(24831, 5800, 6, 'Verzonden door:'),
(24832, 5801, 6, 'Datum verstuurd'),
(24833, 5802, 6, 'Verstuur Items'),
(24834, 5803, 6, 'Verstuur medische verslagleggingen?'),
(24835, 5804, 6, 'Verzenden is gelukt'),
(24836, 5807, 6, 'Verstuur naar printer'),
(24837, 5808, 6, 'Verstuurd aanlaten voor iedereen'),
(24838, 5809, 6, 'Verzonden aan:'),
(24839, 5810, 6, 'Verzonden, maar nog niet geconfirmeerd.'),
(24840, 5811, 6, 'Verzonden, niet aangekomen'),
(24841, 5812, 6, 'Sep'),
(24842, 5813, 6, 'Uit elkaar'),
(24843, 5814, 6, 'September'),
(24844, 5815, 6, 'Seq'),
(24845, 5816, 6, 'Reeks'),
(24846, 5817, 6, 'Servisch'),
(24847, 5818, 6, 'Sev Rep'),
(24848, 5819, 6, 'Server is waarschijnlijk offline'),
(24849, 5820, 6, 'Server bericht:'),
(24850, 5821, 6, 'Service'),
(24851, 5822, 6, 'Categorie verleende Service'),
(24852, 5823, 6, 'Service code'),
(24853, 5824, 6, 'Service code financien verslaglegging'),
(24854, 5825, 6, 'Service codes'),
(24855, 5826, 6, 'Dienst datum'),
(24856, 5827, 6, 'Service datum'),
(24857, 5829, 6, 'Service locatie'),
(24858, 5830, 6, 'Service naam'),
(24859, 5831, 6, 'Dienstverlening door specialist'),
(24860, 5832, 6, 'Service overzicht'),
(24861, 5833, 6, 'Alleen Service overzicht'),
(24862, 5834, 6, 'Verleende diensten'),
(24863, 5835, 6, 'Diensten per Categorie'),
(24864, 5836, 6, 'Verleende diensten'),
(24865, 5837, 6, 'Verleende diensten'),
(24866, 5838, 6, 'Services/Producten'),
(24867, 5839, 6, 'Sessie type'),
(24868, 5840, 6, 'Set'),
(24869, 5841, 6, 'Faciliteit cookie inschakelen om de selectie ussen faciliteiten te behouden'),
(24870, 5842, 6, 'Vastleggen als afgemaakt'),
(24871, 5843, 6, 'Markeer de voorkeurs verwerking voor CDR gebaseerde rapporten.'),
(24872, 5844, 6, 'markeer de voorkeur om patient herinneringne aan te maken (in volledige kliniek modus).'),
(24873, 5845, 6, 'HIer het gehele path gebruiken. Te gebruiken bij SSL certificaten voor HTTPS'),
(24874, 5846, 6, 'Vastgezet op'),
(24875, 5847, 6, 'Terug naar Default'),
(24876, 5848, 6, 'Aanmaken van versie nummer van de Database...'),
(24877, 5849, 6, 'Instellingen'),
(24878, 5851, 6, 'Zware migraine'),
(24879, 5853, 6, 'Ernst van de pijn'),
(24880, 5854, 6, 'Ernst van de pijn:'),
(24881, 5855, 6, 'Gesl'),
(24882, 5856, 6, 'SOA'),
(24883, 5857, 6, 'SFTP'),
(24884, 5858, 6, 'Sha-1 Hash'),
(24885, 5859, 6, 'Delen met'),
(24886, 5860, 6, 'Shell commando om vanaf de Server te printen'),
(24887, 5862, 6, 'Shona'),
(24888, 5863, 6, 'Korte omschrijving'),
(24889, 5864, 6, 'Kortademig'),
(24890, 5865, 6, 'Kortademig'),
(24891, 5866, 6, 'Kortademig 2'),
(24892, 5867, 6, 'Vaccinatie bewijs'),
(24893, 5868, 6, 'Vaccinaties vanaf:'),
(24894, 5869, 6, 'Moet geactiveerd worden'),
(24895, 5870, 6, 'Moet zijn conform nnnn-nnnn-nn'),
(24896, 5871, 6, 'Moet twee letters zijn'),
(24897, 5872, 6, 'Moet tien digits hebben'),
(24898, 5873, 6, 'mag slechts tien digits hebben'),
(24899, 5874, 6, 'Schouder'),
(24900, 5875, 6, 'Schouder en Clavicula'),
(24901, 5876, 6, 'Schouderproblemen'),
(24902, 5877, 6, 'Toon'),
(24903, 5878, 6, 'Laat de actieven zien'),
(24904, 5880, 6, 'Toon alles'),
(24905, 5881, 6, 'Toon alle procedures'),
(24906, 5883, 6, 'Laat alle transacties zien'),
(24907, 5884, 6, 'Bezig'),
(24908, 5885, 6, 'Alleen geautorizeerden'),
(24909, 5886, 6, 'Laat beschikbare tijd zien'),
(24910, 5887, 6, 'Toon zowel US als Metriek (Metriek heeft voorkeur)'),
(24911, 5888, 6, 'Toon zowel US als Metriek (US heeft voorkeur)'),
(24912, 5889, 6, 'Toon details'),
(24913, 5890, 6, 'Alle fouten tonen?'),
(24914, 5891, 6, 'Laat Grafiek zien'),
(24915, 5892, 6, 'Laat gebeurtenis tekst zien bij muis over'),
(24916, 5893, 6, 'Hoeveelheid gebeurtenissen tonen op Admin Pagina?'),
(24917, 5894, 6, 'Laat de NIET-ACTIEVEN zien'),
(24918, 5896, 6, 'Laat menu zien'),
(24919, 5897, 6, 'Alleen Metrieke resultaten tonen'),
(24920, 5898, 6, 'Toon notities'),
(24921, 5900, 6, 'Toon alleen de niet overgeslagen procedures'),
(24922, 5901, 6, 'Laat notities van patient zien'),
(24923, 5902, 6, 'Toon pounds en ounces'),
(24924, 5903, 6, 'Toon pounds als decimale waarde'),
(24925, 5904, 6, 'Laat gehele Primary zien'),
(24926, 5905, 6, 'Toon reminders'),
(24927, 5906, 6, 'Rapport tonen'),
(24928, 5907, 6, 'Toon rapport'),
(24929, 5910, 6, 'Laat de gebruiker status zien om de lijsten widget toe te voegen (vraagt naar titel en afkorting)'),
(24930, 5911, 6, 'Toon deze categorie op het patient samenvattings scherm zelfs als er geen Issues zijn ingevoerd voor deze categorie.'),
(24931, 5912, 6, 'Toon track historie'),
(24932, 5913, 6, 'Toon alleen nog niet in REK gebracht'),
(24933, 5914, 6, 'Alleen US tonen'),
(24934, 5915, 6, 'Toont'),
(24935, 5916, 6, 'Toont resultaten'),
(24936, 5918, 6, 'Nakomelingen geschiedenis'),
(24937, 5920, 6, 'Broers/Zussen'),
(24938, 5921, 6, 'Sikkelcel'),
(24939, 5922, 6, 'S/'),
(24940, 5923, 6, 'Sigmoid/Coloscopie'),
(24941, 5924, 6, 'Onderteken'),
(24942, 5925, 6, 'Ondertekenen van Lab resultaten (schrijf, alleen toevoegen is optioneel)'),
(24943, 5926, 6, 'Resultaten ondertekenen'),
(24944, 5927, 6, 'Handtekening'),
(24945, 5928, 6, 'Handtekening opgeslagen'),
(24946, 5929, 6, 'Handtekening:'),
(24947, 5930, 6, 'Getekend Rx'),
(24948, 5932, 6, 'Aanzienlijke zwelling:'),
(24949, 5933, 6, 'Vereenvoudigd'),
(24950, 5934, 6, 'Extra betaling eenvoudig'),
(24951, 5935, 6, 'Minimum aan Demografische gegevens'),
(24952, 5936, 6, 'Recepten eenvoudig'),
(24953, 5937, 6, 'Sinds'),
(24954, 5938, 6, 'Met vriendelijke groeten,'),
(24955, 5939, 6, 'Sindhi'),
(24956, 5940, 6, 'Ongehuwd'),
(24957, 5941, 6, 'Enkelvoudige selectie lijst'),
(24958, 5942, 6, 'Enkelvoudige selectie lijst met de mogelijkheid om toe te voegen'),
(24959, 5943, 6, 'Enkelvoud'),
(24960, 5944, 6, 'Sinhala'),
(24961, 5945, 6, 'Sinhala, Sinhalees'),
(24962, 5946, 6, 'Sinusproblemen'),
(24963, 5947, 6, 'Chirurgie van de sinus'),
(24964, 5948, 6, 'Sinus gevoelig:'),
(24965, 5949, 6, 'Sinusitis'),
(24966, 5950, 6, 'Site'),
(24967, 5951, 6, 'Site ID'),
(24968, 5952, 6, 'Site ID voor Medische Informatie Inetegratie, LLC Lab Exchange Service.'),
(24969, 5953, 6, 'Site ID voor de LibreEHR ondersteuning v an Lab uitwisselings Service'),
(24970, 5956, 6, 'Lengte'),
(24971, 5957, 6, 'Lengte moet een getal zijn tussen 1 en 999'),
(24972, 5958, 6, 'Lengte/Lijst'),
(24973, 5959, 6, 'Huid'),
(24974, 5960, 6, 'Huidkanker'),
(24975, 5961, 6, 'Huidziekte'),
(24976, 5962, 6, 'Anders huid'),
(24977, 5963, 6, 'Authorisatie van Patient notities verslaan'),
(24978, 5964, 6, 'Sectie overslaan'),
(24979, 5965, 6, 'SQL-Ledger dump wordt overgeslagen- nog niet geimplementeerd voor Windows-server'),
(24980, 5967, 6, 'Slaappatroon'),
(24981, 5968, 6, 'Slaappatroon'),
(24982, 5969, 6, 'Slapen'),
(24983, 5970, 6, 'Slovaaks'),
(24984, 5971, 6, 'Sloveens'),
(24985, 5972, 6, 'Sm schuld w / o'),
(24986, 5973, 6, 'Smarty Cache is gewist'),
(24987, 5974, 6, 'Roker, huidig gebruik onbekend'),
(24988, 5976, 6, 'Rook gedrag'),
(24989, 5977, 6, 'SMS Aut'),
(24990, 5978, 6, 'SMS Gateway'),
(24991, 5979, 6, 'SMS Gateway API-sleutel'),
(24992, 5980, 6, 'SMS Gateway API sleutel'),
(24993, 5981, 6, 'SMS Gateway User Paswoord'),
(24994, 5982, 6, 'SMS Gateway User Naam'),
(24995, 5983, 6, 'SMS-melding'),
(24996, 5984, 6, 'SMS-meldings uren'),
(24997, 5985, 6, 'SMS sturen vóór'),
(24998, 5986, 6, 'SMS verzonden'),
(24999, 5987, 6, 'SMS Tekst, Bruikbare Tag: ***NAAM***, ***AANBIEDER***, ***DATUM ***, ***Begintijd***, *** Eindtijd***<br> b.v. Beste ***Naam***'),
(25000, 5988, 6, 'SMS/E-mail waarschuwingsinstellingen'),
(25001, 5989, 6, 'SMTP Paswoord voor Authenticatie'),
(25002, 5992, 6, 'SMTP Server Hostnaam'),
(25003, 5993, 6, 'SMTP Server Poortnummer'),
(25004, 5994, 6, 'SMTP User voor Autentificatie'),
(25005, 5995, 6, 'SNOMED'),
(25006, 5996, 6, 'SNOMED (RF1 Klinische term'),
(25007, 5997, 6, 'SNOMED (RF1) Diagnoses'),
(25008, 5998, 6, 'SNOMED (RF1) Procedure'),
(25009, 5999, 6, 'SNOMER (RF2) Diagnoses'),
(25010, 6000, 6, 'SNOMED Klinische term'),
(25011, 6001, 6, 'SNOMED Database'),
(25012, 6002, 6, 'SNOMED Diagnose'),
(25013, 6003, 6, 'SNOMED Procedure'),
(25014, 6004, 6, 'Snurken'),
(25015, 6005, 6, 'SOEP'),
(25016, 6006, 6, 'Sociale problemen'),
(25017, 6009, 6, 'Sociale voorgesch.'),
(25018, 6010, 6, 'BSN'),
(25019, 6011, 6, 'oplossing'),
(25020, 6012, 6, 'Somali'),
(25021, 6013, 6, 'Somatische contekst'),
(25022, 6014, 6, 'Sommige machtigingen werden niet getoond. Klik hier om ze allemaal te zien'),
(25023, 6015, 6, 'Sommige codes werden niet getoond.');
INSERT INTO `lang_definitions` VALUES
(25024, 6016, 6, 'Sommige bezoeken werden niet getoond. Klik hier om alles te zien.'),
(25025, 6017, 6, 'Er is een fout opgetreden tijdens De-Identificatie Process'),
(25026, 6018, 6, 'Enkele notities werden niet getoond'),
(25027, 6019, 6, 'Sommige Office notities worden niet getoond. Klik HIER om alles te tonen.'),
(25028, 6020, 6, 'enkele woorden'),
(25029, 6021, 6, 'Iemand anders heeft kort geleden dit bezoek veranderd. Deze pagina dicht maken en weer opneiuw openen'),
(25030, 6023, 6, 'Foutje, probeer het nogmaals'),
(25031, 6024, 6, 'Binnenkort verloopt interval (Kilinische reminders)'),
(25032, 6025, 6, 'Binenkort verloopt interval (Patient reminders)'),
(25033, 6026, 6, 'Zere keel'),
(25034, 6027, 6, 'Mislukt, geen afspraak vastgelegd'),
(25035, 6028, 6, 'Mislukt, probleem met oploaden van de file'),
(25036, 6029, 6, 'Sorteren op'),
(25037, 6030, 6, 'Gesorteerd op'),
(25038, 6031, 6, 'Soteer op Checksom'),
(25039, 6032, 6, 'Sorteren op commentaar'),
(25040, 6033, 6, 'Sorteer op Crt User'),
(25041, 6034, 6, 'Sorteren op datum'),
(25042, 6035, 6, 'Sorteren op datum/tijd'),
(25043, 6036, 6, 'Sorteren op gebeurtenis'),
(25044, 6037, 6, 'Sorteren op groep'),
(25045, 6038, 6, 'Sorteer op de nieuwe checksum'),
(25046, 6039, 6, 'Sorteer op de oude checksum'),
(25047, 6040, 6, 'Sorteer op Pt. ID'),
(25048, 6041, 6, 'Sorteer of Success'),
(25049, 6042, 6, 'Sorteer op "getamperde" datum/tijd'),
(25050, 6043, 6, 'Sorteren op gebruiker'),
(25051, 6044, 6, 'Sorteren op vaccinatie'),
(25052, 6045, 6, 'Neerwaards sorteren'),
(25053, 6046, 6, 'Resultaten sorteren op'),
(25054, 6047, 6, 'Opwaards sorteren'),
(25055, 6048, 6, 'Bron'),
(25056, 6049, 6, 'Bron file'),
(25057, 6050, 6, 'Bron file path'),
(25058, 6051, 6, 'Bron is niet in code opgenomen '),
(25059, 6052, 6, 'Oorsprong van voorraad'),
(25060, 6054, 6, 'Deze patient'),
(25061, 6055, 6, 'Deze patient heeft geen geboorte datum'),
(25062, 6056, 6, 'Deze patient wordt niet gevonden'),
(25063, 6057, 6, 'Bron:'),
(25064, 6058, 6, 'Zuid Nedebele'),
(25065, 6059, 6, 'Zuid Sotho'),
(25066, 6060, 6, 'Spatie'),
(25067, 6061, 6, 'SPATIE'),
(25068, 6062, 6, 'Spaans'),
(25069, 6063, 6, 'Spaans (Latin American)'),
(25070, 6064, 6, 'Spaans (Spaans)'),
(25071, 6065, 6, 'Spaans-Castiliaans'),
(25072, 6066, 6, 'Speciale karakters zijn niet toegestaan'),
(25073, 6067, 6, 'Speciale behandeling voor het Vitals formulier'),
(25074, 6068, 6, 'Specialist'),
(25075, 6069, 6, 'Naam en handtekening specialist'),
(25076, 6071, 6, 'Specialisatie'),
(25077, 6072, 6, 'Gespecificeerde systemen'),
(25078, 6073, 6, 'Specialisatie:'),
(25079, 6074, 6, 'Specifiek'),
(25080, 6075, 6, 'Specifieke Applicatie'),
(25081, 6076, 6, 'Anticonceptie Dienst verlening'),
(25082, 6077, 6, 'Specifiek resultaat'),
(25083, 6078, 6, 'Specifieke Service'),
(25084, 6079, 6, 'Toegspitst'),
(25085, 6080, 6, 'Specifiek formattering voor codes. # = digit, * = ieder char. Leeg indien ongebruikt.'),
(25086, 6081, 6, 'Geeft de manier aan van formatteren # = digit, @= alfa, *=elk karakter. Leeg is ongebruikt.'),
(25087, 6082, 6, 'Dit geeft de manier van formatteren van referentie numme aan. #- getal, * = een letter. Leeg is ongebruikt.'),
(25088, 6083, 6, 'Geeft de manier aan van Invoice referentie nummers. # = digit, A = Alfa, * = elk karakter. Leeg is ongebruikt'),
(25089, 6084, 6, 'Specificeert formattering voor product NDC veld. # = digit, * = ieder char. Leeg indien ongebruikt.'),
(25090, 6085, 6, 'Geeft formattering aan voor produc NDC velden. # = digit, @ = alfa, * = elk karakter. Leeg is ongebruikt.'),
(25091, 6086, 6, 'Dit geeft de manier aan van formatteren voor externe Client ID-nummer ID = getal, * = een letter. Leeg is ongebruikt'),
(25092, 6087, 6, 'Geeft formattering aan van externe patienten ID. # = digit. @ = alfa, * = elk karakter. Leeg is ongebruikt'),
(25093, 6088, 6, 'Specimen'),
(25094, 6089, 6, 'Nummer van Specimen/Indentifier'),
(25095, 6090, 6, 'Specimen soort'),
(25096, 6092, 6, 'Spraak invoer'),
(25097, 6093, 6, 'Spermiciden'),
(25098, 6094, 6, 'Milt verwijdering'),
(25099, 6095, 6, 'Echtgenoot'),
(25100, 6096, 6, 'Geschiedenis echtgenoot'),
(25101, 6097, 6, 'Sputum'),
(25102, 6098, 6, 'Sputum:'),
(25103, 6099, 6, 'Subcutaan'),
(25104, 6100, 6, 'sql'),
(25105, 6102, 6, 'Ploeg'),
(25106, 6103, 6, 'Ploeglidmaatschap'),
(25107, 6104, 6, 'Ploegen'),
(25108, 6105, 6, 'SRH'),
(25109, 6106, 6, 'SRH - Family Planning'),
(25110, 6107, 6, 'SRH Geen Family Planning'),
(25111, 6108, 6, 'SRH verwijzingen'),
(25112, 6109, 6, 'SRH Bezoekformulier'),
(25113, 6110, 6, 'Srv datum'),
(25114, 6111, 6, 'SS'),
(25115, 6112, 6, 'SSL certificaat Administratie'),
(25116, 6113, 6, 'BSN'),
(25117, 6114, 6, 'Stabilitiet'),
(25118, 6115, 6, 'Staps gewijze aanpassingen'),
(25119, 6116, 6, 'Standaard'),
(25120, 6117, 6, 'Standaard Code'),
(25121, 6118, 6, 'Standaard metingen'),
(25122, 6119, 6, 'Standaard Metingen (Actieve alerts)'),
(25123, 6120, 6, 'Standaard Metingen (Passieve alerts)'),
(25124, 6121, 6, 'Standaard Metingen (Patient herinneringen)'),
(25125, 6122, 6, 'Standaard naam'),
(25126, 6123, 6, 'Standaard: vereenvoudigd: alleen titel, start datum, commentaren en en Actieve check box; geen diagnoses, frequenties eind datum, verwezen door, of sport velden. ; Voetbal trauma'),
(25127, 6124, 6, 'Begin'),
(25128, 6125, 6, 'Start (jjjj-mm-dd): '),
(25129, 6126, 6, 'Een ander rapport opstarten'),
(25130, 6128, 6, 'Begindatum'),
(25131, 6129, 6, 'Begindatum bij deze kliniek'),
(25132, 6130, 6, 'Begin datum kan niet na Eind datum vallen'),
(25133, 6131, 6, 'Begindatum:'),
(25134, 6132, 6, 'Begindatum:'),
(25135, 6133, 6, 'Starttijd'),
(25136, 6134, 6, 'Begindatum'),
(25137, 6135, 6, 'nu'),
(25138, 6136, 6, 'Staat'),
(25139, 6137, 6, 'Staat specifieke Data soort'),
(25140, 6138, 6, 'Unicode'),
(25141, 6139, 6, 'Licentie nummer van Staat'),
(25142, 6140, 6, 'Lijst van Staten'),
(25143, 6141, 6, 'Provincie-/Eilandgebiedlijst (schrijven,toevoegen optioneel)'),
(25144, 6142, 6, 'Saten lijst widget om eigen velden aan te maken'),
(25145, 6143, 6, 'Staat of Provincie'),
(25146, 6144, 6, 'Staat/Localiteit'),
(25147, 6145, 6, 'Bario/Parochie'),
(25148, 6146, 6, 'Samenvatting Verklaringen'),
(25149, 6147, 6, 'verklaringen en bijwerken van facturen.'),
(25150, 6148, 6, 'Verklaring verstuurd:'),
(25151, 6149, 6, 'verklaringen; facturen worden niet bijgewerkt.'),
(25152, 6150, 6, 'Niet veranderende tekst'),
(25153, 6151, 6, 'Statistieken'),
(25154, 6152, 6, 'Statistieken'),
(25155, 6153, 6, 'Status'),
(25156, 6154, 6, 'Staus van opname'),
(25157, 6155, 6, 'Status van de claim'),
(25158, 6156, 6, 'Status quo'),
(25159, 6158, 6, 'SOA / AIDS Couns'),
(25160, 6159, 6, 'Sterkte en conditionering'),
(25161, 6163, 6, 'Stappen om CCR XML te uploaden'),
(25162, 6164, 6, 'Stappen om DSM IV database te installeren'),
(25163, 6165, 6, 'Stappen om ICD 10 database te installeren'),
(25164, 6166, 6, 'Stappen om ICD 9 database te installeren'),
(25165, 6167, 6, 'Stappen om RxNorm database te installeren'),
(25166, 6168, 6, 'Stappen om SNOMED database te installeren'),
(25167, 6169, 6, 'Stijve gewrichten'),
(25168, 6170, 6, 'Stijfheid'),
(25169, 6171, 6, 'Stock Maanden'),
(25170, 6172, 6, 'Maagpijn'),
(25171, 6173, 6, 'Stop'),
(25172, 6174, 6, 'OpgeslagenHash'),
(25173, 6175, 6, 'Verrekte spier'),
(25174, 6176, 6, 'Stroming'),
(25175, 6177, 6, 'Straat'),
(25176, 6178, 6, 'Straatnaam'),
(25177, 6179, 6, 'Straat en nummer'),
(25178, 6180, 6, 'Kracht'),
(25179, 6181, 6, 'Kracht en Conditie'),
(25180, 6182, 6, 'Strep keel onst.'),
(25181, 6183, 6, 'Stress fractuur'),
(25182, 6184, 6, 'Stress Test'),
(25183, 6185, 6, 'CVA'),
(25184, 6186, 6, 'Sterk Paswoord betekend minimaal 8 karakters en minstens drie nummers, eenkleine letter eenhoofdletter en een speciaal character.'),
(25185, 6187, 6, 'Stijl'),
(25186, 6188, 6, 'Soort stijl gebruiken om nieuwe patienten toe te voegen'),
(25187, 6189, 6, 'Subcategorie'),
(25188, 6190, 6, 'Subtotaal'),
(25189, 6191, 6, 'Subcategorie'),
(25190, 6192, 6, 'subcategorie'),
(25191, 6193, 6, 'onderhuids'),
(25192, 6194, 6, 'Subject'),
(25193, 6195, 6, 'Subjectief'),
(25194, 6196, 6, 'Onder de tong'),
(25195, 6197, 6, 'onder de tong'),
(25196, 6198, 6, 'Zoek'),
(25197, 6199, 6, 'submit'),
(25198, 6200, 6, 'Bekijk de gehele inhoud'),
(25199, 6201, 6, 'Toezenden en verzoek verwijderen'),
(25200, 6202, 6, 'Bekijk Gebeurtenis'),
(25201, 6203, 6, 'verstuur formulier'),
(25202, 6204, 6, 'Bekijk geselecteerde inhoud'),
(25203, 6205, 6, 'aangeleverd'),
(25204, 6206, 6, 'Aangeleverd door'),
(25205, 6207, 6, 'Leverancier van EDI toegangsnummer (PER06)'),
(25206, 6208, 6, 'Verzekeringnemer'),
(25207, 6209, 6, 'Adres verzekeringnemer'),
(25208, 6210, 6, 'Stad van de abonnee'),
(25209, 6211, 6, 'Geboorte dartum van de abonnee'),
(25210, 6212, 6, 'Werkgever van abonnee'),
(25211, 6213, 6, 'Werkgever abonnee'),
(25212, 6214, 6, 'Werkgever abonnee (SE)'),
(25213, 6215, 6, 'Adres van werkgever'),
(25214, 6216, 6, 'Werkgever Stad van werkgever'),
(25215, 6217, 6, 'Land van werkgever'),
(25216, 6218, 6, 'Staat van werkgever'),
(25217, 6219, 6, 'Straat van werkgever'),
(25218, 6220, 6, 'Zip code van werkgever'),
(25219, 6221, 6, 'Postcode van werkgever'),
(25220, 6222, 6, 'Voornaam van abonnee'),
(25221, 6223, 6, 'Achternaam van abonnee'),
(25222, 6224, 6, 'Midden neem van abonnee'),
(25223, 6225, 6, 'Tel.verzkr.nemer'),
(25224, 6226, 6, 'Verzekeringnemer relatie'),
(25225, 6227, 6, 'Verzekeringnemer relatie is niet Zelf maar de naam is wel hetzelfde! Is dit juist?'),
(25226, 6228, 6, 'Verzekeringnemer relatie is niet Zelf maar ID-NA nummer is wel hetzelfde!'),
(25227, 6229, 6, 'Verzekeringnemer relatie is Zelf maar de naam is niet hetzelfde! Is dit juist?'),
(25228, 6230, 6, 'Verzekeringnemer relatie is Zelf maar ID-NA nummer is niet hetzelfde!'),
(25229, 6231, 6, 'Gesl. verzekeringsnemer'),
(25230, 6232, 6, 'ID van abonnee'),
(25231, 6233, 6, 'Staat van abonnee'),
(25232, 6234, 6, 'Postcode van abonnee'),
(25233, 6235, 6, 'Telefoon van abonnee'),
(25234, 6237, 6, 'Vervanging'),
(25235, 6238, 6, 'substitutie toegestaan'),
(25236, 6240, 6, 'Succes'),
(25237, 6241, 6, 'succes'),
(25238, 6242, 6, 'Met succes afgeronde ontvangst van Lab verslag'),
(25239, 6243, 6, 'Met succes Lab resultaat ontvangen'),
(25240, 6244, 6, 'Informatie opgehaald bij Lab Exchange network was suddesvol'),
(25241, 6246, 6, 'Categorie succesvol toegevoegd'),
(25242, 6247, 6, 'Toegevoegd aan categorie gelukt'),
(25243, 6248, 6, 'Met succes verwijderd'),
(25244, 6249, 6, 'Details met succes geimporteerd. Kies goedkeuren van patient van het klaar staande goedkeurings scherm'),
(25245, 6250, 6, 'Database met succes geinstalleerd'),
(25246, 6251, 6, 'De volgende Database is met succes geinstalleerd'),
(25247, 6252, 6, 'Met succes aangepast'),
(25248, 6253, 6, 'Met succes opgeslagen. Toewijzen?'),
(25249, 6254, 6, 'Met succes opgeslagen. Wilt u het uitsturen?'),
(25250, 6256, 6, 'Opslaan gelukt'),
(25251, 6257, 6, 'Met succes database geupgrade.'),
(25252, 6258, 6, 'De volgende Database is met succes ge-upgraded'),
(25253, 6259, 6, 'Succesvol'),
(25254, 6260, 6, 'Zelfmoord'),
(25255, 6261, 6, 'Samenvatting'),
(25256, 6262, 6, 'Samenvatting van'),
(25257, 6265, 6, 'Zon'),
(25258, 6266, 6, 'Soedanees'),
(25259, 6267, 6, 'Zondag'),
(25260, 6268, 6, 'Superbill'),
(25261, 6269, 6, 'Superbill Codes'),
(25262, 6270, 6, 'Supebill Codes Administratie'),
(25263, 6271, 6, 'Superbill overzicht'),
(25264, 6272, 6, 'Superbill Tarieven lijst'),
(25265, 6273, 6, 'Superbill'),
(25266, 6274, 6, 'Superbills, ook wel Contactformulieren of Routing Slips genoemd, vormen een belangrijk deel van de medische praktijk.'),
(25267, 6275, 6, 'Supergebruiker'),
(25268, 6276, 6, 'Supervisie'),
(25269, 6278, 6, 'Supervisie dokter DEA'),
(25270, 6279, 6, 'Supervisie dokter Voornaam'),
(25271, 6280, 6, 'Supervisie dokter Achternaam'),
(25272, 6281, 6, 'Supervisie dokter NPI'),
(25273, 6282, 6, 'Supervisie dokter UPIN'),
(25274, 6283, 6, 'Naam van faciliteit van leverancier'),
(25275, 6284, 6, 'Ondersteuning van gebeurtenissen van Kalender die meerdere behandelaars betreffen'),
(25276, 6285, 6, 'Ondersteuning exp/imp van configuratie data via de Back-up pagina'),
(25277, 6286, 6, 'Ondersteuning Meedere behandelaars gebeurtenis'),
(25278, 6288, 6, 'Alleen ondersteunen van Triple DES versleuteling/ontgrendeling'),
(25279, 6289, 6, 'Surface Type'),
(25280, 6290, 6, 'Operaties'),
(25281, 6291, 6, 'Chirurgie'),
(25282, 6292, 6, 'Chirurgie Issue lijst'),
(25283, 6293, 6, 'Geschorst'),
(25284, 6294, 6, 'suspensie'),
(25285, 6295, 6, 'Svc Datum'),
(25286, 6296, 6, 'Svc Datum:'),
(25287, 6297, 6, 'Swahili'),
(25288, 6298, 6, 'Swati'),
(25289, 6299, 6, 'Zweten:'),
(25290, 6300, 6, 'Zweeds'),
(25291, 6301, 6, 'Zwelling'),
(25292, 6302, 6, 'Zwelling rechts'),
(25293, 6303, 6, 'Gezwollen gewrichten'),
(25294, 6304, 6, 'Gezwollen lymfeklieren'),
(25295, 6305, 6, 'Symbool gebruikt als een decimale punt voor valuta. Niet gebruiken als het aantal decimalen niet gebruikt worden.'),
(25296, 6306, 6, 'Symbool om duizendtallen voor Valuta aan te geven'),
(25297, 6307, 6, 'Symptomen'),
(25298, 6308, 6, 'Synchroniseren'),
(25299, 6309, 6, 'Vertalingen synchroniseren met de lokaal gebruikte vertaling'),
(25300, 6310, 6, 'Synchroniseren van nieuwe client constante'),
(25301, 6311, 6, 'Synchroniseren nieuwe taal'),
(25302, 6312, 6, 'Synchroniseren nieuwe definitie (Taal, Constant, Definitie)'),
(25303, 6313, 6, 'Syncope'),
(25304, 6314, 6, 'Surveillance observatie'),
(25305, 6315, 6, 'Surveillance observatie - Niet gerapporteerde klachten'),
(25306, 6316, 6, 'Syndroom gericht Surveillance rapport'),
(25307, 6317, 6, 'Synovitis, beknelling, bursitis'),
(25308, 6318, 6, 'Systeem'),
(25309, 6322, 6, 'T'),
(25310, 6323, 6, '3 x daags'),
(25311, 6324, 6, 'T.V.'),
(25312, 6325, 6, 'Tabel'),
(25313, 6327, 6, 'Aanmaken tabel mislukt'),
(25314, 6328, 6, 'Vernieuwen van tabel mislukt'),
(25315, 6329, 6, 'Tabellen'),
(25316, 6330, 6, 'tablet'),
(25317, 6331, 6, 'Aanvinken voor encounter'),
(25318, 6332, 6, 'Tagalog'),
(25319, 6333, 6, 'Tahitiaans'),
(25320, 6334, 6, 'Tajik'),
(25321, 6335, 6, 'Neem'),
(25322, 6336, 6, 'Kies Insurance van Dropdown menu'),
(25323, 6337, 6, 'Kies Betalings formulier, van drop down menu'),
(25324, 6338, 6, 'Terug nemen'),
(25325, 6339, 6, 'Duurt lang'),
(25326, 6340, 6, 'Groot navigatie vak'),
(25327, 6341, 6, 'Tamil'),
(25328, 6342, 6, 'Datum van tampering'),
(25329, 6343, 6, 'Doel en oorsprong DOB zijn niet gelijk'),
(25330, 6344, 6, 'Doel en bron van geboorte datum kloppen niet met elkaar'),
(25331, 6345, 6, 'Doel en bron van pid kunnen niet hetzelfde zijn!'),
(25332, 6346, 6, 'Doel en bron van SSN zijn niet gelijk'),
(25333, 6347, 6, 'Target datum'),
(25334, 6348, 6, 'Target patient'),
(25335, 6349, 6, 'Target patient heeft geen geboorte datum'),
(25336, 6350, 6, 'Target patient niet gevonden'),
(25337, 6351, 6, 'Target/Actie groepen'),
(25338, 6352, 6, 'Tartaars'),
(25339, 6354, 6, 'Tax ID'),
(25340, 6355, 6, 'Belastingtarief'),
(25341, 6356, 6, 'Belasting'),
(25342, 6357, 6, 'Taxonomie'),
(25343, 6358, 6, 'Td'),
(25344, 6359, 6, 'Overzicht van teamletsels'),
(25345, 6360, 6, 'Teamrooster'),
(25346, 6361, 6, 'Overzicht van teamrooster'),
(25347, 6362, 6, 'Team/Squad'),
(25348, 6363, 6, 'Tel'),
(25349, 6364, 6, 'Telefoon Landen Code'),
(25350, 6365, 6, 'Telugu'),
(25351, 6366, 6, 'Temp'),
(25352, 6367, 6, 'Plaats temp.'),
(25353, 6368, 6, 'Methode Temp'),
(25354, 6369, 6, 'Temperatuur'),
(25355, 6370, 6, 'Sjabloon'),
(25356, 6371, 6, 'Naam sjabloon'),
(25357, 6372, 6, 'Namen van sjablonen mogen niet starten met cijfers.'),
(25358, 6373, 6, 'Sjabloon:'),
(25359, 6374, 6, 'Sjablonen'),
(25360, 6375, 6, 'Arteria Temporalis'),
(25361, 6376, 6, 'Peesblesure'),
(25362, 6377, 6, 'Tendinitis /ositis / bursitis'),
(25363, 6378, 6, 'Tentatief Invoice ref. nummer'),
(25364, 6379, 6, 'Derde'),
(25365, 6380, 6, 'Derde verzekering'),
(25366, 6381, 6, 'Derde verzekeringsgegevens'),
(25367, 6382, 6, 'Derde verzekeraar'),
(25368, 6383, 6, 'Test Inplanning'),
(25369, 6384, 6, 'Test het systeem'),
(25370, 6385, 6, 'tekst'),
(25371, 6386, 6, 'Tekst Diagnose'),
(25372, 6387, 6, 'Tekst veld'),
(25373, 6393, 6, 'Datum van tekst'),
(25374, 6394, 6, 'Datum van tekst'),
(25375, 6395, 6, 'Invoerblok voor tekst'),
(25376, 6396, 6, 'Plaats voor tekst'),
(25377, 6397, 6, 'Tekstvak'),
(25378, 6398, 6, 'Tekstvak'),
(25379, 6399, 6, 'Tekstvak lijst'),
(25380, 6400, 6, 'tekstvak lijst'),
(25381, 6401, 6, 'Thaais'),
(25382, 6402, 6, 'Dank U'),
(25383, 6403, 6, 'Bedankt u voor het kiezen'),
(25384, 6404, 6, 'Klik op -Schonen- om alles te verwijderen.'),
(25385, 6405, 6, 'De bovenvermelde statement is mislukt'),
(25386, 6406, 6, 'De Apache SSL server certificaat en sleutel'),
(25387, 6407, 6, 'Het certificaat van Certificaat Authority'),
(25388, 6408, 6, 'Uw claimbestand: '),
(25389, 6409, 6, 'TDe vergelijkbare geplande US extensie van SNOMED pakket is al geinstalleerd.'),
(25390, 6410, 6, 'De corresponderende private sleutel'),
(25391, 6411, 6, 'De data integriteits test voor dit formulier is niet correct'),
(25392, 6413, 6, 'De afwijzings code is'),
(25393, 6414, 6, 'Groep voor onacceptabele Codes'),
(25394, 6415, 6, 'Het bestemmings formulier is gesloten'),
(25395, 6416, 6, 'Het bedoelde formulier is afgesloten; er kan geen actie volgen op uw keuze'),
(25396, 6417, 6, 'De entity die deze procedure uitvoert'),
(25397, 6418, 6, 'Het EP, voorkeurs Hospitaal, of CAH die patienten krijgt van een andere setting of verzorgings instelling of behandelaar of die vindt dat een doktersbezoek belangrijk genoeg is, behoort een reconciliatie van medicatie toe te passen.'),
(25398, 6421, 6, 'Het EP, voorkeurs Hospitaal, of CAH die een patient overplaatst naar een andere verzorgings locatie of behandelaar of die een patient verwijst naar een behandelaar moet een samenvatting aanmaken voor iedere transitie in de zorg of verwijzing.'),
(25399, 6422, 6, 'Gebeurtenis(sen) is/zijn goedgekeurd'),
(25400, 6423, 6, 'Gebeurtenis(sen) is/zijn verborgen'),
(25401, 6424, 6, 'De geexporteerde data verschijnt in het tekstveld hieronder. U kunt het kopieren en plakken in een e-mail of iets anders.'),
(25402, 6426, 6, 'De geexporteerde data verschijnt in het tekstveld hieronder. U kunt het kopieren en plakken in een e-mail of iets anders.'),
(25403, 6427, 6, 'De verstuurde data staat hierna in tekst format. Dit kan met Copy Paste in een e-mail of overal elders geplaatst worden.'),
(25404, 6428, 6, 'Deze fiel kan gesaved worden naar CouchDB'),
(25405, 6429, 6, 'De file could kan niet van naam verandert worden, deze fout komt meestal voort uit toestemmingen in opslag systeeem.'),
(25406, 6430, 6, 'Deze file is niet opgeslagen, dit komt meestal vanwege de permissies toegekend aan het systeem van oipslaan'),
(25407, 6431, 6, 'De eerste ("target") chart is degeen die het meest kompleet en accuraat is. Demografie, geschiedenis en verzekerings sectie worden hiervoor aangepast.'),
(25408, 6433, 6, 'Maak een account aan bij Unified Medical Language Systeem website'),
(25409, 6434, 6, 'De volgende agendagebeurenis is goedgekeurd'),
(25410, 6435, 6, 'De volgende agendagebeurtenis is gewijzigd'),
(25411, 6436, 6, 'De volgende categorien worden van de categorie lijst afgevoerd'),
(25412, 6437, 6, 'De hierna volgende database release is nu geinstalleerd'),
(25413, 6438, 6, 'De volgende documenten werden aan deze Direct Message toegevoegd:'),
(25414, 6439, 6, 'De navolgende EDI file is ge-upload'),
(25415, 6440, 6, 'De volgende SPOED LOGIN Gebruiker is geactiveerd|:'),
(25416, 6441, 6, 'De volgende fouten zijn opgetreden'),
(25417, 6442, 6, 'Het volgenden veld heeft een verkeerde waarde'),
(25418, 6444, 6, 'De volgende velden zijn verplicht'),
(25419, 6446, 6, 'De volgende velden moeten ingevuld zijn om verzoek te versturen.'),
(25420, 6447, 6, 'De volgende Internationale SnoMed release vertalingen worden ondersteund'),
(25421, 6448, 6, 'De volgende problemen hebben dezelfde diagnose codes. Encounter issues worden niet geupdated. Gebruik van encounter interface dijnet hiervoor.'),
(25422, 6449, 6, 'De host naam van de ATNA audit repositorie machine'),
(25423, 6450, 6, 'Het oorspronkelijke venster is het factuur zoekpagina. Aan de bovenzijde kunt u een bron (bijvoorbeeld controlenummer), betaaldatum en controlebedrag invoeren. De reden voor de bron en betaaldatum is, dat u ze niet steeds hoeft in te voeren voor elke vordering. Het bedrag dat u invoert zal worden verlaagd voor elke factuur die wordt gegeven met een deel van de betaling, en hopelijk zal eindigen op nul als u klaar bent met betalen.'),
(25424, 6451, 6, 'De directory waar geinstalleerd wordt moet aangemaakt worden.'),
(25425, 6452, 6, 'De geinstallerde Internationale SNOMED versie is niet compatibel met het geplande US Extensie SNOMED pakket.'),
(25426, 6453, 6, 'De geinstallerde Internationale SNOMED versie is niet up to date en niet compatibel met deze geplande US Extensie van SNOMED File.'),
(25427, 6454, 6, 'De geinstalleerde versie en de partiele files zijn hetzelfde'),
(25428, 6455, 6, 'De geinstalleerde versie is van een recentere datum dan de geplande aanpassing.'),
(25429, 6456, 6, 'Het label dat aan de gebruiker wordt getoond op het Formulier'),
(25430, 6457, 6, 'De lengte mag niet meer zijn dan het volgende aantal caracters'),
(25431, 6458, 6, 'De merge wordt niet gestart tenzij SSN en geboorte datum van de twee kaarten gelijk zijn. Geboortedatum kan niet leeg zijn.'),
(25432, 6459, 6, 'Dit bericht kon nu niet verzonden worden.'),
(25433, 6460, 6, 'De nieuwe categorie wordt een sub-categorie van '),
(25434, 6461, 6, 'Het nieuwe paswoord kan niet gelijk zijn aan het vorige paswoord'),
(25435, 6462, 6, 'De nieuwe paswoord invoer velden zijn niet gelijk.'),
(25436, 6463, 6, 'Het aantal van de geplande files is niet correct. Gebruik alleen de file die gewenst is om geinstalleerd/ge-upgraded te worden.'),
(25437, 6464, 6, 'Het nummer van de geplande files in niet juist. Maak alleen gebruik van de files die u wilt installeren/upgraden.'),
(25438, 6465, 6, 'Deze pagina brengt u terug naar Demographics. U kunt het Land-veld aan passen en weer doorklikken naar NewCrop'),
(25439, 6466, 6, 'Het wachtwoord moet minimaal acht tekens lang zijn en dient'),
(25440, 6467, 6, 'Het gebruikte paswoord is niet geldig'),
(25441, 6468, 6, 'Vezoek om patienten status is vastgelegd'),
(25442, 6469, 6, 'Patienten reminders zijn verzonden'),
(25443, 6470, 6, 'De patient reminders zijn ge-updated'),
(25444, 6471, 6, 'De patient was niet ingelogd toen dit formulier werd gestuurd'),
(25445, 6472, 6, 'De opgemaakte betalingen kunnen niet toegevoegd worden onder deze datum. Dit geeft garantie dat na het opmaken van eind rapportage niemand nog kan toevoegen voor de voorafgaande data.'),
(25446, 6473, 6, 'Het Portaal heeft data en formilier voor deze patient. Nu laden?'),
(25447, 6474, 6, 'De ruwe datafiles kunne opgehaald worden bij'),
(25448, 6475, 6, 'De overige informatie hieronder is alleen van toepassing als u handmatig invoert, of als u handmatige correcties toepast.'),
(25449, 6476, 6, 'Het gevraagde document is net aanwezig op de aangegeven locatie van het file systeem of er zijn onvoldoende permissies om het in te zien'),
(25450, 6477, 6, 'Dit gevraagde document is niet aanwezig op de verwachte locatie van het bestandssysteem of u heeft te weinig rechten voor dit document.'),
(25451, 6479, 6, 'De tweede "bron" kaart zal van de demographics, geschiedenis en verzekerings sectie ontdaan worden. De andere data worden gemerged in de bron kaart.'),
(25452, 6480, 6, 'De Bron en Datum kolommen zijn gekopieerd van de eerste pagina, dus normaliter hoeft u dit niet aan te passen. U kunt een bedrag in de kolom Betalen invoeren, een aanpassingsbedrag in de kolom Aanpassen invoeren of beide. U kunt ook klikken op "W" aan de rechterkant om automatisch een correctie te berekenen, die het restant van de kosten afschrijft.'),
(25453, 6481, 6, 'De geplande files-data zijn niet allemaal van dezelfde versie'),
(25454, 6482, 6, 'De geplande file revisie zijn niet allemaal van dezelfde release.'),
(25455, 6483, 6, 'De geplande US Extensie SNOMED pakket kan niet geinstalleerd worden tenzij de Internationale SNOMED Pakket geinstalleerd is.'),
(25456, 6484, 6, 'De tijdsintervallen van de kalender en het kleinste tijdsinterval voor een afspraak positie'),
(25457, 6485, 6, 'Het vertaalde label dat wordt weergegeven op het formulier in de actieve taal'),
(25458, 6486, 6, 'De vertaalde titel die zal verschijnen in de actieve taal'),
(25459, 6487, 6, 'De vertaling van de beschrijving in de actieve taal'),
(25460, 6488, 6, 'De vertaal tabellen zijn gesynchroniseerd'),
(25461, 6489, 6, 'Het type van deze entiteit'),
(25462, 6490, 6, 'De verkoper-specifieke code die deze procedure of het resultaat indentificeerd'),
(25463, 6491, 6, 'De X12-bestanden evenals de resulterende HTML output rapporten worden gearchiveerd in de "ERA" submap van de hoofd LibreEHR installatie directory. U wilt soms verwijzen naar deze archieven. De URL is'),
(25464, 6492, 6, 'Het zip-bestand zal de volgende items bevatten'),
(25465, 6493, 6, 'Thema'),
(25466, 6494, 6, 'Dan kan de geplande data feed release verkegen worden bij'),
(25467, 6495, 6, 'Therapeutische injecties'),
(25468, 6496, 6, 'Er zijn'),
(25469, 6497, 6, 'Er zijn momenteel geen recepten'),
(25470, 6498, 6, 'Er zijn fouten met uw toezending. Deze worden hieronder beschreven.'),
(25471, 6499, 6, 'er zijn diverse patienten bij de login Portaal.'),
(25472, 6500, 6, 'Er zijn geen Statussen uitgechecked'),
(25473, 6501, 6, 'Er zijn geen vermeldingen voor deze patient'),
(25474, 6502, 6, 'Er is niets nieuws toegevoegd'),
(25475, 6503, 6, 'Er zijn geen notities voor deze patient'),
(25476, 6504, 6, 'Er zijn geen transacties opgeslagen voor deze patient'),
(25477, 6505, 6, 'Foutje bij versturen van e-mail naar'),
(25478, 6506, 6, 'Er is al een categorie met de naam'),
(25479, 6507, 6, 'Er is al een subcategorie met de naam'),
(25480, 6508, 6, 'Er is al een item genaamd'),
(25481, 6509, 6, 'Er is al een verzoek gedaan om patient record te openen'),
(25482, 6510, 6, 'Er is geen COA ingevoerd voor AR rekening '),
(25483, 6511, 6, 'Er is geen COA ingevoerd voor Cash rekeninr '),
(25484, 6512, 6, 'Er is geen COA ingevoerd voor inkomsten rekening '),
(25485, 6513, 6, 'Er is geen huidige patient'),
(25486, 6514, 6, 'Er is geen lokale inhoud voor dit onderwerp.'),
(25487, 6515, 6, 'Er is geen match voor de invoice id'),
(25488, 6516, 6, 'Er is geen match voor de invoice id = '),
(25489, 6517, 6, 'Er is geen onderdelen invoer mogelijk voor diensten ID '),
(25490, 6518, 6, 'Er is geen patient met Portaal login'),
(25491, 6519, 6, 'Er was een probleem bij het verzenden van de boodschap.'),
(25492, 6520, 6, 'Er is een fout opgetreden bij het verwerken van uw verzoek.'),
(25493, 6521, 6, 'Er was een LibreEHR SQL escape fout in de volgende string'),
(25494, 6522, 6, 'Dit zijn de 2012 links'),
(25495, 6523, 6, 'Verdikt rechts'),
(25496, 6524, 6, 'Dijbeen'),
(25497, 6525, 6, 'Dij en hamstrings'),
(25498, 6526, 6, 'Dingen die alleen door back-office ingezien kunen worden'),
(25499, 6527, 6, 'Dingen die backoffice kunnen lezen maar niet aanpassen'),
(25500, 6528, 6, 'Dingen die door boekhouding etc. gelezen en aangepast mogen worden'),
(25501, 6529, 6, 'Dingen die back-office kan lezen en gedeeltelijk kan aanpassen'),
(25502, 6530, 6, 'Dingen die alleen kliniekmedewerkers kunnen inzien'),
(25503, 6531, 6, 'Dingen die kliniekmedewerkers kunnen lezen en invoeren maar niet aanpassen'),
(25504, 6532, 6, 'Dingen die kliniekmedewerkers kunnen lezen en aanpassen'),
(25505, 6533, 6, 'Dingen die kliniekmedewerkers kunnen inzien en gedeeltelijk kunnen aanpassen'),
(25506, 6534, 6, 'Dingen die Fornt Office kunnen inzien'),
(25507, 6535, 6, 'Dingen die de balie kan lezen maar niet aanpassen'),
(25508, 6536, 6, 'Dingen die de balie kan lezen en aanpassen'),
(25509, 6537, 6, 'Dingen die Foront office kunne inzien en gedeeltelijk unnen aanpassen'),
(25510, 6538, 6, 'Dingen die doktoren kunnen inzien'),
(25511, 6539, 6, 'Dingen die doktoren kunnen lezen en invoeren maar niet aanpassen'),
(25512, 6540, 6, 'Dingen die doktoren kunnen lezen en aanpassen'),
(25513, 6541, 6, 'Dingen die doktoren kunnen inzien en gedeeltelijk aanpassen'),
(25514, 6542, 6, 'Derde'),
(25515, 6544, 6, 'Deze actie kan NIET ongedaan worden gemaakt.'),
(25516, 6545, 6, 'Deze actie kan niet ongedaan worden gamaakt.'),
(25517, 6547, 6, 'Deze actie wordt vastgelged'),
(25518, 6549, 6, 'Deze afspraak slot is al toegekend, toch bijvoegen?'),
(25519, 6550, 6, 'Deze afspraak slot is niet beschikbaar, kies een andere optie'),
(25520, 6551, 6, 'DIt kalender jaar'),
(25521, 6552, 6, 'Deze claim is afgewezen'),
(25522, 6553, 6, 'Deze claim is afgesloten'),
(25523, 6554, 6, 'Deze claim is geweigerd. Reden:'),
(25524, 6555, 6, 'Deze claim is doorgestuurd naar het volgende niveau.'),
(25525, 6556, 6, 'Dit type code gaat niet samen met relaties.'),
(25526, 6557, 6, 'Deze contekst bevat categorien die verwijderd gaan worden. Wilt u doorgaan?'),
(25527, 6558, 6, 'Keuzemogelijkheid voor tonen van afspraken in kalender'),
(25528, 6559, 6, 'Hier legt u vast welk kleurschema gebruikt wordt voor afspraken'),
(25529, 6561, 6, 'Dit bezoek'),
(25530, 6562, 6, 'Voor deze encounter is al een rekening gestuurd. Als het verandert moet worden, moet het heropend worden.'),
(25531, 6563, 6, 'Deze necounter is gelocked. Geen nieuwe documenten kunnen toegevoegd worden.'),
(25532, 6564, 6, 'Deze optie is nog niet beschikbaar'),
(25533, 6565, 6, 'Deze functie is zeer experimenteel en niet volledig getest. Eigen risico!'),
(25534, 6566, 6, 'Invoice nummer verandert in '),
(25535, 6569, 6, 'Deze kaart wordt gemerged naar de hoofd kaart toeen wordt dan verwijdert.'),
(25536, 6571, 6, 'Deze kaart is de hoofd kaart en krijgt de data van de andere kaart'),
(25537, 6572, 6, 'deze locatie'),
(25538, 6573, 6, 'Deze tekst boodschap wordt niet automatisch bewaard. Copieer en bewaar indien gewenst afhenkelijk van de inhoud.'),
(25539, 6574, 6, 'Deze module wordt gebruikt door '),
(25540, 6575, 6, 'Deze module is in test-modus. De database zal niet worden gewijzigd.'),
(25541, 6576, 6, 'Deze module bevordert efficiënte toegang van EOB gegevens.'),
(25542, 6577, 6, 'Deze maand tot heden'),
(25543, 6578, 6, 'De order werd reeds verzonden op'),
(25544, 6579, 6, 'Deze pagina laat u alle ondersteunde externe uploads bekijken, die kunnen worden geimporteerd en aangepast. Iedere volgende sectie kan worden uitgeklapt door op de sectie tab te klikken om de opties van die database te bekijken.'),
(25545, 6580, 6, 'De pagina is gedectiveerd ivm veiligheids redenen.'),
(25546, 6581, 6, 'Deze pagina zal de login pagina inline toevoegen, zodat we niet ieder keer opnieuw hoeven in te loggen.'),
(25547, 6582, 6, 'Deze patiënt is inacief.'),
(25548, 6583, 6, 'Deze patiënt-ID is al in gebruik!'),
(25549, 6584, 6, 'Dit product mag maar een voorraad per warenhuis hebben'),
(25550, 6585, 6, 'Dit protocol is nog niet geimplementeerd'),
(25551, 6586, 6, 'Dit rapport werkt alleen bij ICD9 codes.'),
(25552, 6589, 6, 'Dit is de specificatie voor Box 31 toevoegen of niet.'),
(25553, 6590, 6, 'DIt geeft de specificatie aan of het in rekening brengen formulier aangemaakt moet worden.'),
(25554, 6591, 6, 'Deze stap laat u een file aanmaken die u voor toekomstig gebruik moet bewaren. Deze file kan niet opnieuw aangemaakt worden. Doorgaaan?'),
(25555, 6592, 6, 'Deze gebruiker is geen lid van een groep'),
(25556, 6593, 6, 'Deze gebruiker krijgt bericht van de nieuw ingekomen Direct-berichten'),
(25557, 6594, 6, 'Deze Utility is experimenteel. Maak eerst een Back/up van de database en documenten voor deze te gebruiken!'),
(25558, 6595, 6, 'Het bezoek begint met nieuw contraceptie gebruik'),
(25559, 6596, 6, 'Dit bezoek moet een GCAC formulier hebben of een procedure dienstverlening'),
(25560, 6597, 6, 'Dit was het oude niet meer ondersteunde metrieke Vitals formulier.'),
(25561, 6598, 6, 'Deze week tot heden'),
(25562, 6600, 6, 'Dit activeert de CCR(Continuiteit van zorg rapport) en CCD (Continueiteit van zorg document) rapportage.'),
(25563, 6602, 6, 'Dit laat toe om de debug(''dummy'') taal te selecteren.'),
(25564, 6605, 6, 'Dit is een "test opstelling" waarbij geen fysieke update plaats vindt.'),
(25565, 6606, 6, 'Dit zal een backup aanmaken in tar-format, die daarna naar uw webbrowser wordt gezonden zodat u het kunt bewaren'),
(25566, 6607, 6, 'Dit zorgt voor document versleuteling en ontcijferings mogelijkheden en niet tonen in de user interface.'),
(25567, 6608, 6, 'Dit maakt alle knoppen Edit onbruikbaar zodra het parent formulier afgesloten is met e-Sing.'),
(25568, 6609, 6, 'Dit maakt de Edit knop onbruikbaar voor elk formulier dat is ge- e-signed'),
(25569, 6611, 6, 'Dit maakt ondertekenen van een hele Encounter mogelijk, ipv een enkel formulier'),
(25570, 6612, 6, 'Hiermee kunt u ieder formulier apart ondertekenen'),
(25571, 6613, 6, 'Dit dwingt de Rekeningen widget in het patienten samenvattings scherm altijd open te blijven.'),
(25572, 6614, 6, 'Hiermee krijgt de User de mogelijkheid om af te sluiten(aparte sluiting en ondertekening)'),
(25573, 6615, 6, 'Dit verstopt de lege -sing logs voor het patient rapport'),
(25574, 6616, 6, 'Dit is om twee patient kaarten te mergen naar een kaart. Het is te gebruiken wanneer een patient per vvergissing twee karten heeft laten aanmaken. Als dat vaak gebeurd, zorg ervoor dat er een betere procedure wordt gescheven. Doe dit niet routine matig!'),
(25575, 6617, 6, 'Dit zal niet voorkomen dat u toch naar de e-voorschrijf pagina gaat.'),
(25576, 6619, 6, 'Hiermee wordt de immunisatie lijst aangepast in plaats van de CVX immunisatie lijst.'),
(25577, 6622, 6, 'Thoracale wervelkolom'),
(25578, 6623, 6, 'Thous/CU.MM'),
(25579, 6625, 6, 'Keel'),
(25580, 6626, 6, 'Keelkanker'),
(25581, 6627, 6, 'Keelkanker chirurgie'),
(25582, 6628, 6, 'Trombose/CVA'),
(25583, 6629, 6, 'Don'),
(25584, 6630, 6, 'Donderdag'),
(25585, 6631, 6, 'Donderdag'),
(25586, 6632, 6, 'Schildklier normaal'),
(25587, 6633, 6, 'Schildklierproblemen'),
(25588, 6634, 6, 'TIA'),
(25589, 6635, 6, 'Tibetaans standaard, Tibetaans, cantraal'),
(25590, 6636, 6, 'TID'),
(25591, 6637, 6, 'Tigrinya'),
(25592, 6638, 6, 'Tijd'),
(25593, 6639, 6, 'Format om tijd te tonen'),
(25594, 6640, 6, 'Tijdstoename voor Toevoegen (minuten 1-60)'),
(25595, 6641, 6, 'Tijdselectie'),
(25596, 6642, 6, 'Dit tijdslot is open, gebeurtenis wordt opgeslagen'),
(25597, 6643, 6, 'Tijd resterend voor tonen van Allergie SOAP verzoek in seconden'),
(25598, 6644, 6, 'Tijd resterend voor tonen van Medicatie in SOAP verzoek in zeconden'),
(25599, 6647, 6, 'Tijdgebonden gebeurtenis'),
(25600, 6648, 6, 'Keer array (N / A)'),
(25601, 6649, 6, 'Tijdstip en tekst'),
(25602, 6650, 6, 'TIN'),
(25603, 6651, 6, 'Tinnitus'),
(25604, 6652, 6, 'Titel'),
(25605, 6653, 6, 'Titel V'),
(25606, 6654, 6, 'Titels van kolommen moeten nummer hebben tussen 1 en 999'),
(25607, 6655, 6, 'Titels'),
(25608, 6656, 6, 'TM''S:'),
(25609, 6657, 6, 'TMs / EAM''s / EE, ext neus'),
(25610, 6658, 6, 'Tot'),
(25611, 6659, 6, 'NAAR'),
(25612, 6660, 6, 'tot/tav'),
(25613, 6661, 6, 'naar absolute pad van bestand'),
(25614, 6662, 6, 'Om notities toe te voegen klik '),
(25615, 6663, 6, 'Om notities toe te voegen klik hier'),
(25616, 6664, 6, 'Op aangedane gebied'),
(25617, 6665, 6, 'op aangedane gebied'),
(25618, 6666, 6, 'Automatisch het gekozen formulier openen. Sommige sport teams gebruiken hiervoor football_injury_audit.'),
(25619, 6667, 6, 'Naar rekening overzicht'),
(25620, 6668, 6, 'naar categorie'),
(25621, 6669, 6, 'Naar klinisch overzicht'),
(25622, 6670, 6, 'Naar COPAY'),
(25623, 6671, 6, 'De totaan datum moet later vallen dan de vanaf datum'),
(25624, 6672, 6, 'Naar korting'),
(25625, 6673, 6, 'Naar Dems'),
(25626, 6674, 6, 'Stop de Client kant SSL certificaat door de voorgaande regels in Apache Configuratie File van comment te voorzien'),
(25627, 6675, 6, 'Stop HTTPS door de voorgaande regels van comment te voorzien in de Apache Configuratie file'),
(25628, 6676, 6, 'Toestaan van Client side SSL certificaten'),
(25629, 6677, 6, 'Toestaan van Client side SSL certificaat authenticatie kan alleen door HTTPS activatie'),
(25630, 6678, 6, 'Om alleen HTTPS toe te staan, zorg dat eerder vermelde veranderingen zijn aangebracht en herstart Apache server. Als u ook client siede certificaten wil activeren, doe dit in de volgende sectie'),
(25631, 6679, 6, 'Naar consultatie'),
(25632, 6680, 6, 'Scheiding adhv geslacht'),
(25633, 6681, 6, 'Naar Historie'),
(25634, 6682, 6, 'Naar problemen'),
(25635, 6683, 6, 'Om dit contact aan een reeds bestaand probleem/consult te koppelen, klikt u op het '),
(25636, 6684, 6, 'Om dit contact aan een reeds bestaand probleem/consult te koppelen, klikt u op het gewenste probleem hierboven en daarna op [Bewaren]. Houd de [Ctrl] toets ingedrukt als u meerdere problemen tegelijkertijd wilt selecteren.'),
(25637, 6685, 6, 'opnieuw naar inloggen'),
(25638, 6686, 6, 'Om vermeldingen vast te leggen, klikken'),
(25639, 6687, 6, 'lopen'),
(25640, 6688, 6, 'Om https toegang van client certificatie authenticatie te geven doe het volgende'),
(25641, 6689, 6, 'Op de huid'),
(25642, 6690, 6, 'op de huid'),
(25643, 6691, 6, 'naar deze visite?'),
(25644, 6692, 6, 'Om reeds bestaand CCR document te uploaden van een patiënt gebruik: Patient Summary Screen-> Documenten. Voor CCR-document van een nieuwe patiënt maak gebruik van: Miscellanous-> New Documents scherm'),
(25645, 6693, 6, 'Aan:'),
(25646, 6694, 6, 'Aan: '),
(25647, 6695, 6, 'NAAR_STAD'),
(25648, 6696, 6, 'NAAR_FAX'),
(25649, 6697, 6, 'NAAR_VNAAM'),
(25650, 6698, 6, 'NAAR_ANAAM'),
(25651, 6699, 6, 'NAAR_MNAAM'),
(25652, 6700, 6, 'NAAR_ORGANISATIE'),
(25653, 6701, 6, 'NAAR_TELEFOON'),
(25654, 6702, 6, 'NAAR_MOBIELETELEFOON'),
(25655, 6703, 6, 'NAAR_POSTKANTOOR'),
(25656, 6704, 6, 'NAAR _STAAT'),
(25657, 6705, 6, 'NAAR_STRAAT'),
(25658, 6706, 6, 'NAAR_TITEL'),
(25659, 6707, 6, 'NAAR_EXTRA-TITELS'),
(25660, 6708, 6, 'Tabak'),
(25661, 6709, 6, 'Interventie tabaksgebruik stoppen'),
(25662, 6710, 6, 'Interventie tabaksgebruik stoppen (CQM)'),
(25663, 6711, 6, 'Tabaks gebruik'),
(25664, 6712, 6, 'Tabaksgebruik'),
(25665, 6713, 6, 'Evaluatie tabaksgebruik'),
(25666, 6714, 6, 'Evaluatie tabaksgebruik (CQM)'),
(25667, 6715, 6, 'Vandaag'),
(25668, 6716, 6, 'Vandaag'),
(25669, 6717, 6, 'vandaag'),
(25670, 6718, 6, 'Balans van vandaag'),
(25671, 6719, 6, 'Kosten van vandaag'),
(25672, 6720, 6, 'Datum van vandaag'),
(25673, 6721, 6, 'Gebeurtenis(sen) vandaag'),
(25674, 6722, 6, 'Allemaal omzetten'),
(25675, 6723, 6, 'Token ID voor de Medical Information Integration, LLC Lab Exchange Service.'),
(25676, 6724, 6, 'Token ID voor de LibreEHR ondersteuning voor LLC Lab Exchange Service'),
(25677, 6725, 6, 'Tonga (TOnga Eilenden)'),
(25678, 6726, 6, 'Tonsilectomie'),
(25679, 6727, 6, 'tonsilectomie'),
(25680, 6728, 6, 'Boven'),
(25681, 6729, 6, 'Bovenste kantlijk (mm)'),
(25682, 6730, 6, 'Onderdeel'),
(25683, 6731, 6, 'Totaal'),
(25684, 6732, 6, 'totaal'),
(25685, 6733, 6, 'Totaal actieve acties'),
(25686, 6734, 6, 'Toaal actieve reminders na update'),
(25687, 6735, 6, 'Totaal actieve reminders voor update'),
(25688, 6737, 6, 'Totaal verschuldigde bedrag'),
(25689, 6738, 6, 'Totaalbedrag betaald'),
(25690, 6739, 6, 'Totaalbedrag schuldig'),
(25691, 6740, 6, 'Totaal bedrag'),
(25692, 6741, 6, 'Totale extra betalingen'),
(25693, 6742, 6, 'Totaal aantal clienten'),
(25694, 6743, 6, 'Totale kosten'),
(25695, 6744, 6, 'De totale toewijzing voor het volgende check nummer is niet vol'),
(25696, 6745, 6, 'totaal aantal entries'),
(25697, 6746, 6, 'Totaal aantal mislukte reminders verzonden via e-mail'),
(25698, 6747, 6, 'Totaal aantal mislukte reminders verzonden via telefoon'),
(25699, 6748, 6, 'Totaal voor'),
(25700, 6749, 6, 'Totaal voor '),
(25701, 6750, 6, 'Totaal voor categorie'),
(25702, 6751, 6, 'Totaal geinactiveerde reminders'),
(25703, 6752, 6, 'Totaal nieuwe reminders'),
(25704, 6753, 6, 'Totaal aantal afspraken'),
(25705, 6755, 6, 'Totaal aantal immunisaties'),
(25706, 6756, 6, 'Totaal aantal Issues'),
(25707, 6758, 6, 'Totaal aantal patienten'),
(25708, 6760, 6, 'Totaal clinet balans'),
(25709, 6761, 6, 'Totaal aantal patienten'),
(25710, 6764, 6, 'Totaal aantal records gevonden'),
(25711, 6765, 6, 'Totaal SRH & Family planning'),
(25712, 6766, 6, 'Totaal aantal succesvol verstuurde reminders per e-mail'),
(25713, 6767, 6, 'Totaal aantal succesvol verstuurde reminders per telefoon'),
(25714, 6770, 6, 'Totaal niet veranderde reminders'),
(25715, 6771, 6, 'Totaal niet verzonden reminders na versturen'),
(25716, 6772, 6, 'Totaal niet verzonden reminders na update'),
(25717, 6773, 6, 'Totaal niet verzonden reminders voor versturen'),
(25718, 6774, 6, 'Totaal niet verzonden voor update'),
(25719, 6775, 6, 'Totaal aangepaste reminders'),
(25720, 6776, 6, 'Totalen'),
(25721, 6777, 6, 'Totalen voor'),
(25722, 6778, 6, 'Totalen voor '),
(25723, 6780, 6, 'tot{{range}}'),
(25724, 6782, 6, 'Vervolgen'),
(25725, 6783, 6, 'Vervolg rapport'),
(25726, 6784, 6, 'Wat te vervolden'),
(25727, 6785, 6, 'Soort training'),
(25728, 6786, 6, 'Transactie'),
(25729, 6787, 6, 'Verklaring/verwijzing'),
(25730, 6788, 6, 'verklaring'),
(25731, 6789, 6, 'Transactie mislukt, onvoldoende hoeveelheid voor bestemmings voorraad'),
(25732, 6790, 6, 'Transactie mislukt, hoeveelheid is kleiner dan nul'),
(25733, 6791, 6, 'Soort verklaring'),
(25734, 6792, 6, 'Transacties'),
(25735, 6793, 6, 'Transacties'),
(25736, 6794, 6, 'Transacties (schrijven optioneel)'),
(25737, 6795, 6, 'Transactie/Verwijzingen'),
(25738, 6797, 6, 'Overplaatsing'),
(25739, 6798, 6, 'Datum van overplaatsing'),
(25740, 6799, 6, 'Overplaatsing mislukt, onvoldoende hoeveelheid in begin voorraad'),
(25741, 6800, 6, 'Overplaatsings samenvatting'),
(25742, 6801, 6, 'Verwijzen naar'),
(25743, 6804, 6, 'Overplaatsingen'),
(25744, 6806, 6, 'Overdracht van zorg?'),
(25745, 6807, 6, 'Vertaal Access Controle groepen'),
(25746, 6808, 6, 'Vertaal Afpraak Categorieen'),
(25747, 6809, 6, 'Vertaal Document Categorieen'),
(25748, 6810, 6, 'Vertaal Layouts'),
(25749, 6811, 6, 'Vertaal Lijsten'),
(25750, 6812, 6, 'Vertaal patient notitites'),
(25751, 6813, 6, 'vertaal dit'),
(25752, 6814, 6, 'Vertaling'),
(25753, 6815, 6, 'Vertalingen'),
(25754, 6816, 6, 'Verzenden'),
(25755, 6817, 6, 'Verzenden mislukt'),
(25756, 6818, 6, 'Verzend geselecteerde orders'),
(25757, 6819, 6, 'Ongeval'),
(25758, 6820, 6, 'Behandeling'),
(25759, 6822, 6, 'Behandelingsdoelen'),
(25760, 6823, 6, 'Behandelingsplan'),
(25761, 6824, 6, 'Planning voor behandeling'),
(25762, 6825, 6, 'Behandeling gegeven'),
(25763, 6826, 6, 'Behandeling:'),
(25764, 6827, 6, 'Behandeling: '),
(25765, 6828, 6, 'Tendens'),
(25766, 6829, 6, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) ); $month_value'),
(25767, 6830, 6, 'Trigger punt / Compartement Syndroom / DOMS /Cramp'),
(25768, 6831, 6, 'Trimalleolair'),
(25769, 6832, 6, 'Romp en Abdomen'),
(25770, 6833, 6, 'Vertrouwd direct e-mail adres'),
(25771, 6834, 6, 'Vertrouwde e-mail'),
(25772, 6835, 6, 'U probeert een gebruiker met een reeeds bestaande naam te maken!'),
(25773, 6836, 6, 'Tsonga'),
(25774, 6837, 6, 'theelepel'),
(25775, 6838, 6, 'Tswana'),
(25776, 6839, 6, 'TTS'),
(25777, 6840, 6, 'Tuberculose'),
(25778, 6841, 6, 'Din'),
(25779, 6842, 6, 'Dinsd-Dond'),
(25780, 6843, 6, 'Dinsdag'),
(25781, 6844, 6, 'Tumor'),
(25782, 6845, 6, 'Turks'),
(25783, 6846, 6, 'Turkmeens'),
(25784, 6847, 6, 'Twi'),
(25785, 6848, 6, '2 x daags'),
(25786, 6850, 6, 'Trommelvlies'),
(25787, 6851, 6, 'Soort'),
(25788, 6852, 6, 'Gebruik Id of Naam met minimaal drie karakters (inclusief spaties)'),
(25789, 6853, 6, 'Keuze van kolommen die getoond moeten worden voor Patient zoek resultaat'),
(25790, 6854, 6, 'Type vermelding'),
(25791, 6855, 6, 'Soort gebeurtenissen'),
(25792, 6856, 6, 'Soort layout van scherm'),
(25793, 6857, 6, 'Soort scan met hier de patiënt ID'),
(25794, 6858, 6, 'Tiep hier uw bericht'),
(25795, 6859, 6, 'Aanvraag en resultaat'),
(25796, 6864, 6, 'UCSMC codes die door de Universiteit van Calgary Sports Medicine Centre gegeven zijn'),
(25797, 6865, 6, 'Oekrainisch'),
(25798, 6866, 6, 'Ulceraties'),
(25799, 6867, 6, 'Ulceratieve Colitis'),
(25800, 6868, 6, 'Ulcers:'),
(25801, 6869, 6, 'Directorie kan niet bereikt worden'),
(25802, 6870, 6, 'URL kan niet bereikt worden'),
(25803, 6871, 6, 'Niet in staat aan te maken'),
(25804, 6872, 6, 'Niet gelukt om patient document subdireftorie te maken'),
(25805, 6873, 6, 'Geen data in deze file gevonden'),
(25806, 6874, 6, 'Niet mogelijk om deze betaling terug te vinden in ar_activity'),
(25807, 6875, 6, 'Niet mogelijk om applicatie te configureren. Geef schrijf toestemming aan'),
(25808, 6876, 6, 'Nog niet vastgelegd'),
(25809, 6877, 6, 'Maak een keuze'),
(25810, 6878, 6, 'Niet geautoriseerd'),
(25811, 6879, 6, 'Niet geautoriseerde toegang voor ePrescription'),
(25812, 6880, 6, 'Toegang niet geautoriseerd'),
(25813, 6881, 6, 'Niet aangemaakt'),
(25814, 6882, 6, 'Niet verstuurde rekeningen'),
(25815, 6884, 6, 'onder de tong'),
(25816, 6885, 6, 'Ondergewicht'),
(25817, 6886, 6, 'Niet gediagnostiseerd'),
(25818, 6887, 6, 'NIET verwerkt'),
(25819, 6888, 6, 'NIET verwerkt'),
(25820, 6889, 6, 'Niet verwerkt is'),
(25821, 6890, 6, 'Maak Checkout ongedaan'),
(25822, 6892, 6, 'Unieke Klanten'),
(25823, 6893, 6, 'Unieke identificatie, door mens te lezen, voor dit type'),
(25824, 6894, 6, 'Unieke nieuwe klanten'),
(25825, 6895, 6, 'Unieke nummer identifcatie voor dit type'),
(25826, 6896, 6, 'Patiënten die eenmalig gezien werden'),
(25827, 6897, 6, 'Overzicht van Patiënten die eenmalig gezien werden'),
(25828, 6898, 6, 'Eenmalig bezoek patient'),
(25829, 6899, 6, 'Eenheid'),
(25830, 6900, 6, 'Eenheden'),
(25831, 6901, 6, 'eenheden'),
(25832, 6902, 6, 'Units nodig voor de waaerde van het resultaat'),
(25833, 6903, 6, 'Eenheden voor Vitals Formulier'),
(25834, 6904, 6, 'Eenheden moeten een getal zijn'),
(25835, 6905, 6, 'Units niet gedefinieerd'),
(25836, 6906, 6, 'Units/L'),
(25837, 6907, 6, 'Onbekend of N/A'),
(25838, 6908, 6, 'onbekend (zie log)'),
(25839, 6910, 6, 'Niets bekend over roken'),
(25840, 6911, 6, 'Onbekend of N/A'),
(25841, 6912, 6, 'Onbekende User Id:'),
(25842, 6913, 6, 'ontkoppel patient'),
(25843, 6914, 6, 'Niet met name genoemde verzekeringsmij.'),
(25844, 6915, 6, 'Niet geregistreerd'),
(25845, 6916, 6, 'Niet geregistreerde modules'),
(25846, 6918, 6, 'Alles deselecteren'),
(25847, 6919, 6, 'Niet geselecteerd'),
(25848, 6920, 6, 'Ongespecificeerd'),
(25849, 6921, 6, 'ongestructureerd'),
(25850, 6922, 6, 'Het laden van database file wordt niet ondersteund'),
(25851, 6924, 6, 'tot'),
(25852, 6925, 6, 'Onverwachtte aanvulling'),
(25853, 6926, 6, 'Ongebruikt'),
(25854, 6927, 6, 'UOR'),
(25855, 6928, 6, 'Tot aan'),
(25856, 6929, 6, 'Lopende afspraken'),
(25857, 6930, 6, 'Lopende gebeurtenissen'),
(25858, 6931, 6, 'Updaten'),
(25859, 6932, 6, 'Update'),
(25860, 6933, 6, 'Update actief'),
(25861, 6934, 6, 'Bestanden updaten'),
(25862, 6935, 6, 'Info updaten'),
(25863, 6936, 6, 'Update lijst'),
(25864, 6937, 6, 'Update nummer van behandelaar'),
(25865, 6938, 6, 'Update geselecteerde Items'),
(25866, 6939, 6, 'Update de volgende variabelen in de file'),
(25867, 6940, 6, 'Updat User Info'),
(25868, 6942, 6, 'Persoonsgegevens updaten is niet toegestaan'),
(25869, 6943, 6, 'Up-loaden van configuratie file defaults'),
(25870, 6944, 6, 'Aanpassing versie indidcatoren'),
(25871, 6945, 6, 'UPGRADE'),
(25872, 6946, 6, 'Upgrade'),
(25873, 6947, 6, 'Database upgraden'),
(25874, 6948, 6, 'Om LibreEHR database te upgraden om Procedures, Functies en tabellen, nodig voor het De-identificatie proces toe te voegen'),
(25875, 6949, 6, 'Upgrading gaat door'),
(25876, 6950, 6, 'Old NPI'),
(25877, 6951, 6, 'Uploaden'),
(25878, 6952, 6, 'Template uploaden'),
(25879, 6953, 6, 'Uploaden en intalleren'),
(25880, 6954, 6, 'Opladen configuratie data'),
(25881, 6955, 6, 'Document uploaden'),
(25882, 6956, 6, 'Uploaden mislukt!'),
(25883, 6957, 6, 'Plaatje werd geladen naar'),
(25884, 6958, 6, 'Importbestand uploaden:'),
(25885, 6959, 6, 'Uploaden van Patient Educatie PDF naar'),
(25886, 6960, 6, 'Upload proces is gelukt'),
(25887, 6961, 6, 'Rapport uploaden'),
(25888, 6962, 6, 'Uploaden van de xml file naar Categorie CCR'),
(25889, 6963, 6, 'Dit bestand uploaden'),
(25890, 6964, 6, 'Bij het klikken op een invoice nummer verschijnt het "handleiding posting venster". Hier kunt u de datum en notities voor de factuur veranderen, de naam selecteren voor wie je invoert en de verzekeringen selecteren waarvoor alle te verwachen betalingen zijn ontvangen. Belangrijker, voor elke facturerings code waarvoor een bedrag in rekening werd gebracht, kunt u de betaling en informatie aanpassen.'),
(25891, 6965, 6, 'Bij het zoeken wordt u een lijst van facturen getoond. U klikt op een van de factuurnummers om een tweede venster te openen, waarbij gegevensinvoer in de pagina handmatig gedaan kan worden. U kunt ook klikken op de naam van een patiënt als u een notitie wilt maken voor de front office medewerkers, zodat deze kunnen zien wanneer de patiënt aankomt en u kunt de facturen selecteren die op de statements van de patiënt verschijnen en deze statements afdrukken.'),
(25892, 6966, 6, 'Bovenarm'),
(25893, 6967, 6, 'Urdu'),
(25894, 6968, 6, 'Urgentie'),
(25895, 6970, 6, 'Urine'),
(25896, 6971, 6, 'Urineverlies'),
(25897, 6972, 6, 'Frequentie van mictie'),
(25898, 6973, 6, 'Moeizaam op gang komen mictie'),
(25899, 6974, 6, 'Urine microalbumine'),
(25900, 6975, 6, 'Straal van mictie'),
(25901, 6976, 6, 'Mictie drang'),
(25902, 6977, 6, 'URL'),
(25903, 6979, 6, 'URL van ondersteuning voor LibreEHR'),
(25904, 6981, 6, 'URL voor de telefoon Gateway. Geautomatiseerde VOIP service verleend door Maviq. Bezoek http://signup.maviq.com voor meer informatie.'),
(25905, 6985, 6, 'Gebruik'),
(25906, 6986, 6, 'Gebruiks Indicator (ISA15)'),
(25907, 6987, 6, 'Gebruik alleen % in een veld als u die kolom sorteert'),
(25908, 6988, 6, '24-uurs tijdnotering?'),
(25909, 6990, 6, 'Gebruik certified EHR technologie om patient specifieke voorichtings bron te vinden en aan patient te geven indien van toepassing.'),
(25910, 6991, 6, 'Gebruik scherm om inrekening te brengen'),
(25911, 6992, 6, 'Gebruik CPOE voor medicijn bestellingen zelf ingevoerd door een bevoegd behandlaar met licentie die bestellingen kan invoeren inde medische records per State, lokaal en professionele richtlijnen.'),
(25912, 6997, 6, 'Gebruik zelf gemaakte immunisatie lijst'),
(25913, 6999, 6, 'Gebruik datum range'),
(25914, 7000, 6, 'Gebruik standaard'),
(25915, 7001, 6, 'Gebruik DELETE mogelijkheid om te verwijderen'),
(25916, 7002, 6, 'Gebruik internationale datumstijl?'),
(25917, 7003, 6, 'Gebruik SOURCE file naam'),
(25918, 7004, 6, 'Gebruik onderstaand veld voor aankoop of overplaatsing'),
(25919, 7005, 6, 'Gebruik deze mogelijkheid alleen bij NIEUW geinstalleerde site, '),
(25920, 7006, 6, 'Gebruik onderwerpen?'),
(25921, 7007, 6, 'Gebruiker'),
(25922, 7009, 6, 'Gebruiker / groepen'),
(25923, 7010, 6, 'Gebruikers administratie'),
(25924, 7011, 6, 'Gebruiker- en lokatiebeheer'),
(25925, 7012, 6, 'Gebruiker- en groepsbeheer'),
(25926, 7013, 6, 'User kan niet verwijderd worden'),
(25927, 7014, 6, 'User Certificaat Authenticatie is niet geactiveerd'),
(25928, 7015, 6, 'Door gebruiker aangemaakt'),
(25929, 7016, 6, 'Door gebruiker aangemaakte locatie 11'),
(25930, 7017, 6, 'Door gebruiker aangemaakte locatie 12'),
(25931, 7018, 6, 'Door gebruiker aangemaakt veld'),
(25932, 7019, 6, 'Door gebruiker aangemaakte lijst 1'),
(25933, 7020, 6, 'Door gebruiker aangemaakte lijst 2');
INSERT INTO `lang_definitions` VALUES
(25934, 7021, 6, 'Door gebruiker aangemaakte lijst 3'),
(25935, 7022, 6, 'Door gebruiker aangemaakte lijst 4'),
(25936, 7023, 6, 'Door gebruiker aangemaakte lijst 5'),
(25937, 7024, 6, 'Door gebruiker aangemaakte lijst 6'),
(25938, 7025, 6, 'Door gebruiker aangemaakte lijst 7'),
(25939, 7026, 6, 'Door gebruiker aangemaakte tekst 1'),
(25940, 7027, 6, 'Door gebruiker aangemaakte tekst 2'),
(25941, 7028, 6, 'Door gebruiker aangemaakte tekst 3'),
(25942, 7029, 6, 'Door gebruiker aangemaakte tekst 4'),
(25943, 7030, 6, 'Door gebruiker aangemaakte tekst 5'),
(25944, 7031, 6, 'Door gebruiker aangemaakte tekst 6'),
(25945, 7032, 6, 'Door gebruiker aangemaakte tekst 7'),
(25946, 7033, 6, 'Door gebruiker aangemaakte tekst 8'),
(25947, 7034, 6, 'Voornaam User'),
(25948, 7037, 6, 'USER Logon (met 03 hierboven, anders spatie laten staan) (ISA02)'),
(25949, 7038, 6, 'USER Logon noodzakelijke indicator(ISA01~ gebruik 00 of 03)'),
(25950, 7039, 6, 'WEB-Handleiding'),
(25951, 7040, 6, 'Gebruiker groepsindeling'),
(25952, 7041, 6, 'Naamgebruiker'),
(25953, 7042, 6, 'Gebruiker- of Host-naam mag niet leeg zijn'),
(25954, 7043, 6, 'Gebruiker- of Host-computernaam'),
(25955, 7044, 6, 'USER Paswoord (ISA04~ met 01 hierboven alnders spatie laten staan)'),
(25956, 7045, 6, 'USER Paswoord noodzakelijke indicatir (ISA03~ gebruik 00 of 01)'),
(25957, 7046, 6, 'Gebruiker settings'),
(25958, 7047, 6, 'User specifieke setting'),
(25959, 7048, 6, 'User''s nieuwe paswoord'),
(25960, 7049, 6, 'User'),
(25961, 7051, 6, 'Usernaam for telefoon Gateway. Geautomatiseerd VOIP service aangeboden door Maviq. Bezoek http://signup.maviq.com voor meer informatie.'),
(25962, 7052, 6, 'Gebruikersnaam voor SMS Gateway'),
(25963, 7053, 6, 'Gebruikersnaam voor SMS Gateway.'),
(25964, 7054, 6, 'Username om met CouchDB te verbinden'),
(25965, 7055, 6, 'Gebruiker:'),
(25966, 7056, 6, 'Gebruikers'),
(25967, 7057, 6, 'Gebruikers/Groepen/Logs/Administratie'),
(25968, 7058, 6, 'gebruikt php <a href="http://php.net/strftime"></a> format'),
(25969, 7059, 6, 'Urineweg infecties'),
(25970, 7060, 6, 'Uyghur, Uighur'),
(25971, 7061, 6, 'Oesbekstaans'),
(25972, 7062, 6, 'Vakantie'),
(25973, 7063, 6, 'Vakantie'),
(25974, 7064, 6, 'Vaccin'),
(25975, 7065, 6, 'Pessarium'),
(25976, 7066, 6, 'Titulatuur'),
(25977, 7067, 6, 'accoorderen'),
(25978, 7068, 6, 'Waarde'),
(25979, 7069, 6, 'Waarde 1'),
(25980, 7070, 6, 'Waarde 2'),
(25981, 7072, 6, 'Waarde moet numeriek zijn'),
(25982, 7073, 6, 'Var1'),
(25983, 7074, 6, 'Var2'),
(25984, 7075, 6, 'variabele waarmee het de-indentificatie upgrade script moet lopen'),
(25985, 7076, 6, 'Varicella 1'),
(25986, 7077, 6, 'Varicella 2'),
(25987, 7078, 6, 'Spataderen'),
(25988, 7079, 6, 'Vaatconditie'),
(25989, 7080, 6, 'Vasculair ongeluk'),
(25990, 7081, 6, 'Vaatchirurgie'),
(25991, 7082, 6, 'Venda'),
(25992, 7083, 6, 'Verkoper'),
(25993, 7084, 6, 'Versie'),
(25994, 7085, 6, 'Vertigo'),
(25995, 7086, 6, 'Veterans Administratie'),
(25996, 7087, 6, 'Veterans Administration Plan'),
(25997, 7088, 6, 'VFC'),
(25998, 7089, 6, 'Vietnamees'),
(25999, 7090, 6, 'Bekijken'),
(26000, 7091, 6, 'Scherm'),
(26001, 7092, 6, 'Bekijk allergien'),
(26002, 7093, 6, 'Bekijk een x12-835 ERA file'),
(26003, 7094, 6, 'Bekijk Batch claim x12 tekst'),
(26004, 7097, 6, 'Bekijk beknopt rapport van patient'),
(26005, 7098, 6, 'Bekijk CSV tabellen'),
(26006, 7100, 6, 'Bekijk document'),
(26007, 7101, 6, 'Bekijk contact'),
(26008, 7102, 6, 'Bekijk ERA x12 tekst'),
(26009, 7103, 6, 'Evenementen in een popup-venster bekijken?'),
(26010, 7104, 6, 'bekijk Faciliteit specfieke User informatie'),
(26011, 7106, 6, 'Bekijk lokaal x12 file'),
(26012, 7107, 6, 'Bekijk log'),
(26013, 7108, 6, 'Bekijk pagina 1'),
(26014, 7109, 6, 'Bekijk pagina 2'),
(26015, 7110, 6, 'Bekijk reminders van nu en volgenden'),
(26016, 7111, 6, 'Bekijk Client'),
(26017, 7116, 6, 'Bekijk gerelateerde contacten'),
(26018, 7117, 6, 'bekijk rapport'),
(26019, 7118, 6, 'Bekijk de README file'),
(26020, 7121, 6, 'Bekijk/Edit Allergieen'),
(26021, 7122, 6, 'Bekijk/edit Issue'),
(26022, 7123, 6, 'Bekijk/Print'),
(26023, 7124, 6, 'Scherm:'),
(26024, 7125, 6, 'VISA'),
(26025, 7126, 6, 'VISA/MC/AMEX/Dis'),
(26026, 7127, 6, 'Viscerale schade / trauma / chirurgie'),
(26027, 7132, 6, 'Bezoek categorie'),
(26028, 7133, 6, 'Contact categorie:'),
(26029, 7134, 6, 'Datum contact'),
(26030, 7135, 6, 'bezoek datum'),
(26031, 7137, 6, 'Formulieren'),
(26032, 7138, 6, 'Bezoek History'),
(26033, 7140, 6, 'Consultatie'),
(26034, 7141, 6, 'Bezoeken vanaf'),
(26035, 7142, 6, 'Vital Signs'),
(26036, 7143, 6, 'Vitals'),
(26037, 7144, 6, 'Vitals (metriek)'),
(26038, 7145, 6, 'Vitals Form opties'),
(26039, 7146, 6, 'Stem'),
(26040, 7147, 6, 'Voice bericht verzonden'),
(26041, 7148, 6, 'Volapuk'),
(26042, 7149, 6, 'Braken'),
(26043, 7151, 6, 'W'),
(26044, 7152, 6, 'Buikomv'),
(26045, 7153, 6, 'Buikomvang'),
(26046, 7154, 6, 'Wachtende'),
(26047, 7155, 6, 'Binnen gelopen'),
(26048, 7156, 6, 'Wallonisch'),
(26049, 7157, 6, 'Walt Pennington'),
(26050, 7158, 6, 'Warenhuis'),
(26051, 7159, 6, 'Waarhuis maximum, 0 indien niet gebruikt'),
(26052, 7160, 6, 'Waarhuis minimum, 0 indien niet gebruikt'),
(26053, 7161, 6, 'Warenhuizen'),
(26054, 7162, 6, 'Warm'),
(26055, 7163, 6, 'Waarschuwing'),
(26056, 7164, 6, 'Waarschuwing'),
(26057, 7166, 6, 'Waarschuwing, Controleer nummer is reeds in database opgenomen'),
(26058, 7167, 6, 'Waarschuwing: deze patient heeft niet eenduideige codes in de probleem lijst!'),
(26059, 7168, 6, 'Waarschuwing: Er is vandaag voor deze patiënt al een bezoek aangemaakt!'),
(26060, 7169, 6, 'Waarschuwing: Als U de 2012-2013 Spaanse versie gebruikt, let er dan op om deze eenmalig te unzippenvoordat deze in de contri/snomed directory (dit is omdat de release van deze file werd "ge-dubbel zipped").'),
(26061, 7170, 6, 'Waarschuwing: patiënt-ID is niet uniek!'),
(26062, 7171, 6, 'WAARSCHUWING: Data worden overschreven met ge-upload-de file'),
(26063, 7173, 6, 'Waarschuwingen'),
(26064, 7175, 6, 'Werd al eerder ge-upload'),
(26065, 7176, 6, 'werd niet gevonden'),
(26066, 7177, 6, 'We waarderen prompte betaling van verschuldigde bedragen'),
(26067, 7178, 6, 'We hebben de bovenstaande patient voor evaluatie en behandeling gezien op onze psychiatrische polikliniek. Bedankt voor deze verwijzing.'),
(26068, 7179, 6, 'Zwakheid'),
(26069, 7181, 6, 'Web search'),
(26070, 7182, 6, 'Website'),
(26071, 7183, 6, 'Website link voor de Onsite Patient Portal.'),
(26072, 7184, 6, 'Woe'),
(26073, 7185, 6, 'Woensdag'),
(26074, 7186, 6, 'Week'),
(26075, 7187, 6, 'week'),
(26076, 7188, 6, 'Weekoverzicht'),
(26077, 7189, 6, 'Week(en)'),
(26078, 7190, 6, 'Wekelijkse Exposures'),
(26079, 7191, 6, 'weken'),
(26080, 7192, 6, 'Weken'),
(26081, 7193, 6, 'Gewicht'),
(26082, 7194, 6, 'Gewichtsbeoordeling en counseling voor kinderen en adolescenten'),
(26083, 7195, 6, 'Gewichtsbeoordeling en couseling voor kinderen en aldolescenten (CQM)'),
(26084, 7196, 6, 'Gewichtverandering'),
(26085, 7197, 6, 'Gewichtsverlies'),
(26086, 7198, 6, 'Kliniek voor gewicht adviezen'),
(26087, 7199, 6, 'Welkom'),
(26088, 7200, 6, 'Welsh'),
(26089, 7201, 6, 'Wast Fries'),
(26090, 7202, 6, 'Wat moet geteld worden?'),
(26091, 7203, 6, 'Piepend:'),
(26092, 7204, 6, 'Piepen'),
(26093, 7205, 6, 'Piepen:'),
(26094, 7207, 6, 'Indien klaar, klik Submit(hieronder) om uw keuzes toe te passen'),
(26095, 7208, 6, 'Waar kunnen gescande of papieren documenten worden gevonden?'),
(26096, 7209, 6, 'Indien verzekerd'),
(26097, 7211, 6, 'Whiplash'),
(26098, 7212, 6, 'Blank'),
(26099, 7213, 6, 'Wie'),
(26100, 7214, 6, 'Wie gaf antwoord?'),
(26101, 7215, 6, 'Weduwstaat'),
(26102, 7216, 6, 'Breedte'),
(26103, 7217, 6, 'Breedte in pixels vanhet linker navigatie scherm'),
(26104, 7219, 6, 'Met aangegeven Items plot grafiek'),
(26105, 7220, 6, 'met voorkeurs taal'),
(26106, 7221, 6, 'Met geselecteerd als:'),
(26107, 7222, 6, 'met de oude naam'),
(26108, 7224, 6, 'Bij wie kunnen we een bericht achterlaten?'),
(26109, 7225, 6, 'Achtergehouden'),
(26110, 7226, 6, 'binnen uren'),
(26111, 7227, 6, 'binnen uren:'),
(26112, 7228, 6, 'binnen minuten'),
(26113, 7229, 6, 'binnen minuten:'),
(26114, 7230, 6, 'Zonder Faciliteit'),
(26115, 7231, 6, 'Zonder behandelaar'),
(26116, 7232, 6, 'Zonder update'),
(26117, 7233, 6, 'Getuige'),
(26118, 7234, 6, 'wk'),
(26119, 7235, 6, 'Normaal'),
(26120, 7236, 6, 'Wolof'),
(26121, 7237, 6, 'Vrouwen'),
(26122, 7238, 6, 'Alleen vrouwen'),
(26123, 7239, 6, 'WordPress Portaal'),
(26124, 7240, 6, 'Werk'),
(26125, 7241, 6, 'Briefje voor werk'),
(26126, 7242, 6, 'Telefoon werk'),
(26127, 7243, 6, 'Telefoon werk'),
(26128, 7244, 6, 'Werk gerelateerd?'),
(26129, 7245, 6, 'Werk/Scholing/Hobbies'),
(26130, 7246, 6, 'Werk-/Schoolverklaring'),
(26131, 7247, 6, 'werkdag'),
(26132, 7248, 6, 'Arbeids ongeschiktheid compensatie'),
(26133, 7249, 6, 'Arbeidsongeschiktheidsvoorziening Gezondheidsplan'),
(26134, 7250, 6, 'Leeftijds gebonden compensatie of partner regeling met Werkgevers groepsgebonden gezondheids plan'),
(26135, 7251, 6, 'Is bezig..... dit kan enkele minuten duren.'),
(26136, 7252, 6, 'Verslechterd'),
(26137, 7253, 6, 'Zou U het Balans bedrag willen gebruiken voor de Global rekening?'),
(26138, 7254, 6, 'Wilt u deze markeren als opgenomen?'),
(26139, 7255, 6, 'Wilt u toewijzen?'),
(26140, 7256, 6, 'Wilt u Distributie cancelen voor deze patient?'),
(26141, 7257, 6, 'Zou u de betalings distributie willenverwijderen?'),
(26142, 7258, 6, 'Wilt u betalingen verwijderen?'),
(26143, 7259, 6, 'Wilt u betalingen aanpassen en beeindigen'),
(26144, 7260, 6, 'Wilt u betalingen aanpassen?'),
(26145, 7261, 6, 'Wilt u betalingen toewijzen, daarna stopppen?'),
(26146, 7262, 6, 'Wilt u betalingen toewijzen?'),
(26147, 7263, 6, 'Wilt u bewaren?'),
(26148, 7264, 6, 'Pols'),
(26149, 7265, 6, 'Pols en hand'),
(26150, 7266, 6, 'Polsproblemen'),
(26151, 7267, 6, 'schrijven'),
(26152, 7268, 6, 'Afschrijving'),
(26153, 7269, 6, 'Schrijf eenmalig'),
(26154, 7270, 6, 'met enkele'),
(26155, 7271, 6, 'WT'),
(26156, 7273, 6, 'x Geannuleerd'),
(26157, 7274, 6, 'x Geannuleerd'),
(26158, 7275, 6, 'Rontgen'),
(26159, 7276, 6, 'Rontgenverslag:'),
(26160, 7277, 6, 'Rontgenverslag:'),
(26161, 7278, 6, 'Alleen X12: Vervangingsclaim '),
(26162, 7279, 6, 'X12-partner'),
(26163, 7280, 6, 'X12-partners'),
(26164, 7281, 6, 'x12 tekst'),
(26165, 7284, 6, 'Y'),
(26166, 7285, 6, 'Jaar'),
(26167, 7286, 6, 'jaar'),
(26168, 7287, 6, 'Jaaroverzicht'),
(26169, 7288, 6, 'Jaar(en)'),
(26170, 7289, 6, 'Jaren'),
(26171, 7290, 6, 'Jaren of maanden'),
(26172, 7291, 6, 'Jaren, maanden an dagen'),
(26173, 7292, 6, 'Ja'),
(26174, 7293, 6, 'Ja'),
(26175, 7294, 6, 'ja'),
(26176, 7295, 6, 'JA !!'),
(26177, 7296, 6, 'Ja, Verwijderen en Log maken'),
(26178, 7298, 6, 'Ja/Nee'),
(26179, 7299, 6, 'Ja:'),
(26180, 7300, 6, 'Yiddish'),
(26181, 7301, 6, 'Yoruba'),
(26182, 7303, 6, 'U gaat dit bestaande sjabloon voorgoed vervangen. Wilt u doorgaan?'),
(26183, 7304, 6, 'U bent in de grace periode voor inloggen. Verander uw paswoord voor'),
(26184, 7305, 6, 'U mag deze gebeurtenis niet verwijderen'),
(26185, 7306, 6, 'U mag deze gebeurtenis niet anpasssen'),
(26186, 7307, 6, 'U bent hiervoor niet geautoriseerd'),
(26187, 7308, 6, 'U heeft geen bevoegdheid voor deze ploeg'),
(26188, 7309, 6, 'U heeft geen bevoegdheid om problemen toe te voegen/aan te passen'),
(26189, 7310, 6, 'U bent niet geautoriseerd om afspraken te maken'),
(26190, 7311, 6, 'U bent niet bevoegd om dit contact te bekijken.'),
(26191, 7312, 6, 'U probeert de gegevens op te slaan die bij een oud bezoek horen?'),
(26192, 7313, 6, 'U kunt deze functie niet direct benaderen'),
(26193, 7314, 6, 'U kunt deze pagina niet direct benaderen'),
(26194, 7315, 6, 'U kunt geen blanco waarde toevoegen voor een categorie!'),
(26195, 7316, 6, 'U kunt niet een lege waarde toevoegen voor een subcategorie!'),
(26196, 7317, 6, 'U kunt niet een lege waarde toevoegen voor een item!'),
(26197, 7318, 6, 'Nadat er JA ingevuld is, kan er geen toekomstige datum gebruikt worden.'),
(26198, 7319, 6, 'U heeft geen keuze gemaakt'),
(26199, 7320, 6, 'U heeft geen toegang om deze notitie te bekijken/aan te passen'),
(26200, 7321, 6, 'U hebt geprobeerd de inhoud te wijzigen die vergrendeld is. Verwijder het slot als u dit wilt doen. Om te ontgrendelen, verwijdert u de regel ''/ * lock ::*/'''),
(26201, 7322, 6, 'Succesvol uitgelogged'),
(26202, 7323, 6, 'U kunt alleen *.txt file uploaden'),
(26203, 7324, 6, 'U kunt ook naar voorkeur HL7 resultaten van een file uploaden'),
(26204, 7325, 6, 'Patient Encounter formulier'),
(26205, 7326, 6, 'U moet een PAS zin invullen om document te versleutelen'),
(26206, 7327, 6, 'U moet uw eigen Paswoord invullen om gebruikers paswoord te veranderen. Leeg laten om hetzelfde Paswoord te gebruiken.'),
(26207, 7329, 6, 'Uw moet eerst een patient selecteren of toevoegen.'),
(26208, 7330, 6, 'U moet eerst een bezoek selecteren of aanmaken.'),
(26209, 7331, 6, 'U moet een bezoek categorie kiezen'),
(26210, 7332, 6, 'U moet een visite categorie kiezen'),
(26211, 7333, 6, 'U moet enige velden selecteren om door te gaan.'),
(26212, 7334, 6, 'U moet deze test uitvoeren indien deze claim met succes gegenereerd is, maar de daadwerkelijke claim-file geen gegevens bevat of slechts een onvoltooid gedeelte van de hoeveelheid gegevens die zij geacht wordt te bevatten. Het is duidelijk met HCFA vorderingen, omdat ze de menselijke leesbare tekst aanmaken. Met X12 claims is proces matig moeilijker om te bepalen of de claim juist is aangemaakt.'),
(26213, 7335, 6, 'Minstens 1 context kiezen'),
(26214, 7336, 6, 'Mistens 1 provider kiezen'),
(26215, 7338, 6, 'YUw klinische raportage'),
(26216, 7339, 6, 'Uw eindatum is ongeldig'),
(26217, 7340, 6, 'Uw gebeurtenis is verwijderd.'),
(26218, 7341, 6, 'Gebeurtenis is aangepast.'),
(26219, 7342, 6, 'Gebeurtenis is toegevoegd.'),
(26220, 7343, 6, 'U file is te groot'),
(26221, 7344, 6, 'Uw Lab resultaten'),
(26222, 7345, 6, 'U lijstnaam is veranderd om aan de naamvereisten tegemoet te komen.'),
(26223, 7346, 6, 'Uw bericht was verstuurd naar:'),
(26224, 7347, 6, 'Uw naam voor deze categorie, procedure of resultaat'),
(26225, 7348, 6, 'Uw Paswoord'),
(26226, 7349, 6, 'Uw wachtwoord is verlopen. Wijzig a.u.b. uw wachtwoord.'),
(26227, 7350, 6, 'Uw wachtwoord verloopt op'),
(26228, 7351, 6, 'Uw wachtwoord verloopt vandaag. Wijzig a.u.b. uw wachtwoord.'),
(26229, 7353, 6, 'Uw PostCalender configuratie is hersteld naar de oorspronkelijke gegevens'),
(26230, 7354, 6, 'Uw PostCalender configuratie is aangepast'),
(26231, 7355, 6, 'Uw herhalingsfrequentie moet een getal zijn'),
(26232, 7356, 6, 'Aantal herhalingen moet minstens 1 zijn'),
(26233, 7357, 6, 'Uw begindatum is later dan einddatum'),
(26234, 7358, 6, 'Uw begindatum is ongeldig'),
(26235, 7359, 6, 'Uw verzenden is mislukt'),
(26236, 7360, 6, 'jjjj-mm-dd'),
(26237, 7361, 6, 'jjjj-mm-dd'),
(26238, 7362, 6, 'jjjj-mm-dd datum geassocieerd met dit document'),
(26239, 7363, 6, 'jjjj-mm-dd datum vernietigd'),
(26240, 7364, 6, 'jjjj-mm-dd geb datum'),
(26241, 7365, 6, 'jjjj-mm-dd geb datum'),
(26242, 7366, 6, 'jjjj-mm-dd datum verloop'),
(26243, 7367, 6, 'jjjj-mm-dd datun begin hospitalisatie'),
(26244, 7368, 6, 'jjjj-mm-dd datum begin, chirurgie, of begin medicatie'),
(26245, 7369, 6, 'jjjj-mm-dd datum aankoop of overplaatsing'),
(26246, 7370, 6, 'jjjj-mm-dd datum van herstel of einde medicatie'),
(26247, 7371, 6, 'jjjj-mm-dd datum return wedstrijd'),
(26248, 7372, 6, 'jjjj-mm-dd datum van Service'),
(26249, 7373, 6, 'jjjj-mm-dd datum van deze brief'),
(26250, 7374, 6, 'jjjj-mm-dd datum van return wedstrijd'),
(26251, 7375, 6, 'jjjj-mm-dd datum dit document'),
(26252, 7376, 6, 'jjjj-mm-dd gebeurtenis of begindatum'),
(26253, 7377, 6, 'jjjj-mm-dd H:m eind datum'),
(26254, 7378, 6, 'jjjj-mm-dd H:m eind datum'),
(26255, 7379, 6, 'jjjj-mm-dd H:m Begin datum'),
(26256, 7380, 6, 'jjjj-mm-dd H:m Begin datum'),
(26257, 7381, 6, 'jjjj-mm-dd uu:mm:ss'),
(26258, 7382, 6, 'jjjj-mm-dd Uren(24) minuten'),
(26259, 7383, 6, 'jjjj-mm-dd laatste datum van gebeurtenis'),
(26260, 7385, 6, 'ZEF segment interior fout'),
(26261, 7386, 6, 'Zend Module'),
(26262, 7387, 6, 'Zero'),
(26263, 7388, 6, 'Zhuang, Chuang'),
(26264, 7389, 6, 'Postcode'),
(26265, 7390, 6, 'Postcode'),
(26266, 7391, 6, 'Postcode/Land:'),
(26267, 7392, 6, 'Zoeloe'),
(26268, 7393, 6, ' maar was '),
(26269, 7394, 6, ' kon niet bereikt worden'),
(26270, 7395, 6, 'ZEKER verwijderen?'),
(26271, 7396, 6, 'Medicijn'),
(26272, 7397, 6, 'e-mails niet verzonden'),
(26273, 7398, 6, 'van'),
(26274, 7399, 6, 'is aangemaakt '),
(26275, 7400, 6, 'is opnieuw geopend'),
(26276, 7401, 6, 'Geschiedenis'),
(26277, 7402, 6, 'het is geen nummer'),
(26278, 7403, 6, 'opnieuw rekening sturen OK'),
(26279, 7404, 6, 'LLL:'),
(26280, 7405, 6, 'Voorraad'),
(26281, 7406, 6, 'Origineel Medicaid Referentie No. '),
(26282, 7407, 6, 'min'),
(26283, 7408, 6, 'niet gevonden!'),
(26284, 7409, 6, 'Onverwachte resultaten in bepaalde BROWSERS kunnen er de oorzaak van zijn dat de tekst in schokken op het scherm komt met lange pauzes, waardoor het lijkt of het programma vastgelopen is. Uiteindelijk komt het resultaat lijn voor lijn op het scherm.Er kunnen daarna sequentiele nummers getoond worden, dit is hoewel er niets lijkt te gebeuren er nog wel degelijk programma activiteit gaande is. Deze nummers worden getoond met tussenvoeging van stukjes opgemaakte rekeningen en dit alles is normaal.'),
(26285, 7410, 6, 'voorschrift heeft limiet bereikt van'),
(26286, 7411, 6, 'tot'),
(26287, 7412, 6, 'update mislukt, niet in DB?'),
(26288, 7413, 6, 'gemarkeerd als "alleen factureren"'),
(26289, 7414, 6, 'succesvol in wachtrij'),
(26290, 7415, 6, '! Vertrokken zonder bezoek Dr'),
(26291, 7416, 6, '" voor code'),
(26292, 7417, 6, '" is geCHECKED in POST CALENDER settings'),
(26293, 7418, 6, '# ins/fin probleem'),
(26294, 7419, 6, '# aantal tabletten'),
(26295, 7420, 6, 'NAF.'),
(26296, 7421, 6, '$ Gecodeerd'),
(26297, 7422, 6, '$label (jjjj-mm-dd) '),
(26298, 7423, 6, '%'),
(26299, 7424, 6, '% Geannuleerd < 24 uur'),
(26300, 7425, 6, '% Geannuleerd < 24 uur '),
(26301, 7426, 6, 'zou moeten bestaan maar bestaat niet'),
(26302, 7427, 6, '(% komt overeen met elke string _ komt overeen met elk teken)'),
(26303, 7428, 6, '([CTRL] + klik om meerdere ontvangers te selecteren)'),
(26304, 7429, 6, '(Terug)'),
(26305, 7430, 6, '(Klik om aan te passen)'),
(26306, 7431, 6, '(E-mail verzenden gebeurt meteen, terwijl geautomatiseerde VOIP wordt verzonden naar de Sevice provider in afwachting van verdere afhandeling)'),
(26307, 7432, 6, '(Meer)'),
(26308, 7433, 6, '(Nieuwe patient)'),
(26309, 7434, 6, '(Notities en Autorisaties)'),
(26310, 7435, 6, '(Patient Notitie)'),
(26311, 7436, 6, '(Selecteer een van deze of voer uw eigen titel in)'),
(26312, 7437, 6, '(Shift-)Klik of versleep om de waarde te wijzigen'),
(26313, 7438, 6, '* Reminder verstuurd'),
(26314, 7439, 6, '** Verplaats chirurgie naar problemen!'),
(26315, 7440, 6, '*Verplicht'),
(26316, 7441, 6, '+ Status opgezocht'),
(26317, 7442, 6, '- Geen'),
(26318, 7443, 6, '-- Allemaal --'),
(26319, 7444, 6, '--Slecteer Rol--'),
(26320, 7445, 6, '.'),
(26321, 7446, 6, '0'),
(26322, 7447, 6, '0-10'),
(26323, 7448, 6, '0-24'),
(26324, 7449, 6, '02/12{{CMS 1500 formaat datum revisie setting in globals}}'),
(26325, 7450, 6, '08/12{{CMS 1500 formaat datum revisie setting in globals}}'),
(26326, 7451, 6, '1'),
(26327, 7452, 6, '1 - Noord Amerika. See http://www.wtng.info/ voor een lijst met ander Landen Codes'),
(26328, 7453, 6, 'Vanaf nu 1 dag'),
(26329, 7454, 6, 'Vanaf nu 1 maand'),
(26330, 7455, 6, 'Vanaf nu 1 week'),
(26331, 7456, 6, 'Vanaf nu 1 jaar'),
(26332, 7457, 6, '1. Rust houden 2. IJscompressen gedurende twee dagen 3. Compressie, laat verband zitten behalve bij gevoelloos- of bleekheid 4. Voet en been hoogleggen'),
(26333, 7458, 6, '11-14'),
(26334, 7459, 6, '12 uur'),
(26335, 7460, 6, '15-19'),
(26336, 7461, 6, '1ste'),
(26337, 7462, 6, '2'),
(26338, 7463, 6, 'Vanaf nu 2 dagen'),
(26339, 7464, 6, 'Vanaf nu 2 maanden'),
(26340, 7465, 6, 'Vanaf nu 2 weken'),
(26341, 7466, 6, 'Vanaf nu 2 jaar'),
(26342, 7467, 6, '2-20 jaar'),
(26343, 7468, 6, '20-24'),
(26344, 7469, 6, '2011 Automated Measure Calculations (AMC)'),
(26345, 7470, 6, '2011 Clinical Quality Measures (CQM)'),
(26346, 7471, 6, '2011 Official Clinical Quality Measures (CQM) Measure Groups'),
(26347, 7472, 6, '2014 Automated Measure Calculations (AMC)'),
(26348, 7475, 6, '2014 Clinical Quality Measures (CQM)'),
(26349, 7476, 6, '2014 Official Clinical Quality Measures (CQM) Measure Groups'),
(26350, 7477, 6, '2111-13'),
(26351, 7478, 6, '24 uur'),
(26352, 7479, 6, '25+'),
(26353, 7480, 6, '25-29'),
(26354, 7481, 6, '2nd'),
(26355, 7482, 6, 'Vanaf nu 3 dagen'),
(26356, 7483, 6, '3 maanden'),
(26357, 7484, 6, 'Vanaf nu 3 manden'),
(26358, 7485, 6, '3 x daags'),
(26359, 7486, 6, 'Vanaf nu 3 weken'),
(26360, 7487, 6, '30-34'),
(26361, 7488, 6, '35-39'),
(26362, 7489, 6, '3rd'),
(26363, 7490, 6, 'Vanaf nu 4 dagen'),
(26364, 7491, 6, '4 maanden'),
(26365, 7492, 6, 'Vanaf nu 4 maanden'),
(26366, 7493, 6, '4 x daags'),
(26367, 7494, 6, 'Vanaf nu 4 weken'),
(26368, 7495, 6, '40-44'),
(26369, 7496, 6, '45+'),
(26370, 7497, 6, '465.9, Bovenste luchtweg inf'),
(26371, 7498, 6, '466.0 Bronchitis, Acuut niet specifiek'),
(26372, 7499, 6, '486.0, Pneumonie, Acuut'),
(26373, 7500, 6, '491.21, COPD Exacerbatie'),
(26374, 7501, 6, '481.8 Bronchitis, Chronisch'),
(26375, 7502, 6, '483.92 Astma, Acute exacerbatie'),
(26376, 7503, 6, '496,0 COPD'),
(26377, 7504, 6, '4de'),
(26378, 7505, 6, 'Vanaf nu 5 dagen'),
(26379, 7506, 6, 'Vanaf nu 5 maanden'),
(26380, 7507, 6, 'vanaf nu 5 weken'),
(26381, 7508, 6, '519.7, Bronchospasme'),
(26382, 7509, 6, '5de'),
(26383, 7510, 6, 'Vnaf nu 6 dagen'),
(26384, 7511, 6, '6 maanden'),
(26385, 7512, 6, 'Vanaf nu 6 maanden'),
(26386, 7513, 6, 'Vanaf nu 6 weken'),
(26387, 7514, 6, '6de'),
(26388, 7515, 6, 'Vanaf nu 7 maanden'),
(26389, 7516, 6, 'Vanaf nu 8 maanden'),
(26390, 7517, 6, '824.0 Fractuur, mediale malleolus, gesloten'),
(26391, 7518, 6, '824.2 Fractuur, laterale malleolus, gesloten'),
(26392, 7519, 6, '824.6 Fractuur, trimeleoliar, gesloten'),
(26393, 7520, 6, '825.32 Fractuur, os naviculare (enkel)'),
(26394, 7521, 6, '824.35 Fractuur, basis 5e metatarsale'),
(26395, 7522, 6, '845.00 Enkel verstuiking NS'),
(26396, 7523, 6, '845.01 Verstuiking mediale (Deltoideus) Lig.'),
(26397, 7524, 6, '845.02 Verstuiking, calcaneo-fibulare'),
(26398, 7525, 6, 'Vanaf nu 9 maanden'),
(26399, 7526, 6, '99212 Vastgesteld - ongecompliceerd'),
(26400, 7527, 6, '99213 Vastgesteld - lage complexiteit'),
(26401, 7528, 6, '< In onderzoekskamer'),
(26402, 7529, 6, '> Weggegaan'),
(26403, 7530, 6, '?'),
(26404, 7531, 6, '? Niet verschenen'),
(26405, 7532, 6, '@ Gearriveerd'),
(26406, 7533, 6, '[Verander scherm]'),
(26407, 7534, 6, '[Datum laatste bezoek]'),
(26408, 7535, 6, '[Dgn sinds vorige bezoek]'),
(26409, 7536, 6, '[EOBs]'),
(26410, 7537, 6, '[Export OFX]'),
(26411, 7538, 6, '[niet aanbevolen]'),
(26412, 7539, 6, '[Aantal bezoeken]'),
(26413, 7540, 6, '[Verslagen]'),
(26414, 7541, 6, '[Selecteer alles]'),
(26415, 7542, 6, '[SQL Grootboek]'),
(26416, 7543, 6, '[Begin batch-verwerking]'),
(26417, 7544, 6, '[bekijk log]'),
(26418, 7545, 6, '[Bekijk voorbeeld]'),
(26419, 7546, 6, '_PC_DUR_HOURS'),
(26420, 7547, 6, '_PC_DUR_MINUTES'),
(26421, 7548, 6, '_PC_LOCALE'),
(26422, 7549, 6, '~ Te laat gekomen'),
(26423, 59, 7, 'שם חשבון'),
(26424, 74, 7, 'פעולה'),
(26425, 75, 7, 'פעולות'),
(26426, 1071, 7, 'מספר לקוח'),
(26427, 1079, 7, 'קליני'),
(26428, 5583, 7, 'רוסית'),
(26429, 5619, 7, 'יום שבת'),
(26430, 5620, 7, 'שמור'),
(26431, 5621, 7, 'שמור'),
(26432, 1, 8, 'Un'),
(26433, 2, 8, 'Un numéro de chèque ou un numéro de réclamation pour identifier le paiement.'),
(26434, 3, 8, 'Un certificat du client pour l''administrateur'),
(26435, 5, 8, 'Un document clinique est attaché.'),
(26436, 7, 8, 'Un distributeur est requis'),
(26437, 8, 8, 'Un formulaire de visite GCAC doit être ajouté à cette visite'),
(26438, 9, 8, 'Un numéro de lot est requis'),
(26439, 10, 8, 'Un numéro de lot est exigé !'),
(26440, 11, 8, 'Une lettre en minuscule'),
(26441, 12, 8, 'Un nombre'),
(26442, 14, 8, 'Un patient avec cet identifiant existe déjà.'),
(26443, 15, 8, 'Un patient avec ce nom existe déjà.'),
(26444, 16, 8, 'Un patient avec ce numero de sécurité social existe déjà.'),
(26445, 18, 8, 'Un chiffre positif montrera autant de rendez-vous depassés sur un Widget dans l''écran Résumé du patient.'),
(26446, 19, 8, 'Une source de référence peut être spécifiée pour chaque visite.'),
(26447, 20, 8, 'Un code relatif à IPPF est exigé!'),
(26448, 21, 8, 'Un caractère spécial'),
(26449, 22, 8, 'Une valeur unique afin d''identifier ce champ, invisible pour l''utilisateur'),
(26450, 24, 8, 'Avant les repas'),
(26451, 25, 8, 'matin'),
(26452, 26, 8, 'Fluidité d''air au niveau de l''oreille droite'),
(26453, 27, 8, 'AB'),
(26454, 28, 8, 'Abréviation'),
(26455, 29, 8, 'Abcès'),
(26456, 30, 8, 'Abdominal'),
(26457, 31, 8, 'Capable de supporter le poids sur 4 marches:'),
(26458, 32, 8, 'Anormal'),
(26459, 33, 8, 'ABN1'),
(26460, 34, 8, 'Anormal'),
(26461, 35, 8, 'Test Sanguin Anormal'),
(26462, 36, 8, 'Croissance anormale des cheveux'),
(26463, 37, 8, 'Mammographie Anormale'),
(26464, 39, 8, 'Avortement'),
(26465, 40, 8, 'Problème médical relatif à l''avortement'),
(26466, 41, 8, 'Méthode d''avortement'),
(26467, 42, 8, 'Catégories relative à l''avortement'),
(26468, 43, 8, 'Avortements'),
(26469, 44, 8, 'À propos du calendrier'),
(26470, 46, 8, 'Absence de diagnostique'),
(26471, 47, 8, 'Accepter l''affectation'),
(26472, 48, 8, 'Accepter le Paiement pour'),
(26473, 49, 8, 'Accepter le Paiement pour '),
(26474, 50, 8, 'Accepte l''affectation'),
(26475, 51, 8, 'Contrôle d''accès'),
(26476, 52, 8, 'Liste de contrôle d''accès administratif'),
(26477, 54, 8, 'Accès non permi'),
(26478, 55, 8, 'Accès non autorisés'),
(26479, 56, 8, 'Accédez à votre Portail Patients'),
(26480, 59, 8, 'Nom du Compte'),
(26481, 62, 8, 'Comptabilité'),
(26482, 64, 8, 'Douleurs'),
(26483, 65, 8, 'Acquittement demandé (ISA14)'),
(26484, 66, 8, 'Remerciements, Licence et Accréditation'),
(26485, 67, 8, 'ACL'),
(26486, 68, 8, 'ACL d''Administration'),
(26487, 69, 8, 'ACL d''Administration Non Autorisée'),
(26488, 70, 8, 'ACL correctement mis à jour'),
(26489, 71, 8, 'Acné'),
(26490, 72, 8, 'Acte'),
(26491, 73, 8, 'Date d''Acte'),
(26492, 74, 8, 'Action'),
(26493, 75, 8, 'Actions'),
(26494, 77, 8, 'Activer le Rapport CCR/CCD'),
(26495, 78, 8, 'Effective'),
(26496, 79, 8, 'Alerte Active'),
(26497, 80, 8, 'Règles d''Alerte Actives'),
(26498, 81, 8, 'Alertes Actives/Rappels'),
(26499, 82, 8, 'Rencontre active'),
(26500, 84, 8, 'Listes actives'),
(26501, 85, 8, 'Patient actif'),
(26502, 86, 8, 'Régimes Actives'),
(26503, 87, 8, 'Activité'),
(26504, 88, 8, 'Type d''Activité'),
(26505, 90, 8, 'Intoxication/Manque Aiguë'),
(26506, 92, 8, 'Maladie Chronique Aiguë'),
(26507, 93, 8, 'ajouter'),
(26508, 94, 8, 'Ajouter'),
(26509, 95, 8, 'Ajouter'),
(26510, 96, 8, 'Ajouter une Compagnie d''assurance'),
(26511, 98, 8, 'Ajouter une Pharmacie'),
(26512, 100, 8, 'Ajouter un événement pour '),
(26513, 101, 8, 'Ajouter une note'),
(26514, 102, 8, 'Ajouter en tant que nouveau'),
(26515, 104, 8, 'Boutons Ajouter'),
(26516, 105, 8, 'Boutons Ajouter pour les caractères spéciaux, Textes devant figurer en haut de l''éditeur à inclure dans le texte suite à un Clic'),
(26517, 106, 8, 'Ajouter une Catégorie'),
(26518, 107, 8, 'Ajouter une Constante'),
(26519, 108, 8, 'Ajouter un Contexte'),
(26520, 109, 8, 'Insérer un co-payeur'),
(26521, 110, 8, 'Ajouter un Critère'),
(26522, 111, 8, 'Ajouter un Bouton Personnalisé'),
(26523, 112, 8, 'Ajouter un Diagnostic'),
(26524, 113, 8, 'Ajouter un Médicament'),
(26525, 114, 8, 'Ajouter un rendez-vous'),
(26526, 115, 8, 'Ajouter Notes/rendez-vous'),
(26527, 116, 8, 'Ajouter un équipement médical'),
(26528, 117, 8, 'Ajouter un domaine'),
(26529, 118, 8, 'Ajouter les lignes suivantes au fichier de configuration du serveur Apache'),
(26530, 119, 8, 'Ajouter un Groupe'),
(26531, 120, 8, 'Ajouter le code ICD'),
(26532, 121, 8, 'Ajouter une vaccination'),
(26533, 122, 8, 'L''ajout n''est pas autorisé!'),
(26534, 123, 8, 'Ajouter un problème médical'),
(26535, 125, 8, 'Ajouter une langue'),
(26536, 126, 8, 'Ajouter un nouveau'),
(26537, 127, 8, 'Ajouter un nouveau'),
(26538, 128, 8, 'Ajouter une nouvelle catégorie: '),
(26539, 129, 8, 'Ajouter les nouveaux certificats au fichier de configuration du serveur Apache'),
(26540, 132, 8, 'Ajouter un Nouveau Groupe'),
(26541, 134, 8, 'Ajouter un nouveau lot et transaction'),
(26542, 135, 8, 'Ajouter une nouvelle note'),
(26543, 136, 8, 'Ajouter une nouvelle note'),
(26544, 137, 8, 'Ajouter un nouveau Partenaire'),
(26545, 140, 8, 'Ajouter une note'),
(26546, 141, 8, 'Ajouter une fiche Patient'),
(26547, 142, 8, 'Ajouter une ordonnance'),
(26548, 143, 8, 'Ajouter une procédure'),
(26549, 144, 8, 'Ajouter le numéro du prestataire'),
(26550, 145, 8, 'Ajouter une cure de déxintoxication'),
(26551, 146, 8, 'Ajouter une règle'),
(26552, 147, 8, 'Ajouter à'),
(26553, 148, 8, 'Ajouter à la Listes des Médicaments'),
(26554, 149, 8, 'Ajouter le Niveau Supérieur'),
(26555, 150, 8, 'Ajouter une Transaction'),
(26556, 151, 8, 'Ajouter un Utilisateur'),
(26557, 152, 8, 'Ajouter un Utilisateur au Groupe'),
(26558, 153, 8, 'Ajouter/Editer eRx'),
(26559, 154, 8, 'Ajouter/Editer la Transaction du Patient'),
(26560, 155, 8, 'Ajouté'),
(26561, 156, 8, 'L''ajout de données démographiques n''est pas autorisé'),
(26562, 158, 8, 'Syndrome d''Addison'),
(26563, 159, 8, 'Syndrome d''Addison'),
(26564, 160, 8, 'Attributs supplémentaires'),
(26565, 161, 8, 'Diagnostique supplémentaire'),
(26566, 162, 8, 'Antécédent supplémentaire'),
(26567, 163, 8, 'Notes d''antécédent(s) supplémentaire(s)'),
(26568, 164, 8, 'Information complémentaire'),
(26569, 165, 8, 'Laboratoires supplémentaires'),
(26570, 166, 8, 'Notes supplémentaires'),
(26571, 167, 8, 'Notes complémentaires pour ce résultat ou recommandation'),
(26572, 168, 8, 'Notes supplémentaires:'),
(26573, 169, 8, 'Notes supplémentaires: '),
(26574, 170, 8, 'Radiographies supplémentaires:'),
(26575, 171, 8, 'En outre, le paquet Snomed US Extension correspondant peut être importé séparément après l''installation du (version anglaise) Snomed sortie international'),
(26576, 172, 8, 'Ajouter seulement'),
(26577, 173, 8, 'Carnet d''adresses'),
(26578, 174, 8, 'Carnet d''adresses'),
(26579, 175, 8, 'Adresse'),
(26580, 178, 8, 'Carnet d''adresses'),
(26581, 179, 8, 'Entrée au carnet d''adresses pour la compagnie réalisant cette procédure'),
(26582, 180, 8, 'Entrée au carnet d''adresses pour le distributeur'),
(26583, 181, 8, 'Entrée au carnet d''adresses pour le vendeur'),
(26584, 182, 8, 'Type de carnet d''adresse'),
(26585, 187, 8, 'Adresse 1'),
(26586, 188, 8, 'Adresse 2'),
(26587, 189, 8, 'Destinataire'),
(26588, 190, 8, 'Ajuster'),
(26589, 191, 8, 'Montant Ajusté'),
(26590, 192, 8, 'Ajuster'),
(26591, 193, 8, 'Ajustement'),
(26592, 194, 8, 'Ajustemen du montant'),
(26593, 195, 8, 'Raisons de l''ajustement'),
(26594, 196, 8, 'Valeur de l''ajustement pour code '),
(26595, 197, 8, 'Ajustements'),
(26596, 198, 8, 'Ajustement administratif'),
(26597, 199, 8, 'Administrateur'),
(26598, 200, 8, 'Adresse mail Administrateur'),
(26599, 201, 8, 'Administrer via'),
(26600, 202, 8, 'Administré'),
(26601, 203, 8, 'Administré par'),
(26602, 205, 8, 'Site administré'),
(26603, 206, 8, 'Administration'),
(26604, 207, 8, 'Site d''administration'),
(26605, 208, 8, 'Administrateurs'),
(26606, 209, 8, 'Les administrateurs ont tous les droits'),
(26607, 210, 8, 'Date d''admission'),
(26608, 212, 8, 'Suivi et Dépistage du poids pour Adulte'),
(26609, 213, 8, 'Suivi et Dépistage du poids pour Adulte (CQM)'),
(26610, 214, 8, 'Directive préalable'),
(26611, 215, 8, 'Directives préalables'),
(26612, 216, 8, 'Avertissement de directives anticipées'),
(26613, 218, 8, 'Avancé'),
(26614, 219, 8, 'Conseil'),
(26615, 221, 8, 'Affecte Normale'),
(26616, 223, 8, 'Appels hors des heures de travail'),
(26617, 224, 8, 'Après la migration des anciens mécanismes de mot de passe où les mots de passe sont stockés dans la table des utilisateurs sans sel, est complete. Cet indicateur doit être réglé sur Faux afin que seule l''authentification par la nouvelle méthode est possible.'),
(26618, 225, 8, 'Après avoir réalisé les configurations mentionnées, importer le certificat du client administré dans le navigateur puis redémarrer le serveur Apache (mot de passe vide)'),
(26619, 226, 8, 'Après avoir enregistré le PDF, cliquer [view log] pour verifier d''éventuelles erreurs'),
(26620, 227, 8, 'Après avoir enregistré les fichiers TEXT, cliquer [view log] pour verifier d''éventuelles erreurs'),
(26621, 228, 8, 'Après avoir enregistré votre fichier séquentiel (batch), cliquer sur [View Log], pour vérifier d''éventuelles erreurs.'),
(26622, 230, 8, 'Après avoir correctement entrer les informations, cliquer sur le bouton d''enregistrement.'),
(26623, 232, 8, 'Planification du suivi'),
(26624, 233, 8, 'Encore'),
(26625, 234, 8, 'Age'),
(26626, 235, 8, 'Age par'),
(26627, 236, 8, 'Catégorie d''âge'),
(26628, 237, 8, 'Données concernant l''âge sont erronées'),
(26629, 238, 8, 'Format d''affichage de l''age'),
(26630, 239, 8, 'Le format pour "âge à partir de" est invalide'),
(26631, 240, 8, 'Le format pour "âge jusqu''à" est invalide'),
(26632, 241, 8, 'Age à partir de'),
(26633, 242, 8, 'Âge en années pour le changement de format d''affichage'),
(26634, 243, 8, 'Age maximum'),
(26635, 244, 8, 'Age minimum'),
(26636, 245, 8, 'Tranche d''âge'),
(26637, 247, 8, 'Aciennes Colonnes:'),
(26638, 249, 8, 'Albanais(e)'),
(26639, 250, 8, 'Alcool'),
(26640, 251, 8, 'Consommation d''Alcool'),
(26641, 253, 8, 'Nombre d''alerte'),
(26642, 255, 8, 'Alerts'),
(26643, 258, 8, 'ALEUT'),
(26644, 259, 8, 'Tout/ Toutes'),
(26645, 260, 8, 'Tout/ Toutes'),
(26646, 261, 8, 'Tous (Assemblage Format A)'),
(26647, 262, 8, 'Tous (Assemblage Format B)'),
(26648, 263, 8, 'Tous (Cumulative)'),
(26649, 266, 8, 'Toutes catégories'),
(26650, 268, 8, 'Tous codes'),
(26651, 269, 8, 'Tout au long de la journée'),
(26652, 270, 8, 'Evénement durant toute la journée'),
(26653, 271, 8, 'Tout les champs démographiques, avec recherche et vérification des doublons'),
(26654, 272, 8, 'Tous les équipements/ installations'),
(26655, 273, 8, 'Toutes les Blessures/Problèmes'),
(26656, 274, 8, 'Toutes langues autorisées'),
(26657, 276, 8, 'Tout ou une partie du prénom'),
(26658, 277, 8, 'Tout ou une partie du nom de famille'),
(26659, 278, 8, 'Tout ou une partie de l''entreprise'),
(26660, 280, 8, 'Tous produits'),
(26661, 281, 8, 'Tous fournisseurs'),
(26662, 282, 8, 'Tous examinés et négatifs:'),
(26663, 283, 8, 'Tous sujets'),
(26664, 284, 8, 'Tous les utilisateurs'),
(26665, 285, 8, 'Allergique'),
(26666, 286, 8, 'Allergies'),
(26667, 287, 8, 'Allergies:'),
(26668, 288, 8, 'Allergie'),
(26669, 289, 8, 'L''importation des allergies c''est terminé avec succes'),
(26670, 290, 8, 'Liste des problèmes du à l''allergie'),
(26671, 291, 8, 'Réaction allergique'),
(26672, 294, 8, 'Affecter'),
(26673, 295, 8, 'Autoriser'),
(26674, 296, 8, 'Autoriser toutes les langues disponibles en option dans le menu lors de l''ouverture de session'),
(26675, 297, 8, 'Autoriser la creation de demandes d''indémnisation contenant les diagnostiques mais non les procedures ou les frais. La majorité des cliniques y sont réticentes.'),
(26676, 298, 8, 'Autoriser le langage de débogage'),
(26677, 299, 8, 'Autoriser les e-mails'),
(26678, 300, 8, 'Autoriser les messages e-mails ?'),
(26679, 301, 8, 'Autoriser les e-mails ?'),
(26680, 302, 8, 'Autoriser les demandes de rendez-vous'),
(26681, 303, 8, 'Autoriser l''échange d''information médicale'),
(26682, 304, 8, 'Autoriser le partage d''information d''immunisation'),
(26683, 305, 8, 'Autorise l''utilisation du registre d''immunisation'),
(26684, 306, 8, 'Autoriser les courriers'),
(26685, 308, 8, 'Autoriser le Portail Patient'),
(26686, 309, 8, 'Autoriser les SMS'),
(26687, 310, 8, 'Autoriser les SMS (textos) ?'),
(26688, 311, 8, 'Autoriser l''activation instantanée des événements proposés ?'),
(26689, 312, 8, 'Autoriser les messages téléphoniques ?'),
(26690, 313, 8, 'Autoriser les utilisateurs de publier des Evénements Globaux'),
(26691, 314, 8, 'Autoriser les utilisateurs à publier des calendriers personnels'),
(26692, 315, 8, 'Autoriser les messages vocaux'),
(26693, 316, 8, 'Autorisé'),
(26694, 317, 8, 'Langues autorisées'),
(26695, 318, 8, 'Autorisé (c)'),
(26696, 319, 8, 'Permet la signature electronique pour la visite'),
(26697, 320, 8, 'Permet la signature electronique des formulaires'),
(26698, 321, 8, 'Permet le courrier'),
(26699, 322, 8, 'Permet les messages vocaux'),
(26700, 323, 8, 'existe déjà'),
(26701, 324, 8, 'existe déjà.'),
(26702, 325, 8, 'Déjà utilisé, veuillez choisir un autre identifiant'),
(26703, 326, 8, 'Déjà utilisé, veuillez choisir un autre titre'),
(26704, 327, 8, 'Adresse secondaire'),
(26705, 328, 8, 'modifier'),
(26706, 329, 8, 'Alternativement, vous pouvez utiliser la page de recherche pour transférer une remise électronique (X12 835) du fichier que vous avez obtenu à partir de votre payeur ou chambre de compensation. Vous pouvez le faire en cliquant sur le bouton Parcourir et sélectionner le fichier à télécharger, puis en cliquant sur Rechercher pour effectuer le téléchargement et l''affichage des factures correspondantes. Dans ce cas, les autres paramètres mentionnés ci-dessus ne s''appliquent pas et sera ignoré. Téléchargement enregistre le fichier mais n''a pas encore traiter son contenu - ce qui est fait séparément comme décrit ci-dessous.'),
(26707, 330, 8, 'AM'),
(26708, 331, 8, 'Programme Matinal'),
(26709, 332, 8, 'AMC'),
(26710, 333, 8, 'Suivi AMC'),
(26711, 338, 8, 'Modifier la note existante'),
(26712, 343, 8, 'Indien d''Amérique'),
(26713, 344, 8, 'Indiens d''Amérique ou autochtones d''Alaska'),
(26714, 345, 8, 'AMEX'),
(26715, 346, 8, 'Amharique'),
(26716, 347, 8, 'Montant'),
(26717, 348, 8, 'Quantité Administrée'),
(26718, 349, 8, 'Montant des frais'),
(26719, 350, 8, 'Montant du solde précédent'),
(26720, 351, 8, 'Montant pour cette visite'),
(26721, 352, 8, 'Montant payé'),
(26722, 353, 8, 'Montant:'),
(26723, 354, 8, 'Montant a payer'),
(26724, 355, 8, 'Une date de fin postérieur à la date de démarrage est nécessaire pour les événements répétés!'),
(26725, 357, 8, 'Une erreur est survenue durant le vidage de l''arborescence du répertoire web LibreEHR'),
(26726, 358, 8, 'Une erreur est survenue durant le vidage de l''arborescence du répertoire web phpGACL'),
(26727, 359, 8, 'Une erreur est survenue durant le vidage de l''arborescence du répertoire web SQL-Ledger'),
(26728, 360, 8, 'Une édition incomplète de GCAC a été crée et reliée. Elle devra être complétée plus tard.'),
(26729, 362, 8, 'Une erreur inattendue s''est produite.'),
(26730, 363, 8, 'Une lettre majuscule'),
(26731, 365, 8, 'Et'),
(26732, 366, 8, 'ET'),
(26733, 367, 8, 'et'),
(26734, 368, 8, 'et '),
(26735, 369, 8, 'et tous les données secondaires? Cette action sera enregistrée'),
(26736, 370, 8, 'et modificateur'),
(26737, 371, 8, 'et traité.'),
(26738, 372, 8, 'et redémarrer le serveur Apache.'),
(26739, 373, 8, 'et la raison est'),
(26740, 374, 8, 'Anémie'),
(26741, 375, 8, 'Cheville'),
(26742, 376, 8, 'Cheville + Talon'),
(26743, 377, 8, 'Formulaire d''évalution de cheville'),
(26744, 378, 8, 'Problèmes de cheville'),
(26745, 379, 8, 'Spondylarthrite Ankylosante'),
(26746, 380, 8, 'Spondylarthrite Ankylosante'),
(26747, 381, 8, 'Anorexie'),
(26748, 382, 8, 'Une autre manipulation possible dans la fenêtre affichée est la demande d''une seconde facturation. Si vous cocher cette case avant d''enregistrer, alors la demande originale sera ré ouverte, ajoutée à la page de facturation et exécutée lors de la prochaine échéance.'),
(26749, 383, 8, 'avant'),
(26750, 384, 8, 'Anus normal, sans tendreté/masse rectale'),
(26751, 385, 8, 'Anxiété'),
(26752, 386, 8, 'N''importe quel(le) / Tout(e)'),
(26753, 387, 8, 'Toute catégorie'),
(26754, 388, 8, 'Toute partie du code désiré ou sa description'),
(26755, 389, 8, 'Toute partie de le spécialité désirée'),
(26756, 390, 8, 'Toute partie de l''identification ou du nom du médicament'),
(26757, 391, 8, 'Toute partie de l’identification ou du nom d''immunisation'),
(26758, 392, 8, 'Toute partie du nom du patient, ou "nom, prénom", ou "X-Y"'),
(26759, 393, 8, 'Toute autre information pertinente'),
(26760, 394, 8, 'Clé API pour le relais SMS'),
(26761, 395, 8, 'Apnée'),
(26762, 396, 8, 'Apparence'),
(26763, 397, 8, 'Apparence:'),
(26764, 398, 8, 'Ajouter cette note'),
(26765, 399, 8, 'Ajouter à la note existante'),
(26766, 400, 8, 'Ajouter à cette note'),
(26767, 401, 8, 'Ajouter à Cette Note'),
(26768, 402, 8, 'Appendicectomie'),
(26769, 404, 8, 'Les patients concernés'),
(26770, 405, 8, 'Application'),
(26771, 406, 8, 'Nom utilisateur pour la page d’accès et titre de fenêtre principale'),
(26772, 407, 8, 'Code Application receveur (GS03 - si vide ISA08 sera utilisé)'),
(26773, 408, 8, 'Code Application émettrice (GS02)'),
(26774, 409, 8, 'Titre de l''Application'),
(26775, 410, 8, 'Appliquer au formulaire des fonctions vitales et à la courbe de croissance'),
(26776, 411, 8, 'Appliquer au formulaire des fonctions vitales'),
(26777, 412, 8, 'Appliquer les changements seulement à l’événement actuel, à celui ci ainsi qu''aux futurs événements, ou à tous les événements ?'),
(26778, 413, 8, 'Appliquer à la section désignée'),
(26779, 414, 8, 'appliquer sur la peau'),
(26780, 415, 8, 'Application'),
(26781, 416, 8, 'Application du patch au site'),
(26782, 417, 8, 'Rendez-vous'),
(26783, 418, 8, 'Date de rendez-vous'),
(26784, 419, 8, 'Style d''affichage des Rendez-vous'),
(26785, 420, 8, 'Règle de rappel de rendez-vous'),
(26786, 421, 8, 'Statut du rendez-vous'),
(26787, 422, 8, 'Statuts du rendez-vous'),
(26788, 423, 8, 'Rendez-vous dans'),
(26789, 424, 8, 'Couleur d''Evénement/Rendez-vous'),
(26790, 425, 8, 'Des Rendez-vous'),
(26791, 426, 8, 'Rendez-vous (option d''écriture)'),
(26792, 427, 8, 'Rendez-vous(ecrire, pas obligatoire)'),
(26793, 430, 8, 'Rendez-vous et Rencontres'),
(26794, 431, 8, 'Rapport des Rendez-vous'),
(26795, 432, 8, 'Rapport des Rencontres et Rendez-vous'),
(26796, 434, 8, 'Approuver'),
(26797, 436, 8, 'Approuvé'),
(26798, 437, 8, 'Evénements administratifs approuvés'),
(26799, 440, 8, 'RDV-Visite'),
(26800, 441, 8, 'RDVs'),
(26801, 442, 8, 'Avr.'),
(26802, 443, 8, 'Avril'),
(26803, 444, 8, 'Arabe'),
(26804, 446, 8, 'Archive'),
(26805, 447, 8, 'les noms du groupe de contrôle doivent ils être traduits ?'),
(26806, 448, 8, 'Les noms de catégorie de rendez vous doivent ils être traduits ?'),
(26807, 449, 8, 'Les noms de catégorie de documents doivent ils être traduits?'),
(26808, 450, 8, 'Des frais sont ils facturés pour ce type ?'),
(26809, 451, 8, 'Les titres des notes des patients doivent ils être traduits?'),
(26810, 452, 8, 'Les codes sont-ils stocker dans des tables sql externes (0-Non, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(26811, 453, 8, 'Etes vous prêt à compléter une nouvelle version GCAC pour cette consultation ?'),
(26812, 454, 8, 'Etes-vous sûr de vouloir poster pour aujourd''hui?'),
(26813, 455, 8, 'Etes vous sur de vouloir valider ces événements ?'),
(26814, 457, 8, 'Etes vous sur de vouloir complètement effacer ce formulaire ?'),
(26815, 459, 8, 'Etes vous sur de vouloir supprimer cet accès ?'),
(26816, 460, 8, 'Etes vous certain de vouloir effacer cet événement ?'),
(26817, 461, 8, 'Etes vous certain de vouloir effacer cet élément de la base de données ?'),
(26818, 462, 8, 'Etes vous certain de vouloir effacer cette note ?'),
(26819, 464, 8, 'Etes vous certain de vouloir éditer ces événements ?'),
(26820, 465, 8, 'Etes vous certain de vouloir masquer ces événements ?'),
(26821, 467, 8, 'Etes vous certain de vouloir voir ces événements ?'),
(26822, 468, 8, 'Etes vous certain de vouloir effacer l''ensemble du groupe nommé ?'),
(26823, 469, 8, 'Etes vous sur de vouloir effacer l''ensemble de la liste?'),
(26824, 470, 8, 'Etes vous certain de vouloir de vouloir effacer le champs interne ?'),
(26825, 471, 8, 'Etes vous certain de vouloir effacer les champs sélectionnés ?'),
(26826, 472, 8, 'Etes vous certain de vouloir poursuivre ces actions ?'),
(26827, 473, 8, 'Zone non spécifiée'),
(26828, 474, 8, 'Bras'),
(26829, 475, 8, 'Arménien'),
(26830, 477, 8, 'Arythmie'),
(26831, 478, 8, 'Arthrite'),
(26832, 479, 8, 'Arthrite / arthrose'),
(26833, 480, 8, 'Arthrite / arthrose'),
(26834, 481, 8, 'comme'),
(26835, 482, 8, 'A compter de'),
(26836, 484, 8, 'Asiatique'),
(26837, 487, 8, 'Evaluation'),
(26838, 488, 8, 'Affecté à'),
(26839, 489, 8, 'Assistant'),
(26840, 490, 8, 'Asthme'),
(26841, 491, 8, 'à'),
(26842, 492, 8, 'Au moins un paramètre de recherche est requis si vous sélectionnez tout'),
(26843, 493, 8, 'Au naviculaire'),
(26844, 494, 8, 'Au naviculaire:'),
(26845, 495, 8, 'Equipe d''Athlétisme'),
(26846, 496, 8, 'Equipe d''Athlétisme'),
(26847, 497, 8, 'Blessure sportive'),
(26848, 498, 8, 'Certificat CA d’audit ATNA'),
(26849, 499, 8, 'Hôte d''audit ATNA'),
(26850, 500, 8, 'Certificat local d''audit ATNA'),
(26851, 501, 8, 'Port d''audit ATNA'),
(26852, 503, 8, 'Attention'),
(26853, 504, 8, 'Attention'),
(26854, 506, 8, 'Audit des requêtes du moteur CDR'),
(26855, 509, 8, 'Sauvegardes des journaux d''Audit'),
(26856, 510, 8, 'Autres Journalisation d''Audit'),
(26857, 511, 8, 'Commande de journalisation d''Audit'),
(26858, 512, 8, 'Journalisation d''Audit des Enregistrements de Patient'),
(26859, 513, 8, 'Planification de la Journalisation d''Audit'),
(26860, 514, 8, 'Administration de la Sécurité de la Journalisation d''Audit'),
(26861, 515, 8, 'Journalisation d''Audit des requêtes SELECT'),
(26862, 516, 8, 'Août'),
(26863, 517, 8, 'Août'),
(26864, 519, 8, 'Autorisation'),
(26865, 520, 8, 'Autorisation/notes'),
(26866, 523, 8, 'Groupe d''Autorisation'),
(26867, 524, 8, 'Etat de l''autorisation'),
(26868, 525, 8, 'Autorisations'),
(26869, 526, 8, 'Autoriser'),
(26870, 527, 8, 'Autoriser – toutes rencontres'),
(26871, 528, 8, 'Autoriser – mes rencontres'),
(26872, 529, 8, 'Authorize.net'),
(26873, 530, 8, 'Autorisé'),
(26874, 531, 8, 'Autorisé Uniquement'),
(26875, 532, 8, 'Envoi automatique'),
(26876, 535, 8, 'Auto-Création Nouvelles Rencontres'),
(26877, 536, 8, 'Auto-généré'),
(26878, 537, 8, 'Calculs des mesures automatisées (AMC)'),
(26879, 542, 8, 'Suivi des Calculs des mesures automatisées (AMC)'),
(26880, 543, 8, 'Mesures Automatisées (AMC)'),
(26881, 544, 8, 'Automatique'),
(26882, 546, 8, 'Créer automatiquement une nouvelle rencontre lorsque l''état du rendez-vous est fixé à "@" (arrivée).'),
(26883, 549, 8, 'Voiture médicalisée'),
(26884, 550, 8, 'auto-enregistré'),
(26885, 551, 8, 'Catégories Disponibles'),
(26886, 552, 8, 'Horaires Disponibles'),
(26887, 557, 8, 'Moyenne Mensuelle'),
(26888, 558, 8, 'Avulsion / avulsion fracture'),
(26889, 559, 8, 'Avulsion du Malléole latérale'),
(26890, 560, 8, 'Avulsion du Malléole médiale '),
(26891, 561, 8, 'Basées sur la Connaissance'),
(26892, 562, 8, 'Auxiliaire'),
(26893, 565, 8, 'deux fois par jour'),
(26894, 566, 8, 'Derrière'),
(26895, 567, 8, 'derrière'),
(26896, 568, 8, 'Retour huit visites'),
(26897, 569, 8, 'Retour onze visites'),
(26898, 570, 8, 'Retour cinq visites'),
(26899, 571, 8, 'Retour quatre visites'),
(26900, 572, 8, 'Retour neuf visites'),
(26901, 573, 8, 'Retour une visite'),
(26902, 574, 8, 'Douleur dorsale'),
(26903, 575, 8, 'Problèmes de dos'),
(26904, 576, 8, 'Reporter sept visites'),
(26905, 577, 8, 'Reporter six visites'),
(26906, 578, 8, 'Chirurgie du dos'),
(26907, 579, 8, 'Retour dix visites'),
(26908, 580, 8, 'Retour trois visites'),
(26909, 581, 8, 'Retour à la page de l''Admin'),
(26910, 584, 8, 'Retour au patient'),
(26911, 585, 8, 'Retour aux utilisateurs'),
(26912, 586, 8, 'Retour à la Vue'),
(26913, 587, 8, 'Retour douze visites'),
(26914, 588, 8, 'Retour deux visites'),
(26915, 589, 8, 'Les services d''arrière-plan'),
(26916, 590, 8, 'Sauvegarde'),
(26917, 591, 8, 'Un document de sauvegarde a été créé Le téléchargement va être lancé.'),
(26918, 593, 8, 'Sauvegarde effectuée avec succès'),
(26919, 594, 8, 'Chèque sans provision'),
(26920, 595, 8, 'Créances Douteuses'),
(26921, 596, 8, 'Bahasa Indonésien'),
(26922, 597, 8, 'Bal'),
(26923, 598, 8, 'Balance'),
(26924, 599, 8, 'balance'),
(26925, 600, 8, 'Montant du solde'),
(26926, 601, 8, 'Solde dû'),
(26927, 603, 8, 'Traite'),
(26928, 607, 8, 'Base du cinquième (5ème) Métatarsien'),
(26929, 608, 8, 'Base du cinquième (5ème) Métatarsien:'),
(26930, 611, 8, 'Réclamation du Lot (batch)'),
(26931, 612, 8, 'Outil de communication du lot (batch)'),
(26932, 613, 8, 'Entrée de Payement du Lot (batch)'),
(26933, 614, 8, 'Paiement par lots'),
(26934, 615, 8, 'Traitement du lot (batch) lancé; cela peut prendre du temps.'),
(26935, 616, 8, 'Résultats du lot (Batch)'),
(26936, 617, 8, 'BatchCom'),
(26937, 619, 8, 'car cet identifiant n''existe pas.'),
(26938, 620, 8, 'Début'),
(26939, 621, 8, 'Date Début'),
(26940, 623, 8, 'Date début du service aaaa-mm-jj'),
(26941, 624, 8, 'Heure début de journée pour les évènements calendaires.'),
(26942, 626, 8, 'Eructation'),
(26943, 628, 8, 'Bengale'),
(26944, 630, 8, 'entre'),
(26945, 633, 8, 'Bilatéral'),
(26946, 634, 8, 'Bilatéral:'),
(26947, 636, 8, 'Date de facture:'),
(26948, 637, 8, 'Collecter/Facturer'),
(26949, 638, 8, 'Facturé'),
(26950, 640, 8, 'Facturation'),
(26951, 641, 8, 'Facturation (écriture optionnel)'),
(26952, 642, 8, 'Destinataire de facturation'),
(26953, 644, 8, 'Code de facturation pour le Service demandé'),
(26954, 645, 8, 'Codes de facturation'),
(26955, 646, 8, 'Donnée de facturation'),
(26956, 647, 8, 'Service de facturation'),
(26957, 648, 8, 'Fonds de Facturations'),
(26958, 649, 8, 'Information sur la facturation'),
(26959, 650, 8, 'Lieu de facturation'),
(26960, 655, 8, 'Gestionnaire de facturation'),
(26961, 656, 8, 'Note de facturation'),
(26962, 657, 8, 'Note de facturation pour '),
(26963, 658, 8, 'Note de facturation:'),
(26964, 659, 8, 'Résutalt de la file de facturation:'),
(26965, 660, 8, 'Rapport de facturation'),
(26966, 661, 8, 'Statut de facturation'),
(26967, 662, 8, 'Statut de facturation = non facturé'),
(26968, 663, 8, 'facturation à '),
(26969, 665, 8, 'Biopsie'),
(26970, 666, 8, 'Date de naissance'),
(26971, 667, 8, 'Naissance-24 mois'),
(26972, 669, 8, 'Noir'),
(26973, 670, 8, 'Poumons Noir'),
(26974, 671, 8, 'Noir ou Afro-américain'),
(26975, 672, 8, 'Cancer de la vésicule'),
(26976, 673, 8, 'Infections de la vésicule'),
(26977, 674, 8, 'Formulaires blancs'),
(26978, 675, 8, 'Problèmes de saignement'),
(26979, 676, 8, 'Scotome'),
(26980, 677, 8, 'Ballonement'),
(26981, 678, 8, 'Bouché'),
(26982, 679, 8, 'Sang'),
(26983, 680, 8, 'Pression Arterielle'),
(26984, 681, 8, 'Pression arterielle'),
(26985, 682, 8, 'Nez en sang'),
(26986, 683, 8, 'Blue Cross Blue Shield');
INSERT INTO `lang_definitions` VALUES
(26987, 684, 8, 'Les lignes bleues dans ce rapport sont à titre informatif. Les lignes noires indiquent les informations déjà existantes. Les lignes vertes montrent les changements qui ont été appliqués avec succès. Les lignes rouges indiquent des erreurs, ou des changements qui n''ont pas été appliquées; elles doivent être traitées manuellement. Revendications qui sont actuellement privés et les inversions de paiement ne sont pas traitées automatiquement et donc apparaîtra en rouge.'),
(26988, 685, 8, 'Vision Brouillée'),
(26989, 686, 8, 'IMC'),
(26990, 687, 8, 'Etat de L''IMC'),
(26991, 689, 8, 'Région du corps'),
(26992, 690, 8, 'Zone du corps'),
(26993, 691, 8, 'Zone du corps , si applicable'),
(26994, 692, 8, 'Sensibilité osseuse:'),
(26995, 693, 8, 'Sensibilité osseuse: Malléole médiane'),
(26996, 694, 8, 'Booléen'),
(26997, 696, 8, 'En dessous'),
(26998, 697, 8, 'Les deux oreilles'),
(26999, 698, 8, 'les deux oreilles'),
(27000, 699, 8, 'Partie inférieure (Bas)'),
(27001, 701, 8, 'Case 10 A. Liée à l''Emploi '),
(27002, 702, 8, 'Case 10 B. Accident de Voiture '),
(27003, 703, 8, 'Case 10 C. Autre Accident '),
(27004, 706, 8, 'Case 15. Date de maladie identique ou similaire (aaaa-mm-jj):'),
(27005, 708, 8, 'Case 16. Date début d''incapacité de travail (aaaa-mm-jj) :'),
(27006, 709, 8, 'Case 16. Date fin de l''incapacité de travail (aaaa-mm-jj) :'),
(27007, 710, 8, 'Case 18. Date début d''Hospitalisation (aaaa-mm-jj) : '),
(27008, 711, 8, 'Case 18. Date fin d''Hospitalisation (aaaa-mm-jj) : '),
(27009, 712, 8, 'Case 20. Est-ce laboratoire extérieur utilisé?'),
(27010, 713, 8, 'Case 22. Nouvelle présentation du Code Medicaid (CIM-9) '),
(27011, 714, 8, 'Case 23. N ° d''autorisation préalable '),
(27012, 715, 8, 'Pression Atrérielle'),
(27013, 716, 8, 'PA Disatolique'),
(27014, 717, 8, 'PA Systoloque'),
(27015, 719, 8, 'PA diast'),
(27016, 721, 8, 'PA syst'),
(27017, 722, 8, 'Portugais Brésilien'),
(27018, 723, 8, 'Seins'),
(27019, 724, 8, 'Biopsie Mammaire'),
(27020, 725, 8, 'Décharge Seins'),
(27021, 726, 8, 'Maladie du sein'),
(27022, 727, 8, 'Examen Mammaire'),
(27023, 728, 8, 'Masse des Seins'),
(27024, 730, 8, 'Bruits respiratoires:'),
(27025, 732, 8, 'Fractures'),
(27026, 734, 8, 'Formulaire de Bronchites'),
(27027, 735, 8, 'Parcourir'),
(27028, 736, 8, 'Parcourir pour Enregistrement'),
(27029, 737, 8, 'Ecchymose/hématome'),
(27030, 739, 8, 'Enflement Droit:'),
(27031, 741, 8, 'Brûlure à la miction'),
(27032, 742, 8, 'Brûlure à la miction'),
(27033, 744, 8, 'Occupé'),
(27034, 745, 8, 'mais pas encore traité.'),
(27035, 746, 8, 'Fesses'),
(27036, 747, 8, 'Fesses + S.I'),
(27037, 748, 8, 'par'),
(27038, 749, 8, 'Par'),
(27039, 750, 8, 'Par voie orale'),
(27040, 751, 8, 'Par / Source'),
(27041, 752, 8, 'Par:'),
(27042, 753, 8, 'C'),
(27043, 754, 8, 'Certificat CA pour verifier le serveur syslog RFC 5425 TLS'),
(27044, 755, 8, 'Durée de vie du cache (en secondes)'),
(27045, 756, 8, 'Mettre en cache le résultat du modèle?'),
(27046, 757, 8, 'Consommation de caféine'),
(27047, 758, 8, 'Agenda'),
(27048, 759, 8, 'Heure Fin de l''Agenda'),
(27049, 760, 8, 'Intervalle de l''Agenda'),
(27050, 761, 8, 'Ecran de l''Agenda'),
(27051, 762, 8, 'Paramètre de l''Agenda'),
(27052, 763, 8, 'Heure Début de l''Agenda'),
(27053, 764, 8, 'Agenda UI'),
(27054, 765, 8, 'Vue Agenda'),
(27055, 766, 8, 'Appel à addForm () ce fait ici.<br>'),
(27056, 767, 8, 'Calories'),
(27057, 768, 8, 'Cambodgien'),
(27059, 774, 8, 'Annuler'),
(27060, 775, 8, 'Annuler les Modifications'),
(27061, 776, 8, 'Annulés'),
(27062, 777, 8, 'Cancer'),
(27063, 778, 8, 'Dépistage du cancer: cancer du côlon'),
(27064, 779, 8, 'Dépistage du cancer: Mammographie'),
(27065, 780, 8, 'Dépistage du cancer: Pap'),
(27066, 781, 8, 'Dépistage du cancer: cancer de la prostate'),
(27067, 782, 8, 'Impossible d''ajouter cette entrée car elle existe déjà!'),
(27068, 783, 8, 'Impossible d''ajouter/mettre à jour cette entrée, car un doublon existe déjà!'),
(27069, 784, 8, 'ne peut pas être archivé, ignoré'),
(27070, 785, 8, 'ne peut pas être convertie au format JPEG. Peut-être ImageMagick n''est pas installé?'),
(27071, 786, 8, 'ne peut pas être supprimé, ignoré'),
(27072, 787, 8, 'ne peut pas être archivé, ignoré'),
(27073, 788, 8, 'ne peut pas être affiché car son type n''est pas supporté par le navigateur'),
(27074, 789, 8, 'ne peut pas être affiché car son type n''est pas supporté par le navigateur.'),
(27075, 790, 8, 'Impossible de créer'),
(27076, 795, 8, 'Impossible de trouver '),
(27077, 796, 8, 'Impossible de trouver le nom de fichier destination'),
(27078, 799, 8, 'Impossible de trouver le patient à partir du client ID (dans SQL-Ledger)'),
(27079, 800, 8, 'Impossible de trouver le document PostScript en référence '),
(27080, 801, 8, 'Impossible de trouver le fournisseur à partir de ''employé (dans SQL-Ledger) = '),
(27081, 802, 8, 'Impossible de modifier les Paiements. Reste est négatif.'),
(27082, 803, 8, 'Impossible d''ouvrir '),
(27083, 804, 8, 'Ne pouvez pas poster l''Assurance. L’Entité Payeur sélectionnée est le Patient.'),
(27084, 805, 8, 'Ne pouvez pas poster le Patients. L''organisme Payeur choisi est l''Assurance.'),
(27085, 806, 8, 'Ne pouvez pas poster des paiements. Reste est négatif.'),
(27086, 807, 8, 'Impossible de lire'),
(27087, 808, 8, 'Impossible de lire le répertoire'),
(27088, 809, 8, 'Impossible de mettre à jour car vous n''éditez pas une entrée existante !'),
(27089, 810, 8, 'Capitaliser'),
(27090, 812, 8, 'capsule'),
(27091, 813, 8, 'Carte'),
(27092, 814, 8, 'Cathétérisme Cardiaque'),
(27093, 815, 8, 'Echo cardiaque'),
(27094, 816, 8, 'Cardiovasculaire'),
(27095, 821, 8, 'Cartilage / chondrales / dégâts disque'),
(27096, 822, 8, 'Lésion cartilagineuse'),
(27097, 823, 8, 'Pulsations carotides nl, pouls de pédale nl'),
(27098, 824, 8, 'espèces'),
(27099, 825, 8, 'Espèces'),
(27100, 826, 8, 'Reçu d''Espèce'),
(27101, 827, 8, 'Reçus d''Espèce par le fournisseur'),
(27102, 829, 8, 'Chirurgie de la Cataracte'),
(27103, 830, 8, 'Cataracte'),
(27104, 831, 8, 'Catégories'),
(27105, 832, 8, 'Catégories pour'),
(27106, 833, 8, 'Catégorie'),
(27107, 834, 8, 'catégorie'),
(27108, 835, 8, 'Catégorie '),
(27109, 836, 8, 'Détails Catégorie'),
(27110, 837, 8, 'Limites Catégorie'),
(27111, 838, 8, 'Nom Catégorie'),
(27112, 839, 8, 'Nom catégorie vide'),
(27113, 840, 8, 'Titre/Catégorie'),
(27114, 841, 8, 'Caucasien'),
(27115, 842, 8, 'Raisons monétaires pour imprimer des consultations/les informations sur l''assurance principale'),
(27116, 850, 8, 'Dépot de document clinique'),
(27117, 851, 8, 'Priorité de traitement des rapport CDR'),
(27118, 852, 8, 'Cellule'),
(27119, 853, 8, 'Téléphone Cellulaire'),
(27120, 855, 8, 'Numéro de Téléphone Cellulaire'),
(27121, 856, 8, 'Centrale de Certification'),
(27122, 857, 8, 'Centrale/Amérique du Sud'),
(27123, 858, 8, 'L''emplacement du fichier crt de l''Autorité de certification ne peut pas être vide'),
(27124, 859, 8, 'L''emplacement du fichier key de l''Autorité de certification emplacement ne peut pas être vide'),
(27125, 860, 8, 'Certificat à envoyer au serveur RFC 5425 TLS syslog server.'),
(27126, 861, 8, 'Certificat Utilisateur'),
(27127, 862, 8, 'Certificats'),
(27128, 864, 8, 'ChampUS'),
(27129, 865, 8, 'ChampUSVA'),
(27130, 866, 8, 'modifier'),
(27131, 867, 8, 'Modifier'),
(27132, 868, 8, 'Modifier l''Activité'),
(27133, 869, 8, 'Changement échoué! erreur de connexion CouchDB ?'),
(27134, 870, 8, 'Changement de vision'),
(27135, 871, 8, 'Changement de vision'),
(27136, 872, 8, 'Changer mot de passe'),
(27137, 874, 8, 'Modifié'),
(27138, 875, 8, 'Intestin modifié'),
(27139, 876, 8, 'Modification de l''ID patient pour le document'),
(27140, 877, 8, 'Caractéristiques'),
(27141, 878, 8, 'Caractères restants'),
(27142, 879, 8, 'Charge'),
(27143, 880, 8, 'Ajustement de Frais'),
(27144, 881, 8, 'Frais encodé'),
(27145, 882, 8, 'Frais'),
(27146, 883, 8, 'Graphique'),
(27147, 884, 8, 'Graphique d''Activité'),
(27148, 885, 8, 'Rapport d''Activité des Entrées/Sorties'),
(27149, 886, 8, 'ID Graphique'),
(27150, 887, 8, 'ID Graphique:'),
(27151, 889, 8, 'Graphique lieu d''activité'),
(27152, 890, 8, 'Note sur le graphique'),
(27153, 891, 8, 'Numéro Graphique'),
(27154, 892, 8, 'Emplacements de stockage graphique'),
(27155, 893, 8, 'Suivi graphique'),
(27156, 894, 8, 'Suivi graphique'),
(27157, 895, 8, 'Graphiques vérifiés'),
(27158, 896, 8, 'Sortie des graphiques'),
(27159, 898, 8, 'Vérifier'),
(27160, 899, 8, 'vérifier'),
(27161, 900, 8, 'Vérifier Tous'),
(27162, 902, 8, 'Vérifier le Montant'),
(27163, 903, 8, 'vérifier la Date'),
(27164, 904, 8, 'Vérifiez les différences de traductions avec la table personnalisée de la langue.'),
(27165, 906, 8, 'Arrivée à'),
(27166, 907, 8, 'Vérifier les données d''entrée'),
(27167, 909, 8, 'Vérifier les résultats de laboratoire'),
(27168, 910, 8, 'Coche indique revue'),
(27169, 911, 8, 'Ne pas vérifier'),
(27170, 912, 8, 'vérifier le numéro'),
(27171, 915, 8, 'vérifier le Paiement'),
(27172, 916, 8, 'Cochez la case s''il s''agit d''un fichier crypté'),
(27173, 917, 8, 'Cochez cette case si vous souhaitez que les prestataires voient tous les rendez par défaut et non seulement les leurs.'),
(27174, 918, 8, 'Cochez pour créer un problème à partir de ce diagnostic'),
(27175, 919, 8, 'Vérifier/Date de la notice explicative des prestations recues'),
(27176, 920, 8, 'Vérifier/Numéro de la notice explicative des prestations recues'),
(27177, 921, 8, 'Vérifier/Numéro de référence'),
(27178, 922, 8, 'Vérifier/Numéro de référence'),
(27179, 923, 8, 'Liste de case à cocher'),
(27180, 924, 8, 'liste case à cocher'),
(27181, 925, 8, 'case à cocher w/texte'),
(27182, 926, 8, 'Case à cocher w/texte'),
(27183, 928, 8, 'Vérifié'),
(27184, 929, 8, 'Case coché = oui, vide = non'),
(27185, 932, 8, 'Vérification'),
(27186, 933, 8, 'Somme de contrôle'),
(27187, 934, 8, 'Thorax'),
(27188, 935, 8, 'Auscultation pulmonaire'),
(27189, 936, 8, 'Douleur Thoracique'),
(27190, 937, 8, 'Douleur Thoracique:'),
(27191, 938, 8, 'Douleurs Thoraciques'),
(27192, 942, 8, 'Principal réclamation'),
(27193, 943, 8, 'Enfant'),
(27194, 945, 8, 'Statut vaccination infantile (CQM)'),
(27195, 946, 8, 'Frissons'),
(27196, 947, 8, 'Chinois'),
(27197, 948, 8, 'Chinois (simplifié)'),
(27198, 949, 8, 'Chinois (Traditionnel)'),
(27199, 951, 8, 'Choix'),
(27200, 952, 8, 'Cholécystectomie'),
(27201, 954, 8, 'Cholecystestomie'),
(27202, 955, 8, 'Choisissez'),
(27203, 956, 8, 'Choisissez une section et cliquez sur un article, puis dans l''autre section, vous verrez les éléments liés en surbrillance, et vous pouvez cliquer dans cette section pour ajouter et supprimer les relations.'),
(27204, 957, 8, 'Choisir des critères'),
(27205, 959, 8, 'Choisir un fichier'),
(27206, 960, 8, 'Choisir dans la liste'),
(27207, 962, 8, 'Choisir la liste'),
(27208, 965, 8, 'Choisissez le format d''impression pour ce rapport de rencontre.'),
(27209, 967, 8, 'Bronchite chronique'),
(27210, 968, 8, 'Douleurs articulaires chroniques'),
(27211, 969, 8, 'Maladie rénale chronique'),
(27212, 970, 8, 'Synovite chronique / effusion / douleurs articulaires / goutte'),
(27213, 971, 8, 'Chronique / Récurrent'),
(27214, 973, 8, 'Cirrhose du foie'),
(27215, 974, 8, 'Cirrhose du foie'),
(27216, 975, 8, 'Ville'),
(27217, 976, 8, 'Nom Ville'),
(27218, 977, 8, 'Ville, Etat'),
(27219, 978, 8, 'Ville, Etat Code Postal'),
(27220, 979, 8, 'Ville/Etat'),
(27221, 980, 8, 'Réclamation'),
(27222, 981, 8, 'Réclamation '),
(27223, 982, 8, 'Etat de votre demande'),
(27224, 983, 8, 'Exécution du test de la revendication terminé'),
(27225, 984, 8, 'Type de revendication'),
(27226, 985, 8, 'La demande a été généré dans un fichier'),
(27227, 986, 8, 'La demande a été généré dans un fichier '),
(27228, 987, 8, 'Demandes'),
(27229, 988, 8, 'Classification'),
(27230, 989, 8, 'Effacer'),
(27231, 990, 8, 'EFFACER LE PATIENT ACTIF'),
(27232, 991, 8, 'Effacer tout'),
(27233, 992, 8, 'Effacer les données HL7'),
(27234, 993, 8, 'Justification claire'),
(27235, 994, 8, 'Effacer Smarty Cache'),
(27236, 995, 8, 'Informations de la chambre de compensation nécessaires pour la création du lot EDI 270'),
(27237, 996, 8, 'Numéro CLIA'),
(27238, 997, 8, 'Cliquez'),
(27239, 998, 8, 'Cliquez sur «exporter» pour exporter votre Catégorie, Sous-catégorie, objets, et les données de contenu dans un fichier texte. Toute ressemblance de ce fichier à un fichier XML est purement fortuite. Les balises d’ouverture et de fermeture doivent être sur la même ligne, ils doivent être en minuscules et sans espace. Pour importer, rechercher un fichier et cliquez sur «importer». Si les données sont complètement différentes, elles vont être fusionnées avec les données existantes. Si il y’a des noms similaires, l’ancien sera conservé et le nouveau enregistré avec un numéro ajouté à la fin.'),
(27240, 999, 8, 'Cliquez sur un point sur ​​le graphique pour ajouter une nouvelle annotation, cliquez à nouveau pour enlever'),
(27241, 1000, 8, 'Cliquez sur Télécharger le certificat pour télécharger les certificats dans le fichier ssl.zip'),
(27242, 1001, 8, 'Cliquer pour plus'),
(27243, 1002, 8, 'Cliquer pour plus de détails'),
(27244, 1003, 8, 'Cliquez pour un récapitulatif de la commande'),
(27245, 1004, 8, 'Cliquez ici pour les résultats'),
(27246, 1005, 8, 'Cliquez ici'),
(27247, 1006, 8, 'Cliquez ici pour ajouter un nouveau patient.'),
(27248, 1007, 8, 'Cliquez ici pour ajouter le nouveau statut de changement de blessures et de modifier l''activité quotidienne'),
(27249, 1008, 8, 'Cliquez ici pour choisir une date'),
(27250, 1009, 8, 'Cliquez ici pour choisir une date et une heure'),
(27251, 1010, 8, 'Cliquez ici pour choisir une date de début'),
(27252, 1020, 8, 'Cliquez ici pour rechercher'),
(27253, 1021, 8, 'Cliquez ici pour mettre à jour les paramètres de priorité, catégorie et le surnom'),
(27254, 1022, 8, 'Cliquez ici pour tout afficher.'),
(27255, 1023, 8, 'Cliquez ici pour afficher'),
(27256, 1025, 8, 'Cliquez ici pour afficher les signes vitaux.'),
(27257, 1026, 8, 'Cliquez ici pour afficher les détails du patient'),
(27258, 1027, 8, 'Cliquez ici pour les afficher tous.'),
(27259, 1028, 8, 'Cliquez ici pour afficher / éditer plus de détails'),
(27260, 1029, 8, 'Cliquez sur Installer pour installer une version de la base de données de la date suivante'),
(27261, 1030, 8, 'Cliquez sur une des parties du temps de l''augmenter'),
(27262, 1031, 8, 'Cliquez sur le nom du patient pour ouvrir le fichier du patient'),
(27263, 1032, 8, 'Cliquez sur Actualiser pour afficher tous les résultats, ou introduit les critères de recherche ci-dessus pour afficher des résultats spécifiques.'),
(27264, 1033, 8, 'Cliquez sur pour ajouter un diagnostic'),
(27265, 1034, 8, 'Cliquez pour ajouter de nouveaux composants'),
(27266, 1035, 8, 'Cliquez pour ajouter une nouvelle consultation'),
(27267, 1037, 8, 'Cliquez ici pour télécharger'),
(27268, 1038, 8, 'Cliquez pour modifier'),
(27269, 1039, 8, 'Cliquez sur pour éditer la description'),
(27270, 1040, 8, 'Cliquez pour modifier cet événement'),
(27271, 1041, 8, 'Cliquez pour générer le rapport'),
(27272, 1043, 8, 'Cliquez pour imprimer'),
(27273, 1044, 8, 'Cliquez pour recevoir (ajouter) un nouveau lot'),
(27274, 1045, 8, 'Cliquez pour sélectionner'),
(27275, 1046, 8, 'Cliquez pour sélectionner'),
(27276, 1047, 8, 'Cliquez pour sélectionner un code standard pour cette procédure'),
(27277, 1048, 8, 'Cliquez pour sélectionner un code facultatif de procédure'),
(27278, 1050, 8, 'Cliquez pour sélectionner ou modifier le code CVX'),
(27279, 1051, 8, 'Cliquez pour sélectionner ou modifier les diagnostics'),
(27280, 1052, 8, 'Cliquez pour sélectionner ou modifier les codes de service'),
(27281, 1053, 8, 'Cliquez pour sélectionner le patient'),
(27282, 1054, 8, 'Cliquez pour sélectionner le code associé'),
(27283, 1055, 8, 'Cliquez pour sélectionner les services à effectuer si ce résultat est anormal'),
(27284, 1056, 8, 'Cliquez pour sélectionner la procédure désirée'),
(27285, 1057, 8, 'Cliquez pour trier'),
(27286, 1058, 8, 'Cliquez pour afficher'),
(27287, 1059, 8, 'Cliquez pour afficher ou modifier'),
(27288, 1060, 8, 'Cliquez pour afficher/modifier'),
(27289, 1061, 8, 'Cliquez sur le bouton Upgrade pour mettre à niveau la base de données à partir de la date suivante'),
(27290, 1063, 8, 'Cliquez:'),
(27291, 1064, 8, 'Jours d''expiration du certificat client'),
(27292, 1065, 8, 'Période de validation du certificat client'),
(27293, 1066, 8, 'La validité du certificat client doit être un nombre valide.'),
(27294, 1067, 8, 'Copie Client'),
(27295, 1069, 8, 'Résumé dossier médical du client'),
(27296, 1070, 8, 'Nom du client'),
(27297, 1071, 8, 'Numéro du client'),
(27298, 1072, 8, 'Profil client - Nouveaux Clients'),
(27299, 1073, 8, 'Profil client - Clients unique'),
(27300, 1074, 8, 'Clients'),
(27301, 1075, 8, 'Clinique'),
(27302, 1076, 8, 'Copie Clinique'),
(27303, 1077, 8, 'Relevé quotidien Clinique'),
(27304, 1078, 8, 'Identification Clinique'),
(27305, 1079, 8, 'Clinique'),
(27306, 1080, 8, 'Règles de décision clinique, gestionnaire d''alertes'),
(27307, 1081, 8, 'Histoire du clinique'),
(27308, 1083, 8, 'Plans cliniques'),
(27309, 1084, 8, 'Mesures de qualité clinique (LCQ)'),
(27310, 1087, 8, 'Rappels cliniques'),
(27311, 1088, 8, 'Rapports cliniques'),
(27312, 1089, 8, 'Règle clinique, Catégorie d''action'),
(27313, 1090, 8, 'Règle clinique, Elément d''action'),
(27314, 1091, 8, 'Règle cliniques, méthodes de filtrage'),
(27315, 1092, 8, 'Règle cliniques, les méthodes cible'),
(27316, 1093, 8, 'Règles cliniques'),
(27317, 1094, 8, 'Règles cliniques, intervalles d''âge'),
(27318, 1095, 8, 'Règles cliniques, les comparaisons'),
(27319, 1096, 8, 'Règles cliniques, Types Rencontre'),
(27320, 1097, 8, 'Règles cliniques, Options cause de rappel'),
(27321, 1098, 8, 'Règles cliniques, Options inactivation de rappel'),
(27322, 1099, 8, 'Règles cliniques, Intervalles de rappel'),
(27323, 1100, 8, 'Règles cliniques, Méthodes de rappel'),
(27324, 1101, 8, 'Règles cliniques, Intervalles cible'),
(27325, 1102, 8, 'Objectifs cliniques'),
(27326, 1103, 8, 'Terme clinique'),
(27327, 1104, 8, 'Code(s) terme(s) clinique'),
(27328, 1106, 8, 'Cliniciens'),
(27329, 1107, 8, 'Clone'),
(27330, 1108, 8, 'Cloner la dernière visite'),
(27331, 1109, 8, 'Fermer'),
(27332, 1111, 8, 'Fermer la fenêtre'),
(27333, 1112, 8, 'Fermé'),
(27334, 1113, 8, 'cm'),
(27335, 1114, 8, 'Formulaire de remboursement de frais medicaux'),
(27336, 1118, 8, 'ID du formulaire de remboursement de frais medicaux'),
(27337, 1127, 8, 'CN2-12 intact'),
(27338, 1128, 8, 'ticket modérateur'),
(27339, 1129, 8, 'ticket réglé'),
(27340, 1130, 8, 'TICKET MODÉRATEUR'),
(27341, 1131, 8, 'Code'),
(27342, 1132, 8, 'code'),
(27343, 1133, 8, 'code Recherche'),
(27344, 1134, 8, 'Code doit être deux lettre en minuscule'),
(27345, 1135, 8, 'Code ou symbole pour indiquer la monnaie'),
(27346, 1136, 8, 'Texte du code'),
(27347, 1138, 8, 'type de code'),
(27348, 1141, 8, 'Types de code'),
(27349, 1142, 8, 'Code(s)'),
(27350, 1144, 8, 'Codes'),
(27351, 1145, 8, 'Codage'),
(27352, 1147, 8, 'Codage - toutes rencontres (par écrit, avec quelques options)'),
(27353, 1148, 8, 'Codage - mes rencontres (par écrit, avec quelques options)'),
(27354, 1149, 8, 'Codification Non autorisé'),
(27355, 1150, 8, 'Café'),
(27356, 1152, 8, 'Coassurance'),
(27357, 1154, 8, 'Réduire'),
(27358, 1155, 8, 'réduire'),
(27359, 1156, 8, 'Réduire tout'),
(27360, 1157, 8, 'Réduire tout'),
(27361, 1158, 8, 'réduire tout'),
(27362, 1160, 8, 'Date de collection'),
(27363, 1161, 8, 'Collections'),
(27364, 1162, 8, 'Rapport de Collections'),
(27365, 1163, 8, 'Cancer du côlon'),
(27366, 1164, 8, 'Dépistage du cancer du côlon'),
(27367, 1165, 8, 'Chirurgie du cancer du colon'),
(27368, 1166, 8, 'Coloscopie'),
(27369, 1167, 8, 'coloscopie'),
(27370, 1168, 8, 'Couleur'),
(27371, 1169, 8, 'Couleur: Abrév'),
(27372, 1170, 8, 'Colonne'),
(27373, 1171, 8, 'colonnes'),
(27374, 1172, 8, 'Lots Combinés'),
(27375, 1173, 8, 'Virgule'),
(27376, 1174, 8, 'Commentaire'),
(27377, 1175, 8, 'Commentaires'),
(27378, 1176, 8, 'Commentaires ou recommandation pour ce résultat'),
(27379, 1177, 8, 'Entreprise Assurance Cie'),
(27380, 1178, 8, 'Valider les modifications'),
(27381, 1180, 8, 'Communications'),
(27382, 1182, 8, 'Société'),
(27383, 1183, 8, 'Nom de la société'),
(27384, 1184, 8, 'Compléter'),
(27385, 1186, 8, 'Terminé'),
(27386, 1188, 8, 'Terminé?'),
(27387, 1190, 8, 'Complications par Prestataire de services'),
(27388, 1191, 8, 'Les complications d''avortement'),
(27389, 1192, 8, 'Composants'),
(27390, 1193, 8, 'Système de commande Médical Assisté par Ordinateur'),
(27391, 1194, 8, 'Conclusions'),
(27392, 1199, 8, 'Configuration'),
(27393, 1200, 8, 'Export / Import de la Configuration'),
(27394, 1202, 8, 'Configurer Apache et LibreEHR pour utiliser des certificats SSL côté client.'),
(27395, 1203, 8, 'Configurer Apache pour utiliser les certificats SSL côté client'),
(27396, 1204, 8, 'Configurer Apache pour utiliser le protocole HTTPS.'),
(27397, 1205, 8, 'Configurez LibreEHR pour utiliser des certificats SSL côté client'),
(27398, 1208, 8, 'Confirmer la création du nouveau Patient'),
(27399, 1209, 8, 'Confirmer le Nouveau Passe'),
(27400, 1210, 8, 'Confirmer le Payement'),
(27401, 1214, 8, 'Congénitale'),
(27402, 1215, 8, 'Conjonctives, pupilles'),
(27403, 1217, 8, 'Connecteurs'),
(27404, 1218, 8, 'Constante'),
(27405, 1219, 8, 'nom de la constante'),
(27406, 1220, 8, 'Nom de la constante est vide'),
(27407, 1221, 8, 'constantes'),
(27408, 1222, 8, 'Constipation'),
(27409, 1223, 8, 'Constitutionnel'),
(27410, 1226, 8, 'Descriptif bref de la consultation'),
(27411, 1227, 8, 'Contact'),
(27412, 1228, 8, 'Email du Contact'),
(27413, 1229, 8, 'Adresse Email du contact'),
(27414, 1230, 8, 'Contactez EMR Direct pour vous abonner au service de messagerie phiMail Direct'),
(27415, 1231, 8, 'coordonnées'),
(27416, 1232, 8, 'Lentilles de contact'),
(27417, 1233, 8, 'Contacter pour l''intégration d''informations médicale, LLC à http://mi-squared.com pour le service d''échange de laboratoire'),
(27418, 1234, 8, 'Contacter pour l''intégration d''informations médicale, LLC à http://mi-squared.com ou ZH Healthcare à http://zhservices.com pour s''inscrire au service eRx'),
(27419, 1236, 8, 'Nom du contact'),
(27420, 1237, 8, 'Personne à contacter'),
(27421, 1239, 8, 'Numéro de téléphone'),
(27422, 1240, 8, 'Contacter ZMG, LCC (zmghealth@gmail.com) pour s''inscrire au service eRx'),
(27423, 1241, 8, 'contient au moins trois des quatre éléments suivants:'),
(27424, 1242, 8, 'Nom du conteneur de groupe'),
(27425, 1243, 8, 'Contenu'),
(27426, 1244, 8, 'contenu'),
(27427, 1245, 8, 'Contexte'),
(27428, 1246, 8, 'Nom de contexte ne peut être vides'),
(27429, 1247, 8, 'Continuer'),
(27430, 1248, 8, 'Document de Continuité des soins (CCD)'),
(27431, 1249, 8, 'Enregistrement de Continuité des soins (RCC)'),
(27432, 1251, 8, 'Contraception'),
(27433, 1252, 8, 'Problèmes de contraception'),
(27434, 1253, 8, 'Complication de la contraception (à préciser)'),
(27435, 1254, 8, 'Méthode contraceptive'),
(27436, 1255, 8, 'Produits contraceptifs'),
(27437, 1256, 8, 'Services contraceptifs déjà démarré'),
(27438, 1257, 8, 'Début des contraceptifs'),
(27439, 1258, 8, 'ID de Conrôle'),
(27440, 1259, 8, 'N° de Contrôle'),
(27441, 1261, 8, 'TICKET MODÉRATEUR'),
(27442, 1262, 8, 'Ticket modérateur'),
(27443, 1263, 8, 'Ticket modérateur'),
(27444, 1264, 8, 'Ticket modérateur non positif'),
(27445, 1266, 8, 'Tickets modérateurs'),
(27446, 1267, 8, 'MPOC'),
(27447, 1268, 8, 'Copier les pages dans carte du patient'),
(27448, 1269, 8, 'Copier les valeurs'),
(27449, 1270, 8, 'Copie du fichier de base de données. Cela va prendre un certain temps ...'),
(27450, 1271, 8, 'Avis Copyright'),
(27451, 1273, 8, 'Pontage de l''artère coronaire'),
(27452, 1274, 8, 'Greffe de pontage de l''artère coronaire'),
(27453, 1275, 8, 'Corrigé'),
(27454, 1277, 8, 'CouchDB'),
(27455, 1278, 8, 'Échec de la connexion CouchDB.'),
(27456, 1279, 8, 'Base de données CouchDB.'),
(27457, 1280, 8, 'Nom de base de données CouchDB.'),
(27458, 1281, 8, 'Hôte CouchDB.'),
(27459, 1282, 8, 'Nom d''hôte CouchDB.'),
(27460, 1283, 8, 'Log activé CouchDB.'),
(27461, 1284, 8, 'Mot de passe CouchDB.'),
(27462, 1285, 8, 'Numero de port CouchDB.'),
(27463, 1286, 8, 'Numero de port CouchDB.'),
(27464, 1288, 8, 'Nom d''utilisateur CouchDB.'),
(27465, 1289, 8, 'Toux'),
(27466, 1290, 8, 'Toux:'),
(27467, 1294, 8, 'Impossible de lire le fichier'),
(27468, 1296, 8, 'Impossible d''envoyer e-mail en raison d''un problème de serveur, '),
(27469, 1297, 8, 'Impossible d''envoyer e-mail en raison d''un problème de serveur, '),
(27470, 1298, 8, 'Impossible de créer le répertoire de sauvegarde:'),
(27471, 1299, 8, 'Impossible de supprimer le répertoire:'),
(27472, 1300, 8, 'Impossible de supprimer le fichier de sauvegarde ancienne:'),
(27473, 1301, 8, 'Impossible de supprimer l''ancien fichier d''exportation:'),
(27474, 1302, 8, 'Gestion de la coumadine - contrôle INR'),
(27475, 1304, 8, 'Psychothérapie'),
(27476, 1305, 8, 'Activités d''aide psychologique'),
(27477, 1306, 8, 'Formulaire d''envois à l''acceuil'),
(27478, 1307, 8, 'Envois à l''acceuil'),
(27479, 1308, 8, 'Pays'),
(27480, 1309, 8, 'Type de données Pays'),
(27481, 1310, 8, 'Liste des Pays'),
(27482, 1311, 8, 'Liste des Pays(ecriture, ajout seulement optionnel)'),
(27483, 1312, 8, 'Nom du pays devrait être représenté dans deux lettres. (Exemple: États-Unis c''est US)'),
(27484, 1313, 8, 'région'),
(27485, 1315, 8, 'Coupon'),
(27486, 1318, 8, 'CPT'),
(27487, 1319, 8, 'CPT Code'),
(27488, 1320, 8, 'CPT Codes'),
(27489, 1321, 8, 'CPT4 Procedure/Service'),
(27490, 1322, 8, 'CPTII Mesure des perfomances'),
(27491, 1323, 8, 'LCQ'),
(27492, 1324, 8, 'Craquements:'),
(27493, 1325, 8, 'Crème'),
(27494, 1326, 8, 'Créer un certificat SSL côté client pour chaque utilisateur ou ordinateur client.'),
(27495, 1327, 8, 'Créer un certificat SSL côté client pour un utilisateur ou un nom d''hôte client.'),
(27496, 1329, 8, 'Créer un événement'),
(27497, 1330, 8, 'Créer et télécharger une sauvegarde complète'),
(27498, 1332, 8, 'Créer une sauvegarde'),
(27499, 1333, 8, 'créer un lot'),
(27500, 1334, 8, 'Créer un certificat client'),
(27501, 1335, 8, 'Créer des certificats SSL côté client'),
(27502, 1336, 8, 'Créer un duplicata'),
(27503, 1338, 8, 'Créer une sauvegarde du journal d''événements'),
(27504, 1339, 8, 'Créer un nouveau problème'),
(27505, 1340, 8, 'Créer un nouveau patient'),
(27506, 1342, 8, 'Créer crédentiels pour un portail hors site'),
(27507, 1343, 8, 'Créer crédentiels pour un portail sur site'),
(27508, 1344, 8, 'Créer remarque patient'),
(27509, 1345, 8, 'Créer l''autorité de certification SSL et les certificats du serveur.'),
(27510, 1346, 8, 'Créer Visite'),
(27511, 1347, 8, 'Créé'),
(27512, 1348, 8, 'Préparation du fichier d''exportation'),
(27513, 1350, 8, 'La création de ce fichier sur l''hôte distant a échoué'),
(27514, 1351, 8, 'Créateur'),
(27515, 1352, 8, 'Crédit'),
(27516, 1353, 8, 'Carte de crédit'),
(27517, 1354, 8, 'Crédits'),
(27518, 1356, 8, 'Critère'),
(27519, 1358, 8, 'Maladie de Crohn'),
(27520, 1359, 8, 'Maladie de Crohn'),
(27521, 1360, 8, 'Exportation au format CSV'),
(27522, 1361, 8, 'Fichier CSV'),
(27523, 1362, 8, 'Table CSV'),
(27524, 1363, 8, 'Millimètre cube'),
(27525, 1364, 8, 'Cubain'),
(27526, 1365, 8, 'Nombre de décimales'),
(27527, 1366, 8, 'Symbole de décimales'),
(27528, 1367, 8, 'Désignateur de devise'),
(27529, 1368, 8, 'Séparateur des milliers'),
(27530, 1369, 8, 'Actuelle'),
(27531, 1370, 8, 'Alcool actuelle'),
(27532, 1371, 8, 'Consultation actuelle'),
(27533, 1372, 8, 'Critère actuel'),
(27534, 1373, 8, 'Couleur d''accentuation pour le jour courant'),
(27535, 1374, 8, 'Fumeur quotidien actif'),
(27536, 1375, 8, 'Nom du fichier courant a ét changé pour'),
(27537, 1376, 8, 'Hachage actuelle'),
(27538, 1377, 8, 'Adresse actuelle'),
(27539, 1378, 8, 'Médicaments en vigeur'),
(27540, 1379, 8, 'Mot de passe en vigeur'),
(27541, 1380, 8, 'Patient en cours'),
(27542, 1382, 8, 'Drogues actuelles'),
(27543, 1383, 8, 'Fumeur occasionnel'),
(27544, 1386, 8, 'Actif actuellement'),
(27545, 1387, 8, 'En cours d''exécution'),
(27546, 1388, 8, 'Actuellement, il n''existe uncune installation.'),
(27547, 1389, 8, 'Syndrome de Cushing'),
(27548, 1390, 8, 'Syndrome de Cushing'),
(27549, 1392, 8, 'Personalisé'),
(27550, 1393, 8, 'Entrée personnalisée?'),
(27551, 1394, 8, 'Table personnalisée'),
(27552, 1396, 8, 'Code CVX'),
(27553, 1397, 8, 'Mappage code CVX'),
(27554, 1398, 8, 'Immunisation CVX'),
(27555, 1399, 8, 'Cycle'),
(27556, 1403, 8, 'Tchèque'),
(27557, 1404, 8, 'D'),
(27558, 1405, 8, 'D&C'),
(27559, 1406, 8, 'D&E'),
(27560, 1407, 8, 'D.D.N'),
(27561, 1408, 8, 'quotidien'),
(27562, 1409, 8, 'Relevé quotidien'),
(27563, 1410, 8, 'Danois'),
(27564, 1411, 8, 'Données similaires sont déjà en base de données,veuillez change le code et/ou la description'),
(27565, 1412, 8, 'Données similaires sont déjà en base de données, veuillez changer le nom de la constante'),
(27566, 1413, 8, 'données Cols'),
(27567, 1416, 8, 'Erreur de données'),
(27568, 1420, 8, 'Type de données'),
(27569, 1421, 8, 'Base de Données'),
(27570, 1422, 8, 'Base de Données non installée'),
(27571, 1423, 8, 'Correction de base de données'),
(27572, 1424, 8, 'Rapports de la Base de données'),
(27573, 1425, 8, 'Mise à niveau Base de Données términée.'),
(27574, 1426, 8, 'DataCols doit être un nombre entre 1 et 999'),
(27575, 1427, 8, 'Date'),
(27576, 1428, 8, 'DATE'),
(27577, 1429, 8, 'Date & heure Administré'),
(27578, 1431, 8, 'Date d''administration'),
(27579, 1432, 8, 'Date et heure du prélèvement'),
(27580, 1433, 8, 'Date et heure de cette observation'),
(27581, 1435, 8, 'Date et heure auxquelles le prélèvement a été recueilli'),
(27582, 1436, 8, 'Date ne peut être supérieure à Aujourd''hui'),
(27583, 1437, 8, 'Date de services de contraception initialement prévu'),
(27584, 1438, 8, 'Date de création'),
(27585, 1439, 8, 'Date de décès'),
(27586, 1440, 8, 'Date de déstruction'),
(27587, 1441, 8, 'Format d''affichage des dates'),
(27588, 1442, 8, 'Format de la date de "fin de rendez-vous" n''est pas valide'),
(27589, 1443, 8, 'Format de la date de "début du rendez-" n''est pas valide'),
(27590, 1444, 8, 'Format de date pour "Prochain rendez-vous" n''est pas valide'),
(27591, 1445, 8, 'Format de la date de "jamais vu depuis" n''est pas valide'),
(27592, 1446, 8, 'Format de date pour "vu depuis" n''est pas valide'),
(27593, 1447, 8, 'Date de vaccination des déclarations de l''information tenu'),
(27594, 1448, 8, 'Manque la Date pour le code '),
(27595, 1449, 8, 'Date de Critère principal'),
(27596, 1450, 8, 'Date de dépôt bancaire aaaa-mm-jj'),
(27597, 1451, 8, 'Date de facturation'),
(27598, 1452, 8, 'Date de naissance'),
(27599, 1453, 8, 'Date de naissance'),
(27600, 1454, 8, 'Date de naissance'),
(27601, 1455, 8, 'Date d''entrée'),
(27602, 1456, 8, 'Date de l''accident'),
(27603, 1458, 8, 'Date de paiement aaaa-mm-jj'),
(27604, 1459, 8, 'Date de saisine'),
(27605, 1460, 8, 'Date de réponse'),
(27606, 1461, 8, 'Date du rapport'),
(27607, 1462, 8, 'Date du service'),
(27608, 1463, 8, 'Date du service'),
(27609, 1464, 8, 'Date du service = Aujourd''hui'),
(27610, 1465, 8, 'Date du service mm/jj/aaaa'),
(27611, 1466, 8, 'Date du service:'),
(27612, 1467, 8, 'Date de signature'),
(27613, 1468, 8, 'Date de changement de statut'),
(27614, 1469, 8, 'Date de cette commande'),
(27615, 1470, 8, 'Date du présent rapport'),
(27616, 1471, 8, 'Date de déclaration VIS'),
(27617, 1472, 8, 'Date de commande'),
(27618, 1475, 8, 'Sélecteur de Date'),
(27619, 1476, 8, 'Date d''envoi'),
(27620, 1477, 8, 'Date de l''envoi du message'),
(27621, 1479, 8, 'La date ne peut être vide.'),
(27622, 1480, 8, 'Date/Appt'),
(27623, 1481, 8, 'Date/Notes'),
(27624, 1482, 8, 'Date/Notes de dernière'),
(27625, 1483, 8, 'Date/Heure'),
(27626, 1484, 8, 'Date:'),
(27627, 1485, 8, 'Journal des messages daté'),
(27628, 1486, 8, 'Jour'),
(27629, 1487, 8, 'jour'),
(27630, 1489, 8, 'Vue quotidienne'),
(27631, 1490, 8, 'Jour(s)'),
(27632, 1491, 8, 'Jour(s) M-F'),
(27633, 1492, 8, 'jours'),
(27634, 1493, 8, 'Jours'),
(27635, 1494, 8, 'jours avant'),
(27636, 1495, 8, 'Jours et Jeux manqués'),
(27637, 1496, 8, 'Jours depuis dernière Rencontre'),
(27638, 1497, 8, 'jours manqués'),
(27639, 1498, 8, 'Jours par colonne:'),
(27640, 1500, 8, 'Jours/Col:'),
(27641, 1501, 8, 'BD installée'),
(27642, 1502, 8, 'JJ/MM/AAAA'),
(27643, 1503, 8, 'Dés-identification'),
(27644, 1504, 8, 'Processus de dés-identification est terminé'),
(27645, 1505, 8, 'Processus de dés-identification est en cours'),
(27646, 1506, 8, 'Processus de dés-identification est démarré et s''exécute en arrière-plan'),
(27647, 1507, 8, 'Données dépersonnalisées peuvent ne pas être complète'),
(27648, 1508, 8, 'Fichiers dés-identification seront sauvegardés dans'),
(27649, 1509, 8, 'DEA'),
(27650, 1511, 8, 'Sourd'),
(27651, 1512, 8, 'informations de débogage'),
(27652, 1514, 8, 'débogage'),
(27653, 1515, 8, 'Dec.'),
(27654, 1516, 8, 'Décédé'),
(27655, 1517, 8, 'Décembre'),
(27656, 1518, 8, 'Livres décimales ou livres et onces séparés par #(i.e. 5#4)'),
(27657, 1520, 8, 'Déductible'),
(27658, 1522, 8, 'Par défaut'),
(27659, 1523, 8, 'Afficher Calendrier par défaut'),
(27660, 1524, 8, 'ID formulaire par défaut des Rencontres'),
(27661, 1526, 8, 'Facilité par défaut'),
(27662, 1527, 8, 'Langue par défaut'),
(27663, 1528, 8, 'Langue par défaut si aucune autre n''est autorisé ou choisi.'),
(27664, 1529, 8, 'Liste par défaut (écrire, ajouter seulement en option)'),
(27665, 1530, 8, 'Méthode par défaut'),
(27666, 1531, 8, 'Délai en Jours d''expiration du mot de passe par défaut'),
(27667, 1532, 8, 'Période d''expiration par défaut du mot de passe en jours. 0 signifie que cette fonctionnalité est désactivée.'),
(27668, 1533, 8, 'Pays par defaut du patient'),
(27669, 1535, 8, 'Priorité par defaut'),
(27670, 1536, 8, 'Fournisseur par défaut'),
(27671, 1537, 8, 'Plage par défaut'),
(27672, 1538, 8, 'Motif de la visite par défaut'),
(27673, 1540, 8, 'Paramètre par défaut'),
(27674, 1541, 8, 'État par défault de la nouvelle fenètre de checkbox dans la liste des patients'),
(27675, 1542, 8, 'Modèle par défaut'),
(27676, 1546, 8, 'Unités par défaut'),
(27677, 1547, 8, 'Valeur par défaut'),
(27678, 1548, 8, 'Entrepôt par défaut'),
(27679, 1549, 8, 'Partenaire X12 par défaut'),
(27680, 1550, 8, 'Défaut / Global'),
(27681, 1551, 8, 'Sup.'),
(27682, 1552, 8, 'sup.'),
(27683, 1553, 8, 'Pecurrence différée (> 12 Mo)'),
(27684, 1554, 8, 'Supprimer'),
(27685, 1555, 8, 'supprimer'),
(27686, 1556, 8, 'Supprimer les catégories avec ID(s): '),
(27687, 1557, 8, 'Supprimer Catégorie'),
(27688, 1559, 8, 'Echec de suppression!'),
(27689, 1560, 8, 'Supprimer groupe'),
(27690, 1561, 8, 'Supprimer liste'),
(27691, 1562, 8, 'Supprimer des pages'),
(27692, 1563, 8, 'Supprimer Patient, Rencontre, formulaire, Problème, Document, Paiement, Facturation ou Transaction'),
(27693, 1565, 8, 'Supprimer ligne'),
(27694, 1566, 8, 'Supprimer éléments sélectionnés'),
(27695, 1568, 8, 'Suppression avec succès.'),
(27696, 1569, 8, 'Supprimer ce document'),
(27697, 1570, 8, 'Supprimer ce formulaire'),
(27698, 1571, 8, 'Supprimer cette note'),
(27699, 1573, 8, 'Supprimé avec succès.'),
(27700, 1574, 8, 'Suppression en cours'),
(27701, 1575, 8, 'La suppression de cet événement ne peut être annulée. Il ne peut pas être récupéré une fois qu''il est effacé. Etes-vous sûr de vouloir supprimer cet événement?'),
(27702, 1576, 8, 'Livraison Confirmé'),
(27703, 1578, 8, 'La livraison n''est pas actuellement autorisé à l''adresse directe indiquée.'),
(27704, 1580, 8, 'Livraison du document clinique ci-joint a été demandé par le patient.'),
(27705, 1581, 8, 'Démence'),
(27706, 1582, 8, 'Données démographiques'),
(27707, 1583, 8, 'Données démographiques (écriture, ajouter seulement en option)'),
(27708, 1585, 8, 'Données démographiques critères de recherche'),
(27709, 1586, 8, 'Données démographiques non autorisés'),
(27710, 1587, 8, 'Données démographiques non autorisés.'),
(27711, 1588, 8, 'Refusé'),
(27712, 1589, 8, 'Dénominateur'),
(27713, 1590, 8, 'Dentaire'),
(27714, 1591, 8, 'Liste des problèmes dentaire'),
(27715, 1592, 8, 'Problèmes dentaires'),
(27716, 1595, 8, 'Selon le type de facture que vous testez, vous verrez une sortie similaire à HCFA sur une page vierge pour les factures HCFA, vous verrez de nombreuses lignes de texte et information quelque peu déformé si vous testez une réclamation X12. Ce texte déformé est le format X12 EDI 4010A. Occasionnellement, vous verrez caractères étranges qui ressemblent aux dominos ou tildes, ce sont les caractères de contrôle tels que les sauts de page et sont normales.'),
(27717, 1596, 8, 'date de dépôt'),
(27718, 1597, 8, 'La date de dépôt ne peut pas être supérieur à Aujourd''hui'),
(27719, 1598, 8, 'Date de dépôt:'),
(27720, 1599, 8, 'Déprimé'),
(27721, 1600, 8, 'Dépression'),
(27722, 1602, 8, 'Description'),
(27723, 1603, 8, 'description'),
(27724, 1605, 8, 'Description de la divulgation'),
(27725, 1606, 8, 'Description de cette procédure ou le code résultat'),
(27726, 1607, 8, 'Traduction de la description'),
(27727, 1609, 8, 'Destination'),
(27728, 1610, 8, 'Nom du fichier destination'),
(27729, 1611, 8, 'Détruire lot'),
(27730, 1612, 8, 'Détruire...'),
(27731, 1613, 8, 'Détruite'),
(27732, 1614, 8, 'Médicaments détruits'),
(27733, 1615, 8, 'Rapport de destruction des Médicaments'),
(27734, 1616, 8, 'Détail'),
(27735, 1617, 8, 'Détails'),
(27736, 1619, 8, 'Anomalie de développement'),
(27737, 1620, 8, 'Diabètes'),
(27738, 1621, 8, 'Diabètes sucrées'),
(27739, 1622, 8, 'Diabètes: gestion de la pression artérielle (LCQ)'),
(27740, 1623, 8, 'Diabètes: examen de la vue'),
(27741, 1624, 8, 'Diabètes: examen des yeux (LCQ)'),
(27742, 1625, 8, 'Diabètes: examen des pieds'),
(27743, 1626, 8, 'Diabètes: examen des pieds (LCQ)'),
(27744, 1627, 8, 'Diabètes: Faible contrôle HbA1c (LCQ)'),
(27745, 1628, 8, 'Diabètes: Hémoglobine A1C'),
(27746, 1629, 8, 'Diabètes: Gestion et de contrôle LDL (LCQ)'),
(27747, 1630, 8, 'Diabètes: Microalbumine urinaire'),
(27748, 1631, 8, 'Diagnostic'),
(27749, 1632, 8, 'Diagnostics'),
(27750, 1633, 8, 'Diagnostic'),
(27751, 1634, 8, 'Code diagnostic'),
(27752, 1636, 8, 'Date du diagnostic'),
(27753, 1637, 8, 'Le diagnostic doit être codé en une rencontre liée'),
(27754, 1638, 8, 'Nom du Diagnostic'),
(27755, 1639, 8, 'Rapport de diagnostic'),
(27756, 1640, 8, 'Rapports de diagnostic'),
(27757, 1641, 8, 'Rapports de diagnostic seulement'),
(27758, 1642, 8, 'Titre du Diagnostic'),
(27759, 1643, 8, 'Diagnostic:'),
(27760, 1644, 8, 'Diagnostic: '),
(27761, 1645, 8, 'Tests de diagnostic:'),
(27762, 1646, 8, 'Cadrans'),
(27763, 1647, 8, 'Diaphragmes / Casquettes'),
(27764, 1648, 8, 'Diarrhée'),
(27765, 1650, 8, 'Dictée'),
(27766, 1651, 8, 'Dictée: '),
(27767, 1652, 8, 'Avez-vous reçu une copie de l''avis HIPAA?'),
(27768, 1653, 8, 'Diffuse:'),
(27769, 1654, 8, 'Signé numériquement'),
(27770, 1657, 8, 'Publipostage direct'),
(27771, 1658, 8, 'Messsage de log direct'),
(27772, 1659, 8, 'Message reçu direct'),
(27773, 1660, 8, 'Le système de messagerie direct est actuellement indisponible'),
(27774, 1661, 8, 'Echec du système d''envois de message direct'),
(27775, 1663, 8, 'Nom du Directeur'),
(27776, 1664, 8, 'Echet de la suppréssion du répertoire; continuer.'),
(27777, 1665, 8, 'Handicap'),
(27778, 1667, 8, 'Désactiver le calendrier'),
(27779, 1668, 8, 'Désactiver Graphique Suivi'),
(27780, 1669, 8, 'Désactiver Vaccination'),
(27781, 1670, 8, 'Désactiver Formulaire Ancien métrique des signes vitaux'),
(27782, 1672, 8, 'Désactiver phpMyAdmin'),
(27783, 1673, 8, 'Désactiver Prescriptions'),
(27784, 1674, 8, 'Désactiver Groupes d''utilisateurs'),
(27785, 1675, 8, 'handicapé'),
(27786, 1676, 8, 'Handicapé'),
(27787, 1677, 8, 'Bénéficiaire handicapés de moins de 65 ans avec l''allocation de solidarité'),
(27788, 1678, 8, 'DISQUE'),
(27789, 1681, 8, 'Refoulement'),
(27790, 1682, 8, 'Refoulement de l''urètre'),
(27791, 1684, 8, 'Refoulement à droite'),
(27792, 1685, 8, 'Refoulement à droite:'),
(27793, 1688, 8, 'Déchargé'),
(27794, 1689, 8, 'Divulgation info'),
(27795, 1690, 8, 'Type de divulgation'),
(27796, 1691, 8, 'Types de divulgation'),
(27797, 1692, 8, 'Divulgations'),
(27798, 1694, 8, 'Remise'),
(27799, 1695, 8, 'Montant de remise'),
(27800, 1696, 8, 'Niveau de remise'),
(27801, 1697, 8, 'Taux de remise'),
(27802, 1698, 8, 'Réductions au montant en numéraire'),
(27803, 1699, 8, 'Réductions au moment du contrôle sont entrés comme montants, par opposition au pourcentage.'),
(27804, 1700, 8, 'Résultat discret'),
(27805, 1701, 8, 'Maladie'),
(27806, 1702, 8, 'Luxation'),
(27807, 1703, 8, 'Disp #'),
(27808, 1704, 8, 'Expédition'),
(27809, 1705, 8, 'Document expédié reçu'),
(27810, 1706, 8, 'Distribué'),
(27811, 1707, 8, 'Afficher les pré-arrangements dans l''écran démographie'),
(27812, 1709, 8, 'Afficher les dates d''évènements dans le bloc?'),
(27813, 1710, 8, 'Format d''affichage des poids des États-Unis'),
(27814, 1711, 8, 'Afficher combien d''évènements'),
(27815, 1713, 8, 'Afficher l''adresse dans le bloc'),
(27816, 1714, 8, 'Afficher le nom'),
(27817, 1715, 8, 'Afficher le calendrier?'),
(27818, 1718, 8, 'Afficher dans le bloc les évènements du jour?'),
(27819, 1719, 8, 'Afficher dans le bloc les sujets?'),
(27820, 1720, 8, 'Afficher dans le bloc les évènements à venir?'),
(27821, 1721, 8, 'Colonnes visibles'),
(27822, 1722, 8, 'Passer au numéro suivant de la liste des divulgations récentes:'),
(27823, 1723, 8, 'Passer au numéro suivant de la liste de notes récentes'),
(27824, 1724, 8, 'Passer au numéro suivant de la liste de notes récentes:'),
(27825, 1725, 8, 'Distribution'),
(27826, 1726, 8, 'Distributions'),
(27827, 1727, 8, 'Distributeur'),
(27828, 1729, 8, 'Sigmoïdite'),
(27829, 1730, 8, 'Chirurgie pour la sigmoïdite'),
(27830, 1731, 8, 'Diverticulite'),
(27831, 1732, 8, 'Chirurgie pour la diverticulite'),
(27832, 1733, 8, 'Divorcé'),
(27833, 1734, 8, 'Vertiges:'),
(27834, 1735, 8, 'Ne pas modifier'),
(27835, 1737, 8, 'Ne pas afficher Allergie téléchargés à NewCrop'),
(27836, 1739, 8, 'Ne pas afficher Médicament téléchargés à NewCrop'),
(27837, 1742, 8, 'Ne pas afficher le calendrier.'),
(27838, 1744, 8, 'Pas d''inventaire et vente de produits'),
(27839, 1745, 8, 'Ne nécessite pas une autorisation écrite du patient'),
(27840, 1746, 8, 'Prescription de non-réanimation'),
(27841, 1747, 8, 'ne pas enregistrer'),
(27842, 1748, 8, 'ne pas substituer'),
(27843, 1749, 8, 'ne rien faire'),
(27844, 1751, 8, 'Voulez-vous vraiment supprimer'),
(27845, 1752, 8, 'Voulez-vous vraiment supprimer la sélection?'),
(27846, 1753, 8, 'Voulez-vous vraiment supprimer ce groupe'),
(27847, 1755, 8, 'Voulez-vous continuer?'),
(27848, 1756, 8, 'Voulez-vous supprimer cet élément?'),
(27849, 1757, 8, 'Voulez-vous supprimer?'),
(27850, 1758, 8, 'Voulez-vous supprimer cet enregistrement?'),
(27851, 1759, 8, 'Vous désirez continuer l''ajout de ce nouveau patient?'),
(27852, 1760, 8, 'Vous désirez continuer sous le nouveau nom?'),
(27853, 1761, 8, 'Vous désirez supprimer DEFINITIVEMENT ce dossier de vaccination?'),
(27854, 1762, 8, 'DDN'),
(27855, 1763, 8, 'La date des naissance est manquante, fournir si disponible'),
(27856, 1764, 8, 'Documents'),
(27857, 1765, 8, 'Médecin'),
(27858, 1766, 8, 'Médecin:'),
(27859, 1767, 8, 'Nom du médecin et signature'),
(27860, 1768, 8, 'Document'),
(27861, 1769, 8, 'document'),
(27862, 1770, 8, 'Catégories document'),
(27863, 1775, 8, 'Document ne peut être attaché à l''identification du patient'),
(27864, 1777, 8, 'Date du document'),
(27865, 1778, 8, 'Date et version du document modifiés avec succès'),
(27866, 1779, 8, 'Nº du document'),
(27867, 1780, 8, 'Document déplacé vers la nouvelle catégorie'),
(27868, 1781, 8, 'Document attaché à l''identification du patient'),
(27869, 1783, 8, 'Vérification d''intégrité du Document passé.'),
(27870, 1784, 8, 'Méthode de stockage de documents'),
(27871, 1785, 8, 'Document renommé avec succès.'),
(27872, 1790, 8, 'Lieu Document/Imagerie'),
(27873, 1791, 8, 'Documents'),
(27874, 1792, 8, 'Documents (écriture, ajout seulement optionnel)'),
(27875, 1794, 8, 'Date d''entrée'),
(27876, 1796, 8, 'Ne correspond pas au nombre de rencontre PV1'),
(27877, 1797, 8, 'Ne semble pas valide'),
(27878, 1798, 8, 'Est-ce que ce type permet codes connexes?'),
(27879, 1799, 8, 'Partenaire domestique'),
(27880, 1800, 8, 'Ne pas sauvegarder'),
(27881, 1801, 8, 'Ne pas sauvegarder'),
(27882, 1802, 8, 'Ne pas sauvegarder les changements'),
(27883, 1803, 8, 'Terminé'),
(27884, 1804, 8, 'Effectué avec:'),
(27885, 1805, 8, 'Terminé. Envoi du téléchargement'),
(27886, 1806, 8, 'DOS'),
(27887, 1807, 8, 'Posologie'),
(27888, 1809, 8, 'Double-cliquez pour éditer'),
(27889, 1810, 8, 'Vision Double'),
(27890, 1811, 8, 'Télécharger'),
(27891, 1814, 8, 'Télécharger dans tout les cas'),
(27892, 1815, 8, 'Télécharger la facturation, la posté à la comptabilité la marquer comme facturé'),
(27893, 1817, 8, 'Télécharger les certificats'),
(27894, 1818, 8, 'Télécharger les données de configuration'),
(27895, 1820, 8, 'télécharger le fichier crypté'),
(27896, 1825, 8, 'Télécharger le PDF'),
(27897, 1827, 8, 'Télécharger les déclarations sélectionnées'),
(27898, 1828, 8, 'Contrôle du Dr'),
(27899, 1829, 8, 'Visite du Dr'),
(27900, 1830, 8, 'Dr'),
(27901, 1831, 8, 'Glissez pour déplacer'),
(27902, 1832, 8, 'Bavements'),
(27903, 1833, 8, 'Permis de conduire ou de N° Identification'),
(27904, 1834, 8, 'Médicament'),
(27905, 1835, 8, 'Chercheur de médicaments'),
(27906, 1836, 8, 'Formes médicamenteuse'),
(27907, 1837, 8, 'ID du médicament manquant!'),
(27908, 1838, 8, 'Intervale des prises de médicament'),
(27909, 1839, 8, 'Inventaire des médicaments'),
(27910, 1840, 8, 'Nom du médicament'),
(27911, 1841, 8, 'Voies du médicament'),
(27912, 1845, 8, 'Unités du médicament'),
(27913, 1846, 8, 'Médicaments'),
(27914, 1847, 8, 'Produits et Médicaments'),
(27915, 1848, 8, 'Bouche sèche'),
(27916, 1849, 8, 'Diagnostique DSMIV'),
(27917, 1850, 8, 'DT 1'),
(27918, 1851, 8, 'DT 2'),
(27919, 1852, 8, 'DT 3'),
(27920, 1853, 8, 'DT 4'),
(27921, 1854, 8, 'DT 5'),
(27922, 1855, 8, 'DTaP 1'),
(27923, 1856, 8, 'DTaP 2'),
(27924, 1857, 8, 'DTaP 3'),
(27925, 1858, 8, 'DTaP 4'),
(27926, 1859, 8, 'DTaP 5'),
(27927, 1860, 8, 'Échéance'),
(27928, 1861, 8, 'Date d''échéance'),
(27929, 1862, 8, 'Date d''échéance mm/jj/aaaa ou aaaa-mm-jj'),
(27930, 1863, 8, 'Date d''échéance:'),
(27931, 1864, 8, 'Échéance de l''assurance'),
(27932, 1865, 8, 'Échéance du patient'),
(27933, 1866, 8, 'Échéance prochaine'),
(27934, 1867, 8, 'Etat échéance'),
(27935, 1868, 8, 'Mise à jour de Etat échéance'),
(27936, 1869, 8, 'Dumping de la base de données LibreEHR'),
(27937, 1870, 8, 'Dumping de l''arborescence web LibreEHR'),
(27938, 1871, 8, 'Dumping de la base de données phpGACL'),
(27939, 1872, 8, 'Dumping de l''arborescence web phpGACL'),
(27940, 1873, 8, 'Dumping de la base de données SQL-Ledger'),
(27941, 1874, 8, 'Dumping de l''arborescence web SQL-Ledger'),
(27942, 1875, 8, 'Vérifiez Dup'),
(27943, 1876, 8, 'Numéro ID dupliqué sur la ligne'),
(27944, 1877, 8, 'Nom dupliqué sur la ligne'),
(27945, 1878, 8, 'AVERTISSEMENT DUPLICATION'),
(27946, 1879, 8, 'Procuration durable'),
(27947, 1880, 8, 'durée'),
(27948, 1881, 8, 'Durée'),
(27949, 1882, 8, 'Hollandais'),
(27950, 1883, 8, 'Dx Rep'),
(27951, 1884, 8, 'Dysphagie'),
(27952, 1885, 8, 'Dyspnée:'),
(27953, 1886, 8, 'Dysurie'),
(27954, 1888, 8, 'Préscription électronique'),
(27955, 1889, 8, 'Rapports électronique'),
(27956, 1890, 8, 'Prescription électronique'),
(27957, 1892, 8, 'Renouvellement e-Rx'),
(27958, 1893, 8, 'Chaque destinataire doit marquer ses propre messages comme terminés.'),
(27959, 1894, 8, 'Récidive précoce (<2 Mo)'),
(27960, 1895, 8, 'Oreilles'),
(27961, 1896, 8, 'ECG'),
(27962, 1897, 8, 'Réclamations électronique'),
(27963, 1898, 8, 'Œdème'),
(27964, 1899, 8, 'Historique EDI'),
(27965, 1900, 8, 'Historique EDI'),
(27966, 1901, 8, 'Historique (sous honoraires) EDI pour le stockage et l''interprétation des fichiers de réponse au revendications EDI'),
(27967, 1902, 8, 'EDI-271 Fichier Upload'),
(27968, 1903, 8, 'EDI-271 Fichier Réponse Upload'),
(27969, 1904, 8, 'Editer'),
(27970, 1905, 8, 'éditer'),
(27971, 1906, 8, 'Editer les Allergies'),
(27972, 1907, 8, 'Editer les Catégories'),
(27973, 1908, 8, 'Editer les Définitions'),
(27974, 1909, 8, 'Editer les définitions'),
(27975, 1910, 8, 'Editer les Diagnostics pour'),
(27976, 1911, 8, 'Editer Divulgation'),
(27977, 1912, 8, 'Editer les Services'),
(27978, 1913, 8, 'Editer Facilité'),
(27979, 1914, 8, 'Editer les informations de Service'),
(27980, 1916, 8, 'Editer le fichier de'),
(27981, 1917, 8, 'Editer la forme'),
(27982, 1918, 8, 'Editer les paramètres globaux'),
(27983, 1919, 8, 'Modification non autorisée!'),
(27984, 1920, 8, 'Editer mise en page'),
(27985, 1921, 8, 'Editer la liste'),
(27986, 1922, 8, 'Editer paiement'),
(27987, 1923, 8, 'Editer la structure'),
(27988, 1924, 8, 'Editer l''utilisateur'),
(27989, 1925, 8, 'Editer les paramètres de l''utilisateur'),
(27990, 1928, 8, 'Education'),
(27991, 1929, 8, 'Date Education'),
(27992, 1931, 8, 'Voir la Licence * GNU GPL pour plus de détails. * * Vous devriez avoir reçu une copie de la Licence Publique Générale GNU * avec ce programme, sinon, écrivez à Free '),
(27993, 1932, 8, 'Date d''effet'),
(27994, 1934, 8, 'Efficacité'),
(27995, 1935, 8, 'EIN'),
(27996, 1936, 8, 'Ejaculations'),
(27997, 1937, 8, 'Coude'),
(27998, 1938, 8, 'Problèmes de coude'),
(27999, 1939, 8, 'Electronique'),
(28000, 1942, 8, 'Versements électroniques'),
(28001, 1943, 8, 'Rapports électroniques'),
(28002, 1944, 8, 'Admissibilité'),
(28003, 1945, 8, 'Admissibilité 270 enquête globale'),
(28004, 1946, 8, 'Réponse d''Admissibilité'),
(28005, 1947, 8, 'Status de l''autorisation pour vacciner des enfants avec les vaccins fournient'),
(28006, 1948, 8, 'Admissible'),
(28007, 1949, 8, 'Courriel'),
(28008, 1951, 8, 'Courriel'),
(28009, 1953, 8, 'L''adresse de réponse pour les courriels de rappel envoyés aux patients. Les réponses des patientes à leur courriel de rappel seront envoyés à cette adresse. Il est important d''utiliser une adresse de réponse qui fait partie du domaine de votre clinique afin d''empêcher que les réponses de vos patients ne sont retrouvent classées parmi les pourriels.'),
(28010, 1954, 8, 'Courriel, si disponible, pour recevoir les messages administratifs.'),
(28011, 1955, 8, 'Courriel, si disponible, pour recevoir l''activation d''urgence des login des usagers'),
(28012, 1956, 8, 'Authentifiant courriel'),
(28013, 1957, 8, 'Email du Batchcom'),
(28014, 1958, 8, 'Notification courriel'),
(28015, 1959, 8, 'Heures de la notification courriel'),
(28016, 1960, 8, 'Rapport de la notification courriel'),
(28017, 1961, 8, 'Envoyer le mail avant'),
(28018, 1962, 8, 'Expéditeur');
INSERT INTO `lang_definitions` VALUES
(28019, 1963, 8, 'Message envoyé'),
(28020, 1964, 8, 'Message envoyé à'),
(28021, 1965, 8, 'Sujet de l''email'),
(28022, 1968, 8, 'Methode de transport du courriel'),
(28023, 1969, 8, 'Email a été envoyé à l''adresse suivante'),
(28024, 1971, 8, 'Contact d''urgence'),
(28025, 1972, 8, 'Personne à contacter en cas d''urgence'),
(28026, 1973, 8, 'Numéro de téléphone du contact d''urgence'),
(28027, 1974, 8, 'Contraception d''urgence'),
(28028, 1975, 8, 'Identifiant d''urgence'),
(28029, 1976, 8, 'Le login d''urgence ACL est choisis. L''utilisateur est encore dans un état actif, s''il vous plait désactivez l''utilisateur et réactivez le même en cas de situations d''urgence. Visitez Adminstration->Utilisateurs pour les activations et désactivations.'),
(28030, 1977, 8, 'L''activation par courriel du login d''urgence sera envoyé uniquement si les paramètres suivant du fichier interface/globals.php sont configuré:'),
(28031, 1978, 8, 'Courriel du login d''urgence'),
(28032, 1979, 8, 'Le login d''urgence peut tout faire'),
(28033, 1980, 8, 'Téléphone d''urgence'),
(28034, 1981, 8, 'Conditions et complications émotionnelles et comportementalles'),
(28035, 1982, 8, 'Emphysème'),
(28036, 1983, 8, 'Employé(e)'),
(28037, 1984, 8, 'Employeur'),
(28038, 1985, 8, 'Adresse de l''employeur'),
(28039, 1986, 8, 'Information sur l''employeur'),
(28040, 1987, 8, 'Nom de l''employeur'),
(28041, 1988, 8, 'VIDE'),
(28042, 1989, 8, 'vide'),
(28043, 1990, 8, 'Mot de passe vide non autorisé'),
(28044, 1991, 8, 'Aucune données pour "Horaire de courriel"'),
(28045, 1992, 8, 'Aucune entrée pour "Expéditeur du courrier"'),
(28046, 1993, 8, 'Aucune entrée pour "Sujet du courrier"'),
(28047, 1994, 8, 'Aucune entrée pour "Texte du courrier"'),
(28048, 1995, 8, 'Aucune entrée pour "Nom du dispensateur"'),
(28049, 1996, 8, 'Aucune entrée pour "Mot de passe"'),
(28050, 1997, 8, 'Aucune entrée pour "Expéditeur du courrier"'),
(28051, 1998, 8, 'Aucune entrée pour "Texto"'),
(28052, 1999, 8, 'Aucune entrée pour "Nom d''usager'),
(28053, 2008, 8, 'Activer les rapports sur CAM'),
(28054, 2009, 8, 'Activer le suivis de CAM'),
(28055, 2011, 8, 'Activer l''Audit ATNA'),
(28056, 2013, 8, 'Activer la journalisation d''Audit'),
(28057, 2015, 8, 'Activer les rapports sur la calculation automatique des mesures (CAM)'),
(28058, 2016, 8, 'Activer SSL pour les clients'),
(28059, 2017, 8, 'Activer l''authentification par certificat SSL pour les clients'),
(28060, 2019, 8, 'Activer les Règles de Décisions Clinique (RDC)'),
(28061, 2022, 8, 'Activer le rapport des mesures de qualité clinique (LCQ)'),
(28062, 2023, 8, 'Activer le popup de rappel cilnique'),
(28063, 2024, 8, 'Activer le gadget de rappel clinique'),
(28064, 2027, 8, 'Activer les rapports LCQ'),
(28065, 2028, 8, 'Activer Historique EDI dans le menu de Gauche'),
(28066, 2030, 8, 'activer les honnoraires dans le menu de gauche'),
(28067, 2031, 8, 'Activer le support Hylafax'),
(28068, 2037, 8, 'Activer Lab Exchange'),
(28069, 2039, 8, 'Activer l''outil de log pour les document téléversés/téléchargés sur CouchDB'),
(28070, 2040, 8, 'Activer la journalisation des requêtes SELECT SQL.'),
(28071, 2041, 8, 'Activer la journalisation des activités liés aux sauvegardes.'),
(28072, 2042, 8, 'Activer la journalisation des requettes du moteur CDR'),
(28073, 2043, 8, 'Activer la journalisation des activités diverses.'),
(28074, 2044, 8, 'Activer la journalisation des activités de commande.'),
(28075, 2045, 8, 'Activer la journalisation des modifications du dossier patient.'),
(28076, 2046, 8, 'Activer la journalisation des activités de planification.'),
(28077, 2047, 8, 'Activer la journalisation des activités de sécurité et d''administration.'),
(28078, 2049, 8, 'Activer le service NewCrop eRx'),
(28079, 2051, 8, 'Activer l''accès à distance au portail patient'),
(28080, 2052, 8, 'Activer l''accès à distance au portail patient.'),
(28081, 2053, 8, 'Activer l''accès local au portail patient'),
(28082, 2055, 8, 'Activer l''accès local au portail patient.'),
(28083, 2056, 8, 'Activer le widget de rappel patient'),
(28084, 2057, 8, 'Activer le service de messagerie direct phiMail'),
(28085, 2061, 8, 'Activer le support du scanner'),
(28086, 2064, 8, 'Activer l''intégration des informations médical, LLC service d''échange de laboratoire'),
(28087, 2065, 8, 'Activer le support LibreEHR du LLC service d''échange de laboratoire'),
(28088, 2066, 8, 'Activer lauthentification utilisateur par certificat'),
(28089, 2067, 8, 'Activer ZMG, service LLC eRx'),
(28090, 2068, 8, 'Activé'),
(28091, 2070, 8, 'Activer l''ancien panneau des Taxes pour entrer les codes de facturation et les payements. Non recommendé, utilisez Fee Sheet à la place.'),
(28092, 2071, 8, 'Rdv'),
(28093, 2072, 8, 'Rencontre'),
(28094, 2073, 8, 'Rencontre'),
(28095, 2074, 8, 'Rencontre'),
(28096, 2075, 8, 'rencontre '),
(28097, 2081, 8, 'Date Rencontre'),
(28098, 2084, 8, 'Enregistrement de rencontre EDI'),
(28099, 2086, 8, 'Formulaires de rencontre'),
(28100, 2087, 8, 'Consultation médicale'),
(28101, 2088, 8, 'Historique des rencontres'),
(28102, 2089, 8, 'N° Rencontre'),
(28103, 2091, 8, 'Numéro Rencontre'),
(28104, 2094, 8, 'Rencontre du service d''infirmerie'),
(28105, 2097, 8, 'Rencontre avec un patient externe'),
(28106, 2099, 8, 'Taille de la page des rencontres'),
(28107, 2100, 8, 'Rencontre de payement'),
(28108, 2101, 8, 'Rencontre pour la grossesse'),
(28109, 2102, 8, 'rencontre de médecine préventive - aide psychologique individuelle'),
(28110, 2103, 8, 'rencontre de médecine préventive pour les 40 ans et plus'),
(28111, 2104, 8, 'rencontre de médecine préventive groupe d''aide psychologique'),
(28112, 2105, 8, 'rencontre de médecine préventive autres services'),
(28113, 2106, 8, 'rencontre de médecine préventive pour les 18 ans et plus'),
(28114, 2107, 8, 'rencontre psychatrique et psychologique'),
(28115, 2108, 8, 'Statistique de la rencontre'),
(28116, 2109, 8, 'Résumé de la rencontre'),
(28117, 2110, 8, 'La rencontre était codé'),
(28118, 2111, 8, 'Rencontre:'),
(28119, 2113, 8, 'Rencontres'),
(28120, 2114, 8, 'Rencontres et Formulaires'),
(28121, 2115, 8, 'Rencontres et Formulaires'),
(28122, 2116, 8, 'Rencontres non authorizées'),
(28123, 2117, 8, 'Rapport des rencontres'),
(28124, 2118, 8, 'Partie rencontres'),
(28125, 2120, 8, 'Encryption'),
(28126, 2121, 8, 'Fin'),
(28127, 2122, 8, 'Fin (aaaa-mm-jj): '),
(28128, 2123, 8, 'Date Fin'),
(28129, 2124, 8, 'Date fin'),
(28130, 2126, 8, 'Date fin doit être supérieur à date début'),
(28131, 2127, 8, 'Date Fin:'),
(28132, 2131, 8, 'Heure Fin'),
(28133, 2133, 8, 'Date de fin de service aaaa-mm-jj'),
(28134, 2135, 8, 'Heure fin de journée pour les événements du calendrier.'),
(28135, 2136, 8, 'Sang endocrinien anormal'),
(28136, 2137, 8, 'Endocrine'),
(28137, 2138, 8, 'Endoscopie'),
(28138, 2141, 8, 'Anglais'),
(28139, 2142, 8, 'Anglais '),
(28140, 2143, 8, 'Anglais (Indien)'),
(28141, 2144, 8, 'Anglais (Standard)'),
(28142, 2145, 8, 'Commande Enscript utilisé par Hylafax.'),
(28143, 2146, 8, 'Vérifier que LibreEHR a les privilèges d''écriture dans le répertoire'),
(28144, 2149, 8, 'Entrer un code diagnostic pour exclure toute les factures exemptent de ce code'),
(28145, 2152, 8, 'Entrer le mot de passe root de la base de donnée'),
(28146, 2153, 8, 'Entrer le nom d''utilisateur root de la base de donnée'),
(28147, 2154, 8, 'Entrer le diagnostic'),
(28148, 2155, 8, 'Entrer la liste des médicaments'),
(28149, 2156, 8, 'Entrer une rencontre'),
(28150, 2157, 8, 'Entrer un numéro de rencontre'),
(28151, 2158, 8, 'Entrer les vaccinations'),
(28152, 2159, 8, 'Entrer la clef'),
(28153, 2161, 8, 'Entrer un nouvel État'),
(28154, 2162, 8, 'Entrer les adresses direct des destinataires'),
(28155, 2164, 8, 'Entrer le code de Re-Identification'),
(28156, 2165, 8, 'Entrer vos critères de recherches ci-dessus'),
(28157, 2166, 8, 'Entré dans Erreur'),
(28158, 2167, 8, 'entrées'),
(28159, 2168, 8, 'Environnementale'),
(28160, 2176, 8, 'Épilepsie'),
(28161, 2179, 8, 'Fichiers ERA'),
(28162, 2181, 8, 'Effacer'),
(28163, 2182, 8, 'Érections'),
(28164, 2183, 8, 'Erreur'),
(28165, 2185, 8, 'L''accusé réception des résulats de laboratoire a généré une erreur'),
(28166, 2187, 8, 'Une erreur est survenue dans l''obtention des resultats de labo via Lab Exchange Network'),
(28167, 2188, 8, 'Erreur dans le champ "Sexe"'),
(28168, 2189, 8, 'Erreur dans la selection "HIPAA"'),
(28169, 2190, 8, 'Erreur dans la selection "Processus"'),
(28170, 2191, 8, 'Erreur dans la selection de la "SMS Gateway"'),
(28171, 2192, 8, 'Erreur dans la selection de "Tri"'),
(28172, 2193, 8, 'Erreur lors de la compression gzip du fichier: '),
(28173, 2194, 8, 'Erreur dans les options OUI ou NON'),
(28174, 2195, 8, 'Erreur lors de l''ouverture du fichier téléchargé'),
(28175, 2196, 8, 'Erreur du traitement du fichier'),
(28176, 2197, 8, 'Erreur lors du téléversement en cours'),
(28177, 2198, 8, 'Erreur lors de la suppression du message'),
(28178, 2199, 8, 'Erreur lors de la récupérations des résultats via Lab Exchange Network'),
(28179, 2200, 8, 'Erreur lors de la récupération des valeurs.'),
(28180, 2202, 8, 'Erreur lors de l''élevage de privilège sur les fichier pour l''utilisateur LibreEHR'),
(28181, 2205, 8, 'erreur lors de l''enregistrement du formulaire!'),
(28182, 2206, 8, 'Erreur lors de l''enregistrement du fichier'),
(28183, 2208, 8, 'Erreur lors de l''écriture dans le ficher'),
(28184, 2209, 8, 'erreur(s) rencontrée(s) dans les nouveaux résultats'),
(28185, 2210, 8, 'Erreur, ce fichier n''existe pas'),
(28186, 2211, 8, 'ERREUR, impossible de collecter des données depuis le serveur'),
(28187, 2212, 8, 'Erreur, impossible de créer le certificat client.'),
(28188, 2213, 8, 'Erreur, impossible de créer le certificat admin.p12.'),
(28189, 2214, 8, 'Erreur, impossible de créer le certificat de l''autorité de certification.'),
(28190, 2215, 8, 'Erreur, impossible de créer le certificat serveur.'),
(28191, 2216, 8, 'Erreur, impossible d''ouvrir le fichier'),
(28192, 2217, 8, 'Erreur, l''authorité de certification est pas activée dand LibreEHR'),
(28193, 2218, 8, 'Erreur, vous devez intaller le module php Archive/Tar.php.'),
(28194, 2219, 8, 'ERREUR: ne peut pas ouvrir table.sql, le formulaire est-il cassé?'),
(28195, 2220, 8, 'Erreur: identifiant dupliqué à la ligne'),
(28196, 2221, 8, 'Erreur: nom dupliqué à la ligne'),
(28197, 2222, 8, 'ERREUR: Champ'),
(28198, 2223, 8, 'ERREUR: L''archive zip du module PHP est absente'),
(28199, 2224, 8, 'ERREUR: pas de répertoire pour l''importation d''ICD'),
(28200, 2225, 8, 'Erreur: les mots de passe sont différent. S''il vous plait verifiez votre orthographe.'),
(28201, 2226, 8, 'Erreur: les mots de passe sont différent. S''il vous plait verifiez votre orthographe.'),
(28202, 2227, 8, 'Erreur: le fichier n''existe pas'),
(28203, 2228, 8, 'ERREUR: La variable suivante contient des caractères non autorisés'),
(28204, 2229, 8, 'ERREUR: Impossible de copier le fichier.'),
(28205, 2230, 8, 'Erreur: Impossible de créer une archive téléchargeable'),
(28206, 2231, 8, 'ERREUR: Impossible de créer une archive Zip'),
(28207, 2232, 8, 'ERREUR: Impossible d''extraire le fichier.'),
(28208, 2233, 8, 'ERREUR: Impossible de charger le fichier dans la base de donnée'),
(28209, 2234, 8, 'ERREUR: Impossible d''affecter le numéro de version'),
(28210, 2235, 8, 'Erreurs'),
(28211, 2236, 8, 'Status du compte eRx'),
(28212, 2237, 8, 'Logs d''ERX'),
(28213, 2238, 8, 'Nom d''ERX'),
(28214, 2239, 8, 'Mot de passe d''ERX'),
(28215, 2240, 8, 'Rôle d''ERX'),
(28216, 2241, 8, 'Utilisateur d''ERX'),
(28217, 2242, 8, 'Erythème:'),
(28218, 2245, 8, 'Esquimaux'),
(28219, 2247, 8, 'Patient établi'),
(28220, 2248, 8, 'Estonien'),
(28221, 2249, 8, 'Éthnicité'),
(28222, 2250, 8, 'Éthnicité ou Race'),
(28223, 2251, 8, 'Liste des éthnicié ou race (écriture, ajout seulement optionnel)'),
(28224, 2252, 8, 'ETIN'),
(28225, 2253, 8, 'Évènement'),
(28226, 2254, 8, 'Évènement commence'),
(28227, 2255, 8, 'Catégorie de l''Évènement'),
(28228, 2256, 8, 'Date de l''Évènement'),
(28229, 2257, 8, 'Description de l''Évènement'),
(28230, 2258, 8, 'Détails de l''Évènement'),
(28231, 2259, 8, 'Évènement ne se répètant pas'),
(28232, 2260, 8, 'Durée de l''Évènement'),
(28233, 2261, 8, 'Durée de l''Évènement en min.'),
(28234, 2262, 8, 'Coût de l''Évènement'),
(28235, 2263, 8, 'Lieu de l''Évènement'),
(28236, 2264, 8, 'Évènement se répètant tous les'),
(28237, 2265, 8, 'Évènement se répètant chaque'),
(28238, 2266, 8, 'Heure de début de l''Évènement'),
(28239, 2267, 8, 'Nom de l''évènement'),
(28240, 2268, 8, 'Nom de l''Évènement'),
(28241, 2269, 8, 'Site web de l''évènement'),
(28242, 2270, 8, 'Évènements'),
(28243, 2271, 8, 'Évènements pour'),
(28244, 2272, 8, 'Évènements s''ouvrent dans nouvelle fenêtre'),
(28245, 2273, 8, 'chaque/toutes'),
(28246, 2274, 8, 'Chaque/Toutes'),
(28247, 2275, 8, 'toutes les 3 heures'),
(28248, 2276, 8, 'toutes les 4 heures'),
(28249, 2277, 8, 'toutes les 5 heures'),
(28250, 2278, 8, 'toutes les 6 heures'),
(28251, 2279, 8, 'toutes les 8 heures'),
(28252, 2280, 8, 'Toutes les quatrième'),
(28253, 2281, 8, 'Toutes Autres'),
(28254, 2282, 8, 'Tous les troisièmes'),
(28255, 2283, 8, 'Tous, tout les autes, tout les 3èmes, etc.'),
(28256, 2285, 8, 'Examen et résultats de test'),
(28257, 2286, 8, 'Résultats d''examen'),
(28258, 2289, 8, 'Examination'),
(28259, 2290, 8, 'Date de l''examination'),
(28260, 2291, 8, 'Exemple'),
(28261, 2292, 8, 'Exemples'),
(28262, 2293, 8, 'Exams/Tests'),
(28263, 2294, 8, 'Sauf'),
(28264, 2295, 8, 'Production de larme excessive'),
(28265, 2296, 8, 'Patients Exclus'),
(28266, 2297, 8, 'Exclusion'),
(28267, 2300, 8, 'Exercice'),
(28268, 2301, 8, 'Types d''Exercices'),
(28269, 2302, 8, 'Types d''exercices'),
(28270, 2303, 8, 'Existe'),
(28271, 2304, 8, 'Quite l''administration'),
(28272, 2305, 8, 'Agr'),
(28273, 2306, 8, 'Agrandir'),
(28274, 2307, 8, 'agrandir'),
(28275, 2308, 8, 'Tout Agrandir'),
(28276, 2311, 8, 'Agrandir Vue'),
(28277, 2312, 8, 'form_encounter.pid attendu '),
(28278, 2313, 8, 'Expiration'),
(28279, 2314, 8, 'Date d''expiration'),
(28280, 2315, 8, 'Expire'),
(28281, 2316, 8, 'expire dans'),
(28282, 2317, 8, 'Exporter'),
(28283, 2318, 8, 'Exporter en CSV'),
(28284, 2319, 8, 'Exporter Configuration'),
(28285, 2322, 8, 'Exporter les données démographique du patient'),
(28286, 2323, 8, 'Export de Raport PQRI'),
(28287, 2325, 8, 'Exporter Sélection en CSV'),
(28288, 2326, 8, 'Exporter la sélection en collections'),
(28289, 2327, 8, 'Exporter en CSV'),
(28290, 2328, 8, 'Exporter vers le sytème de faturation externe'),
(28291, 2329, 8, 'Exposition à des pays étrangé'),
(28292, 2330, 8, 'Exposition à des pays étrangé'),
(28293, 2331, 8, 'Temps Ext Collecté'),
(28294, 2332, 8, 'Externe'),
(28295, 2334, 8, 'Données externes chargées'),
(28296, 2335, 8, 'Outils d''importation d''une base de donnée externe'),
(28297, 2336, 8, 'ID externe'),
(28298, 2337, 8, 'Id externe'),
(28299, 2338, 8, 'Identifiant externe'),
(28300, 2339, 8, 'Externe uniquement'),
(28301, 2342, 8, 'Spécialiste externe'),
(28302, 2343, 8, 'Suivis du spécialiste externe'),
(28303, 2344, 8, 'Spécialiste externe ?'),
(28304, 2345, 8, 'Specialistes Externes'),
(28305, 2346, 8, 'Extraire le fichier ZIP'),
(28306, 2347, 8, 'Extraction du fichier. ceci peut durer un peu...'),
(28307, 2349, 8, 'Iritation Oculaire'),
(28308, 2350, 8, 'Douleur Oculaire'),
(28309, 2351, 8, 'Oeil Rouge'),
(28310, 2352, 8, 'Yeux'),
(28311, 2353, 8, 'F'),
(28312, 2354, 8, 'F/H Problèmes Sanguins'),
(28313, 2356, 8, 'Etablissements'),
(28314, 2357, 8, 'Etablissement'),
(28315, 2358, 8, 'etablissement'),
(28316, 2359, 8, 'Etablissement Médical Adminstration'),
(28317, 2360, 8, 'Etablissement Médical Ville'),
(28318, 2361, 8, 'Etablissement Médical Code Postal'),
(28319, 2362, 8, 'Etablissement Medical Code Pays'),
(28320, 2363, 8, 'Etablissement Medical Fax'),
(28321, 2364, 8, 'Etablissement Medical Nom'),
(28322, 2365, 8, 'Etablissement Medical NPI'),
(28323, 2366, 8, 'Etablissement Medical Télèphone'),
(28324, 2368, 8, 'État des locaux'),
(28325, 2369, 8, 'Rue des locaux'),
(28326, 2370, 8, 'Code postal des locaux'),
(28327, 2372, 8, 'Locaux:'),
(28328, 2373, 8, 'ECHEC'),
(28329, 2374, 8, 'échoué'),
(28330, 2375, 8, 'Echoué'),
(28331, 2380, 8, 'Echec de création du dossier temporaire. CouchDB ne vas pas fonctionner'),
(28332, 2382, 8, 'Échoué.'),
(28333, 2383, 8, 'échec'),
(28334, 2390, 8, 'Antécédents Familiaux'),
(28335, 2391, 8, 'Antécédents Familiaux de Glaucome'),
(28336, 2392, 8, 'Antécédents Familiaux:'),
(28337, 2394, 8, 'Payement familliaux'),
(28338, 2395, 8, 'Taille de la Famille'),
(28339, 2396, 8, 'Envie'),
(28340, 2400, 8, 'Père'),
(28341, 2402, 8, 'Fatigue'),
(28342, 2403, 8, 'asthénié'),
(28343, 2404, 8, 'Fax/Télécopie'),
(28344, 2405, 8, 'Nombre Fax'),
(28345, 2406, 8, 'Numéro FAX'),
(28346, 2408, 8, 'Fax/Document numérisé'),
(28347, 2409, 8, 'Fax reçus'),
(28348, 2410, 8, 'Fax envoyés'),
(28349, 2411, 8, 'Fonctionnalités'),
(28350, 2412, 8, 'févr.'),
(28351, 2413, 8, 'Février'),
(28352, 2418, 8, 'Frais'),
(28353, 2419, 8, 'frais'),
(28354, 2420, 8, 'Frais non autorisés'),
(28355, 2421, 8, 'Note de Frais'),
(28356, 2422, 8, 'Options Note de Frais'),
(28357, 2423, 8, 'Frais'),
(28358, 2424, 8, 'Féminin'),
(28359, 2426, 8, 'Préservatifs Féminins'),
(28360, 2427, 8, 'Point G'),
(28361, 2428, 8, 'Dernière conception'),
(28362, 2429, 8, 'Pelvis féminin'),
(28363, 2430, 8, 'Symptômes Féminin'),
(28364, 2434, 8, 'Fièvre'),
(28365, 2435, 8, 'Fièvre:'),
(28366, 2436, 8, 'Problèmes sanguins FH'),
(28367, 2437, 8, 'Fibromes'),
(28368, 2441, 8, 'Type de champs à utiliser dans démographiques pour un employeur ou un nouveau pays.'),
(28369, 2442, 8, 'Type de champs à utiliser dans démographiques pour un employeur ou un nouvel État.'),
(28370, 2443, 8, 'Le(s) champs manquent!'),
(28371, 2447, 8, 'Fichier'),
(28372, 2448, 8, 'Fichier dans le répertoire de documentation pour apprendre comment créer le processus de création des sauvegardes de log'),
(28373, 2449, 8, 'Location du fichier'),
(28374, 2450, 8, 'Gestion de Fichiers'),
(28375, 2453, 8, 'Privilège sur les fichiers accordé à l''utilisateur LibreEHR'),
(28376, 2454, 8, 'Echec de la récupération du fichier via CouchDB'),
(28377, 2455, 8, 'Chambre du fichier'),
(28378, 2456, 8, 'Fichier à télécharger'),
(28379, 2457, 8, 'Fichier à Télécharger'),
(28380, 2458, 8, 'Fichier avec même nom existe déjà à:'),
(28381, 2459, 8, 'Nom Fichier'),
(28382, 2461, 8, 'Fichiers'),
(28383, 2462, 8, 'Philippin'),
(28384, 2463, 8, 'Remplissez une des ligne en dessous.'),
(28385, 2464, 8, 'Remplissez ici que si la notification est envoyé par email aux patients'),
(28386, 2465, 8, 'Complétez les valeurs ci-dessous'),
(28387, 2467, 8, 'Remplissez la ligne.'),
(28388, 2468, 8, 'Filtre'),
(28389, 2469, 8, 'Filtre pour les constantes'),
(28390, 2470, 8, 'Filtre pour les définitions'),
(28391, 2471, 8, 'filtré depuis'),
(28392, 2472, 8, 'filtres'),
(28393, 2473, 8, 'Filtres'),
(28394, 2474, 8, 'Final'),
(28395, 2475, 8, 'Diagnostic final'),
(28396, 2476, 8, 'Le diagnostic final par un spécialiste'),
(28397, 2478, 8, 'Financier'),
(28398, 2479, 8, 'Date de clôture financière (aaaa-mm-jj)'),
(28399, 2480, 8, 'Report Financier - tout'),
(28400, 2481, 8, 'Report Financier - mes visites'),
(28401, 2482, 8, 'Date de révision financière'),
(28402, 2483, 8, 'Résumé financier via un code service'),
(28403, 2484, 8, 'Trouver'),
(28404, 2485, 8, 'Trouver Disponible'),
(28405, 2486, 8, 'Trouver rendez-vous disponible'),
(28406, 2487, 8, 'Trouver un patient'),
(28407, 2488, 8, 'Trouver éducation des patients'),
(28408, 2489, 8, 'Résultats'),
(28409, 2490, 8, 'Les résultats par un spécialiste'),
(28410, 2491, 8, 'Bien'),
(28411, 2492, 8, 'Finition des Paiements'),
(28412, 2493, 8, 'finis'),
(28413, 2495, 8, 'Premier'),
(28414, 2497, 8, 'Premier jour de la semaine'),
(28415, 2498, 8, 'Prénom'),
(28416, 2499, 8, 'Prénom'),
(28417, 2500, 8, 'Prénom:'),
(28418, 2503, 8, 'Fitness'),
(28419, 2504, 8, 'Niveau de Fitness'),
(28420, 2505, 8, 'La condition physique pour ce joueur cette journée'),
(28421, 2507, 8, 'Fitness à jouer'),
(28422, 2508, 8, 'Fix rencontre dates - toutes les rencontres'),
(28423, 2509, 8, 'corriger ce'),
(28424, 2510, 8, 'FL'),
(28425, 2511, 8, 'flatulence'),
(28426, 2512, 8, 'Débit'),
(28427, 2514, 8, 'Saison grippale'),
(28428, 2515, 8, 'Saison grippale'),
(28429, 2516, 8, 'Vaccination contre la grippe'),
(28430, 2517, 8, 'Fluide et problème d''électrolytes'),
(28431, 2518, 8, 'FMS'),
(28432, 2520, 8, 'Suivez manuellement'),
(28433, 2521, 8, 'Suivez ses instruction pour installer ou mètre à jour la base de donnée suivante'),
(28434, 2522, 8, 'Suivi'),
(28435, 2524, 8, 'Raison de Suivi'),
(28436, 2525, 8, 'Voici une nouvelle constante personnalisée:'),
(28437, 2526, 8, 'Voici un nouveau langage personnalisé:'),
(28438, 2527, 8, 'Voici une nouvelle définition (Langue, Constant, Définition):'),
(28439, 2529, 8, 'Services de suivi'),
(28440, 2530, 8, 'Suivis indiqués'),
(28441, 2531, 8, 'Intolérance alimentaire'),
(28442, 2532, 8, 'Pied'),
(28443, 2533, 8, 'Problèmes de pied'),
(28444, 2534, 8, 'Pied:'),
(28445, 2535, 8, 'Blessures de football'),
(28446, 2536, 8, 'Blessure de football'),
(28447, 2537, 8, 'Rapport de blessure de football'),
(28448, 2538, 8, 'Type de chaussures'),
(28449, 2539, 8, 'pour'),
(28450, 2540, 8, 'Pour'),
(28451, 2541, 8, 'Pour le code'),
(28452, 2543, 8, 'Pour les réclamations Rencontre'),
(28453, 2544, 8, 'Par exemple:'),
(28454, 2547, 8, 'pour la facturation'),
(28455, 2553, 8, 'Pour le passé'),
(28456, 2554, 8, 'pour la variable'),
(28457, 2555, 8, 'pour:'),
(28458, 2556, 8, 'Forcer l''ouverture du gadget de facturation'),
(28459, 2557, 8, 'Forcer la création d''un nouveau patient'),
(28460, 2558, 8, 'Forcer la vue'),
(28461, 2559, 8, 'Avant-bras'),
(28462, 2560, 8, 'Formulaire'),
(28463, 2561, 8, 'formulaire'),
(28464, 2564, 8, 'Format'),
(28465, 2565, 8, 'format'),
(28466, 2566, 8, 'Format pour laffichage de l''age'),
(28467, 2567, 8, 'Format incorrect pour NDC'),
(28468, 2568, 8, 'Format utilisé pour afficher les dates.'),
(28469, 2569, 8, 'Format utilisé pour afficher le temps.'),
(28470, 2570, 8, 'Rapport formaté'),
(28471, 2571, 8, 'Ancien fumeur'),
(28472, 2572, 8, 'Formulaires'),
(28473, 2573, 8, 'Formulaires d''administration'),
(28474, 2575, 8, 'Faire suivre'),
(28475, 2576, 8, 'Envoi Pages par fax'),
(28476, 2577, 8, 'Transmis'),
(28477, 2579, 8, 'Quatrième'),
(28478, 2581, 8, 'Fracture'),
(28479, 2582, 8, 'Fracture du naviculaire'),
(28480, 2583, 8, 'Fracture du malléole latéral'),
(28481, 2584, 8, 'Fracture du malléole médian'),
(28482, 2585, 8, 'Fracture, à la base du cinquième métatarsien'),
(28483, 2586, 8, 'Support de l''ossature requis'),
(28484, 2587, 8, 'Français'),
(28485, 2588, 8, 'Français (Canadien)'),
(28486, 2589, 8, 'Français (Standard)'),
(28487, 2590, 8, 'Fréquence'),
(28488, 2591, 8, 'Rhumes fréquents'),
(28489, 2592, 8, 'Maladie fréquente'),
(28490, 2593, 8, 'Ven.'),
(28491, 2594, 8, 'Vendredi'),
(28492, 2595, 8, 'De'),
(28493, 2596, 8, 'DE'),
(28494, 2597, 8, 'de'),
(28495, 2598, 8, 'Date De ne peut être supérieur à Date A.'),
(28496, 2599, 8, 'De :'),
(28497, 2600, 8, 'De : '),
(28498, 2613, 8, 'Bureau dacceuil'),
(28499, 2614, 8, 'Recettes du bureau d''acceuil'),
(28500, 2615, 8, 'Rapport des recettes du bureau d''acceuil'),
(28501, 2619, 8, 'Nom Complet'),
(28502, 2620, 8, 'Chemin complet du dossier contenant les executables MySQL.'),
(28503, 2621, 8, 'Chemin complet du dossier contenant les executables Perl'),
(28504, 2622, 8, 'Chemin complet du dossier pour les sauvegarde des logs des evenements'),
(28505, 2623, 8, 'Chemin complet du dossier utilisé pour les fichiers temporaires'),
(28506, 2625, 8, 'Entrainement complet'),
(28507, 2626, 8, 'Soldé'),
(28508, 2636, 8, 'Irritation de la vessie'),
(28509, 2637, 8, 'Lithiases biliaires'),
(28510, 2638, 8, 'Période du jeu'),
(28511, 2639, 8, 'Jeux'),
(28512, 2640, 8, 'Jeux manqués'),
(28513, 2641, 8, 'jeux / événements'),
(28514, 2642, 8, 'Jeux / Evénements manqués'),
(28515, 2644, 8, 'Gastrite'),
(28516, 2645, 8, 'Douleur ventrale'),
(28517, 2646, 8, 'Gastrointestinal'),
(28518, 2650, 8, 'Genre'),
(28519, 2651, 8, 'Genre '),
(28520, 2652, 8, 'Général'),
(28521, 2653, 8, 'Liste des problèmes généraux'),
(28522, 2655, 8, 'Catégories de services généraux'),
(28523, 2668, 8, 'Généré une facture'),
(28524, 2669, 8, 'Généré une lettre'),
(28525, 2670, 8, 'Généré une lettre a propos '),
(28526, 2677, 8, 'Généré un rapport'),
(28527, 2678, 8, 'Généré un utilisateur et un mot de passe pour'),
(28528, 2679, 8, 'Généré X12'),
(28529, 2680, 8, 'Généré rencontre x12'),
(28530, 2682, 8, 'Généré le'),
(28531, 2683, 8, 'Génère'),
(28532, 2684, 8, 'Génito-urinaire'),
(28533, 2687, 8, 'Allemand'),
(28534, 2691, 8, 'Obtenir HL7'),
(28535, 2692, 8, 'Glaucome'),
(28536, 2693, 8, 'Antécédents Familiaux de Glaucome'),
(28537, 2694, 8, 'Globale'),
(28538, 2696, 8, 'ID Globale'),
(28539, 2697, 8, 'Paramètres Globales'),
(28540, 2698, 8, 'Globales'),
(28541, 2700, 8, 'aller'),
(28542, 2701, 8, 'Aller'),
(28543, 2704, 8, 'Aller à'),
(28544, 2705, 8, 'Aller à la semaine du'),
(28545, 2706, 8, 'Aujourd''hui'),
(28546, 2707, 8, 'Objectif A'),
(28547, 2708, 8, 'But et méthodes'),
(28548, 2709, 8, 'Objectif B'),
(28549, 2710, 8, 'Objectif C'),
(28550, 2711, 8, 'Degré de traumatismes'),
(28551, 2712, 8, 'Grade:'),
(28552, 2713, 8, 'grammes'),
(28553, 2714, 8, 'Total général'),
(28554, 2715, 8, 'Totaux généraux'),
(28555, 2720, 8, 'Supérieur à'),
(28556, 2721, 8, 'Supérieur ou égal à'),
(28557, 2722, 8, 'Grecque'),
(28558, 2724, 8, 'Groupe'),
(28559, 2725, 8, 'Nom du groupe'),
(28560, 2726, 8, 'Nom du groupe ne peut pas être vide'),
(28561, 2727, 8, 'Nom du groupe ne peut pas commencé par un nombre ou un espace'),
(28562, 2728, 8, 'Nom du groupe ne peut pas commencé par un nombre'),
(28563, 2729, 8, 'Nombre de groupe'),
(28564, 2730, 8, 'Condition du groupe'),
(28565, 2731, 8, 'Groupe:'),
(28566, 2732, 8, 'Nom du groupe'),
(28567, 2733, 8, 'Groupes et contrôles d''acces'),
(28568, 2734, 8, 'Courbe de Croissance'),
(28569, 2735, 8, 'Courbe de Croissance'),
(28570, 2736, 8, 'gouttes'),
(28571, 2739, 8, 'Nom du résponsable'),
(28572, 2741, 8, 'Examen Gynécologique'),
(28573, 2745, 8, 'a été correctement supprimé. Les sous-catégories, si présentes, ont été déplacés en dessous'),
(28574, 2746, 8, 'Hématomes / Echymoses'),
(28575, 2750, 8, 'Main + Doigts'),
(28576, 2751, 8, 'Problèmes au niveau Main'),
(28577, 2752, 8, 'Disque dur'),
(28578, 2754, 8, 'À été relier à la visite'),
(28579, 2755, 8, 'a expiré'),
(28580, 2760, 8, 'Hawaien'),
(28581, 2761, 8, 'Activités Dangereuses'),
(28582, 2762, 8, 'Activités dangereuses'),
(28583, 2768, 8, 'Tête'),
(28584, 2769, 8, 'Per Crânien'),
(28585, 2770, 8, 'Périmètre Crânien'),
(28586, 2771, 8, 'Céphalée'),
(28587, 2772, 8, 'Céphalées'),
(28588, 2773, 8, 'Opérations de santé'),
(28589, 2774, 8, 'Opérations de Santé'),
(28590, 2775, 8, 'Hôpital / centre de soin'),
(28591, 2778, 8, 'Perte d''Audition'),
(28592, 2779, 8, 'Infarctus'),
(28593, 2780, 8, 'Maladie Cardiaque'),
(28594, 2781, 8, 'Insuffisance Cardiaque'),
(28595, 2782, 8, 'Problème Cardiaque'),
(28596, 2783, 8, 'Problèmes Cardiaques'),
(28597, 2784, 8, 'Chirurgie Cardiaque'),
(28598, 2785, 8, 'Transplantation Cardiaque'),
(28599, 2786, 8, 'COEUR:'),
(28600, 2787, 8, 'Pyrosis'),
(28601, 2788, 8, 'Chaud ou Froid'),
(28602, 2789, 8, 'CHAUD Ou FROID'),
(28603, 2790, 8, 'Grand fumeur de tabac'),
(28604, 2791, 8, 'Israëlien'),
(28605, 2794, 8, 'Hauteur'),
(28606, 2796, 8, 'Aide'),
(28607, 2797, 8, 'aide'),
(28608, 2798, 8, 'Hématémèse'),
(28609, 2799, 8, 'Rectorragie'),
(28610, 2800, 8, 'Hématologie'),
(28611, 2801, 8, 'Hématurie'),
(28612, 2802, 8, 'Hémoglobine'),
(28613, 2803, 8, 'Hémoglobine A1C'),
(28614, 2804, 8, 'Hémoptysie'),
(28615, 2805, 8, 'Hépatite'),
(28616, 2806, 8, 'Hépatite A 1'),
(28617, 2807, 8, 'Hépatite A 2'),
(28618, 2808, 8, 'Hépatite B 1'),
(28619, 2809, 8, 'Hépatite B 2'),
(28620, 2810, 8, 'Hépatite B 3'),
(28621, 2811, 8, 'ici'),
(28622, 2813, 8, 'Cure d''Hernie'),
(28623, 2814, 8, 'Hernie discale'),
(28624, 2815, 8, 'Herpès'),
(28625, 2816, 8, 'Hésitation'),
(28626, 2817, 8, 'heyyo. vous avez été ici pour '),
(28627, 2819, 8, 'Hib 2'),
(28628, 2820, 8, 'Hib 3'),
(28629, 2821, 8, 'Hib 4'),
(28630, 2822, 8, 'Caché'),
(28631, 2823, 8, 'Evénements d''Administration masqués'),
(28632, 2824, 8, 'Cacher'),
(28633, 2825, 8, 'Masquer les détails'),
(28634, 2827, 8, 'Masquer l''option cryptage/décryptage dans la gestion documentaire'),
(28635, 2828, 8, 'Masquer les menus'),
(28636, 2830, 8, 'Cacher les rappels'),
(28637, 2831, 8, 'Afficher / Masquer les colonnes'),
(28638, 2833, 8, 'Elevé'),
(28639, 2834, 8, 'Hypertension artérielle'),
(28640, 2835, 8, 'Hindi'),
(28641, 2836, 8, 'La hanche + l''aine'),
(28642, 2837, 8, 'La hanche et l''aine'),
(28643, 2838, 8, 'Les problèmes de hanche'),
(28644, 2839, 8, 'Prothèse de la hanche'),
(28645, 2842, 8, 'Hirsutisme'),
(28646, 2843, 8, 'Hispanique'),
(28647, 2844, 8, 'Hispanique - Autres (Né aux Etats-Unis)'),
(28648, 2845, 8, 'Hispanique - Autres (Né à l''extérieur des États-Unis)'),
(28649, 2846, 8, 'Hispanique ou Latino'),
(28650, 2847, 8, 'Histoire'),
(28651, 2848, 8, 'Historique des données'),
(28652, 2849, 8, 'Date de l''histoire'),
(28653, 2851, 8, 'Historique du Souffle'),
(28654, 2852, 8, 'Historique non autorisé'),
(28655, 2853, 8, 'Historique du souffle cardiaque'),
(28656, 2854, 8, 'visites (Clics)'),
(28657, 2855, 8, 'VIH'),
(28658, 2858, 8, 'Visionneuse HL7'),
(28659, 2862, 8, 'Maintenir [Ctrl] appuyé pour une sélection multiple ou pour déselectionner'),
(28660, 2863, 8, 'Maintenir Ctrl appuyé pour sélectionner plusieurs items'),
(28661, 2864, 8, 'Maintenir Ctrl appuyé pour sélectionner plusieurs groupes'),
(28662, 2865, 8, 'Accueil'),
(28663, 2866, 8, 'Téléphone à domicile'),
(28664, 2867, 8, 'Numéro de téléphone a domicile'),
(28665, 2868, 8, 'Sans-abri ou similaires?'),
(28666, 2869, 8, 'Sans-abri, etc.'),
(28667, 2870, 8, 'Sans-abri, etc.'),
(28668, 2872, 8, 'Nom de l''hôte'),
(28669, 2873, 8, 'Nom de l''hôte ne peut pas être vide'),
(28670, 2875, 8, 'Heure'),
(28671, 2876, 8, 'Heures'),
(28672, 2878, 8, 'Comment vous êtes blessé?'),
(28673, 2879, 8, 'Comment vous êtes blessé?:'),
(28674, 2880, 8, 'Comment nous avez connus'),
(28675, 2881, 8, 'Combiens de mois se sont écouler depuis la requète jusqu''au evenements à venir ?'),
(28676, 2884, 8, 'HTML'),
(28677, 2885, 8, 'sortie HTML ?'),
(28678, 2886, 8, 'Liens https pour le support LLC le service d''échange de laboratoire via OpenEMP'),
(28679, 2887, 8, 'Hongrois'),
(28680, 2888, 8, 'Répertoire pour Hylafax'),
(28681, 2889, 8, 'Commande de chiffrement pour Hylafax'),
(28682, 2890, 8, 'Serveur Hylafax'),
(28683, 2891, 8, 'Nom du serveur Hylafax'),
(28684, 2892, 8, 'Hyperactive'),
(28685, 2893, 8, 'Hypertension'),
(28686, 2894, 8, 'Hypertension: mesure de pression artérielle.'),
(28687, 2895, 8, 'Hypertension: mesure de pression artérielle (CQM).'),
(28688, 2896, 8, 'Hyperthyroïdie'),
(28689, 2897, 8, 'Hypothyroïdie'),
(28690, 2898, 8, 'Hystérectomie'),
(28691, 2899, 8, 'je'),
(28692, 2900, 8, 'Je suis occupé pendant ce temps.'),
(28693, 2901, 8, 'Je n''ai pas l''autorisation de lecture '),
(28694, 2902, 8, 'ICD'),
(28695, 2903, 8, 'Diagnostic ICD10'),
(28696, 2904, 8, 'Service/Procédure ICD10'),
(28697, 2905, 8, 'ICD9'),
(28698, 2906, 8, 'Diagnostic ICD9'),
(28699, 2907, 8, 'Service/Procédure ICD9'),
(28700, 2909, 8, 'ID'),
(28701, 2910, 8, 'Identifiant'),
(28702, 2911, 8, 'L''ID ne peux pas être vide'),
(28703, 2912, 8, 'Carte d''identité'),
(28704, 2914, 8, 'identifié comme'),
(28705, 2915, 8, 'Identifiant(un seul mot)'),
(28706, 2916, 8, 'Code d''identification'),
(28707, 2917, 8, 'Temps avant la fermeture d''une session en seconde'),
(28708, 2919, 8, 'Si toutes les données pour toute les colones de ce formulaire sont completées'),
(28709, 2920, 8, 'Si une justification de facturation est utilisé entré le nom du type de code de diagnostic'),
(28710, 2921, 8, 'Si entré, sélectionner uniquement ceux qui ont eu accès à ce service'),
(28711, 2922, 8, 'Si nom, partie du nom de famille ou nom de famile, prénom'),
(28712, 2923, 8, 'Si payé par'),
(28713, 2924, 8, 'Si la personne est décédé, alors entrer la date de décé.'),
(28714, 2925, 8, 'Si SMTP est utilisé, le nom du serveur ou l''adresse IP.'),
(28715, 2926, 8, 'Si SMTP est utilisé, le numéro de port du TCP du serveur (normalement 25).'),
(28716, 2927, 8, 'si chômeur entrer étudiant'),
(28717, 2928, 8, 'Si AMJ est sélectionner pour l''affichage de l''age, changer pour uniquement l''Année quand les patients sont plus vieux que cette valeur en année'),
(28718, 2933, 8, 'Si vous désirez changer les types des données, ajouter des lignes ou colonnes'),
(28719, 2936, 8, 'Ignorer'),
(28720, 2937, 8, 'Maladie'),
(28721, 2941, 8, 'Service d''imagerie'),
(28722, 2942, 8, 'Vaccination'),
(28723, 2943, 8, 'Code du Vaccin'),
(28724, 2945, 8, 'Date de la Vaccination'),
(28725, 2946, 8, 'Date d''expiration de la vaccination'),
(28726, 2947, 8, 'Numéro de lot du Vaccin'),
(28727, 2948, 8, 'Fabriquant du Vaccin'),
(28728, 2949, 8, 'Registre de vaccination'),
(28729, 2951, 8, 'Service de vaccination'),
(28730, 2952, 8, 'Nom de la Vaccination'),
(28731, 2953, 8, 'Vaccinations'),
(28732, 2954, 8, 'Vaccine'),
(28733, 2955, 8, 'Immunologique'),
(28734, 2956, 8, 'Implants'),
(28735, 2957, 8, 'Importer'),
(28736, 2961, 8, 'Importé le certificant dans le navigateur.'),
(28737, 2962, 8, 'Importer Configuration'),
(28738, 2964, 8, 'Importer Patient'),
(28739, 2965, 8, 'Importer les Données démographiques du Patient'),
(28740, 2966, 8, 'Codes importants'),
(28741, 2969, 8, 'Importer de la Comptabilité'),
(28742, 2972, 8, 'Amélioré'),
(28743, 2973, 8, 'dans'),
(28744, 2974, 8, 'DANS'),
(28745, 2975, 8, 'dans chaque oeil'),
(28746, 2976, 8, 'dans l''oeil gauche'),
(28747, 2977, 8, 'dans les narines'),
(28748, 2978, 8, 'Dans le bureau'),
(28749, 2979, 8, 'dans l''oeil droit'),
(28750, 2980, 8, 'dans la maison'),
(28751, 2981, 8, 'Inactif'),
(28752, 2982, 8, 'Jours inactif'),
(28753, 2983, 8, 'Dans la boite'),
(28754, 2986, 8, 'Inclure la somme de contrôle'),
(28755, 2987, 8, 'Inclusion complété'),
(28756, 2988, 8, 'Inclure les utilisateurs inactif'),
(28757, 2989, 8, 'Inclure les non catégorisé'),
(28758, 2990, 8, 'Inclure les données non structuré'),
(28759, 2991, 8, 'Inclure les données vitales'),
(28760, 2992, 8, 'Inclure les données vitales ?'),
(28761, 2993, 8, 'inclusion'),
(28762, 2994, 8, 'Revenus'),
(28763, 2996, 8, 'Incomplété'),
(28764, 2997, 8, 'Traitement d''avortement incompété'),
(28765, 2998, 8, 'Incontinence'),
(28766, 3000, 8, 'Mot de passe incorrect!'),
(28767, 3001, 8, 'augmenté:'),
(28768, 3002, 8, 'Indemnité de l''assurance'),
(28769, 3003, 8, 'Indeterminé'),
(28770, 3004, 8, 'Indien'),
(28771, 3005, 8, 'Indiquez les anomaiies'),
(28772, 3006, 8, 'Indiquez si ce problème est actuelement actif'),
(28773, 3008, 8, 'Indicateur pour une utilisation spécialisée'),
(28774, 3009, 8, 'Patients très pauvres'),
(28775, 3010, 8, 'Rapport sur les patients très pauvres'),
(28776, 3011, 8, 'Très pauvres'),
(28777, 3014, 8, 'Avortement causé par'),
(28778, 3016, 8, 'Non éligible'),
(28779, 3017, 8, 'Infection / Abcès'),
(28780, 3018, 8, 'Infections'),
(28781, 3020, 8, 'Infertilité'),
(28782, 3021, 8, 'Vaccin anti-grippale 1'),
(28783, 3022, 8, 'Vaccin anti-grippale 2'),
(28784, 3023, 8, 'Vaccin anti-grippale pour Patients >=50 ans'),
(28785, 3024, 8, 'Vaccin anti-grippale pour Patients >=50 ans (LCQ)'),
(28786, 3025, 8, 'Vaccin anti-Grippal'),
(28787, 3034, 8, 'inhalations'),
(28788, 3037, 8, 'Utilisateur initial'),
(28789, 3039, 8, 'Injectables'),
(28790, 3040, 8, 'Injection'),
(28791, 3041, 8, 'Partie du corps blessée'),
(28792, 3043, 8, 'Blessure'),
(28793, 3044, 8, 'Méchanisme de blessure'),
(28794, 3045, 8, 'Rapport de la blessure vue d''ensemble'),
(28795, 3046, 8, 'Surveillance de la blessure'),
(28796, 3047, 8, 'Type de blessure'),
(28797, 3048, 8, 'Lié a la blessure/maladie'),
(28798, 3051, 8, 'Champs à insérer'),
(28799, 3053, 8, 'Ins 1'),
(28800, 3054, 8, 'Ins 2 ou Ins 3'),
(28801, 3055, 8, 'Adresse de l''ins'),
(28802, 3058, 8, 'Code de l''ins'),
(28803, 3059, 8, 'Groupe e l''ins'),
(28804, 3060, 8, 'Nom de l''ins'),
(28805, 3061, 8, 'Sur-payement de l''ins'),
(28806, 3062, 8, 'Politique de l''ins'),
(28807, 3063, 8, 'Rembourcement de l''ins'),
(28808, 3064, 8, 'Résumé de l''ins'),
(28809, 3065, 8, 'Ins1'),
(28810, 3066, 8, 'Ins2'),
(28811, 3067, 8, 'Ins3'),
(28812, 3069, 8, 'Insertion échoué: '),
(28813, 3070, 8, 'Insertion d''anciens evenements dans les tables'),
(28814, 3072, 8, 'Insomnie'),
(28815, 3073, 8, 'Inspecter les logs'),
(28816, 3074, 8, 'Inspection'),
(28817, 3075, 8, 'Instabilité / sous-luxation'),
(28818, 3076, 8, 'INSTALLER'),
(28819, 3077, 8, 'Installer'),
(28820, 3079, 8, 'installer DB'),
(28821, 3080, 8, 'Version installée'),
(28822, 3081, 8, 'Instruit'),
(28823, 3082, 8, 'Instruction'),
(28824, 3084, 8, 'Instructions:'),
(28825, 3085, 8, 'Stock insufisant pour le produit d''identifiant'),
(28826, 3086, 8, 'Diabètes necessitant de l''insuline'),
(28827, 3087, 8, 'Assurance'),
(28828, 3088, 8, 'assurance'),
(28829, 3091, 8, 'Balance de l''assurance'),
(28830, 3092, 8, 'Balance de l''assurance dû'),
(28831, 3093, 8, 'Comp d''assurance'),
(28832, 3094, 8, 'Companies d''assurance'),
(28833, 3095, 8, 'Companie d''assurance'),
(28834, 3096, 8, 'Rechercher/Ajouter une companie d''assurance'),
(28835, 3098, 8, 'Données de l''assurance'),
(28836, 3099, 8, 'Information sur l''assurance dans le fichier'),
(28837, 3100, 8, 'Numéros d''assurance'),
(28838, 3101, 8, 'Payement de l''assurance'),
(28839, 3103, 8, 'Fournisseur de l''assurance'),
(28840, 3106, 8, 'Assuré'),
(28841, 3109, 8, 'Déclin intellectuel'),
(28842, 3113, 8, 'Erreur interne - aucune pages ont été sélectionner!'),
(28843, 3114, 8, 'Erreur interne - l''ID du patient n''a pas été fournis!'),
(28844, 3115, 8, 'Erreur interne durant l''accès au fichier téléversé!'),
(28845, 3116, 8, 'Erreur interne!'),
(28846, 3117, 8, 'Erreur interne, aucun identifant de médicament spécifié'),
(28847, 3119, 8, 'Erreur interne: réclamation '),
(28848, 3120, 8, 'Erreur interne: rencontre'),
(28849, 3121, 8, 'Erreur interne: le pid ou la rencontre manque.'),
(28850, 3122, 8, 'Erreur interne: nous n''avons pas l''air d''être dans une rencontre'),
(28851, 3123, 8, 'Identifiant interne (pid)'),
(28852, 3126, 8, 'Envois interne'),
(28853, 3127, 8, 'Temps interne colllecté'),
(28854, 3128, 8, 'Devoir international'),
(28855, 3129, 8, 'interprète'),
(28856, 3130, 8, 'Besoin d''un interprète ?'),
(28857, 3131, 8, 'Maladie des interstices du poumon'),
(28858, 3132, 8, 'Intervale'),
(28859, 3133, 8, 'Intervale (minutes)'),
(28860, 3134, 8, 'Intervale entre les verification des messages (mettre à 0 pour faire uniquement des verifications manuel)'),
(28861, 3135, 8, 'Opération'),
(28862, 3136, 8, 'Opération fournis'),
(28863, 3137, 8, 'Intolérance'),
(28864, 3139, 8, 'Intramusculaire'),
(28865, 3140, 8, 'Intraveineuse'),
(28866, 3141, 8, 'Introduction'),
(28867, 3144, 8, 'Caractère invalide dans'),
(28868, 3147, 8, 'Taille invalide pour'),
(28869, 3148, 8, 'Caractère non numérique invalide dans'),
(28870, 3150, 8, 'Adresse du destinataire invaide. S''il vous plait essayez encore.'),
(28871, 3151, 8, 'Codes service invalident'),
(28872, 3152, 8, 'Source désignée invalide "'),
(28873, 3153, 8, 'Nom d''utilisateur ou mot de passe invalide'),
(28874, 3155, 8, 'Inventaire'),
(28875, 3156, 8, 'Activité de l''inventaire'),
(28876, 3157, 8, 'Inventaire et vente de médicaments et d''autres produits'),
(28877, 3158, 8, 'Inventaire et ventes de médicament seulement'),
(28878, 3159, 8, 'L''inventaire n''est pas disponible pour cette commande.'),
(28879, 3160, 8, 'Liste d''inventaire'),
(28880, 3161, 8, 'Transactions d''inventaire'),
(28881, 3162, 8, 'Facture'),
(28882, 3163, 8, 'facture'),
(28883, 3164, 8, 'Balance de facturation'),
(28884, 3165, 8, 'La balance de facturation ne peut pas être posté. Aucune rencontre est créée'),
(28885, 3166, 8, 'Date de facturation'),
(28886, 3167, 8, 'La facturaton n''a pas de date!'),
(28887, 3168, 8, 'Nombre de la facturation'),
(28888, 3169, 8, 'Nombre de référence de la facturation'),
(28889, 3173, 8, 'Facturation:'),
(28890, 3185, 8, 'Battement de corps irrégulier'),
(28891, 3186, 8, 'Irritabilité'),
(28892, 3187, 8, 'Irritation'),
(28893, 3188, 8, 'est une version différente du langage de la base de donnée suivante'),
(28894, 3189, 8, 'est une version différente de la base de donnée suivante'),
(28895, 3190, 8, 'est une version plus récente de la base de donnée suivant'),
(28896, 3191, 8, 'est un champ requis.'),
(28897, 3193, 8, 'est une extension de la base de donnée suivante'),
(28898, 3195, 8, 'est malplacé ou inconnu'),
(28899, 3197, 8, 'est non valide (les fractions décimale sont OK).'),
(28900, 3198, 8, 'Est PHP utilisant le mode de sureté?'),
(28901, 3202, 8, 'Le fichier est il chiffré ?'),
(28902, 3203, 8, 'Est un type de code pour un terme clinique?'),
(28903, 3204, 8, 'Est un type de diagnistic?'),
(28904, 3205, 8, 'Est un type de code pour un problème médicale?'),
(28905, 3207, 8, 'Est un type de procedure/service?'),
(28906, 3208, 8, 'Est actif?'),
(28907, 3209, 8, 'Ce type de code est-il actif?'),
(28908, 3210, 8, 'Ce type de code est-il utilisé dans les demandes?'),
(28909, 3212, 8, 'Ce type de code est-il actif?'),
(28910, 3213, 8, 'Est ce que ca utilise des tables sql externe? Si oui, alors choissiez le format.'),
(28911, 3214, 8, 'est trop long'),
(28912, 3216, 8, 'Problème'),
(28913, 3217, 8, 'problème'),
(28914, 3218, 8, 'Date du problème'),
(28915, 3219, 8, 'ID du problème'),
(28916, 3220, 8, 'Titre du problème'),
(28917, 3221, 8, 'Type du problème'),
(28918, 3222, 8, 'Type de problèmes'),
(28919, 3223, 8, 'Problèmes'),
(28920, 3224, 8, 'Problèmes (Blessures/Medicale/Alergies)'),
(28921, 3225, 8, 'Problèmes (Blessures/Medicale/Alergies):'),
(28922, 3226, 8, 'Problèmes et rencontres'),
(28923, 3227, 8, 'Problèmes et rencontres pour'),
(28924, 3228, 8, 'Problèmes non autorisé'),
(28925, 3229, 8, 'Partie des problèmes'),
(28926, 3230, 8, 'Italien'),
(28927, 3231, 8, 'Article'),
(28928, 3232, 8, 'article'),
(28929, 3233, 8, 'articles'),
(28930, 3234, 8, 'Chargement d''Articles a échoué'),
(28931, 3238, 8, 'janv.'),
(28932, 3239, 8, 'Janvier'),
(28933, 3240, 8, 'Japonais'),
(28934, 3241, 8, 'Jaunisse'),
(28935, 3243, 8, 'Description de la Tâche'),
(28936, 3244, 8, 'ID Tâche'),
(28937, 3245, 8, 'Dislocations conjointe'),
(28938, 3246, 8, 'Douleurs articulaires'),
(28939, 3247, 8, 'Entorses conjointe'),
(28940, 3248, 8, 'juil.'),
(28941, 3249, 8, 'Juillet'),
(28942, 3250, 8, 'juin'),
(28943, 3251, 8, 'Juin'),
(28944, 3252, 8, 'Juste en dessous l''information vérifié est une zone bleu ou vous mettez vos paramètres de recherche. Vous pouvez chercher en fonction du nom du patient, du numéro de graphique, du numéro de rencontre ou de la date de service, or n''importe quel combinaison. Vous pouvez aussi selectionner ce que vous voullez pour voir toutes les facturations, les facturations ouverte, ou seulement les facturation non payées (par le patient). Cliquez sur le bouton Rechercher pour effectuer la recherche.'),
(28945, 3253, 8, 'Seulement mien'),
(28946, 3254, 8, 'Entrée de la justification'),
(28947, 3255, 8, 'Justifier'),
(28948, 3256, 8, 'Justifier/Sauvegarder'),
(28949, 3264, 8, 'Clef'),
(28950, 3265, 8, 'Mots clef'),
(28951, 3266, 8, 'kg'),
(28952, 3267, 8, 'kg/m^2'),
(28953, 3269, 8, 'Cancer du rein'),
(28954, 3270, 8, 'Deficiance du rein'),
(28955, 3271, 8, 'Infections du rein'),
(28956, 3272, 8, 'Calculs rénale'),
(28957, 3273, 8, 'Transplantation de rein'),
(28958, 3277, 8, 'Genoux'),
(28959, 3278, 8, 'Problème au genoux'),
(28960, 3279, 8, 'Remplacement du genoux'),
(28961, 3282, 8, 'Coréen'),
(28962, 3286, 8, 'Lab'),
(28963, 3294, 8, 'Status de la requete pour le laboratoire'),
(28964, 3295, 8, 'Rapport du laboratoire'),
(28965, 3296, 8, 'Résultat du laboratoire'),
(28966, 3297, 8, 'Résultats du laboratoire'),
(28967, 3299, 8, 'Rapport des résultats du laboratoire'),
(28968, 3300, 8, 'Service du laboratoire'),
(28969, 3301, 8, 'Résultats des tests fait par le laboratoire'),
(28970, 3303, 8, 'Étiquette'),
(28971, 3304, 8, 'L''étiquette ne peut pas être vide'),
(28972, 3306, 8, 'Étiquette pour ce type'),
(28973, 3308, 8, 'Étiquettes'),
(28974, 3311, 8, 'Labs'),
(28975, 3312, 8, 'Lacération / problèmes de peau'),
(28976, 3313, 8, 'Lacération/abrasion'),
(28977, 3316, 8, 'Langue'),
(28978, 3317, 8, 'Code de la langue'),
(28979, 3318, 8, 'Définition de la langue ajouté'),
(28980, 3320, 8, 'Liste des langues (écriture, ajout seulement optionnel)'),
(28981, 3321, 8, 'Nom de la langue'),
(28982, 3322, 8, 'langue:'),
(28983, 3324, 8, 'Laotien'),
(28984, 3325, 8, 'Dernier'),
(28985, 3326, 8, 'Date de la dernière activité'),
(28986, 3328, 8, 'Date de la dernière facturation:'),
(28987, 3330, 8, 'Dernière année du calendrier'),
(28988, 3333, 8, 'Dernière rencontre'),
(28989, 3343, 8, 'Mois dernier'),
(28990, 3344, 8, 'Nom de Famille'),
(28991, 3345, 8, 'Nom de famille'),
(28992, 3346, 8, 'Nom de Famille:'),
(28993, 3350, 8, 'Dernière révision'),
(28994, 3352, 8, 'Dernière savegarde'),
(28995, 3356, 8, 'Dernière modification par'),
(28996, 3357, 8, 'Dernière verification sur'),
(28997, 3358, 8, 'Dernière visite'),
(28998, 3360, 8, 'Dernière récurrence (2-12 Mo)'),
(28999, 3361, 8, 'Maléolle latérale'),
(29000, 3362, 8, 'Maléolle latérale:'),
(29001, 3363, 8, 'Latéralité'),
(29002, 3381, 8, 'Colopathie fonctionnelle'),
(29003, 3383, 8, 'Laissez vide si encore actif'),
(29004, 3384, 8, 'Laissez vide pour garder le nom du fichier originel'),
(29005, 3385, 8, 'Laissez vide pour ne pas changer le mot de passe'),
(29006, 3386, 8, 'Laissez un message avec'),
(29007, 3387, 8, 'Laissez le formulaire'),
(29008, 3388, 8, 'Laisser le long mot de passe vide ne vas pas chiffrer le document'),
(29009, 3390, 8, 'Gauche'),
(29010, 3391, 8, 'Oreille Gauche'),
(29011, 3392, 8, 'oreille gauche'),
(29012, 3394, 8, 'Gauche:'),
(29013, 3395, 8, 'Gauche: '),
(29014, 3396, 8, 'Douleur à la jambe/Crampe'),
(29015, 3397, 8, 'Legale'),
(29016, 3399, 8, 'Taille Legale du papier'),
(29017, 3400, 8, 'Legende:'),
(29018, 3401, 8, 'Longueur'),
(29019, 3403, 8, 'Plus petit que'),
(29020, 3404, 8, 'Plus petit ou égale à'),
(29021, 3406, 8, 'Lettre'),
(29022, 3407, 8, 'Générateur de lettre'),
(29023, 3408, 8, 'Taille du papier à lettre'),
(29024, 3409, 8, 'Entête que les médecins signent'),
(29025, 3410, 8, 'Entête que les patients signent'),
(29026, 3411, 8, 'Niveau d''urgence'),
(29027, 3423, 8, 'Style de vie'),
(29028, 3424, 8, 'Satus du style de vie'),
(29029, 3425, 8, 'déchirrement du ligament ou entorse'),
(29030, 3426, 8, 'Petit fumeur de tabac'),
(29031, 3428, 8, 'Limite des évenements'),
(29032, 3429, 8, 'Limites'),
(29033, 3431, 8, 'Lien'),
(29034, 3432, 8, 'Lien au patient'),
(29035, 3433, 8, 'Lié'),
(29036, 3434, 8, 'Document lié'),
(29037, 3435, 8, 'Ordre de procédure lié'),
(29038, 3436, 8, 'Lié au document'),
(29039, 3437, 8, 'Lié à l''ordre de procédure'),
(29040, 3438, 8, 'Liste'),
(29041, 3439, 8, 'Boite de liste'),
(29042, 3440, 8, 'boite de liste'),
(29043, 3443, 8, 'Editeur de liste'),
(29044, 3444, 8, 'Liste des rencontres'),
(29045, 3445, 8, 'Liste des groupes'),
(29046, 3446, 8, 'Liste des compagnies d''assurance'),
(29047, 3448, 8, 'La liste d''élements ne peux pas commencer avec un nombre.'),
(29048, 3449, 8, 'La liste d''élements contient un/des caractères illegale/illegaux'),
(29049, 3451, 8, 'Liste de listes'),
(29050, 3452, 8, 'Liste de noms'),
(29051, 3453, 8, 'Liste de noms ne peux pas commencer par un nombres.'),
(29052, 3454, 8, 'Liste de prescriptions'),
(29053, 3458, 8, 'Listes'),
(29054, 3459, 8, 'Lithuanien'),
(29055, 3463, 8, 'Charger les collections'),
(29056, 3464, 8, 'Charger les définitions'),
(29057, 3465, 8, 'Charger la configuration du laboratoire'),
(29058, 3467, 8, 'Charger l''ordre des definitions'),
(29059, 3468, 8, 'Charger l''ordre des questions entré'),
(29060, 3470, 8, 'CHARGEMENT'),
(29061, 3471, 8, 'Chargement des fichiers dans la base de donnée. Ceci va prendre du temps...'),
(29062, 3473, 8, 'Locale'),
(29063, 3476, 8, 'Locale'),
(29064, 3477, 8, 'Localité'),
(29065, 3478, 8, 'Location'),
(29066, 3479, 8, 'location de la machine libreehr et peut contenir des données sensible, il est recommendé de supprimer manuelement les fichiers après leurs utilisation'),
(29067, 3480, 8, 'Location de ce lot'),
(29068, 3481, 8, 'Location non spécifié'),
(29069, 3482, 8, 'Location ou Hylafax stock les faxes.'),
(29070, 3483, 8, 'Location ou les scans sont stocké.'),
(29071, 3484, 8, 'Location:'),
(29072, 3485, 8, 'Verrous'),
(29073, 3492, 8, 'Connexion'),
(29074, 3493, 8, 'Connexion'),
(29075, 3494, 8, 'Déconnexion'),
(29076, 3495, 8, 'Connecté'),
(29077, 3496, 8, 'Connecté comme'),
(29078, 3497, 8, 'Connecté comme: '),
(29079, 3498, 8, 'Déconnecté'),
(29080, 3499, 8, 'Connecté'),
(29081, 3500, 8, 'Connexion'),
(29082, 3501, 8, 'Connexion'),
(29083, 3503, 8, 'Connexion a un hôte distant'),
(29084, 3504, 8, 'Connexion a cet hôte distant a échoué'),
(29085, 3505, 8, 'Déconnexion'),
(29086, 3506, 8, 'déconnexion'),
(29087, 3507, 8, 'Logs'),
(29088, 3508, 8, 'Afficheur des logs'),
(29089, 3511, 8, 'Lot'),
(29090, 3512, 8, 'L''ID du lot est manquante!'),
(29091, 3513, 8, 'Numéro du lot'),
(29092, 3514, 8, 'Faible'),
(29093, 3515, 8, 'Faible priorité'),
(29094, 3516, 8, 'mollet'),
(29095, 3517, 8, 'Priorité minimun'),
(29096, 3519, 8, 'Colonne lombaire'),
(29097, 3520, 8, 'Déjeuner'),
(29098, 3521, 8, 'Déjeuner'),
(29099, 3522, 8, 'Cancer du Poummon'),
(29100, 3523, 8, 'Chirurgie du Cancer de poumon'),
(29101, 3524, 8, 'POUMMONS:'),
(29102, 3525, 8, 'Poummons:'),
(29103, 3526, 8, 'Lupus'),
(29104, 3533, 8, 'Courriel envoyé'),
(29105, 3534, 8, 'Principale'),
(29106, 3535, 8, 'Adresse principale'),
(29107, 3537, 8, 'Maintenir actif la liste d''allergie médicale'),
(29108, 3538, 8, 'Maintenir actif la liste des médicaments'),
(29109, 3539, 8, 'Maintenir une liste à jour de problèmes des diagnostics actif'),
(29110, 3540, 8, 'Faire les modifications sur les catégories actuel.'),
(29111, 3541, 8, 'Faire un nouveau rendez-vous pour'),
(29112, 3545, 8, 'Malaise:'),
(29113, 3548, 8, 'Masculin'),
(29114, 3549, 8, 'Préservatifs Masculin'),
(29115, 3552, 8, 'Mammographie'),
(29116, 3553, 8, 'Gérer'),
(29117, 3556, 8, 'Gérer les traductions'),
(29118, 3557, 8, 'Gestion'),
(29119, 3558, 8, 'Les champs obligatoires et spécifiés'),
(29120, 3559, 8, 'Les champs obligatoires ou spécifié, contrôle de dup, pas de recherche'),
(29121, 3560, 8, 'Les champs obligatoires ou spécifié, recherche et contrôle de dup'),
(29122, 3561, 8, 'Manuel'),
(29123, 3562, 8, 'Postage Manuel'),
(29124, 3563, 8, 'Fabriquant'),
(29125, 3565, 8, 'mars'),
(29126, 3568, 8, 'Mars'),
(29127, 3569, 8, 'État civil'),
(29128, 3571, 8, 'Marquer comme facturés, mais la facturation est ignoré'),
(29129, 3572, 8, 'Marquer comme réglé'),
(29130, 3573, 8, 'Marquer comme non facturées'),
(29131, 3574, 8, 'Marquer ces rapports comme relue');
INSERT INTO `lang_definitions` VALUES
(29132, 3575, 8, 'Marquer comme réglé'),
(29133, 3576, 8, 'Marié'),
(29134, 3578, 8, 'Masque'),
(29135, 3579, 8, 'Masque pour les numéros de facturation'),
(29136, 3580, 8, 'Masque pour les ID Patient'),
(29137, 3581, 8, 'Masque pour les ID de produit'),
(29138, 3582, 8, 'Correspond'),
(29139, 3591, 8, 'Max'),
(29140, 3594, 8, 'Maxillaire droit:'),
(29141, 3595, 8, 'Age maximum'),
(29142, 3596, 8, 'Nombre de caractères maximun'),
(29143, 3597, 8, 'Le temps maximum d''inactivité en secondes avant la déconnexion. Par défaut est 7200 (2 heures).'),
(29144, 3600, 8, 'Inventaire maximale raisonnable, 0 si non applicable'),
(29145, 3601, 8, 'Taille maximum'),
(29146, 3602, 8, 'Taille maximum (entré 0 n''autorisera aucune taille'),
(29147, 3603, 8, 'Mai'),
(29148, 3607, 8, 'Aucun des trois dernier mot de passe ne sont autorisé lors du changement de mot de passe.'),
(29149, 3609, 8, 'Code du groupe de mesure'),
(29150, 3611, 8, 'Mesure'),
(29151, 3612, 8, 'Malléole interne:'),
(29152, 3613, 8, 'Couverture médicale minimum'),
(29153, 3614, 8, 'Médical'),
(29154, 3615, 8, 'Avortement médicamenteux'),
(29155, 3616, 8, 'Administration médical'),
(29156, 3617, 8, 'Antécédents médicaux'),
(29157, 3618, 8, 'Problème médical'),
(29158, 3619, 8, 'Problème médical'),
(29159, 3620, 8, 'Problème médical'),
(29160, 3621, 8, 'Problème Médical'),
(29161, 3622, 8, 'Liste de problemes médicaux'),
(29162, 3623, 8, 'Problèmes Médicaux'),
(29163, 3624, 8, 'Enregistrement Médical'),
(29164, 3625, 8, 'Pas d''enregistrement médical'),
(29165, 3626, 8, 'Enregistrements Médicaux'),
(29166, 3627, 8, 'Enregistrements médicaux envoyé'),
(29167, 3629, 8, 'Résumé médical fournis'),
(29168, 3630, 8, 'Système Médical'),
(29169, 3631, 8, 'Type Médical'),
(29170, 3632, 8, 'Médical/Historique (écriture, ajout seulement optionnel)'),
(29171, 3635, 8, 'Médication'),
(29172, 3640, 8, 'Médications'),
(29173, 3641, 8, 'Médications:'),
(29174, 3642, 8, 'Unités Médicale'),
(29175, 3643, 8, 'Moyen'),
(29176, 3646, 8, 'Problèmes de Mémoire'),
(29177, 3647, 8, 'Homme'),
(29178, 3648, 8, 'Hommes et Femmes'),
(29179, 3649, 8, 'Hommes Seulement'),
(29180, 3650, 8, 'Ménarche'),
(29181, 3651, 8, 'Ménopause'),
(29182, 3652, 8, 'Flux Menstruel'),
(29183, 3653, 8, 'Fréquence Menstruel'),
(29184, 3654, 8, 'Maladie Mentale'),
(29185, 3657, 8, 'Fusionner'),
(29186, 3658, 8, 'Fusion finis.'),
(29187, 3659, 8, 'Fusion des patients'),
(29188, 3661, 8, 'Message'),
(29189, 3662, 8, 'Message et centre de rappel'),
(29190, 3663, 8, 'Le contenu n''est pas uniquement du texte donc il a été stocké comme un document.'),
(29191, 3665, 8, 'Message envoyé'),
(29192, 3666, 8, 'Etat du Message'),
(29193, 3669, 8, 'Type du message'),
(29194, 3670, 8, 'MESSAGE:'),
(29195, 3671, 8, 'Messages'),
(29196, 3672, 8, 'Messages que vous avez envoyer aujourd''hui'),
(29197, 3673, 8, 'Méthode'),
(29198, 3674, 8, 'Méthode et Produit Spécifique'),
(29199, 3675, 8, 'Mode d''envoi e-mails sortants.'),
(29200, 3676, 8, 'Méthode de Destruction'),
(29201, 3679, 8, 'mg'),
(29202, 3680, 8, 'mg/1cc'),
(29203, 3681, 8, 'mg/2cc'),
(29204, 3682, 8, 'mg/3cc'),
(29205, 3683, 8, 'mg/4cc'),
(29206, 3684, 8, 'mg/5cc'),
(29207, 3685, 8, 'MG/DL'),
(29208, 3686, 8, 'Moyen'),
(29209, 3687, 8, 'Deuxième Prénom'),
(29210, 3688, 8, 'Deuxième prénom'),
(29211, 3696, 8, 'Immigrant ou travailleur saisonnier?'),
(29212, 3697, 8, 'Immigrant/Saisonnier'),
(29213, 3703, 8, 'Min'),
(29214, 3704, 8, 'min'),
(29215, 3705, 8, 'Age minimum'),
(29216, 3708, 8, 'Minute'),
(29217, 3709, 8, 'minutes'),
(29218, 3710, 8, 'Minutes'),
(29219, 3712, 8, 'Divers'),
(29220, 3713, 8, 'Autres Options de Facturation'),
(29221, 3714, 8, 'Autres Options de Facturation pour HCFA-1500'),
(29222, 3715, 8, 'Autres Options de Facturation HCFA'),
(29223, 3716, 8, 'Divers/Autres'),
(29224, 3717, 8, 'Manqué'),
(29225, 3718, 8, 'manquante'),
(29226, 3719, 8, 'Manque d''un champ requis'),
(29227, 3720, 8, 'Frais Manquants'),
(29228, 3721, 8, 'Mods manquants seulement'),
(29229, 3722, 8, 'Manquant ou Invalide'),
(29230, 3723, 8, 'PID manquant.'),
(29231, 3724, 8, 'Manque date de rapport'),
(29232, 3726, 8, 'Mixe'),
(29233, 3727, 8, 'ml'),
(29234, 3728, 8, 'MM/JJ/AAAA'),
(29235, 3729, 8, 'mm/hg'),
(29236, 3730, 8, 'mmHg'),
(29237, 3733, 8, 'Portable'),
(29238, 3734, 8, 'Téléphone portable'),
(29239, 3735, 8, 'Mod'),
(29240, 3738, 8, 'Priorité modéré'),
(29241, 3740, 8, 'Priorité modéré/faible'),
(29242, 3741, 8, 'Modificateur'),
(29243, 3742, 8, 'Modificateurs'),
(29244, 3743, 8, 'Modifié'),
(29245, 3745, 8, 'Modifier les Paiements'),
(29246, 3753, 8, 'Lu.'),
(29247, 3754, 8, 'Lu. à Ve.'),
(29248, 3755, 8, 'Lu. Mer. &amp; Ve.'),
(29249, 3756, 8, 'Lundi'),
(29250, 3758, 8, 'Mois'),
(29251, 3759, 8, 'mois'),
(29252, 3760, 8, 'Vue du Mois'),
(29253, 3761, 8, 'Mois'),
(29254, 3762, 8, 'Revenue Mensuel'),
(29255, 3763, 8, 'Mois'),
(29256, 3765, 8, 'Plus de 100 enregistrement trouvé. S''il vous plait utilisez des critères de recherches plus précis'),
(29257, 3766, 8, 'Plus de 50 enregistrement trouvé. S''il vous plait utilisez des critères de recherches plus précis'),
(29258, 3767, 8, 'La plupart des entêtes de colonnes peuvent êtres cliquées pour changer l''ordre de trie'),
(29259, 3768, 8, 'Formulaire le plus récent'),
(29260, 3770, 8, 'Formulaire des constantes vitales le plus récent:'),
(29261, 3771, 8, 'Mère'),
(29262, 3772, 8, 'Nom de la Mère'),
(29263, 3774, 8, 'Bouche'),
(29264, 3775, 8, 'Déplacer'),
(29265, 3776, 8, 'Déplacer un document vers Catégorie:'),
(29266, 3777, 8, 'Déplacer vers bas'),
(29267, 3778, 8, 'Déplacement échoué!'),
(29268, 3779, 8, 'Déplacer vers le patient'),
(29269, 3780, 8, 'Déplacer vers ...'),
(29270, 3781, 8, 'Déplacer vers haut'),
(29271, 3782, 8, 'Déplacement'),
(29272, 3783, 8, 'M.'),
(29273, 3785, 8, 'Mme.'),
(29274, 3786, 8, 'Mlle.'),
(29275, 3796, 8, 'Outil multi langues'),
(29276, 3797, 8, 'Zones multiples'),
(29277, 3798, 8, 'Plusieurs fichiers peuvent êtres téléchargé en une seule fois en les sélectionnant en utilisant CTRL+Clic ou SHIFT+Clic.'),
(29278, 3799, 8, 'Plusieurs lots'),
(29279, 3800, 8, 'Plusieurs modificateur peuvent êtres separé par les colonnes ou des espaces, 4 maximum (M1:M2:M3:M4)'),
(29280, 3802, 8, 'Multiracial'),
(29281, 3803, 8, 'Murmur:'),
(29282, 3804, 8, 'Douleurs musculaires'),
(29283, 3805, 8, 'Douleurs musculaires'),
(29284, 3806, 8, 'Rougeur musculaire'),
(29285, 3807, 8, 'Raideur musculaire'),
(29286, 3808, 8, 'Enflure musculaire'),
(29287, 3809, 8, 'Chaleur musculaire'),
(29288, 3810, 8, 'Muscle'),
(29289, 3811, 8, 'Lésion musculaire'),
(29290, 3812, 8, 'Musculo-squelettiques'),
(29291, 3813, 8, 'Doit être vide si l''autentification SMTP n''est pas utilisé.'),
(29292, 3814, 8, 'Définis Mutuellement'),
(29293, 3818, 8, 'Moi-même'),
(29294, 3821, 8, 'N/A'),
(29295, 3822, 8, 'n/a'),
(29296, 3823, 8, 'Nom'),
(29297, 3825, 8, 'Nom (Cliquer pour plus de détails)'),
(29298, 3826, 8, 'Nom 1'),
(29299, 3827, 8, 'Nom 2'),
(29300, 3828, 8, 'Nom et titre de l''administrateur de la vaccination'),
(29301, 3831, 8, 'Nom des événements'),
(29302, 3832, 8, 'Nom de la societé d''assurance'),
(29303, 3833, 8, 'Nom du fournisseur'),
(29304, 3834, 8, 'Nom de l''expéditeur pour les rappels des patients.'),
(29305, 3835, 8, 'Traduction du nom'),
(29306, 3836, 8, 'Nom/Valeur'),
(29307, 3837, 8, 'Nom:'),
(29308, 3840, 8, 'Mucoses nasal rose, cloison médiane'),
(29309, 3841, 8, 'Notes des pays'),
(29310, 3842, 8, 'Configuré les notes des pays'),
(29311, 3844, 8, 'Nationalité'),
(29312, 3847, 8, 'Natifs d''Hawaii ou autres îles du Pacifique'),
(29313, 3852, 8, 'Nausée'),
(29314, 3854, 8, 'Navigation'),
(29315, 3855, 8, 'Zone de navigation comprend des formulaires de rencontre'),
(29316, 3856, 8, 'Zone de navigation utilise plein hauteur des cadres'),
(29317, 3858, 8, 'Largeur de la zone de navigation'),
(29318, 3859, 8, 'Menu de navigation composée de paires de boutons radio'),
(29319, 3860, 8, 'Menu de navigation est une arborescence'),
(29320, 3861, 8, 'Navigation utilise un menu coulissant'),
(29321, 3866, 8, 'Cou'),
(29322, 3867, 8, 'Problèmes de cou'),
(29323, 3868, 8, 'Cou souple'),
(29324, 3869, 8, 'Vous devez saisir une description'),
(29325, 3870, 8, 'Vous devez saisir une valeur de retour'),
(29326, 3871, 8, 'Vous devez saisir un identifiant'),
(29327, 3872, 8, 'Vous devez saisir le titre'),
(29328, 3873, 8, 'Besoin d''authentification'),
(29329, 3874, 8, 'Besoin de justification'),
(29330, 3875, 8, 'Besoins de facturation secondaire'),
(29331, 3876, 8, 'Négatif'),
(29332, 3877, 8, 'Négatifs'),
(29333, 3880, 8, 'Blessures aux nerfs'),
(29334, 3881, 8, 'Problèmes neuraux / damage neuraux'),
(29335, 3882, 8, 'Engourdissement neurale'),
(29336, 3883, 8, 'Faiblaisse neurale'),
(29337, 3884, 8, 'Neurologique'),
(29338, 3885, 8, 'Jamais'),
(29339, 3886, 8, 'Jamais alcoolique'),
(29340, 3887, 8, 'Jamais fumeur'),
(29341, 3888, 8, 'Nouveau7'),
(29342, 3889, 8, 'Nouveau =>'),
(29343, 3892, 8, 'Nouvelle allergie'),
(29344, 3894, 8, 'Nouveau rendez-vous'),
(29345, 3895, 8, 'Nouvelles catégories'),
(29346, 3896, 8, 'Nouvelle catégorie'),
(29347, 3897, 8, 'Nouveaux clients'),
(29348, 3898, 8, 'Nouvelle consultation'),
(29349, 3899, 8, 'Nouvelle récolte'),
(29350, 3900, 8, 'Nouvel ensemble de définition ajouté'),
(29351, 3901, 8, 'Nouveau document'),
(29352, 3902, 8, 'Nouveaux Documents'),
(29353, 3904, 8, 'Nouvelle rencontre'),
(29354, 3905, 8, 'Nouvelle rencontre créé avec l''id'),
(29355, 3906, 8, 'Nouveau formulaire de rencontre'),
(29356, 3907, 8, 'De nouvelles rencontres ne sont pas autorisées'),
(29357, 3909, 8, 'Information d''un nouveau locale'),
(29358, 3910, 8, 'Nouveau fichier'),
(29359, 3911, 8, 'Nouveaux Fichiers'),
(29360, 3912, 8, 'Nouveau groupe'),
(29361, 3913, 8, 'Nouvelle information du Groupe'),
(29362, 3914, 8, 'Nouvelle blessure/status'),
(29363, 3916, 8, 'Nouvelle limite d''événements'),
(29364, 3917, 8, 'Nouvelle liste'),
(29365, 3918, 8, 'Nouvelles commandes'),
(29366, 3919, 8, 'Nouveau paragraphe'),
(29367, 3920, 8, 'Nouveau mot de passe'),
(29368, 3921, 8, 'nouveau patient'),
(29369, 3922, 8, 'NOUVEAU PATIENT'),
(29370, 3923, 8, 'Nouvelle rencontre avec le patient'),
(29371, 3924, 8, 'Nouveau formulaire du patient'),
(29372, 3925, 8, 'Nouvel ID du patient'),
(29373, 3926, 8, 'Nouveau paiement'),
(29374, 3929, 8, 'De nouveaux résultats de Lab Exchange'),
(29375, 3930, 8, 'Nouvelle recherche'),
(29376, 3931, 8, 'Nouvelles demandes'),
(29377, 3932, 8, 'Nouvel utilisateur'),
(29378, 3934, 8, 'Nouvelle visite'),
(29379, 3935, 8, 'Nouveau/Recherche'),
(29380, 3936, 8, 'NewCrop Statut du compte'),
(29381, 3937, 8, 'NewCrop Admin'),
(29382, 3938, 8, 'NewCrop Echec de l''appel'),
(29383, 3939, 8, 'NewCrop Docteur'),
(29384, 3944, 8, 'NewCrop Nom eRx'),
(29385, 3945, 8, 'NewCrop Nom du partenaire eRx'),
(29386, 3946, 8, 'NewCrop mot de passe eRx'),
(29387, 3947, 8, 'NewCrop rôle eRx'),
(29388, 3948, 8, 'NewCrop rôle eRx'),
(29389, 3949, 8, 'NewCrop adresse du site eRx'),
(29390, 3954, 8, 'NewCrop Adresse Web de Service eRx'),
(29391, 3955, 8, 'NewCrop gérant'),
(29392, 3958, 8, 'NewCrop Infirmière'),
(29393, 3959, 8, 'NewCrop médecin superviseur'),
(29394, 3961, 8, 'Journal'),
(29395, 3962, 8, 'Suivant'),
(29396, 3964, 8, 'Jour suivant'),
(29397, 3965, 8, 'Mois suivant'),
(29398, 3966, 8, 'Le mois prochain (maintenir enfoncé pour le menu)'),
(29399, 3967, 8, 'Prochaine exécution prévue'),
(29400, 3968, 8, 'Semaine suivante'),
(29401, 3969, 8, 'l''année prochaine (maintenir enfoncé pour le menu)'),
(29402, 3971, 8, 'Pseudonyme'),
(29403, 3973, 8, 'Sueurs nocturne'),
(29404, 3974, 8, 'Parties génitale feminine, mucose vaginale, col de l''utérus'),
(29405, 3975, 8, 'Non'),
(29406, 3976, 8, 'NON'),
(29407, 3977, 8, 'Pas d''accès'),
(29408, 3978, 8, 'Aucun rappel pour le patient actif.'),
(29409, 3979, 8, 'Pas d''adénopathie (2 zones sont requises)'),
(29410, 3983, 8, 'Aucun rendez-vous'),
(29411, 3985, 8, 'Aucun système de payement est actuelement actif'),
(29412, 3989, 8, 'Aucun code a été spécifié!'),
(29413, 3992, 8, 'Pas de diagnostic'),
(29414, 3993, 8, 'Pas de document trouvé'),
(29415, 3994, 8, 'Aucune rencontre ne peut être crée'),
(29416, 3995, 8, 'Pas de date de fin'),
(29417, 3996, 8, 'Pas d''entrés trouvé, utilisé le formulaire si dessous pour ajouter une entré.'),
(29418, 3997, 8, 'Pas d''erreurs trouvé'),
(29419, 3998, 8, 'Pas d''evenements'),
(29420, 4001, 8, 'Aucun groupe n''a été sélectionné'),
(29421, 4002, 8, 'Pas d''hernie'),
(29422, 4005, 8, 'Pas de blessures/maladies'),
(29423, 4006, 8, 'Pas de compagnie d''assurance trouvé'),
(29424, 4007, 8, 'Pas de problèmes'),
(29425, 4008, 8, 'Pas de problèmes sur cette rencontre'),
(29426, 4009, 8, 'Pas d''objets dans la catégorie sélectionné'),
(29427, 4010, 8, 'Aucun objets n''a été sélectionné!'),
(29428, 4025, 8, 'Aucun fichier de logs pour la date sélectionné'),
(29429, 4027, 8, 'Pas de masses, tendresse'),
(29430, 4028, 8, 'Aucun patient ne correspond au code d''identification'),
(29431, 4029, 8, 'Aucune correspondance trouvé. Essayez de rechercher encore.'),
(29432, 4030, 8, 'Pas de correspondances trouvé.'),
(29433, 4031, 8, 'Pas de correspondances trouvé. Crée un nouveau patient?'),
(29434, 4032, 8, 'Pas de données correspondante trouvé'),
(29435, 4033, 8, 'Aucun nouveau resultats trouvé'),
(29436, 4034, 8, 'Pas de notes'),
(29437, 4036, 8, 'Aucune ouverture ont été trouvé sur cette période.'),
(29438, 4037, 8, 'Pas d''autres numéros de téléphone listé'),
(29439, 4039, 8, 'Pas de partenaire trouvé'),
(29440, 4040, 8, 'Pas d''enregistrement de patient trouvé pour les critères sélectionné'),
(29441, 4041, 8, 'Pas d''enregistrement de patient trouvé pour le code d''identification'),
(29442, 4042, 8, 'Pas d''eudème périphérique'),
(29443, 4043, 8, 'Pas de pharmacies trouvée'),
(29444, 4044, 8, 'Pas de prescriptions trouvé'),
(29445, 4045, 8, 'Ne présente pas de maladie/blessure'),
(29446, 4046, 8, 'Pas d''entrés précédente.'),
(29447, 4048, 8, 'Pas de rencontre précedentes'),
(29448, 4049, 8, 'Pas de procédures sur cette rencontre.'),
(29449, 4051, 8, 'Pas de fournisseurs trouvé.'),
(29450, 4052, 8, 'Pas de rashes ou de lésions annormale'),
(29451, 4053, 8, 'Pas d''enregistrement trouvé'),
(29452, 4055, 8, 'Pas d''enregistrement trouvé. S''ils vous plait généralisé vos critères de recherche.'),
(29453, 4056, 8, 'Pas de rapels'),
(29454, 4057, 8, 'Pas de résultats trouvé, pour les critères de recherches ci-dessus'),
(29455, 4058, 8, 'Pas de résultats'),
(29456, 4059, 8, 'Pas de résultats trouvé'),
(29457, 4060, 8, 'Pas de résultats trouvé pour la recherche'),
(29458, 4061, 8, 'Pas de résultats trouvé, s''il vous plait essayez encore.'),
(29459, 4062, 8, 'Pas de résultats, s''il vous plait essayez encore.'),
(29460, 4063, 8, 'Pas de résultats, s''il vous plait essayez encore.'),
(29461, 4065, 8, 'Pas d''affichage'),
(29462, 4067, 8, 'Pas de tendresse des sinus'),
(29463, 4068, 8, 'Pas de criblage de la peau ou de nodules dans les seins'),
(29464, 4070, 8, 'Pas de table sélectionné. Sélectionnez une table.'),
(29465, 4071, 8, 'Pas de tendresses/masses testiculaire'),
(29466, 4072, 8, 'Pas de frissons ou de nausées'),
(29467, 4075, 8, 'Pas de visite'),
(29468, 4076, 8, 'Aucun signe vitaux n''a été documenté.'),
(29469, 4077, 8, 'Non, annulation'),
(29470, 4079, 8, 'Non:'),
(29471, 4081, 8, 'Non payé'),
(29472, 4082, 8, 'Enregistrement non reporté'),
(29473, 4083, 8, 'Pas de blessure spécifique'),
(29474, 4085, 8, 'Diabètes non dépendant a l''insuline'),
(29475, 4086, 8, 'Non assuré'),
(29476, 4089, 8, 'Aucun(e)'),
(29477, 4090, 8, 'aucun(e)'),
(29478, 4091, 8, 'Aucun défini'),
(29479, 4092, 8, 'Aucun n''a été documenté'),
(29480, 4093, 8, 'Aucun de ceux au dessus'),
(29481, 4095, 8, 'Diabètes non dépendant a l''insuline'),
(29482, 4097, 8, 'Normale'),
(29483, 4099, 8, 'Examen cardiaque normal:'),
(29484, 4100, 8, 'Examen cardiaque normal: '),
(29485, 4101, 8, 'Examen des poumons normal:'),
(29486, 4102, 8, 'Examen des poumons normal: '),
(29487, 4103, 8, 'Visite normale du bureau'),
(29488, 4105, 8, 'Droite normale'),
(29489, 4106, 8, 'Droite normale:'),
(29490, 4107, 8, 'Vue normale:'),
(29491, 4108, 8, 'normal(e):'),
(29492, 4109, 8, 'Normalement cela devrait etre vérifié. N''est pas relié au controle d''acces'),
(29493, 4112, 8, 'Norvegien'),
(29494, 4115, 8, 'Nez'),
(29495, 4116, 8, 'Saignement du nez'),
(29496, 4117, 8, 'N''est pas une lettre ou un nombre'),
(29497, 4119, 8, 'Tout les champs ne sont pas requis pour tout les codes ou types de codes'),
(29498, 4120, 8, 'Non autorisé'),
(29499, 4121, 8, 'Suppression du groupe d''administration n''est pas autorisé'),
(29500, 4122, 8, 'Edition non autorisé'),
(29501, 4123, 8, 'Désactiver tout les objets de sécurité n''est pas autorisé'),
(29502, 4127, 8, 'Non applicable'),
(29503, 4129, 8, 'Non autorisé'),
(29504, 4130, 8, 'Non Autorisé'),
(29505, 4131, 8, 'Non autorisé pour ce groupe!'),
(29506, 4132, 8, 'Non autorisé pour ce groupe.'),
(29507, 4133, 8, 'Gestion des utilisateur non autorisé'),
(29508, 4134, 8, 'Signer les resultats n''est pas autorisé'),
(29509, 4135, 8, 'Non disponible'),
(29510, 4137, 8, 'Non facturé'),
(29511, 4138, 8, 'Non vérifié'),
(29512, 4140, 8, 'Non codé'),
(29513, 4141, 8, 'Non dû'),
(29514, 4143, 8, 'Non examiné'),
(29515, 4144, 8, 'Non examiné:'),
(29516, 4145, 8, 'Non examiné: '),
(29517, 4146, 8, 'non trouvé'),
(29518, 4148, 8, 'non trouvé!'),
(29519, 4149, 8, 'N''est pas hispanique ou Latino'),
(29520, 4150, 8, 'Non installé'),
(29521, 4152, 8, 'N''a pas été vue depuis'),
(29522, 4153, 8, 'Non envoyé'),
(29523, 4154, 8, 'Non envoyé pour le moment'),
(29524, 4155, 8, 'Non spécifié'),
(29525, 4156, 8, 'Non spécifié.'),
(29526, 4157, 8, 'Note'),
(29527, 4158, 8, 'Codes des notes'),
(29528, 4159, 8, 'Cela va prendre 5 à 10 min pour finir le processus après avoir cliqué sur installer'),
(29529, 4160, 8, 'Cela va prendre 5 à 10 min pour finir le processus après avoir cliqué sur mettre à jour'),
(29530, 4162, 8, 'Type de la note'),
(29531, 4172, 8, 'Notes'),
(29532, 4173, 8, 'Notes - toutes rencontres (écriture, ajout seulement optionnel)'),
(29533, 4174, 8, 'Notes - mes rencontres (écriture, ajout seulement optionnel)'),
(29534, 4175, 8, 'Notes non autorisé'),
(29535, 4177, 8, 'Rien d''enregistré'),
(29536, 4179, 8, 'Rien à importé pour les allergies'),
(29537, 4180, 8, 'Rien à importé pour les prescriptions'),
(29538, 4181, 8, 'Rien a montrer'),
(29539, 4182, 8, 'Rien n''a été sélectionné'),
(29540, 4185, 8, 'Notification'),
(29541, 4186, 8, 'Notification d''adresse courriel'),
(29542, 4188, 8, 'Notifications'),
(29543, 4189, 8, 'Notifié l''admin au sujet des evenement de soumission/modifiation ?'),
(29544, 4190, 8, 'Nov.'),
(29545, 4191, 8, 'Novembre'),
(29546, 4192, 8, 'Poster maintenant pour:'),
(29547, 4193, 8, 'Imprimer maintenant'),
(29548, 4200, 8, 'Nombre'),
(29549, 4201, 8, 'Nombre de labos'),
(29550, 4204, 8, 'Nombre de colonnes dans la vue annuelle.'),
(29551, 4211, 8, 'Nombre de jours ou le certificat client est valide.'),
(29552, 4213, 8, 'Nombre de chiffre après le point décimale pour la monnais, habituellement 0 ou 2'),
(29553, 4214, 8, 'Nombre de rencontres a afficher par pages.'),
(29554, 4215, 8, 'Nombre de jeux ou d''evenements manqué, si il y a'),
(29555, 4216, 8, 'Nombre d''heures d''avance pour les notifications courriel.'),
(29556, 4217, 8, 'Nombre d''heures d''avance pour les notifications téléphonique.'),
(29557, 4218, 8, 'Nombre d''heures d''avance pour les notifications SMS.'),
(29558, 4222, 8, 'Nombre de patient à afficher par page dans la liste de patients'),
(29559, 4225, 8, 'Affichage par ordre numérique'),
(29560, 4227, 8, 'Nutrition'),
(29561, 4231, 8, 'Obésité I'),
(29562, 4232, 8, 'Obésité II'),
(29563, 4233, 8, 'Obésité III'),
(29564, 4234, 8, 'Objectif'),
(29565, 4237, 8, 'Occupation'),
(29566, 4239, 8, 'Occurence'),
(29567, 4240, 8, 'Oct'),
(29568, 4241, 8, 'Octobre'),
(29569, 4242, 8, 'OD'),
(29570, 4243, 8, 'de'),
(29571, 4244, 8, 'de quantité'),
(29572, 4245, 8, 'de tablettes'),
(29573, 4249, 8, 'Notes du bureau'),
(29574, 4250, 8, 'Visite du bureau'),
(29575, 4263, 8, 'descendance'),
(29576, 4267, 8, 'OK'),
(29577, 4269, 8, 'OK pour lié le problème GCAC daté'),
(29578, 4270, 8, 'Ancien'),
(29579, 4272, 8, 'Clients anciens'),
(29580, 4274, 8, 'Ancien type d''affichage sans menu à gauche'),
(29581, 4277, 8, 'Oublier'),
(29582, 4278, 8, 'Circomférences oubliées'),
(29583, 4279, 8, 'Informations sur l''employeur oubliées dans Données démographiques du patient'),
(29584, 4280, 8, 'Employeurs oubliés'),
(29585, 4282, 8, 'Oublit de l''assurance et diverses autres choses dans le formulaire démographique'),
(29586, 4283, 8, 'Utilisateurs internes oubliés?'),
(29587, 4286, 8, 'sur'),
(29588, 4287, 8, 'Sur'),
(29589, 4288, 8, 'Sur la main'),
(29590, 4289, 8, 'Sur l''ordre'),
(29591, 4290, 8, 'Sur le site'),
(29592, 4292, 8, 'Une fois que vous avez changé votre mot de passe, vous devez vous reconnecter'),
(29593, 4297, 8, 'Support en ligne'),
(29594, 4298, 8, 'Lien du support en ligne'),
(29595, 4299, 8, 'Actif seulement'),
(29596, 4302, 8, 'Seulement si location de la facturation'),
(29597, 4303, 8, 'Seulement innactif'),
(29598, 4304, 8, 'Seulement mien'),
(29599, 4305, 8, 'Montré uniquement les codes de diagnostique rapporté'),
(29600, 4307, 8, 'Mettre a jour uniquement les prescriptions actives'),
(29601, 4310, 8, 'Commencement de la maladie:'),
(29602, 4311, 8, 'Commencement de la maladie: '),
(29603, 4312, 8, 'Commencement de l''enflure'),
(29604, 4313, 8, 'Date du début d''hospatilisation'),
(29605, 4315, 8, 'Oops!'),
(29606, 4316, 8, 'Ouvrir'),
(29607, 4318, 8, 'Ouvrir dans une nouvelle fenètre'),
(29608, 4321, 8, 'Ouvrir les visites d''aujourd''hui'),
(29609, 4322, 8, 'LibreEHR a déjà un certificat d''autorité configuré'),
(29610, 4324, 8, 'Mettre à jour la base de donnée d''LibreEHR'),
(29611, 4329, 8, 'Utilisateurs d''LibreEHR'),
(29612, 4330, 8, 'Ouvertures'),
(29613, 4333, 8, 'Option'),
(29614, 4336, 8, 'Optionneil'),
(29615, 4350, 8, 'Options'),
(29616, 4351, 8, 'Ou'),
(29617, 4352, 8, 'OU'),
(29618, 4353, 8, 'ou choisir'),
(29619, 4354, 8, 'ou cliquer et glisser pour une sélection plus rapide.'),
(29620, 4358, 8, 'Ou Shift-clic pour le diminuer'),
(29621, 4359, 8, 'Ou téléverser un fchier ERA:'),
(29622, 4360, 8, 'Oral'),
(29623, 4361, 8, 'Mucoses buccal roses, gorge normale'),
(29624, 4362, 8, 'Commander'),
(29625, 4363, 8, 'Commander et types de resultats'),
(29626, 4364, 8, 'Catalogue de commande'),
(29627, 4365, 8, 'Date de la commande'),
(29628, 4367, 8, 'Commander depuis'),
(29629, 4368, 8, 'ID de la commande'),
(29630, 4381, 8, 'Commandé'),
(29631, 4382, 8, 'Commandé par'),
(29632, 4386, 8, 'Blessure à l''organe'),
(29633, 4387, 8, 'Organisation'),
(29634, 4388, 8, 'Nom de l''organisation'),
(29635, 4390, 8, 'Organisations'),
(29636, 4392, 8, 'Original'),
(29637, 4397, 8, 'Orthopédiee'),
(29638, 4402, 8, 'Autre'),
(29639, 4403, 8, 'autre'),
(29640, 4404, 8, 'Autre (spécifier)'),
(29641, 4405, 8, 'Autre - Spécifié'),
(29642, 4406, 8, 'Autre programe fédérale'),
(29643, 4408, 8, 'Autre blessure, pas d''autre endroit spécifié'),
(29644, 4410, 8, 'autre mois'),
(29645, 4411, 8, 'Autre programes non-fédérale'),
(29646, 4412, 8, 'Autres Notes'),
(29647, 4413, 8, 'Autres symptômes pertinents'),
(29648, 4414, 8, 'Autres symptômes pertinents:'),
(29649, 4417, 8, 'Autre chirurgie'),
(29650, 4418, 8, 'Autre choses relié à l''avortement'),
(29651, 4420, 8, 'Autres'),
(29652, 4421, 8, 'sinon vous allez detruire des references à/de données existantes.'),
(29653, 4423, 8, 'OU'),
(29654, 4424, 8, 'En dehors'),
(29655, 4425, 8, 'En dehors du bureau'),
(29656, 4426, 8, 'Rapport de départ'),
(29657, 4427, 8, 'Dépenses'),
(29658, 4428, 8, 'Outlook'),
(29659, 4431, 8, 'Trop de dettes'),
(29660, 4432, 8, 'Trop d''utilisation'),
(29661, 4433, 8, 'Vue générale'),
(29662, 4434, 8, 'Sucharge pondérale'),
(29663, 4437, 8, 'Saturation d''O2'),
(29664, 4440, 8, 'pc'),
(29665, 4441, 8, 'pm'),
(29666, 4442, 8, 'prn'),
(29667, 4444, 8, 'Pédiatrique'),
(29668, 4445, 8, 'Page'),
(29669, 4446, 8, 'Pages'),
(29670, 4447, 8, 'Payé'),
(29671, 4450, 8, 'Payé avec'),
(29672, 4451, 8, 'Douleur'),
(29673, 4453, 8, 'Palpitation'),
(29674, 4455, 8, 'Test de Pap'),
(29675, 4456, 8, 'Papier'),
(29676, 4457, 8, 'Taille du papier'),
(29677, 4458, 8, 'Paralysie'),
(29678, 4463, 8, 'Partenaire'),
(29679, 4464, 8, 'Nom du partenaire'),
(29680, 4470, 8, 'Alerte passive'),
(29681, 4471, 8, 'Règles d''alerte passive'),
(29682, 4472, 8, 'Mot de passe'),
(29683, 4473, 8, 'Modification de mot de passe'),
(29684, 4474, 8, 'Mot de passe modifié avec succes'),
(29685, 4475, 8, 'Mot de passe modifié avec succes.'),
(29686, 4477, 8, 'Periode de grâce avant expiration du mot de passe'),
(29687, 4486, 8, 'Mot de passe:'),
(29688, 4487, 8, 'Les mots de passes ne correspondent pas!'),
(29689, 4488, 8, 'Anciens rendez-vous'),
(29690, 4489, 8, 'Gadget d''affichage d''ancien rendez-vous'),
(29691, 4490, 8, 'Dû passé'),
(29692, 4491, 8, 'Dû Passé'),
(29693, 4494, 8, 'Liste de rencontres passées'),
(29694, 4495, 8, 'Rencontres passées'),
(29695, 4496, 8, 'Rencontres passées et documents'),
(29696, 4497, 8, 'Rencontrres passées pour'),
(29697, 4514, 8, 'Patient'),
(29698, 4515, 8, 'patient'),
(29699, 4516, 8, 'PATIENT'),
(29700, 4517, 8, 'L''adresse du patient manque'),
(29701, 4518, 8, 'L''adresse du patient'),
(29702, 4521, 8, 'Allergies du patient'),
(29703, 4522, 8, 'Allergies du Patient'),
(29704, 4523, 8, 'Rendez-vous du patient'),
(29705, 4524, 8, 'Payements du patient'),
(29706, 4525, 8, 'Payements restant du patient'),
(29707, 4528, 8, 'Numéro de dossier'),
(29708, 4531, 8, 'Ville du patient'),
(29709, 4532, 8, 'Ville patient est manquante'),
(29710, 4533, 8, 'Communication patient envoyé'),
(29711, 4534, 8, 'Communication patient envoyé'),
(29712, 4535, 8, 'Pays patient'),
(29713, 4536, 8, 'Pays Patients est manquant. Aussi, vous n''avez pas réglé Pays par défaut pour les patients dans Paramètres Globaux'),
(29714, 4537, 8, 'Couverture du patient'),
(29715, 4539, 8, 'Les données des patients'),
(29716, 4541, 8, 'Date de naissance du patient est manquante'),
(29717, 4542, 8, 'Données du patient'),
(29718, 4543, 8, 'Date de naissance du patient'),
(29719, 4544, 8, 'Document du patient'),
(29720, 4545, 8, 'Education du patient'),
(29721, 4547, 8, 'Rencontre avec le patient'),
(29722, 4548, 8, 'Formulaire de rencontre avec le patient'),
(29723, 4549, 8, 'Rencontres avec le patient'),
(29724, 4550, 8, 'Annuaire des patients'),
(29725, 4551, 8, 'Prénom du patient'),
(29726, 4553, 8, 'Prénom du patient manquant'),
(29727, 4558, 8, 'Sexe du patient'),
(29728, 4559, 8, 'Sexe du patient manquant'),
(29729, 4560, 8, 'Patient n''a pas autorisé le Portail des patients.'),
(29730, 4561, 8, 'Historique du patient'),
(29731, 4562, 8, 'Historique du patient / Mode de vie'),
(29732, 4563, 8, 'Téléphone à domicile du patient'),
(29733, 4564, 8, 'ID Patient'),
(29734, 4565, 8, 'ID Patient'),
(29735, 4566, 8, 'ID carte du patient'),
(29736, 4568, 8, 'Vaccination du patient'),
(29737, 4569, 8, 'Informations du patient'),
(29738, 4570, 8, 'Instructions du patient'),
(29739, 4573, 8, 'Problèmes du patient'),
(29740, 4575, 8, 'Nom du patient'),
(29741, 4577, 8, 'Nom du patient manquant'),
(29742, 4581, 8, 'Liste des patients'),
(29743, 4582, 8, 'Colonnes de la liste des patients'),
(29744, 4584, 8, 'Liste des patients dans une nouvelle fenêtre'),
(29745, 4585, 8, 'Taille de la page de la liste des patients'),
(29746, 4586, 8, 'Erreurs de recherche patient'),
(29747, 4587, 8, 'Problèmes médicaux du patient'),
(29748, 4588, 8, 'Les médicaments du patient'),
(29749, 4589, 8, 'Nom du patient'),
(29750, 4590, 8, 'Nom et adresse du patient'),
(29751, 4593, 8, 'Nom du patient requis'),
(29752, 4595, 8, 'Remarque patient'),
(29753, 4596, 8, 'Types des remarques patient'),
(29754, 4597, 8, 'Remarques patient'),
(29755, 4598, 8, 'Notes du patient (écrire, ajout seulement optionnel)'),
(29756, 4599, 8, 'Nombre du patient'),
(29757, 4600, 8, 'Paiement du patient'),
(29758, 4603, 8, 'Portail Patient'),
(29759, 4605, 8, 'Portail Patient est désactivé'),
(29760, 4606, 8, 'Connexion au Portail Patient'),
(29761, 4607, 8, 'Adresse web du Portail Patient'),
(29762, 4608, 8, 'Rapport imprimé du patient'),
(29763, 4609, 8, 'Rapport de dossier patient'),
(29764, 4610, 8, 'Demande de dossier patient'),
(29765, 4611, 8, 'Demande des dossiers patient'),
(29766, 4613, 8, 'Rappel du patient'),
(29767, 4615, 8, 'Priorité de traitement pour la création d''un rappel patient'),
(29768, 4616, 8, 'Règles de rappel des patients'),
(29769, 4617, 8, 'Expéditeur e-mail pour les rappels patients'),
(29770, 4618, 8, 'Nom d''expéditeur pour les rappels patients'),
(29771, 4619, 8, 'Rappels patients'),
(29772, 4620, 8, 'Rapport patient'),
(29773, 4621, 8, 'Demande patient'),
(29774, 4622, 8, 'Dossiers médicaux demandés par le patient'),
(29775, 4623, 8, 'Résultats du patients'),
(29776, 4624, 8, 'Style des résultats de recherche des patients'),
(29777, 4625, 8, 'Ecran de Recherche/Ajout patient'),
(29778, 4626, 8, 'Réglages du patient'),
(29779, 4627, 8, 'Etat du patient'),
(29780, 4629, 8, 'Résumé du patient'),
(29781, 4630, 8, 'Transactions du patient'),
(29782, 4631, 8, 'Code postale du patient'),
(29783, 4632, 8, 'Patient (s) dans la base de données qui correspond(ent) aux critères démographique que vous avez entré.'),
(29784, 4633, 8, 'Patient / client'),
(29785, 4634, 8, 'Patient:'),
(29786, 4635, 8, 'ID Patient'),
(29787, 4636, 8, 'Patients'),
(29788, 4637, 8, 'Patient traité'),
(29789, 4638, 8, 'Payer'),
(29790, 4640, 8, 'Date de payement'),
(29791, 4641, 8, 'Status du payement'),
(29792, 4647, 8, 'Payement'),
(29793, 4648, 8, 'payement'),
(29794, 4651, 8, 'Montant du payement'),
(29795, 4652, 8, 'Le montant du payement doit etre numérique'),
(29796, 4653, 8, 'Catégorie du payement'),
(29797, 4654, 8, 'Date du payement'),
(29798, 4655, 8, 'payement entré le'),
(29799, 4656, 8, 'payement provenant de'),
(29800, 4659, 8, 'Liste du payement'),
(29801, 4660, 8, 'Methode du payement'),
(29802, 4661, 8, 'Trié les payement par'),
(29803, 4662, 8, 'Status du payement'),
(29804, 4663, 8, 'Type de payement'),
(29805, 4665, 8, 'Payements'),
(29806, 4669, 8, 'PDF'),
(29807, 4672, 8, 'Pelvis et fesses'),
(29808, 4674, 8, 'En attente'),
(29809, 4677, 8, 'Suivis en attente'),
(29810, 4678, 8, 'Suivis en attente depuis les resultats'),
(29811, 4679, 8, 'Commandes en attentes'),
(29812, 4685, 8, 'maladie d''ulcer digestif'),
(29813, 4686, 8, 'Par rencontre'),
(29814, 4687, 8, 'par min'),
(29815, 4688, 8, 'Au nombril'),
(29816, 4689, 8, 'au nombril'),
(29817, 4692, 8, 'Au rectum'),
(29818, 4693, 8, 'au rectum'),
(29819, 4694, 8, 'Pourcent'),
(29820, 4697, 8, 'centile'),
(29821, 4699, 8, 'Faire une recherche'),
(29822, 4700, 8, 'Faire cette action'),
(29823, 4705, 8, 'Période'),
(29824, 4706, 8, 'Période en jour ou un utilisateur pourra se connecter avec un mot de passe expiré.'),
(29825, 4708, 8, 'Périphérique'),
(29826, 4709, 8, 'Autoriser les mots de passe non salé'),
(29827, 4710, 8, 'Perse'),
(29828, 4712, 8, 'Personne'),
(29829, 4713, 8, 'Personnaliser'),
(29830, 4717, 8, 'Pharmacies'),
(29831, 4718, 8, 'Pharmacie'),
(29832, 4719, 8, 'Dispensaire de batiment'),
(29833, 4729, 8, 'Téléphone'),
(29834, 4730, 8, 'Liste d''appel du téléphone'),
(29835, 4731, 8, 'Rapport sur la liste d''appel du téléphone'),
(29836, 4738, 8, 'Numéro de téléphone'),
(29837, 4740, 8, 'Photophobie'),
(29838, 4741, 8, 'Photos'),
(29839, 4742, 8, 'PHP compressé'),
(29840, 4746, 8, 'PHP-gacl n''est pas installé'),
(29841, 4747, 8, 'Examen Physique'),
(29842, 4749, 8, 'Demande du médecin'),
(29843, 4750, 8, 'Signature du médecin'),
(29844, 4752, 8, 'Médecins'),
(29845, 4753, 8, 'choisir'),
(29846, 4754, 8, 'Chosir'),
(29847, 4755, 8, 'Choisir un thème CSS.'),
(29848, 4757, 8, 'PID (maladie inflammatoire pelvienne)'),
(29849, 4758, 8, 'Taille de la pilule'),
(29850, 4759, 8, 'Pilules'),
(29851, 4767, 8, 'Texte uniquement'),
(29852, 4768, 8, 'Plan'),
(29853, 4771, 8, 'Nom du plan'),
(29854, 4779, 8, 'Plan:'),
(29855, 4782, 8, 'Plans'),
(29856, 4784, 8, 'Joueur'),
(29857, 4785, 8, 'Position de jeu'),
(29858, 4786, 8, 'S''il vous plait appelez si n''importe quel information ci-dessus est incorrecte'),
(29859, 4787, 8, 'S''il vous plait changer votre mot de passe.'),
(29860, 4788, 8, 'S''il vous plait choississez un fichié'),
(29861, 4789, 8, 'S''il vous plait chossissez un patient'),
(29862, 4790, 8, 'S''il vous plait choississez une selection valide dans la liste.'),
(29863, 4791, 8, 'S''il vous plait choississez une sélection valide.'),
(29864, 4792, 8, 'S''il vous plait choississez une valeur pour'),
(29865, 4797, 8, 'S''il vous plait fermer cette fenètre.'),
(29866, 4810, 8, 'S''il vous plait entrer une date.'),
(29867, 4812, 8, 'S''il vous plait entrer un message'),
(29868, 4813, 8, 'S''il vous plait entrer entrer un montant monaitaire en utilisant uniquement des nombres et le point decimal.'),
(29869, 4814, 8, 'S''il vous plait entrer un nouveau mot de passe'),
(29870, 4815, 8, 'S''il vous plait entrer un titre!'),
(29871, 4821, 8, 'S''il vous plait entrer une nouvelle phrase de recherche'),
(29872, 4823, 8, 'S''il vous plait entrer le mot de passe'),
(29873, 4826, 8, 'S''il vous plait remplissez la date'),
(29874, 4827, 8, 'S''il vous plait rentrez le montant du payement'),
(29875, 4828, 8, 'S''il vous plait rentrez la catégorie de payement'),
(29876, 4832, 8, 'S''il vous plait indiquez la raison de la visite'),
(29877, 4836, 8, 'S''il vous plait connectez vous de nouveau.'),
(29878, 4839, 8, 'S''il vous plait utilisez des caractères alphabetique'),
(29879, 4840, 8, 'S''il vous plait utilisez des caractères alphabetique sans espace'),
(29880, 4841, 8, 'S''il vous plait payez ce montant'),
(29881, 4842, 8, 'S''il vous plait placez vos fichiers d''installation dans le dossier suivant'),
(29882, 4844, 8, 'S''il vous plait resetez le mot de passe'),
(29883, 4847, 8, 'S''il vous plait selectionnez'),
(29884, 4849, 8, 'S''il vous plait selectionnez une langue'),
(29885, 4850, 8, 'S''il vous plait selectionnez un patient.'),
(29886, 4859, 8, 'S''il vous plait selectionnez un évenement'),
(29887, 4860, 8, 'S''il vous plait selectionnez n''importe quel option de recherche/'),
(29888, 4863, 8, 'S''il vous plait selectionnez au moins une prescription!'),
(29889, 4865, 8, 'S''il vous plait selectionnez les pages voulues pour copier ou faire suivre:'),
(29890, 4866, 8, 'S''il vous plait selectionnez la méthode de payement'),
(29891, 4867, 8, 'S''il vous plait selectionnez le type de payement.'),
(29892, 4870, 8, 'S''il vous plait mettre'),
(29893, 4878, 8, 'S''il vous plait visitez l''ecran après un certain temps'),
(29894, 4881, 8, 'Pluriel'),
(29895, 4891, 8, 'Vaccin contre la pneumonie'),
(29896, 4892, 8, 'Status du vaccin contre la pneumonie pour adultes les plus anciens'),
(29897, 4893, 8, 'Status du vaccin contre la pneumonie pour adultes les plus anciens (LCQ)'),
(29898, 4894, 8, 'Podologie'),
(29899, 4899, 8, 'Numéro de la politice'),
(29900, 4900, 8, 'Polonais'),
(29901, 4902, 8, 'Polypes'),
(29902, 4904, 8, 'Faible appétit'),
(29903, 4905, 8, 'Faible circulation'),
(29904, 4906, 8, 'Ouïe faible'),
(29905, 4907, 8, 'Les pop up doivent être activés pour voir ces rapport'),
(29906, 4910, 8, 'Portail'),
(29907, 4911, 8, 'Activité du portail'),
(29908, 4917, 8, 'Portugais'),
(29909, 4918, 8, 'Portugais (Brésillien)'),
(29910, 4919, 8, 'Portugais (Européen)'),
(29911, 4922, 8, 'Positif'),
(29912, 4923, 8, 'Positifs'),
(29913, 4937, 8, 'Postal'),
(29914, 4938, 8, 'Code Postal'),
(29915, 4939, 8, 'Code postal'),
(29916, 4946, 8, 'Date d''envois'),
(29917, 4953, 8, 'Entrainement'),
(29918, 4954, 8, 'Paramètre par defaut des entrainements'),
(29919, 4955, 8, 'Paramètre par defaut des entrainements'),
(29920, 4956, 8, 'Entraineur'),
(29921, 4958, 8, 'Pré-payement'),
(29922, 4959, 8, 'Pré-payement'),
(29923, 4960, 8, 'Consultation pré-avortement'),
(29924, 4961, 8, 'Aide psychologique pré-avortement'),
(29925, 4964, 8, 'Préférences'),
(29926, 4965, 8, 'Catégorie d''évenement préféré'),
(29927, 4966, 8, 'Langue préféré'),
(29928, 4967, 8, 'Pharmacie préféré'),
(29929, 4969, 8, 'Test de grossesse'),
(29930, 4970, 8, 'Préliminaire'),
(29931, 4972, 8, 'Pré-payement'),
(29932, 4973, 8, 'Prescription'),
(29933, 4975, 8, 'Historique des prescriptions'),
(29934, 4976, 8, 'L''historique des prescriptions a été importé avec succes'),
(29935, 4979, 8, 'Prescriptions'),
(29936, 4983, 8, 'Rapport des prescriptions'),
(29937, 4984, 8, 'Prescriptions/Envois vers des spécialistes'),
(29938, 4985, 8, 'Présent'),
(29939, 4986, 8, 'À des réclamations'),
(29940, 4987, 8, 'À des problèmes'),
(29941, 4988, 8, 'Appuyer sur Continuer pour effectuer l''action'),
(29942, 4989, 8, 'Diagnostic présumé'),
(29943, 4990, 8, 'Diagnostic présumé par un spécialiste'),
(29944, 4995, 8, 'Soin préventif'),
(29945, 4998, 8, 'Aperçu de l''evenement'),
(29946, 5000, 8, 'Aperçu de'),
(29947, 5001, 8, 'Précédent'),
(29948, 5002, 8, 'Consultations précédente'),
(29949, 5003, 8, 'Jour précédent'),
(29950, 5005, 8, 'Mois précédent'),
(29951, 5006, 8, 'Semaine précédente'),
(29952, 5007, 8, 'Prix'),
(29953, 5008, 8, 'Prix sacrifié'),
(29954, 5009, 8, 'Niveau du prix'),
(29955, 5010, 8, 'Niveau du prix:'),
(29956, 5011, 8, 'Prix'),
(29957, 5012, 8, 'Principale'),
(29958, 5023, 8, 'Assurance principale'),
(29959, 5024, 8, 'Donnée de l''assurance principale'),
(29960, 5025, 8, 'Fournisseur de l''assurance principale'),
(29961, 5026, 8, 'Fournisseur principale'),
(29962, 5027, 8, 'Imprimer'),
(29963, 5028, 8, 'Imprimer (HTML)'),
(29964, 5029, 8, 'Imprimer (PDF)'),
(29965, 5031, 8, 'Imprimer n''importe quel rencontre'),
(29966, 5034, 8, 'Imprimer la date'),
(29967, 5042, 8, 'Imprimer message'),
(29968, 5043, 8, 'Impression multiple'),
(29969, 5046, 8, 'Imprimer notes'),
(29970, 5047, 8, 'Impression Page 1'),
(29971, 5048, 8, 'Impression Page 2'),
(29972, 5052, 8, 'Imprimer l''enregistrement'),
(29973, 5056, 8, 'Imprimer cette rencontre'),
(29974, 5057, 8, 'Imprimer cette note'),
(29975, 5058, 8, 'Imprimer Cette Note'),
(29976, 5062, 8, 'imprimable'),
(29977, 5063, 8, 'Version imprimable'),
(29978, 5064, 8, 'Imprimé'),
(29979, 5066, 8, 'Résultats en cours d''impression:'),
(29980, 5069, 8, 'Authorisation précédente'),
(29981, 5070, 8, 'Formulaire d''authorisation précédente'),
(29982, 5071, 8, 'Visite précédente'),
(29983, 5072, 8, 'Priorité'),
(29984, 5073, 8, 'Priorité '),
(29985, 5074, 8, 'Privé'),
(29986, 5075, 8, 'Problème'),
(29987, 5077, 8, 'Liste de problème'),
(29988, 5079, 8, 'Problèmes'),
(29989, 5086, 8, 'Procédure'),
(29990, 5089, 8, 'Code de la procédure'),
(29991, 5090, 8, 'Codes de la procédure'),
(29992, 5092, 8, 'Nom de la procédure'),
(29993, 5093, 8, 'Ordre de la Procédure'),
(29994, 5094, 8, 'Ordre de la procédure'),
(29995, 5095, 8, 'Ordre de la Procédure pour'),
(29996, 5097, 8, 'Ordres de la procédure et rapport'),
(29997, 5099, 8, 'Fournisseur de la procédure'),
(29998, 5100, 8, 'Fournisseur de la Procédure'),
(29999, 5101, 8, 'Fournisseurs de la procédure'),
(30000, 5102, 8, 'Rapport de la Procédure'),
(30001, 5103, 8, 'Status des rapport de la procédure'),
(30002, 5104, 8, 'Resultat anormal suite à la procédure'),
(30003, 5105, 8, 'Status du résultat de la procédure'),
(30004, 5106, 8, 'Résultats de la procédure'),
(30005, 5110, 8, 'Type de procédure'),
(30006, 5111, 8, 'Types de procédure'),
(30007, 5113, 8, 'Procédure/Service'),
(30008, 5114, 8, 'Procédures'),
(30009, 5115, 8, 'Processus'),
(30010, 5116, 8, 'Processus et envoyer les rappels'),
(30011, 5121, 8, 'Préparé'),
(30012, 5122, 8, 'Préparé par'),
(30013, 5123, 8, 'Date préparé'),
(30014, 5124, 8, 'préparé avec succes'),
(30015, 5125, 8, 'Traitement'),
(30016, 5126, 8, 'Traitement et envois des rappels du patient'),
(30017, 5127, 8, 'Traitement des rappels du patient'),
(30018, 5128, 8, 'Traitement du temps'),
(30019, 5129, 8, 'Produit'),
(30020, 5131, 8, 'Production'),
(30021, 5132, 8, 'Produits'),
(30022, 5136, 8, 'Cancer prostatique'),
(30023, 5137, 8, 'Depistage cancer prostatique'),
(30024, 5138, 8, 'Examen prostatique'),
(30025, 5139, 8, 'Problèmes prostatiques'),
(30026, 5141, 8, 'Protocole'),
(30027, 5142, 8, 'Fournir le chemin absolu'),
(30028, 5143, 8, 'Fournir le chemin absolu du fichier'),
(30029, 5145, 8, 'Fournir les résumés clinique des patients pour chaque visite au bureau.'),
(30030, 5148, 8, 'Fournir les enregistrement au patient pour la visite'),
(30031, 5149, 8, 'Fournir une adresse courriel valide'),
(30032, 5150, 8, 'Résumé clinique fournis?'),
(30033, 5151, 8, 'Ressources d''éducation fournis?'),
(30034, 5152, 8, 'Fourisseur'),
(30035, 5153, 8, 'Id du fournisseur'),
(30036, 5154, 8, 'Id du Fournisseur'),
(30037, 5155, 8, 'ID du Fournisseur du batiment spécifié'),
(30038, 5162, 8, 'Fournisseur:'),
(30039, 5163, 8, 'Fournisseurs'),
(30040, 5165, 8, 'Les fournisseurs voient le calendrier en entier'),
(30041, 5168, 8, 'Psoriasis'),
(30042, 5171, 8, 'Psychiatrique'),
(30043, 5172, 8, 'Résumé de la lettre psychiatrique'),
(30044, 5173, 8, 'Diagnostic psychiatrique'),
(30045, 5174, 8, 'Examen psychiatrique'),
(30046, 5175, 8, 'Historique psychiatrique'),
(30047, 5177, 8, 'Médication psychiatrique'),
(30048, 5201, 8, 'Publique'),
(30049, 5203, 8, 'Service de santé publique ou autre agence fédérale'),
(30050, 5204, 8, 'Porto ricain'),
(30051, 5205, 8, 'Pulmonaire'),
(30052, 5206, 8, 'Pouls'),
(30053, 5207, 8, 'Panjabi'),
(30054, 5208, 8, 'Achat'),
(30055, 5209, 8, 'Achat / Retour'),
(30056, 5210, 8, 'Achats'),
(30057, 5213, 8, 'toutes les 3 h'),
(30058, 5214, 8, 'toutes les 4 h'),
(30059, 5215, 8, 'toutes les 5 h'),
(30060, 5216, 8, 'toutes les 6 h'),
(30061, 5217, 8, 'toutes les 8 h'),
(30062, 5218, 8, 'une fois par jour'),
(30063, 5219, 8, '4 fois par jour'),
(30064, 5222, 8, 'Qté.'),
(30065, 5223, 8, 'Qté.'),
(30066, 5224, 8, 'Qualité'),
(30067, 5225, 8, 'Mesures de Qualité (CQM)'),
(30068, 5226, 8, 'Quantité'),
(30069, 5228, 8, 'Quantité disponible'),
(30070, 5229, 8, 'La quantité semble non utilisable'),
(30071, 5231, 8, 'Point d''intégoration'),
(30072, 5241, 8, 'Quitter'),
(30073, 5242, 8, 'Quitter Alcool'),
(30074, 5245, 8, 'Race'),
(30075, 5246, 8, 'Race et ethnicité'),
(30076, 5247, 8, 'Race/Ethnicité'),
(30077, 5248, 8, 'Radio'),
(30078, 5249, 8, 'Boutons radio'),
(30079, 5251, 8, 'Plage'),
(30080, 5252, 8, 'Eruptions'),
(30081, 5253, 8, 'Taux'),
(30082, 5254, 8, 'Ratio'),
(30083, 5255, 8, 'Données brute'),
(30084, 5261, 8, 'Re-ouvrir'),
(30085, 5262, 8, 'Ré-ouvert'),
(30086, 5263, 8, 'Reaction'),
(30087, 5264, 8, 'Réactions'),
(30088, 5265, 8, 'Lire'),
(30089, 5268, 8, 'Nom réel'),
(30090, 5269, 8, 'Vraiment supprimé'),
(30091, 5270, 8, 'Raison'),
(30092, 5271, 8, 'Raison du décés'),
(30093, 5272, 8, 'Cause du décès'),
(30094, 5274, 8, 'Raison de l''envois vers le spécialiste'),
(30095, 5275, 8, 'Motif de la visite'),
(30096, 5276, 8, 'Raison/Formulaire'),
(30097, 5277, 8, 'Reçu'),
(30098, 5278, 8, 'Reçu du paiement'),
(30099, 5279, 8, 'Reçu créé'),
(30100, 5281, 8, 'Résumé des reçus'),
(30101, 5282, 8, 'Reçus'),
(30102, 5283, 8, 'Reçus par'),
(30103, 5284, 8, 'Faxes reçus'),
(30104, 5285, 8, 'Reçus, non vérifié'),
(30105, 5287, 8, 'Receveur'),
(30106, 5288, 8, 'ID du receveur'),
(30107, 5291, 8, 'IDs du receveur'),
(30108, 5292, 8, 'Les trois mot de passe les plus recent ne sont pas autorisé.'),
(30109, 5293, 8, 'Destinataire'),
(30110, 5294, 8, 'La liste du destinataire est vide'),
(30111, 5295, 8, 'Nom du destinataire'),
(30112, 5297, 8, 'Destinataire requis à moins que le status est Finis'),
(30113, 5298, 8, 'Recommendation'),
(30114, 5299, 8, 'Recommendation pour le suivis'),
(30115, 5300, 8, 'Recommendations'),
(30116, 5301, 8, 'Recommendations et traitement'),
(30117, 5302, 8, 'Recommendations par un spécialiste'),
(30118, 5303, 8, 'Enregistrement'),
(30119, 5304, 8, 'L''enregistrement existe déjà'),
(30120, 5311, 8, 'Enregistements démographique.'),
(30121, 5313, 8, 'Enregistrement de la forme physique'),
(30122, 5314, 8, 'Enregistrement du payement'),
(30123, 5315, 8, 'Enregistrement de la date de la requète'),
(30124, 5316, 8, 'Enregistrement de la consommation de tabac pour les patients de plus de 13 ans.'),
(30125, 5317, 8, 'Enregistrements'),
(30126, 5318, 8, 'enregistrements trouvés'),
(30127, 5319, 8, 'enregistrements trouvés.'),
(30128, 5320, 8, 'Usage de drogues récréationnelles'),
(30129, 5321, 8, 'Drogues récréationnelles'),
(30130, 5322, 8, 'Rectale'),
(30131, 5323, 8, 'Examen Rectal'),
(30132, 5324, 8, 'Voie Rectale'),
(30133, 5325, 8, 'Redirection'),
(30134, 5326, 8, 'Rougeurs'),
(30135, 5327, 8, 'réduit:'),
(30136, 5328, 8, 'Mentionner'),
(30137, 5329, 8, 'Mentionner par'),
(30138, 5330, 8, 'Date de la mention'),
(30139, 5331, 8, 'Mentionner pour'),
(30140, 5333, 8, 'Plage de référence des résultats'),
(30141, 5336, 8, 'Mentionner le nom et la signature'),
(30142, 5337, 8, 'Envois vers un spécialite'),
(30143, 5338, 8, 'Envois vers un spécialite par'),
(30144, 5339, 8, 'Carte du spécialiste'),
(30145, 5340, 8, 'Date de l''envois vers un spécialiste'),
(30146, 5341, 8, 'Formulaire de l''envois vers un spécialiste'),
(30147, 5343, 8, 'ID du spécialiste'),
(30148, 5359, 8, 'Recharge'),
(30149, 5360, 8, 'Recharges'),
(30150, 5361, 8, 'recharges'),
(30151, 5362, 8, 'Reflexes normaux'),
(30152, 5363, 8, 'Actualiser'),
(30153, 5365, 8, 'Actualisation des rappels'),
(30154, 5368, 8, 'Refuser dans l''Étant'),
(30155, 5370, 8, 's''enregistrer'),
(30156, 5372, 8, 'Enregistré'),
(30157, 5373, 8, 'enregistré'),
(30158, 5375, 8, 'Date d''Enregistrement'),
(30159, 5376, 8, 'Forumalire d''Enregistrement'),
(30160, 5377, 8, 'Rééducation'),
(30161, 5380, 8, 'Potentiel de rechute'),
(30162, 5381, 8, 'Fait référence à'),
(30163, 5382, 8, 'Relié'),
(30164, 5383, 8, 'Problème relié'),
(30165, 5384, 8, 'Notes des patient reliées'),
(30166, 5385, 8, 'Relation(s) / Enfant'),
(30167, 5386, 8, 'Relations'),
(30168, 5387, 8, 'Lien'),
(30169, 5388, 8, 'Odre relatif de cette entitée'),
(30170, 5389, 8, 'Relatifs'),
(30171, 5403, 8, 'Religion'),
(30172, 5406, 8, 'Reconnexion'),
(30173, 5409, 8, 'Rappel'),
(30174, 5410, 8, 'Intervals des rappels'),
(30175, 5411, 8, 'Rappel pas encore Envoyé'),
(30176, 5412, 8, 'Rappel Envoye Le'),
(30177, 5413, 8, 'Rappels'),
(30178, 5415, 8, 'Hôte distant'),
(30179, 5416, 8, 'Supprimer'),
(30180, 5419, 8, 'Supprimer Groupe'),
(30181, 5420, 8, 'Formulaire de suppression d''un groupe'),
(30182, 5422, 8, 'Supprime aide pour phpMyAdmin'),
(30183, 5423, 8, 'Supprime aide pour prescription'),
(30184, 5426, 8, 'Lithiases rénales'),
(30185, 5427, 8, 'Renommer'),
(30186, 5428, 8, 'Renommer groupe'),
(30187, 5429, 8, 'Rendu'),
(30188, 5430, 8, 'Fournisseur de rendu'),
(30189, 5431, 8, 'Numéro du fournissseur de rendu'),
(30190, 5432, 8, 'Réorganiser'),
(30191, 5433, 8, 'Réorganiser à'),
(30192, 5434, 8, 'Le point dé réorganisation a été atteind'),
(30193, 5437, 8, 'Répéter le nouveau mot de passe'),
(30194, 5438, 8, 'Evènement répété'),
(30195, 5439, 8, 'Répéter l''information'),
(30196, 5440, 8, 'Répétés'),
(30197, 5441, 8, 'REMPLACER'),
(30198, 5444, 8, 'Date de Réponse'),
(30199, 5445, 8, 'Réponse De'),
(30200, 5446, 8, 'Rapport'),
(30201, 5447, 8, 'Rapport - Clinique'),
(30202, 5449, 8, 'Rapport par'),
(30203, 5453, 8, 'Rapporter l''historique/les résultats'),
(30204, 5454, 8, 'Rapport des résultats'),
(30205, 5455, 8, 'Rapporter les résultats/l''historique'),
(30206, 5457, 8, 'Status du rapport'),
(30207, 5458, 8, 'Rapport totaux'),
(30208, 5459, 8, 'Rapport / Formulaire'),
(30209, 5460, 8, 'Rapportable'),
(30210, 5461, 8, 'Rapporté'),
(30211, 5462, 8, 'Date rapporté'),
(30212, 5463, 8, 'Rapports'),
(30213, 5467, 8, 'Requète ignoré - le processus de récamation est déjà débuté!'),
(30214, 5474, 8, 'Service requis'),
(30215, 5475, 8, 'Requière des mots de passes fort'),
(30216, 5476, 8, 'Requière des mots de passes unique'),
(30217, 5477, 8, 'Exigé'),
(30218, 5478, 8, 'ticket modérateur exigé'),
(30219, 5479, 8, 'Champ manquant: choisir le fichier EDI-271 à télécharger svp'),
(30220, 5480, 8, 'Champ manquant: entrer le prénom svp'),
(30221, 5481, 8, 'Champ manquant: entrer le nom de famille svp'),
(30222, 5482, 8, 'Champ manquant: entrer le nom d''utilisateur svp'),
(30223, 5483, 8, 'Champs obligatoires'),
(30224, 5484, 8, 'Pré-requis'),
(30225, 5485, 8, 'RESERVE'),
(30226, 5486, 8, 'Réservé'),
(30227, 5491, 8, 'Redémaré'),
(30228, 5496, 8, 'Résolu'),
(30229, 5497, 8, 'Respiration'),
(30230, 5499, 8, 'Respiratoire'),
(30231, 5504, 8, 'Résultat'),
(30232, 5505, 8, 'Nom du résultat'),
(30233, 5506, 8, 'Status du résultat'),
(30234, 5507, 8, 'Satus du resultat ou ''annormalité est manquante'),
(30235, 5509, 8, 'Résultats'),
(30236, 5510, 8, 'Résultats et'),
(30237, 5511, 8, 'Résultats trouvé pour la recherche'),
(30238, 5512, 8, 'Groupe des résultats'),
(30239, 5514, 8, 'Chemin des résultats'),
(30240, 5515, 8, 'Résultats par page'),
(30241, 5516, 8, 'Résultats/Détails'),
(30242, 5517, 8, 'Examen rétinal'),
(30243, 5519, 8, 'Retour'),
(30244, 5521, 8, 'Retour à l''Agenda'),
(30245, 5522, 8, 'Retour au rapport des résultats'),
(30246, 5527, 8, 'Valeur de retour'),
(30247, 5528, 8, 'Retour de la visite'),
(30248, 5530, 8, 'Réutilisé les trois dernier mot de passe n''est pas utilisable!'),
(30249, 5535, 8, 'Revue des systèmes'),
(30250, 5536, 8, 'Revue des systèmes via checkbox'),
(30251, 5537, 8, 'Relu'),
(30252, 5538, 8, 'Révision'),
(30253, 5539, 8, 'Polyarthrite rhumatoïde'),
(30254, 5540, 8, 'Polyarthrite rhumatoïde'),
(30255, 5541, 8, 'Droite'),
(30256, 5542, 8, 'Oreille Droite'),
(30257, 5543, 8, 'oreille droite'),
(30258, 5545, 8, 'Droite:'),
(30259, 5546, 8, 'Acouphènes'),
(30260, 5547, 8, 'Acouphènes'),
(30261, 5549, 8, 'Facteurs de risque'),
(30262, 5550, 8, 'Niveau de risque'),
(30263, 5553, 8, 'Roumain'),
(30264, 5560, 8, 'Tableau de service'),
(30265, 5563, 8, 'Routé'),
(30266, 5564, 8, 'Lignes'),
(30267, 5568, 8, 'Règle'),
(30268, 5569, 8, 'Ajouter règle'),
(30269, 5570, 8, 'Détail de règle'),
(30270, 5572, 8, 'Modifier règle'),
(30271, 5578, 8, 'Règles'),
(30272, 5580, 8, 'Règles de configuration'),
(30273, 5581, 8, 'Commande fonctionnant: '),
(30274, 5582, 8, 'Rupture'),
(30275, 5583, 8, 'Russe'),
(30276, 5605, 8, 'Vente'),
(30277, 5606, 8, 'Ventes'),
(30278, 5607, 8, 'Ventes par objet'),
(30279, 5608, 8, 'Ventes par rapport de produit'),
(30280, 5609, 8, 'Salive'),
(30281, 5610, 8, 'Même jour'),
(30282, 5612, 8, 'Echantillon'),
(30283, 5613, 8, 'Type de sanction'),
(30284, 5617, 8, 'Sam.'),
(30285, 5618, 8, 'Sam. et Dim.'),
(30286, 5619, 8, 'Samedi'),
(30287, 5620, 8, 'Sauvegarder'),
(30288, 5621, 8, 'SAUVEGARDER'),
(30289, 5622, 8, 'Sauvegarder et fermer'),
(30290, 5624, 8, 'Sauvegarder et prodiguer'),
(30291, 5625, 8, 'Sauvegarder et transmètre'),
(30292, 5626, 8, 'Sauvegarder comme nouveau'),
(30293, 5627, 8, 'Sauvegarder comme une nouvelle note'),
(30294, 5628, 8, 'Sauvegarder les paramètres du certificat'),
(30295, 5629, 8, 'Sauvegarder les changements'),
(30296, 5630, 8, 'Sauvegarder le formulaire'),
(30297, 5631, 8, 'Sauvegarder les immunisation'),
(30298, 5632, 8, 'Sauvegarder un nouveau champs'),
(30299, 5633, 8, 'Sauvegarder comme un nouveau groupe'),
(30300, 5634, 8, 'Sauvegarder une nouvelle liste'),
(30301, 5636, 8, 'Sauvegarder les séléctions omisent'),
(30302, 5637, 8, 'Savegarder les données démographique du patient');
INSERT INTO `lang_definitions` VALUES
(30303, 5639, 8, 'Sauvegarder la transaction'),
(30304, 5641, 8, 'Numérisé'),
(30305, 5642, 8, 'Note de la rencontre numérisé'),
(30306, 5643, 8, 'Répertoire du scanner'),
(30307, 5645, 8, 'Emplois du temps'),
(30308, 5646, 8, 'Emplois du temps des établissements:'),
(30309, 5647, 8, 'Notes d''écoles'),
(30310, 5648, 8, 'Scoliose'),
(30311, 5659, 8, 'Chercher'),
(30312, 5661, 8, 'chercher'),
(30313, 5662, 8, 'chercher de nouveau'),
(30314, 5663, 8, 'Rechercher sur toutes les colonnes'),
(30315, 5664, 8, 'Chercher par:'),
(30316, 5665, 8, 'Recherche de'),
(30317, 5666, 8, 'Recherche de:'),
(30318, 5667, 8, 'Rechercher Dans'),
(30319, 5668, 8, 'Chercher dans'),
(30320, 5669, 8, 'Chercher ou Ajouter patient'),
(30321, 5670, 8, 'Recherche Paiement'),
(30322, 5671, 8, 'Chercher les résultats'),
(30323, 5672, 8, 'Recherche Résultats:'),
(30324, 5673, 8, 'Recherche selectionnée'),
(30325, 5674, 8, 'La chaine de caractères recherchée ne correspond pas avec une liste dans la base de donnée'),
(30326, 5675, 8, 'La chaine de caractères recherchée devrait avoir au moins 3 caractères'),
(30327, 5676, 8, 'Texte rechercher'),
(30328, 5677, 8, 'Rechercher les évenements'),
(30329, 5678, 8, 'Chercher/Ajouter'),
(30330, 5679, 8, 'Rechercher/Ajouter un assuré'),
(30331, 5680, 8, 'Recherche pour des rendez-vous'),
(30332, 5681, 8, 'Recherche...'),
(30333, 5684, 8, 'Seconde'),
(30334, 5687, 8, 'Secondaire'),
(30335, 5688, 8, 'Assurance secondaire'),
(30336, 5689, 8, 'Données de l''assurance secondaire'),
(30337, 5690, 8, 'Fournisseur de l''assurance secondaire'),
(30338, 5698, 8, 'Sécurité'),
(30339, 5699, 8, 'Voir Tout'),
(30340, 5700, 8, 'Voir les autorisations'),
(30341, 5701, 8, 'Voir Courbe de croissance'),
(30342, 5702, 8, 'Voir les messages depuis le dernier lot de réclamations générée'),
(30343, 5704, 8, 'Vue depuis'),
(30344, 5705, 8, 'Nom du segment'),
(30345, 5707, 8, 'Crises d''épilepsie'),
(30346, 5709, 8, 'Sélectionner'),
(30347, 5710, 8, 'sélectionner'),
(30348, 5712, 8, 'Sélectionner un contexte'),
(30349, 5715, 8, 'Sélectionner un Utilisateur'),
(30350, 5716, 8, 'Tout Sélectionner'),
(30351, 5720, 8, 'Sélectionner catégorie'),
(30352, 5723, 8, 'Selectionner les critères à supprimé'),
(30353, 5727, 8, 'Sélectionner date'),
(30354, 5728, 8, 'Sélectionner le groupe désiré'),
(30355, 5729, 8, 'Sélectionner Diagnostic'),
(30356, 5731, 8, 'Sélectionner Médication'),
(30357, 5732, 8, 'Sélectionner Médications'),
(30358, 5736, 8, 'Sélectionner champ'),
(30359, 5737, 8, 'Sélectionner Champs'),
(30360, 5738, 8, 'Sélection à imprimer'),
(30361, 5739, 8, 'Sélectionner Vaccins'),
(30362, 5741, 8, 'Sélectionner Assurance, en tapant'),
(30363, 5742, 8, 'Sélectionner Problème'),
(30364, 5744, 8, 'Sélectionner Langue'),
(30365, 5745, 8, 'Sélectionner un(e'),
(30366, 5746, 8, 'Sélectionner un ou plusieur codes diagnostique pour justifié le service'),
(30367, 5747, 8, 'Sélectionner un ou plusieurs fichiers à téléversé'),
(30368, 5754, 8, 'Sélectionner les objets de configuration à exporter'),
(30369, 5759, 8, 'Sélectionner Utilisateur'),
(30370, 5760, 8, 'Sélectionner Utilisateurs dans Liste déroulante'),
(30371, 5762, 8, 'Sélectionner Oui pour confirmer la suppression du groupe'),
(30372, 5765, 8, 'Sélectionné'),
(30373, 5766, 8, 'Rencontre sélectionnée'),
(30374, 5771, 8, 'Envoyer'),
(30375, 5772, 8, 'Envoyer une date de rappel'),
(30376, 5773, 8, 'Envoyer un rappel'),
(30377, 5774, 8, 'Envoi en cours'),
(30378, 5775, 8, 'Envoyer un message'),
(30379, 5779, 8, 'Envoyer ce fichier'),
(30380, 5780, 8, 'Envoyer ce message'),
(30381, 5781, 8, 'Envoyer à'),
(30382, 5784, 8, 'Envoyer à tous'),
(30383, 5788, 8, 'Envoyeur'),
(30384, 5789, 8, 'ID de l''envoyeur'),
(30385, 5792, 8, 'IDs de l''envoyeur'),
(30386, 5793, 8, 'Envoi à'),
(30387, 5794, 8, 'Sensitivitées'),
(30388, 5795, 8, 'Sensitivité'),
(30389, 5796, 8, 'Examen sensoriel normal'),
(30390, 5797, 8, 'Envoyé'),
(30391, 5799, 8, 'Envoyé par, laissez vide pour tous'),
(30392, 5801, 8, 'Date d''envoi'),
(30393, 5802, 8, 'Objets envoyés'),
(30394, 5803, 8, 'Envoyer les enregistrements médicaux'),
(30395, 5804, 8, 'Envoi terminé'),
(30396, 5807, 8, 'Envoyé à l''imprimante'),
(30397, 5808, 8, 'Envoyé à, laissez vide pour tous'),
(30398, 5810, 8, 'Envoyé, mais récéption non confirmée'),
(30399, 5811, 8, 'Envoyé, mais non reçu'),
(30400, 5812, 8, 'Sep.'),
(30401, 5813, 8, 'Séparé'),
(30402, 5814, 8, 'Septembre'),
(30403, 5815, 8, 'Séq.'),
(30404, 5816, 8, 'Séquence'),
(30405, 5821, 8, 'Service'),
(30406, 5822, 8, 'Catégorie de service'),
(30407, 5823, 8, 'Code de service'),
(30408, 5825, 8, 'Codes service'),
(30409, 5826, 8, 'Date de service'),
(30410, 5827, 8, 'Date de service:'),
(30411, 5829, 8, 'Emplacement du service'),
(30412, 5830, 8, 'Nom du service'),
(30413, 5831, 8, 'Service fourni par un spécialiste'),
(30414, 5834, 8, 'Services'),
(30415, 5835, 8, 'Services par Catégorie'),
(30416, 5836, 8, 'Services fournis'),
(30417, 5837, 8, 'Services fournis'),
(30418, 5838, 8, 'Produits/Services'),
(30419, 5839, 8, 'Type de Service'),
(30420, 5840, 8, 'Mettre'),
(30421, 5842, 8, 'Mettre comme complété'),
(30422, 5846, 8, 'Mettre à'),
(30423, 5849, 8, 'Réglages'),
(30424, 5851, 8, 'Migraine sévère'),
(30425, 5853, 8, 'Intensité de la douleur'),
(30426, 5854, 8, 'Intensité de la douleur:'),
(30427, 5855, 8, 'Sexe'),
(30428, 5856, 8, 'Maladies sexuellement transmissibles'),
(30429, 5857, 8, 'SFTP'),
(30430, 5858, 8, 'Hashe Sha-1'),
(30431, 5859, 8, 'Partage'),
(30432, 5860, 8, 'Commande shell pour imprimé depuis le serveur'),
(30433, 5863, 8, 'Petite description'),
(30434, 5864, 8, 'Souffle court'),
(30435, 5865, 8, 'Souffle Court'),
(30436, 5866, 8, 'Souffle Court 2'),
(30437, 5870, 8, 'devrait être comme nnnnn-nnnn-nn'),
(30438, 5871, 8, 'Devrait être de deux lettres'),
(30439, 5872, 8, 'devrait contenir 10 chiffres'),
(30440, 5873, 8, 'devrait contenir uniquement 10 chiffres'),
(30441, 5874, 8, 'Épaule'),
(30442, 5875, 8, 'Épaule + clavicule'),
(30443, 5876, 8, 'Problème à l''épaule'),
(30444, 5877, 8, 'Montrer'),
(30445, 5878, 8, 'Montrer les actifs'),
(30446, 5880, 8, 'Montrer tout'),
(30447, 5881, 8, 'Montrer toutes les procédures'),
(30448, 5883, 8, 'Montrer toutes les transactions'),
(30449, 5884, 8, 'Montrer comme occupé'),
(30450, 5885, 8, 'Montrer les autorisés seulement'),
(30451, 5886, 8, 'Montrer les horraires disponible'),
(30452, 5889, 8, 'Montrer les détails'),
(30453, 5890, 8, 'Montrer les erreurs seulement?'),
(30454, 5891, 8, 'Montrer le graphique'),
(30455, 5894, 8, 'Montrer les innactifs'),
(30456, 5896, 8, 'Montrer le menu'),
(30457, 5898, 8, 'Montrer les notes'),
(30458, 5901, 8, 'Montrer les notes du patient'),
(30459, 5902, 8, 'Montrer les livres et les onces'),
(30460, 5903, 8, 'Montrer les livres avec des valeurs décimale'),
(30461, 5905, 8, 'Montrer les rappels'),
(30462, 5906, 8, 'Montrer les rapports'),
(30463, 5913, 8, 'Montrer les non facturé seulement'),
(30464, 5914, 8, 'Montrer les USA seulement'),
(30465, 5915, 8, 'Montrer'),
(30466, 5916, 8, 'Montrer les résultats'),
(30467, 5920, 8, 'Frères et Soeurs'),
(30468, 5921, 8, 'Drépanocyte'),
(30469, 5923, 8, 'Sigmoïde/Coloscopie'),
(30470, 5925, 8, 'Signez les résultats du laboratoire (écrire, ajout seulement optionnel)'),
(30471, 5926, 8, 'Signez les résultats'),
(30472, 5927, 8, 'Signature'),
(30473, 5929, 8, 'Signature:'),
(30474, 5932, 8, 'Enflure significatif:'),
(30475, 5933, 8, 'Simplifié'),
(30476, 5934, 8, 'Ticket modérateur simplifié'),
(30477, 5935, 8, 'Démographique simplifié'),
(30478, 5936, 8, 'Prescriptions simplifié'),
(30479, 5937, 8, 'Depuis'),
(30480, 5938, 8, 'Sincèrement'),
(30481, 5940, 8, 'Célibataire'),
(30482, 5941, 8, 'Liste à une seule sélection'),
(30483, 5942, 8, 'Liste à une seule sélection avec la capacité d''ajouté à la liste'),
(30484, 5943, 8, 'Singulié'),
(30485, 5946, 8, 'Problèmes aux sinus'),
(30486, 5947, 8, 'Chirurgie des sinus'),
(30487, 5948, 8, 'TENDRESSE DES SINUS:'),
(30488, 5949, 8, 'Sinusite'),
(30489, 5950, 8, 'Site'),
(30490, 5951, 8, 'ID du site'),
(30491, 5956, 8, 'Taille'),
(30492, 5957, 8, 'La taille doit être un nombre entre 1 et 999'),
(30493, 5958, 8, 'Taille/Liste'),
(30494, 5959, 8, 'Peau'),
(30495, 5960, 8, 'Cancer de la peau'),
(30496, 5961, 8, 'Maladie de peau'),
(30497, 5962, 8, 'Autre choses sur la peau'),
(30498, 5963, 8, 'Passée l''autorisation pour les notes du patient'),
(30499, 5964, 8, 'Passée la sélection'),
(30500, 5967, 8, 'Motif de Sommeil'),
(30501, 5968, 8, 'Motif de sommeil'),
(30502, 5969, 8, 'Sommeil'),
(30503, 5970, 8, 'Slovaque'),
(30504, 5974, 8, 'Fummeur, status actuel non connu'),
(30505, 5976, 8, 'Status du tabagisme'),
(30506, 5977, 8, 'Authentification SMS'),
(30507, 5978, 8, 'SMS Gateway'),
(30508, 5979, 8, 'SMS Gateway API key'),
(30509, 5980, 8, 'SMS Gateway API Key'),
(30510, 5981, 8, 'SMS Gateway Mot de passe'),
(30511, 5982, 8, 'SMS Gateway login utilisateur'),
(30512, 5983, 8, 'Notification SMS'),
(30513, 5984, 8, 'Heures de notification SMS'),
(30514, 5985, 8, 'SMS envoyé précédement'),
(30515, 5986, 8, 'SMS envoyé'),
(30516, 5988, 8, 'Paramètre des alertes SMS/Courriel'),
(30517, 5989, 8, 'SMTP mot de passe d''authentification'),
(30518, 5992, 8, 'SMTP Hostname du serveur'),
(30519, 5993, 8, 'SMTP Serveur Numero du Port'),
(30520, 5994, 8, 'SMTP login pour l''authentification'),
(30521, 5995, 8, 'SNOMED'),
(30522, 6004, 8, 'Ronflement'),
(30523, 6006, 8, 'Difficulté social'),
(30524, 6009, 8, 'Historique social:'),
(30525, 6010, 8, 'Numéro de sécurité social'),
(30526, 6011, 8, 'solution'),
(30527, 6013, 8, 'Contexte physique'),
(30528, 6014, 8, 'Certaines autorisations n''ont pas été affichées.Cliquez ici pour les voir tous.'),
(30529, 6015, 8, 'Certaines codes n''ont pas été affichées.'),
(30530, 6017, 8, 'Certaines erreurs ont été rencontrées lors du processus d''Identification'),
(30531, 6018, 8, 'Certaines notes n''ont pas été affichées'),
(30532, 6019, 8, 'Certaines notes du bureau n''ont pas été affichées.Cliquez ici pour voir tous.'),
(30533, 6020, 8, 'certain mots'),
(30534, 6023, 8, 'Quelquechose c''est mal passée. S''il vous plait essayez encore'),
(30535, 6026, 8, 'Irritation de la gorge'),
(30536, 6027, 8, 'Désolé aucun rendez-vous est pris'),
(30537, 6028, 8, 'Désolé, il y a eu un problème lors du téléversement de votre fichier'),
(30538, 6029, 8, 'Trier par'),
(30539, 6030, 8, 'Trier Par'),
(30540, 6031, 8, 'Trier par somme de contrôle'),
(30541, 6032, 8, 'Trier par commentaires'),
(30542, 6034, 8, 'Trier par la date'),
(30543, 6035, 8, 'Trier par la date'),
(30544, 6036, 8, 'Trier par évenement'),
(30545, 6037, 8, 'Trier par groupe'),
(30546, 6040, 8, 'Trier par ID patient'),
(30547, 6041, 8, 'Trier par succes'),
(30548, 6043, 8, 'Trier par utilisateur'),
(30549, 6044, 8, 'Trier par vaccin'),
(30550, 6045, 8, 'Trier par ordre décroissant'),
(30551, 6046, 8, 'Trier les resultats par'),
(30552, 6047, 8, 'Trier par odre croissant'),
(30553, 6048, 8, 'Source'),
(30554, 6049, 8, 'Fichier source'),
(30555, 6050, 8, 'Chemin du fichier source'),
(30556, 6054, 8, 'Patient source'),
(30557, 6055, 8, 'Le patient source n''a pas de D.D.N'),
(30558, 6056, 8, 'Le patient source n''a pas été trouvé'),
(30559, 6057, 8, 'Source:'),
(30560, 6060, 8, 'Espace'),
(30561, 6061, 8, 'ESPACE'),
(30562, 6062, 8, 'Espagnol'),
(30563, 6063, 8, 'Espagnol (Amerique Latine)'),
(30564, 6064, 8, 'Espagnol (Espagne)'),
(30565, 6066, 8, 'Les caractères spéciaux ne sont pas autorisé'),
(30566, 6067, 8, 'Traitement spéciale pour le formulaire des constantes vitales'),
(30567, 6068, 8, 'Spécialiste'),
(30568, 6069, 8, 'Nom et signature du Spécialiste'),
(30569, 6071, 8, 'Spécialité'),
(30570, 6072, 8, 'Systèmes spécialisés'),
(30571, 6073, 8, 'Spécialité:'),
(30572, 6074, 8, 'Spécifique'),
(30573, 6075, 8, 'Spplication spécifique'),
(30574, 6076, 8, 'Service de contraception spécifique'),
(30575, 6077, 8, 'Résultat spécifique'),
(30576, 6078, 8, 'Service spécifique'),
(30577, 6079, 8, 'Spécifiée'),
(30578, 6088, 8, 'Spécimen'),
(30579, 6089, 8, 'Numéro du spécimen/identifiant'),
(30580, 6090, 8, 'Type de spécimen'),
(30581, 6092, 8, 'Dictée vocale'),
(30582, 6093, 8, 'Spermicides'),
(30583, 6094, 8, 'Splénectomie'),
(30584, 6095, 8, 'Conjoint'),
(30585, 6097, 8, 'Crachat'),
(30586, 6098, 8, 'Crachat:'),
(30587, 6102, 8, 'Equipe'),
(30588, 6103, 8, 'Membres déquipe'),
(30589, 6104, 8, 'Equipes'),
(30590, 6111, 8, 'N.S.S.'),
(30591, 6112, 8, 'Administration du certificat SSL'),
(30592, 6113, 8, 'N.S.S.'),
(30593, 6114, 8, 'Stabilité'),
(30594, 6116, 8, 'Standard'),
(30595, 6117, 8, 'Code standard'),
(30596, 6118, 8, 'Mesures standard'),
(30597, 6119, 8, 'Mesures standard (Alertes active)'),
(30598, 6120, 8, 'Mesures standard (Alertes passive)'),
(30599, 6121, 8, 'Mesures standard (Rappels patient)'),
(30600, 6122, 8, 'Nom standard'),
(30601, 6124, 8, 'Début'),
(30602, 6125, 8, 'Début (aaaa-mm-jj): '),
(30603, 6126, 8, 'Commencer un nouveau rapport'),
(30604, 6128, 8, 'Date de début'),
(30605, 6129, 8, 'Date de début dans cette clinique'),
(30606, 6130, 8, 'Date de début ne doit pas être supérieur Date de fin'),
(30607, 6131, 8, 'Date de début:'),
(30608, 6132, 8, 'Date de début:'),
(30609, 6133, 8, 'Heure de début'),
(30610, 6134, 8, 'Date de démarrage'),
(30611, 6136, 8, 'État'),
(30612, 6137, 8, 'Type de donnée État'),
(30613, 6139, 8, 'Numéro de licence de l''État'),
(30614, 6140, 8, 'Liste des États'),
(30615, 6141, 8, 'Liste des États (écriture, ajout seulement optionnel)'),
(30616, 6142, 8, 'Liste des États (écriture, ajout seulement optionnel)'),
(30617, 6143, 8, 'État ou province'),
(30618, 6144, 8, 'État/Localité'),
(30619, 6145, 8, 'État/Paroisse'),
(30620, 6146, 8, 'Résumé du relevé'),
(30621, 6147, 8, 'Relevés et factures en cours de traitement.'),
(30622, 6148, 8, 'Relevés envoyés:'),
(30623, 6149, 8, 'Relevés; les factures ne seront pas mise à jour.'),
(30624, 6150, 8, 'Texte statique'),
(30625, 6151, 8, 'Statistiques'),
(30626, 6152, 8, 'Stats'),
(30627, 6153, 8, 'Status'),
(30628, 6154, 8, 'Status de l''admission'),
(30629, 6155, 8, 'Satus de la réclamation'),
(30630, 6156, 8, 'Status quo'),
(30631, 6158, 8, 'MST/SIDA aide psychologique'),
(30632, 6159, 8, 'Force et conditionnement'),
(30633, 6164, 8, 'Etapes pour l''installation de la base de données DSM IV'),
(30634, 6165, 8, 'Etapes pour l''installation de la base de données ICD 10'),
(30635, 6166, 8, 'Etapes pour l''installation de la base de données ICD 9'),
(30636, 6167, 8, 'Etapes pour l''installation de la base de données RxNorm'),
(30637, 6168, 8, 'Etapes pour l''installation de la base de données Snomed'),
(30638, 6169, 8, 'Raideur articulaire'),
(30639, 6170, 8, 'Raideur'),
(30640, 6172, 8, 'Douleurs a l''estomac'),
(30641, 6174, 8, 'Hashe enregistré'),
(30642, 6175, 8, 'Effort des muscles'),
(30643, 6176, 8, 'Flux'),
(30644, 6177, 8, 'Rue'),
(30645, 6178, 8, 'Rue de l''adresse'),
(30646, 6179, 8, 'Rue et numéro'),
(30647, 6180, 8, 'Force'),
(30648, 6182, 8, 'Angine'),
(30649, 6183, 8, 'Fracture de fatigue'),
(30650, 6184, 8, 'Test de stresse'),
(30651, 6185, 8, 'AVC'),
(30652, 6186, 8, 'Un mot de passe fort doit faire 8 caractères au minimum, et contenir au moins 3 des 4 types suivant: un nombre, une lettre minuscule, une lettre majuscule, un caratère spécial.'),
(30653, 6187, 8, 'Style'),
(30654, 6188, 8, 'Style de formulaire utilisé pour ajouter de nouveaux patients'),
(30655, 6189, 8, 'Sous-catégorie'),
(30656, 6190, 8, 'Sous-total'),
(30657, 6191, 8, 'Souscatégorie'),
(30658, 6192, 8, 'souscatégorie'),
(30659, 6193, 8, 'sous-cutané'),
(30660, 6194, 8, 'Sujet'),
(30661, 6195, 8, 'Subjectif'),
(30662, 6196, 8, 'Sous la langue'),
(30663, 6197, 8, 'sous la langue'),
(30664, 6198, 8, 'Soumettre'),
(30665, 6199, 8, 'soumettre'),
(30666, 6200, 8, 'Soumettre tout le contenu'),
(30667, 6202, 8, 'Soumettre l''evenement'),
(30668, 6203, 8, 'soumettre le formulaire'),
(30669, 6204, 8, 'Soumettre le contenu sélectionné'),
(30670, 6205, 8, 'Soumis'),
(30671, 6206, 8, 'Soumis par'),
(30672, 6208, 8, 'Abonné'),
(30673, 6209, 8, 'Adresse de l''abonné'),
(30674, 6213, 8, 'Employeur de l''abonné'),
(30675, 6215, 8, 'Adresse de l''employeur de l''abonné'),
(30676, 6216, 8, 'Ville de l''employeur de l''abonné'),
(30677, 6217, 8, 'Pays de l''employeur de l''abonné'),
(30678, 6218, 8, 'État de l''employeur de l''abonné'),
(30679, 6221, 8, 'Code postal de l''employeur de l''abonné'),
(30680, 6225, 8, 'Téléphone de l''abonné'),
(30681, 6226, 8, 'Relation de l''abonné'),
(30682, 6227, 8, 'L''abonné n''a pas célibataire en relation mais le nom est le même! Est ce réelement juste?'),
(30683, 6228, 8, 'L''abonné n''a pas célibataire en relation mais le N.S.S. est le même!'),
(30684, 6229, 8, 'L''abonné a célibataire en relation mais le nom est différent! Est ce réellement juste?'),
(30685, 6230, 8, 'L''abonné a célibataire en relation mais le S.S.N. est différent!'),
(30686, 6231, 8, 'Sexe de l''abonné'),
(30687, 6237, 8, 'Subtitution'),
(30688, 6238, 8, 'substitition autorisé'),
(30689, 6240, 8, 'Succès'),
(30690, 6241, 8, 'succès'),
(30691, 6242, 8, 'Succès confirmant la réception des résultats de laboratoire'),
(30692, 6243, 8, 'Succès d''obtention des resultats de laboratoire'),
(30693, 6244, 8, 'Succès de la récupération des résultats depuis le reseau d''echange de laboratoire'),
(30694, 6246, 8, 'Catégorie ajoutée avec succès'),
(30695, 6247, 8, 'a été ajouté avec succes à la catégorie'),
(30696, 6248, 8, 'Supprimé avec succès'),
(30697, 6250, 8, 'La base de donnée a été installée avec succès.'),
(30698, 6251, 8, 'La base de donnée suivante a été installée avec succès'),
(30699, 6252, 8, 'Modifié avec succès'),
(30700, 6253, 8, 'Sauvegarde Reussi.Souhaitez-vous l''atribuer ?'),
(30701, 6254, 8, 'Sauvegarde Reussi.Souhaitez-vous le distribuer ?'),
(30702, 6256, 8, 'Rangé avec succès.'),
(30703, 6257, 8, 'La mise à jour de la base de donnée cest déroulée avec succès'),
(30704, 6258, 8, 'La mise à jour de la base de donnée suivante cest déroulée avec succès'),
(30705, 6259, 8, 'Avec succès.'),
(30706, 6260, 8, 'Suicide'),
(30707, 6261, 8, 'Résumé'),
(30708, 6262, 8, 'Résumé de'),
(30709, 6265, 8, 'Soleil'),
(30710, 6267, 8, 'Dimanche'),
(30711, 6275, 8, 'Superutilisateur'),
(30712, 6276, 8, 'Suveillance'),
(30713, 6283, 8, 'Nom de l''établissement fournisseur'),
(30714, 6289, 8, 'Type de surface'),
(30715, 6290, 8, 'Chirurgies'),
(30716, 6291, 8, 'Chirurgie'),
(30717, 6292, 8, 'Liste des problèmes de la chirurgie'),
(30718, 6293, 8, 'Suspendu'),
(30719, 6294, 8, 'suspension'),
(30720, 6299, 8, 'Traspiration:'),
(30721, 6300, 8, 'Suèdois'),
(30722, 6301, 8, 'Enflure'),
(30723, 6302, 8, 'Enflure droite'),
(30724, 6303, 8, 'Articulations enflées'),
(30725, 6304, 8, 'Ganglions lymphatique enflés'),
(30726, 6305, 8, 'Symbole utilisé comme point décimal pour les monaies. Non utilisé si Decimal Places est à 0.'),
(30727, 6306, 8, 'Symbole utilisé pour séparé les centaines pour les monaies.'),
(30728, 6307, 8, 'Symptômes'),
(30729, 6308, 8, 'Synchroniser'),
(30730, 6309, 8, 'Synchroniser les traductions avec la table de personnalisation du langage'),
(30731, 6310, 8, 'Nouvelle constante personalisé synchronisé'),
(30732, 6311, 8, 'Nouvelle langue personalisée synchronisé'),
(30733, 6312, 8, 'Nouvelle definition synchronisé (Langage,constante,definition):'),
(30734, 6313, 8, 'Syncope'),
(30735, 6317, 8, 'Synovie, empiètement, bursite'),
(30736, 6318, 8, 'Système'),
(30737, 6325, 8, 'Table'),
(30738, 6327, 8, 'Création de la table échouée'),
(30739, 6328, 8, 'Mise à jour de la table échouée'),
(30740, 6330, 8, 'comprimé'),
(30741, 6332, 8, 'Tagalog'),
(30742, 6335, 8, 'Prendre'),
(30743, 6336, 8, 'Choisir l''assurance, depuis le menu déroulant'),
(30744, 6337, 8, 'Selectionner le paiment à partir, depuis le menu déroulant'),
(30745, 6339, 8, 'Prend du temps'),
(30746, 6340, 8, 'Grande zone de navigation'),
(30747, 6344, 8, 'La D.D.N source et cible ne correspondent pas'),
(30748, 6345, 8, 'Le pid source et cible pourrait ne pas être le même!'),
(30749, 6346, 8, 'Le N.S.S source et cible ne correspondent pas'),
(30750, 6347, 8, 'Date cible'),
(30751, 6348, 8, 'Patient cible'),
(30752, 6349, 8, 'Le patient cible n''a pas de D.D.N'),
(30753, 6350, 8, 'Le patient cible n''a pas été trouvé'),
(30754, 6351, 8, 'Groupes de cible/actions'),
(30755, 6354, 8, 'ID Taxe'),
(30756, 6355, 8, 'Taux de la taxe'),
(30757, 6356, 8, 'Taxes'),
(30758, 6357, 8, 'Taxonomie'),
(30759, 6359, 8, 'Vue de l''équipe des blessures'),
(30760, 6360, 8, 'Tableau de service'),
(30761, 6361, 8, 'Vue du tableau de service'),
(30762, 6362, 8, 'Équipe/Groupe'),
(30763, 6363, 8, 'Tel'),
(30764, 6364, 8, 'Code téléphonique du pays'),
(30765, 6366, 8, 'Temporaire'),
(30766, 6367, 8, 'Emplacement temporaire'),
(30767, 6368, 8, 'Méthode temporaire'),
(30768, 6369, 8, 'Température'),
(30769, 6370, 8, 'Gabarit'),
(30770, 6371, 8, 'Nom du gabarit'),
(30771, 6372, 8, 'Les noms de gabarit ne peuvent pas commencer avec des nombres.'),
(30772, 6373, 8, 'Gabarit:'),
(30773, 6374, 8, 'Gabarits'),
(30774, 6375, 8, 'Artère temporale'),
(30775, 6376, 8, 'lésion tendineuse'),
(30776, 6377, 8, 'Tendinite / problème / bursite'),
(30777, 6378, 8, 'Tentative de facture Ref No'),
(30778, 6379, 8, 'Tertiaire'),
(30779, 6380, 8, 'Assurance tertiaire'),
(30780, 6381, 8, 'Données de l''assurance tertiaire'),
(30781, 6382, 8, 'Fournisseur de l''assurance tertiaire'),
(30782, 6383, 8, 'Emplois du temps test'),
(30783, 6384, 8, 'Système de test'),
(30784, 6385, 8, 'Texte'),
(30785, 6386, 8, 'Texte diagnostic'),
(30786, 6387, 8, 'Champs texte'),
(30787, 6393, 8, 'Date-Texte'),
(30788, 6394, 8, 'date-texte'),
(30789, 6395, 8, 'Zone de texte'),
(30790, 6396, 8, 'zone de texte'),
(30791, 6397, 8, 'Boite de texte'),
(30792, 6398, 8, 'boite de texte'),
(30793, 6399, 8, 'Liste de boites de texte'),
(30794, 6400, 8, 'Liste de boites de texte'),
(30795, 6401, 8, 'Thai'),
(30796, 6402, 8, 'Merci'),
(30797, 6403, 8, 'Merci à vous pour avoir choisit'),
(30798, 6404, 8, 'Le bouton ''Effacer'' va supprimer toutes les annotations.'),
(30799, 6405, 8, 'La déclaration ci-dessus a échouée'),
(30800, 6408, 8, 'Le fichier de réclamation: '),
(30801, 6422, 8, 'Le(s) évenement(s) a/ont été autorisé.'),
(30802, 6423, 8, 'Le(s) évenement(s) a/ont été caché.'),
(30803, 6458, 8, 'La fusion ne va pas s''executer a moins que le N.S.S. et la D.D.N des deux entités soient identique. Les D.D.Ns ne peuvent pas être vide.'),
(30804, 6459, 8, 'Le message pourrait ne pas être envoyé durant cette période.'),
(30805, 6460, 8, 'La nouvelle catégorie sera une sous-catégorie de '),
(30806, 6461, 8, 'Le nouveau mot de passe ne peut pas être le même que le mot de passe actuel.'),
(30807, 6462, 8, 'Les champs de nouveau mot de passe ne sont pas les même.'),
(30808, 6466, 8, 'Le mot de passe doit avoir au moins 8 caractères, et doit'),
(30809, 6469, 8, 'Les rappels du patient à été envoyé'),
(30810, 6470, 8, 'Les rappels du patient à été envoyé'),
(30811, 6492, 8, 'Le fichier vide va contenir les objets suivant'),
(30812, 6493, 8, 'Theme'),
(30813, 6495, 8, 'Injections thérapeutique'),
(30814, 6496, 8, 'Il y a'),
(30815, 6497, 8, 'Actuelement il y a aucunes prescriptions'),
(30816, 6501, 8, 'Il n''y a pas de divulgations enregistré pour ce patient'),
(30817, 6502, 8, 'Il n''y a pas de nouvelle sousmissions'),
(30818, 6503, 8, 'Il n''y a pas de notes sur le fichier pour ce patient.'),
(30819, 6504, 8, 'Il n''y a aucune transactions sur le fichier de ce patient.'),
(30820, 6505, 8, 'Il y a eu une erreur lors de l''envois de mail'),
(30821, 6506, 8, 'Il y a déjà une catégorie nommé'),
(30822, 6507, 8, 'Il y a déjà une sous-catégorie nommé'),
(30823, 6508, 8, 'Il y a déjà un objet nommé'),
(30824, 6509, 8, 'Il y a toujours une requète d''enregistrement de patient ouverte.'),
(30825, 6513, 8, 'Il n''y a pas de patient actuel'),
(30826, 6515, 8, 'Il n''y a pas de correspondance avec l''id de la facture'),
(30827, 6516, 8, 'Il n''y a pas de correspondance avec l''id de la facture = '),
(30828, 6519, 8, 'Il y a eu un problème a l''envois du message.'),
(30829, 6520, 8, 'Il y a eu une erreur durant l''execution de votre requète.'),
(30830, 6522, 8, 'Ceci sont les liens 2012'),
(30831, 6524, 8, 'Cuisse'),
(30832, 6525, 8, 'Cuisse + tendon du jarret'),
(30833, 6526, 8, 'Choses que les services administratifs peuvent seulement lire'),
(30834, 6527, 8, 'Choses que les services administratifs peuvent seulement lire et ajouter mais pas modifier'),
(30835, 6528, 8, 'Choses que les services administratifs peuvent lire et modifier'),
(30836, 6529, 8, 'Choses que les services administratifs peuvent lire et partielement modifier'),
(30837, 6530, 8, 'Choses que les cliniciens peuvent seulements lire'),
(30838, 6531, 8, 'Choses que les cliniciens peuvent lire et ajouter mais pas modifier'),
(30839, 6532, 8, 'Choses que les cliniciens peuvent lire et modifier'),
(30840, 6533, 8, 'Choses que les cliniciens peuvent lire et partielement modifier'),
(30841, 6534, 8, 'Choses que l''acceuil peut seulement lire'),
(30842, 6535, 8, 'Choses que l''acceuil peut seulement lire et ajouter mais pas modifier'),
(30843, 6536, 8, 'Choses que l''acceuil peut lire et modifier'),
(30844, 6537, 8, 'Choses que l''acceuil peut lire et partielement modifier'),
(30845, 6538, 8, 'Choses que les médecins peuvent seulement lire'),
(30846, 6539, 8, 'Choses que les médecins peuvent lire et ajouter mais pas modifier'),
(30847, 6540, 8, 'Choses que les médecins peuvent lire et modifier'),
(30848, 6541, 8, 'Choses que les médecins peuvent lire et partielement modifier'),
(30849, 6542, 8, 'Troisième'),
(30850, 6544, 8, 'Cette action NE PEUT PAS être annulée.'),
(30851, 6545, 8, 'Cette action ne peut pas être annulée.'),
(30852, 6547, 8, 'Cette action sera enregistrée'),
(30853, 6552, 8, 'Cette réclamation a été annulée'),
(30854, 6553, 8, 'Cette réclamation a été fermée.'),
(30855, 6554, 8, 'Cette réclamation a été refusée. Raison:-'),
(30856, 6555, 8, 'Cette réclamation est passée au niveau suivant.'),
(30857, 6556, 8, 'Ce type de code n''accèpte pas les relations.'),
(30858, 6558, 8, 'Ceci determine comment les rendez-vous s''affiche sur le calendrier.'),
(30859, 6559, 8, 'Ceci determine quel schéma de couleur sera utilisé pour les rendez-vous'),
(30860, 6561, 8, 'Cette rencontre'),
(30861, 6562, 8, 'Cette rencontre a été payée. Si vous devez changer ceci, elle doit être ré-ouverte.'),
(30862, 6564, 8, 'Cette fonctionnalitée n''est pas disponible'),
(30863, 6565, 8, 'Cette fonctionnalitée est très expérimentale et peu testée. Utilisez la a vos propre risques!'),
(30864, 6566, 8, 'Le numéro de facturation a été changer en '),
(30865, 6572, 8, 'cette location'),
(30866, 6575, 8, 'Ce module est en mode test. La base de donnée ne sera pas changée.'),
(30867, 6580, 8, 'Cette page est désactivée pour des raisons de sécurité.'),
(30868, 6582, 8, 'Ce patient a aucune activité.'),
(30869, 6583, 8, 'Cette ID patient est déjà utilisée!'),
(30870, 6584, 8, 'Ce produit autorise seulement un lot par entrepôt.'),
(30871, 6585, 8, 'Ce protocole est non implémenté'),
(30872, 6586, 8, 'Ce rapport fonctionne actuelement seulement pour les codes ICD9.'),
(30873, 6591, 8, 'Cette étape va générer un fichier que vous devez sauvegarder pour une utilisation futur. Ce fichier ne pourra pas être regénéré. Voulez vous continuer?'),
(30874, 6592, 8, 'Cet utilisateur est membre d''aucun groupes'),
(30875, 6593, 8, 'Cet utilisateur va recevoir des notifications des nouveau messages Direct arrivant'),
(30876, 6595, 8, 'Cette visite marque le début d''une nouvelle utilisation de contraceptifs'),
(30877, 6597, 8, 'Ceci était l''ancien formulaire des constantes vitals avec métrique seulement, maintenant déprécié.'),
(30878, 6622, 8, 'Colonne vertébrale thorasique'),
(30879, 6625, 8, 'Gorge'),
(30880, 6626, 8, 'Cancer de la gorge'),
(30881, 6627, 8, 'Chirurgie du cancer de la gorge'),
(30882, 6628, 8, 'Thrombose/AVC'),
(30883, 6629, 8, 'Jeu.'),
(30884, 6630, 8, 'Jeudi'),
(30885, 6631, 8, 'Jeudi'),
(30886, 6632, 8, 'Thyroïde normale'),
(30887, 6633, 8, 'Problèmes à la thyroïde'),
(30888, 6638, 8, 'Temps'),
(30889, 6639, 8, 'Format d''affichage du temps'),
(30890, 6640, 8, 'Incrément du temps pour l''ajout (minutes 1-60)'),
(30891, 6641, 8, 'Sélection du temps'),
(30892, 6642, 8, 'Période de temps ouverte, sauvegarde de l''événement'),
(30893, 6647, 8, 'Événement daté'),
(30894, 6649, 8, 'Marqueur temporel et texte'),
(30895, 6651, 8, 'Acouphène'),
(30896, 6652, 8, 'Titre'),
(30897, 6653, 8, 'Titre V'),
(30898, 6655, 8, 'Titres'),
(30899, 6658, 8, 'Pour'),
(30900, 6659, 8, 'POUR'),
(30901, 6660, 8, 'pour'),
(30902, 6661, 8, 'Pour le chemin absolu du fichier'),
(30903, 6662, 8, 'Pour ajouter des notes, s''il vous plait cliquez '),
(30904, 6663, 8, 'Pour ajouter des notes, s''il vous plait cliquez ici'),
(30905, 6664, 8, 'Vers la zone affectée'),
(30906, 6665, 8, 'vers la zone affectée'),
(30907, 6666, 8, 'Pour ouvrir automatiquement le formulaire spécifié. Certaines équipes de sport utilise ici football_injury_audit.'),
(30908, 6667, 8, 'Vers la vue de facturation'),
(30909, 6668, 8, 'Vers la vue de facturation'),
(30910, 6669, 8, 'Vers la vue clinique'),
(30911, 6670, 8, 'Vers le ticket modérateur'),
(30912, 6674, 8, 'Pour désactiver les certificats SSL coté client, commenter les lignes ci-dessus dans le fichier de configuration Apache et mettre'),
(30913, 6675, 8, 'Pour désactivé https, commnenter les lignes ci-dessus dans le fichier de configuration Apache et redémarer le serveur Apache.'),
(30914, 6676, 8, 'Pour activer les certificats ssl coté client'),
(30915, 6677, 8, 'Pour activer l''authentification coté client par certificat SSL. HTTPS devrait être activé.'),
(30916, 6678, 8, 'Pour activité uniquement HTTPS, faites les changement ci-dessus et redémaré le serveur Apache. Si vous voullez configurer égalements les certificats coté client, s''il vous plait configuré les dans la section suivante.'),
(30917, 6680, 8, 'Pour filtrer par sexe'),
(30918, 6681, 8, 'Pour l''historique'),
(30919, 6682, 8, 'Pour les problèmes'),
(30920, 6683, 8, 'Pour lié cette rencontre/consultation à un problème existant, cliquez sur le '),
(30921, 6685, 8, 'Pour ce connecter encore'),
(30922, 6686, 8, 'Pour enregistrer les révélations, s''il vous plait cliquez'),
(30923, 6687, 8, 'Pour executer'),
(30924, 6688, 8, 'Pour configurer les accès https avec l''authentification client par certification, faire ce qui suit'),
(30925, 6691, 8, 'Pour cette visite?'),
(30926, 6693, 8, 'À:'),
(30927, 6694, 8, 'À: '),
(30928, 6708, 8, 'Tabac'),
(30929, 6709, 8, 'Intervention en abandon du tabagisme'),
(30930, 6710, 8, 'Intervention en abandon du tabagisme (CQC)'),
(30931, 6712, 8, 'Tabagisme'),
(30932, 6713, 8, 'Questionnaire sur tabagisme'),
(30933, 6714, 8, 'Questionnaire sur tabagisme (CQC)'),
(30934, 6715, 8, 'Aujourd''hui'),
(30935, 6716, 8, 'AUJOURD''HUI'),
(30936, 6717, 8, 'aujourd''hui'),
(30937, 6718, 8, 'Solde d''aujourd''hui'),
(30938, 6719, 8, 'Charges d''aujourd''hui'),
(30939, 6720, 8, 'Date d''Aujourd''hui'),
(30940, 6721, 8, 'Evènements Ce jour'),
(30941, 6726, 8, 'Amydalectomie'),
(30942, 6728, 8, 'Haut'),
(30943, 6730, 8, 'Sujet'),
(30944, 6731, 8, 'Total'),
(30945, 6732, 8, 'total'),
(30946, 6733, 8, 'Total des actions actives'),
(30947, 6734, 8, 'Total des rappels actif après mise à jour'),
(30948, 6735, 8, 'Total des rappels actif avant mise à jour'),
(30949, 6737, 8, 'Montant total dû'),
(30950, 6738, 8, 'Montant Total Payé'),
(30951, 6739, 8, 'Total de solde du'),
(30952, 6740, 8, 'Total de la charge'),
(30953, 6741, 8, 'Total des charges'),
(30954, 6742, 8, 'Total des clients'),
(30955, 6743, 8, 'Coût total'),
(30956, 6745, 8, 'Entrées totales'),
(30957, 6746, 8, 'Total des échecs des envois de rappels par courriel'),
(30958, 6747, 8, 'Total des échecs des envois de rappels par téléphone'),
(30959, 6748, 8, 'Total pour'),
(30960, 6749, 8, 'Total pour '),
(30961, 6750, 8, 'Total pour la catégorie'),
(30962, 6751, 8, 'Total de Rappels désactivés'),
(30963, 6752, 8, 'Total de nouveaux rappels'),
(30964, 6753, 8, 'Nombre total de rendez-vous'),
(30965, 6755, 8, 'Nombre Total de Vaccination'),
(30966, 6756, 8, 'Nombre total de problèmes'),
(30967, 6758, 8, 'Nombre Total de Patients'),
(30968, 6760, 8, 'Solde total du patient'),
(30969, 6761, 8, 'Patients total'),
(30970, 6764, 8, 'Total des enregistrement fournis'),
(30971, 6766, 8, 'Total des rappels envoyés avec succès par courriel'),
(30972, 6767, 8, 'Total des rappels envoyés avec succès par téléphone'),
(30973, 6770, 8, 'Total des rappels non changé'),
(30974, 6771, 8, 'Total des rappels non envoyé après le processus d''envois'),
(30975, 6772, 8, 'Total des rappels non envoyé après mise à jour'),
(30976, 6773, 8, 'Total des rappels non envoyé avant le processus d''envois'),
(30977, 6774, 8, 'Total des rappels non envoyé avant mise à jour'),
(30978, 6775, 8, 'Total des rappels mis à jour'),
(30979, 6776, 8, 'Totals'),
(30980, 6777, 8, 'Totals pour'),
(30981, 6778, 8, 'Totals pour '),
(30982, 6785, 8, 'Type d''entrainement'),
(30983, 6787, 8, 'Transaction'),
(30984, 6788, 8, 'transaction'),
(30985, 6789, 8, 'Transaction échoué, quantité insufisante dans le lot de destination'),
(30986, 6790, 8, 'Transaction échoué, la quantité est inférieur a zéro'),
(30987, 6791, 8, 'Type de transaction'),
(30988, 6792, 8, 'transactions'),
(30989, 6793, 8, 'Transactions'),
(30990, 6794, 8, 'Transactions (écriture optionnel)'),
(30991, 6795, 8, 'Transactions/Envois vers un spécialiste'),
(30992, 6797, 8, 'Transfert'),
(30993, 6798, 8, 'Date de transfert'),
(30994, 6799, 8, 'Transfert'),
(30995, 6800, 8, 'Résumé de transfert'),
(30996, 6801, 8, 'Transféré à'),
(30997, 6804, 8, 'Transferts'),
(30998, 6806, 8, 'Transition/Transfert de soin?'),
(30999, 6807, 8, 'Traduire les groupes de controles d''accès'),
(31000, 6808, 8, 'Traduire les categories de rendez-vous'),
(31001, 6809, 8, 'Traduire les categories de documents'),
(31002, 6810, 8, 'Disposition des traductions'),
(31003, 6811, 8, 'Listes de traduction'),
(31004, 6812, 8, 'Traduire les titres des notes patients'),
(31005, 6813, 8, 'Traduire ceci'),
(31006, 6814, 8, 'Traduction'),
(31007, 6815, 8, 'Traductions'),
(31008, 6816, 8, 'Transmettre'),
(31009, 6817, 8, 'Transmission échoué'),
(31010, 6818, 8, 'Transmission des ordres sélectionné'),
(31011, 6819, 8, 'Traumatisme'),
(31012, 6820, 8, 'Traitement'),
(31013, 6822, 8, 'Objectifs du traitement'),
(31014, 6823, 8, 'Plan thérapeutique'),
(31015, 6824, 8, 'Planning thérapeutique'),
(31016, 6825, 8, 'Traitement reçu'),
(31017, 6826, 8, 'Traitement:'),
(31018, 6827, 8, 'Traitement: '),
(31019, 6828, 8, 'Tendance'),
(31020, 6831, 8, 'Tri-malléolaire'),
(31021, 6832, 8, 'Thorax et abdomen'),
(31022, 6835, 8, 'Tentative de création d''un utilisateur avec un nom existant!'),
(31023, 6840, 8, 'Tuberculose'),
(31024, 6841, 8, 'Mar.'),
(31025, 6842, 8, 'Mar. &amp; Jeu.'),
(31026, 6843, 8, 'Mardi'),
(31027, 6844, 8, 'Tumeur'),
(31028, 6845, 8, 'Turque'),
(31029, 6848, 8, 'deux fois par jour'),
(31030, 6850, 8, 'Tympan'),
(31031, 6851, 8, 'Type'),
(31032, 6852, 8, 'Taper Id ou Nom, 3 caractères min. (espaces inclus)'),
(31033, 6853, 8, 'Type de colonnes affichées pour les resultats de recherche sur les patients'),
(31034, 6854, 8, 'Type de divulgation'),
(31035, 6855, 8, 'Type d''évenements'),
(31036, 6856, 8, 'Type de disposition d''écran'),
(31037, 6857, 8, 'Entrer ou scanner l''identifiant du patient ici'),
(31038, 6858, 8, 'Entrer votre message ici'),
(31039, 6859, 8, 'Types d''ordre ou de résultats'),
(31040, 6864, 8, 'UCSMC code fournies par le Centre de la medicine du Sports de l''Université de Calgary'),
(31041, 6865, 8, 'Ukrainien'),
(31042, 6866, 8, 'Ulcérations'),
(31043, 6867, 8, 'Colite Ulcéreuse'),
(31044, 6868, 8, 'Ulcères:'),
(31045, 6871, 8, 'Création Impossible'),
(31046, 6874, 8, 'Impossible de faire correspondre ce paiement dans les ar_activity'),
(31047, 6876, 8, 'Non Appliquée'),
(31048, 6877, 8, 'Non Attribué'),
(31049, 6878, 8, 'Non autorisé'),
(31050, 6879, 8, 'Accès non autorisé à ePrescription'),
(31051, 6880, 8, 'Accès non autorisé.'),
(31052, 6881, 8, 'Non facturé'),
(31053, 6882, 8, 'Uniquement Les non Facturés'),
(31054, 6884, 8, 'sous la langue'),
(31055, 6885, 8, 'Insuffisance Pondérale'),
(31056, 6886, 8, 'Non Diagnostiqué'),
(31057, 6887, 8, 'NON RÉPARTI'),
(31058, 6888, 8, 'Non réparti'),
(31059, 6889, 8, 'Non réparti est'),
(31060, 6890, 8, 'Annuler la Vérification'),
(31061, 6892, 8, 'Clients Unique'),
(31062, 6893, 8, 'Identifiant lisible Unique pour ce type'),
(31063, 6894, 8, 'Nouveau Client Unique'),
(31064, 6895, 8, 'Identificateur numérique unique pour ce type'),
(31065, 6896, 8, 'Patients Vu Unique'),
(31066, 6897, 8, 'Rapport de Patients Vu Unique'),
(31067, 6898, 8, 'SP Unique'),
(31068, 6899, 8, 'Unité'),
(31069, 6900, 8, 'Unités'),
(31070, 6901, 8, 'unités'),
(31071, 6902, 8, 'Unités applicable a la valeur résultat'),
(31072, 6903, 8, 'Unités pour les Formulaire de Visite'),
(31073, 6904, 8, 'Les unités doivent être un nombre'),
(31074, 6905, 8, 'Unités Indéfinies'),
(31075, 6906, 8, 'Unités / L'),
(31076, 6907, 8, 'Inconnu'),
(31077, 6910, 8, 'Inconnu si déjà fumé'),
(31078, 6911, 8, 'Inconnu ou N/A'),
(31079, 6912, 8, 'ID utilisateur inconnue'),
(31080, 6913, 8, 'patient non lié'),
(31081, 6914, 8, 'AMO sans Nom'),
(31082, 6915, 8, 'non inscrit'),
(31083, 6918, 8, 'Tout dé-sélectionner'),
(31084, 6919, 8, 'non sélectionnés'),
(31085, 6920, 8, 'Non spécifié'),
(31086, 6921, 8, 'non structuré'),
(31087, 6922, 8, 'Fichier de chargement de base de données Non-Supporté'),
(31088, 6924, 8, 'jusqu''à ce'),
(31089, 6925, 8, 'le dépôt intempestif'),
(31090, 6926, 8, 'Inutilisé'),
(31091, 6928, 8, 'Jusqu''à'),
(31092, 6929, 8, 'Prochains Rendez-vous'),
(31093, 6930, 8, 'Événements à venir'),
(31094, 6931, 8, 'Mise à jour'),
(31095, 6932, 8, 'mise à jour'),
(31096, 6933, 8, 'Mise à jour Actif'),
(31097, 6934, 8, 'Mise à jour de fichiers'),
(31098, 6935, 8, 'Info de Mise à Jour'),
(31099, 6936, 8, 'Liste de Mise à jour'),
(31100, 6937, 8, 'Mettre à jour le Numéro de fournisseur'),
(31101, 6938, 8, 'Mettre à jour les éléments sélectionnés'),
(31102, 6939, 8, 'Mettre à jour les variables suivantes dans le fichier'),
(31103, 6940, 8, 'Mettre à jour les données utilisateur'),
(31104, 6942, 8, 'Mise à jour des données démographiques n''est pas autorisée.'),
(31105, 6943, 8, 'Mise à jour de la configuration globale par défauts'),
(31106, 6944, 8, 'Mise à jour des indicateurs de version'),
(31107, 6945, 8, 'MISE À JOUR'),
(31108, 6946, 8, 'Mise à niveau'),
(31109, 6947, 8, 'Mise à niveau de Base de Données'),
(31110, 6948, 8, 'Mises à niveau la base de données LibreEHR afin d''inclure les Procédures, Fonctions et tables nécessaires au processus de De-identification'),
(31111, 6949, 8, 'Mise à niveau va continuer'),
(31112, 6951, 8, 'Transférer'),
(31113, 6954, 8, 'Transférer les données de configuration'),
(31114, 6955, 8, 'Transférer le Document'),
(31115, 6956, 8, 'Échec du transfert!'),
(31116, 6957, 8, 'Transférer l''image à'),
(31117, 6958, 8, 'Transférer le fichier d''import :'),
(31118, 6960, 8, 'La mise à jour c''est déroullée avec succès'),
(31119, 6961, 8, 'Transférer le Rapport'),
(31120, 6963, 8, 'Transférer ce fichier:'),
(31121, 6966, 8, 'Haut du bras'),
(31122, 6968, 8, 'Urgence'),
(31123, 6970, 8, 'Urine'),
(31124, 6971, 8, 'Miction Goutte à Goutte'),
(31125, 6972, 8, 'Fréquence des Mictions'),
(31126, 6973, 8, 'Hésitation d''Urine'),
(31127, 6974, 8, 'Microalbumine urinaire'),
(31128, 6975, 8, 'Jet d''Urine'),
(31129, 6976, 8, 'Urgence urinaire'),
(31130, 6977, 8, 'URL'),
(31131, 6979, 8, 'URL pour le support LibreEHR.'),
(31132, 6981, 8, 'URL pour la passerelle téléphonique. Service automatisé VOIP offert par Maviq. Veuillez visitez http://signup.maviq.com pour plus d''informations.'),
(31133, 6985, 8, 'Utilisation'),
(31134, 6986, 8, 'Indicateur d''Utilisation (ISA15)'),
(31135, 6987, 8, 'Utilisez % uniquement dans un champ pour trié en fonction de cette colonne'),
(31136, 6988, 8, 'Utiliser le format 24 heures?'),
(31137, 6990, 8, 'Utiliser la technologie certifiée DSE pour identifier des ressources d''éducation spécifique à chaque patient et de fournir les ressources nécessaires pour le patient, le cas échéant.'),
(31138, 6991, 8, 'Utilisez le Panel des Frais'),
(31139, 6992, 8, 'Utilisez CPOE pour les commandes de médication entrés directement par tout professionnel de santé agréé qui peut entrer des commandes dans le dossier médical par Etat, directives locales et professionnelles.'),
(31140, 6997, 8, 'Utiliser la liste de vaccination personnalisée'),
(31141, 6999, 8, 'Utiliser Intervalle de dates'),
(31142, 7000, 8, 'Utiliser les Valeurs par Défaut'),
(31143, 7001, 8, 'Utilisez l''Option Supprimer pour le Retirer.'),
(31144, 7002, 8, 'Utilisez le style de date international?'),
(31145, 7003, 8, 'Utiliser le nom du fichier source'),
(31146, 7004, 8, 'Utilisez le champs ci-dessous pour un achat ou un transfert.'),
(31147, 7005, 8, 'Utilisez cette fonction uniquement avec des sites nouvellement installés, '),
(31148, 7006, 8, 'Utilisez les sujets?'),
(31149, 7007, 8, 'Utilisateur'),
(31150, 7009, 8, 'Utilisateur / Groupes'),
(31151, 7010, 8, 'Administration des Utilisateurs'),
(31152, 7011, 8, 'Administration des Utilisateurs et Services'),
(31153, 7012, 8, 'Administration des Utilisateurs et Groupe'),
(31154, 7014, 8, 'Certificat d''Authentification Utilisateur est désactivé'),
(31155, 7015, 8, 'Défini par l''Utilisateur'),
(31156, 7016, 8, 'Défini par l''Utilisateur Zone 11'),
(31157, 7017, 8, 'Défini par l''Utilisateur Zone 12'),
(31158, 7018, 8, 'Défini par l''Utilisateur Champ'),
(31159, 7019, 8, 'Défini par l''Utilisateur Liste 1'),
(31160, 7020, 8, 'Défini par l''Utilisateur Liste 2'),
(31161, 7021, 8, 'Défini par l''Utilisateur Liste 3'),
(31162, 7022, 8, 'Défini par l''Utilisateur Liste 4'),
(31163, 7023, 8, 'Défini par l''Utilisateur Liste 5'),
(31164, 7024, 8, 'Défini par l''Utilisateur Liste 6'),
(31165, 7025, 8, 'Défini par l''Utilisateur Liste 7'),
(31166, 7026, 8, 'Défini par l''Utilisateur Texte 1'),
(31167, 7027, 8, 'Défini par l''Utilisateur Texte 2'),
(31168, 7028, 8, 'Défini par l''Utilisateur Texte 3'),
(31169, 7029, 8, 'Défini par l''Utilisateur Texte 4'),
(31170, 7030, 8, 'Défini par l''Utilisateur Texte 5'),
(31171, 7031, 8, 'Défini par l''Utilisateur Texte 6'),
(31172, 7032, 8, 'Défini par l''Utilisateur Texte 7'),
(31173, 7033, 8, 'Défini par l''Utilisateur Texte 8'),
(31174, 7034, 8, 'Prénom utilisateur'),
(31175, 7037, 8, 'Login Utilisateur (si 03 et plus, sinon laisser des espaces) (ISA02)'),
(31176, 7038, 8, 'Nom d''utilisateur requiere un indice (ISA01~ utiliser 00 ou 03)'),
(31177, 7039, 8, 'Manuel Utilisateur'),
(31178, 7040, 8, 'Affiliations d''Utilisateur'),
(31179, 7041, 8, 'Nom Utilisateur'),
(31180, 7042, 8, 'Nom d''Utilisateur ou le nom d''Hôte ne peut pas être vide'),
(31181, 7043, 8, 'Utilisateur ou nom d''Hôte'),
(31182, 7044, 8, 'Mot de passe utilisateur (ISA04~si 01 et plus, sinon laisser des espaces)'),
(31183, 7045, 8, 'Mot de passe utilisateur requiere un indice (ISA03~ utiliser 00 ou 01)'),
(31184, 7046, 8, 'Paramètres Utilisateur'),
(31185, 7047, 8, 'Paramètre Utilisateur Spécifique'),
(31186, 7048, 8, 'Nouveau mot de passe de l''utilisateur'),
(31187, 7049, 8, 'Nom Utilisateur'),
(31188, 7051, 8, 'Nom utilisateur pour la passerelle téléphonique. Service automatisé VOIP offert par Maviq. Veuillez visitez http://signup.maviq.com pour plus d''informations.'),
(31189, 7052, 8, 'Nom Utilisateur pour la Passerelle SMS'),
(31190, 7053, 8, 'Nom Utilisateur pour la Passerelle SMS.'),
(31191, 7054, 8, 'Nom d''utilisateur pour ce connecter a CouchDB'),
(31192, 7055, 8, 'Nom Utilisateur:'),
(31193, 7056, 8, 'Utilisateurs'),
(31194, 7057, 8, 'Utilisateurs/Groupes/Journaux d''Administration'),
(31195, 7058, 8, 'Utilise le format php <a href="http://php.net/strftime">strftime</a>'),
(31196, 7059, 8, 'Infections Urinaires'),
(31197, 7062, 8, 'Vacances'),
(31198, 7063, 8, 'Vacances'),
(31199, 7064, 8, 'vaccin'),
(31200, 7065, 8, 'Anneau Vaginal'),
(31201, 7066, 8, 'Discours d''adieu'),
(31202, 7067, 8, 'valider'),
(31203, 7068, 8, 'Valeur'),
(31204, 7069, 8, 'Valeur 1'),
(31205, 7070, 8, 'Valeur 2'),
(31206, 7072, 8, 'La Valeur doit être numérique'),
(31207, 7073, 8, 'Var1'),
(31208, 7074, 8, 'Var2'),
(31209, 7076, 8, 'Varicelle 1'),
(31210, 7077, 8, 'Varicelle 2'),
(31211, 7078, 8, 'Varices'),
(31212, 7079, 8, 'Etat vasculaire'),
(31213, 7080, 8, 'Lésion vasculaire'),
(31214, 7081, 8, 'Chirurgie Vasculaire'),
(31215, 7083, 8, 'Vendeur'),
(31216, 7084, 8, 'Version'),
(31217, 7085, 8, 'Vertige'),
(31218, 7086, 8, 'Administration des vétérans'),
(31219, 7087, 8, 'Régime des Vétérans'),
(31220, 7089, 8, 'Vietnamien'),
(31221, 7090, 8, 'vue'),
(31222, 7091, 8, 'Vue'),
(31223, 7092, 8, 'Afficher les Allergies'),
(31224, 7097, 8, 'Afficher le rapport globale du patient'),
(31225, 7098, 8, 'Afficher les tables CSV'),
(31226, 7100, 8, 'Afficher le document'),
(31227, 7101, 8, 'Afficher la visite'),
(31228, 7103, 8, 'Afficher les événements dans une fenêtre popup?'),
(31229, 7107, 8, 'Afficher les log'),
(31230, 7108, 8, 'Afficher la Page 1'),
(31231, 7109, 8, 'Afficher la Page 2'),
(31232, 7110, 8, 'Afficher les rappels futur et passé'),
(31233, 7111, 8, 'Afficher le Patient'),
(31234, 7116, 8, 'Afficher les visites liées'),
(31235, 7117, 8, 'Afficher le rapport'),
(31236, 7118, 8, 'Afficher le fichier README'),
(31237, 7121, 8, 'Afficher/Editer les Allergies'),
(31238, 7122, 8, 'Afficher/Editer problème'),
(31239, 7123, 8, 'Afficher/Imprimer'),
(31240, 7124, 8, 'Vue:'),
(31241, 7125, 8, 'VISA'),
(31242, 7126, 8, 'Autre carte bleu'),
(31243, 7127, 8, 'Dommages/Traumatisme/Chirurgie Viscérale'),
(31244, 7133, 8, 'Catégorie la Visite:'),
(31245, 7134, 8, 'Date Visite'),
(31246, 7135, 8, 'Date de visite'),
(31247, 7137, 8, 'Formulaires de Visite'),
(31248, 7138, 8, 'Historique des Visites'),
(31249, 7140, 8, 'Visites'),
(31250, 7141, 8, 'Visites depuis'),
(31251, 7142, 8, 'Signes vitaux'),
(31252, 7143, 8, 'Vitaux'),
(31253, 7144, 8, 'Signes vitaux (métrique)'),
(31254, 7145, 8, 'Options du formulaire des Signes vitaux'),
(31255, 7146, 8, 'Voix'),
(31256, 7147, 8, 'Voix transmise'),
(31257, 7149, 8, 'Vomissements'),
(31258, 7152, 8, 'Tour de taille'),
(31259, 7153, 8, 'Tour de taille'),
(31260, 7154, 8, 'En attente'),
(31261, 7158, 8, 'Entrepôt'),
(31262, 7159, 8, 'Entrepôt maximal, 0 n''est pas applicable'),
(31263, 7160, 8, 'Entrepôt minimal, 0 n''est pas applicable'),
(31264, 7161, 8, 'Entrepôts'),
(31265, 7162, 8, 'Chaud'),
(31266, 7163, 8, 'Attention'),
(31267, 7164, 8, 'ATTENTION'),
(31268, 7166, 8, 'Attention, Numéro de Chèque existe déjà dans la base de données'),
(31269, 7167, 8, 'Attention, le patient a des codes ambigues dans la liste des problemes'),
(31270, 7168, 8, 'Attention: Une visite est déjà créé pour ce patient aujourd''hui!'),
(31271, 7170, 8, 'Attention: l''ID du Patient n''est pas unique!'),
(31272, 7171, 8, 'AVERISSEMENT: Cette action va remplacer les données de la configuration par ceux du fichier téléchargé!'),
(31273, 7173, 8, 'Avertissements'),
(31274, 7175, 8, 'déjà transféré'),
(31275, 7176, 8, 'n''a pas été trouvé'),
(31276, 7177, 8, 'Nous apprécions le paiement rapide des soldes exigibles'),
(31277, 7178, 8, 'nous avons vu votre patient, référencé ci-dessus, pour l''évaluation et le traitement dans notre clinique de psychiatrie ambulatoire. Je vous remercie de cette saisine.'),
(31278, 7179, 8, 'Faiblesses'),
(31279, 7181, 8, 'Recherche Web'),
(31280, 7182, 8, 'Site Web'),
(31281, 7183, 8, 'Lien du site web pour le portail patient sur le site'),
(31282, 7184, 8, 'mer.'),
(31283, 7185, 8, 'Mercredi'),
(31284, 7186, 8, 'Semaine'),
(31285, 7187, 8, 'semaine'),
(31286, 7188, 8, 'Vue Hebdomadaire'),
(31287, 7189, 8, 'Semaine(s)'),
(31288, 7190, 8, 'Expositions Hebdomadaire'),
(31289, 7191, 8, 'semaines'),
(31290, 7192, 8, 'Semaines'),
(31291, 7193, 8, 'Poids'),
(31292, 7194, 8, 'Évaluation du poids et de conseils aux enfants et les adolescents'),
(31293, 7195, 8, 'Évaluation du poids et de conseils aux enfants et les adolescents (CQM)'),
(31294, 7196, 8, 'Changement de Poids'),
(31295, 7197, 8, 'Perte de Poids'),
(31296, 7198, 8, 'Clinique de perte de poids'),
(31297, 7199, 8, 'Bienvenue'),
(31298, 7202, 8, 'Que faut-il comptés?'),
(31299, 7203, 8, 'Sifflements:'),
(31300, 7204, 8, 'Sifflement'),
(31301, 7205, 8, 'Sifflement:'),
(31302, 7208, 8, 'Où se trouvent les documents ou papier numérisés?'),
(31303, 7209, 8, 'Si assuré'),
(31304, 7211, 8, 'Coup de lapin'),
(31305, 7212, 8, 'Blanc'),
(31306, 7213, 8, 'Qui'),
(31307, 7214, 8, 'Qui a répondu?'),
(31308, 7215, 8, 'Veuf(ve)'),
(31309, 7216, 8, 'Largeur'),
(31310, 7217, 8, 'Largeur en pixels du cadre gauche de navigation.'),
(31311, 7221, 8, 'Avec la sélection:'),
(31312, 7222, 8, 'avec l''ancien nom'),
(31313, 7224, 8, 'Avec qui pouvons-nous laisser un message?'),
(31314, 7225, 8, 'Retenu'),
(31315, 7226, 8, 'en quelques heures'),
(31316, 7227, 8, 'en quelques heures:'),
(31317, 7228, 8, 'en quelques minutes'),
(31318, 7229, 8, 'en quelques minutes:'),
(31319, 7230, 8, 'Sans batiment'),
(31320, 7231, 8, 'Sans fournisseur'),
(31321, 7232, 8, 'Sans mise à jour'),
(31322, 7233, 8, 'Témoignage'),
(31323, 7234, 8, 'semaine'),
(31324, 7237, 8, 'Femme'),
(31325, 7238, 8, 'Femmes Seulement'),
(31326, 7239, 8, 'Wordpress Portail'),
(31327, 7240, 8, 'Travaux'),
(31328, 7241, 8, 'NOTE DE TRAVAIL'),
(31329, 7242, 8, 'Téléphone Professionnel'),
(31330, 7243, 8, 'Numéro de Téléphone Professionnel'),
(31331, 7244, 8, 'Les travaux liés?'),
(31332, 7245, 8, 'Travail/ Education/ Loisirs'),
(31333, 7246, 8, 'Travail/ Note Scolaire'),
(31334, 7247, 8, 'jour ouvrable'),
(31335, 7248, 8, 'Idemnisation du personnel'),
(31336, 7249, 8, 'Régime d''indemnisation du personnel de santé'),
(31337, 7251, 8, 'En cours... Ceci pourrait prendre une minute.'),
(31338, 7252, 8, 'Pire'),
(31339, 7253, 8, 'Souhaitez-vous imputer le montant qui reste sur le Compte Global?'),
(31340, 7254, 8, 'Voulez-vous qu''ils soient marqués comme compensés.'),
(31341, 7255, 8, 'Vous souhaitez allouer?'),
(31342, 7256, 8, 'Voulez-vous Annuler Répartition de ce Patient?'),
(31343, 7257, 8, 'Voulez-vous Supprimer Répartition du paiement?'),
(31344, 7258, 8, 'Voulez-vous Supprimer les Paiements?'),
(31345, 7259, 8, 'Voulez-vous Modifier et Terminer les Paiements?'),
(31346, 7260, 8, 'Voulez-vous Modifier les Paiements?'),
(31347, 7261, 8, 'Voulez-vous Poster et Terminer Les Paiements?'),
(31348, 7262, 8, 'Voulez-vous Poster les Paiements?'),
(31349, 7263, 8, 'Voulez-vous Sauvegarder?'),
(31350, 7264, 8, 'Poignet'),
(31351, 7265, 8, 'Poignet et main'),
(31352, 7266, 8, 'Problèmes de Poignet'),
(31353, 7267, 8, 'écrire'),
(31354, 7268, 8, 'radiation'),
(31355, 7270, 8, 'avec quelques'),
(31356, 7271, 8, 'POIDS'),
(31357, 7273, 8, 'x Annulé'),
(31358, 7274, 8, 'x Annulé'),
(31359, 7275, 8, 'Rayon X'),
(31360, 7276, 8, 'Interprétation Rayon X:'),
(31361, 7277, 8, 'Interprétation Rayon X:');
INSERT INTO `lang_definitions` VALUES
(31362, 7278, 8, 'X12 uniquement: Demande de Remplacement '),
(31363, 7279, 8, 'X12 Partenaire'),
(31364, 7280, 8, 'X12 Partenaires'),
(31365, 7281, 8, 'Texte X12'),
(31366, 7284, 8, 'An'),
(31367, 7285, 8, 'année'),
(31368, 7286, 8, 'année'),
(31369, 7287, 8, 'Vue Annuelle'),
(31370, 7288, 8, 'Année(s)'),
(31371, 7289, 8, 'Années'),
(31372, 7290, 8, 'Années ou mois'),
(31373, 7291, 8, 'Années, mois, et jours'),
(31374, 7292, 8, 'OUI'),
(31375, 7293, 8, 'Oui'),
(31376, 7294, 8, 'oui'),
(31377, 7295, 8, 'OUI!'),
(31378, 7296, 8, 'Oui, supprimer et enregistrer'),
(31379, 7298, 8, 'Oui/Non'),
(31380, 7299, 8, 'Oui:'),
(31381, 7300, 8, 'Yidich'),
(31382, 7303, 8, 'Vous allez définitivement remplacer le modèle existant. Etes-vous sûr de vouloir continuer?'),
(31383, 7304, 8, 'Vous êtes en période de connexion supplémentaire. Changez votre mot de passe avant'),
(31384, 7305, 8, 'Vous n''êtes pas autorisé à supprimer cet événement'),
(31385, 7306, 8, 'Vous n''êtes pas autorisé à modifier l''événement'),
(31386, 7307, 8, 'Vous n''êtes pas autorisé pour cela.'),
(31387, 7308, 8, 'Vous n''êtes pas autorisé à accéder à cette équipe.'),
(31388, 7309, 8, 'Vous n''êtes pas autorisé à ajouter/modifier ces sujets'),
(31389, 7310, 8, 'Vous n''êtes pas autorisé à planifier des rendez.'),
(31390, 7311, 8, 'Vous n''êtes pas autorisé de voir cette visite.'),
(31391, 7312, 8, 'Vous postez contre une ancienne rencontre?'),
(31392, 7313, 8, 'Vous ne pouvez pas accéder à cette fonctionnalité directement.'),
(31393, 7314, 8, 'Vous ne pouvez accéder à cette page directement.'),
(31394, 7315, 8, 'Vous ne pouvez ajouter une valeur vide pour une catégorie!'),
(31395, 7316, 8, 'Vous ne pouvez ajouter une valeur vide pour une sous-catégorie!'),
(31396, 7317, 8, 'Vous ne pouvez ajouter une valeur vide pour un élément!'),
(31397, 7318, 8, 'Vous ne pouvez pas entrer une date future avec une valeur OUI (YES) introduite.'),
(31398, 7319, 8, 'Vous n''avez sélectionné aucune action.'),
(31399, 7320, 8, 'Vous n''avez pas accès pour voir/éditer cette note'),
(31400, 7321, 8, 'Vous avez tenté de modifier un contenu qui est verrouillé. Retirez le verrou si vous voulez faire cela. Pour déverrouiller, supprimer la ligne, ''/*lock ::*/'''),
(31401, 7322, 8, 'Vous avez été déconnecter avec succès.'),
(31402, 7323, 8, 'Vous ne pouvez transférer que les fichiers .txt'),
(31403, 7325, 8, 'Vous pouvez mettre insérer ici la plainte par défaut dans le formulaire Nouvelle Visite du Patient.'),
(31404, 7326, 8, 'Vous devez entrer un mot de passe pour crypter le document'),
(31405, 7327, 8, 'Vous devez entrer votre mot de passe pour changer les mots de passe des utilisateurs. Laissez vide pour garder le mot de passe inchangé.'),
(31406, 7329, 8, 'Vous devez d''abord sélectionner ou ajouter un patient.'),
(31407, 7330, 8, 'Vous devez d''abord sélectionner ou créer une visite.'),
(31408, 7331, 8, 'Vous devez sélectionner une catégorie de visite'),
(31409, 7332, 8, 'Vous devez sélectionner une catégorie de visite.'),
(31410, 7333, 8, 'Vous devez sélectionner des champs pour continuer.'),
(31411, 7335, 8, 'Vous devez sélectionner au moins un contexte'),
(31412, 7336, 8, 'Vous devez sélectionner au moins un Prestataire'),
(31413, 7339, 8, 'Votre date fin est invalide'),
(31414, 7340, 8, 'Votre événement a été supprimé.'),
(31415, 7341, 8, 'Votre événement a été modifié.'),
(31416, 7342, 8, 'Votre événement a été soumis.'),
(31417, 7343, 8, 'Votre fichier est trop grand'),
(31418, 7345, 8, 'Votre nom de liste a été modifiée pour répondre aux exigences de nommage.'),
(31419, 7346, 8, 'Votre message a été soumis pour une livraison à'),
(31420, 7347, 8, 'Votre nom pour cette catégorie, procédure ou résultat'),
(31421, 7348, 8, 'Votre mot de passe'),
(31422, 7349, 8, 'Votre mot de passe a expiré. Veuillez changer votre mot de passe.'),
(31423, 7350, 8, 'Votre mot de passe expire le'),
(31424, 7351, 8, 'Votre mot de passe expire aujourd''hui. Veuillez changer votre mot de passe.'),
(31425, 7353, 8, 'Votre configuration PostCalendar est réinitialisé par les paramètres par défaut.'),
(31426, 7354, 8, 'Votre configuration PostCalendar est actualisé.'),
(31427, 7355, 8, 'Votre fréquence de répétition doit être un entier.'),
(31428, 7356, 8, 'Votre fréquence de répétition doit être au moins 1.'),
(31429, 7357, 8, 'Votre date début est supérieure à la date fin'),
(31430, 7358, 8, 'Votre date début est invalide'),
(31431, 7359, 8, 'Votre soumission a échoué.'),
(31432, 7360, 8, 'aaaa-mm-jj'),
(31433, 7361, 8, 'AAAA-MM-JJ'),
(31434, 7362, 8, 'aaaa-mm-jj date associé à ce document'),
(31435, 7363, 8, 'aaaa-mm-jj date de destruction'),
(31436, 7364, 8, 'aaaa-mm-jj date de naissance'),
(31437, 7365, 8, 'aaaa-mm-jj Date de Naissance'),
(31438, 7366, 8, 'aaaa-mm-jj date d''expiration'),
(31439, 7367, 8, 'aaaa-mm-jj Date du début ou de l''hospitalisation'),
(31440, 7368, 8, 'aaaa-mm-jj date du début, chirurgie ou début de médication'),
(31441, 7369, 8, 'aaaa-mm-jj date d''achat ou transfert'),
(31442, 7370, 8, 'aaaa-mm-jj date de récupération et fin de médication'),
(31443, 7371, 8, 'aaaa-mm-jj Date de retour au jeu'),
(31444, 7372, 8, 'aaaa-mm-jj Date de service'),
(31445, 7373, 8, 'aaaa-mm-jj date de cette lettre'),
(31446, 7374, 8, 'aaaa-mm-jj date de retour au jeu'),
(31447, 7375, 8, 'aaaa-mm-jj date du document'),
(31448, 7376, 8, 'aaaa-mm-jj date d''évènement ou de début'),
(31449, 7381, 8, 'aaaa-mm-jj hh:mm:ss'),
(31450, 7383, 8, 'aaaa-mm-jj dernière date de l''événement'),
(31451, 7387, 8, 'Zéro'),
(31452, 7389, 8, 'Code Postal'),
(31453, 7390, 8, 'Code Postal'),
(31454, 7391, 8, 'Code Postal/Pays:'),
(31455, 7392, 8, 'Zoulou'),
(31456, 7393, 8, ' mais étais '),
(31457, 7394, 8, ' ne peut être accédé'),
(31458, 7395, 8, 'Voulez-vous vraiment supprimer'),
(31459, 7396, 8, 'Médicament'),
(31460, 7397, 8, 'email non envoyé'),
(31461, 7398, 8, 'de'),
(31462, 7399, 8, 'a été crée '),
(31463, 7400, 8, 'a été ré-ouvert'),
(31464, 7401, 8, 'Histoire'),
(31465, 7402, 8, 'n''est pas un nombre'),
(31466, 7403, 8, 'est prêt à une ré-facturation'),
(31467, 7405, 8, 'Lot'),
(31468, 7406, 8, 'N° Référence d''Origine Assurance Maladie '),
(31469, 7407, 8, 'min'),
(31470, 7408, 8, 'introuvable!'),
(31471, 7409, 8, 'Particularités dans de nombreux navigateurs peut signifier que la sortie ci-dessous entre votre écran par saccades brusques et qu''il y a de longues pauses de plusieurs secondes, où il semble que les choses peuvent avoir écrasé. Ce n''est pas le cas, vous finirez par voir la sortie sortant ligne par ligne. Il y a peut-être des numéros séquentiels apparaissant ci-dessous, ce n''est pour indiquer que même si rien d''autre peut-être il y a une activité affichant passe. Ces numéros seront entrecoupés avec le contenu de la facturation et c''est normal.'),
(31472, 7410, 8, 'ordonnance a atteint sa limite de'),
(31473, 7411, 8, 'jusqu''à'),
(31474, 7412, 8, 'mise à jour échoué, pas dans la base de données?'),
(31475, 7413, 8, 'a été marqué comme facturé uniquement.'),
(31476, 7414, 8, 'a été mis en file d''attente avec succès.'),
(31477, 7415, 8, '! Laissé w/o visite'),
(31478, 7416, 8, '" pour le code'),
(31479, 7417, 8, '" est activé dans les règles du Calendrier!'),
(31480, 7419, 8, 'nb de comprimés:'),
(31481, 7420, 8, '$'),
(31482, 7421, 8, '$ Codage fait'),
(31483, 7422, 8, '$label (aaaa-mm-jj): '),
(31484, 7423, 8, '%'),
(31485, 7424, 8, '% Annulé < 24h'),
(31486, 7425, 8, '% Annulé < 24h '),
(31487, 7426, 8, 'devrait exister mais au contraire.'),
(31488, 7427, 8, '(% correspond à toute chaîne, _ à tout caractères)'),
(31489, 7428, 8, '([ctrl] + clic pour sélectionner des destinataires multiple)'),
(31490, 7429, 8, '(Arrière)'),
(31491, 7430, 8, '(Cliquez pour modifier)'),
(31492, 7431, 8, '(Livraison Email est immédiat, tandis que le VOIP automatisés est envoyé au fournisseur de service pour un traitement ultérieur.)'),
(31493, 7432, 8, '(Plus)'),
(31494, 7433, 8, '(Nouveau Patient)'),
(31495, 7434, 8, '(Notes et Autorisations)'),
(31496, 7435, 8, '(Notes sur le Patient)'),
(31497, 7436, 8, '(Selectionner un parmis cela, ou tapé votre propre titre)'),
(31498, 7437, 8, '(Shift-)Click ou glissé pour changer la valeur'),
(31499, 7438, 8, '* Rappel fait'),
(31500, 7439, 8, '** S''il vous plait transférez les chirurgies vers les problèmes!'),
(31501, 7440, 8, '*Obligatoire'),
(31502, 7441, 8, '+ Diagramme retiré'),
(31503, 7442, 8, '- Aucun'),
(31504, 7443, 8, '-- Tous --'),
(31505, 7444, 8, '--Sélectionné un rôle--'),
(31506, 7445, 8, '.'),
(31507, 7446, 8, '0'),
(31508, 7447, 8, '0-10'),
(31509, 7448, 8, '0-24'),
(31510, 7451, 8, '1'),
(31511, 7452, 8, '1 = Amérique du Nord. Voir http://www.wtng.info/ pour la liste des codes des autres pays.'),
(31512, 7453, 8, '1 jour à partir de maintenant'),
(31513, 7454, 8, '1 mois à partir de maintenant'),
(31514, 7455, 8, '1 semaine à partir de maintenant'),
(31515, 7456, 8, '1 an à partir de maintenant'),
(31516, 7457, 8, '1. Repos 2. Glace pour deux jours 3. Compression, laissez le pansement en place à moins que le pied ne développe un engourdissement ou a une couleur pâle 4. Surélever le pied et la jambe'),
(31517, 7459, 8, '12 H'),
(31518, 7460, 8, '15-19'),
(31519, 7462, 8, '2'),
(31520, 7463, 8, '2 jours à partir de maintenant'),
(31521, 7464, 8, '2 mois à partir de maintenant'),
(31522, 7465, 8, '2 semaines à partir de maintenant'),
(31523, 7466, 8, '2 mois à partir de maintenant'),
(31524, 7467, 8, '2-20 années'),
(31525, 7468, 8, '20-24'),
(31526, 7477, 8, '2111-13'),
(31527, 7478, 8, '24 H'),
(31528, 7479, 8, '25+'),
(31529, 7480, 8, '25-29'),
(31530, 7481, 8, '2ème'),
(31531, 7482, 8, '3 jours à partir de maintenant'),
(31532, 7483, 8, '3 mois'),
(31533, 7484, 8, '3 mois à partir de maintenant'),
(31534, 7485, 8, '3 fois par jour'),
(31535, 7486, 8, '3 semaines à partir de maintenant'),
(31536, 7487, 8, '30-34'),
(31537, 7488, 8, '35-39'),
(31538, 7489, 8, '3ème'),
(31539, 7490, 8, '4 jours à partir de maintenant'),
(31540, 7491, 8, '4 mois'),
(31541, 7492, 8, '4 mois à partir de maintenant'),
(31542, 7493, 8, '4 fois par jour'),
(31543, 7494, 8, '4 semaines à partir de maintenant'),
(31544, 7495, 8, '40-44'),
(31545, 7496, 8, '45+'),
(31546, 7498, 8, '466.0, Bronchite, Aiguë NOS'),
(31547, 7499, 8, '486.0, Pneumonie, Aiguë'),
(31548, 7501, 8, '491.8, Bronchite, Chronique'),
(31549, 7502, 8, '493.92, Asthme, Exacerbés Aiguë.'),
(31550, 7504, 8, '4ème'),
(31551, 7505, 8, '5 jours à partir de maintenant'),
(31552, 7506, 8, '5 mois à partir de maintenant'),
(31553, 7507, 8, '5 semaines à partir de maintenant'),
(31554, 7508, 8, '519.7, Broncho-spasme'),
(31555, 7509, 8, '5ème'),
(31556, 7510, 8, '6 jours à partir de maintenant'),
(31557, 7511, 8, '6 mois'),
(31558, 7512, 8, '6 mois à partir de maintenant'),
(31559, 7513, 8, '6 semaines à partir de maintenant'),
(31560, 7514, 8, '6ème'),
(31561, 7515, 8, '7 mois à partir de maintenant'),
(31562, 7516, 8, '8 mois à partir de maintenant'),
(31563, 7517, 8, '824.0 Fracture, malléole interne, fermée'),
(31564, 7518, 8, '824.2 Fracture, malléole latérale, fermée'),
(31565, 7519, 8, '824.6 Fracture, tri-malléolaires, fermé'),
(31566, 7520, 8, '825,32 Fracture, de la Naviculaire (cheville)'),
(31567, 7521, 8, '825,35 Fracture, Base de cinquième (5ème) Métatarsien'),
(31568, 7522, 8, '845,00 entorse de la cheville NOS'),
(31569, 7523, 8, '845,01 Entorse Médial (deltoïde) Lig.'),
(31570, 7524, 8, '845,02 Entorse, péroné calcanéum'),
(31571, 7525, 8, '9 mois à partir de maintenant'),
(31572, 7526, 8, '99212 Installé - sans complication'),
(31573, 7527, 8, '99213 Installé - faible complication'),
(31574, 7528, 8, '< En salle d''examen'),
(31575, 7529, 8, '> Vérifié'),
(31576, 7530, 8, '?'),
(31577, 7531, 8, '? Pas d''affichage'),
(31578, 7532, 8, '@ Arrivé'),
(31579, 7533, 8, '[Changer de Vue]'),
(31580, 7534, 8, '[Date de Dernière Visite]'),
(31581, 7535, 8, '[Jours Depuis Dernière Visite]'),
(31582, 7536, 8, '[Notice explicative des prestations]'),
(31583, 7537, 8, '[Exporter OFX]'),
(31584, 7538, 8, '[déconseillé]'),
(31585, 7539, 8, '[Nombre De Visites]'),
(31586, 7540, 8, '[Rapports]'),
(31587, 7541, 8, '[Sélectionner Tout]'),
(31588, 7542, 8, '[SQL-Ledger]'),
(31589, 7543, 8, '[Début de Traitement par Lots]'),
(31590, 7544, 8, '[Afficher le Journal]'),
(31591, 7545, 8, '[Afficher Rapport Imprimable]'),
(31592, 7546, 8, '_PC_DUR_HEURES'),
(31593, 7547, 8, '_PC_DUR_MINUTES'),
(31594, 7548, 8, '_PC_LOCALE'),
(31595, 7549, 8, '~ Arrivé en retard'),
(31596, 1, 9, 'Un'),
(31597, 2, 9, 'Un numéro de chèque ou un numéro de réclamation pour identifier le paiement.'),
(31598, 3, 9, 'Un certificat du client pour l''administrateur'),
(31599, 4, 9, 'Un document clinique se trouve en attachement'),
(31600, 5, 9, 'Un document clinique est attaché.'),
(31601, 7, 9, 'Un distributeur est requis'),
(31602, 8, 9, 'Un formulaire de visite GCAC doit être ajouté à cette visite'),
(31603, 9, 9, 'Un numéros de lot est requis'),
(31604, 10, 9, 'Un numéro de lot est exigé !'),
(31605, 11, 9, 'Une lettre en minuscule'),
(31606, 12, 9, 'Un nombre'),
(31607, 14, 9, 'Un patient avec cet identifiant existe déjà.'),
(31608, 15, 9, 'Un patient avec ce nom existe déjà.'),
(31609, 16, 9, 'Un patient avec ce matriculant existe déjà.'),
(31610, 19, 9, 'Une source de référence peut être spécifiée pour chaque visite.'),
(31611, 20, 9, 'Le code relatif à IPPF est exigé!'),
(31612, 21, 9, 'Un caractère spécial'),
(31613, 22, 9, 'Une valeur unique afin d''identifier ce champ, invisible pour l''utilisateur'),
(31614, 23, 9, 'Une visite existe déjà aujourd''hui pour ce patient.  Sélectionner Annuler pour ouvrir la visite existante ou Ok pour créer une nouvelle visite.'),
(31615, 24, 9, 'Avant les repas'),
(31616, 25, 9, 'matin'),
(31617, 26, 9, 'Fluidité d''air au niveau de l''oreille droite'),
(31618, 27, 9, 'AB'),
(31619, 28, 9, 'Abréviation'),
(31620, 29, 9, 'Abcès'),
(31621, 30, 9, 'Abdominal'),
(31622, 31, 9, 'Capable de supporter le poids sur 4 marches:'),
(31623, 32, 9, 'Anormal'),
(31624, 34, 9, 'Anormal'),
(31625, 35, 9, 'Test Sanguin Anormal'),
(31626, 36, 9, 'Croissance anormale des cheveux'),
(31627, 37, 9, 'Mammographie Anormale'),
(31628, 39, 9, 'Avortement'),
(31629, 40, 9, 'Problème médical relatif à l''avortement'),
(31630, 41, 9, 'Méthode d''avortement'),
(31631, 42, 9, 'Catégories relative à l''avortement'),
(31632, 43, 9, 'Avortements'),
(31633, 44, 9, 'A propos du calendrier'),
(31634, 46, 9, 'Absence de diagnostique'),
(31635, 47, 9, 'Accepter l''affectation'),
(31636, 49, 9, 'Accepter le Paiement pour '),
(31637, 50, 9, 'Accepte l''affectation'),
(31638, 51, 9, 'Contrôle d''accès'),
(31639, 52, 9, 'Liste de contrôle d''accès administratif'),
(31640, 53, 9, 'Date d''accès'),
(31641, 56, 9, 'Accédez à votre Portail Patients'),
(31642, 59, 9, 'Nom du Compte'),
(31643, 62, 9, 'Comptabilité'),
(31644, 64, 9, 'Douleurs'),
(31645, 65, 9, 'Acquittement demandé (ISA14)'),
(31646, 67, 9, 'ACL'),
(31647, 68, 9, 'ACL d''Administration'),
(31648, 69, 9, 'ACL d''Administration Non Autorisée'),
(31649, 70, 9, 'ACL mis à jour'),
(31650, 71, 9, 'Acné'),
(31651, 72, 9, 'Acte'),
(31652, 73, 9, 'Date d''Acte'),
(31653, 74, 9, 'Action'),
(31654, 75, 9, 'Actions'),
(31655, 77, 9, 'Activer le Rapport CCR/CCD'),
(31656, 78, 9, 'Effective'),
(31657, 79, 9, 'Alerte Active'),
(31658, 80, 9, 'Règles d''Alerte Actives'),
(31659, 81, 9, 'Alertes Actives/Rappels'),
(31660, 82, 9, 'Rencontre active'),
(31661, 84, 9, 'Listes actives'),
(31662, 85, 9, 'Patient actif'),
(31663, 86, 9, 'Régimes Actives'),
(31664, 87, 9, 'Activité'),
(31665, 88, 9, 'Type d''Activité'),
(31666, 90, 9, 'Intoxication / Sevrage aigü'),
(31667, 91, 9, 'Manifestation aigüe d''une condition chronique'),
(31668, 92, 9, 'Maladie Chronique Aiguë'),
(31669, 93, 9, 'ajouter'),
(31670, 94, 9, 'Ajouter'),
(31671, 95, 9, 'Ajouter'),
(31672, 96, 9, 'Ajouter une Campanie d''assurance'),
(31673, 98, 9, 'Ajouter une Pharmacie'),
(31674, 100, 9, 'Ajouter un événement pour '),
(31675, 101, 9, 'Ajouter une note'),
(31676, 102, 9, 'Ajouter en tant que nouveau'),
(31677, 104, 9, 'Boutons Ajout'),
(31678, 105, 9, 'Boutons Ajouter pour les caractères spéciaux, Textes devant figurer en haut de l''éditeur à inclure dans le texte suite à un Clic'),
(31679, 106, 9, 'Ajouter une Catégorie'),
(31680, 107, 9, 'Ajouter une Constante'),
(31681, 108, 9, 'Ajouter un Contexte'),
(31682, 109, 9, 'Insérer un co-payeur'),
(31683, 110, 9, 'Ajouter un Critère'),
(31684, 111, 9, 'Ajouter un Bouton Personnalisé'),
(31685, 112, 9, 'Ajouter un Diagnostic'),
(31686, 113, 9, 'Ajouter un Médicament'),
(31687, 114, 9, 'Ajouter un rendez-vous'),
(31688, 115, 9, 'Ajouter Notes/rendez-vous'),
(31689, 116, 9, 'Ajouter un équipement médical'),
(31690, 117, 9, 'Ajouter un domaine'),
(31691, 118, 9, 'Ajouter les lignes suivantes au fichier de configuration du serveur Apache'),
(31692, 119, 9, 'Ajouter un Groupe'),
(31693, 120, 9, 'Ajouter le code ICD'),
(31694, 121, 9, 'Ajouter une vaccination'),
(31695, 122, 9, 'L''ajout n''est pas permis!'),
(31696, 123, 9, 'Ajouter un problème médical'),
(31697, 124, 9, 'Ajouter un élément à suivre'),
(31698, 125, 9, 'Ajouter une langue'),
(31699, 126, 9, 'Ajouter du nouveau'),
(31700, 127, 9, 'Ajouter du nouveau'),
(31701, 128, 9, 'Ajouter une nouvelle catégorie: '),
(31702, 129, 9, 'Ajouter les nouveaux certificats au fichier de configuration du serveur Apache'),
(31703, 130, 9, 'Ajouter un nouveau composant'),
(31704, 131, 9, 'Ajouter des nouveaux composants'),
(31705, 132, 9, 'Ajouter un Nouveau Groupe'),
(31706, 133, 9, 'Ajouter un nouveau problème clinique'),
(31707, 134, 9, 'Ajouter un nouveau lot et transaction'),
(31708, 135, 9, 'Ajouter une nouvelle note'),
(31709, 136, 9, 'Ajouter une nouvelle note'),
(31710, 137, 9, 'Ajouter un nouveau Partenaire'),
(31711, 138, 9, 'Ajouter un nouveau patient'),
(31712, 140, 9, 'Ajouter une note'),
(31713, 141, 9, 'Ajouter une fiche Patient'),
(31714, 142, 9, 'Ajouter une ordonnance'),
(31715, 143, 9, 'Ajouter une procédure'),
(31716, 144, 9, 'Ajouter le numéro du prestataire'),
(31717, 145, 9, 'Ajouter une cure de désintoxication'),
(31718, 146, 9, 'Ajouter une règle'),
(31719, 147, 9, 'Ajouter à'),
(31720, 148, 9, 'Ajouter à la Listes des Médicaments'),
(31721, 149, 9, 'Ajouter le Niveau Supérieur'),
(31722, 150, 9, 'Ajouter une Transaction'),
(31723, 151, 9, 'Ajouter un Utilisateur'),
(31724, 152, 9, 'Ajouter un Utilisateur au Groupe'),
(31725, 153, 9, 'Ajouter/Editer eRx'),
(31726, 154, 9, 'Ajouter/Editer la Transaction du Patient'),
(31727, 155, 9, 'Ajouté'),
(31728, 156, 9, 'L''ajout de données démographiques n''est pas autorisé'),
(31729, 157, 9, 'Échec d''ajout d''un élément à suivre'),
(31730, 158, 9, 'Syndrome d''Addison'),
(31731, 159, 9, 'Syndrome d''Addison'),
(31732, 160, 9, 'Attributs supplémentaires'),
(31733, 161, 9, 'Diagnostique supplémentaire'),
(31734, 162, 9, 'Antécédent supplémentaire'),
(31735, 163, 9, 'Notes d''antécédent(s) supplémentaire(s)'),
(31736, 164, 9, 'Information complémentaire'),
(31737, 165, 9, 'Laboratoires supplémentaires'),
(31738, 166, 9, 'Notes supplémentaires'),
(31739, 167, 9, 'Notes complémentaires / Recommendation pour ce résultat'),
(31740, 168, 9, 'Notes supplémentaires:'),
(31741, 169, 9, 'Notes supplémentaires: '),
(31742, 170, 9, 'Radiographies supplémentaires:'),
(31743, 171, 9, 'De plus, le composant US Snomed Extension correspondant peut être importé séparément après avoir installé la version internationale de la mise à jour Snomed (version anglaise)'),
(31744, 172, 9, 'Ajouter seulement'),
(31745, 173, 9, 'Carnet d''adresses'),
(31746, 174, 9, 'Carnet d''adresses'),
(31747, 175, 9, 'Adresse'),
(31748, 178, 9, 'Carnet d''adresses'),
(31749, 179, 9, 'Entrée au carnet d''adresses pour la compagnie réalisant cette procédure'),
(31750, 180, 9, 'Entrée au carnet d''adresses pour le distributeur'),
(31751, 181, 9, 'Entrée au carnet d''adresses pour le vendeur'),
(31752, 182, 9, 'Type de carnet d''adresse'),
(31753, 183, 9, 'Étiquette d''adresse'),
(31754, 187, 9, 'Adresse 1'),
(31755, 188, 9, 'Adresse 2'),
(31756, 189, 9, 'Destinataire'),
(31757, 190, 9, 'Ajuster'),
(31758, 191, 9, 'Montant Ajusté'),
(31759, 192, 9, 'Ajuster'),
(31760, 193, 9, 'Ajustement'),
(31761, 194, 9, 'Montant de l''ajustement'),
(31762, 195, 9, 'Raisons de l''ajustement'),
(31763, 196, 9, 'Valeur de l''ajustement pour code '),
(31764, 197, 9, 'Ajustements'),
(31765, 198, 9, 'Ajustement administratif'),
(31766, 199, 9, 'Administrateur'),
(31767, 200, 9, 'Adresse mail Administrateur'),
(31768, 201, 9, 'Administrer via'),
(31769, 202, 9, 'Administré'),
(31770, 203, 9, 'Administré par'),
(31771, 204, 9, 'Administré le (date)'),
(31772, 205, 9, 'Administré à (site)'),
(31773, 206, 9, 'Administration'),
(31774, 207, 9, 'Site d''administration'),
(31775, 208, 9, 'Administrateurs'),
(31776, 209, 9, 'Les administrateurs ont tous les droits'),
(31777, 210, 9, 'Date d''admission'),
(31778, 212, 9, 'Suivi et Dépistage du poids pour Adulte'),
(31779, 213, 9, 'Suivi et Dépistage du poids pour Adulte (CQM)'),
(31780, 214, 9, 'Directive préalable'),
(31781, 215, 9, 'Directives préalables'),
(31782, 216, 9, 'Avertissement de directives anticipées'),
(31783, 218, 9, 'Avancé'),
(31784, 219, 9, 'Conseil'),
(31785, 220, 9, 'de loin'),
(31786, 221, 9, 'Affecte Normale'),
(31787, 222, 9, 'Afrikaans'),
(31788, 223, 9, 'Appels hors des heures de travail'),
(31789, 224, 9, 'Suite à la migration des méchanismes antérieurs selon lesquels les mots de passe sont stockés dans la table des utilisateurs sans sel est complet, ce témoin devrait être configuré à Faux de sort que seule l''authentification par le nouveau mécanisme est possible.'),
(31790, 225, 9, 'Après avoir réalisé les configurations mentionnées, importer le certificat du client administré dans le navigateur puis redémarrer le serveur Apache (mot de passe vide)'),
(31791, 226, 9, 'Après avoir enregistré le PDF, cliquer [view log] pour verifier d''éventuelles erreurs'),
(31792, 227, 9, 'Après avoir enregistré les fichiers TEXT, cliquer [view log] pour verifier d''éventuelles erreurs'),
(31793, 228, 9, 'Après avoir enregistré votre fichier séquentiel (batch), cliquer sur [View Log], pour vérifier d''éventuelles erreurs.'),
(31794, 230, 9, 'Après avoir correctement entrer les informations, cliquer sur le bouton d''enregistrement.'),
(31795, 231, 9, 'Après avoir téléchargé, sélectionner "Importer"'),
(31796, 232, 9, 'Planification du suivi post-soins'),
(31797, 233, 9, 'Encore'),
(31798, 234, 9, 'Age'),
(31799, 235, 9, 'Age par'),
(31800, 236, 9, 'Catégorie d''âge'),
(31801, 237, 9, 'Données concernant l''âge sont erronées'),
(31802, 238, 9, 'Format de l''affichage de l''âge'),
(31803, 239, 9, 'Le format pour "âge à partir de" est invalide'),
(31804, 240, 9, 'Le format pour "âge jusqu''à" est invalide'),
(31805, 241, 9, 'Age à partir de'),
(31806, 242, 9, 'Âge en années pour le changement de format d''affichage'),
(31807, 243, 9, 'Age maximum'),
(31808, 244, 9, 'Age minimum'),
(31809, 245, 9, 'Tranche d''âge'),
(31810, 247, 9, 'Aciennes Colonnes:'),
(31811, 249, 9, 'Albanais(e)'),
(31812, 250, 9, 'Alcool'),
(31813, 251, 9, 'Consommation d''Alcool'),
(31814, 252, 9, 'Usage de produits alcoolisés'),
(31815, 253, 9, 'Nombre d''alerte'),
(31816, 255, 9, 'Alerts'),
(31817, 259, 9, 'Tout/ Toutes'),
(31818, 260, 9, 'Tout/ Toutes'),
(31819, 261, 9, 'Tous (Assemblage Format A)'),
(31820, 262, 9, 'Tous (Assemblage Format B)'),
(31821, 263, 9, 'Tous (Cumulative)'),
(31822, 266, 9, 'Toutes catégories'),
(31823, 268, 9, 'Tous codes'),
(31824, 269, 9, 'Tout au long de la journée'),
(31825, 270, 9, 'Evénement durant toute la journée'),
(31826, 271, 9, 'Tout les champs démographiques, avec recherche et vérification des doublons'),
(31827, 272, 9, 'Tous les équipements/ installations'),
(31828, 273, 9, 'Toutes les Blessures/Problèmes'),
(31829, 274, 9, 'Toutes langues autorisées'),
(31830, 276, 9, 'Tout ou une partie du prénom'),
(31831, 277, 9, 'Tout ou une partie du nom de famille'),
(31832, 278, 9, 'Tout ou une partie de l''entreprise'),
(31833, 279, 9, 'Tous les patients'),
(31834, 280, 9, 'Tous produits'),
(31835, 281, 9, 'Tous fournisseurs'),
(31836, 282, 9, 'Tous examinés et négatifs:'),
(31837, 283, 9, 'Tous sujets'),
(31838, 284, 9, 'Tous les utilisateurs'),
(31839, 285, 9, 'Allergique'),
(31840, 286, 9, 'Allergies'),
(31841, 287, 9, 'Allergies:'),
(31842, 288, 9, 'Allergie'),
(31843, 289, 9, 'Importation des allergies complété avec succès'),
(31844, 290, 9, 'Liste des problèmes reliés aux allergies'),
(31845, 291, 9, 'Réaction allergique'),
(31846, 294, 9, 'Affecter'),
(31847, 295, 9, 'Autoriser'),
(31848, 296, 9, 'Autoriser toutes les langues disponibles en option dans le menu lors de l''ouverture de session'),
(31849, 297, 9, 'Autoriser la creation de demandes d''indémnisation contenant les diagnostiques mais non les procedures ou les frais. La majorité des cliniques y sont réticentes.'),
(31850, 298, 9, 'Autoriser le langage de débogage'),
(31851, 299, 9, 'Autoriser les e-mails'),
(31852, 300, 9, 'Autoriser les messages e-mails ?'),
(31853, 301, 9, 'Autoriser les e-mails ?'),
(31854, 302, 9, 'Autoriser les Réclamations de Rencontre'),
(31855, 303, 9, 'Autoriser l''échange d''information médicale'),
(31856, 304, 9, 'Autoriser le partage d''information d''immunisation'),
(31857, 305, 9, 'Autorise l''utilisation du registre d''immunisation'),
(31858, 306, 9, 'Autoriser les courriers'),
(31859, 308, 9, 'Autoriser le Portail Patient'),
(31860, 309, 9, 'Autoriser les SMS'),
(31861, 310, 9, 'Autoriser les SMS (textos) ?'),
(31862, 311, 9, 'Autoriser l''activation instantanée des événements proposés ?'),
(31863, 312, 9, 'Autoriser les messages téléphoniques ?'),
(31864, 313, 9, 'Autoriser les utilisateurs de publier des Evénements Globaux'),
(31865, 314, 9, 'Autoriser les utilisateurs à publier des calendriers personnels'),
(31866, 315, 9, 'Autoriser les messages vocaux'),
(31867, 316, 9, 'Autorisé'),
(31868, 317, 9, 'Langues autorisées'),
(31869, 318, 9, 'Autorisé (c)'),
(31870, 319, 9, 'Permet le E-Sign pour toute la consultation'),
(31871, 320, 9, 'Permet le E-Sign pour les formulaires individuels'),
(31872, 321, 9, 'Permet le courrier'),
(31873, 322, 9, 'Permet les messages vocaux'),
(31874, 323, 9, 'existe déjà'),
(31875, 324, 9, 'existe déjà.'),
(31876, 325, 9, 'Déjà utilisé, veuillez choisir un autre identifiant'),
(31877, 326, 9, 'Déjà utilisé, veuillez choisir un autre titre'),
(31878, 327, 9, 'Adresse secondaire'),
(31879, 328, 9, 'modifier'),
(31880, 329, 9, 'Alternativement, vous pouvez utiliser la page de recherche pour transférer une remise électronique (X12 835) du fichier que vous avez obtenu à partir de votre payeur ou chambre de compensation. Vous pouvez le faire en cliquant sur le bouton Parcourir et sélectionner le fichier à télécharger, puis en cliquant sur Rechercher pour effectuer le téléchargement et l''affichage des factures correspondantes. Dans ce cas, les autres paramètres mentionnés ci-dessus ne s''appliquent pas et sera ignoré. Téléchargement enregistre le fichier mais n''a pas encore traiter son contenu - ce qui est fait séparément comme décrit ci-dessous.'),
(31881, 330, 9, 'AM'),
(31882, 331, 9, 'Programme Matinal'),
(31883, 333, 9, 'Suivi AMC'),
(31884, 338, 9, 'Modifier la note existante'),
(31885, 343, 9, 'Indien d''Amérique'),
(31886, 344, 9, 'Indiens d''Amérique ou autochtones d''Alaska'),
(31887, 345, 9, 'AMEX'),
(31888, 346, 9, 'Amharique'),
(31889, 347, 9, 'Montant'),
(31890, 349, 9, 'Montant des frais'),
(31891, 350, 9, 'Montant du solde précédent'),
(31892, 351, 9, 'Montant pour cette visite'),
(31893, 352, 9, 'Montant payé'),
(31894, 353, 9, 'Montant:'),
(31895, 354, 9, 'Montant facturé'),
(31896, 355, 9, 'Une date de fin ultérieure à la date de début est requise pour des événements répétés!'),
(31897, 356, 9, 'Une erreur s''est produite à la signature du formulaire'),
(31898, 357, 9, 'Une erreur est survenue durant le vidage de l''arborescence du répertoire web LibreEHR'),
(31899, 358, 9, 'Une erreur est survenue durant le vidage de l''arborescence du répertoire web phpGACL'),
(31900, 359, 9, 'Une erreur est survenue durant le vidage de l''arborescence du répertoire web SQL-Ledger'),
(31901, 360, 9, 'Une édition incomplète de GCAC a été crée et reliée. Elle devra être complétée plus tard.'),
(31902, 362, 9, 'Une erreur inattendue s''est produite.'),
(31903, 363, 9, 'Une lettre majuscule'),
(31904, 365, 9, 'Et'),
(31905, 366, 9, 'ET'),
(31906, 367, 9, 'et'),
(31907, 368, 9, 'et '),
(31908, 369, 9, 'et tous les données secondaires? Cette action sera enregistrée'),
(31909, 370, 9, 'et modificateur'),
(31910, 371, 9, 'et traité.'),
(31911, 372, 9, 'et redémarrer le serveur Apache.'),
(31912, 373, 9, 'et la raison est'),
(31913, 374, 9, 'Anémie'),
(31914, 375, 9, 'Cheville'),
(31915, 376, 9, 'Cheville + Talon'),
(31916, 377, 9, 'Formulaire d''évalution de cheville'),
(31917, 378, 9, 'Problèmes de cheville'),
(31918, 379, 9, 'Spondylarthrite Ankylosante'),
(31919, 380, 9, 'Spondylarthrite Ankylosante'),
(31920, 381, 9, 'Anorexie'),
(31921, 382, 9, 'Une autre manipulation possible dans la fenêtre affichée est la demande d''une seconde facturation. Si vous cocher cette case avant d''enregistrer, alors la demande originale sera ré ouverte, ajoutée à la page de facturation et exécutée lors de la prochaine échéance.'),
(31922, 383, 9, 'avant'),
(31923, 384, 9, 'Anus normal, sans tendreté/masse rectale'),
(31924, 385, 9, 'Anxiété'),
(31925, 386, 9, 'N''importe quel(le) / Tout(e)'),
(31926, 387, 9, 'Toute catégorie'),
(31927, 388, 9, 'Toute partie du code désiré ou sa description'),
(31928, 389, 9, 'Toute partie de le spécialité désirée'),
(31929, 390, 9, 'Toute partie de l''identification ou du nom du médicament'),
(31930, 391, 9, 'Toute partie de l’identification ou du nom d''immunisation'),
(31931, 392, 9, 'Toute partie du nom du patient, ou "nom, prénom", ou "X-Y"'),
(31932, 393, 9, 'Toute autre information pertinente'),
(31933, 394, 9, 'Clé API pour le relais SMS'),
(31934, 395, 9, 'Apnée'),
(31935, 396, 9, 'Apparence'),
(31936, 397, 9, 'Apparence:'),
(31937, 398, 9, 'Ajouter cette note'),
(31938, 399, 9, 'Ajouter à la note existante'),
(31939, 400, 9, 'Ajouter à cette note'),
(31940, 401, 9, 'Ajouter à Cette Note'),
(31941, 402, 9, 'Appendicectomie'),
(31942, 403, 9, 'appendicectomie'),
(31943, 404, 9, 'Les patients concernés'),
(31944, 405, 9, 'Application'),
(31945, 406, 9, 'Nom utilisateur pour la page d’accès et titre de fenêtre principale'),
(31946, 407, 9, 'Code Application receveur (GS03 - si vide ISA08 sera utilisé)'),
(31947, 408, 9, 'Code Application émettrice (GS02)'),
(31948, 409, 9, 'Titre de l''Application'),
(31949, 410, 9, 'S''applique au formulaire des Fonctions Vitaux et de la Courbe de Croissance'),
(31950, 411, 9, 'S''applique au formulaire des fonctions vitales'),
(31951, 412, 9, 'Appliquer les changements seulement à l’événement actuel, à celui ci ainsi qu''aux futurs événements, ou à tous les événements ?'),
(31952, 413, 9, 'Appliquer à la section désignée'),
(31953, 414, 9, 'appliquer sur la peau'),
(31954, 415, 9, 'Application'),
(31955, 416, 9, 'Application de la rustine au site'),
(31956, 417, 9, 'Rendez-vous'),
(31957, 418, 9, 'Date de rendez-vous'),
(31958, 419, 9, 'Style d''affichage des Rendez-vous'),
(31959, 420, 9, 'Règle de rappel de rendez-vous'),
(31960, 421, 9, 'Statut du rendez-vous'),
(31961, 422, 9, 'Statuts du rendez-vous'),
(31962, 423, 9, 'Rendez-vous dans'),
(31963, 424, 9, 'Couleur d''Evénement/Rendez-vous'),
(31964, 425, 9, 'Des Rendez-vous'),
(31965, 426, 9, 'Rendez-vous (option d''écriture)'),
(31966, 430, 9, 'Rendez-vous et Rencontres'),
(31967, 431, 9, 'Rapport des Rendez-vous'),
(31968, 432, 9, 'Rapport des Rencontres et Rendez-vous'),
(31969, 434, 9, 'Approuver'),
(31970, 435, 9, 'Approuver le patient à partir de Patient/Client->Importer->En attente d''approbation'),
(31971, 436, 9, 'Approuvé'),
(31972, 437, 9, 'Evénements administratifs approuvés'),
(31973, 438, 9, 'Approuvé avec succès'),
(31974, 440, 9, 'RDV-Visite'),
(31975, 441, 9, 'RDVs'),
(31976, 442, 9, 'Avr.'),
(31977, 443, 9, 'Avril'),
(31978, 444, 9, 'Arabe'),
(31979, 447, 9, 'les noms du groupe de contrôle doivent ils être traduits ?'),
(31980, 448, 9, 'Les noms de catégorie de rendez vous doivent ils être traduits ?'),
(31981, 449, 9, 'Les noms de catégorie de documents doivent ils être traduits?'),
(31982, 450, 9, 'Des frais sont ils facturés pour ce type ?'),
(31983, 451, 9, 'Les titres des notes des patients doivent ils être traduits?'),
(31984, 452, 9, 'Les codes sont-ils stockés dans des tables sql externes (0-Non, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(31985, 453, 9, 'Etes vous prêt à compléter une nouvelle version GCAC pour cette consultation ?'),
(31986, 454, 9, 'Êtes vous certain(e) de faire une inscription aujourd''hui?'),
(31987, 455, 9, 'Etes vous sur de vouloir valider ces événements ?'),
(31988, 457, 9, 'Etes vous sur de vouloir complètement effacer ce formulaire ?'),
(31989, 459, 9, 'Etes vous sur de vouloir supprimer cet accès ?'),
(31990, 460, 9, 'Etes vous certain de vouloir effacer cet événement ?'),
(31991, 461, 9, 'Etes vous certain de vouloir effacer cet élément de la base de données ?'),
(31992, 462, 9, 'Etes vous certain de vouloir effacer cette note ?'),
(31993, 464, 9, 'Etes vous certain de vouloir éditer ces événements ?'),
(31994, 465, 9, 'Etes vous certain de vouloir masquer ces événements ?'),
(31995, 467, 9, 'Etes vous certain de vouloir voir ces événements ?'),
(31996, 468, 9, 'Etes vous certain de vouloir effacer l''ensemble du groupe nommé ?'),
(31997, 469, 9, 'Etes vous sur de vouloir effacer l''ensemble de la liste?'),
(31998, 470, 9, 'Etes vous certain de vouloir de vouloir effacer le champs interne ?'),
(31999, 471, 9, 'Etes vous certain de vouloir effacer les champs sélectionnés ?'),
(32000, 472, 9, 'Etes vous certain de vouloir poursuivre ces actions ?'),
(32001, 473, 9, 'Zone non spécifiée'),
(32002, 474, 9, 'Bras'),
(32003, 475, 9, 'Arménien'),
(32004, 477, 9, 'Arythmie'),
(32005, 478, 9, 'Arthrite'),
(32006, 479, 9, 'Arthrite / arthrose'),
(32007, 480, 9, 'Arthrite / arthrose'),
(32008, 481, 9, 'comme'),
(32009, 482, 9, 'A compter de'),
(32010, 484, 9, 'Asiatique'),
(32011, 487, 9, 'Evaluation'),
(32012, 488, 9, 'Affecté à'),
(32013, 489, 9, 'Assistant'),
(32014, 490, 9, 'Asthme'),
(32015, 491, 9, 'à'),
(32016, 492, 9, 'Au moins un paramètre de recherche est requis si vous sélectionnez tout'),
(32017, 493, 9, 'Au naviculaire'),
(32018, 494, 9, 'Au naviculaire:'),
(32019, 495, 9, 'Equipe d''Athlétisme'),
(32020, 497, 9, 'Blessure sportive'),
(32021, 498, 9, 'Certificat CA d’audit ATNA'),
(32022, 499, 9, 'Hôte d''audit ATNA'),
(32023, 500, 9, 'Certificat local d''audit ATNA'),
(32024, 501, 9, 'Port d''audit ATNA'),
(32025, 503, 9, 'Attention'),
(32026, 504, 9, 'Attention'),
(32027, 509, 9, 'Sauvegardes des journaux d''Audit'),
(32028, 510, 9, 'Autres Journalisation d''Audit'),
(32029, 511, 9, 'Commande de journalisation d''Audit'),
(32030, 512, 9, 'Journalisation d''Audit des Enregistrements de Patient'),
(32031, 513, 9, 'Planification de la Journalisation d''Audit'),
(32032, 514, 9, 'Administration de la Sécurité de la Journalisation d''Audit'),
(32033, 515, 9, 'Journalisation d''Audit des requêtes SELECT'),
(32034, 516, 9, 'Août'),
(32035, 517, 9, 'Août'),
(32036, 519, 9, 'Autorisation'),
(32037, 520, 9, 'Autorisation/notes'),
(32038, 523, 9, 'Groupe d''Autorisation'),
(32039, 525, 9, 'Autorisations'),
(32040, 526, 9, 'Autoriser'),
(32041, 527, 9, 'Autoriser – toutes rencontres'),
(32042, 528, 9, 'Autoriser – mes rencontres'),
(32043, 530, 9, 'Autorisé'),
(32044, 531, 9, 'Autorisé Uniquement'),
(32045, 532, 9, 'Envoi automatique'),
(32046, 535, 9, 'Auto-Création Nouvelles Rencontres'),
(32047, 536, 9, 'Auto-généré'),
(32048, 537, 9, 'Calculs des mesures automatisées (AMC)'),
(32049, 542, 9, 'Suivi des Calculs des mesures automatisées (AMC)'),
(32050, 543, 9, 'Mesures Automatisées (AMC)'),
(32051, 544, 9, 'Automatique'),
(32052, 546, 9, 'Créer automatiquement une nouvelle rencontre lorsque l''état du rendez-vous est fixé à "@" (arrivée).'),
(32053, 549, 9, 'Voiture médicalisée'),
(32054, 550, 9, 'auto-enregistré'),
(32055, 551, 9, 'Catégories Disponibles'),
(32056, 552, 9, 'Horaires Disponibles'),
(32057, 557, 9, 'Moyenne Mensuelle'),
(32058, 558, 9, 'Avulsion / avulsion fracture'),
(32059, 559, 9, 'Avulsion du Malléole latérale'),
(32060, 560, 9, 'Avulsion du Malléole médiale '),
(32061, 561, 9, 'Basées sur la Connaissance'),
(32062, 562, 9, 'Auxiliaire'),
(32063, 565, 9, 'deux fois par jour'),
(32064, 566, 9, 'Derrière'),
(32065, 567, 9, 'derrière'),
(32066, 568, 9, 'Retour huit visites'),
(32067, 569, 9, 'Retour onze visites'),
(32068, 570, 9, 'Retour cinq visites'),
(32069, 571, 9, 'Retour quatre visites'),
(32070, 572, 9, 'Retour neuf visites'),
(32071, 573, 9, 'Retour une visite'),
(32072, 574, 9, 'Douleur dorsale'),
(32073, 575, 9, 'Problèmes de dos'),
(32074, 576, 9, 'Reporter sept visites'),
(32075, 577, 9, 'Reporter six visites'),
(32076, 578, 9, 'Chirurgie du dos'),
(32077, 579, 9, 'Retour dix visites'),
(32078, 580, 9, 'Retour trois visites'),
(32079, 581, 9, 'Retour à la page d''administration'),
(32080, 582, 9, 'Retour à la consultation'),
(32081, 583, 9, 'Retour au Patient'),
(32082, 584, 9, 'Retour au patient'),
(32083, 585, 9, 'Retour aux Utilisateurs'),
(32084, 586, 9, 'Retour à la Vue'),
(32085, 587, 9, 'Retour douze visites'),
(32086, 588, 9, 'Retour deux visites'),
(32087, 589, 9, 'Services d''arrière-plan'),
(32088, 590, 9, 'Sauvegarde'),
(32089, 591, 9, 'Un document de sauvegarde a été créé Le téléchargement va être lancé.'),
(32090, 592, 9, 'Liste de sauvegarde'),
(32091, 593, 9, 'Sauvegarde effectuée avec succès'),
(32092, 594, 9, 'Chèque sans provision'),
(32093, 595, 9, 'Créances Douteuses'),
(32094, 596, 9, 'Bahasa Indonésien'),
(32095, 597, 9, 'Bal'),
(32096, 598, 9, 'Balance'),
(32097, 599, 9, 'balance'),
(32098, 600, 9, 'Montant du solde'),
(32099, 601, 9, 'Solde dû'),
(32100, 603, 9, 'Traite'),
(32101, 604, 9, 'Étiquette code-barres'),
(32102, 605, 9, 'Type d''étiquette code-barres'),
(32103, 606, 9, 'Type de code-barres pour l''impression d''étiquettes code-barres à partir des menus locaux dans la fenêtre de navigation gauche.'),
(32104, 607, 9, 'Base du cinquième (5ème) Métatarsien'),
(32105, 608, 9, 'Base du cinquième (5ème) Métatarsien:'),
(32106, 611, 9, 'Réclamation en lot'),
(32107, 612, 9, 'Outil de communication du lot (batch)'),
(32108, 613, 9, 'Entrée de Payement du Lot (batch)'),
(32109, 614, 9, 'Paiements en lot'),
(32110, 615, 9, 'Traitement du lot (batch) lancé; cela peut prendre du temps.'),
(32111, 616, 9, 'Résultats du lot (Batch)'),
(32112, 618, 9, 'Veuillez patienter, certains fichiers peuvent prendre plusieurs minutes à traiter!'),
(32113, 619, 9, 'car cet identifiant n''existe pas.'),
(32114, 620, 9, 'Début'),
(32115, 621, 9, 'Date Début'),
(32116, 623, 9, 'Date début du service aaaa-mm-jj'),
(32117, 624, 9, 'Heure début de journée pour les évènements calendaires.'),
(32118, 626, 9, 'Eructation'),
(32119, 630, 9, 'entre'),
(32120, 631, 9, 'bi-directionnel'),
(32121, 633, 9, 'Bilatéral'),
(32122, 634, 9, 'Bilatéral:'),
(32123, 636, 9, 'Date de facture:'),
(32124, 637, 9, 'Collecter/Facturer'),
(32125, 638, 9, 'Facturé'),
(32126, 640, 9, 'Facturation'),
(32127, 641, 9, 'Facturation (écriture optionnel)'),
(32128, 642, 9, 'Destinataire de facturation'),
(32129, 644, 9, 'Code de facturation pour le Service demandé'),
(32130, 645, 9, 'Codes de facturation'),
(32131, 646, 9, 'Donnée de facturation'),
(32132, 647, 9, 'Service de facturation'),
(32133, 648, 9, 'Fonds de Facturations'),
(32134, 649, 9, 'Information sur la facturation'),
(32135, 650, 9, 'Lieu de facturation'),
(32136, 655, 9, 'Gestionnaire de facturation'),
(32137, 656, 9, 'Note de facturation'),
(32138, 657, 9, 'Note de facturation pour '),
(32139, 658, 9, 'Note de facturation:'),
(32140, 659, 9, 'Résutalt de la file de facturation:'),
(32141, 660, 9, 'Rapport de facturation'),
(32142, 661, 9, 'État de facturation'),
(32143, 662, 9, 'Statut de facturation = non facturé'),
(32144, 663, 9, 'facturation à '),
(32145, 665, 9, 'Biopsie'),
(32146, 666, 9, 'Date de naissance'),
(32147, 669, 9, 'Noir'),
(32148, 670, 9, 'Poumon noir'),
(32149, 671, 9, 'Noir ou Afro-américain'),
(32150, 672, 9, 'Cancer de la vésicule'),
(32151, 673, 9, 'Infections de la vésicule'),
(32152, 674, 9, 'Formulaires blancs'),
(32153, 675, 9, 'Problèmes de saignement'),
(32154, 676, 9, 'Scotome'),
(32155, 677, 9, 'Ballonement'),
(32156, 678, 9, 'Bouché'),
(32157, 679, 9, 'Sang'),
(32158, 680, 9, 'Pression Arterielle'),
(32159, 681, 9, 'Pression arterielle'),
(32160, 682, 9, 'Nez en sang'),
(32161, 683, 9, 'Blue Cross Blue Shield'),
(32162, 684, 9, 'Les lignes bleues dans ce rapport sont à titre informatif. Les lignes noires indiquent les informations déjà existantes. Les lignes vertes montrent les changements qui ont été appliqués avec succès. Les lignes rouges indiquent des erreurs, ou des changements qui n''ont pas été appliquées; elles doivent être traitées manuellement. Revendications qui sont actuellement privés et les inversions de paiement ne sont pas traitées automatiquement et donc apparaîtra en rouge.'),
(32163, 685, 9, 'Vision Brouillée'),
(32164, 686, 9, 'IMC'),
(32165, 687, 9, 'Etat de L''IMC'),
(32166, 689, 9, 'Région du corps'),
(32167, 690, 9, 'Zone du corps'),
(32168, 691, 9, 'Zone du corps , si applicable'),
(32169, 692, 9, 'Sensibilité osseuse:'),
(32170, 693, 9, 'Sensibilité osseuse: Malléole médiane'),
(32171, 694, 9, 'Booléen'),
(32172, 695, 9, 'Bosniaque'),
(32173, 697, 9, 'Les deux oreilles'),
(32174, 698, 9, 'les deux oreilles'),
(32175, 699, 9, 'Partie inférieure (Bas)'),
(32176, 701, 9, 'Case 10 A. Liée à l''Emploi '),
(32177, 702, 9, 'Case 10 B. Accident de Voiture '),
(32178, 703, 9, 'Case 10 C. Autre Accident '),
(32179, 706, 9, 'Case 15. Date de maladie identique ou similaire (aaaa-mm-jj):'),
(32180, 707, 9, 'Case 15. Date de maladie identique ou similaire/Autre Date (aaaa-mm-jj):'),
(32181, 708, 9, 'Case 16. Date début d''incapacité de travail (aaaa-mm-jj) :'),
(32182, 709, 9, 'Case 16. Date fin de l''incapacité de travail (aaaa-mm-jj) :'),
(32183, 710, 9, 'Case 18. Date début d''Hospitalisation (aaaa-mm-jj) : '),
(32184, 711, 9, 'Case 18. Date fin d''Hospitalisation (aaaa-mm-jj) : '),
(32185, 712, 9, 'Case 20. Est-ce laboratoire extérieur utilisé?'),
(32186, 713, 9, 'Case 22. Nouvelle présentation du Code Medicaid (CIM-9) '),
(32187, 714, 9, 'Case 23. N ° d''autorisation préalable '),
(32188, 715, 9, 'Pression Atrérielle'),
(32189, 716, 9, 'PA Disatolique'),
(32190, 717, 9, 'PA Systoloque'),
(32191, 719, 9, 'PA diast'),
(32192, 721, 9, 'PA syst'),
(32193, 722, 9, 'Portugais Brésilien'),
(32194, 723, 9, 'Seins'),
(32195, 724, 9, 'Biopsie Mammaire'),
(32196, 725, 9, 'Décharge Seins'),
(32197, 726, 9, 'Maladie du sein'),
(32198, 727, 9, 'Examen Mammaire'),
(32199, 728, 9, 'Masse des Seins'),
(32200, 730, 9, 'Bruits respiratoires:'),
(32201, 731, 9, 'Breton'),
(32202, 732, 9, 'Fractures'),
(32203, 734, 9, 'Formulaire de Bronchites'),
(32204, 735, 9, 'Parcourir'),
(32205, 736, 9, 'Parcourir pour Enregistrement'),
(32206, 737, 9, 'Ecchymose/hématome'),
(32207, 738, 9, 'Bulgare'),
(32208, 739, 9, 'Enflement Droit:'),
(32209, 741, 9, 'Brûlure à la miction'),
(32210, 742, 9, 'Brûlure à la miction'),
(32211, 743, 9, 'Téléphone au bureau'),
(32212, 744, 9, 'Occupé'),
(32213, 745, 9, 'mais pas encore traité.'),
(32214, 746, 9, 'Fesses'),
(32215, 747, 9, 'Fesses + S.I'),
(32216, 748, 9, 'par'),
(32217, 749, 9, 'Par'),
(32218, 750, 9, 'Par voie orale'),
(32219, 751, 9, 'Par / Source'),
(32220, 752, 9, 'Par:'),
(32221, 753, 9, 'C'),
(32222, 754, 9, 'Certificat CA pour verifier le serveur syslog RFC 5425 TLS'),
(32223, 755, 9, 'Durée de vie du cache (en secondes)'),
(32224, 756, 9, 'Mettre en cache le résultat du modèle?'),
(32225, 757, 9, 'Consommation de caféine'),
(32226, 758, 9, 'Agenda'),
(32227, 759, 9, 'Heure Fin de l''Agenda'),
(32228, 760, 9, 'Intervalle de l''Agenda'),
(32229, 761, 9, 'Ecran de l''Agenda'),
(32230, 762, 9, 'Paramètre de l''Agenda'),
(32231, 763, 9, 'Heure Début de l''Agenda'),
(32232, 764, 9, 'Agenda UI'),
(32233, 765, 9, 'Vue Agenda'),
(32234, 766, 9, 'Appel à addForm () ce fait ici.<br>'),
(32235, 767, 9, 'Calories'),
(32236, 768, 9, 'Cambodgien'),
(32237, 774, 9, 'Annuler'),
(32238, 775, 9, 'Annuler les Modifications'),
(32239, 776, 9, 'Annulés'),
(32240, 777, 9, 'Cancer'),
(32241, 778, 9, 'Dépistage du cancer: cancer du côlon'),
(32242, 779, 9, 'Dépistage du cancer: Mammographie'),
(32243, 780, 9, 'Dépistage du cancer: Pap'),
(32244, 781, 9, 'Dépistage du cancer: cancer de la prostate'),
(32245, 782, 9, 'Impossible d''ajouter cette entrée car elle existe déjà!'),
(32246, 783, 9, 'Impossible d''ajouter/mettre à jour cette entrée, car un doublon existe déjà!'),
(32247, 785, 9, 'ne peut pas être convertie au format JPEG. Peut-être ImageMagick n''est pas installé?'),
(32248, 787, 9, 'ne peut pas être affiché car son type n''est pas supporté par le navigateur.'),
(32249, 788, 9, 'ne peut pas être affiché car son type n''est pas supporté par le navigateur'),
(32250, 789, 9, 'ne peut pas être affiché car son type n''est pas supporté par le navigateur.'),
(32251, 790, 9, 'Impossible de créer'),
(32252, 795, 9, 'Impossible de trouver '),
(32253, 796, 9, 'Impossible de trouver le nom de fichier destination'),
(32254, 799, 9, 'Impossible de trouver le patient à partir du client ID (dans SQL-Ledger)'),
(32255, 800, 9, 'Impossible de trouver le document PostScript en référence '),
(32256, 801, 9, 'Impossible de trouver le fournisseur à partir de ''employé (dans SQL-Ledger) = '),
(32257, 802, 9, 'Impossible de modifier les Paiements. Reste est négatif.'),
(32258, 803, 9, 'Impossible d''ouvrir '),
(32259, 804, 9, 'Ne pouvez pas poster l''Assurance. L’Entité Payeur sélectionnée est le Patient.'),
(32260, 805, 9, 'Ne pouvez pas poster le Patients. L''organisme Payeur choisi est l''Assurance.'),
(32261, 806, 9, 'Ne pouvez pas poster des paiements. Reste est négatif.'),
(32262, 807, 9, 'Impossible de lire'),
(32263, 808, 9, 'Impossible de lire le répertoire'),
(32264, 809, 9, 'Impossible de mettre à jour car vous n''éditez pas une entrée existante !'),
(32265, 810, 9, 'Capitaliser'),
(32266, 812, 9, 'capsule'),
(32267, 813, 9, 'Carte'),
(32268, 814, 9, 'Cathétérisme Cardiaque'),
(32269, 815, 9, 'Echo cardiaque'),
(32270, 816, 9, 'Cardiovasculaire'),
(32271, 821, 9, 'Cartilage / chondrales / dégâts disque'),
(32272, 822, 9, 'Lésion cartilagineuse'),
(32273, 823, 9, 'Pulsations carotides nl, pouls de pédale nl'),
(32274, 824, 9, 'espèces'),
(32275, 825, 9, 'Espèces'),
(32276, 826, 9, 'Reçu d''Espèce'),
(32277, 827, 9, 'Reçus d''Espèce par le fournisseur'),
(32278, 829, 9, 'Chirurgie de la Cataracte'),
(32279, 830, 9, 'Cataracte'),
(32280, 831, 9, 'Catégories'),
(32281, 832, 9, 'Catégories pour'),
(32282, 833, 9, 'Catégorie'),
(32283, 834, 9, 'catégorie'),
(32284, 835, 9, 'Catégorie '),
(32285, 836, 9, 'Détails Catégorie'),
(32286, 837, 9, 'Limites Catégorie'),
(32287, 838, 9, 'Nom Catégorie'),
(32288, 839, 9, 'Nom catégorie vide'),
(32289, 840, 9, 'Titre/Catégorie'),
(32290, 841, 9, 'Caucasien'),
(32291, 853, 9, 'Téléphone Cellulaire'),
(32292, 855, 9, 'Numéro de Téléphone Cellulaire'),
(32293, 856, 9, 'Centrale de Certification'),
(32294, 857, 9, 'Centrale/Amérique du Sud'),
(32295, 858, 9, 'L''emplacement du fichier crt de l''Autorité de certification ne peut pas être vide'),
(32296, 859, 9, 'L''emplacement du fichier key de l''Autorité de certification emplacement ne peut pas être vide'),
(32297, 861, 9, 'Certificat Utilisateur'),
(32298, 862, 9, 'Certificats'),
(32299, 866, 9, 'modifier'),
(32300, 867, 9, 'Modifier'),
(32301, 868, 9, 'Modifier l''Activité'),
(32302, 870, 9, 'Changement de vision'),
(32303, 871, 9, 'Changement de vision'),
(32304, 874, 9, 'Modifié'),
(32305, 875, 9, 'Intestin modifié'),
(32306, 877, 9, 'Caractéristiques'),
(32307, 879, 9, 'Charge'),
(32308, 880, 9, 'Ajustement de Frais'),
(32309, 882, 9, 'Frais'),
(32310, 883, 9, 'Graphique'),
(32311, 884, 9, 'Graphique d''Activité'),
(32312, 885, 9, 'Rapport d''Activité des Entrées/Sorties'),
(32313, 886, 9, 'ID Graphique'),
(32314, 887, 9, 'ID Graphique:'),
(32315, 889, 9, 'Graphique lieu d''activité'),
(32316, 890, 9, 'Note sur le graphique'),
(32317, 891, 9, 'Numéro Graphique'),
(32318, 892, 9, 'Emplacements de stockage graphique'),
(32319, 893, 9, 'Suivi graphique'),
(32320, 895, 9, 'Graphiques vérifiés'),
(32321, 896, 9, 'Sortie des graphiques'),
(32322, 898, 9, 'Vérifier'),
(32323, 899, 9, 'vérifier'),
(32324, 900, 9, 'Vérifier Tous'),
(32325, 902, 9, 'Vérifier le Montant'),
(32326, 903, 9, 'vérifier la Date'),
(32327, 904, 9, 'Vérifiez les différences de traductions avec la table personnalisée de la langue.'),
(32328, 906, 9, 'Arrivée à'),
(32329, 907, 9, 'Vérifier les données d''entrée'),
(32330, 909, 9, 'Vérifier les résultats de laboratoire'),
(32331, 912, 9, 'vérifier le numéro'),
(32332, 915, 9, 'vérifier le Paiement'),
(32333, 916, 9, 'Cochez la case s''il s''agit d''un fichier crypté'),
(32334, 917, 9, 'Cochez cette case si vous souhaitez que les prestataires voient tous les rendez par défaut et non seulement les leurs.'),
(32335, 923, 9, 'Liste de case à cocher'),
(32336, 924, 9, 'liste case à cocher'),
(32337, 925, 9, 'case à cocher w/texte'),
(32338, 926, 9, 'Case à cocher w/texte'),
(32339, 928, 9, 'Vérifié'),
(32340, 929, 9, 'Case coché = oui, vide = non'),
(32341, 932, 9, 'Vérification'),
(32342, 933, 9, 'Somme de contrôle'),
(32343, 934, 9, 'Thorax'),
(32344, 936, 9, 'Douleur Thoracique'),
(32345, 937, 9, 'Douleur Thoracique:'),
(32346, 938, 9, 'Douleurs Thoraciques'),
(32347, 942, 9, 'Principal réclamation'),
(32348, 943, 9, 'Enfant'),
(32349, 945, 9, 'Statut vaccination infantile (CQM)'),
(32350, 946, 9, 'Frissons'),
(32351, 947, 9, 'Chinois'),
(32352, 948, 9, 'Chinois (simplifié)'),
(32353, 949, 9, 'Chinois (Traditionnel)'),
(32354, 951, 9, 'Choix'),
(32355, 952, 9, 'Cholécystectomie'),
(32356, 954, 9, 'Cholecystestomie'),
(32357, 955, 9, 'Choisissez'),
(32358, 956, 9, 'Choisissez une section et cliquez sur un article, puis dans l''autre section, vous verrez les éléments liés en surbrillance, et vous pouvez cliquer dans cette section pour ajouter et supprimer les relations.'),
(32359, 957, 9, 'Choisir des critères'),
(32360, 962, 9, 'Choisir la liste'),
(32361, 965, 9, 'Choisissez le format d''impression pour ce rapport de rencontre.'),
(32362, 967, 9, 'Bronchite chronique'),
(32363, 968, 9, 'Douleurs articulaires chroniques'),
(32364, 969, 9, 'Maladie rénale chronique'),
(32365, 970, 9, 'Synovite chronique / effusion / douleurs articulaires / goutte'),
(32366, 971, 9, 'Chronique / Récurrent'),
(32367, 973, 9, 'Cirrhose du foie');
INSERT INTO `lang_definitions` VALUES
(32368, 974, 9, 'Cirrhose du foie'),
(32369, 975, 9, 'Ville'),
(32370, 976, 9, 'Nom Ville'),
(32371, 977, 9, 'Ville, Etat'),
(32372, 978, 9, 'Ville, Etat Code Postal'),
(32373, 979, 9, 'Ville/Etat'),
(32374, 980, 9, 'Réclamation'),
(32375, 981, 9, 'Réclamation '),
(32376, 988, 9, 'Classification'),
(32377, 989, 9, 'Effacer'),
(32378, 991, 9, 'Effacer tout'),
(32379, 992, 9, 'Effacer les données HL7'),
(32380, 993, 9, 'Justification claire'),
(32381, 997, 9, 'Cliquez'),
(32382, 1001, 9, 'Cliquer pour plus'),
(32383, 1005, 9, 'Cliquez ici'),
(32384, 1006, 9, 'Cliquez ici pour ajouter un nouveau patient.'),
(32385, 1008, 9, 'Cliquez ici pour choisir une date'),
(32386, 1009, 9, 'Cliquez ici pour choisir une date et une heure'),
(32387, 1010, 9, 'Cliquez ici pour choisir une date de début'),
(32388, 1020, 9, 'Cliquez ici pour rechercher'),
(32389, 1021, 9, 'Cliquez ici pour mettre à jour les paramètres de priorité, catégorie et le surnom'),
(32390, 1022, 9, 'Cliquez ici pour tout afficher.'),
(32391, 1023, 9, 'Cliquez ici pour afficher'),
(32392, 1025, 9, 'Cliquez ici pour afficher les signes vitaux.'),
(32393, 1026, 9, 'Cliquez ici pour afficher les détails du patient'),
(32394, 1027, 9, 'Cliquez ici pour les affichés tous.'),
(32395, 1029, 9, 'Cliquez sur Installer pour installer une version de la base de données de la date suivante'),
(32396, 1030, 9, 'Cliquez sur une des parties du temps de l''augmenter'),
(32397, 1032, 9, 'Cliquez sur Actualiser pour afficher tous les résultats, ou introduit les critères de recherche ci-dessus pour afficher des résultats spécifiques.'),
(32398, 1034, 9, 'Cliquez pour ajouter de nouveaux composants'),
(32399, 1035, 9, 'Cliquez pour ajouter une nouvelle consultation'),
(32400, 1037, 9, 'Cliquez ici pour télécharger'),
(32401, 1038, 9, 'Cliquez pour modifier'),
(32402, 1040, 9, 'Cliquez pour modifier cet événement'),
(32403, 1041, 9, 'Cliquez pour générer le rapport'),
(32404, 1043, 9, 'Cliquez pour imprimer'),
(32405, 1044, 9, 'Cliquez pour recevoir (ajouter) un nouveau lot'),
(32406, 1045, 9, 'Cliquez pour sélectionner'),
(32407, 1046, 9, 'Cliquez pour sélectionner'),
(32408, 1047, 9, 'Cliquez pour sélectionner un code standard pour cette procédure'),
(32409, 1050, 9, 'Cliquez pour sélectionner ou modifier le code CVX'),
(32410, 1051, 9, 'Cliquez pour sélectionner ou modifier les diagnostics'),
(32411, 1052, 9, 'Cliquez pour sélectionner ou modifier les codes de service'),
(32412, 1053, 9, 'Cliquez pour sélectionner le patient'),
(32413, 1054, 9, 'Cliquez pour sélectionner le code associé'),
(32414, 1055, 9, 'Cliquez pour sélectionner les services à effectuer si ce résultat est anormal'),
(32415, 1056, 9, 'Cliquez pour sélectionner la procédure désirée'),
(32416, 1058, 9, 'Cliquez pour afficher'),
(32417, 1059, 9, 'Cliquez pour afficher ou modifier'),
(32418, 1060, 9, 'Cliquez pour afficher/modifier'),
(32419, 1061, 9, 'Cliquez sur le bouton Upgrade pour mettre à niveau la base de données à partir de la date suivante'),
(32420, 1063, 9, 'Cliquez:'),
(32421, 1064, 9, 'Jours d''expiration du certificat client'),
(32422, 1065, 9, 'Période de validation du certificat client'),
(32423, 1066, 9, 'La validité du certificat client doit être un nombre valide.'),
(32424, 1067, 9, 'Copie Client'),
(32425, 1069, 9, 'Résumé dossier médical du client'),
(32426, 1072, 9, 'Profil client - Nouveaux Clients'),
(32427, 1073, 9, 'Profil client - Clients unique'),
(32428, 1074, 9, 'Clients'),
(32429, 1075, 9, 'Clinique'),
(32430, 1076, 9, 'Copie Clinique'),
(32431, 1077, 9, 'Relevé quotidien Clinique'),
(32432, 1078, 9, 'Identification Clinique'),
(32433, 1079, 9, 'Clinique'),
(32434, 1080, 9, 'Règles de décision clinique, gestionnaire d''alertes'),
(32435, 1083, 9, 'Plans cliniques'),
(32436, 1084, 9, 'Critères de qualité clinique (CQC)'),
(32437, 1087, 9, 'Rappels cliniques'),
(32438, 1088, 9, 'Rapports cliniques'),
(32439, 1089, 9, 'Règle clinique, Catégorie d''action'),
(32440, 1090, 9, 'Règle clinique, Elément d''action'),
(32441, 1091, 9, 'Règle cliniques, méthodes de filtrage'),
(32442, 1092, 9, 'Règle cliniques, les méthodes cible'),
(32443, 1093, 9, 'Règles cliniques'),
(32444, 1094, 9, 'Règles cliniques, intervalles d''âge'),
(32445, 1095, 9, 'Règles cliniques, les comparaisons'),
(32446, 1096, 9, 'Règles cliniques, Types Rencontre'),
(32447, 1097, 9, 'Règles cliniques, Options cause de rappel'),
(32448, 1098, 9, 'Règles cliniques, Options inactivation de rappel'),
(32449, 1099, 9, 'Règles cliniques, Intervalles de rappel'),
(32450, 1100, 9, 'Règles cliniques, Méthodes de rappel'),
(32451, 1101, 9, 'Règles cliniques, Intervalles cible'),
(32452, 1102, 9, 'Objectifs cliniques'),
(32453, 1106, 9, 'Cliniciens'),
(32454, 1107, 9, 'Clone'),
(32455, 1108, 9, 'Cloner dernière Visite'),
(32456, 1109, 9, 'Fermer'),
(32457, 1111, 9, 'Fermer la fenêtre'),
(32458, 1112, 9, 'Fermé'),
(32459, 1113, 9, 'cm'),
(32460, 1130, 9, 'copaiement'),
(32461, 1131, 9, 'Code'),
(32462, 1132, 9, 'code'),
(32463, 1133, 9, 'code Recherche'),
(32464, 1134, 9, 'Code doit être deux lettre en minuscule'),
(32465, 1135, 9, 'Code ou symbole pour indiquer la monnaie'),
(32466, 1136, 9, 'Texte du code'),
(32467, 1138, 9, 'type de code'),
(32468, 1141, 9, 'Types de code'),
(32469, 1144, 9, 'Codes'),
(32470, 1145, 9, 'Codage'),
(32471, 1147, 9, 'Codage - toutes rencontres (par écrit, avec quelques options)'),
(32472, 1148, 9, 'Codage - mes rencontres (par écrit, avec quelques options)'),
(32473, 1149, 9, 'Codification Non autorisé'),
(32474, 1150, 9, 'Café'),
(32475, 1152, 9, 'Coassurance'),
(32476, 1154, 9, 'Réduire'),
(32477, 1155, 9, 'réduire'),
(32478, 1156, 9, 'Réduire tout'),
(32479, 1157, 9, 'Réduire tout'),
(32480, 1158, 9, 'réduire tout'),
(32481, 1161, 9, 'Collections'),
(32482, 1162, 9, 'Rapport de Collections'),
(32483, 1163, 9, 'Cancer du côlon'),
(32484, 1164, 9, 'Dépistage du cancer du côlon'),
(32485, 1165, 9, 'Chirurgie du cancer du colon'),
(32486, 1166, 9, 'Coloscopie'),
(32487, 1167, 9, 'coloscopie'),
(32488, 1168, 9, 'Couleur'),
(32489, 1169, 9, 'Couleur: Abrév'),
(32490, 1170, 9, 'Colonne'),
(32491, 1171, 9, 'colonnes'),
(32492, 1172, 9, 'Lots Combinés'),
(32493, 1173, 9, 'Virgule'),
(32494, 1174, 9, 'Commentaire'),
(32495, 1175, 9, 'Commentaires'),
(32496, 1176, 9, 'Commentaires ou recommandation pour ce résultat'),
(32497, 1177, 9, 'Entreprise Assurance Cie'),
(32498, 1178, 9, 'Valider les modifications'),
(32499, 1180, 9, 'Communications'),
(32500, 1182, 9, 'Société'),
(32501, 1183, 9, 'Nom de la société'),
(32502, 1184, 9, 'Compléter'),
(32503, 1186, 9, 'Terminé'),
(32504, 1188, 9, 'Terminé?'),
(32505, 1190, 9, 'Complications par Prestataire de services'),
(32506, 1191, 9, 'Les complications d''avortement'),
(32507, 1192, 9, 'Composants'),
(32508, 1193, 9, 'Système de commande Médical Assisté par Ordinateur'),
(32509, 1194, 9, 'Conclusions'),
(32510, 1199, 9, 'Configuration'),
(32511, 1200, 9, 'Export / Import de la Configuration'),
(32512, 1202, 9, 'Configurer Apache et LibreEHR pour utiliser les certificats SSL coté client'),
(32513, 1203, 9, 'Configurer Apache pour utiliser les certificats SSL coté client'),
(32514, 1204, 9, 'Configurer Apache pour utiliser HTTPS'),
(32515, 1205, 9, 'Configurer LibreEHR pour utiliser les certificats SSL coté client'),
(32516, 1208, 9, 'Confirmer la création du nouveau Patient'),
(32517, 1209, 9, 'Confirmer le Nouveau Passe'),
(32518, 1210, 9, 'Confirmer le Payement'),
(32519, 1214, 9, 'Congénitale'),
(32520, 1215, 9, 'Conjonctives, pupilles'),
(32521, 1218, 9, 'Constante'),
(32522, 1219, 9, 'nom de la constante'),
(32523, 1220, 9, 'Nom de la constante est vide'),
(32524, 1221, 9, 'constantes'),
(32525, 1222, 9, 'Constipation'),
(32526, 1223, 9, 'Constitutionnel'),
(32527, 1226, 9, 'Descriptif bref de la consultation'),
(32528, 1227, 9, 'Contact'),
(32529, 1228, 9, 'Email du Contact'),
(32530, 1229, 9, 'Adresse Email du contact'),
(32531, 1231, 9, 'coordonnées'),
(32532, 1232, 9, 'Lentilles de contact'),
(32533, 1236, 9, 'Nom du contact'),
(32534, 1237, 9, 'Personne à contacter'),
(32535, 1239, 9, 'Numéro de téléphone'),
(32536, 1241, 9, 'contient au moins trois des quatre éléments suivants:'),
(32537, 1243, 9, 'Contenu'),
(32538, 1244, 9, 'contenu'),
(32539, 1245, 9, 'Contexte'),
(32540, 1246, 9, 'Nom de contexte ne peut être vides'),
(32541, 1247, 9, 'Continuer'),
(32542, 1248, 9, 'Document de Continuité des soins (CCD)'),
(32543, 1249, 9, 'Enregistrement de Continuité des soins (RCC)'),
(32544, 1251, 9, 'Contraception'),
(32545, 1252, 9, 'Problèmes de contraception'),
(32546, 1253, 9, 'Complication de la contraception (à préciser)'),
(32547, 1254, 9, 'Méthode contraceptive'),
(32548, 1255, 9, 'Produits contraceptifs'),
(32549, 1256, 9, 'Services contraceptifs déjà démarré'),
(32550, 1257, 9, 'Début des contraceptifs'),
(32551, 1329, 9, 'Créer un événement'),
(32552, 1330, 9, 'Créer et télécharger une sauvegarde complète'),
(32553, 1332, 9, 'Créer une sauvegarde'),
(32554, 1333, 9, 'créer un lot'),
(32555, 1334, 9, 'Créer un certificat client'),
(32556, 1335, 9, 'Créer des certificats SSL côté client'),
(32557, 1336, 9, 'Créer une duplicata'),
(32558, 1338, 9, 'Créer une sauvegarde du journal d''événements'),
(32559, 1339, 9, 'Créer un nouveau problème'),
(32560, 1340, 9, 'Créer un nouveau patient'),
(32561, 1342, 9, 'Créer crédentiels pour un portail hors site'),
(32562, 1343, 9, 'Créer crédentiels pour un portail sur site'),
(32563, 1344, 9, 'Créer remarque patient'),
(32564, 1345, 9, 'Créer l''autorité de certification SSL et les certificats du serveur.'),
(32565, 1346, 9, 'Ajouter une visite'),
(32566, 1347, 9, 'Ajoutée'),
(32567, 1348, 9, 'Préparation du fichier d''exportation'),
(32568, 1350, 9, 'La création de ce fichier sur l''hôte distant a échoué'),
(32569, 1351, 9, 'Créateur'),
(32570, 1352, 9, 'Crédit'),
(32571, 1353, 9, 'Carte de crédit'),
(32572, 1354, 9, 'Crédits'),
(32573, 1356, 9, 'Critères'),
(32574, 1358, 9, 'La maladie de Crohn'),
(32575, 1359, 9, 'La maladie de Crohn'),
(32576, 1360, 9, 'Exporter CSV'),
(32577, 1361, 9, 'Fichier CSV'),
(32578, 1362, 9, 'Table CSV'),
(32579, 1377, 9, 'Adresse actuelle'),
(32580, 1378, 9, 'Médicaments en vigeur'),
(32581, 1379, 9, 'Mot de passe en vigeur'),
(32582, 1380, 9, 'Patient en cours'),
(32583, 1382, 9, 'Drogues de rue en usage'),
(32584, 1386, 9, 'Active actuellement'),
(32585, 1389, 9, 'Syndrome de Cushing'),
(32586, 1390, 9, 'Syndrome de Cushing'),
(32587, 1392, 9, 'Personnalisé'),
(32588, 1404, 9, 'D'),
(32589, 1405, 9, 'D&C'),
(32590, 1406, 9, 'D&E'),
(32591, 1407, 9, 'D.O.B.'),
(32592, 1408, 9, 'quotidien'),
(32593, 1409, 9, 'Relevé quotidien'),
(32594, 1410, 9, 'Danois'),
(32595, 1411, 9, 'Données similaires sont déjà en base de données,veuillez change le code et/ou la description'),
(32596, 1412, 9, 'Données similaires sont déjà en base de données, veuillez changer le nom de la constante'),
(32597, 1413, 9, 'données Cols'),
(32598, 1420, 9, 'Type de données'),
(32599, 1421, 9, 'Base de Données'),
(32600, 1422, 9, 'Base de Données non installée'),
(32601, 1424, 9, 'Rapports de la Base de données'),
(32602, 1425, 9, 'Mise à niveau Base de Données términée.'),
(32603, 1426, 9, 'DataCols doit être un nombre entre 1 et 999'),
(32604, 1427, 9, 'Date'),
(32605, 1428, 9, 'DATE'),
(32606, 1431, 9, 'Date d''administration'),
(32607, 1432, 9, 'Date et heure du prélèvement'),
(32608, 1435, 9, 'Date et heure auxquelles le prélèvement a été recueilli'),
(32609, 1436, 9, 'Date ne peut être supérieure à Aujourd''hui'),
(32610, 1437, 9, 'Date de services de contraception initialement prévu'),
(32611, 1438, 9, 'Date de création'),
(32612, 1439, 9, 'Date de décès'),
(32613, 1440, 9, 'Date de déstruction'),
(32614, 1441, 9, 'Format d''affichage des dates'),
(32615, 1442, 9, 'Format de la date de "fin de rendez-vous" n''est pas valide'),
(32616, 1443, 9, 'Format de la date de "début du rendez-" n''est pas valide'),
(32617, 1444, 9, 'Format de date pour "Prochain rendez-vous" n''est pas valide'),
(32618, 1445, 9, 'Format de la date de "jamais vu depuis" n''est pas valide'),
(32619, 1446, 9, 'Format de date pour "vu depuis" n''est pas valide'),
(32620, 1447, 9, 'Date de vaccination des déclarations de l''information tenu'),
(32621, 1448, 9, 'Manque la Date pour le code '),
(32622, 1449, 9, 'Date de Critère principal'),
(32623, 1450, 9, 'Date de dépôt bancaire aaaa-mm-jj'),
(32624, 1452, 9, 'Date de naissance'),
(32625, 1453, 9, 'Date de naissance'),
(32626, 1454, 9, 'Date de naissance'),
(32627, 1456, 9, 'Date de l''accident'),
(32628, 1458, 9, 'Date de paiement aaaa-mm-jj'),
(32629, 1459, 9, 'Date de saisine'),
(32630, 1460, 9, 'Date de réponse'),
(32631, 1463, 9, 'Date du service'),
(32632, 1464, 9, 'Date du service = Aujourd''hui'),
(32633, 1465, 9, 'Date du service mm/jj/aaaa'),
(32634, 1466, 9, 'Date du service:'),
(32635, 1467, 9, 'Date de signature'),
(32636, 1469, 9, 'Date de cette commande'),
(32637, 1470, 9, 'Date du présent rapport'),
(32638, 1471, 9, 'Date de déclaration VIS'),
(32639, 1472, 9, 'Date de commande'),
(32640, 1475, 9, 'Sélecteur de Date'),
(32641, 1476, 9, 'Date d''envoi'),
(32642, 1479, 9, 'La date ne peut être vide.'),
(32643, 1480, 9, 'Date/Appt'),
(32644, 1481, 9, 'Date/Notes'),
(32645, 1482, 9, 'Date/Notes de dernière'),
(32646, 1483, 9, 'Date/Heure'),
(32647, 1484, 9, 'Date:'),
(32648, 1486, 9, 'Jour'),
(32649, 1487, 9, 'jour'),
(32650, 1489, 9, 'Vue quotidienne'),
(32651, 1490, 9, 'Jour(s)'),
(32652, 1491, 9, 'Jour(s) M-F'),
(32653, 1492, 9, 'jours'),
(32654, 1493, 9, 'Jours'),
(32655, 1494, 9, 'jours avant'),
(32656, 1495, 9, 'Jours et Jeux manqués'),
(32657, 1496, 9, 'Jours depuis dernière Rencontre'),
(32658, 1497, 9, 'jours manqués'),
(32659, 1498, 9, 'Jours par colonne:'),
(32660, 1500, 9, 'Jours/Col:'),
(32661, 1501, 9, 'BD installée'),
(32662, 1502, 9, 'JJ/MM/AAAA'),
(32663, 1503, 9, 'Dés-identification'),
(32664, 1504, 9, 'Processus de dés-identification est terminé'),
(32665, 1505, 9, 'Processus de dés-identification est en cours'),
(32666, 1506, 9, 'Processus de dés-identification est démarré et s''exécute en arrière-plan'),
(32667, 1507, 9, 'Données dépersonnalisées peuvent ne pas être complète'),
(32668, 1508, 9, 'Fichiers dés-identification seront sauvegardés dans'),
(32669, 1509, 9, 'DEA'),
(32670, 1511, 9, 'Sourd'),
(32671, 1512, 9, 'informations de débogage'),
(32672, 1515, 9, 'Dec.'),
(32673, 1516, 9, 'Décédé'),
(32674, 1517, 9, 'Décembre'),
(32675, 1520, 9, 'Déductible'),
(32676, 1522, 9, 'Par défaut'),
(32677, 1523, 9, 'Afficher Calendrier par défaut'),
(32678, 1524, 9, 'ID formulaire par défaut des Rencontres'),
(32679, 1526, 9, 'Facilité par défaut'),
(32680, 1527, 9, 'Langue par défaut'),
(32681, 1528, 9, 'Langue par défaut si aucune autre n''est autorisé ou choisi.'),
(32682, 1529, 9, 'Liste par défaut (écrire, ajouter seulement en option)'),
(32683, 1530, 9, 'Méthode par défaut'),
(32684, 1531, 9, 'Délai en Jours d''expiration du mot de passe par défaut'),
(32685, 1532, 9, 'Période d''expiration par défaut du mot de passe en jours. 0 signifie que cette fonctionnalité est désactivée.'),
(32686, 1536, 9, 'Fournisseur par défaut'),
(32687, 1537, 9, 'Plage par défaut'),
(32688, 1538, 9, 'Motif de la visite par défaut'),
(32689, 1540, 9, 'Paramètre par défaut'),
(32690, 1542, 9, 'Modèle par défaut'),
(32691, 1546, 9, 'Unités par défaut'),
(32692, 1547, 9, 'Valeur par défaut'),
(32693, 1548, 9, 'Entrepôt par défaut'),
(32694, 1549, 9, 'Partenaire X12 par défaut'),
(32695, 1550, 9, 'Défaut / Global'),
(32696, 1551, 9, 'Sup.'),
(32697, 1552, 9, 'sup.'),
(32698, 1553, 9, 'Pecurrence différée (> 12 Mo)'),
(32699, 1554, 9, 'Supprimer'),
(32700, 1555, 9, 'supprimer'),
(32701, 1556, 9, 'Supprimer les catégories avec ID(s): '),
(32702, 1557, 9, 'Supprimer Catégorie'),
(32703, 1560, 9, 'Supprimer groupe'),
(32704, 1561, 9, 'Supprimer liste'),
(32705, 1562, 9, 'Supprimer des pages'),
(32706, 1563, 9, 'Supprimer Patient, Rencontre, formulaire, Problème, Document, Paiement, Facturation ou Transaction'),
(32707, 1565, 9, 'Supprimer ligne'),
(32708, 1566, 9, 'Supprimer éléments sélectionnés'),
(32709, 1568, 9, 'Suppression avec succès.'),
(32710, 1569, 9, 'Supprimer ce document'),
(32711, 1570, 9, 'Supprimer ce formulaire'),
(32712, 1571, 9, 'Supprimer cette note'),
(32713, 1573, 9, 'Supprimé avec succès.'),
(32714, 1581, 9, 'Démence'),
(32715, 1582, 9, 'Données démographiques'),
(32716, 1583, 9, 'Données démographiques (écriture, ajouter seulement en option)'),
(32717, 1585, 9, 'Données démographiques critères de recherche'),
(32718, 1586, 9, 'Données démographiques non autorisés'),
(32719, 1587, 9, 'Données démographiques non autorisés.'),
(32720, 1589, 9, 'Dénominateur'),
(32721, 1590, 9, 'Dentaire'),
(32722, 1592, 9, 'Problèmes dentaires'),
(32723, 1595, 9, 'Selon le type de facture que vous testez, vous verrez une sortie similaire à HCFA sur une page vierge pour les factures HCFA, vous verrez de nombreuses lignes de texte et information quelque peu déformé si vous testez une réclamation X12. Ce texte déformé est le format X12 EDI 4010A. Occasionnellement, vous verrez caractères étranges qui ressemblent aux dominos ou tildes, ce sont les caractères de contrôle tels que les sauts de page et sont normales.'),
(32724, 1596, 9, 'Date dépôt'),
(32725, 1597, 9, 'Date dépôt ne peut pas être supérieur à Aujourd''hui'),
(32726, 1598, 9, 'Date dépôt:'),
(32727, 1599, 9, 'Déprimé'),
(32728, 1600, 9, 'Dépression'),
(32729, 1602, 9, 'Description'),
(32730, 1603, 9, 'description'),
(32731, 1605, 9, 'Description de la divulgation'),
(32732, 1606, 9, 'Description de cette procédure ou le code résultat'),
(32733, 1607, 9, 'Traduction de la description'),
(32734, 1609, 9, 'Destination'),
(32735, 1610, 9, 'Nom du fichier destination'),
(32736, 1611, 9, 'Détruire lot'),
(32737, 1612, 9, 'Détruire...'),
(32738, 1613, 9, 'Détruite'),
(32739, 1614, 9, 'Médicaments détruits'),
(32740, 1615, 9, 'Rapport de destruction des Médicaments'),
(32741, 1616, 9, 'Détail'),
(32742, 1617, 9, 'Détails'),
(32743, 1619, 9, 'Developmental anomalie'),
(32744, 1620, 9, 'Diabète'),
(32745, 1621, 9, 'Diabète'),
(32746, 1622, 9, 'Diabète: gestion de la pression artérielle (CQM)'),
(32747, 1623, 9, 'Diabète: examen de la vue'),
(32748, 1624, 9, 'Diabète: examen des yeux (CQM)'),
(32749, 1625, 9, 'Diabète: examen des pieds'),
(32750, 1626, 9, 'Diabète: examen des pieds (CQM)'),
(32751, 1627, 9, 'Diabète: Faible contrôle HbA1c (CQM)'),
(32752, 1628, 9, 'Diabète: Hémoglobine A1C'),
(32753, 1629, 9, 'Diabète: Gestion et de contrôle LDL (CQM)'),
(32754, 1630, 9, 'Diabète: Microalbumine urinaire'),
(32755, 1631, 9, 'Diagnostic'),
(32756, 1633, 9, 'Diagnostic'),
(32757, 1634, 9, 'Code diagnostic'),
(32758, 1636, 9, 'Date diagnostic'),
(32759, 1637, 9, 'Le diagnostic doit être codé en une rencontre liée'),
(32760, 1638, 9, 'Nom Diagnostic'),
(32761, 1639, 9, 'Rapport de diagnostic'),
(32762, 1642, 9, 'Titre Diagnostic'),
(32763, 1643, 9, 'Diagnostic:'),
(32764, 1644, 9, 'Diagnostic: '),
(32765, 1645, 9, 'Tests de diagnostic:'),
(32766, 1646, 9, 'Cadrans'),
(32767, 1647, 9, 'Diaphragmes / Casquettes'),
(32768, 1648, 9, 'Diarrhée'),
(32769, 1650, 9, 'Dictée'),
(32770, 1651, 9, 'Dictée: '),
(32771, 1652, 9, 'Avez-vous reçu une copie de l''avis HIPAA?'),
(32772, 1653, 9, 'Diffuse:'),
(32773, 1654, 9, 'Signé numériquement'),
(32774, 1657, 9, 'Publipostage direct'),
(32775, 1663, 9, 'Nom du Directeur'),
(32776, 1665, 9, 'Handicap'),
(32777, 1667, 9, 'Désactiver Calendrier'),
(32778, 1668, 9, 'Désactiver Graphique Suivi'),
(32779, 1669, 9, 'Désactiver Vaccination'),
(32780, 1670, 9, 'Désactiver Formulaire Ancien métrique des signes vitaux'),
(32781, 1672, 9, 'Désactiver phpMyAdmin'),
(32782, 1673, 9, 'Désactiver Prescriptions'),
(32783, 1674, 9, 'Désactiver Groupes d''utilisateurs'),
(32784, 1675, 9, 'handicapé'),
(32785, 1676, 9, 'Handicapé'),
(32786, 1678, 9, 'DISQUE'),
(32787, 1681, 9, 'Refoulement'),
(32788, 1682, 9, 'Refoulement de l''urètre'),
(32789, 1684, 9, 'Refoulement à droite'),
(32790, 1685, 9, 'Refoulement à droite:'),
(32791, 1689, 9, 'Divulgation info'),
(32792, 1690, 9, 'Type Divulgation'),
(32793, 1691, 9, 'Types Divulgation'),
(32794, 1692, 9, 'Divulgations'),
(32795, 1694, 9, 'Remise'),
(32796, 1695, 9, 'Montant de remise'),
(32797, 1696, 9, 'Niveau de remise'),
(32798, 1697, 9, 'Taux de remise'),
(32799, 1698, 9, 'Réductions au montant en numéraire'),
(32800, 1699, 9, 'Réductions au moment du contrôle sont entrés comme montants, par opposition au pourcentage.'),
(32801, 1700, 9, 'Résultat discret'),
(32802, 1701, 9, 'Maladie'),
(32803, 1702, 9, 'Luxation'),
(32804, 1704, 9, 'Expédition'),
(32805, 1705, 9, 'Expédition document reçu'),
(32806, 1706, 9, 'Distribué'),
(32807, 1707, 9, 'Afficher les pré-arrangements dans l''écran démographie'),
(32808, 1709, 9, 'Afficher les dates d''évènements dans le bloc?'),
(32809, 1711, 9, 'Afficher combien d''évènements'),
(32810, 1714, 9, 'Afficher le nom'),
(32811, 1715, 9, 'Afficher le calendrier?'),
(32812, 1718, 9, 'Afficher dans le bloc les évènements du jour?'),
(32813, 1719, 9, 'Afficher dans le bloc les sujets?'),
(32814, 1720, 9, 'Afficher dans le bloc les évènements à venir?'),
(32815, 1721, 9, 'Colonnes visibles'),
(32816, 1722, 9, 'Passer au numéro suivant de la liste des divulgations récentes:'),
(32817, 1723, 9, 'Passer au numéro suivant de la liste de notes récentes:'),
(32818, 1724, 9, 'Passer au numéro suivant de la liste de notes récentes'),
(32819, 1725, 9, 'Distribution'),
(32820, 1726, 9, 'Distributions'),
(32821, 1727, 9, 'Distributeur'),
(32822, 1729, 9, 'Sigmoïdite'),
(32823, 1730, 9, 'Chirurgie pour diverticulite'),
(32824, 1731, 9, 'Diverticulite'),
(32825, 1732, 9, 'Chirurgie pour diverticulite'),
(32826, 1733, 9, 'Divorcé'),
(32827, 1734, 9, 'Vertiges:'),
(32828, 1735, 9, 'Ne pas modifier'),
(32829, 1742, 9, 'Ne pas afficher le calendrier.'),
(32830, 1744, 9, 'Pas d''inventaire et vente de produits'),
(32831, 1745, 9, 'Ne nécessite pas une autorisation écrite du patient'),
(32832, 1746, 9, 'Prescription de non-réanimation'),
(32833, 1747, 9, 'ne pas enregistrer'),
(32834, 1748, 9, 'ne pas substituer'),
(32835, 1749, 9, 'ne rien faire'),
(32836, 1751, 9, 'Voulez-vous vraiment supprimer'),
(32837, 1752, 9, 'Voulez-vous vraiment supprimer la sélection?'),
(32838, 1753, 9, 'Voulez-vous vraiment supprimer ce groupe'),
(32839, 1755, 9, 'Voulez-vous continuer?'),
(32840, 1756, 9, 'Voulez-vous supprimer cet élément?'),
(32841, 1757, 9, 'Voulez-vous supprimer?'),
(32842, 1758, 9, 'Voulez-vous supprimer cet enregistrement?'),
(32843, 1759, 9, 'Vous désirez continuer l''ajout de ce nouveau patient?'),
(32844, 1760, 9, 'Vous désirez continuer sous le nouveau nom?'),
(32845, 1761, 9, 'Vous désirez supprimer DEFINITIVEMENT ce dossier de vaccination?'),
(32846, 1763, 9, 'La date des naissance est manquante, fournir si disponible'),
(32847, 1764, 9, 'Documents'),
(32848, 1765, 9, 'Médecin'),
(32849, 1766, 9, 'Médecin:'),
(32850, 1767, 9, 'Nom du médecin et signature'),
(32851, 1768, 9, 'Document'),
(32852, 1769, 9, 'document'),
(32853, 1770, 9, 'Catégories document'),
(32854, 1775, 9, 'Document ne peut être attaché à l''identification du patient'),
(32855, 1777, 9, 'Date du document'),
(32856, 1778, 9, 'Date et version du document modifiés avec succès'),
(32857, 1779, 9, 'Nº du document'),
(32858, 1780, 9, 'Document déplacé vers la nouvelle catégorie'),
(32859, 1781, 9, 'Document attaché à l''identification du patient'),
(32860, 1783, 9, 'Vérification d''intégrité du Document passé.'),
(32861, 1785, 9, 'Document renommé avec succès.'),
(32862, 1790, 9, 'Lieu Document/Imagerie'),
(32863, 1791, 9, 'Documents'),
(32864, 1792, 9, 'Documents (écriture, addonly optionnel)'),
(32865, 1794, 9, 'Date d''entrée'),
(32866, 1800, 9, 'Ne pas sauvegarder'),
(32867, 1801, 9, 'Ne pas sauvegarder'),
(32868, 1802, 9, 'Ne pas sauvegarder les changements'),
(32869, 1803, 9, 'Terminé'),
(32870, 1804, 9, 'Effectué avec:'),
(32871, 1805, 9, 'Terminé. Envoi du téléchargement'),
(32872, 1807, 9, 'Posologie'),
(32873, 1809, 9, 'Double-cliquez pour éditer'),
(32874, 1810, 9, 'Vision Double'),
(32875, 1811, 9, 'Télécharger'),
(32876, 1814, 9, 'Télécharger dans tout les cas'),
(32877, 1815, 9, 'Télécharger la facturation, la posté à la comptabilité la marquer comme facturé'),
(32878, 1817, 9, 'Télécharger les certificats'),
(32879, 1818, 9, 'Télécharger les données de configuration'),
(32880, 1820, 9, 'télécharger le fichier crypté'),
(32881, 1827, 9, 'Télécharger les déclarations sélectionnées'),
(32882, 1828, 9, 'Contrôle du Dr'),
(32883, 1829, 9, 'Visite du Dr'),
(32884, 1830, 9, 'Dr'),
(32885, 1831, 9, 'Glissez pour déplacer'),
(32886, 1832, 9, 'Dribble'),
(32887, 1833, 9, 'Permis de conduire ou de N° Identification'),
(32888, 1834, 9, 'Médicament'),
(32889, 1835, 9, 'Chercheur médicaments'),
(32890, 1836, 9, 'Formes médicamenteuse'),
(32891, 1837, 9, 'ID du médicament manquant!'),
(32892, 1839, 9, 'Inventaire des médicaments'),
(32893, 1840, 9, 'Nom du médicament'),
(32894, 1841, 9, 'Voies du médicament'),
(32895, 1845, 9, 'Unités du médicament'),
(32896, 1846, 9, 'Médicaments'),
(32897, 1847, 9, 'Produits et Médicaments'),
(32898, 1848, 9, 'Bouche sèche'),
(32899, 1860, 9, 'Due'),
(32900, 1861, 9, 'Date d''échéance'),
(32901, 1862, 9, 'Date d''échéance mm/jj/aaaa ou aaaa-mm-jj'),
(32902, 1863, 9, 'Date d''échéance:'),
(32903, 1864, 9, 'Due Ins'),
(32904, 1865, 9, 'Due Pt'),
(32905, 1866, 9, 'Due Bientôt'),
(32906, 1867, 9, 'Etat échéance'),
(32907, 1868, 9, 'Mise à jour de Etat échéance'),
(32908, 1869, 9, 'Dumping de la base de données LibreEHR'),
(32909, 1870, 9, 'Dumping de l''arborescence web LibreEHR'),
(32910, 1871, 9, 'Dumping de la base de données phpGACL'),
(32911, 1872, 9, 'Dumping de l''arborescence web phpGACL'),
(32912, 1873, 9, 'Dumping de la base de données SQL-Ledger'),
(32913, 1874, 9, 'Dumping de l''arborescence web SQL-Ledger'),
(32914, 1875, 9, 'Vérifiez Dup'),
(32915, 1876, 9, 'Numéro ID dupliqué sur la ligne'),
(32916, 1877, 9, 'Nom dupliqué sur la ligne'),
(32917, 1878, 9, 'AVERTISSEMENT DUPLICATION'),
(32918, 1879, 9, 'Procuration durable'),
(32919, 1880, 9, 'durée'),
(32920, 1881, 9, 'Durée'),
(32921, 1882, 9, 'Hollandais'),
(32922, 1884, 9, 'Dysphagie'),
(32923, 1885, 9, 'Dyspnée:'),
(32924, 1886, 9, 'Dysurie'),
(32925, 1888, 9, 'Procuration durable'),
(32926, 1892, 9, 'Renouvellement e-Rx'),
(32927, 1894, 9, 'Récidive précoce (<2 Mo)'),
(32928, 1895, 9, 'Oreilles'),
(32929, 1896, 9, 'ECG'),
(32930, 1898, 9, 'OEdème'),
(32931, 1902, 9, 'EDI-271 Fichier Upload'),
(32932, 1903, 9, 'EDI-271 Fichier Réponse Upload'),
(32933, 1904, 9, 'Editer'),
(32934, 1905, 9, 'éditer'),
(32935, 1906, 9, 'Editer les Allergies'),
(32936, 1907, 9, 'Editer les Catégories'),
(32937, 1908, 9, 'Editer les Définitions'),
(32938, 1909, 9, 'Editer les définitions'),
(32939, 1910, 9, 'Editer les Diagnostics pour'),
(32940, 1911, 9, 'Editer Divulgation'),
(32941, 1912, 9, 'Editer les Services'),
(32942, 1913, 9, 'Editer Facilité'),
(32943, 1914, 9, 'Editer les informations de Service'),
(32944, 1916, 9, 'Editer le fichier de'),
(32945, 1917, 9, 'Editer la forme'),
(32946, 1918, 9, 'Editer les paramètres globaux'),
(32947, 1920, 9, 'Editer mise en page'),
(32948, 1921, 9, 'Editer la liste'),
(32949, 1922, 9, 'Editer paiement'),
(32950, 1923, 9, 'Editer la structure'),
(32951, 1924, 9, 'Editer l''utilisateur'),
(32952, 1925, 9, 'Editer les paramètres de l''utilisateur'),
(32953, 1928, 9, 'Education'),
(32954, 1929, 9, 'Date Education'),
(32955, 1931, 9, 'Voir la Licence * GNU GPL pour plus de détails. * * Vous devriez avoir reçu une copie de la Licence Publique Générale GNU * avec ce programme, sinon, écrivez à Free '),
(32956, 1932, 9, 'Date d''effet'),
(32957, 1934, 9, 'Efficacité'),
(32958, 1935, 9, 'EIN'),
(32959, 1936, 9, 'Ejaculations'),
(32960, 1937, 9, 'Coude'),
(32961, 1938, 9, 'Problèmes de coude'),
(32962, 1939, 9, 'Electronique'),
(32963, 1944, 9, 'Admissibilité'),
(32964, 1946, 9, 'Réponse d''Admissibilité'),
(32965, 1948, 9, 'Admissible'),
(32966, 1949, 9, 'Courriel'),
(32967, 1951, 9, 'Courriel'),
(32968, 1953, 9, 'L''adresse de réponse pour les courriels de rappel envoyés aux patients. Les réponses des patientes à leur courriel de rappel seront envoyés à cette adresse. Il est important d''utiliser une adresse de réponse qui fait partie du domaine de votre clinique afin d''empêcher que les réponses de vos patients ne sont retrouvent classées parmi les pourriels.'),
(32969, 1954, 9, 'Courriel, si disponible, pour recevoir les messages administratifs.'),
(32970, 1955, 9, 'Courriel, si disponible, pour recevoir l''activation d''urgence des login des usagers'),
(32971, 1982, 9, 'Emphysème'),
(32972, 1983, 9, 'Employé(e)'),
(32973, 1984, 9, 'Employeur'),
(32974, 1985, 9, 'Adresse de l''employeur'),
(32975, 1986, 9, 'Information sur l''employeur'),
(32976, 1987, 9, 'Nom de l''employeur'),
(32977, 1988, 9, 'VIDE'),
(32978, 1989, 9, 'vide'),
(32979, 1991, 9, 'Aucune données pour "Horaire de courriel"'),
(32980, 1992, 9, 'Aucune entrée pour "Expéditeur du courrier"'),
(32981, 1993, 9, 'Aucune entrée pour "Sujet du courrier"'),
(32982, 1994, 9, 'Aucune entrée pour "Texte du courrier"'),
(32983, 1995, 9, 'Aucune entrée pour "Nom du dispensateur"'),
(32984, 1996, 9, 'Aucune entrée pour "Mot de passe"'),
(32985, 1997, 9, 'Aucune entrée pour "Expéditeur du courrier"'),
(32986, 1998, 9, 'Aucune entrée pour "Texto"'),
(32987, 1999, 9, 'Aucune entrée pour "Nom d''usager'),
(32988, 2016, 9, 'Activer le client SSL'),
(32989, 2017, 9, 'Activer la validation des certificats de client SSL'),
(32990, 2019, 9, 'Activer les Règles de Choix Cliniques (RCC)'),
(32991, 2022, 9, 'Création des rapports de Critères de Qualité Clinique (CQC)'),
(32992, 2027, 9, 'Création des rapports de Mesure de Qualité Clinique (CQC)'),
(32993, 2051, 9, 'Activer l''accès à distance au portail patient'),
(32994, 2052, 9, 'Activer l''accès à distance au portail patient.'),
(32995, 2053, 9, 'Activer l''accès local au portail patient'),
(32996, 2055, 9, 'Activer l''accès local au portail patient.'),
(32997, 2056, 9, 'Activer le widget de rappel patient'),
(32998, 2072, 9, 'Rencontre'),
(32999, 2073, 9, 'Rencontre'),
(33000, 2074, 9, 'rencontre'),
(33001, 2075, 9, 'Rencontre '),
(33002, 2081, 9, 'Date Rencontre'),
(33003, 2086, 9, 'Formulaires Rencontre'),
(33004, 2089, 9, 'N° Rencontre'),
(33005, 2091, 9, 'Numéro Rencontre'),
(33006, 2111, 9, 'Rencontre:'),
(33007, 2113, 9, 'Rencontres'),
(33008, 2121, 9, 'Fin'),
(33009, 2122, 9, 'Fin (aaaa-mm-jj): '),
(33010, 2123, 9, 'Date Fin'),
(33011, 2124, 9, 'Date fin'),
(33012, 2126, 9, 'Date fin doit être supérieur à date début'),
(33013, 2127, 9, 'Date Fin:'),
(33014, 2131, 9, 'Heure Fin'),
(33015, 2133, 9, 'Date de fin de service aaaa-mm-jj'),
(33016, 2135, 9, 'Heure fin de journée pour les événements du calendrier.'),
(33017, 2136, 9, 'Sang endocrinien anormal'),
(33018, 2137, 9, 'Endocrine'),
(33019, 2138, 9, 'Endoscopie'),
(33020, 2141, 9, 'Anglais'),
(33021, 2142, 9, 'Anglais '),
(33022, 2143, 9, 'Anglais (Indien)'),
(33023, 2144, 9, 'Anglais (Standard)'),
(33024, 2145, 9, 'Commande Enscript utilisé par Hylafax.'),
(33025, 2146, 9, 'Vérifier que LibreEHR a les privilèges d''écriture dans le répertoire'),
(33026, 2154, 9, 'Entrer le diagnostic'),
(33027, 2155, 9, 'Entrer la liste des médicaments'),
(33028, 2158, 9, 'Entrer les vaccinations'),
(33029, 2176, 9, 'Épilepsie'),
(33030, 2181, 9, 'Effacer'),
(33031, 2182, 9, 'Érections'),
(33032, 2183, 9, 'Erreur'),
(33033, 2185, 9, 'L''accusé réception des résulats de laboratoire a généré une erreur'),
(33034, 2253, 9, 'Évènement'),
(33035, 2273, 9, 'chaque/toutes'),
(33036, 2274, 9, 'Chaque/Toutes'),
(33037, 2275, 9, 'toutes les 3 heures'),
(33038, 2276, 9, 'toutes les 4 heures'),
(33039, 2277, 9, 'toutes les 5 heures'),
(33040, 2278, 9, 'toutes les 6 heures'),
(33041, 2279, 9, 'toutes les 8 heures'),
(33042, 2280, 9, 'Toutes les quatrième'),
(33043, 2281, 9, 'Toutes Autres'),
(33044, 2282, 9, 'Tous les troisièmes'),
(33045, 2286, 9, 'Résultats d''examen'),
(33046, 2291, 9, 'Example'),
(33047, 2292, 9, 'Examples'),
(33048, 2306, 9, 'Aggrandir'),
(33049, 2307, 9, 'aggrandir'),
(33050, 2308, 9, 'Tout aggrandir'),
(33051, 2404, 9, 'Fax/Télécopie'),
(33052, 2405, 9, 'Nombre Fax'),
(33053, 2406, 9, 'Numéro FAX'),
(33054, 2412, 9, 'févr.'),
(33055, 2413, 9, 'Février'),
(33056, 2418, 9, 'Frais'),
(33057, 2419, 9, 'frais'),
(33058, 2420, 9, 'Frais non autorisés'),
(33059, 2421, 9, 'Note de Frais'),
(33060, 2422, 9, 'Options Note de Frais'),
(33061, 2423, 9, 'Frais'),
(33062, 2424, 9, 'Féminin'),
(33063, 2426, 9, 'Préservatifs Féminins'),
(33064, 2427, 9, 'Point G'),
(33065, 2430, 9, 'Symptômes Féminin'),
(33066, 2434, 9, 'Fièvre'),
(33067, 2435, 9, 'Fièvre:'),
(33068, 2436, 9, 'Problèmes sanguins FH'),
(33069, 2437, 9, 'Fibromes'),
(33070, 2447, 9, 'Fichier'),
(33071, 2450, 9, 'Gestion de Fichiers'),
(33072, 2459, 9, 'Nom Fichier'),
(33073, 2461, 9, 'Fichiers'),
(33074, 2462, 9, 'Philippin'),
(33075, 2463, 9, 'Remplissez une des ligne en dessous.'),
(33076, 2464, 9, 'Remplissez ici que si la notification est envoyé par email aux patients'),
(33077, 2465, 9, 'Complétez les valeurs ci-dessous'),
(33078, 2467, 9, 'Remplissez la ligne.'),
(33079, 2468, 9, 'Filter'),
(33080, 2469, 9, 'Filtre pour les constantes'),
(33081, 2470, 9, 'Filtre pour les définitions'),
(33082, 2473, 9, 'Filtres'),
(33083, 2474, 9, 'Final'),
(33084, 2475, 9, 'Diagnostic final'),
(33085, 2476, 9, 'Le diagnostic final par un spécialiste'),
(33086, 2478, 9, 'Financier'),
(33087, 2479, 9, 'Date de clôture financière (aaaa-mm-jj)'),
(33088, 2480, 9, 'Report Financier - tout'),
(33089, 2481, 9, 'Report Financier - mes visites'),
(33090, 2482, 9, 'Date de révision financière'),
(33091, 2484, 9, 'Trouver'),
(33092, 2485, 9, 'Trouver Disponible'),
(33093, 2486, 9, 'Trouver rendez-vous disponible'),
(33094, 2487, 9, 'Trouver un patient'),
(33095, 2488, 9, 'Trouver éducation des patients'),
(33096, 2489, 9, 'Résultats'),
(33097, 2490, 9, 'Les résultats par un spécialiste'),
(33098, 2491, 9, 'Bien'),
(33099, 2492, 9, 'Finition des Paiements'),
(33100, 2495, 9, 'Premier'),
(33101, 2497, 9, 'Premier jour de la semaine'),
(33102, 2498, 9, 'Prénom'),
(33103, 2499, 9, 'Prénom'),
(33104, 2500, 9, 'Prénom:'),
(33105, 2503, 9, 'Fitness'),
(33106, 2504, 9, 'Niveau de Fitness'),
(33107, 2505, 9, 'La condition physique pour ce joueur cette journée'),
(33108, 2507, 9, 'Fitness à jouer'),
(33109, 2508, 9, 'Fix rencontre dates - toutes les rencontres'),
(33110, 2509, 9, 'corriger ce'),
(33111, 2511, 9, 'flatulence'),
(33112, 2512, 9, 'Débit'),
(33113, 2514, 9, 'Saison grippale'),
(33114, 2515, 9, 'Saison grippale'),
(33115, 2516, 9, 'Vaccination contre la grippe'),
(33116, 2517, 9, 'Fluide et problème d''électrolytes'),
(33117, 2520, 9, 'Suivez manuellement'),
(33118, 2522, 9, 'Suivi'),
(33119, 2524, 9, 'Raison de Suivi'),
(33120, 2525, 9, 'Voici une nouvelle constante personnalisée:'),
(33121, 2526, 9, 'Voici un nouveau langage personnalisé:'),
(33122, 2527, 9, 'Voici une nouvelle définition (Langue, Constant, Définition):'),
(33123, 2529, 9, 'Services de suivi'),
(33124, 2530, 9, 'Suivis indiqués'),
(33125, 2531, 9, 'Intolérance alimentaire'),
(33126, 2532, 9, 'Pied'),
(33127, 2533, 9, 'Problèmes de pied'),
(33128, 2534, 9, 'Pied:'),
(33129, 2535, 9, 'Blessures de football'),
(33130, 2537, 9, 'Rapport de blessure de football'),
(33131, 2538, 9, 'Type de chaussures'),
(33132, 2539, 9, 'pour'),
(33133, 2540, 9, 'Pour'),
(33134, 2541, 9, 'Pour le code'),
(33135, 2543, 9, 'Pour les réclamations Rencontre'),
(33136, 2544, 9, 'Par exemple:'),
(33137, 2547, 9, 'pour la facturation'),
(33138, 2553, 9, 'Pour le passé'),
(33139, 2554, 9, 'pour la variable'),
(33140, 2555, 9, 'pour:'),
(33141, 2559, 9, 'Avant-bras'),
(33142, 2560, 9, 'Formulaire'),
(33143, 2561, 9, 'formulaire'),
(33144, 2564, 9, 'Format'),
(33145, 2565, 9, 'format'),
(33146, 2567, 9, 'Format incorrect pour NDC'),
(33147, 2568, 9, 'Format utilisé pour afficher les dates.'),
(33148, 2569, 9, 'Format utilisé pour afficher le temps.'),
(33149, 2570, 9, 'Rapport formaté'),
(33150, 2571, 9, 'Ancien fumeur'),
(33151, 2572, 9, 'Formulaires'),
(33152, 2573, 9, 'Formulaires d''administration'),
(33153, 2576, 9, 'Envoi Pages par fax'),
(33154, 2577, 9, 'Transmis'),
(33155, 2579, 9, 'Quatrième'),
(33156, 2581, 9, 'Fracture'),
(33157, 2587, 9, 'Français'),
(33158, 2590, 9, 'Fréquence'),
(33159, 2591, 9, 'Rhumes fréquents'),
(33160, 2592, 9, 'Maladie fréquente'),
(33161, 2593, 9, 'Ven.'),
(33162, 2594, 9, 'Vendredi'),
(33163, 2595, 9, 'De'),
(33164, 2596, 9, 'DE'),
(33165, 2597, 9, 'de'),
(33166, 2598, 9, 'Date De ne peut être supérieur à Date A.'),
(33167, 2599, 9, 'De :'),
(33168, 2600, 9, 'De : '),
(33169, 2619, 9, 'Nom Complet'),
(33170, 2626, 9, 'Soldé'),
(33171, 2638, 9, 'Période du jeu'),
(33172, 2639, 9, 'Jeux'),
(33173, 2640, 9, 'Jeux manqués'),
(33174, 2641, 9, 'jeux / événements'),
(33175, 2642, 9, 'Jeux / Evénements manqués'),
(33176, 2644, 9, 'Gastrite'),
(33177, 2646, 9, 'Gastrointestinal'),
(33178, 2650, 9, 'Genre'),
(33179, 2651, 9, 'Genre '),
(33180, 2652, 9, 'Général'),
(33181, 2687, 9, 'Allemand'),
(33182, 2692, 9, 'Glaucome'),
(33183, 2700, 9, 'aller'),
(33184, 2701, 9, 'Aller'),
(33185, 2704, 9, 'Aller à'),
(33186, 2705, 9, 'Aller à la semaine du'),
(33187, 2706, 9, 'Aujourd''hui'),
(33188, 2711, 9, 'Degré de traumatismes'),
(33189, 2712, 9, 'Grade:'),
(33190, 2713, 9, 'grammes'),
(33191, 2714, 9, 'Total général'),
(33192, 2715, 9, 'Totaux généraux'),
(33193, 2720, 9, 'Supérieur à'),
(33194, 2721, 9, 'Supérieur ou égal à'),
(33195, 2722, 9, 'Grecque'),
(33196, 2724, 9, 'Groupe'),
(33197, 2725, 9, 'Nom du groupe'),
(33198, 2731, 9, 'Groupe:'),
(33199, 2736, 9, 'gouttes'),
(33200, 2794, 9, 'Hauteur'),
(33201, 2796, 9, 'Aide'),
(33202, 2797, 9, 'aide'),
(33203, 2798, 9, 'Hématémèse'),
(33204, 2799, 9, 'Rectorragie'),
(33205, 2800, 9, 'Hématologie'),
(33206, 2801, 9, 'Hématurie'),
(33207, 2802, 9, 'Hémoglobine'),
(33208, 2803, 9, 'Hémoglobine A1C'),
(33209, 2804, 9, 'Hémoptysie'),
(33210, 2805, 9, 'Hépatite'),
(33211, 2806, 9, 'Hépatite A 1'),
(33212, 2807, 9, 'Hépatite A 2'),
(33213, 2808, 9, 'Hépatite B 1'),
(33214, 2809, 9, 'Hépatite B 2'),
(33215, 2810, 9, 'Hépatite B 3'),
(33216, 2811, 9, 'ici'),
(33217, 2813, 9, 'Cure d''Hernie'),
(33218, 2814, 9, 'Hernie discale'),
(33219, 2815, 9, 'Herpès'),
(33220, 2816, 9, 'Hésitation'),
(33221, 2817, 9, 'heyyo. vous avez été ici pour '),
(33222, 2822, 9, 'Caché'),
(33223, 2823, 9, 'Evénements d''Administration masqués'),
(33224, 2824, 9, 'Cacher'),
(33225, 2825, 9, 'Masquer les détails'),
(33226, 2827, 9, 'Masquer l''option cryptage/décryptage dans la gestion documentaire'),
(33227, 2828, 9, 'Masquer les menus'),
(33228, 2831, 9, 'Afficher / Masquer les colonnes'),
(33229, 2833, 9, 'Elevé'),
(33230, 2834, 9, 'Hypertension artérielle'),
(33231, 2835, 9, 'Hindi'),
(33232, 2836, 9, 'La hanche + l''aine'),
(33233, 2837, 9, 'La hanche et l''aine'),
(33234, 2838, 9, 'Les problèmes de hanche'),
(33235, 2839, 9, 'Prothèse de la hanche'),
(33236, 2843, 9, 'Hispanique'),
(33237, 2844, 9, 'Hispanique - Autres (Né aux Etats-Unis)'),
(33238, 2845, 9, 'Hispanique - Autres (Né à l''extérieur des États-Unis)'),
(33239, 2846, 9, 'Hispanique ou Latino'),
(33240, 2847, 9, 'Histoire'),
(33241, 2848, 9, 'Historique des données'),
(33242, 2849, 9, 'Date de l''histoire'),
(33243, 2851, 9, 'Historique du Souffle'),
(33244, 2852, 9, 'Historique non autorisé'),
(33245, 2853, 9, 'Historique du souffle cardiaque'),
(33246, 2854, 9, 'visites (Clics)'),
(33247, 2855, 9, 'VIH'),
(33248, 2865, 9, 'Accueil'),
(33249, 2866, 9, 'Téléphone à domicile'),
(33250, 2867, 9, 'Numéro de téléphone a domicile'),
(33251, 2868, 9, 'Sans-abri ou similaires?'),
(33252, 2869, 9, 'Sans-abri, etc.'),
(33253, 2870, 9, 'Sans-abri, etc.'),
(33254, 2872, 9, 'Nom de l''hôte'),
(33255, 2873, 9, 'Nom de l''hôte ne peut pas être vide'),
(33256, 2875, 9, 'Heure'),
(33257, 2876, 9, 'Heures'),
(33258, 2878, 9, 'Comment vous êtes blessé?'),
(33259, 2879, 9, 'Comment vous êtes blessé?:'),
(33260, 2892, 9, 'Hyperactive'),
(33261, 2893, 9, 'Hypertension'),
(33262, 2894, 9, 'Hypertension: mesure de pression artérielle.'),
(33263, 2895, 9, 'Hypertension: mesure de pression artérielle (CQC).'),
(33264, 2896, 9, 'Hyperthyroïdie'),
(33265, 2897, 9, 'Hypothyroïdie'),
(33266, 2898, 9, 'Hystérectomie'),
(33267, 2899, 9, 'je'),
(33268, 2900, 9, 'Je suis occupé pendant ce temps.'),
(33269, 2901, 9, 'Je n''ai pas l''autorisation de lecture '),
(33270, 3230, 9, 'Italien'),
(33271, 3231, 9, 'Article'),
(33272, 3232, 9, 'article'),
(33273, 3234, 9, 'Chargement d''Articles a échoué'),
(33274, 3238, 9, 'janv.'),
(33275, 3239, 9, 'Janvier'),
(33276, 3240, 9, 'Japonais'),
(33277, 3241, 9, 'Jaunisse'),
(33278, 3243, 9, 'Description de la Tâche'),
(33279, 3244, 9, 'ID Tâche'),
(33280, 3245, 9, 'Dislocations conjointe'),
(33281, 3246, 9, 'Douleurs articulaires'),
(33282, 3247, 9, 'Entorses conjointe'),
(33283, 3248, 9, 'juil.'),
(33284, 3249, 9, 'Juillet'),
(33285, 3250, 9, 'juin'),
(33286, 3251, 9, 'Juin'),
(33287, 3520, 9, 'Déjeuner'),
(33288, 3521, 9, 'Déjeuner'),
(33289, 3522, 9, 'Cancer du Poummon'),
(33290, 3523, 9, 'Chirurgie du Cancer de poumon'),
(33291, 3524, 9, 'POUMMONS:'),
(33292, 3525, 9, 'Poummons:'),
(33293, 3545, 9, 'Malaise:'),
(33294, 3548, 9, 'Masculin'),
(33295, 3549, 9, 'Préservatifs Masculin'),
(33296, 3552, 9, 'Mammographie'),
(33297, 3553, 9, 'Gérer'),
(33298, 3556, 9, 'Gérer les traductions'),
(33299, 3557, 9, 'Gestion'),
(33300, 3558, 9, 'Les champs obligatoires et spécifiés'),
(33301, 3559, 9, 'Les champs obligatoires ou spécifié, contrôle de dup, pas de recherche'),
(33302, 3560, 9, 'Les champs obligatoires ou spécifié, recherche et contrôle de dup'),
(33303, 3561, 9, 'Manuel'),
(33304, 3562, 9, 'Postage Manuel'),
(33305, 3563, 9, 'Fabriquant'),
(33306, 3565, 9, 'mars'),
(33307, 3568, 9, 'Mars'),
(33308, 3569, 9, 'État civil'),
(33309, 3571, 9, 'Marquer comme facturés, mais la facturation est ignoré'),
(33310, 3572, 9, 'Marquer comme réglé'),
(33311, 3573, 9, 'Marquer comme non facturées'),
(33312, 3575, 9, 'Marquer comme réglé'),
(33313, 3576, 9, 'Marié'),
(33314, 3578, 9, 'Masque'),
(33315, 3579, 9, 'Masque pour les numéros de facturation'),
(33316, 3580, 9, 'Masque pour les ID Patient'),
(33317, 3581, 9, 'Masque pour les ID de produit'),
(33318, 3582, 9, 'Correspond'),
(33319, 3591, 9, 'Max'),
(33320, 3594, 9, 'Maxillaire droit:'),
(33321, 3595, 9, 'Age maximum'),
(33322, 3597, 9, 'Le temps maximum d''inactivité en secondes avant la déconnexion. Par défaut est 7200 (2 heures).'),
(33323, 3603, 9, 'Mai'),
(33324, 3611, 9, 'Mesure'),
(33325, 3612, 9, 'Malléole interne:'),
(33326, 3614, 9, 'Médicale'),
(33327, 3615, 9, 'Avortement médicamenteux'),
(33328, 3616, 9, 'Administration médicale'),
(33329, 3617, 9, 'Antécédents médicaux'),
(33330, 3618, 9, 'Problème médical'),
(33331, 3619, 9, 'Problème médical'),
(33332, 3620, 9, 'Problème médical'),
(33333, 3623, 9, 'Problèmes Médicaux'),
(33334, 3624, 9, 'Enregistrement Médical'),
(33335, 3625, 9, 'No Enregistrement Médical'),
(33336, 3626, 9, 'Enregistrements Médicaux'),
(33337, 3630, 9, 'Système Médical'),
(33338, 3635, 9, 'Médication'),
(33339, 3640, 9, 'Médications'),
(33340, 3641, 9, 'Médications:'),
(33341, 3642, 9, 'Unités Médicale'),
(33342, 3643, 9, 'Moyen'),
(33343, 3646, 9, 'Problèmes de Mémoire'),
(33344, 3647, 9, 'Homme'),
(33345, 3648, 9, 'Hommes et Femmes'),
(33346, 3649, 9, 'Hommes Seulement'),
(33347, 3650, 9, 'Ménarche'),
(33348, 3651, 9, 'Ménopause'),
(33349, 3652, 9, 'Flux Menstruel'),
(33350, 3653, 9, 'Fréquence Menstruel'),
(33351, 3654, 9, 'Maladie Mentale'),
(33352, 3666, 9, 'Etat du Message'),
(33353, 3673, 9, 'Méthode'),
(33354, 3674, 9, 'Méthode et Produit Spécifique'),
(33355, 3675, 9, 'Mode d''envoi e-mails sortants.'),
(33356, 3676, 9, 'Méthode de Destruction'),
(33357, 3686, 9, 'Moyen'),
(33358, 3687, 9, 'Deuxième Prénom'),
(33359, 3688, 9, 'Deuxième prénom'),
(33360, 3712, 9, 'Divers'),
(33361, 3713, 9, 'Autres Options de Facturation'),
(33362, 3714, 9, 'Autres Options de Facturation pour HCFA-1500'),
(33363, 3715, 9, 'Autres Options de Facturation HCFA'),
(33364, 3716, 9, 'Divers/Autres'),
(33365, 3717, 9, 'Manqué'),
(33366, 3719, 9, 'Manque d''un champ requis'),
(33367, 3720, 9, 'Frais Manquants'),
(33368, 3722, 9, 'Manquant ou Invalide'),
(33369, 3724, 9, 'Manque date de rapport'),
(33370, 3726, 9, 'Mixe'),
(33371, 3728, 9, 'MM/JJ/AAAA'),
(33372, 3741, 9, 'Modificateur'),
(33373, 3745, 9, 'Modifier les Paiements'),
(33374, 3753, 9, 'Lu.'),
(33375, 3754, 9, 'Lu. à Ve.'),
(33376, 3755, 9, 'Lu. Mer. &amp; Ve.'),
(33377, 3756, 9, 'Lundi'),
(33378, 3758, 9, 'Mois'),
(33379, 3759, 9, 'mois'),
(33380, 3760, 9, 'Vue du Mois'),
(33381, 3761, 9, 'Mois'),
(33382, 3762, 9, 'Revenue Mensuel'),
(33383, 3763, 9, 'Mois'),
(33384, 3771, 9, 'Mère'),
(33385, 3772, 9, 'Nom de la Mère'),
(33386, 3774, 9, 'Bouche'),
(33387, 3775, 9, 'Déplacer'),
(33388, 3776, 9, 'Déplacer un document vers Catégorie:'),
(33389, 3777, 9, 'Déplacer vers bas'),
(33390, 3779, 9, 'Déplacer vers le patient'),
(33391, 3780, 9, 'Déplacer vers ...'),
(33392, 3781, 9, 'Déplacer vers haut'),
(33393, 3783, 9, 'M.'),
(33394, 3785, 9, 'Mme.'),
(33395, 3786, 9, 'Mlle.'),
(33396, 3796, 9, 'Outil multi langues'),
(33397, 3797, 9, 'Zones multiples'),
(33398, 3799, 9, 'Plusieurs lots'),
(33399, 3802, 9, 'Multiracial'),
(33400, 3803, 9, 'Murmur:'),
(33401, 3804, 9, 'Douleurs musculaires'),
(33402, 3805, 9, 'Douleurs musculaires'),
(33403, 3806, 9, 'Rougeur musculaire'),
(33404, 3807, 9, 'Raideur musculaire'),
(33405, 3808, 9, 'Enflure musculaire'),
(33406, 3809, 9, 'Chaleur musculaire'),
(33407, 3810, 9, 'Muscle'),
(33408, 3811, 9, 'Lésion musculaire'),
(33409, 3812, 9, 'Musculo-squelettiques'),
(33410, 4251, 9, 'Groupement officiel des Critères de Qualité Clinique'),
(33411, 4252, 9, 'Lien Https pour l''accès à distance au portail patient'),
(33412, 4254, 9, 'Mot de passe pour l''accès à distance au portail patient'),
(33413, 4255, 9, 'Mot de passe pour l''accès à distance au portail patient (laisser le champs vide si vous n''êtes pas enregistré)'),
(33414, 4258, 9, 'Adresse pour l''accès à distance au portail patient'),
(33415, 4265, 9, 'Onguent'),
(33416, 4267, 9, 'Confirmer'),
(33417, 4277, 9, 'Omettre'),
(33418, 4387, 9, 'Organisation'),
(33419, 4388, 9, 'Nom de l''organisation'),
(33420, 4389, 9, 'Nom de l''unité organisationnelle'),
(33421, 4390, 9, 'Organisations'),
(33422, 4392, 9, 'Original'),
(33423, 4401, 9, 'Osthéopathie'),
(33424, 4402, 9, 'Autre'),
(33425, 4403, 9, 'autre'),
(33426, 4404, 9, 'Autre (préciser)'),
(33427, 4405, 9, 'Autre - Précisé'),
(33428, 4406, 9, 'Autre programme fédéral'),
(33429, 4427, 9, 'Résultat(s)'),
(33430, 4428, 9, 'Prognostic'),
(33431, 4429, 9, 'Type de prognostic'),
(33432, 4430, 9, 'État général au congé'),
(33433, 4434, 9, 'Sucharge pondérale'),
(33434, 4437, 9, 'Saturation d''O2'),
(33435, 4440, 9, 'pc'),
(33436, 4441, 9, 'pm'),
(33437, 4442, 9, 'prn'),
(33438, 4444, 9, 'Pédiatrique'),
(33439, 4445, 9, 'Page'),
(33440, 4446, 9, 'Pages'),
(33441, 4447, 9, 'Payé'),
(33442, 4450, 9, 'Payé avec'),
(33443, 4451, 9, 'Douleur'),
(33444, 4453, 9, 'Palpitation'),
(33445, 4455, 9, 'Test de Pap'),
(33446, 4458, 9, 'Paralysie'),
(33447, 4472, 9, 'Mot de passe'),
(33448, 4473, 9, 'Modification de mot de passe'),
(33449, 4475, 9, 'Mot de passe modifié'),
(33450, 4486, 9, 'Mot de passe:'),
(33451, 4514, 9, 'Patient'),
(33452, 4515, 9, 'patient'),
(33453, 4516, 9, 'PATIENT'),
(33454, 4521, 9, 'Allergie'),
(33455, 4522, 9, 'Allergie'),
(33456, 4528, 9, 'Numéro de dossier'),
(33457, 5207, 9, 'Panjabi'),
(33458, 5208, 9, 'Achat'),
(33459, 5209, 9, 'Achat / Retour'),
(33460, 5210, 9, 'Achats'),
(33461, 5222, 9, 'Qté.'),
(33462, 5223, 9, 'Qté.'),
(33463, 5224, 9, 'Qualité'),
(33464, 5225, 9, 'Critères de Qualité (CQ)'),
(33465, 5226, 9, 'Quantité'),
(33466, 5228, 9, 'Quantité disponible'),
(33467, 5317, 9, 'Enregistrements'),
(33468, 5318, 9, 'enregistrements trouvés'),
(33469, 5319, 9, 'enregistrements trouvés.'),
(33470, 5322, 9, 'Rectale'),
(33471, 5323, 9, 'Examen Rectal'),
(33472, 5324, 9, 'Voie Rectale'),
(33473, 5326, 9, 'Rougeurs'),
(33474, 5812, 9, 'sept.'),
(33475, 5813, 9, 'Séparé'),
(33476, 5814, 9, 'Septembre'),
(33477, 5815, 9, 'Séq.'),
(33478, 5816, 9, 'Séquence'),
(33479, 5821, 9, 'Service'),
(33480, 5822, 9, 'Catégorie de service'),
(33481, 5823, 9, 'Code de service'),
(33482, 5825, 9, 'Codes service'),
(33483, 5826, 9, 'Date de service'),
(33484, 5827, 9, 'Date de service:'),
(33485, 5829, 9, 'Emplacement du service'),
(33486, 5831, 9, 'Service fourni par un spécialiste'),
(33487, 5834, 9, 'Services'),
(33488, 5835, 9, 'Services par Catégorie'),
(33489, 5836, 9, 'Services fournis'),
(33490, 5837, 9, 'Services fournis'),
(33491, 5838, 9, 'Produits/Services'),
(33492, 5839, 9, 'Type de Service'),
(33493, 5849, 9, 'Réglages'),
(33494, 5851, 9, 'Migraine sévère'),
(33495, 5853, 9, 'Intensité de la douleur'),
(33496, 5854, 9, 'Intensité de la douleur:'),
(33497, 5855, 9, 'Sexe'),
(33498, 5856, 9, 'Maladies sexuellement transmissibles'),
(33499, 6062, 9, 'Espagnol'),
(33500, 6068, 9, 'Spécialiste'),
(33501, 6069, 9, 'Nom et signature du Spécialiste'),
(33502, 6071, 9, 'Spécialité'),
(33503, 6072, 9, 'Systèmes spécialisés'),
(33504, 6073, 9, 'Spécialité:'),
(33505, 6074, 9, 'Spécifique'),
(33506, 6075, 9, 'Spplication spécifique'),
(33507, 6076, 9, 'Service de contraception spécifique'),
(33508, 6077, 9, 'Résultat spécifique'),
(33509, 6078, 9, 'Service spécifique'),
(33510, 6079, 9, 'Spécifiée'),
(33511, 6088, 9, 'Spécimen'),
(33512, 6089, 9, 'Numéro du spécimen/identifiant'),
(33513, 6090, 9, 'Type de spécimen'),
(33514, 6092, 9, 'Dictée vocale'),
(33515, 6093, 9, 'Spermicides'),
(33516, 6094, 9, 'Splénectomie'),
(33517, 6095, 9, 'Conjoint'),
(33518, 6097, 9, 'Crachat'),
(33519, 6098, 9, 'Crachat:'),
(33520, 6102, 9, 'Equipe'),
(33521, 6103, 9, 'Membres déquipe'),
(33522, 6104, 9, 'Equipes'),
(33523, 6114, 9, 'Stabilité'),
(33524, 6116, 9, 'Standard'),
(33525, 6117, 9, 'Code standard'),
(33526, 6118, 9, 'Mesures standard'),
(33527, 6122, 9, 'Nom standard'),
(33528, 6124, 9, 'Début'),
(33529, 6125, 9, 'Début (aaaa-mm-jj): '),
(33530, 6128, 9, 'Date de début'),
(33531, 6129, 9, 'Date de début dans cette clinique'),
(33532, 6130, 9, 'Date de début ne doit pas être supérieur Date de fin'),
(33533, 6131, 9, 'Date de début:'),
(33534, 6132, 9, 'Date de début:'),
(33535, 6133, 9, 'Heure de début'),
(33536, 6134, 9, 'Date de démarrage'),
(33537, 6693, 9, 'A:'),
(33538, 6694, 9, 'A: '),
(33539, 6709, 9, 'Intervention en abandon du tabagisme'),
(33540, 6710, 9, 'Intervention en abandon du tabagisme (CQC)'),
(33541, 6712, 9, 'Tabagisme'),
(33542, 6713, 9, 'Questionnaire sur tabagisme'),
(33543, 6714, 9, 'Questionnaire sur tabagisme (CQC)'),
(33544, 6814, 9, 'Traduction'),
(33545, 6815, 9, 'Traductions'),
(33546, 6816, 9, 'Transmettre'),
(33547, 6817, 9, 'Échec de la transmission'),
(33548, 6818, 9, 'Transmettre les requêtes sélectionnées'),
(33549, 6819, 9, 'Traumatologie'),
(33550, 6820, 9, 'Traitement'),
(33551, 6822, 9, 'Objectifs du traitement'),
(33552, 6823, 9, 'Plan de traitement'),
(33553, 6824, 9, 'Planification du traitement');
INSERT INTO `lang_definitions` VALUES
(33554, 6825, 9, 'Traitement reçu'),
(33555, 6826, 9, 'Traitement:'),
(33556, 6827, 9, 'Traitement: '),
(33557, 6828, 9, 'Tendance'),
(33558, 6831, 9, 'Tri-malléolaire'),
(33559, 6832, 9, 'Thorax et abdomen'),
(33560, 6840, 9, 'Tuberculose'),
(33561, 6841, 9, 'Mar.'),
(33562, 6842, 9, 'Mar. &amp; Jeu.'),
(33563, 6843, 9, 'Mardi'),
(33564, 6844, 9, 'Tumeur'),
(33565, 6845, 9, 'Turque'),
(33566, 6848, 9, 'deux fois par jour'),
(33567, 6850, 9, 'Tympan'),
(33568, 6851, 9, 'Type'),
(33569, 6856, 9, 'Configuration de l''écran'),
(33570, 6857, 9, 'Saisir ou lire l''identifiant du patient ici'),
(33571, 6858, 9, 'Saisir votre message ici'),
(33572, 6859, 9, 'Types d''ordonnances et résultats'),
(33573, 6866, 9, 'ulcérations'),
(33574, 6867, 9, 'Colite Ulcéreuse'),
(33575, 6868, 9, 'Ulcères:'),
(33576, 6871, 9, 'Création Impossible'),
(33577, 6876, 9, 'Non Appliquée'),
(33578, 6877, 9, 'Non Attribué'),
(33579, 6878, 9, 'Non autorisé'),
(33580, 6879, 9, 'Accès non autorisé à ePrescription'),
(33581, 6880, 9, 'Accès non autorisé.'),
(33582, 6881, 9, 'Non-facturé'),
(33583, 6882, 9, 'Uniquement Les non Facturés'),
(33584, 6884, 9, 'sous la langue'),
(33585, 6885, 9, 'Insuffisance Pondérale'),
(33586, 6886, 9, 'Non Diagnostiqué'),
(33587, 6887, 9, 'NON RÉPARTI'),
(33588, 6888, 9, 'NON RÉPARTI'),
(33589, 6889, 9, 'non réparti est'),
(33590, 6890, 9, 'Annuler la Vérification'),
(33591, 6892, 9, 'Clients Unique'),
(33592, 6893, 9, 'Identifiant lisible Unique pour ce type'),
(33593, 6894, 9, 'Nouveau Client Unique'),
(33594, 6895, 9, 'Identificateur numérique unique pour ce type'),
(33595, 6896, 9, 'Patients Vu Unique'),
(33596, 6897, 9, 'Rapport de Patients Vu Unique'),
(33597, 6898, 9, 'SP Unique'),
(33598, 6899, 9, 'Unité'),
(33599, 6900, 9, 'Unités'),
(33600, 6901, 9, 'unités'),
(33601, 6903, 9, 'Unités pour les Formulaire de Visite'),
(33602, 6904, 9, 'Les unités doivent être un nombre'),
(33603, 6905, 9, 'Unités Indéfinies'),
(33604, 6906, 9, 'Unités / L'),
(33605, 6907, 9, 'Inconnu'),
(33606, 6910, 9, 'Inconnu si déjà fumé'),
(33607, 6911, 9, 'Inconnu ou N/A'),
(33608, 6913, 9, 'Disjoindre patient'),
(33609, 6914, 9, 'AMO sans Nom'),
(33610, 6915, 9, 'non inscrit'),
(33611, 6918, 9, 'Tout dé-sélectionner'),
(33612, 6919, 9, 'non sélectionnés'),
(33613, 6920, 9, 'Non spécifié'),
(33614, 6921, 9, 'non structuré'),
(33615, 6922, 9, 'Fichier de chargement de base de données NON-SUPPORTÉ'),
(33616, 6924, 9, 'jusqu''à ce'),
(33617, 6925, 9, 'le dépôt intempestif'),
(33618, 6926, 9, 'Inutilisé'),
(33619, 6928, 9, 'Jusqu''à'),
(33620, 6929, 9, 'Prochains Rendez-vous'),
(33621, 6930, 9, 'Événements à venir'),
(33622, 6931, 9, 'Mise à jour'),
(33623, 6932, 9, 'mise à jour'),
(33624, 6933, 9, 'Mise à jour Actif'),
(33625, 6934, 9, 'Mise à jour de fichiers'),
(33626, 6935, 9, 'Info de Mise à Jour'),
(33627, 6936, 9, 'Liste de Mise à jour'),
(33628, 6937, 9, 'Mettre à jour le Numéro de fournisseur'),
(33629, 6938, 9, 'Mettre à jour les éléments sélectionnés'),
(33630, 6939, 9, 'Mettre à jour les variables suivantes dans le fichier'),
(33631, 6940, 9, 'Mettre à jour les données utilisateur'),
(33632, 6942, 9, 'Mise à jour des données démographiques n''est pas autorisée.'),
(33633, 6943, 9, 'Mettre à niveau les valeurs initiales des paramètres globaux'),
(33634, 6944, 9, 'Mettre à niveau les indicateurs de version'),
(33635, 6945, 9, 'MISE À NIVEAU'),
(33636, 6946, 9, 'Mise à niveau'),
(33637, 6947, 9, 'Mise à niveau de Base de Données'),
(33638, 6948, 9, 'Mises à niveau la base de données LibreEHR afin d''inclure les Procédures, Fonctions et tables nécessaires au processus de De-identification'),
(33639, 6949, 9, 'Mise à niveau va continuer'),
(33640, 6951, 9, 'Transférer'),
(33641, 6954, 9, 'Transférer les données de configuration'),
(33642, 6955, 9, 'Transférer le Document'),
(33643, 6956, 9, 'Échec du transfert!'),
(33644, 6957, 9, 'Transférer l''image à'),
(33645, 6958, 9, 'Transférer le fichier d''import :'),
(33646, 6961, 9, 'Transférer le Rapport'),
(33647, 6963, 9, 'Transférer ce fichier:'),
(33648, 6966, 9, 'Haut du bras'),
(33649, 6968, 9, 'Urgence'),
(33650, 6970, 9, 'Urine'),
(33651, 6971, 9, 'Miction Goutte à Goutte'),
(33652, 6972, 9, 'Fréquence des Mictions'),
(33653, 6973, 9, 'Hésitation d''Urine'),
(33654, 6974, 9, 'Microalbumine urinaire'),
(33655, 6975, 9, 'Jet d''Urine'),
(33656, 6976, 9, 'Urgence urinaire'),
(33657, 6977, 9, 'URL'),
(33658, 6979, 9, 'URL pour le support LibreEHR.'),
(33659, 6981, 9, 'URL pour la passerelle téléphonique. Service automatisé VOIP offert par Maviq. Veuillez visitez http://signup.maviq.com pour plus d''informations.'),
(33660, 6986, 9, 'Indicateur d''Utilisation (ISA15)'),
(33661, 6987, 9, 'Utiliser % seul dans un champ afin de trier uniquement sur cette colonne'),
(33662, 6988, 9, 'Utiliser le format 24 heures?'),
(33663, 6990, 9, 'Utiliser la technologie certifiée DSE pour identifier des ressources d''éducation spécifique à chaque patient et de fournir les ressources nécessaires pour le patient, le cas échéant.'),
(33664, 6991, 9, 'Utilisez le Panel des Frais'),
(33665, 6992, 9, 'Utilisez CPOE pour les commandes de médication entrés directement par tout professionnel de santé agréé qui peut entrer des commandes dans le dossier médical par Etat, directives locales et professionnelles.'),
(33666, 6997, 9, 'Utiliser la liste de vaccination personnalisée'),
(33667, 6999, 9, 'Utiliser Intervalle de dates'),
(33668, 7000, 9, 'Utiliser les Valeurs par Défaut'),
(33669, 7001, 9, 'Utilisez l''Option Supprimer pour le Retirer.'),
(33670, 7002, 9, 'Utilisez le style de date international?'),
(33671, 7003, 9, 'Utiliser le nom du fichier source'),
(33672, 7004, 9, 'Utilisez le champs ci-dessous pour un achat ou un transfert.'),
(33673, 7005, 9, 'Utilisez cette fonction uniquement avec des sites nouvellement installés, '),
(33674, 7006, 9, 'Utilisez les sujets?'),
(33675, 7007, 9, 'Utilisateur'),
(33676, 7009, 9, 'Utilisateur / Groupes'),
(33677, 7010, 9, 'Administration des Utilisateurs'),
(33678, 7011, 9, 'Administration des Utilisateurs et Services'),
(33679, 7012, 9, 'Administration des Utilisateurs et Groupe'),
(33680, 7014, 9, 'Certificat d''Authentification Utilisateur est désactivé'),
(33681, 7015, 9, 'Défini par l''Utilisateur'),
(33682, 7016, 9, 'Défini par l''Utilisateur Zone 11'),
(33683, 7017, 9, 'Défini par l''Utilisateur Zone 12'),
(33684, 7018, 9, 'Défini par l''Utilisateur Champ'),
(33685, 7019, 9, 'Défini par l''Utilisateur Liste 1'),
(33686, 7020, 9, 'Défini par l''Utilisateur Liste 2'),
(33687, 7021, 9, 'Défini par l''Utilisateur Liste 3'),
(33688, 7022, 9, 'Défini par l''Utilisateur Liste 4'),
(33689, 7023, 9, 'Défini par l''Utilisateur Liste 5'),
(33690, 7024, 9, 'Défini par l''Utilisateur Liste 6'),
(33691, 7025, 9, 'Défini par l''Utilisateur Liste 7'),
(33692, 7026, 9, 'Défini par l''Utilisateur Texte 1'),
(33693, 7027, 9, 'Défini par l''Utilisateur Texte 2'),
(33694, 7028, 9, 'Défini par l''Utilisateur Texte 3'),
(33695, 7029, 9, 'Défini par l''Utilisateur Texte 4'),
(33696, 7030, 9, 'Défini par l''Utilisateur Texte 5'),
(33697, 7031, 9, 'Défini par l''Utilisateur Texte 6'),
(33698, 7032, 9, 'Défini par l''Utilisateur Texte 7'),
(33699, 7033, 9, 'Défini par l''Utilisateur Texte 8'),
(33700, 7034, 9, 'Prénom utilisateur'),
(33701, 7039, 9, 'Manuel Utilisateur'),
(33702, 7040, 9, 'Affiliations d''Utilisateur'),
(33703, 7041, 9, 'Nom Utilisateur'),
(33704, 7042, 9, 'Nom d''Utilisateur ou le nom d''Hôte ne peut pas être vide'),
(33705, 7043, 9, 'Utilisateur ou nom d''Hôte'),
(33706, 7046, 9, 'Paramètres Utilisateur'),
(33707, 7047, 9, 'Paramètre Utilisateur Spécifique'),
(33708, 7049, 9, 'Nom Utilisateur'),
(33709, 7051, 9, 'Nom utilisateur pour la passerelle téléphonique. Service automatisé VOIP offert par Maviq. Veuillez visitez http://signup.maviq.com pour plus d''informations.'),
(33710, 7052, 9, 'Nom Utilisateur pour la Passerelle SMS'),
(33711, 7053, 9, 'Nom Utilisateur pour la Passerelle SMS.'),
(33712, 7055, 9, 'Nom Utilisateur:'),
(33713, 7056, 9, 'Utilisateurs'),
(33714, 7057, 9, 'Utilisateurs/Groupes/Journaux d''Administration'),
(33715, 7058, 9, 'Utilise le format php <a href="http://php.net/strftime">strftime</a>'),
(33716, 7059, 9, 'Infections Urinaires'),
(33717, 7062, 9, 'Vacances'),
(33718, 7063, 9, 'Vacances'),
(33719, 7064, 9, 'vaccin'),
(33720, 7065, 9, 'Anneau Vaginal'),
(33721, 7066, 9, 'Discours d''adieu'),
(33722, 7067, 9, 'valider'),
(33723, 7068, 9, 'Valeur'),
(33724, 7069, 9, 'Valeur 1'),
(33725, 7070, 9, 'Valeur 2'),
(33726, 7072, 9, 'La Valeur doit être numérique'),
(33727, 7073, 9, 'Var1'),
(33728, 7074, 9, 'Var2'),
(33729, 7076, 9, 'Varicelle 1'),
(33730, 7077, 9, 'Varicelle 2'),
(33731, 7078, 9, 'Varices'),
(33732, 7079, 9, 'Etat vasculaire'),
(33733, 7080, 9, 'Lésion vasculaire'),
(33734, 7081, 9, 'Chirurgie Vasculaire'),
(33735, 7083, 9, 'Vendeur'),
(33736, 7084, 9, 'Version'),
(33737, 7085, 9, 'Vertige'),
(33738, 7086, 9, 'Ministère des anciens combattants'),
(33739, 7087, 9, 'Régime des anciens combattants'),
(33740, 7089, 9, 'Vietnamien'),
(33741, 7090, 9, 'vue'),
(33742, 7091, 9, 'Vue'),
(33743, 7092, 9, 'Afficher les Allergies'),
(33744, 7097, 9, 'Afficher le rapport globale du patient'),
(33745, 7100, 9, 'Afficher le document'),
(33746, 7101, 9, 'Afficher la visite'),
(33747, 7103, 9, 'Afficher les événements dans une fenêtre popup?'),
(33748, 7108, 9, 'Afficher la Page 1'),
(33749, 7109, 9, 'Afficher la Page 2'),
(33750, 7111, 9, 'Afficher le Patient'),
(33751, 7116, 9, 'Afficher les visites liées'),
(33752, 7121, 9, 'Afficher/Editer les Allergies'),
(33753, 7122, 9, 'Afficher/Editer problème'),
(33754, 7123, 9, 'Afficher/Imprimer'),
(33755, 7124, 9, 'Vue:'),
(33756, 7125, 9, 'VISA'),
(33757, 7127, 9, 'Dommages/Traumatisme/Chirurgie Viscérale'),
(33758, 7133, 9, 'Catégorie la Visite:'),
(33759, 7134, 9, 'Date Visite'),
(33760, 7137, 9, 'Formulaires de Visite'),
(33761, 7138, 9, 'Historique des Visites'),
(33762, 7140, 9, 'Visites'),
(33763, 7141, 9, 'Visites depuis'),
(33764, 7142, 9, 'Signes vitaux'),
(33765, 7143, 9, 'Vitaux'),
(33766, 7144, 9, 'Signes vitaux (métrique)'),
(33767, 7146, 9, 'Voix'),
(33768, 7147, 9, 'Voix transmise'),
(33769, 7149, 9, 'Vomissements'),
(33770, 7152, 9, 'Tour de taille'),
(33771, 7153, 9, 'Tour de taille'),
(33772, 7154, 9, 'En attente'),
(33773, 7158, 9, 'Entrepôt'),
(33774, 7161, 9, 'Entrepôts'),
(33775, 7162, 9, 'Chaud'),
(33776, 7163, 9, 'Attention'),
(33777, 7164, 9, 'ATTENTION'),
(33778, 7166, 9, 'Attention, Numéro de Chèque existe déjà dans la base de données'),
(33779, 7168, 9, 'Attention: Une visite est déjà créé pour ce patient aujourd''hui!'),
(33780, 7170, 9, 'Attention: l''ID du Patient n''est pas unique!'),
(33781, 7171, 9, 'AVERISSEMENT: Cette action va remplacer les données de la configuration par ceux du fichier téléchargé!'),
(33782, 7173, 9, 'Avertissements'),
(33783, 7175, 9, 'déjà transféré'),
(33784, 7177, 9, 'Nous apprécions le paiement rapide des soldes exigibles'),
(33785, 7178, 9, 'nous avons vu votre patient, référencé ci-dessus, pour l''évaluation et le traitement dans notre clinique de psychiatrie ambulatoire. Je vous remercie de cette saisine.'),
(33786, 7179, 9, 'Faiblesses'),
(33787, 7181, 9, 'Recherche Web'),
(33788, 7182, 9, 'Site Web'),
(33789, 7184, 9, 'mer.'),
(33790, 7185, 9, 'Mercredi'),
(33791, 7186, 9, 'Semaine'),
(33792, 7187, 9, 'semaine'),
(33793, 7188, 9, 'Vue Hebdomadaire'),
(33794, 7189, 9, 'Semaine(s)'),
(33795, 7190, 9, 'Expositions Hebdomadaire'),
(33796, 7192, 9, 'Semaines'),
(33797, 7193, 9, 'Poids'),
(33798, 7194, 9, 'Évaluation du poids et de conseils aux enfants et les adolescents'),
(33799, 7195, 9, 'Évaluation du poids et de conseils aux enfants et les adolescents (CQM)'),
(33800, 7196, 9, 'Changement de Poids'),
(33801, 7197, 9, 'Perte de Poids'),
(33802, 7198, 9, 'Clinique de perte de poids'),
(33803, 7199, 9, 'Bienvenue'),
(33804, 7202, 9, 'Que faut-il comptés?'),
(33805, 7203, 9, 'Sifflements:'),
(33806, 7204, 9, 'Sifflement'),
(33807, 7205, 9, 'Sifflement:'),
(33808, 7208, 9, 'Où se trouvent les documents ou papier numérisés?'),
(33809, 7211, 9, 'Coup de lapin'),
(33810, 7212, 9, 'Blanc'),
(33811, 7213, 9, 'Qui'),
(33812, 7214, 9, 'Qui a répondu?'),
(33813, 7215, 9, 'Veuf(ve)'),
(33814, 7217, 9, 'Largeur en pixels du cadre gauche de navigation.'),
(33815, 7221, 9, 'Avec la sélection:'),
(33816, 7222, 9, 'avec l''ancien nom'),
(33817, 7224, 9, 'Avec qui pouvons-nous laisser un message?'),
(33818, 7225, 9, 'Retenu'),
(33819, 7226, 9, 'en quelques heures'),
(33820, 7227, 9, 'en quelques heures:'),
(33821, 7228, 9, 'en quelques minutes'),
(33822, 7229, 9, 'en quelques minutes:'),
(33823, 7232, 9, 'Sans mise à jour'),
(33824, 7233, 9, 'Témoignage'),
(33825, 7234, 9, 'semaine'),
(33826, 7237, 9, 'Femme'),
(33827, 7238, 9, 'Femmes Seulement'),
(33828, 7240, 9, 'Travaux'),
(33829, 7241, 9, 'NOTE DE TRAVAIL'),
(33830, 7242, 9, 'Téléphone Professionnel'),
(33831, 7243, 9, 'Numéro de Téléphone Professionnel'),
(33832, 7244, 9, 'Les travaux liés?'),
(33833, 7245, 9, 'Travail/ Education/ Loisirs'),
(33834, 7246, 9, 'Travail/ Note Scolaire'),
(33835, 7247, 9, 'jour ouvrable'),
(33836, 7249, 9, 'Régime d''indemnisation du personnel de santé'),
(33837, 7252, 9, 'Pire'),
(33838, 7253, 9, 'Souhaitez-vous imputer le montant qui reste sur le Compte Global?'),
(33839, 7254, 9, 'Voulez-vous qu''ils soient marqués comme compensés.'),
(33840, 7255, 9, 'Vous souhaitez allouer?'),
(33841, 7256, 9, 'Voulez-vous Annuler Répartition de ce Patient?'),
(33842, 7257, 9, 'Voulez-vous Supprimer Répartition du paiement?'),
(33843, 7258, 9, 'Voulez-vous Supprimer les Paiements?'),
(33844, 7259, 9, 'Voulez-vous Modifier et Terminer les Paiements?'),
(33845, 7260, 9, 'Voulez-vous Modifier les Paiements?'),
(33846, 7261, 9, 'Voulez-vous Poster et Terminer Les Paiements?'),
(33847, 7262, 9, 'Voulez-vous Poster les Paiements?'),
(33848, 7263, 9, 'Voulez-vous Sauvegarder?'),
(33849, 7264, 9, 'Poignet'),
(33850, 7265, 9, 'Poignet et main'),
(33851, 7266, 9, 'Problèmes de Poignet'),
(33852, 7267, 9, 'écrire'),
(33853, 7268, 9, 'radiation'),
(33854, 7270, 9, 'avec quelques'),
(33855, 7271, 9, 'POIDS'),
(33856, 7273, 9, 'x Annulé'),
(33857, 7274, 9, 'x Annulé'),
(33858, 7275, 9, 'Rayon X'),
(33859, 7276, 9, 'Interprétation Rayon X:'),
(33860, 7277, 9, 'Interprétation Rayon X:'),
(33861, 7278, 9, 'X12 uniquement: Demande de Remplacement '),
(33862, 7279, 9, 'X12 Partenaire'),
(33863, 7280, 9, 'X12 Partenaires'),
(33864, 7285, 9, 'année'),
(33865, 7286, 9, 'année'),
(33866, 7287, 9, 'Vue Annuelle'),
(33867, 7288, 9, 'Année(s)'),
(33868, 7289, 9, 'Années'),
(33869, 7290, 9, 'Années ou mois'),
(33870, 7291, 9, 'Années, mois et jours'),
(33871, 7292, 9, 'OUI'),
(33872, 7293, 9, 'Oui'),
(33873, 7294, 9, 'oui'),
(33874, 7295, 9, 'OUI!'),
(33875, 7296, 9, 'Oui, supprimer et enregistrer'),
(33876, 7298, 9, 'Oui/Non'),
(33877, 7299, 9, 'Oui:'),
(33878, 7300, 9, 'Yidich'),
(33879, 7303, 9, 'Vous allez définitivement remplacer le modèle existant. Etes-vous sûr de vouloir continuer?'),
(33880, 7304, 9, 'Vous êtes en période de connexion supplémentaire. Changez votre mot de passe avant'),
(33881, 7305, 9, 'Vous n''êtes pas autorisé à supprimer cet événement'),
(33882, 7306, 9, 'Vous n''êtes pas autorisé à modifier l''événement'),
(33883, 7307, 9, 'Vous n''êtes pas autorisé pour cela.'),
(33884, 7308, 9, 'Vous n''êtes pas autorisé à accéder à cette équipe.'),
(33885, 7309, 9, 'Vous n''êtes pas autorisé à ajouter/modifier ces sujets'),
(33886, 7310, 9, 'Vous n''êtes pas autorisé à planifier des rendez.'),
(33887, 7311, 9, 'Vous n''êtes pas autorisé de voir cette visite.'),
(33888, 7313, 9, 'Vous ne pouvez pas accéder à cette fonctionnalité directement.'),
(33889, 7314, 9, 'Vous ne pouvez accéder à cette page directement.'),
(33890, 7315, 9, 'Vous ne pouvez ajouter une valeur vide pour une catégorie!'),
(33891, 7316, 9, 'Vous ne pouvez ajouter une valeur vide pour une sous-catégorie!'),
(33892, 7317, 9, 'Vous ne pouvez ajouter une valeur vide pour un élément!'),
(33893, 7318, 9, 'Vous ne pouvez pas entrer une date future avec une valeur OUI (YES) introduite.'),
(33894, 7319, 9, 'Vous n''avez sélectionné aucune action.'),
(33895, 7320, 9, 'Vous n''avez pas accès pour voir/éditer cette note'),
(33896, 7321, 9, 'Vous avez tenté de modifier un contenu qui est verrouillé. Retirez le verrou si vous voulez faire cela. Pour déverrouiller, supprimer la ligne, ''/*lock ::*/'''),
(33897, 7322, 9, 'Vous avez été déconnecter avec succès.'),
(33898, 7323, 9, 'Vous ne pouvez transférer que les fichiers .txt'),
(33899, 7324, 9, 'Vous pouvez télécharger des résultats en format HL7 à partir d''un fichier'),
(33900, 7325, 9, 'Vous pouvez mettre insérer ici la plainte par défaut dans le formulaire Nouvelle Visite du Patient.'),
(33901, 7326, 9, 'Vous devez entrer un mot de passe pour crypter le document'),
(33902, 7327, 9, 'Vous devez saisir votre mot de passe pour modifier les mots de passe des utilisateurs. Veuillez laisser vide pour que le mot de passe demeure inchangé.'),
(33903, 7329, 9, 'Vous devez d''abord sélectionner ou ajouter un patient.'),
(33904, 7330, 9, 'Vous devez d''abord sélectionner ou créer une visite.'),
(33905, 7331, 9, 'Vous devez sélectionner une catégorie de visite'),
(33906, 7332, 9, 'Vous devez sélectionner une catégorie de visite.'),
(33907, 7333, 9, 'Vous devez sélectionner des champs pour continuer.'),
(33908, 7335, 9, 'Vous devez sélectionner au moins un contexte'),
(33909, 7336, 9, 'Vous devez sélectionner au moins un Prestataire'),
(33910, 7338, 9, 'Votre rapport clinique'),
(33911, 7339, 9, 'Votre date fin est invalide'),
(33912, 7340, 9, 'Votre événement a été supprimé.'),
(33913, 7341, 9, 'Votre événement a été modifié.'),
(33914, 7342, 9, 'Votre événement a été soumis.'),
(33915, 7343, 9, 'Votre fichier est trop grand'),
(33916, 7344, 9, 'Vos résultats de laboratoire'),
(33917, 7345, 9, 'Votre nom de liste a été modifiée pour répondre aux exigences de nommage.'),
(33918, 7346, 9, 'Votre message a été soumis pour être livré à'),
(33919, 7347, 9, 'Votre nom pour cette catégorie, procédure ou résultat'),
(33920, 7348, 9, 'Votre mot de passe'),
(33921, 7349, 9, 'Votre mot de passe a expiré. Veuillez changer votre mot de passe.'),
(33922, 7350, 9, 'Votre mot de passe expire le'),
(33923, 7351, 9, 'Votre mot de passe expire aujourd''hui. Veuillez changer votre mot de passe.'),
(33924, 7352, 9, 'Votre mot de passe sert de signature'),
(33925, 7353, 9, 'Votre configuration PostCalendar est réinitialisé par les paramètres par défaut.'),
(33926, 7354, 9, 'Votre configuration PostCalendar est actualisé.'),
(33927, 7355, 9, 'Votre fréquence de répétition doit être un entier.'),
(33928, 7356, 9, 'Votre fréquence de répétition doit être au moins 1.'),
(33929, 7357, 9, 'Votre date début est supérieure à la date fin'),
(33930, 7358, 9, 'Votre date début est invalide'),
(33931, 7359, 9, 'Votre soumission a échoué.'),
(33932, 7360, 9, 'aaaa-mm-jj'),
(33933, 7361, 9, 'AAAA-MM-JJ'),
(33934, 7362, 9, 'aaaa-mm-jj date associé à ce document'),
(33935, 7363, 9, 'aaaa-mm-jj date de destruction'),
(33936, 7364, 9, 'aaaa-mm-jj date de naissance'),
(33937, 7365, 9, 'aaaa-mm-jj Date de Naissance'),
(33938, 7366, 9, 'aaaa-mm-jj date d''expiration'),
(33939, 7367, 9, 'aaaa-mm-jj Date du début ou de l''hospitalisation'),
(33940, 7368, 9, 'aaaa-mm-jj date du début, chirurgie ou début de médication'),
(33941, 7369, 9, 'aaaa-mm-jj date d''achat ou transfert'),
(33942, 7370, 9, 'aaaa-mm-jj date de récupération et fin de médication'),
(33943, 7371, 9, 'aaaa-mm-jj Date de retour au jeu'),
(33944, 7372, 9, 'aaaa-mm-jj Date de service'),
(33945, 7373, 9, 'aaaa-mm-jj date de cette lettre'),
(33946, 7374, 9, 'aaaa-mm-jj date de retour au jeu'),
(33947, 7375, 9, 'aaaa-mm-jj date du document'),
(33948, 7376, 9, 'aaaa-mm-jj date d''évènement ou de début'),
(33949, 7377, 9, 'yyyy-mm-dd H:m Date de fin'),
(33950, 7378, 9, 'yyyy-mm-dd H:m Date de fin'),
(33951, 7379, 9, 'yyyy-mm-dd H:m Date de début'),
(33952, 7380, 9, 'yyyy-mm-dd H:m Date de début'),
(33953, 7381, 9, 'aaaa-mm-jj hh:mm:ss'),
(33954, 7383, 9, 'aaaa-mm-jj dernière date de l''événement'),
(33955, 7387, 9, 'Zéro'),
(33956, 7389, 9, 'Code Postal'),
(33957, 7390, 9, 'Code Postal'),
(33958, 7391, 9, 'Code Postal/Pays:'),
(33959, 7392, 9, 'Zoulou'),
(33960, 7393, 9, ' mais étais '),
(33961, 7394, 9, ' ne peut être accédé'),
(33962, 7395, 9, 'Voulez-vous vraiment supprimer'),
(33963, 7396, 9, 'Médicament'),
(33964, 7397, 9, 'email non envoyé'),
(33965, 7398, 9, 'de'),
(33966, 7399, 9, 'a été crée '),
(33967, 7400, 9, 'a été ré-ouvert'),
(33968, 7401, 9, 'Histoire'),
(33969, 7402, 9, 'n''est pas un nombre'),
(33970, 7403, 9, 'est prêt à une ré-facturation'),
(33971, 7405, 9, 'Lot'),
(33972, 7406, 9, 'N° Référence d''Origine Assurance Maladie '),
(33973, 7407, 9, 'min'),
(33974, 7408, 9, 'introuvable!'),
(33975, 7409, 9, 'Particularités dans de nombreux navigateurs peut signifier que la sortie ci-dessous entre votre écran par saccades brusques et qu''il y a de longues pauses de plusieurs secondes, où il semble que les choses peuvent avoir écrasé. Ce n''est pas le cas, vous finirez par voir la sortie sortant ligne par ligne. Il y a peut-être des numéros séquentiels apparaissant ci-dessous, ce n''est pour indiquer que même si rien d''autre peut-être il y a une activité affichant passe. Ces numéros seront entrecoupés avec le contenu de la facturation et c''est normal.'),
(33976, 7410, 9, 'ordonnance a atteint sa limite de'),
(33977, 7411, 9, 'jusqu''à'),
(33978, 7412, 9, 'mise à jour échoué, pas dans la base de données?'),
(33979, 7413, 9, 'a été marqué comme facturé uniquement.'),
(33980, 7414, 9, 'a été mis en file d''attente avec succès.'),
(33981, 7415, 9, '! Laissé w/o visite'),
(33982, 7416, 9, '" pour le code'),
(33983, 7417, 9, '" est activé dans les règles du Calendrier!'),
(33984, 7419, 9, 'nb de comprimés:'),
(33985, 7421, 9, '$ Codage fait'),
(33986, 7422, 9, '$label (aaaa-mm-jj): '),
(33987, 7423, 9, '%'),
(33988, 7424, 9, '% Annulé < 24h'),
(33989, 7425, 9, '% Annulé < 24h '),
(33990, 7426, 9, 'devrait exister mais au contraire.'),
(33991, 7427, 9, '(% correspond à toute chaîne, _ à tout caractères)'),
(33992, 7429, 9, '(Arrière)'),
(33993, 7430, 9, '(Cliquez pour modifier)'),
(33994, 7431, 9, '(Livraison Email est immédiat, tandis que le VOIP automatisés est envoyé au fournisseur de service pour un traitement ultérieur.)'),
(33995, 7432, 9, '(Plus)'),
(33996, 7433, 9, '(Nouveau Patient)'),
(33997, 7434, 9, '(Notes et Autorisations)'),
(33998, 7435, 9, '(Notes sur le Patient)'),
(33999, 7436, 9, '(Veuillez electionner parmi eux ou saisir votre propre titre)'),
(34000, 7437, 9, '(Shift-)Cliquer ou glisser pour modifier la valeur'),
(34001, 7438, 9, '* Rappel effectué'),
(34002, 7439, 9, '** Veuillez déplacer les chirurgies vers les problèmes cliniques!'),
(34003, 7440, 9, '*Obligatoire'),
(34004, 7441, 9, '+ Diagramme retiré'),
(34005, 7442, 9, '- Aucun'),
(34006, 7443, 9, '-- Tous --'),
(34007, 7444, 9, '--Sélectionner un rôle--'),
(34008, 7446, 9, '0'),
(34009, 7447, 9, '0-11'),
(34010, 7448, 9, '0-25'),
(34011, 7452, 9, '1 = Amérique du Nord. Voir http://www.wtng.info/ pour la liste des codes des autres pays.'),
(34012, 7453, 9, 'Dans une journée'),
(34013, 7454, 9, 'Dans un mois'),
(34014, 7455, 9, 'Dans une semaine'),
(34015, 7456, 9, 'Dans un an'),
(34016, 7457, 9, '1. Repos 2. Glace pour deux jours 3. Compression, laissez le pansement en place à moins que le pied ne développe un engourdissement ou a une couleur pâle 4. Surélever le pied et la jambe'),
(34017, 7458, 9, '11-14'),
(34018, 7459, 9, '12 H'),
(34019, 7460, 9, '15-20'),
(34020, 7461, 9, '1er'),
(34021, 7462, 9, '2'),
(34022, 7463, 9, 'Dans 2 jours'),
(34023, 7464, 9, 'Dans 2 mois'),
(34024, 7465, 9, 'Dans 2 semaines'),
(34025, 7466, 9, 'Dans 2 mois'),
(34026, 7467, 9, '2-20 ans'),
(34027, 7468, 9, '20-25'),
(34028, 7477, 9, '2111-14'),
(34029, 7478, 9, '24 H'),
(34030, 7479, 9, '25+'),
(34031, 7480, 9, '25-30'),
(34032, 7481, 9, '2ème'),
(34033, 7482, 9, 'Dans 3 jours'),
(34034, 7483, 9, '3 mois'),
(34035, 7484, 9, 'Dans 3 mois'),
(34036, 7485, 9, '3 fois par jour'),
(34037, 7486, 9, 'Dans 3 semaines'),
(34038, 7487, 9, '30-35'),
(34039, 7488, 9, '35-40'),
(34040, 7489, 9, '3ème'),
(34041, 7490, 9, 'Dans 4 jours'),
(34042, 7491, 9, '4 mois'),
(34043, 7492, 9, 'Dans 4 mois'),
(34044, 7493, 9, '4 fois par jour'),
(34045, 7494, 9, 'Dans 4 semaines'),
(34046, 7498, 9, '466.0, Bronchite, Aiguë NOS'),
(34047, 7499, 9, '486.0, Pneumonie, Aiguë'),
(34048, 7501, 9, '491.8, Bronchite, Chronique'),
(34049, 7502, 9, '493.92, Asthme, Exacerbés Aiguë.'),
(34050, 7504, 9, '4ème'),
(34051, 7505, 9, 'Dans 5 jours'),
(34052, 7506, 9, 'Dans 5 mois'),
(34053, 7507, 9, 'Dans 5 semaines'),
(34054, 7508, 9, '519.7, Broncho-spasme'),
(34055, 7509, 9, '5ème'),
(34056, 7510, 9, 'Dans 6 jours'),
(34057, 7511, 9, '6 mois'),
(34058, 7512, 9, 'Dans 6 mois'),
(34059, 7513, 9, 'Dans 6 semaines'),
(34060, 7514, 9, '6ème'),
(34061, 7515, 9, 'Dans 7 mois'),
(34062, 7516, 9, 'Dans 8 mois'),
(34063, 7517, 9, '824.0 Fracture, malléole interne, fermée'),
(34064, 7518, 9, '824.2 Fracture, malléole latérale, fermée'),
(34065, 7519, 9, '824.6 Fracture, tri-malléolaires, fermé'),
(34066, 7520, 9, '825,32 Fracture, de la Naviculaire (cheville)'),
(34067, 7521, 9, '825,35 Fracture, Base de cinquième (5ème) Métatarsien'),
(34068, 7522, 9, '845,00 entorse de la cheville NOS'),
(34069, 7523, 9, '845,01 Entorse Médial (deltoïde) Lig.'),
(34070, 7524, 9, '845,02 Entorse, péroné calcanéum'),
(34071, 7525, 9, 'Dans 9 mois'),
(34072, 7526, 9, '99212 Installé - sans complication'),
(34073, 7527, 9, '99213 Installé - faible complication'),
(34074, 7528, 9, '< En salle d''examen'),
(34075, 7529, 9, '> Vérifié'),
(34076, 7530, 9, '?'),
(34077, 7531, 9, '? Ne s''est pas présenté'),
(34078, 7532, 9, '@ Arrivé'),
(34079, 7533, 9, '[Changer de Vue]'),
(34080, 7534, 9, '[Date de Dernière Visite]'),
(34081, 7535, 9, '[Jours Depuis Dernière Visite]'),
(34082, 7537, 9, '[Exporter OFX]'),
(34083, 7538, 9, '[déconseillé]'),
(34084, 7539, 9, '[Nombre De Visites]'),
(34085, 7540, 9, '[Rapports]'),
(34086, 7541, 9, '[Sélectionner Tout]'),
(34087, 7542, 9, '[SQL-Ledger]'),
(34088, 7543, 9, '[Début de Traitement par Lots]'),
(34089, 7544, 9, '[Afficher le Journal]'),
(34090, 7545, 9, '[Afficher Rapport Imprimable]'),
(34091, 7546, 9, '_PC_DUR_HEURES'),
(34092, 7547, 9, '_PC_DUR_MINUTES'),
(34093, 7548, 9, '_PC_LOCALE'),
(34094, 7549, 9, '~ Arrivé en retard'),
(34095, 2, 10, 'Et betalingsnummer til å identifisere betalingen'),
(34096, 10, 10, 'Et serienummer kreves!'),
(34097, 15, 10, 'En pasient med dette navnet eksisterer allerede.'),
(34098, 20, 10, 'En relatert IPPF kode trenges'),
(34099, 21, 10, 'Spesialtegn'),
(34100, 34, 10, 'Unormal'),
(34101, 35, 10, 'Unormal Blodprøve'),
(34102, 36, 10, 'Unormal Hårvekst'),
(34103, 39, 10, 'Abort'),
(34104, 43, 10, 'Aborter'),
(34105, 44, 10, 'Om kalenderen'),
(34106, 47, 10, 'Akseptere Jobb'),
(34107, 49, 10, 'Akseptere penger for '),
(34108, 50, 10, 'Akseptere jobb'),
(34109, 51, 10, 'Tilgangs kontroll'),
(34110, 59, 10, 'Kontonavn'),
(34111, 62, 10, 'Regnskap'),
(34112, 74, 10, 'Handling'),
(34113, 75, 10, 'Handlinger'),
(34114, 78, 10, 'Aktiv'),
(34115, 82, 10, 'Aktivt møte'),
(34116, 85, 10, 'Aktiv Pasient'),
(34117, 87, 10, 'Aktivitet'),
(34118, 88, 10, 'Aktivitets type'),
(34119, 93, 10, 'legg til'),
(34120, 94, 10, 'Legg til'),
(34121, 96, 10, 'Legg til en Bedrift'),
(34122, 98, 10, 'Legg til et Apotek'),
(34123, 100, 10, 'Legg til en hendelse for '),
(34124, 102, 10, 'Legg til som ny'),
(34125, 106, 10, 'Legg til kategori'),
(34126, 107, 10, 'Legg til konstant'),
(34127, 110, 10, 'Legg til kriterie'),
(34128, 113, 10, 'Legg til medisin'),
(34129, 114, 10, 'Legg til Møte'),
(34130, 116, 10, 'Legg til Lokale'),
(34131, 119, 10, 'Legg til gruppe'),
(34132, 123, 10, 'Legg til problem'),
(34133, 125, 10, 'Legg til språk'),
(34134, 126, 10, 'Legg til ny'),
(34135, 128, 10, 'Legg til ny kategori : '),
(34136, 132, 10, 'Legg til ny gruppe'),
(34137, 135, 10, 'Legg til nytt notat'),
(34138, 137, 10, 'Legg til ny partner'),
(34139, 140, 10, 'Legg til notat'),
(34140, 141, 10, 'Legg til pasient historie'),
(34141, 142, 10, 'Legg til Resept'),
(34142, 146, 10, 'Legg til Regel'),
(34143, 148, 10, 'Legg til medisin liste'),
(34144, 150, 10, 'Legg til Transaksjon'),
(34145, 151, 10, 'Legg til bruker'),
(34146, 152, 10, 'Legg til bruker til gruppe'),
(34147, 161, 10, 'Flere diagnoser:'),
(34148, 162, 10, 'Mere historie'),
(34149, 164, 10, 'Mere info'),
(34150, 168, 10, 'Flere notater:'),
(34151, 169, 10, 'Flere notater: '),
(34152, 170, 10, 'Flere røntgen notater:'),
(34153, 175, 10, 'Adresse'),
(34154, 178, 10, 'Adressebok'),
(34155, 187, 10, 'adresse1'),
(34156, 188, 10, 'adresse2'),
(34157, 192, 10, 'Justér'),
(34158, 196, 10, 'Justerings verdi for kode '),
(34159, 197, 10, 'Justeringer'),
(34160, 198, 10, 'Adm juster'),
(34161, 199, 10, 'Admin'),
(34162, 200, 10, 'Admin Email Adresse'),
(34163, 203, 10, 'Administrert Av'),
(34164, 206, 10, 'Administrasjon'),
(34165, 219, 10, 'Råd'),
(34166, 221, 10, 'Påvirker normalt'),
(34167, 223, 10, 'Ringninger etter stengetid'),
(34168, 230, 10, 'Etter informasjonen er skrevet inn slik den skal, trykk lagre knappen'),
(34169, 233, 10, 'Igjen'),
(34170, 234, 10, 'Alder'),
(34171, 235, 10, 'Alder etter'),
(34172, 236, 10, 'Alder kategori'),
(34173, 239, 10, 'Alder formatet for "Age fra" er ikke gyldig'),
(34174, 240, 10, 'Alder formatet for "alder opp til" er ikke gyldig'),
(34175, 241, 10, 'Alder fra'),
(34176, 247, 10, 'Aldrings kolonner:'),
(34177, 250, 10, 'Alkohol'),
(34178, 259, 10, 'Alle'),
(34179, 266, 10, 'Alle kategorier'),
(34180, 269, 10, 'Alle dager'),
(34181, 270, 10, 'Heldags hendelse'),
(34182, 272, 10, 'Alle Lokaler'),
(34183, 276, 10, 'Alt eller deler av det fornavnet'),
(34184, 277, 10, 'Alt eller deler av etternavnet'),
(34185, 280, 10, 'Alle Produkter'),
(34186, 282, 10, 'Alt Gjennomsett og Negative:'),
(34187, 283, 10, 'Alle Emner'),
(34188, 284, 10, 'Alle Brukere'),
(34189, 286, 10, 'Allergier:'),
(34190, 287, 10, 'Allergier:'),
(34191, 288, 10, 'Allergi'),
(34192, 291, 10, 'Allergireaksjon'),
(34193, 299, 10, 'Tillat Epost'),
(34194, 309, 10, 'Tillat SMS'),
(34195, 310, 10, 'Tillat SMS (Tekstmeldinger)?'),
(34196, 311, 10, 'Tillatt sendte hendelser til å bli gjort aktive nå?'),
(34197, 313, 10, 'Tillatt bruker å publisere Globale Hendelser'),
(34198, 314, 10, 'Tillat brukere til å publisere Personlige kallendere'),
(34199, 316, 10, 'Tillatt'),
(34200, 325, 10, 'Allerede i bruk, velg en annen'),
(34201, 326, 10, 'Allerede i bruk, velg en annen titel'),
(34202, 327, 10, 'Alternativ adresse'),
(34203, 347, 10, 'Mengde'),
(34204, 351, 10, 'Mengde for dette besøket'),
(34205, 352, 10, 'Mengde Betalt'),
(34206, 353, 10, 'Mengde:'),
(34207, 365, 10, 'Og'),
(34208, 368, 10, 'og '),
(34209, 375, 10, 'Ankel'),
(34210, 376, 10, 'Ankel + hel'),
(34211, 377, 10, 'Ankel Evaluerings Skjema'),
(34212, 378, 10, 'Ankel Problemer'),
(34213, 386, 10, 'Hvilken som helst'),
(34214, 388, 10, 'Hvilken som helst av den ønskede kode eller dens forklarinng'),
(34215, 396, 10, 'Utseende'),
(34216, 397, 10, 'Utseende:'),
(34217, 401, 10, 'Henvis til denne notisen'),
(34218, 413, 10, 'Bruk på påvirket område'),
(34219, 414, 10, 'Bruk på hud'),
(34220, 418, 10, 'Avtale dato'),
(34221, 421, 10, 'Avtale status'),
(34222, 423, 10, 'Avtale innenfor'),
(34223, 425, 10, 'Avtaler'),
(34224, 430, 10, 'Avtaler og hendelser'),
(34225, 431, 10, 'Avtale rapport'),
(34226, 432, 10, 'Avtale-Hendelses Rapport'),
(34227, 434, 10, 'Godkjenn'),
(34228, 436, 10, 'Godkjent'),
(34229, 443, 10, 'April'),
(34230, 455, 10, 'Er du sikker på at du vil godkjenne disse hendelsene?'),
(34231, 460, 10, 'Er du sikker på at du vil slette disse hendelsene?'),
(34232, 464, 10, 'Er du sikker på at du vil redigere disse hendelsene?'),
(34233, 465, 10, 'Er du sikker på at du vil skjule disse hendelsene?'),
(34234, 467, 10, 'Er du sikker på at du vil se på disse hendelsene?'),
(34235, 472, 10, 'Er du sikker på at du vil fortsette med disse handlingene?'),
(34236, 473, 10, 'Område ikke spesifisert'),
(34237, 482, 10, 'Fra og med'),
(34238, 489, 10, 'Assistent'),
(34239, 497, 10, 'Atletisk/skade'),
(34240, 503, 10, 'Oppmerksomhet'),
(34241, 517, 10, 'August'),
(34242, 525, 10, 'Tilganger'),
(34243, 526, 10, 'Gi tilgang'),
(34244, 530, 10, 'Har tilgang'),
(34245, 532, 10, 'Auto send'),
(34246, 552, 10, 'Tilgjengelige tider'),
(34247, 566, 10, 'Rygg'),
(34248, 567, 10, 'rygg'),
(34249, 575, 10, 'Rygg Problemer'),
(34250, 578, 10, 'Rygg operasjon'),
(34251, 590, 10, 'Sikkerhets kopi'),
(34252, 598, 10, 'Balanse'),
(34253, 620, 10, 'Start'),
(34254, 621, 10, 'Start Dato'),
(34255, 623, 10, 'Start dato for service åååå-mm-dd'),
(34256, 636, 10, 'Regnings Dato:'),
(34257, 660, 10, 'Rapport for regninger'),
(34258, 663, 10, 'Regning til '),
(34259, 666, 10, 'Fødelses Dato'),
(34260, 672, 10, 'Blære kreft'),
(34261, 673, 10, 'Blære infeksjon'),
(34262, 678, 10, 'Blokkert'),
(34263, 682, 10, 'Blodig nese'),
(34264, 685, 10, 'Tåkete syn'),
(34265, 689, 10, 'Kropps region'),
(34266, 698, 10, 'Begge ører'),
(34267, 699, 10, 'Bunn'),
(34268, 701, 10, 'BOX 10 A. Ansettelses relatert '),
(34269, 702, 10, 'BOX 10 B. Bil ulykke '),
(34270, 703, 10, 'BOX 10 C. Annen ulykke '),
(34271, 708, 10, 'BOX 16. Kan ikke arbeide fra dato (åååå-mm-dd):'),
(34272, 709, 10, 'BOX 16. Kan ikke arbeide til dato (åååå-mm-dd)'),
(34273, 723, 10, 'Bryst'),
(34274, 727, 10, 'Brystundersøkelse'),
(34275, 730, 10, 'Puste Lyder:'),
(34276, 732, 10, 'Brukne Bein'),
(34277, 735, 10, 'Se igjennom'),
(34278, 744, 10, 'Opptatt'),
(34279, 748, 10, 'av'),
(34280, 750, 10, 'av mund'),
(34281, 751, 10, 'Av/Skilde'),
(34282, 752, 10, 'Av:'),
(34283, 758, 10, 'Kalender'),
(34284, 764, 10, 'Kalender UI'),
(34285, 774, 10, 'avbryt'),
(34286, 777, 10, 'Kreft'),
(34287, 790, 10, 'Kan ikke lage'),
(34288, 795, 10, 'Kan ikke finne '),
(34289, 803, 10, 'Kan ikke åpne '),
(34290, 812, 10, 'Kapsul'),
(34291, 813, 10, 'Kort'),
(34292, 824, 10, 'penger'),
(34293, 825, 10, 'Penger'),
(34294, 831, 10, 'Kategorier'),
(34295, 833, 10, 'Kategori'),
(34296, 834, 10, 'kategori'),
(34297, 835, 10, 'Kategori '),
(34298, 836, 10, 'Kategori Detaljer'),
(34299, 837, 10, 'Kategori Grenser'),
(34300, 838, 10, 'Kategori navn'),
(34301, 841, 10, 'Hvit'),
(34302, 853, 10, 'Mobiltelefon'),
(34303, 855, 10, 'Mobilnummer'),
(34304, 856, 10, 'sentral sertifikasjon'),
(34305, 866, 10, 'forandre'),
(34306, 867, 10, 'Forandre'),
(34307, 868, 10, 'Forandre Aktivitet'),
(34308, 874, 10, 'Forandret'),
(34309, 883, 10, 'Diagram'),
(34310, 898, 10, 'Sjekk'),
(34311, 899, 10, 'sjekk'),
(34312, 932, 10, 'Sjekk ut'),
(34313, 934, 10, 'Bryst'),
(34314, 937, 10, 'Bryst Smerte:'),
(34315, 938, 10, 'Bryst Smerter'),
(34316, 946, 10, 'Grøssninger'),
(34317, 957, 10, 'Velg Kriterie'),
(34318, 967, 10, 'Kronisk bronkit'),
(34319, 975, 10, 'By'),
(34320, 977, 10, 'By, landsdel'),
(34321, 979, 10, 'By/landsdel'),
(34322, 988, 10, 'Klassifisert'),
(34323, 989, 10, 'Tøm'),
(34324, 991, 10, 'Tøm alle'),
(34325, 997, 10, 'Klikk'),
(34326, 1001, 10, 'Klikk for mere'),
(34327, 1008, 10, 'Klikk her for å velge en dato'),
(34328, 1021, 10, 'Klikk her for å oppdatere prioritet, kategori og kallenavn instillinger'),
(34329, 1037, 10, 'Klikk for å laste ned'),
(34330, 1038, 10, 'Klikk for å redigere'),
(34331, 1041, 10, 'Klikk for å generere rapport'),
(34332, 1045, 10, 'Klikk for å velge'),
(34333, 1051, 10, 'Klikk for å velge eller forandre diagnose'),
(34334, 1053, 10, 'Klikk for å velge en pasient'),
(34335, 1054, 10, 'Klikk for å velge relatert kode'),
(34336, 1063, 10, 'Klikk:'),
(34337, 1067, 10, 'Klient Kopi'),
(34338, 1074, 10, 'Klienter'),
(34339, 1075, 10, 'Klinikk'),
(34340, 1107, 10, 'Klon'),
(34341, 1108, 10, 'Klon siste besøk'),
(34342, 1109, 10, 'Steng'),
(34343, 1111, 10, 'Steng vindu'),
(34344, 1112, 10, 'Stengt'),
(34345, 1131, 10, 'Kode'),
(34346, 1132, 10, 'kode'),
(34347, 1133, 10, 'Kode finner'),
(34348, 1134, 10, 'Koden må inneholde 2 små bokstaver'),
(34349, 1144, 10, 'Koder'),
(34350, 1145, 10, 'Koding'),
(34351, 1149, 10, 'Koding ikke tillatt'),
(34352, 1150, 10, 'Kaffe'),
(34353, 1168, 10, 'Farge'),
(34354, 1171, 10, 'Kolonner'),
(34355, 1175, 10, 'Kommentarer'),
(34356, 1178, 10, 'Fullfør Endringer'),
(34357, 1186, 10, 'Fullført'),
(34358, 1191, 10, 'Komplikasjoner ved abort'),
(34359, 1227, 10, 'Kontakt'),
(34360, 1228, 10, 'Kontakt Epost'),
(34361, 1236, 10, 'Kontakt navn'),
(34362, 1237, 10, 'Kontakt person'),
(34363, 1239, 10, 'Kontakt Tlf'),
(34364, 1243, 10, 'Innhold'),
(34365, 1244, 10, 'innhold'),
(34366, 1269, 10, 'Kopier verdier'),
(34367, 1290, 10, 'Hoste:'),
(34368, 1296, 10, 'Kunne ikke sende epost grunnet et problem med serveren '),
(34369, 1304, 10, 'Rådgiving'),
(34370, 1308, 10, 'Land'),
(34371, 1325, 10, 'krem'),
(34372, 1329, 10, 'Lag en ny Hendelse'),
(34373, 1340, 10, 'Lag en Ny Pasient'),
(34374, 1344, 10, 'Lag et Pasient Notis'),
(34375, 1347, 10, 'Laget'),
(34376, 1352, 10, 'kreditt'),
(34377, 1353, 10, 'Kredittkort'),
(34378, 1354, 10, 'Kreditter'),
(34379, 1386, 10, 'For øyeblikket aktiv'),
(34380, 1408, 10, 'Daglig'),
(34381, 1420, 10, 'Data Type'),
(34382, 1421, 10, 'Database'),
(34383, 1427, 10, 'Dato'),
(34384, 1440, 10, 'Dato Ødelagt'),
(34385, 1441, 10, 'Dato Vis Format'),
(34386, 1450, 10, 'Dato for bank innskudd åååå-mm-dd'),
(34387, 1456, 10, 'Dato Når Skaden Intraff'),
(34388, 1458, 10, 'Betalings dato åååå-mm-dd'),
(34389, 1463, 10, 'Service Dato'),
(34390, 1465, 10, 'Service dato mm/dd/åååå'),
(34391, 1466, 10, 'Service Dato:'),
(34392, 1484, 10, 'Dato:'),
(34393, 1486, 10, 'Dag'),
(34394, 1489, 10, 'Dags oversikt'),
(34395, 1490, 10, 'Dag(er)'),
(34396, 1491, 10, 'Dag(er) M-F'),
(34397, 1492, 10, 'dager'),
(34398, 1493, 10, 'Dager'),
(34399, 1498, 10, 'Dager per Kolonne:'),
(34400, 1512, 10, 'Informasjon om feilen'),
(34401, 1517, 10, 'Desember'),
(34402, 1522, 10, 'Vanlig'),
(34403, 1523, 10, 'Vanlig kallender perspektiv'),
(34404, 1526, 10, 'Vanlige lokale'),
(34405, 1530, 10, 'Vanlig metode'),
(34406, 1547, 10, 'Vanlig Verdi'),
(34407, 1550, 10, 'Vanlig/Global'),
(34408, 1554, 10, 'Slett'),
(34409, 1556, 10, 'Slett Kategorier med ID(s): '),
(34410, 1562, 10, 'Slett Sider'),
(34411, 1598, 10, 'Innskudds Dato:'),
(34412, 1599, 10, 'Deprimert'),
(34413, 1602, 10, 'Forklaring'),
(34414, 1603, 10, 'forklaring'),
(34415, 1609, 10, 'Mål'),
(34416, 1612, 10, 'Ødelegg...'),
(34417, 1614, 10, 'Ødelegg Medisiner'),
(34418, 1615, 10, 'Ødelegg Medisin Rapport'),
(34419, 1617, 10, 'Detaljer'),
(34420, 1620, 10, 'Diabetes'),
(34421, 1633, 10, 'Diagnose'),
(34422, 1643, 10, 'Diagnose:'),
(34423, 1644, 10, 'Diagnose: '),
(34424, 1651, 10, 'Diktering: '),
(34425, 1675, 10, 'avslått'),
(34426, 1676, 10, 'Avslått'),
(34427, 1694, 10, 'Rabatt'),
(34428, 1695, 10, 'Rabatt Mengde'),
(34429, 1715, 10, 'Viss kalenderen?'),
(34430, 1734, 10, 'Svimmelhet:'),
(34431, 1747, 10, 'ikke lagre'),
(34432, 1748, 10, 'ikke bytt ut'),
(34433, 1753, 10, 'Vil du virkelig slette denne gruppen'),
(34434, 1763, 10, 'DOB mangler, Skriv in hvis mulig'),
(34435, 1766, 10, 'Doktor:'),
(34436, 1768, 10, 'Dokument'),
(34437, 1770, 10, 'Dokument Kategori'),
(34438, 1777, 10, 'Dokumentasjons Dato'),
(34439, 1791, 10, 'Dokumenter'),
(34440, 1801, 10, 'Ikke lagre'),
(34441, 1802, 10, 'Ikke lagre Endringer'),
(34442, 1804, 10, 'Ferdig Med:'),
(34443, 1807, 10, 'Dosering'),
(34444, 1810, 10, 'Dobbelt syn'),
(34445, 1828, 10, 'Dr Sjekk'),
(34446, 1829, 10, 'Dr Besøk'),
(34447, 1834, 10, 'Medisin'),
(34448, 1839, 10, 'Medisin Inventar'),
(34449, 1840, 10, 'Medisin navn'),
(34450, 1846, 10, 'Medisiner'),
(34451, 1847, 10, 'Medikamenter og Produkter'),
(34452, 1848, 10, 'Tørr munn'),
(34453, 1880, 10, 'varighet'),
(34454, 1881, 10, 'Varighet'),
(34455, 1904, 10, 'Rediger'),
(34456, 1905, 10, 'rediger'),
(34457, 1906, 10, 'Rediger Allergier'),
(34458, 1907, 10, 'Rediger Kategorier'),
(34459, 1909, 10, 'Rediger Definisjoner'),
(34460, 1910, 10, 'Rediger Diagnoser for'),
(34461, 1912, 10, 'Rediger Lokaler'),
(34462, 1914, 10, 'Rediger Informasjon om Lokaler'),
(34463, 1918, 10, 'Rediger Globale Innstillinger'),
(34464, 1923, 10, 'Rediger Struktur'),
(34465, 1924, 10, 'Rediger Bruker'),
(34466, 1925, 10, 'Rediger Brukerinnstillinger'),
(34467, 1928, 10, 'Utdannelse'),
(34468, 1929, 10, 'Utdannelses Dato'),
(34469, 1932, 10, 'Effektiv Dato'),
(34470, 1937, 10, 'Albue'),
(34471, 1938, 10, 'Albue problemer'),
(34472, 1939, 10, 'Elektronikk'),
(34473, 1949, 10, 'Epost'),
(34474, 1951, 10, 'Epost-adresse'),
(34475, 1957, 10, 'Epost fra Batchcom'),
(34476, 1958, 10, 'Epost-påminnelse'),
(34477, 1961, 10, 'Epost send før'),
(34478, 1962, 10, 'Epost Sender'),
(34479, 1965, 10, 'Epost Emne'),
(34480, 1971, 10, 'Nød kontakt'),
(34481, 1983, 10, 'Ansatt'),
(34482, 1984, 10, 'Arbeidsgiver'),
(34483, 1985, 10, 'Arbeidsgivers adresse'),
(34484, 1986, 10, 'Arbeidsgiver Data'),
(34485, 1989, 10, 'Tom'),
(34486, 1991, 10, 'Tom verdi i "Epost Timer"'),
(34487, 1992, 10, 'Tom verdi i "Epost Sender"'),
(34488, 1993, 10, 'Tom verdi i "Epost Emne"'),
(34489, 1994, 10, 'Tom verdi i "Epost Tekst"'),
(34490, 1996, 10, 'Tom verdi i "Passord"'),
(34491, 1997, 10, 'Tom verdi i "SMS Timer"'),
(34492, 1998, 10, 'Tom verdi i "SMS Tekst"'),
(34493, 1999, 10, 'Tom verdi i "Brukernavn"'),
(34494, 2068, 10, 'på'),
(34495, 2073, 10, 'Møte'),
(34496, 2075, 10, 'Møte '),
(34497, 2086, 10, 'Møte skjerma'),
(34498, 2091, 10, 'Møte nummer'),
(34499, 2111, 10, 'Møte:'),
(34500, 2113, 10, 'Møter'),
(34501, 2114, 10, 'Møter & skjemaer'),
(34502, 2116, 10, 'Møter ikke tilatt'),
(34503, 2117, 10, 'Rapport for Møter'),
(34504, 2118, 10, 'Møte seksjon'),
(34505, 2121, 10, 'Slutt'),
(34506, 2122, 10, 'Slutt (åååå-mm-dd): '),
(34507, 2123, 10, 'Slutt Dato'),
(34508, 2124, 10, 'Slutt dato'),
(34509, 2127, 10, 'Slutt Dato:'),
(34510, 2131, 10, 'Slutt Tid'),
(34511, 2176, 10, 'Epilepsi'),
(34512, 2181, 10, 'Slett'),
(34513, 2183, 10, 'Feil'),
(34514, 2188, 10, 'Feil i "Kjønn" valg'),
(34515, 2194, 10, 'Error i JA eller NEI valg'),
(34516, 2235, 10, 'Flere Feil'),
(34517, 2253, 10, 'Hendelse'),
(34518, 2254, 10, 'Hendelse begynner'),
(34519, 2255, 10, 'Hendelse Kategori'),
(34520, 2256, 10, 'Hendelses dato'),
(34521, 2257, 10, 'Forklaring av hendelsen'),
(34522, 2258, 10, 'Hendelses detaljer'),
(34523, 2259, 10, 'Hendelse gjentaes ikke'),
(34524, 2260, 10, 'Hendelses varighet'),
(34525, 2261, 10, 'Hendelses varighet i minutter'),
(34526, 2263, 10, 'Hendelses sted'),
(34527, 2264, 10, 'Hendelse gjentar seg hver'),
(34528, 2265, 10, 'Hendelse gjentar seg på'),
(34529, 2266, 10, 'Start tid for hendelsen'),
(34530, 2267, 10, 'Hendelses titel'),
(34531, 2268, 10, 'Hendelses titel'),
(34532, 2270, 10, 'Hendelser'),
(34533, 2271, 10, 'Hendelser for'),
(34534, 2272, 10, 'Hendelser åpnes i et nytt vindu'),
(34535, 2274, 10, 'Hver'),
(34536, 2275, 10, 'hver 3 time'),
(34537, 2276, 10, 'hver 4 time'),
(34538, 2277, 10, 'hver 5 time'),
(34539, 2278, 10, 'hver 6 time'),
(34540, 2279, 10, 'hver 8 time'),
(34541, 2280, 10, 'Hver Fjerde'),
(34542, 2281, 10, 'Annen hver'),
(34543, 2282, 10, 'Hver Tredje'),
(34544, 2301, 10, 'Øvnings Mønstre'),
(34545, 2304, 10, 'Avslutt fra administrasjon'),
(34546, 2306, 10, 'Utvid'),
(34547, 2308, 10, 'Utvid alt'),
(34548, 2311, 10, 'Utvidet oversikt'),
(34549, 2313, 10, 'Utløps'),
(34550, 2314, 10, 'Utløps Dato'),
(34551, 2315, 10, 'Utløper'),
(34552, 2316, 10, 'utløper om'),
(34553, 2317, 10, 'Eksporter'),
(34554, 2318, 10, 'Eksporter som CSV'),
(34555, 2327, 10, 'Eksporter til CSV'),
(34556, 2336, 10, 'Ekstern'),
(34557, 2345, 10, 'Eksterne Refferanser'),
(34558, 2349, 10, 'Øye-irritasjon'),
(34559, 2357, 10, 'Lokale'),
(34560, 2358, 10, 'lokale'),
(34561, 2372, 10, 'Lokale:'),
(34562, 2375, 10, 'Mislykket'),
(34563, 2390, 10, 'Familie Historie'),
(34564, 2392, 10, 'Familie Historie:'),
(34565, 2395, 10, 'Familie størrelse'),
(34566, 2400, 10, 'Far'),
(34567, 2403, 10, 'utmattet'),
(34568, 2404, 10, 'Faks'),
(34569, 2409, 10, 'Inkommende Fakser'),
(34570, 2410, 10, 'Utgående Fakser'),
(34571, 2413, 10, 'Februar'),
(34572, 2418, 10, 'Avgift'),
(34573, 2419, 10, 'avgift'),
(34574, 2421, 10, 'Avgifts skjema'),
(34575, 2423, 10, 'Avgifter'),
(34576, 2424, 10, 'Kvinnelig'),
(34577, 2426, 10, 'Kvinnelige Kondommer'),
(34578, 2434, 10, 'Feber'),
(34579, 2435, 10, 'Feber:'),
(34580, 2459, 10, 'Filnavn'),
(34581, 2461, 10, 'Filer'),
(34582, 2464, 10, 'Fyll inn her hvis du skal sende email påmindelser til pasient'),
(34583, 2473, 10, 'Filter'),
(34584, 2478, 10, 'Finansiell'),
(34585, 2484, 10, 'Finn'),
(34586, 2485, 10, 'Finn Tilgjengelige'),
(34587, 2486, 10, 'Finn Tilgjengelige Avtaler'),
(34588, 2487, 10, 'Finn Pasient'),
(34589, 2495, 10, 'Først'),
(34590, 2497, 10, 'Første dag i uken'),
(34591, 2498, 10, 'Fornavn'),
(34592, 2500, 10, 'Fornavn:'),
(34593, 2503, 10, 'Form'),
(34594, 2516, 10, 'Influensa vaksinasjon'),
(34595, 2520, 10, 'Følg manuelt'),
(34596, 2532, 10, 'Fot'),
(34597, 2533, 10, 'Fot Problemer'),
(34598, 2534, 10, 'Fot:'),
(34599, 2537, 10, 'Fotball Skade Rapport'),
(34600, 2538, 10, 'Fotplagg Type'),
(34601, 2539, 10, 'for'),
(34602, 2555, 10, 'for:'),
(34603, 2559, 10, 'Forarm'),
(34604, 2560, 10, 'Skjema'),
(34605, 2564, 10, 'Format'),
(34606, 2572, 10, 'Skjemaer'),
(34607, 2573, 10, 'Skjema Administrasjon'),
(34608, 2576, 10, 'Send videre via Fax'),
(34609, 2579, 10, 'Fjerde'),
(34610, 2581, 10, 'Brudd'),
(34611, 2594, 10, 'Fredag'),
(34612, 2595, 10, 'Fra'),
(34613, 2599, 10, 'Fra:'),
(34614, 2600, 10, 'Fra: '),
(34615, 2625, 10, 'Full Trenning'),
(34616, 2637, 10, 'Galle Steiner'),
(34617, 2638, 10, 'Spill periode'),
(34618, 2639, 10, 'Spill'),
(34619, 2651, 10, 'Kjønn '),
(34620, 2652, 10, 'Generelt'),
(34621, 2655, 10, 'Generel Service Kategori'),
(34622, 2670, 10, 'Generer brev som omhandler '),
(34623, 2677, 10, 'Generer rapport'),
(34624, 2682, 10, 'Generert på'),
(34625, 2683, 10, 'Genererer'),
(34626, 2694, 10, 'Global'),
(34627, 2724, 10, 'Gruppe'),
(34628, 2729, 10, 'Gruppe Nummer'),
(34629, 2731, 10, 'Gruppe:'),
(34630, 2732, 10, 'Gruppenavn'),
(34631, 2750, 10, 'Hender + Fingre'),
(34632, 2751, 10, 'Hånd Problemer'),
(34633, 2761, 10, 'Skadelige Aktiviteter'),
(34634, 2768, 10, 'Hode'),
(34635, 2772, 10, 'Hodepine'),
(34636, 2779, 10, 'Hjerte Infarkt'),
(34637, 2781, 10, 'Hjerte Svikt'),
(34638, 2783, 10, 'Hjerte Problemer'),
(34639, 2784, 10, 'Hjerte Operasjon'),
(34640, 2785, 10, 'Hjerte Transplantasjon'),
(34641, 2786, 10, 'HJERTE:'),
(34642, 2796, 10, 'Hjelp'),
(34643, 2797, 10, 'hjelp'),
(34644, 2815, 10, 'Herpes'),
(34645, 2822, 10, 'Skjult'),
(34646, 2824, 10, 'Skjul'),
(34647, 2825, 10, 'Skjul Detaljer'),
(34648, 2834, 10, 'Høyt Bloodtrykk'),
(34649, 2836, 10, 'Hofte + lysk'),
(34650, 2837, 10, 'Hofte og lysk'),
(34651, 2838, 10, 'Hofte Problemer'),
(34652, 2839, 10, 'Hofte Erstatning'),
(34653, 2847, 10, 'Historie'),
(34654, 2862, 10, 'Hold nede [Ctrl] for å velge flere eller til å ta bort individuelle'),
(34655, 2866, 10, 'Hjemme Telefon'),
(34656, 2869, 10, 'Hjemløs, osv'),
(34657, 2876, 10, 'Timer'),
(34658, 2878, 10, 'Hvordan inntraff skaden?'),
(34659, 2879, 10, 'Hvordan inntraff skaden?:'),
(34660, 2884, 10, 'HTML'),
(34661, 2892, 10, 'Hyperaktiv'),
(34662, 2900, 10, 'Jeg er opptatt under denne perioden.'),
(34663, 2901, 10, 'Jeg har ikke tilgang til å lese '),
(34664, 2927, 10, 'Hvis arbeidsløs skriv inn Student'),
(34665, 2933, 10, 'Hvis du vil forandre data typer, eller legge til rader eller kolonner'),
(34666, 2937, 10, 'Sykdom'),
(34667, 2942, 10, 'Immunisering'),
(34668, 2953, 10, 'Immuniseringer'),
(34669, 2956, 10, 'Implantater'),
(34670, 2957, 10, 'Import'),
(34671, 2969, 10, 'Importert fra Økonomi'),
(34672, 2973, 10, 'i'),
(34673, 2975, 10, 'i hvert øye'),
(34674, 2976, 10, 'i venstre øye'),
(34675, 2977, 10, 'i nesa'),
(34676, 2979, 10, 'i høyre øye'),
(34677, 2980, 10, 'innom hus'),
(34678, 2994, 10, 'innkom'),
(34679, 3001, 10, 'øket:'),
(34680, 3018, 10, 'Infeksjoner'),
(34681, 3026, 10, 'Info'),
(34682, 3027, 10, 'Info test 1'),
(34683, 3028, 10, 'Info test 2'),
(34684, 3029, 10, 'Info test 3'),
(34685, 3030, 10, 'Info test 4'),
(34686, 3031, 10, 'Info test 5'),
(34687, 3032, 10, 'Info test 6'),
(34688, 3045, 10, 'Oversikts Rapport Over Skade'),
(34689, 3047, 10, 'Skade Type'),
(34690, 3072, 10, 'Søvnløshet'),
(34691, 3074, 10, 'Inspisering'),
(34692, 3079, 10, 'Installer DB'),
(34693, 3084, 10, 'Instrukser:'),
(34694, 3087, 10, 'Forsikring'),
(34695, 3088, 10, 'forsikring'),
(34696, 3094, 10, 'Forsikrings Selskaper'),
(34697, 3095, 10, 'Forsikrings Selskap'),
(34698, 3096, 10, 'Forsikrings Selskap Søk/Legg til'),
(34699, 3098, 10, 'Forsikrings Data'),
(34700, 3100, 10, 'Forsikrings Nummer'),
(34701, 3103, 10, 'Forsikrings Giver'),
(34702, 3113, 10, 'Intern feil - ingen sider var valgt!'),
(34703, 3114, 10, 'Intern feil - Pasient ID var ikke oppgitt!'),
(34704, 3129, 10, 'Tolker'),
(34705, 3132, 10, 'Interval'),
(34706, 3151, 10, 'Ugyldige service koder'),
(34707, 3152, 10, 'Ugyldig kilde valg "'),
(34708, 3160, 10, 'Inventar Liste'),
(34709, 3185, 10, 'Uvanlig Hjerte Rytme'),
(34710, 3191, 10, 'feltet krever utfylling.'),
(34711, 3197, 10, 'Ikke gyldig (desimal fraksjoner er OK).'),
(34712, 3198, 10, 'Bruker PHP sikker modus?'),
(34713, 3216, 10, 'Problem'),
(34714, 3223, 10, 'Problemer'),
(34715, 3225, 10, 'Problemer (Skader/medisinske/allergi):'),
(34716, 3226, 10, 'Problemer og Møter'),
(34717, 3227, 10, 'Problemer og Møter for'),
(34718, 3228, 10, 'Problemer ikke tilgjengelig'),
(34719, 3229, 10, 'Problem seksjon'),
(34720, 3239, 10, 'Januar'),
(34721, 3243, 10, 'Beskrivelse av Jobb'),
(34722, 3249, 10, 'Juli'),
(34723, 3251, 10, 'Juni'),
(34724, 3255, 10, 'Begrunne'),
(34725, 3256, 10, 'Begrunne/Lagre'),
(34726, 3258, 10, 'ok, her er resten'),
(34727, 3265, 10, 'Nøkkelord'),
(34728, 3269, 10, 'Nyre kreft'),
(34729, 3270, 10, 'Nyre Svikt'),
(34730, 3271, 10, 'Nyre infeksjoner'),
(34731, 3272, 10, 'Nyre steiner'),
(34732, 3273, 10, 'Nyre transplantasjon'),
(34733, 3277, 10, 'Kne'),
(34734, 3278, 10, 'Kne Problemer'),
(34735, 3279, 10, 'Kne Erstatning'),
(34736, 3303, 10, 'Merke'),
(34737, 3308, 10, 'Merker'),
(34738, 3312, 10, 'Blødning/ Hudens kondisjon'),
(34739, 3316, 10, 'Språk'),
(34740, 3317, 10, 'Språk kode'),
(34741, 3318, 10, 'Språk definisjon lagt til'),
(34742, 3321, 10, 'Språk navn'),
(34743, 3325, 10, 'Siste'),
(34744, 3333, 10, 'Siste møte'),
(34745, 3344, 10, 'Etternavn'),
(34746, 3346, 10, 'Etternavn:'),
(34747, 3358, 10, 'Sist Besøk'),
(34748, 3385, 10, 'La være blankt for å holde passordet uforandret.'),
(34749, 3387, 10, 'Forlatt skjema'),
(34750, 3390, 10, 'Venstre'),
(34751, 3392, 10, 'venstre øre'),
(34752, 3394, 10, 'Venstre:'),
(34753, 3395, 10, 'Venstre: '),
(34754, 3397, 10, 'Lovlig'),
(34755, 3401, 10, 'Lengde'),
(34756, 3406, 10, 'Brev'),
(34757, 3423, 10, 'Livsstill'),
(34758, 3446, 10, 'Hvis Forsikrings selskaper'),
(34759, 3451, 10, 'Hvis lister'),
(34760, 3454, 10, 'Hvis Resepter'),
(34761, 3458, 10, 'Lister'),
(34762, 3470, 10, 'LASTER'),
(34763, 3473, 10, 'Lokal'),
(34764, 3495, 10, 'Inlogget'),
(34765, 3496, 10, 'Logget in som'),
(34766, 3497, 10, 'Logget in som: '),
(34767, 3498, 10, 'Logget ut.'),
(34768, 3500, 10, 'Log in'),
(34769, 3505, 10, 'Log ut'),
(34770, 3507, 10, 'Logger'),
(34771, 3522, 10, 'Lunge Kreft'),
(34772, 3524, 10, 'LUNGER:'),
(34773, 3525, 10, 'Lunger:'),
(34774, 3535, 10, 'Hoved Adresse'),
(34775, 3548, 10, 'Manlig'),
(34776, 3549, 10, 'Kondommer'),
(34777, 3614, 10, 'Medisinsk'),
(34778, 3620, 10, 'Medisinsk problem');
INSERT INTO `lang_definitions` VALUES
(34779, 3623, 10, 'Medisinske Problemer'),
(34780, 3624, 10, 'Medisinsk Historie'),
(34781, 3640, 10, 'Medisiner'),
(34782, 3641, 10, 'Medisiner:'),
(34783, 3647, 10, 'Menn'),
(34784, 3648, 10, 'Menn og Kvinner'),
(34785, 3649, 10, 'Bare Menn'),
(34786, 3654, 10, 'Psykisk Sykdom'),
(34787, 3661, 10, 'Melding'),
(34788, 3670, 10, 'MELDING:'),
(34789, 3673, 10, 'Metode'),
(34790, 3676, 10, 'Ødeleggelses Metode'),
(34791, 3687, 10, 'Mellom Navn'),
(34792, 3709, 10, 'minutter'),
(34793, 3710, 10, 'Minutter'),
(34794, 3717, 10, 'Bommet'),
(34795, 3726, 10, 'Mikset'),
(34796, 3733, 10, 'Mobil'),
(34797, 3753, 10, 'Man'),
(34798, 3754, 10, 'Man til Fre'),
(34799, 3756, 10, 'Mandag'),
(34800, 3758, 10, 'Måned'),
(34801, 3759, 10, 'måned'),
(34802, 3760, 10, 'Månedlig Perspektiv'),
(34803, 3761, 10, 'Måned(er)'),
(34804, 3771, 10, 'Mor'),
(34805, 3775, 10, 'Flytt'),
(34806, 3779, 10, 'Flytt til Pasient'),
(34807, 3797, 10, 'Flere steder'),
(34808, 3811, 10, 'Muskel skade'),
(34809, 3814, 10, 'Gjensidig Definert'),
(34810, 3823, 10, 'Navn'),
(34811, 3832, 10, 'Forsikrings Selskapets Navn'),
(34812, 3837, 10, 'Navn:'),
(34813, 3844, 10, 'Nasjonalitet'),
(34814, 3866, 10, 'Nakke'),
(34815, 3867, 10, 'Nakke Problemer'),
(34816, 3880, 10, 'Nerve skade'),
(34817, 3888, 10, 'Ny'),
(34818, 3889, 10, 'Ny=>'),
(34819, 3894, 10, 'Ny Avtale'),
(34820, 3895, 10, 'Nye Kategorier'),
(34821, 3897, 10, 'Nye Klienter'),
(34822, 3912, 10, 'Ny Gruppe'),
(34823, 3921, 10, 'Ny Pasient'),
(34824, 3932, 10, 'Ny Bruker'),
(34825, 3962, 10, 'Neste'),
(34826, 3964, 10, 'Neste Dag'),
(34827, 3965, 10, 'Neste Måned'),
(34828, 3968, 10, 'Neste Uke'),
(34829, 3971, 10, 'Kallenavn'),
(34830, 3975, 10, 'Nei'),
(34831, 3976, 10, 'NEI'),
(34832, 3977, 10, 'Ingen tilgang'),
(34833, 3992, 10, 'Ingen Diagnose'),
(34834, 3995, 10, 'Ingen slutt dato'),
(34835, 4001, 10, 'Ingen gruppe var valgt'),
(34836, 4006, 10, 'Ingen Forsikrings Selskap Funnet'),
(34837, 4039, 10, 'Ingen Partnere Funnet'),
(34838, 4089, 10, 'Ingen'),
(34839, 4090, 10, 'ingen'),
(34840, 4093, 10, 'Ingen av de ovenfor'),
(34841, 4097, 10, 'Normal'),
(34842, 4101, 10, 'Normal Lunge Eksaminering:'),
(34843, 4102, 10, 'Normal Lunge Eksaminering: '),
(34844, 4105, 10, 'Normal Høyre'),
(34845, 4106, 10, 'Normal Høyre:'),
(34846, 4108, 10, 'normal:'),
(34847, 4120, 10, 'Ikke Tilatt'),
(34848, 4121, 10, 'Ikke tilatt å slette administrators gruppe'),
(34849, 4143, 10, 'Ikke Eksaminert'),
(34850, 4144, 10, 'Ikke Eksaminert:'),
(34851, 4145, 10, 'Ikke Eksaminert: '),
(34852, 4152, 10, 'Ikke sett siden'),
(34853, 4157, 10, 'Notat'),
(34854, 4182, 10, 'Ingenting var valgt'),
(34855, 4191, 10, 'November'),
(34856, 4200, 10, 'Nummer'),
(34857, 4237, 10, 'Okkupering'),
(34858, 4241, 10, 'Oktober'),
(34859, 4245, 10, 'av tabletter'),
(34860, 4249, 10, 'Kontor Notater'),
(34861, 4263, 10, 'Avkom'),
(34862, 4267, 10, 'OK'),
(34863, 4272, 10, 'Gamle Klienter'),
(34864, 4286, 10, 'På'),
(34865, 4288, 10, 'På Hånden'),
(34866, 4299, 10, 'Bare Aktiv'),
(34867, 4316, 10, 'Åpen'),
(34868, 4333, 10, 'Valg'),
(34869, 4336, 10, 'Valgfritt'),
(34870, 4351, 10, 'Eller'),
(34871, 4362, 10, 'Bestilling'),
(34872, 4386, 10, 'Organ skade'),
(34873, 4387, 10, 'Organisasjon'),
(34874, 4402, 10, 'Annet'),
(34875, 4403, 10, 'annet'),
(34876, 4410, 10, 'annen måned'),
(34877, 4427, 10, 'Utfall'),
(34878, 4446, 10, 'Sider'),
(34879, 4447, 10, 'Betalt'),
(34880, 4450, 10, 'Betalt Via'),
(34881, 4463, 10, 'Partner'),
(34882, 4472, 10, 'Passord'),
(34883, 4473, 10, 'Endre Passord'),
(34884, 4486, 10, 'Passord:'),
(34885, 4495, 10, 'Tidligere Møter'),
(34886, 4496, 10, 'Tidligere Møter og Dokumenter'),
(34887, 4514, 10, 'Pasient'),
(34888, 4522, 10, 'Pasient Allergier'),
(34889, 4523, 10, 'Pasient Avtale'),
(34890, 4544, 10, 'Pasient Dokument'),
(34891, 4561, 10, 'Pasient Historie'),
(34892, 4562, 10, 'Pasient Historie / Livsstill'),
(34893, 4573, 10, 'Pasient Problemer'),
(34894, 4587, 10, 'Pasientens Medisinske Problemer'),
(34895, 4597, 10, 'Pasient Notater'),
(34896, 4599, 10, 'Pasient Nummer'),
(34897, 4620, 10, 'Pasient Rapport'),
(34898, 4633, 10, 'Pasient/Klient'),
(34899, 4634, 10, 'Pasient:'),
(34900, 4636, 10, 'Pasienter'),
(34901, 4640, 10, 'Betalings Dato:'),
(34902, 4645, 10, 'Betaler'),
(34903, 4674, 10, 'Venter'),
(34904, 4729, 10, 'Telefon'),
(34905, 4738, 10, 'Telefon Nummer'),
(34906, 4759, 10, 'Piller'),
(34907, 4841, 10, 'Vær vennlig å betal denne summen'),
(34908, 4897, 10, 'Polise'),
(34909, 4904, 10, 'Dårlig Appetit'),
(34910, 4905, 10, 'Dårlig Sirkulasjon'),
(34911, 4906, 10, 'Dårlig Hørsel'),
(34912, 7084, 10, 'versjon'),
(34913, 7091, 10, 'Se'),
(34914, 7097, 10, 'Viss omfattende pasient rapport'),
(34915, 7103, 10, 'Se handlinger i et popup vindu?'),
(34916, 7124, 10, 'Se:'),
(34917, 7133, 10, 'Besøks Kategori:'),
(34918, 7134, 10, 'Besøks dato'),
(34919, 7140, 10, 'Besøk'),
(34920, 7141, 10, 'Besøk Fra'),
(34921, 7151, 10, 'W'),
(34922, 7154, 10, 'venter'),
(34923, 7182, 10, 'Web side'),
(34924, 7184, 10, 'Ons'),
(34925, 7185, 10, 'Onsdag'),
(34926, 7186, 10, 'Uke'),
(34927, 7187, 10, 'uke'),
(34928, 7188, 10, 'Uke oversikt'),
(34929, 7189, 10, 'Uke(r)'),
(34930, 7197, 10, 'Vekt tap'),
(34931, 7202, 10, 'Var servicen relatert til en nødsituasjon?'),
(34932, 7203, 10, 'Hva skal taes med i betraktning?'),
(34933, 7205, 10, 'veser'),
(34934, 7211, 10, 'vesing'),
(34935, 7226, 10, 'innen timer'),
(34936, 7227, 10, 'innen timer:'),
(34937, 7228, 10, 'innen minuter'),
(34938, 7229, 10, 'innen minuter:'),
(34939, 7232, 10, 'Foruten oppdatering'),
(34940, 7233, 10, 'Vitne'),
(34941, 7237, 10, 'Kvinner'),
(34942, 7238, 10, 'Kun kvinner'),
(34943, 7240, 10, 'Arbeid'),
(34944, 7241, 10, 'ARBEIDS NOTIS'),
(34945, 7242, 10, 'Jobb telefon'),
(34946, 7244, 10, 'Arbeids relatert?'),
(34947, 7246, 10, 'Arbeid/Skole notis'),
(34948, 7264, 10, 'Håndledd'),
(34949, 7265, 10, 'Håndledd og hånd'),
(34950, 7266, 10, 'Håndledds problemer'),
(34951, 7268, 10, 'skriv av'),
(34952, 7274, 10, 'x kansellert'),
(34953, 7275, 10, 'Røntgen'),
(34954, 7285, 10, 'År'),
(34955, 7286, 10, 'år'),
(34956, 7287, 10, 'År oversikt'),
(34957, 7288, 10, 'År'),
(34958, 7292, 10, 'JA'),
(34959, 7293, 10, 'Ja'),
(34960, 7294, 10, 'ja'),
(34961, 7295, 10, 'JA!'),
(34962, 7299, 10, 'Ja:'),
(34963, 7305, 10, 'Du har ikke tilgang til å slette denne hendelsen'),
(34964, 7306, 10, 'Du har ikke tilgang til å forandre på denne hendelsen'),
(34965, 7307, 10, 'Du har ikke tilgang til dette'),
(34966, 7313, 10, 'Du får ikke tilgang til denne funksjonen direkte'),
(34967, 7314, 10, 'Du får ikke tilgang til denne siden direkte'),
(34968, 7319, 10, 'Du valgte ingen hendelser'),
(34969, 7329, 10, 'Velg eller lag en pasient først'),
(34970, 7330, 10, 'Velg eller lag et møte'),
(34971, 7339, 10, 'Din slutt dato er ugyldig'),
(34972, 7340, 10, 'Din sak har blitt slettet'),
(34973, 7341, 10, 'Din sak har blitt forandret'),
(34974, 7342, 10, 'Din sak har blitt sendtDin'),
(34975, 7353, 10, 'postkallenderen dins konfigurasjon har blitt tilbakestilt til utganspunktet'),
(34976, 7354, 10, 'Postkallenderen dins konfigurasjon har blitt oppdatert'),
(34977, 7355, 10, 'Din gjentagelses frekvens må være et siffer.'),
(34978, 7356, 10, 'Din gjentagelses frekvens må være minst 1.'),
(34979, 7357, 10, 'Din start dato er større en din slutt dato'),
(34980, 7358, 10, 'Din start dato er ikke gyldig'),
(34981, 7360, 10, 'åååå-mm-dd'),
(34982, 7362, 10, 'åååå-mm-dd datoer assosiert med dette dokumentet'),
(34983, 7364, 10, 'åååå-mm-dd fødselsdato'),
(34984, 7365, 10, 'åååå-mm-dd Fødselsdato'),
(34985, 7371, 10, 'åååå-mm-dd dato for bedring eller slutt av medikament'),
(34986, 7373, 10, 'åååå-mm-dd dato for service'),
(34987, 7374, 10, 'åååå-mm-dd datoen til dette brevet'),
(34988, 7376, 10, 'åååå-mm-dd hendelses dato eller start dato'),
(34989, 7383, 10, 'åååå-mm-dd siste dato for denne hendelsen'),
(34990, 7389, 10, 'Postnummer'),
(34991, 7390, 10, 'Postnummer'),
(34992, 7391, 10, 'Postnummer'),
(34993, 7393, 10, ' men var '),
(34994, 7394, 10, ' kunne ikke få tilgang'),
(34995, 7395, 10, 'er du sikker på at du vil slette dette?'),
(34996, 7396, 10, 'medisin'),
(34997, 7397, 10, 'epost ikke sendt'),
(34998, 7398, 10, 'fra'),
(34999, 7399, 10, 'har blitt laget '),
(35000, 7400, 10, 'har blitt åpnet igjen'),
(35001, 7401, 10, 'Historie'),
(35002, 7402, 10, 'er ikke et nummer'),
(35003, 7403, 10, 'er klar for sending av regning om igjen'),
(35004, 7406, 10, 'original medicaid referanse Nr '),
(35005, 7408, 10, 'ikke funnet!'),
(35006, 7410, 10, 'reseptet har nådd grensen sin av'),
(35007, 7411, 10, 'inntil'),
(35008, 7412, 10, 'oppdatering feilet, ikke i databasen?'),
(35009, 7414, 10, 'var vellyket satt i kø'),
(35010, 7415, 10, '! Dro uten besøk'),
(35011, 7416, 10, '"for kode'),
(35012, 7417, 10, '"er SJEKKET av i Postkalender instillinger!'),
(35013, 7419, 10, '# av tabletter:'),
(35014, 7421, 10, '$ Koding ferdig'),
(35015, 7422, 10, '$merket (åååå-mm-dd): '),
(35016, 7425, 10, '% Kansellert < 24t '),
(35017, 7426, 10, 'burde eksistere men gjør ikke det.'),
(35018, 7433, 10, '(Ny pasient)'),
(35019, 7434, 10, '(Notater og Tillatelser)'),
(35020, 7435, 10, '(Pasient Notater)'),
(35021, 7438, 10, '*Påminnelse gjort'),
(35022, 7439, 10, '**Flytt operasjoner til Problemer!'),
(35023, 7440, 10, '*Nødvendig'),
(35024, 7447, 10, '0-10'),
(35025, 7483, 10, '3 måneder'),
(35026, 7485, 10, '3 ganger daglig'),
(35027, 7491, 10, '4 måneder'),
(35028, 7493, 10, '4 ganger daglig'),
(35029, 7498, 10, '466.0, akut bronkit'),
(35030, 7501, 10, '491.8, Kronisk bronkit'),
(35031, 7502, 10, '493.92, Akut astma'),
(35032, 7511, 10, '6 måneder'),
(35033, 7526, 10, '99212 Opprettet - Ukomplisert'),
(35034, 7527, 10, '99213 Opprettet - lite komplisert'),
(35035, 7528, 10, '< i undersøkelses rommet'),
(35036, 7529, 10, '> Sjekket ut'),
(35037, 7531, 10, '? Ikke vist seg'),
(35038, 7532, 10, '@ Ankommet'),
(35039, 7533, 10, '[Skifte perspektiv]'),
(35040, 7534, 10, '[Dato for siste besøk]'),
(35041, 7535, 10, '[Dager siden siste besøk]'),
(35042, 7538, 10, '[ikke anbefalt]'),
(35043, 7539, 10, '[Antall besøk]'),
(35044, 7540, 10, '[Rapporter]'),
(35045, 7541, 10, '[Velg alle]'),
(35046, 7543, 10, '[Start Batch prosessering]'),
(35047, 7544, 10, '[Se logg]'),
(35048, 7545, 10, '[Se printvennlig versjon av Rapport]'),
(35049, 7549, 10, '~ Ankom sent'),
(35050, 1, 11, '一'),
(35051, 2, 11, '支票或索赔编号用于辨别付款'),
(35052, 3, 11, '管理员用户的客户端证书'),
(35053, 7, 11, '需要一个分销商'),
(35054, 8, 11, '本次门诊应添加一个GCAC门诊表格'),
(35055, 9, 11, '需要一个批号'),
(35056, 10, 11, '需要一个批号！'),
(35057, 11, 11, '小写字母'),
(35058, 12, 11, '数字'),
(35059, 14, 11, '已有客户持有此身份证号。'),
(35060, 15, 11, '已有客户使用此姓名。'),
(35061, 16, 11, '已有客户使用此身份证号。'),
(35062, 19, 11, '可为每次门诊标明转介来源。'),
(35063, 20, 11, '需要一个相关的IPPF代码！'),
(35064, 21, 11, '一个特殊字符'),
(35065, 22, 11, '一个辨认此域的独有值，用户看不到'),
(35066, 24, 11, 'a.c.'),
(35067, 25, 11, '上午'),
(35068, 26, 11, 'A/F级右侧：'),
(35069, 27, 11, 'AB'),
(35070, 28, 11, '缩写'),
(35071, 29, 11, '脓肿：'),
(35072, 30, 11, '腹部'),
(35073, 31, 11, '能承受重量四(4)步骤：'),
(35074, 32, 11, '异常的'),
(35075, 33, 11, '异常1'),
(35076, 34, 11, '异常的'),
(35077, 35, 11, '异常的血液测验'),
(35078, 36, 11, '异常的毛发生长'),
(35079, 37, 11, '异常的乳房X光'),
(35080, 39, 11, '堕胎'),
(35081, 40, 11, '堕胎问题'),
(35082, 41, 11, '堕胎方式'),
(35083, 42, 11, '与堕胎有关的分类'),
(35084, 43, 11, '堕胎'),
(35085, 44, 11, '关于日历'),
(35086, 46, 11, '缺席的诊断'),
(35087, 47, 11, '接受指派'),
(35088, 48, 11, '接受付款'),
(35089, 49, 11, '接受付款 '),
(35090, 50, 11, '接受指派'),
(35091, 51, 11, '访问权限管理'),
(35092, 52, 11, '访问权限列表管理'),
(35093, 54, 11, '禁止访问'),
(35094, 56, 11, '访问客户管理门户'),
(35095, 59, 11, '帐号名'),
(35096, 62, 11, '会计'),
(35097, 64, 11, '疼痛'),
(35098, 65, 11, '确认要求（ISA14）'),
(35099, 67, 11, 'ACL'),
(35100, 68, 11, 'ACL管理'),
(35101, 69, 11, '未授权管理ACL'),
(35102, 71, 11, '粉刺'),
(35103, 72, 11, '行动'),
(35104, 73, 11, '行动日期'),
(35105, 74, 11, '行动'),
(35106, 75, 11, '行动'),
(35107, 77, 11, '启动CCR/CCD报表'),
(35108, 78, 11, '起始治疗'),
(35109, 79, 11, '起始治疗提示'),
(35110, 80, 11, '起始治疗提示规则'),
(35111, 81, 11, '起始治疗提示'),
(35112, 82, 11, '起始治疗接触'),
(35113, 84, 11, '起始治疗清单'),
(35114, 85, 11, '起始治疗客户'),
(35115, 86, 11, '起始治疗计划'),
(35116, 87, 11, '治疗方案'),
(35117, 88, 11, '治疗类型'),
(35118, 92, 11, '急性或慢性'),
(35119, 93, 11, '添加'),
(35120, 94, 11, '添加'),
(35121, 95, 11, '添加'),
(35122, 96, 11, '添加单位'),
(35123, 98, 11, '添加药房'),
(35124, 100, 11, '添加事件为 '),
(35125, 101, 11, '添加为新备注'),
(35126, 102, 11, '添加为新增'),
(35127, 104, 11, '添加按钮'),
(35128, 105, 11, '添加特殊字符按钮，以单机方式在编辑器顶部显示'),
(35129, 106, 11, '添加分类'),
(35130, 107, 11, '添加常数'),
(35131, 108, 11, '添加上下文'),
(35132, 109, 11, '添加共付额'),
(35133, 110, 11, '添加标准'),
(35134, 111, 11, '添加自定义按钮'),
(35135, 112, 11, '添加诊断'),
(35136, 113, 11, '添加药物'),
(35137, 114, 11, '添加治疗接触'),
(35138, 115, 11, '添加治疗接触/备注'),
(35139, 116, 11, '添加设施'),
(35140, 117, 11, '添加字段'),
(35141, 118, 11, '添加以下行到Apache配置文件'),
(35142, 119, 11, '添加组'),
(35143, 120, 11, '添加ICD码'),
(35144, 121, 11, '添加免疫'),
(35145, 122, 11, '无权限执行添加！'),
(35146, 123, 11, '添加问题'),
(35147, 125, 11, '添加语言'),
(35148, 126, 11, '新增'),
(35149, 127, 11, '新增'),
(35150, 128, 11, '新增类别： '),
(35151, 129, 11, '新增证书到Apache配置文件'),
(35152, 132, 11, '新增组'),
(35153, 134, 11, '新增批号和交易'),
(35154, 135, 11, '新增备注'),
(35155, 136, 11, '新增备注'),
(35156, 137, 11, '新增伙伴'),
(35157, 140, 11, '添加备注'),
(35158, 141, 11, '添加病历'),
(35159, 142, 11, '添加处方'),
(35160, 144, 11, '添加专家编号'),
(35161, 145, 11, '添加康复'),
(35162, 146, 11, '添加规则'),
(35163, 147, 11, '添加到'),
(35164, 148, 11, '添加到药品清单'),
(35165, 149, 11, '添加最高级别'),
(35166, 150, 11, '添加交易'),
(35167, 151, 11, '添加用户'),
(35168, 152, 11, '添加到用户组'),
(35169, 153, 11, '添加/编辑eRX'),
(35170, 154, 11, '添加/编辑客户交易'),
(35171, 155, 11, '添加完毕'),
(35172, 156, 11, '不允许添加户口资料'),
(35173, 160, 11, '附加属性'),
(35174, 161, 11, '附加诊断：'),
(35175, 162, 11, '附加病史'),
(35176, 163, 11, '附加病史备注'),
(35177, 164, 11, '其它信息'),
(35178, 165, 11, '附加实验室'),
(35179, 166, 11, '附加备注'),
(35180, 168, 11, '附加备注：'),
(35181, 169, 11, '附加备注： '),
(35182, 170, 11, '额外的X射线备注：'),
(35183, 172, 11, '只添加'),
(35184, 173, 11, '通讯录'),
(35185, 174, 11, '通讯录'),
(35186, 175, 11, '地址'),
(35187, 178, 11, '通讯录'),
(35188, 179, 11, '执行此疗程的单位通讯录条目'),
(35189, 180, 11, '经销商的通讯录'),
(35190, 181, 11, '供应商的通讯录'),
(35191, 182, 11, '通讯录类型'),
(35192, 187, 11, '地址1'),
(35193, 188, 11, '地址2'),
(35194, 189, 11, '收件人'),
(35195, 190, 11, '调整'),
(35196, 191, 11, '调整金额'),
(35197, 192, 11, '调整'),
(35198, 193, 11, '调整'),
(35199, 194, 11, '调整金额'),
(35200, 195, 11, '调整原因'),
(35201, 196, 11, '将值调整为代码 '),
(35202, 197, 11, '调整'),
(35203, 198, 11, '行政调整'),
(35204, 199, 11, '管理员'),
(35205, 200, 11, '管理员Email地址'),
(35206, 201, 11, '管理方式'),
(35207, 202, 11, '管理'),
(35208, 203, 11, '管理工作由'),
(35209, 206, 11, '管理'),
(35210, 208, 11, '管理员'),
(35211, 209, 11, '管理员可以做任何事'),
(35212, 212, 11, '成人体重筛查和跟踪'),
(35213, 213, 11, '成人体重筛查和跟踪（CQM）'),
(35214, 214, 11, '事先指示'),
(35215, 215, 11, '事先指示'),
(35216, 216, 11, '事先指示警告'),
(35217, 218, 11, '高级的'),
(35218, 219, 11, '建议'),
(35219, 221, 11, '影响正常'),
(35220, 223, 11, '办公时间以外致电'),
(35221, 225, 11, '在执行上述配置，进口的管理客户端证书的浏览器并重新启动服务器（空密码）。'),
(35222, 226, 11, '保存后，点击[查看]检查错误日志。'),
(35223, 227, 11, '保存后，点击查看检查错误日志[ ]。'),
(35224, 228, 11, '保存您的批号后，点击[查看日志]检查错误。'),
(35225, 230, 11, '输入正确的信息后，点击"保存"按钮。'),
(35226, 233, 11, '再次'),
(35227, 234, 11, '年龄'),
(35228, 235, 11, '年龄按'),
(35229, 236, 11, '年龄分类'),
(35230, 237, 11, '年龄数据超出范围'),
(35231, 239, 11, '年龄从的格式无效'),
(35232, 240, 11, '年龄到的格式无效'),
(35233, 241, 11, '年龄从'),
(35234, 243, 11, '最大年龄'),
(35235, 244, 11, '最小年龄'),
(35236, 245, 11, '年龄范围'),
(35237, 247, 11, '实效列：'),
(35238, 249, 11, '阿尔巴尼亚人'),
(35239, 250, 11, '酒精'),
(35240, 251, 11, '酒精消耗量'),
(35241, 253, 11, '提醒次数'),
(35242, 255, 11, '提醒'),
(35243, 258, 11, 'ALEUT'),
(35244, 259, 11, '全部'),
(35245, 260, 11, '全部'),
(35246, 261, 11, '全部(整合格式A)'),
(35247, 262, 11, '全部(整合格式B)'),
(35248, 263, 11, '全部(渐增)'),
(35249, 266, 11, '所有类别'),
(35250, 268, 11, '所有编码'),
(35251, 269, 11, '全天'),
(35252, 270, 11, '全天活动'),
(35253, 271, 11, '所有个人户口资料字段，附带搜索和重复检查'),
(35254, 272, 11, '所有设施'),
(35255, 273, 11, '所有伤害/问题'),
(35256, 274, 11, '所有允许的语言'),
(35257, 276, 11, '名字的全部或部分'),
(35258, 277, 11, '姓氏的全部或部分'),
(35259, 278, 11, '组织的全部或部分'),
(35260, 280, 11, '所有产品'),
(35261, 281, 11, '所有服务者'),
(35262, 282, 11, '所有已评估的胶片：'),
(35263, 283, 11, '所有主题'),
(35264, 284, 11, '所有用户'),
(35265, 285, 11, '过敏'),
(35266, 286, 11, '过敏症'),
(35267, 287, 11, '过敏症：'),
(35268, 288, 11, '过敏症'),
(35269, 289, 11, '过敏清单导入完成'),
(35270, 291, 11, '过敏反应'),
(35271, 294, 11, '分配'),
(35272, 295, 11, '允许'),
(35273, 296, 11, '登入时提供所有可用语言选择'),
(35274, 297, 11, '允许创建包含诊断的索偿，不包含程序或收费。大部分诊所不需要这。'),
(35275, 298, 11, '允许调试语言'),
(35276, 299, 11, '允许电子邮件'),
(35277, 300, 11, '是否允许电子邮件信息？'),
(35278, 301, 11, '是否允许电子邮件？'),
(35279, 302, 11, '允许接触的索赔'),
(35280, 303, 11, '允许健康信息交换'),
(35281, 304, 11, '允许分享免疫信息'),
(35282, 305, 11, '允许用于免疫注册'),
(35283, 306, 11, '允许邮件信息'),
(35284, 308, 11, '允许客户网站'),
(35285, 309, 11, '允许短信'),
(35286, 310, 11, '是否允许短信(文本信息)？'),
(35287, 311, 11, '是否允许将提交事件作出了执行的？'),
(35288, 312, 11, '是否允许电话留言？'),
(35289, 313, 11, '允许用户发布全局活动'),
(35290, 314, 11, '允许用户发布个人日历'),
(35291, 315, 11, '允许使用语音留言'),
(35292, 316, 11, '允许的'),
(35293, 317, 11, '允许的语言'),
(35294, 318, 11, '允许(c）'),
(35295, 323, 11, '已经存在'),
(35296, 324, 11, '已经存在。'),
(35297, 325, 11, '已使用，选择另一个标识符'),
(35298, 326, 11, '已使用，选择另一个名称'),
(35299, 327, 11, '备选地址'),
(35300, 328, 11, '备选'),
(35301, 329, 11, '“或者，你可以使用搜索页面上传文件，您从您的付款人或票据交换所获得的电子汇款（ X12的835 ） 。您可以通过点击”浏览“按钮并选择要上传的文件，然后单击搜索以执行上传，并显示相应的发票。其他参数，在这种情况下，上述不适用，将被忽略，上传的文件保存，但还没有处理它的内容 - 。分别完成如下所述”'),
(35302, 330, 11, '上午'),
(35303, 331, 11, '上午计划'),
(35304, 332, 11, '先天多发性关节挛缩症'),
(35305, 333, 11, '先天多发性关节挛缩症追踪'),
(35306, 338, 11, '修订现有备注'),
(35307, 343, 11, '印第安人'),
(35308, 344, 11, '美洲印地安人或阿拉斯加原住民'),
(35309, 345, 11, '美国运通'),
(35310, 346, 11, '阿姆哈啦語'),
(35311, 347, 11, '金额'),
(35312, 349, 11, '收费金额'),
(35313, 350, 11, '过去平衡的金额'),
(35314, 351, 11, '本次诊疗金额'),
(35315, 352, 11, '已付金额'),
(35316, 353, 11, '金额：'),
(35317, 354, 11, '已开发票金额'),
(35318, 355, 11, '重复活动的结束日期必须晚于起始日期！'),
(35319, 357, 11, '导出LibreEHR网页目录时错误'),
(35320, 358, 11, '导出phpGACL网页目录时错误'),
(35321, 359, 11, '导出SQL数据库时错误'),
(35322, 360, 11, '一个不完成的GCAC问题已经被创建和连接，稍后需要有人去完成。'),
(35323, 362, 11, '发生意外的错误。'),
(35324, 363, 11, '一个大写字母'),
(35325, 365, 11, '以及'),
(35326, 366, 11, '以及'),
(35327, 367, 11, '以及'),
(35328, 368, 11, '以及 '),
(35329, 369, 11, '以及所有从属数据？此次操作将被记录'),
(35330, 370, 11, '以及修改'),
(35331, 371, 11, '并处理。'),
(35332, 372, 11, '重新启动Apache服务器。'),
(35333, 373, 11, '并且原因是'),
(35334, 374, 11, '贫血'),
(35335, 375, 11, '腳踝'),
(35336, 376, 11, '腳踝 +足跟'),
(35337, 377, 11, '腳踝评估表'),
(35338, 378, 11, '腳踝问题'),
(35339, 379, 11, '强直性脊柱炎'),
(35340, 380, 11, '强直性脊柱炎'),
(35341, 381, 11, '厌食'),
(35342, 382, 11, '另一件事，你可以在发布窗口是要求二次计费。保存之前，如果您选择此复选框，然后在原索赔将被重新打开计费页上，将在下一次计费中处理。“'),
(35343, 383, 11, '前'),
(35344, 385, 11, '焦虑'),
(35345, 386, 11, '任何'),
(35346, 387, 11, '任何类别'),
(35347, 388, 11, '任何部分或其所需的代码说明'),
(35348, 389, 11, '任何部分的理想专业'),
(35349, 390, 11, '任何药物编号或药物名称的一部分'),
(35350, 391, 11, '免疫标识或免疫名称的任何部分'),
(35351, 392, 11, '患者姓名的任何部分，或“最后，第一”或“的XY ”'),
(35352, 394, 11, '短信网关的API密钥'),
(35353, 395, 11, '窒息'),
(35354, 396, 11, '外观'),
(35355, 397, 11, '外观：'),
(35356, 398, 11, '附加本备注'),
(35357, 399, 11, '附加到现有备注'),
(35358, 400, 11, '附加到本备注'),
(35359, 401, 11, '附加到本备注'),
(35360, 402, 11, '阑尾切除术'),
(35361, 404, 11, '适用患者'),
(35362, 406, 11, '登录页面的应用程序的名称和主窗口的标题'),
(35363, 407, 11, '应用接收器代码（如果ISA08空白将使用GS03 ）'),
(35364, 408, 11, '应用发件人代码（ GS02 ）'),
(35365, 409, 11, '应用程序标题'),
(35366, 410, 11, '在生命微像和生长曲线图上适用'),
(35367, 412, 11, '修改应用到当前的事件，这和所有未来的事件，或全部事件？'),
(35368, 413, 11, '适用于受影响地区'),
(35369, 414, 11, '适用于皮肤'),
(35370, 415, 11, '应用'),
(35371, 416, 11, '应用补丁到网站上'),
(35372, 417, 11, '预约'),
(35373, 418, 11, '预约日期'),
(35374, 419, 11, '预约显示格式'),
(35375, 420, 11, '预约提醒规则'),
(35376, 421, 11, '预约状态'),
(35377, 422, 11, '预约状态'),
(35378, 423, 11, '预约内容'),
(35379, 424, 11, '预约/事件颜色'),
(35380, 425, 11, '预约'),
(35381, 426, 11, '预约（可选写）'),
(35382, 430, 11, '预约和治疗'),
(35383, 431, 11, '预约报告'),
(35384, 432, 11, '预约-治疗报告'),
(35385, 434, 11, '批准'),
(35386, 436, 11, '批准'),
(35387, 437, 11, '批准事件管理'),
(35388, 440, 11, 'Appt-Enc'),
(35389, 441, 11, '聘任'),
(35390, 442, 11, '四月'),
(35391, 443, 11, '四月'),
(35392, 444, 11, '阿拉伯'),
(35393, 447, 11, '门诊控制组名称要翻译吗？'),
(35394, 448, 11, '预约类名称要翻译吗？'),
(35395, 449, 11, '文档类名称要翻译吗？'),
(35396, 450, 11, '这种类型要收费吗？'),
(35397, 451, 11, '患者备注标题要翻译吗？'),
(35398, 452, 11, '是代码存储在外部数据库表（0 -没有，1-icd10，2-snomed（rf1），3-snomed（rf2））？'),
(35399, 453, 11, '是否准备一个新的GCAC来完成此次门诊？'),
(35400, 455, 11, '你确定要批准这些事件吗？'),
(35401, 457, 11, '你确定你要完全消除这种形式吗？'),
(35402, 459, 11, '你确定要删除这个泄露？'),
(35403, 460, 11, '你确定要删除这个事件？'),
(35404, 461, 11, '你确定要从数据库中删除这个项目吗？'),
(35405, 462, 11, '你确定要删除这个备注吗 ？'),
(35406, 464, 11, '你确定要编辑这些事件？'),
(35407, 465, 11, '你确定要隐藏这些事件？'),
(35408, 467, 11, '你确定要浏览这些事件？'),
(35409, 468, 11, '你确定要删除整组命名？'),
(35410, 469, 11, '你确定要删除整个清单？'),
(35411, 470, 11, '你确定要删除字段？'),
(35412, 471, 11, '你确定要删除选定的字段吗？'),
(35413, 472, 11, '你确定你想继续这些操作吗？'),
(35414, 473, 11, '区域未指定'),
(35415, 474, 11, '手臂'),
(35416, 475, 11, '亚美尼亚语'),
(35417, 477, 11, '心律失常'),
(35418, 478, 11, '关节炎'),
(35419, 479, 11, '关节炎/退化性关节疾病'),
(35420, 480, 11, '关节炎/退化性关节疾病'),
(35421, 481, 11, '同样的'),
(35422, 482, 11, '作为'),
(35423, 484, 11, '亚洲'),
(35424, 487, 11, '评价'),
(35425, 488, 11, '分配给'),
(35426, 489, 11, '助理'),
(35427, 490, 11, '哮喘'),
(35428, 491, 11, '在'),
(35429, 492, 11, '如果你选择全部，至少有一个搜索参数是必需的。'),
(35430, 493, 11, '在舟状骨'),
(35431, 494, 11, '在舟状骨'),
(35432, 495, 11, '田径队'),
(35433, 497, 11, '田径/损伤'),
(35434, 498, 11, 'ATNA审计CA证书'),
(35435, 499, 11, 'ATNA审计主机'),
(35436, 500, 11, 'ATNA审计的本地证书'),
(35437, 501, 11, 'ATNA审计端口'),
(35438, 503, 11, '注意项'),
(35439, 504, 11, '经办人'),
(35440, 509, 11, '审计备份日志'),
(35441, 510, 11, '审计杂项日志'),
(35442, 511, 11, '审计采购日志'),
(35443, 512, 11, '审计客户记录日志'),
(35444, 513, 11, '审计调度日志'),
(35445, 514, 11, '审计安全管理日志'),
(35446, 515, 11, '审计查询日志'),
(35447, 516, 11, '八月'),
(35448, 517, 11, '八月'),
(35449, 519, 11, '验证'),
(35450, 520, 11, '验证/备注'),
(35451, 523, 11, '授权组'),
(35452, 525, 11, '授权组'),
(35453, 526, 11, '授权组'),
(35454, 527, 11, '授权-任何治疗'),
(35455, 528, 11, '授权-我的治疗'),
(35456, 530, 11, '授权'),
(35457, 531, 11, '只授权'),
(35458, 532, 11, '自动发送'),
(35459, 535, 11, '自动-创建新的治疗'),
(35460, 536, 11, '自动生成'),
(35461, 537, 11, '自动测量计算（AMC）'),
(35462, 542, 11, '自动追踪测量计算（AMC）'),
(35463, 543, 11, '自动措施（AMC）'),
(35464, 544, 11, '自动'),
(35465, 546, 11, '自动创建一个新的约会时治疗的状态设置为“@”（到）。'),
(35466, 549, 11, '汽车医疗'),
(35467, 550, 11, '自动保存'),
(35468, 551, 11, '可用类别'),
(35469, 552, 11, '可用时间'),
(35470, 557, 11, '平均每月'),
(35471, 558, 11, '撕脱/撕脱骨折'),
(35472, 559, 11, '外踝撕脱'),
(35473, 560, 11, '内踝撕脱 '),
(35474, 561, 11, '感知的'),
(35475, 562, 11, '腋窝'),
(35476, 565, 11, '出价'),
(35477, 566, 11, '回来'),
(35478, 567, 11, '回来'),
(35479, 568, 11, '后八次门诊'),
(35480, 569, 11, '后十一次门诊'),
(35481, 570, 11, '后五次门诊'),
(35482, 571, 11, '后四次门诊'),
(35483, 572, 11, '后九次门诊'),
(35484, 573, 11, '返回门诊'),
(35485, 574, 11, '背部疼痛'),
(35486, 575, 11, '背部问题'),
(35487, 576, 11, '后七次门诊'),
(35488, 577, 11, '后六次门诊'),
(35489, 578, 11, '背部手术'),
(35490, 579, 11, '后十次门诊'),
(35491, 580, 11, '后三次门诊'),
(35492, 584, 11, '回到客户'),
(35493, 586, 11, '回观'),
(35494, 587, 11, '后十二次门诊'),
(35495, 588, 11, '复诊两次'),
(35496, 590, 11, '备用的，备份文件'),
(35497, 591, 11, '备份文件已经建立，将要发送下载'),
(35498, 593, 11, '备份成功建立'),
(35499, 594, 11, '空头支票'),
(35500, 595, 11, '呆账（收不回的帐）'),
(35501, 596, 11, '印度尼西亚语'),
(35502, 597, 11, '巴拉腊特（美、澳地名）'),
(35503, 598, 11, '结账平衡'),
(35504, 599, 11, '结平（账目）'),
(35505, 601, 11, '由于负债'),
(35506, 603, 11, '银行汇票'),
(35507, 607, 11, '第五Metarsal底部（基地）'),
(35508, 608, 11, '第五Metarsal底部（基地）'),
(35509, 612, 11, '成批通信工具'),
(35510, 613, 11, '批量付款条目'),
(35511, 615, 11, '批处理开始，这可能需要一段时间。'),
(35512, 616, 11, '批处理结果'),
(35513, 617, 11, '批量命令，批量Com'),
(35514, 619, 11, '因为我不存在'),
(35515, 620, 11, '开始'),
(35516, 621, 11, '开始日期'),
(35517, 623, 11, '服务开始日期，以年/月/日形式'),
(35518, 624, 11, '日历事项上一天开始的时间'),
(35519, 626, 11, '打嗝，吐出'),
(35520, 630, 11, '两者之间'),
(35521, 633, 11, '双边的，双向的；两侧的。'),
(35522, 634, 11, '双边的，双向的；两侧的。'),
(35523, 636, 11, '账单日期'),
(35524, 637, 11, '账单/收账'),
(35525, 638, 11, '给……开账单；为……发提货单；把……登录在帐'),
(35526, 640, 11, '开具账单，营业额'),
(35527, 641, 11, '计费（写可选）'),
(35528, 642, 11, '结算经办人'),
(35529, 644, 11, '结算规范要求的服务'),
(35530, 645, 11, '结算代码'),
(35531, 646, 11, '结算日期'),
(35532, 647, 11, '结算部门'),
(35533, 648, 11, '结算设备'),
(35534, 649, 11, '结算信息'),
(35535, 650, 11, '帐单位置'),
(35536, 655, 11, '结账经理'),
(35537, 656, 11, '结算说明'),
(35538, 657, 11, '结算说明 '),
(35539, 658, 11, '帐单票据：'),
(35540, 659, 11, '结算队列结果：'),
(35541, 660, 11, '结算报告'),
(35542, 662, 11, '开票状态=未开票'),
(35543, 663, 11, '帐单 '),
(35544, 665, 11, '或组织检查，活体检视'),
(35545, 666, 11, '出生日期'),
(35546, 669, 11, '黑色'),
(35547, 670, 11, '黑（矽）肺病，肺尘病'),
(35548, 671, 11, '黑人或者非裔美国人'),
(35549, 672, 11, '膀胱癌'),
(35550, 673, 11, '膀胱感染'),
(35551, 674, 11, '空白表格'),
(35552, 675, 11, '出血问题'),
(35553, 676, 11, '盲点'),
(35554, 677, 11, '膨胀'),
(35555, 678, 11, '封锁'),
(35556, 679, 11, '血液'),
(35557, 680, 11, '血压'),
(35558, 681, 11, '血压'),
(35559, 682, 11, '鼻子出血'),
(35560, 683, 11, '蓝十字蓝盾'),
(35561, 684, 11, '蓝线在本报告中的信息。黑色的线条显示先前存在的信息。绿色线条显示变化，成功的应用。红色线显示错误'),
(35562, 685, 11, '视力模糊'),
(35563, 686, 11, '体质指数'),
(35564, 687, 11, '体质指数等级'),
(35565, 689, 11, '身体部位'),
(35566, 690, 11, '身体位置'),
(35567, 691, 11, '身体位置'),
(35568, 692, 11, '骨嫩：'),
(35569, 693, 11, '骨嫩：内踝'),
(35570, 694, 11, '布尔'),
(35571, 696, 11, '博特'),
(35572, 697, 11, '双耳'),
(35573, 698, 11, '双耳'),
(35574, 699, 11, '底部'),
(35575, 701, 11, '方框10 A.就业相关 '),
(35576, 702, 11, '方框10湾车祸 '),
(35577, 703, 11, '方框10 C.其他事故 '),
(35578, 706, 11, '方框15.日期相同或类似的疾病(年-月-日）'),
(35579, 708, 11, '方框16 。日期无法工作（格式yyyy - mm - DD ）的：'),
(35580, 709, 11, '方框16 。日期无法工作（格式yyyy - mm - DD ）的：'),
(35581, 710, 11, '箱18 。住院日（格式yyyy - mm - DD ）的： '),
(35582, 711, 11, '箱18 。住院日期（格式yyyy - mm - DD ）的： '),
(35583, 712, 11, '箱20 。境外实验室使用？'),
(35584, 713, 11, '箱22 。医疗重新码（的ICD - 9 ） '),
(35585, 714, 11, '箱23 。事先授权号 '),
(35586, 715, 11, '血压'),
(35587, 716, 11, '舒张压'),
(35588, 717, 11, '收缩压'),
(35589, 719, 11, 'Bpd'),
(35590, 721, 11, 'Bps'),
(35591, 722, 11, '巴西葡萄牙语'),
(35592, 723, 11, '乳房'),
(35593, 724, 11, '乳腺活组织检查'),
(35594, 725, 11, '乳腺排出物'),
(35595, 726, 11, '乳腺疾病'),
(35596, 727, 11, '乳房检查'),
(35597, 728, 11, '乳房肿块'),
(35598, 730, 11, '呼吸音：'),
(35599, 732, 11, '骨折'),
(35600, 734, 11, '支气管炎表格'),
(35601, 735, 11, '浏览'),
(35602, 736, 11, '浏览记录'),
(35603, 737, 11, '青肿/血肿'),
(35604, 739, 11, '胀右：'),
(35605, 741, 11, '燃烧排尿'),
(35606, 742, 11, '燃烧排尿'),
(35607, 744, 11, '忙碌的'),
(35608, 745, 11, '但尚未处理的。'),
(35609, 746, 11, '臀部'),
(35610, 747, 11, '臀部+副省长'),
(35611, 748, 11, '通过'),
(35612, 749, 11, '通过'),
(35613, 750, 11, '经口'),
(35614, 751, 11, '文/来源'),
(35615, 752, 11, '方式：'),
(35616, 753, 11, 'C'),
(35617, 754, 11, '证书验证的玫瑰花5425协议日志服务器。'),
(35618, 755, 11, '缓存寿命（秒）'),
(35619, 756, 11, '缓存模板输出？'),
(35620, 757, 11, '喝咖啡'),
(35621, 758, 11, '日历'),
(35622, 759, 11, '日历结束时间'),
(35623, 760, 11, '日历区间'),
(35624, 761, 11, '日历画面'),
(35625, 762, 11, '日历设置'),
(35626, 763, 11, '日历开始时间'),
(35627, 764, 11, '日历界面'),
(35628, 765, 11, '日历视图'),
(35629, 766, 11, '呼吁addForm（ ）这里。'),
(35630, 767, 11, '卡路里'),
(35631, 768, 11, '柬埔寨'),
(35633, 774, 11, '取消'),
(35634, 775, 11, '取消变更'),
(35635, 776, 11, '取消'),
(35636, 777, 11, '癌症'),
(35637, 778, 11, '癌症检查：结肠癌的筛查'),
(35638, 779, 11, '癌症检查：检查'),
(35639, 780, 11, '癌症检查：子宫颈抹片'),
(35640, 781, 11, '癌症检查：前列腺癌的筛查'),
(35641, 782, 11, '无法添加该项已经存在！'),
(35642, 783, 11, '无法添加/更新这项重复已经存在！'),
(35643, 785, 11, '不能转换为JPEG格式。也许照片管理没有安装？'),
(35644, 787, 11, '无法显示内置类型，因为它不支持的浏览器。'),
(35645, 788, 11, '无法显示内置类型，因为它不支持的浏览器'),
(35646, 789, 11, '无法显示内置类型，因为它不支持的浏览器。'),
(35647, 790, 11, '无法创建'),
(35648, 795, 11, '无法找到 '),
(35649, 796, 11, '找不到目标文件名'),
(35650, 799, 11, '找不到客户从SQL查问客户ID'),
(35651, 800, 11, '找不到后记中提到的文件 '),
(35652, 801, 11, '找不到提供商从SQL查问雇员= '),
(35653, 802, 11, '不能修改支付未分配是否定的。'),
(35654, 803, 11, '无法打开 '),
(35655, 804, 11, '不能为保险付费单位选定的客户。'),
(35656, 805, 11, '不能为客户支付单位选定的保险。'),
(35657, 806, 11, '不能支付未分配是否定的。'),
(35658, 807, 11, '不能读'),
(35659, 808, 11, '无法读取目录'),
(35660, 809, 11, '不能更新，是因为您没有编辑现有条目！'),
(35661, 810, 11, '利用'),
(35662, 812, 11, '胶囊'),
(35663, 813, 11, '卡片'),
(35664, 814, 11, '心导管'),
(35665, 815, 11, '心脏回声'),
(35666, 816, 11, '心血管'),
(35667, 821, 11, '软骨/软骨/椎间盘损伤'),
(35668, 822, 11, '软骨损伤'),
(35669, 823, 11, '颈动脉搏动荷，踏板脉冲荷'),
(35670, 824, 11, '现金'),
(35671, 825, 11, '现金'),
(35672, 826, 11, '现金市盈率'),
(35673, 827, 11, '现金收据的服务人员'),
(35674, 829, 11, '白内障手术'),
(35675, 830, 11, '白内障'),
(35676, 831, 11, '分类'),
(35677, 832, 11, '分类'),
(35678, 833, 11, '分类'),
(35679, 834, 11, '分类'),
(35680, 835, 11, '分类 '),
(35681, 836, 11, '分类信息'),
(35682, 837, 11, '分类界限'),
(35683, 838, 11, '分类名称'),
(35684, 839, 11, '类别名称是空的'),
(35685, 840, 11, '分类标题'),
(35686, 841, 11, '高加索'),
(35687, 842, 11, '原因收据打印治疗/主要服务人员信息'),
(35688, 852, 11, '手机'),
(35689, 853, 11, '手机'),
(35690, 855, 11, '手机号码'),
(35691, 856, 11, '中央认证'),
(35692, 857, 11, '中美洲和南美洲'),
(35693, 858, 11, '证书权威阴极射线管文件的位置不能为空'),
(35694, 859, 11, '证书颁发机构密钥文件位置不能为空'),
(35695, 860, 11, '证书送玫瑰花5425协议日志服务器。'),
(35696, 861, 11, '证书用户'),
(35697, 862, 11, '证书'),
(35698, 864, 11, '保健医疗计划'),
(35699, 865, 11, '保健医疗计划'),
(35700, 866, 11, '更改'),
(35701, 867, 11, '更改'),
(35702, 868, 11, '变更活动'),
(35703, 870, 11, '视力变化'),
(35704, 871, 11, '视力变化'),
(35705, 874, 11, '改变'),
(35706, 875, 11, '改变肠'),
(35707, 877, 11, '特征'),
(35708, 878, 11, '剩余字符'),
(35709, 879, 11, '电荷'),
(35710, 880, 11, '费用调整'),
(35711, 882, 11, '收费'),
(35712, 883, 11, '病历'),
(35713, 884, 11, '病历活动'),
(35714, 885, 11, '病历登记/登出活动报告'),
(35715, 886, 11, '病历编号：'),
(35716, 887, 11, '病历编号：'),
(35717, 889, 11, '病历地点活动'),
(35718, 890, 11, '病历附注'),
(35719, 891, 11, '病历编号：'),
(35720, 892, 11, '病历存放地址'),
(35721, 893, 11, '病历跟踪'),
(35722, 894, 11, '病历蒂尔克'),
(35723, 895, 11, '病历借出'),
(35724, 896, 11, '病历输出'),
(35725, 898, 11, '检查'),
(35726, 899, 11, '检查'),
(35727, 900, 11, '检查所有'),
(35728, 902, 11, '检查金额'),
(35729, 903, 11, '检查日期'),
(35730, 904, 11, '检查差异与习语翻译表。'),
(35731, 906, 11, '登记到'),
(35732, 907, 11, '检查输入数据'),
(35733, 909, 11, '检查实验室成果'),
(35734, 912, 11, '检查号码'),
(35735, 915, 11, '检查付款'),
(35736, 916, 11, '检查框，如果这是一个加密文件'),
(35737, 917, 11, '检查如果您想提供者看到所有任命了违约，不只是自己。'),
(35738, 919, 11, '检查/ EOB日期：'),
(35739, 920, 11, '检查/ EOB编号：'),
(35740, 921, 11, '检查/参考编号'),
(35741, 922, 11, '检查/编号'),
(35742, 923, 11, '复选框列表'),
(35743, 924, 11, '复选框列表'),
(35744, 925, 11, '复选框瓦特/文'),
(35745, 926, 11, '复选框瓦特/文'),
(35746, 928, 11, '选中'),
(35747, 929, 11, '检查盒=，=没有空'),
(35748, 932, 11, '结帐'),
(35749, 933, 11, '检验和'),
(35750, 934, 11, '胸膛'),
(35751, 935, 11, '公益金的CTAB'),
(35752, 936, 11, '胸痛：'),
(35753, 937, 11, '胸痛：'),
(35754, 938, 11, '胸部疼痛'),
(35755, 940, 11, '孟加拉'),
(35756, 942, 11, '主诉'),
(35757, 943, 11, '儿童'),
(35758, 945, 11, '儿童免疫接种状况（CQM）'),
(35759, 946, 11, '冷'),
(35760, 947, 11, '中文'),
(35761, 948, 11, '中文简体'),
(35762, 949, 11, '中文繁体'),
(35763, 951, 11, '选择'),
(35764, 952, 11, '胆囊切除术'),
(35765, 954, 11, '胆囊切除术'),
(35766, 955, 11, '选择'),
(35767, 956, 11, '选择一个部分，点击一个项目内；然后在其他部分你会看到有关项目突出，你可以点击，添加和删除的关系。'),
(35768, 957, 11, '选择标准'),
(35769, 962, 11, '选择表格'),
(35770, 965, 11, '选择打印格式该报告。'),
(35771, 967, 11, '慢性支气管炎'),
(35772, 968, 11, '慢性关节痛'),
(35773, 969, 11, '慢性肾脏疾病（慢性肾病）'),
(35774, 970, 11, '慢性滑膜炎/积液/关节疼痛/痛风'),
(35775, 971, 11, '慢性/复发'),
(35776, 973, 11, '肝硬化'),
(35777, 974, 11, '肝硬化肝'),
(35778, 975, 11, '城市'),
(35779, 976, 11, '城市名称'),
(35780, 977, 11, '城市，国家'),
(35781, 978, 11, '市，州邮编'),
(35782, 979, 11, '城市/州'),
(35783, 980, 11, '主张'),
(35784, 981, 11, '主张 '),
(35785, 983, 11, '索赔运行测试已完成'),
(35786, 986, 11, '索赔产生的文件 '),
(35787, 988, 11, '分类'),
(35788, 989, 11, '清楚的'),
(35789, 991, 11, '全部清除'),
(35790, 992, 11, '明确的标准数据'),
(35791, 993, 11, '明确的理由'),
(35792, 994, 11, '明确Smarty缓存'),
(35793, 995, 11, '结算信息需要联通270批创作。'),
(35794, 996, 11, '集数'),
(35795, 997, 11, '点击'),
(35796, 998, 11, '点击''出口''出口您的类别，子类别，项目，内容数据到一个文本文件。任何相似性这一文件的文件是纯粹的巧合。开幕式和闭幕式的标签必须在同一行，他们必须小写没有空间。进口，浏览文件并单击“导入”。如果数据是完全不同的，它将与您现有的数据。如果有类似的项目名称，旧将保持和新的保存与一个号码添加到结束。'),
(35797, 999, 11, '点击一个点上的图形添加一个新的诠释，再次点击删除”'),
(35798, 1000, 11, '点击下载证书下载证书的文件ssl.zip'),
(35799, 1001, 11, '点击查看更多'),
(35800, 1005, 11, '点击这里'),
(35801, 1006, 11, '点击此处添加一个新的客户。'),
(35802, 1007, 11, '点击此处新增损伤改变现状和编辑日常活动'),
(35803, 1008, 11, '点击这里选择日期'),
(35804, 1009, 11, '点击这里选择日期和时间'),
(35805, 1010, 11, '点击这里选择开始日期'),
(35806, 1020, 11, '点击这里搜索'),
(35807, 1021, 11, '点击这里更新优先'),
(35808, 1022, 11, '点击此处查看全部。'),
(35809, 1023, 11, '点击这里查看和图'),
(35810, 1025, 11, '点击这里查看和图形所有生命迹象。'),
(35811, 1026, 11, '点击这里查看客户的细节'),
(35812, 1027, 11, '点击这里查看他们所有。'),
(35813, 1029, 11, '点击安装按钮安装数据库释放从以下日期'),
(35814, 1030, 11, '点击任何地方的时间增加'),
(35815, 1031, 11, '点击打开文件名客户客户'),
(35816, 1032, 11, '点击刷新查看所有结果或请输入搜索标准查看结果。'),
(35817, 1034, 11, '点击新增组件'),
(35818, 1035, 11, '点击新增咨询'),
(35819, 1037, 11, '点击下载'),
(35820, 1038, 11, '点击修改'),
(35821, 1040, 11, '点击编辑这个事件'),
(35822, 1041, 11, '点击生成报告'),
(35823, 1043, 11, '点击打印'),
(35824, 1044, 11, '点击领取（添加）全新地段'),
(35825, 1045, 11, '单击以选中'),
(35826, 1046, 11, '点击选择'),
(35827, 1047, 11, '点击选择一个行业标准的代码，这个程序'),
(35828, 1050, 11, '点击以更改CVX编码'),
(35829, 1051, 11, '单击以选中或改变诊断'),
(35830, 1052, 11, '点击选择或更改服务代码'),
(35831, 1053, 11, '单击以选中客户'),
(35832, 1054, 11, '单击以选中相关的代码'),
(35833, 1055, 11, '点击选择服务执行这个结果是不正常的'),
(35834, 1056, 11, '点击选择需要的程序'),
(35835, 1058, 11, '点击查看'),
(35836, 1059, 11, '点击查看或编辑'),
(35837, 1060, 11, '点击查看/编辑'),
(35838, 1061, 11, '点击升级按钮升级数据库释放从以下日期'),
(35839, 1063, 11, '点击：'),
(35840, 1064, 11, '客户证书到期日'),
(35841, 1065, 11, '客户端证书有效期'),
(35842, 1066, 11, '客户端证书的有效性应是一个有效的数目。'),
(35843, 1067, 11, '客户端复制'),
(35844, 1069, 11, '客户端医学史'),
(35845, 1072, 11, '客户简介-新客户'),
(35846, 1073, 11, '客户简介-独特的客户'),
(35847, 1074, 11, '客户'),
(35848, 1075, 11, '诊所'),
(35849, 1076, 11, '诊所复制'),
(35850, 1077, 11, '诊所每日纪录'),
(35851, 1078, 11, '诊所编号'),
(35852, 1079, 11, '临床'),
(35853, 1080, 11, '临床决策规则警报'),
(35854, 1083, 11, '诊所计划'),
(35855, 1084, 11, '临床质量的措施（CQM）'),
(35856, 1087, 11, '临床指示'),
(35857, 1088, 11, '临床报告'),
(35858, 1089, 11, '临床规则的行动类'),
(35859, 1090, 11, '临床规则的行动项目'),
(35860, 1091, 11, '临床规则过滤方法'),
(35861, 1092, 11, '临床规则目标的方法'),
(35862, 1093, 11, '临床规则'),
(35863, 1094, 11, '临床规则的年龄间隔'),
(35864, 1095, 11, '临床规则比较'),
(35865, 1096, 11, '临床规则治疗的类型'),
(35866, 1097, 11, '由于临床规则提醒选项'),
(35867, 1098, 11, '临床规则提醒失活的选择'),
(35868, 1099, 11, '临床规则提示间隔'),
(35869, 1100, 11, '临床规则提醒方法'),
(35870, 1101, 11, '临床规则目标间隔'),
(35871, 1102, 11, '临床目标'),
(35872, 1106, 11, '临床医生'),
(35873, 1107, 11, '克隆'),
(35874, 1108, 11, '克隆过去的门诊'),
(35875, 1109, 11, '关闭'),
(35876, 1111, 11, '关闭窗口'),
(35877, 1112, 11, '公开'),
(35878, 1113, 11, '厘米'),
(35879, 1114, 11, '1500利润'),
(35880, 1118, 11, '不育系编号'),
(35881, 1127, 11, 'CN2网络- 12完整'),
(35882, 1130, 11, '共付款'),
(35883, 1131, 11, '码'),
(35884, 1132, 11, '代码'),
(35885, 1133, 11, '代码查找'),
(35886, 1134, 11, '代码必须是两个字母小写'),
(35887, 1135, 11, '代码或符号表示货币'),
(35888, 1136, 11, '代码文本'),
(35889, 1138, 11, '代码类型'),
(35890, 1141, 11, '代码类型'),
(35891, 1144, 11, '码'),
(35892, 1145, 11, '编码'),
(35893, 1147, 11, '编码-任何治疗（写wsome可选）'),
(35894, 1148, 11, '编码-任何治疗（写wsome可选）'),
(35895, 1149, 11, '编码未授权'),
(35896, 1150, 11, '咖啡'),
(35897, 1152, 11, '共同保险'),
(35898, 1153, 11, '科尔W / O型'),
(35899, 1154, 11, '折叠'),
(35900, 1155, 11, '折叠'),
(35901, 1156, 11, '全部折叠'),
(35902, 1157, 11, '全部折叠'),
(35903, 1158, 11, '全部折叠'),
(35904, 1161, 11, '集合'),
(35905, 1162, 11, '馆藏报告'),
(35906, 1163, 11, '结肠癌'),
(35907, 1164, 11, '结肠癌的筛查'),
(35908, 1165, 11, '结肠癌手术'),
(35909, 1166, 11, '结肠镜检查'),
(35910, 1167, 11, '结肠镜检查'),
(35911, 1168, 11, '彩色'),
(35912, 1169, 11, '颜色：简称'),
(35913, 1170, 11, '列'),
(35914, 1171, 11, '专栏'),
(35915, 1172, 11, '结合大量'),
(35916, 1173, 11, '逗号'),
(35917, 1174, 11, '评论'),
(35918, 1175, 11, '评论'),
(35919, 1176, 11, '这一结果或推荐意见'),
(35920, 1177, 11, '商业保险有限公司'),
(35921, 1178, 11, '承诺更改'),
(35922, 1180, 11, '通信'),
(35923, 1182, 11, '公司'),
(35924, 1183, 11, '公司名称'),
(35925, 1184, 11, '完全'),
(35926, 1186, 11, '完成'),
(35927, 1188, 11, '完成？'),
(35928, 1190, 11, '并发症的服务提供商'),
(35929, 1191, 11, '堕胎并发症'),
(35930, 1192, 11, '组件'),
(35931, 1193, 11, '医学计算机辅助订货系统'),
(35932, 1194, 11, '结论'),
(35933, 1199, 11, '配置'),
(35934, 1200, 11, '配置导入/导出'),
(35935, 1202, 11, '配置及libreehr使用客户端证书。'),
(35936, 1203, 11, '配置要使用客户端证书'),
(35937, 1204, 11, '配置要使用加密。'),
(35938, 1205, 11, '配置libreehr使用客户端证书'),
(35939, 1208, 11, '创建确认新客户'),
(35940, 1209, 11, '创建新的密码'),
(35941, 1210, 11, '创建新的付款方式'),
(35942, 1214, 11, '先天性'),
(35943, 1215, 11, '结膜成形'),
(35944, 1218, 11, '常数'),
(35945, 1219, 11, '常量名'),
(35946, 1220, 11, '不断的名称是空的'),
(35947, 1221, 11, '常数'),
(35948, 1222, 11, '便秘'),
(35949, 1223, 11, '保健运动'),
(35950, 1226, 11, '咨询简介'),
(35951, 1227, 11, '联系方式'),
(35952, 1228, 11, '联系人电子邮件'),
(35953, 1229, 11, '联系电子邮件地址'),
(35954, 1231, 11, '联系信息'),
(35955, 1232, 11, '隐形眼镜'),
(35956, 1236, 11, '联系人姓名'),
(35957, 1237, 11, '联系人'),
(35958, 1239, 11, '联系电话号码'),
(35959, 1240, 11, '订阅服务的电子服务定联系LLC（zmghealth@gmail.com）'),
(35960, 1241, 11, '至少包含三个以下四个项目：'),
(35961, 1243, 11, '内容'),
(35962, 1244, 11, '内容'),
(35963, 1245, 11, '上下文'),
(35964, 1246, 11, '上下文的名称不能为空'),
(35965, 1247, 11, '继续'),
(35966, 1248, 11, '连续性的护理文件（电荷耦合器件）'),
(35967, 1249, 11, '持续护理记录（重整）'),
(35968, 1250, 11, '康特拉客户'),
(35969, 1251, 11, '避孕的'),
(35970, 1252, 11, '避孕的问题'),
(35971, 1253, 11, '避孕并发症（具体说明）'),
(35972, 1254, 11, '避孕方法'),
(35973, 1255, 11, '避孕产品'),
(35974, 1256, 11, '避孕服务以前开始'),
(35975, 1257, 11, '避孕药开始'),
(35976, 1258, 11, '控制编号'),
(35977, 1259, 11, '编号'),
(35978, 1262, 11, '挂号费'),
(35979, 1263, 11, '挂号费'),
(35980, 1264, 11, '不主动挂号'),
(35981, 1266, 11, '挂号费'),
(35982, 1267, 11, '慢性阻塞性肺病'),
(35983, 1268, 11, '复制页面客户图'),
(35984, 1269, 11, '复制价值观'),
(35985, 1270, 11, '复制数据库文件。这将需要一些时间…'),
(35986, 1271, 11, '版权声明'),
(35987, 1273, 11, '冠状动脉搭桥'),
(35988, 1274, 11, '冠状动脉旁路移植术（术）'),
(35989, 1275, 11, '改正'),
(35990, 1289, 11, '咳嗽'),
(35991, 1290, 11, '咳嗽：'),
(35992, 1294, 11, '无法读取文件'),
(35993, 1296, 11, '因服务器问题无法发送电子邮件 '),
(35994, 1298, 11, '无法创建备份目录：'),
(35995, 1299, 11, '不能删除目录：'),
(35996, 1300, 11, '无法删除旧的备份文件：'),
(35997, 1301, 11, '无法删除旧文件：'),
(35998, 1302, 11, '香豆管理-比值监测'),
(35999, 1303, 11, '顾问的方法'),
(36000, 1304, 11, '咨询'),
(36001, 1305, 11, '咨询活动'),
(36002, 1306, 11, '案子转介表格'),
(36003, 1307, 11, '案子转介'),
(36004, 1308, 11, '国家'),
(36005, 1309, 11, '国家数据类型'),
(36006, 1310, 11, '国家列表'),
(36007, 1311, 11, '国家名单（写只添加可选）'),
(36008, 1312, 11, '国家应在2个字母代表。（例如：United States 是 US）'),
(36009, 1313, 11, '县'),
(36010, 1315, 11, '优惠券'),
(36011, 1318, 11, '胸腔物理治疗'),
(36012, 1319, 11, '胸腔物理治疗代码'),
(36013, 1320, 11, '胸腔物理治疗代码'),
(36014, 1323, 11, '喹芥子气'),
(36015, 1324, 11, '裂纹：'),
(36016, 1325, 11, '奶油'),
(36017, 1326, 11, '创建一个客户端证书为每个用户或客户机。'),
(36018, 1327, 11, '创建一个客户端证书或者用户或客户端的名称。'),
(36019, 1329, 11, '创建活动'),
(36020, 1330, 11, '创建和下载一个完整备份'),
(36021, 1332, 11, '创建备份'),
(36022, 1333, 11, '创建批量'),
(36023, 1334, 11, '创建客户端证书'),
(36024, 1335, 11, '创建客户端SSL证书'),
(36025, 1336, 11, '创建副本'),
(36026, 1338, 11, '创建事件日志备份'),
(36027, 1339, 11, '创建新的问题'),
(36028, 1340, 11, '创造新的客户'),
(36029, 1342, 11, '建立异地门户凭据'),
(36030, 1343, 11, '建立本地门户凭据'),
(36031, 1344, 11, '创建患者注意'),
(36032, 1345, 11, '创建证书权威和服务器证书。'),
(36033, 1346, 11, '创建门诊'),
(36034, 1347, 11, '创建'),
(36035, 1348, 11, '创建导出文件'),
(36036, 1351, 11, '创建者'),
(36037, 1352, 11, '信贷'),
(36038, 1353, 11, '信用卡'),
(36039, 1354, 11, '信用'),
(36040, 1356, 11, '标准'),
(36041, 1358, 11, '克罗恩病'),
(36042, 1359, 11, '克罗恩病'),
(36043, 1360, 11, '导出成CSV格式'),
(36044, 1361, 11, 'CSV文件'),
(36045, 1363, 11, 'CU.MM'),
(36046, 1364, 11, '古巴语'),
(36047, 1365, 11, '货币小数'),
(36048, 1366, 11, '货币小数点符号'),
(36049, 1367, 11, '货币代号'),
(36050, 1368, 11, '货币的千位分隔符'),
(36051, 1369, 11, '当前的'),
(36052, 1370, 11, '目前酒精'),
(36053, 1371, 11, '目前的协商'),
(36054, 1372, 11, '当前标准'),
(36055, 1373, 11, '当天标明颜色'),
(36056, 1374, 11, '当天的吸烟者');
INSERT INTO `lang_definitions` VALUES
(36057, 1375, 11, '目前文件名改为'),
(36058, 1376, 11, '目前哈希'),
(36059, 1377, 11, '目前位置'),
(36060, 1378, 11, '目前药物'),
(36061, 1379, 11, '目前密码'),
(36062, 1380, 11, '目前客户'),
(36063, 1382, 11, '目前的娱乐性药物'),
(36064, 1383, 11, '目前有一天吸烟'),
(36065, 1386, 11, '目前活跃'),
(36066, 1388, 11, '目前没有任何设施。'),
(36067, 1389, 11, '柯兴综合征'),
(36068, 1390, 11, '柯兴综合征'),
(36069, 1392, 11, '风俗'),
(36070, 1393, 11, '自定义输入？'),
(36071, 1394, 11, '自定义表'),
(36072, 1396, 11, 'CVX编码'),
(36073, 1397, 11, 'CVX编码绘图'),
(36074, 1399, 11, '过期'),
(36075, 1400, 11, '色素'),
(36076, 1401, 11, '色素因子'),
(36077, 1402, 11, '色素报告'),
(36078, 1403, 11, '捷克语'),
(36079, 1404, 11, 'D'),
(36080, 1405, 11, '扩张宫颈及刮宫'),
(36081, 1406, 11, '发展和é'),
(36082, 1407, 11, 'D.O.B.'),
(36083, 1408, 11, '每日'),
(36084, 1409, 11, '日志'),
(36085, 1410, 11, '丹麦语'),
(36086, 1411, 11, '数据一样，是已经在数据库中，请改变代码和/或描述'),
(36087, 1412, 11, '数据一样，是已经在数据库中，请改变常量的名称'),
(36088, 1413, 11, '数据列'),
(36089, 1416, 11, '数据错误'),
(36090, 1420, 11, '数据类型'),
(36091, 1421, 11, '数据库'),
(36092, 1422, 11, '未安装数据库。'),
(36093, 1424, 11, '数据库报告'),
(36094, 1425, 11, '数据库升级完成。'),
(36095, 1426, 11, '数据列必须是一个数字1和999之间'),
(36096, 1427, 11, '日期'),
(36097, 1428, 11, '日期'),
(36098, 1431, 11, '迄今为止直辖'),
(36099, 1432, 11, '样品采集的日期和时间'),
(36100, 1433, 11, '这个观察的日期和时间'),
(36101, 1435, 11, '样品采集的日期和时间'),
(36102, 1436, 11, '日期不能比今天更大'),
(36103, 1437, 11, '迄今为止最初提供避孕服务'),
(36104, 1438, 11, '创建日期'),
(36105, 1439, 11, '最新的死者'),
(36106, 1440, 11, '日期毁坏'),
(36107, 1441, 11, '日期显示格式'),
(36108, 1442, 11, '日期格式为“任命结束”是无效的'),
(36109, 1443, 11, '日期格式为“任命开始”是无效的'),
(36110, 1444, 11, '日期格式“下一个约会”是无效的'),
(36111, 1445, 11, '日期格式“以来从未见过的”无效'),
(36112, 1446, 11, '日期格式“以来”是无效的'),
(36113, 1447, 11, '日期免疫信息陈述'),
(36114, 1448, 11, '日期代码遗失 '),
(36115, 1449, 11, '日期大师标准'),
(36116, 1450, 11, '银行存款日期年-月-日'),
(36117, 1452, 11, '出生日期'),
(36118, 1453, 11, '出生日期'),
(36119, 1454, 11, '出生日期'),
(36120, 1456, 11, '外伤日期'),
(36121, 1458, 11, '付款日期年-月-日'),
(36122, 1459, 11, '转介日期'),
(36123, 1460, 11, '答辩日期'),
(36124, 1463, 11, '送达日期'),
(36125, 1464, 11, '服务日期=今天'),
(36126, 1465, 11, '服务日期月-日-年'),
(36127, 1466, 11, '服务日期：'),
(36128, 1467, 11, '签字日期'),
(36129, 1469, 11, '这个命令的日期'),
(36130, 1470, 11, '这份报告的日期'),
(36131, 1471, 11, '可见声明日期'),
(36132, 1472, 11, '日期排列'),
(36133, 1475, 11, '日期选择'),
(36134, 1476, 11, '发送日期'),
(36135, 1477, 11, '消息被发送的日期'),
(36136, 1479, 11, '日期值不能为空。'),
(36137, 1480, 11, '日期/ APPT'),
(36138, 1481, 11, '日期/备注'),
(36139, 1482, 11, '最后日期/债券'),
(36140, 1483, 11, '日期/时间'),
(36141, 1484, 11, '日期：'),
(36142, 1485, 11, '过时的消息日志'),
(36143, 1486, 11, '天'),
(36144, 1487, 11, '天'),
(36145, 1489, 11, '日视图'),
(36146, 1490, 11, '天（S）'),
(36147, 1491, 11, '天（S）M - F'),
(36148, 1492, 11, '天'),
(36149, 1493, 11, '天'),
(36150, 1494, 11, '日前'),
(36151, 1495, 11, '天及投篮游戏'),
(36152, 1496, 11, '最后治疗天'),
(36153, 1497, 11, '天漏'),
(36154, 1498, 11, '每列的日子：'),
(36155, 1500, 11, '天/彩色：'),
(36156, 1501, 11, 'DB的安装'),
(36157, 1502, 11, '月/日/年'),
(36158, 1503, 11, '德鉴定'),
(36159, 1504, 11, '德识别过程完成'),
(36160, 1505, 11, '德识别过程是正在进行'),
(36161, 1506, 11, '德鉴定过程启动并运行在后台'),
(36162, 1507, 11, '德查明的数据可能是不完整的'),
(36163, 1508, 11, '德识别文件将被保存在'),
(36164, 1509, 11, 'DEA方法'),
(36165, 1511, 11, '聋'),
(36166, 1512, 11, '调试信息'),
(36167, 1515, 11, '十二月'),
(36168, 1516, 11, '死者'),
(36169, 1517, 11, '十二月'),
(36170, 1520, 11, '扣税'),
(36171, 1521, 11, '抵扣气象'),
(36172, 1522, 11, '默认'),
(36173, 1523, 11, '默认日历视图'),
(36174, 1524, 11, '默认治疗表格编号'),
(36175, 1526, 11, '默认设备'),
(36176, 1527, 11, '默认语言'),
(36177, 1528, 11, '允许或默认情况下，如果没有其他的语言选择。'),
(36178, 1529, 11, '默认列表（写'),
(36179, 1530, 11, '默认的方法'),
(36180, 1531, 11, '默认密码到期日'),
(36181, 1532, 11, '默认密码在天的有效期。 0表示禁用此功能。'),
(36182, 1533, 11, '默认患者国家'),
(36183, 1536, 11, '默认提供'),
(36184, 1537, 11, '默认范围'),
(36185, 1538, 11, '默认用餐的原因'),
(36186, 1540, 11, '默认设置'),
(36187, 1542, 11, '默认模板'),
(36188, 1546, 11, '默认单位'),
(36189, 1547, 11, '默认值'),
(36190, 1548, 11, '默认仓库'),
(36191, 1549, 11, '缺省值X12的合作伙伴'),
(36192, 1550, 11, '默认/全球'),
(36193, 1551, 11, '德尔'),
(36194, 1552, 11, '德尔'),
(36195, 1553, 11, '延迟复发（>12个月）'),
(36196, 1554, 11, '删除'),
(36197, 1555, 11, '删除'),
(36198, 1556, 11, '删除类别编号（补） ： '),
(36199, 1557, 11, '删除类别'),
(36200, 1560, 11, '删除组'),
(36201, 1561, 11, '删除列表'),
(36202, 1562, 11, '删除页面'),
(36203, 1563, 11, '删除客户'),
(36204, 1565, 11, '删除行'),
(36205, 1566, 11, '删除所选项目'),
(36206, 1568, 11, '删除成功。'),
(36207, 1569, 11, '删除这个文件'),
(36208, 1570, 11, '删除这个表格'),
(36209, 1571, 11, '删除本说明'),
(36210, 1573, 11, '成功删除。'),
(36211, 1581, 11, '痴呆'),
(36212, 1582, 11, '户口资料'),
(36213, 1583, 11, '户口资料（写、只添加都可选）'),
(36214, 1585, 11, '户口资料筛选条件'),
(36215, 1586, 11, '不允许设置户口资料'),
(36216, 1587, 11, '不允许设置户口资料。'),
(36217, 1588, 11, '拒绝'),
(36218, 1589, 11, '分母'),
(36219, 1590, 11, '牙科'),
(36220, 1592, 11, '牙科问题'),
(36221, 1595, 11, '根据条例草案，你正在测试，你会看到像输出HCFA票据HCFA一个空白的页面上，你会看到许多行有点乱码的文字和信息，如果你正在测试一个X12的索赔。这乱码的文字是X12的4010A的EDI格式。偶尔，你会看到奇怪的字符，看起来像多米诺骨牌或squiglies'),
(36222, 1596, 11, '存款日期'),
(36223, 1597, 11, '存款日期不能比今天更大'),
(36224, 1598, 11, '存款日期：'),
(36225, 1599, 11, '郁闷'),
(36226, 1600, 11, '萧条'),
(36227, 1602, 11, '描述'),
(36228, 1603, 11, '描述'),
(36229, 1605, 11, '披露的说明'),
(36230, 1606, 11, '这个过程或结果代码的说明'),
(36231, 1607, 11, '描写语言的翻译'),
(36232, 1609, 11, '目的地'),
(36233, 1610, 11, '目标文件名'),
(36234, 1611, 11, '破坏地段'),
(36235, 1612, 11, '摧毁...'),
(36236, 1613, 11, '销毁'),
(36237, 1614, 11, '销毁毒品'),
(36238, 1615, 11, '摧毁毒品报告'),
(36239, 1616, 11, '细节'),
(36240, 1617, 11, '详情'),
(36241, 1619, 11, '发育异常'),
(36242, 1620, 11, '糖尿病'),
(36243, 1621, 11, '糖尿病'),
(36244, 1622, 11, '糖尿病：血压管理（CQM）'),
(36245, 1623, 11, '糖尿病：眼睛考试'),
(36246, 1624, 11, '糖尿病：眼科检查（CQM）'),
(36247, 1625, 11, '糖尿病：足部检查'),
(36248, 1626, 11, '糖尿病：足部检查（CQM）'),
(36249, 1627, 11, '糖尿病：糖化血红蛋白控制能力较差（CQM）'),
(36250, 1628, 11, '糖尿病：糖化血红蛋白'),
(36251, 1629, 11, '糖尿病：LDL的管理和控制（CQM）'),
(36252, 1630, 11, '糖尿病：尿微量白蛋白'),
(36253, 1631, 11, '诊断'),
(36254, 1633, 11, '诊断'),
(36255, 1634, 11, '诊断代码'),
(36256, 1636, 11, '诊断日期'),
(36257, 1637, 11, '诊断必须被编码到一个链接的邂逅'),
(36258, 1638, 11, '诊断名称'),
(36259, 1639, 11, '诊断报告'),
(36260, 1642, 11, '诊断名称'),
(36261, 1643, 11, '诊断：'),
(36262, 1644, 11, '诊断： '),
(36263, 1645, 11, '诊断测试：'),
(36264, 1646, 11, '拨号'),
(36265, 1647, 11, '膜片/瓶盖'),
(36266, 1648, 11, '腹泻'),
(36267, 1650, 11, '听写'),
(36268, 1651, 11, '听写： '),
(36269, 1652, 11, '你收到一份HIPAA的通告？'),
(36270, 1653, 11, '弥漫性：'),
(36271, 1654, 11, '数字签名'),
(36272, 1657, 11, '商函'),
(36273, 1663, 11, '董事姓名'),
(36274, 1665, 11, '残疾'),
(36275, 1667, 11, '禁用日历'),
(36276, 1668, 11, '禁用走势跟踪'),
(36277, 1669, 11, '禁用免疫'),
(36278, 1670, 11, '停用旧表公制命脉'),
(36279, 1672, 11, '禁用的phpMyAdmin'),
(36280, 1673, 11, '禁用处方'),
(36281, 1674, 11, '禁用用户组'),
(36282, 1675, 11, '禁用'),
(36283, 1676, 11, '禁用'),
(36284, 1677, 11, '65岁以下，大集团的健康计划（LGHP禁用受益人）'),
(36285, 1678, 11, '光盘'),
(36286, 1681, 11, '排出'),
(36287, 1682, 11, '排放从尿道'),
(36288, 1684, 11, '排污权'),
(36289, 1685, 11, '排污权：'),
(36290, 1689, 11, '披露信息'),
(36291, 1690, 11, '披露类型'),
(36292, 1691, 11, '披露类型'),
(36293, 1692, 11, '披露'),
(36294, 1694, 11, '折扣'),
(36295, 1695, 11, '折扣额'),
(36296, 1696, 11, '折扣级别'),
(36297, 1697, 11, '折扣百分比'),
(36298, 1698, 11, '货币金额的折扣'),
(36299, 1699, 11, '折扣结帐时进入货币数量，而不是百分比。'),
(36300, 1700, 11, '结果离散'),
(36301, 1701, 11, '疾病'),
(36302, 1702, 11, '脱位'),
(36303, 1703, 11, '显示#'),
(36304, 1704, 11, '调度'),
(36305, 1705, 11, '调度收稿文件'),
(36306, 1706, 11, '配药'),
(36307, 1707, 11, '事前指示在人口统计页面显示。'),
(36308, 1709, 11, '展示活动日期块？'),
(36309, 1711, 11, '显示多少个活动？'),
(36310, 1713, 11, '显示位置块？'),
(36311, 1714, 11, '显示姓名'),
(36312, 1715, 11, '显示日历？'),
(36313, 1718, 11, '显示今天的事件块？'),
(36314, 1719, 11, '显示话题块？'),
(36315, 1720, 11, '即将举行的活动中显示块？'),
(36316, 1721, 11, '显示列'),
(36317, 1722, 11, '显示以下一些最新披露：'),
(36318, 1723, 11, '显示以下一些最新的笔记'),
(36319, 1724, 11, '显示以下一些最新的笔记'),
(36320, 1725, 11, '分布'),
(36321, 1726, 11, '分布'),
(36322, 1727, 11, '经销商'),
(36323, 1729, 11, '憩室'),
(36324, 1730, 11, '憩室外科'),
(36325, 1731, 11, 'divirticulitis'),
(36326, 1732, 11, 'divirticulitis外科'),
(36327, 1733, 11, '离婚'),
(36328, 1734, 11, '头晕：'),
(36329, 1735, 11, '不要改变'),
(36330, 1737, 11, '不显示上传到NewCrop过敏'),
(36331, 1739, 11, '不显示上传到NewCrop的药物'),
(36332, 1742, 11, '不显示日历。'),
(36333, 1744, 11, '不要库存和销售任何产品'),
(36334, 1745, 11, '不需要客户笔记被授权'),
(36335, 1746, 11, '不复苏订购的'),
(36336, 1747, 11, '不保存'),
(36337, 1748, 11, '不能取代'),
(36338, 1749, 11, '什么也不做'),
(36339, 1751, 11, '你真的要删除'),
(36340, 1752, 11, '你真的要删除的选择吗？'),
(36341, 1753, 11, '你真的要删除这个组'),
(36342, 1755, 11, '你要继续吗？'),
(36343, 1756, 11, '你要删除这个吗？'),
(36344, 1757, 11, '你要删除吗？'),
(36345, 1758, 11, '你想删除此记录？'),
(36346, 1759, 11, '你是否愿意继续加入这个新的客户吗？'),
(36347, 1760, 11, '你想继续用新的名称？'),
(36348, 1761, 11, '你想永久删除这个免疫记录？'),
(36349, 1762, 11, '出生日期'),
(36350, 1763, 11, '出生丢失，如果可能的话，请输入'),
(36351, 1764, 11, '文档'),
(36352, 1765, 11, '医生'),
(36353, 1766, 11, '医生：'),
(36354, 1767, 11, '医生的姓名和签字'),
(36355, 1768, 11, '文件'),
(36356, 1769, 11, '文件'),
(36357, 1770, 11, '文件分类'),
(36358, 1775, 11, '文件无法移动到客户编号'),
(36359, 1777, 11, '文件日期'),
(36360, 1778, 11, '成功更新文件的日期和问题'),
(36361, 1779, 11, '文档编号'),
(36362, 1780, 11, '文件移动到新的类别'),
(36363, 1781, 11, '文件移动到客户编号'),
(36364, 1783, 11, '文件通过完整性检查。'),
(36365, 1785, 11, '文件改名成功。'),
(36366, 1790, 11, '文档/影像店'),
(36367, 1791, 11, '文件'),
(36368, 1792, 11, '文件（写，只添加可选）'),
(36369, 1794, 11, '运动时呼吸困难'),
(36370, 1798, 11, '是否允许这种类型的相关代码？'),
(36371, 1799, 11, '国内合作伙伴'),
(36372, 1800, 11, '不保存'),
(36373, 1801, 11, '不保存'),
(36374, 1802, 11, '不保存更改'),
(36375, 1803, 11, '完成'),
(36376, 1804, 11, '这样做：'),
(36377, 1805, 11, '完成。现在将发送下载。'),
(36378, 1806, 11, 'DOS'),
(36379, 1807, 11, '剂量'),
(36380, 1809, 11, '双击编辑'),
(36381, 1810, 11, '双瞳'),
(36382, 1811, 11, '下载'),
(36383, 1814, 11, '下载无论如何'),
(36384, 1815, 11, '下载计费文件，张贴到嘴的会计和标志'),
(36385, 1817, 11, '下载证书'),
(36386, 1818, 11, '下载配置数据'),
(36387, 1820, 11, '加密文件下载'),
(36388, 1827, 11, '下载选中的语句'),
(36389, 1828, 11, '医生检查'),
(36390, 1829, 11, '博士门诊'),
(36391, 1830, 11, '博士'),
(36392, 1831, 11, '拖动以移动'),
(36393, 1832, 11, '运球'),
(36394, 1833, 11, '驾驶执照或州身份证'),
(36395, 1834, 11, '药物'),
(36396, 1835, 11, '药品搜索'),
(36397, 1836, 11, '剂型'),
(36398, 1837, 11, '药物身份证丢失！'),
(36399, 1838, 11, '药品警告'),
(36400, 1839, 11, '药品库存'),
(36401, 1840, 11, '药品名称'),
(36402, 1841, 11, '贩毒路线'),
(36403, 1845, 11, '禁毒单位'),
(36404, 1846, 11, '药品'),
(36405, 1847, 11, '毒品和产品'),
(36406, 1848, 11, '口干'),
(36407, 1850, 11, '白喉，破伤风疫苗 1'),
(36408, 1851, 11, '白喉，破伤风疫苗 2'),
(36409, 1852, 11, '白喉，破伤风疫苗 3'),
(36410, 1853, 11, '白喉，破伤风疫苗 4'),
(36411, 1854, 11, '白喉，破伤风疫苗 5'),
(36412, 1855, 11, '百白破三联疫苗 1'),
(36413, 1856, 11, '百白破三联疫苗 2'),
(36414, 1857, 11, '百白破三联疫苗 3'),
(36415, 1858, 11, '百白破三联疫苗 4'),
(36416, 1859, 11, '百白破三联疫苗 5'),
(36417, 1860, 11, '由于'),
(36418, 1861, 11, '截止日期'),
(36419, 1862, 11, '截止日期月/日/年或格式年-月 -日'),
(36420, 1863, 11, '截止日期：'),
(36421, 1864, 11, '由于集'),
(36422, 1865, 11, '由于铂'),
(36423, 1866, 11, '即将到期'),
(36424, 1867, 11, '应有的地位'),
(36425, 1868, 11, '应有的地位更新'),
(36426, 1869, 11, '倾倒LibreEHR数据库'),
(36427, 1870, 11, '倾倒LibreEHR web目录树'),
(36428, 1871, 11, '倾倒phpGACL数据库'),
(36429, 1872, 11, '倾倒phpGACL Web目录树'),
(36430, 1873, 11, '倾销SQL的总帐数据库'),
(36431, 1874, 11, '倾倒SQL总帐web目录树'),
(36432, 1875, 11, 'DUP检查'),
(36433, 1876, 11, '重复的ID上线'),
(36434, 1877, 11, '重复上线名称'),
(36435, 1878, 11, '复制的警告'),
(36436, 1879, 11, '检察长的持久动力'),
(36437, 1880, 11, '期限'),
(36438, 1881, 11, '有效期'),
(36439, 1882, 11, '荷兰文'),
(36440, 1884, 11, '吞咽困难'),
(36441, 1885, 11, '呼吸困难：'),
(36442, 1886, 11, '排尿困难'),
(36443, 1888, 11, '电子处方？'),
(36444, 1890, 11, '的E-Rx'),
(36445, 1892, 11, '电子接收重建'),
(36446, 1893, 11, '每个收件人必须设置为完成自己的消息。'),
(36447, 1894, 11, '早期复发（<2个月）'),
(36448, 1895, 11, '耳朵'),
(36449, 1896, 11, '心电图'),
(36450, 1898, 11, '浮肿'),
(36451, 1902, 11, 'EDI-271文件上传'),
(36452, 1903, 11, 'EDI-271响应文件上传'),
(36453, 1904, 11, '编辑'),
(36454, 1905, 11, '编辑'),
(36455, 1906, 11, '编辑过敏'),
(36456, 1907, 11, '编辑类别'),
(36457, 1908, 11, '编辑定义'),
(36458, 1909, 11, '编辑定义'),
(36459, 1910, 11, '编辑诊断'),
(36460, 1911, 11, '编辑披露'),
(36461, 1912, 11, '编辑设施'),
(36462, 1913, 11, '编辑设备'),
(36463, 1914, 11, '编辑设施信息'),
(36464, 1916, 11, '编辑中的文件'),
(36465, 1917, 11, '编辑表格'),
(36466, 1918, 11, '编辑全局设置'),
(36467, 1919, 11, '编辑不认可！'),
(36468, 1920, 11, '编辑布局'),
(36469, 1921, 11, '编辑列表'),
(36470, 1922, 11, '编辑付款'),
(36471, 1923, 11, '编辑结构'),
(36472, 1924, 11, '编辑用户'),
(36473, 1925, 11, '编辑用户设置'),
(36474, 1928, 11, '教育'),
(36475, 1929, 11, '教育日期'),
(36476, 1931, 11, '｜*通用公共许可证的更多细节。* *您应该已经收到一份通用公共许可证*随着这个程序；如果没有，写信给自由 '),
(36477, 1932, 11, '生效日期'),
(36478, 1934, 11, '效力'),
(36479, 1935, 11, 'EIN'),
(36480, 1936, 11, '射精'),
(36481, 1937, 11, '肘'),
(36482, 1938, 11, '手肘问题'),
(36483, 1939, 11, '电子'),
(36484, 1942, 11, '电子汇款'),
(36485, 1944, 11, '合格'),
(36486, 1945, 11, '资格270询问批次'),
(36487, 1946, 11, '资格响应'),
(36488, 1947, 11, '儿童疫苗的资格地位提供疫苗'),
(36489, 1948, 11, '合格'),
(36490, 1949, 11, '电子邮件'),
(36491, 1951, 11, '电邮地址'),
(36492, 1953, 11, '客户提醒发件人的电子邮件地址。客户提醒的回复将被定向到这个地址。重要的是要使用您的诊所“域的地址，以避免有助于防止垃圾邮件文件夹要耐心提醒。'),
(36493, 1954, 11, '电子邮件地址，如果有的话，收到行政通知。'),
(36494, 1955, 11, '电子邮件地址，如果有的话，接受紧急登录用户激活邮件。'),
(36495, 1956, 11, '电子邮件验证'),
(36496, 1957, 11, '电子邮件从Batchcom'),
(36497, 1958, 11, '电子邮件通知'),
(36498, 1959, 11, '电子邮件通知时间'),
(36499, 1961, 11, '电子邮件发送之前'),
(36500, 1962, 11, '电子邮件发件人'),
(36501, 1963, 11, '电子邮件发送'),
(36502, 1965, 11, '电子邮件主题'),
(36503, 1966, 11, '电子邮件的文本，可用标签：***姓名***，即亲爱的***姓名***'),
(36504, 1968, 11, '电子邮件传输方法'),
(36505, 1969, 11, '电子邮件发送到以下地址'),
(36506, 1971, 11, '紧急联络人'),
(36507, 1972, 11, '紧急联络人'),
(36508, 1973, 11, '紧急联络电话号码'),
(36509, 1974, 11, '紧急避孕'),
(36510, 1975, 11, '紧急登录'),
(36511, 1976, 11, '紧急登录ACL选择。用户仍处于活跃状态，请取消激活用户和在紧急情况下需要时激活相同。门诊管理“ - >”激活或去激活的用户。'),
(36512, 1977, 11, '紧急登录激活电子邮件将发给如果在接口/ globals.php文件配置以下设置：'),
(36513, 1978, 11, '紧急登录的电邮地址'),
(36514, 1979, 11, '紧急登录的用户可以做什么'),
(36515, 1980, 11, '紧急电话'),
(36516, 1982, 11, '肺气肿'),
(36517, 1983, 11, '雇员'),
(36518, 1984, 11, '单位'),
(36519, 1985, 11, '单位地址'),
(36520, 1986, 11, '单位数据'),
(36521, 1987, 11, '单位名称'),
(36522, 1988, 11, '空的'),
(36523, 1989, 11, '空的'),
(36524, 1991, 11, '空值在“电子邮件时间”'),
(36525, 1992, 11, '空值在“电子邮件发件人”'),
(36526, 1993, 11, '空值在“电子邮件的主题”'),
(36527, 1994, 11, '空值在“电子邮件正文”'),
(36528, 1995, 11, '空值在“名称的提供者”'),
(36529, 1996, 11, '空值在“密码”'),
(36530, 1997, 11, '空值在“短信时间”'),
(36531, 1998, 11, '空值在“短信”'),
(36532, 1999, 11, '空值在“用户名”'),
(36533, 2006, 11, '启用资产管理公司的激励'),
(36534, 2008, 11, '启用资产管理报告'),
(36535, 2009, 11, '启用资产管理公司跟踪'),
(36536, 2011, 11, '启用ATNA审计'),
(36537, 2013, 11, '启用审核日志记录'),
(36538, 2014, 11, '启用审计跟踪和节点认证（ATNA）。'),
(36539, 2015, 11, '启用自动测量计算（AMC）的报告'),
(36540, 2016, 11, '启用客户端SSL'),
(36541, 2017, 11, '启用客户端SSL证书认证。'),
(36542, 2019, 11, '使临床决策规则“（CDR）'),
(36543, 2022, 11, '使临床质量的措施（CQM）报告'),
(36544, 2023, 11, '使临床提醒弹出'),
(36545, 2024, 11, '使临床提醒部件'),
(36546, 2027, 11, '启用CQM报告'),
(36547, 2031, 11, '启用HylaFax等支持'),
(36548, 2033, 11, '使进口NewCrop ERX状态消息'),
(36549, 2037, 11, '启用实验室交流'),
(36550, 2040, 11, '启用所有的SQL SELECT查询的记录。'),
(36551, 2041, 11, '启用日志记录备份的相关活动。'),
(36552, 2043, 11, '使杂项活动的记录。'),
(36553, 2044, 11, '启用排序活动的记录。'),
(36554, 2045, 11, '启用病历修改的记录。'),
(36555, 2046, 11, '启用调度活动的记录。'),
(36556, 2047, 11, '启用安全和管理活动的记录。'),
(36557, 2049, 11, '启用NewCrop ERX服务'),
(36558, 2051, 11, '启用异地患者门户'),
(36559, 2052, 11, '启用异地患者门户。'),
(36560, 2053, 11, '启用上门患者门户'),
(36561, 2055, 11, '启用上门患者门户。'),
(36562, 2056, 11, '使客户提醒部件'),
(36563, 2058, 11, '启用自动测量计算所需的数据（AMC）的激励'),
(36564, 2060, 11, '启用的自动测量计算日期（AMC）的跟踪报告'),
(36565, 2061, 11, '启用扫描仪支持'),
(36566, 2065, 11, '启用的LibreEHR支持LLC实验室外汇服务。'),
(36567, 2066, 11, '启用用户证书验证'),
(36568, 2067, 11, '启用ZMG，ERX服务有限责任公司'),
(36569, 2068, 11, '启用'),
(36570, 2070, 11, '使老费面板进入帐单代码和付款。不推荐使用，而费用表。'),
(36571, 2071, 11, '电子图'),
(36572, 2072, 11, '电子图'),
(36573, 2073, 11, '治疗'),
(36574, 2074, 11, '治疗'),
(36575, 2075, 11, '治疗 '),
(36576, 2076, 11, '治疗急性住院或急诊'),
(36577, 2081, 11, '治疗日期'),
(36578, 2086, 11, '治疗表格'),
(36579, 2087, 11, '治疗健康和行为评估'),
(36580, 2088, 11, '治疗历史'),
(36581, 2089, 11, '治疗的ID'),
(36582, 2090, 11, '治疗流感'),
(36583, 2091, 11, '治疗数'),
(36584, 2093, 11, '治疗护理放电'),
(36585, 2094, 11, '治疗护理设施'),
(36586, 2095, 11, '治疗职业治疗'),
(36587, 2096, 11, '治疗办公室门诊'),
(36588, 2097, 11, '治疗门诊'),
(36589, 2098, 11, '治疗门诊W / PCP及妇产科'),
(36590, 2099, 11, '治疗页面大小'),
(36591, 2101, 11, '治疗怀孕'),
(36592, 2102, 11, '治疗预防医学 - 个别辅导'),
(36593, 2103, 11, '治疗预防医学40岁及以上'),
(36594, 2104, 11, '治疗预防医学小组辅导'),
(36595, 2105, 11, '治疗预防医学的其他服务'),
(36596, 2106, 11, '治疗预防医学服务，18岁及以上'),
(36597, 2107, 11, '治疗精神与心理'),
(36598, 2108, 11, '治疗统计'),
(36599, 2109, 11, '治疗摘要'),
(36600, 2110, 11, '治疗编码'),
(36601, 2111, 11, '治疗：'),
(36602, 2112, 11, '治疗：遇到急性输入，门诊，或眼科'),
(36603, 2113, 11, '邂逅'),
(36604, 2114, 11, '治疗与形式'),
(36605, 2115, 11, '治疗与形式'),
(36606, 2116, 11, '治疗未授权'),
(36607, 2117, 11, '座谈会报告'),
(36608, 2118, 11, '治疗科'),
(36609, 2120, 11, '加密'),
(36610, 2121, 11, '结束'),
(36611, 2122, 11, '结束（年-月-日）： '),
(36612, 2123, 11, '结束日期'),
(36613, 2124, 11, '结束日期'),
(36614, 2126, 11, '比开始日期结束日期应该更大'),
(36615, 2127, 11, '结束日期：'),
(36616, 2131, 11, '结束时间'),
(36617, 2132, 11, '终末期肾脏病中的MCP与用人单位的集团计划的受益人'),
(36618, 2133, 11, '服务的结束日期（年-月-日）'),
(36619, 2134, 11, '如果你想进入一个范围结束DOS（月/日/年）'),
(36620, 2135, 11, '结束一天的小时日历事件。'),
(36621, 2136, 11, '远藤异常血'),
(36622, 2137, 11, '内分泌'),
(36623, 2138, 11, '内窥镜'),
(36624, 2141, 11, '英语'),
(36625, 2142, 11, '英语 '),
(36626, 2143, 11, '英语（印度）'),
(36627, 2144, 11, '英语（标准）'),
(36628, 2145, 11, 'enscript命令使用HylaFax等。'),
(36629, 2146, 11, '确保LibreEHR有写权限的目录'),
(36630, 2147, 11, '耳鼻喉科放电'),
(36631, 2148, 11, '耳鼻喉科疼痛'),
(36632, 2149, 11, '输入诊断代码排除所有不包含发票'),
(36633, 2151, 11, '在此处输入信件的正文'),
(36634, 2152, 11, '输入数据库root密码'),
(36635, 2153, 11, '输入数据库的root用户名'),
(36636, 2154, 11, '进入诊断'),
(36637, 2155, 11, '输入药品'),
(36638, 2158, 11, '进入免疫接种'),
(36639, 2159, 11, '回车键'),
(36640, 2161, 11, '输入新的国家'),
(36641, 2164, 11, '进入再识别代码'),
(36642, 2165, 11, '输入您的搜索标准以上'),
(36643, 2168, 11, '环境'),
(36644, 2169, 11, 'EOB数据录入'),
(36645, 2170, 11, 'EOB发布-电子汇款'),
(36646, 2171, 11, 'EOB张贴-说明'),
(36647, 2172, 11, 'EOB发布-发票'),
(36648, 2173, 11, 'EOB张贴-患者请注意'),
(36649, 2174, 11, 'EOB发布-搜索'),
(36650, 2176, 11, '癫痫'),
(36651, 2178, 11, '自责'),
(36652, 2180, 11, '自责发帖'),
(36653, 2181, 11, '抹去'),
(36654, 2182, 11, '勃起'),
(36655, 2183, 11, '错误'),
(36656, 2185, 11, '实验室结果的错误确认收到'),
(36657, 2187, 11, '从实验室交换网络实验室结果错误'),
(36658, 2188, 11, '中的错误“性别”的选择'),
(36659, 2189, 11, '中的错误“法案”的选择'),
(36660, 2190, 11, '中的错误“过程”选择'),
(36661, 2191, 11, '错误的“短信网关”选择'),
(36662, 2192, 11, '中的错误“排序方式”的选择'),
(36663, 2193, 11, '在GZIP压缩文件中的错误： '),
(36664, 2194, 11, 'YES或NO选项的错误'),
(36665, 2195, 11, '阅读文件上传错误开幕'),
(36666, 2198, 11, '删除邮件时出错'),
(36667, 2199, 11, '从实验室交换网络的​​错误检索结果'),
(36668, 2202, 11, '批准文件的特权的LibreEHR用户时的错误。'),
(36669, 2205, 11, '在注册表格的错误！'),
(36670, 2206, 11, '错误，而保存的文件'),
(36671, 2208, 11, '写入文件时出错'),
(36672, 2210, 11, '错误，该文件不存在'),
(36673, 2211, 11, '错误，无法从服务器收集数据'),
(36674, 2212, 11, '错误，无法创建客户端证书。'),
(36675, 2213, 11, '错误，无法，以创建该admin.p12的的证书。'),
(36676, 2214, 11, '错误，无法创建的证书颁发机构证书。'),
(36677, 2215, 11, '错误，无法创建服务器证书。'),
(36678, 2216, 11, '错误，无法打开文件'),
(36679, 2217, 11, '错误，用户证书验证不在LibreEHR启用'),
(36680, 2218, 11, '错误。你需要安装存档/ Tar.php的PHP模块。'),
(36681, 2219, 11, '错误：无法打开table.sql，破碎的形式？'),
(36682, 2220, 11, '错误：重复的ID上线'),
(36683, 2221, 11, '错误：重复的名称上线'),
(36684, 2222, 11, '错误：场'),
(36685, 2223, 11, '错误：缺少ZipArchive PHP模块'),
(36686, 2225, 11, '错误：密码不匹配。请检查您的打字。'),
(36687, 2226, 11, '错误：密码不''吨匹配。请检查您的打字。'),
(36688, 2227, 11, '错误：文件不存在'),
(36689, 2228, 11, '错误：以下变量包含无效字符'),
(36690, 2229, 11, '错误：无法复制的文件。'),
(36691, 2230, 11, '错误：无法创建下载的存档'),
(36692, 2231, 11, '错误：无法创建Zip存档。'),
(36693, 2232, 11, '错误：无法提取该文件。'),
(36694, 2233, 11, '错误：无法加载到数据库中的文件。'),
(36695, 2234, 11, '错误：无法设置版本号。'),
(36696, 2235, 11, '错误'),
(36697, 2236, 11, 'ERX帐户状态'),
(36698, 2237, 11, 'ERX日志'),
(36699, 2238, 11, '的ERX名称'),
(36700, 2239, 11, '的ERX密码'),
(36701, 2240, 11, '的ERX作用'),
(36702, 2241, 11, '的ERX用户'),
(36703, 2242, 11, '红斑：'),
(36704, 2245, 11, '爱斯基摩人'),
(36705, 2247, 11, '建立客户'),
(36706, 2249, 11, '种族'),
(36707, 2250, 11, '民族或种族'),
(36708, 2251, 11, '种族赛名单（写，只添加可选）'),
(36709, 2252, 11, '生成'),
(36710, 2253, 11, '事件'),
(36711, 2254, 11, '活动开始'),
(36712, 2255, 11, '事件类别'),
(36713, 2256, 11, '活动日期'),
(36714, 2257, 11, '事件描述'),
(36715, 2258, 11, '活动详情'),
(36716, 2259, 11, '事件不会重演'),
(36717, 2260, 11, '事件时间'),
(36718, 2261, 11, '活动期间在几分钟'),
(36719, 2262, 11, '活动费'),
(36720, 2263, 11, '活动地点'),
(36721, 2264, 11, '每一个事件重复'),
(36722, 2265, 11, '事件重复的'),
(36723, 2266, 11, '活动开始时间'),
(36724, 2267, 11, '活动名称'),
(36725, 2268, 11, '活动名称'),
(36726, 2269, 11, '网址'),
(36727, 2270, 11, '事件'),
(36728, 2271, 11, '事件'),
(36729, 2272, 11, '活动在新视窗开启'),
(36730, 2273, 11, '每个的'),
(36731, 2274, 11, '每个的'),
(36732, 2275, 11, '每3小时'),
(36733, 2276, 11, '每4小时'),
(36734, 2277, 11, '每5个小时'),
(36735, 2278, 11, '每6小时'),
(36736, 2279, 11, '每隔8小时'),
(36737, 2280, 11, '每4名'),
(36738, 2281, 11, '所有其他'),
(36739, 2282, 11, '每三'),
(36740, 2283, 11, '每一个，每个，每第三，等。'),
(36741, 2285, 11, '考试和测试结果'),
(36742, 2286, 11, '考试结果'),
(36743, 2289, 11, '考试'),
(36744, 2290, 11, '考试日期'),
(36745, 2291, 11, '例子'),
(36746, 2292, 11, '举例'),
(36747, 2293, 11, '考试/考试'),
(36748, 2294, 11, '除'),
(36749, 2295, 11, '过多的流泪'),
(36750, 2296, 11, '排除患者'),
(36751, 2297, 11, '排除'),
(36752, 2298, 11, '独家服务人员组织（EPO）'),
(36753, 2299, 11, '执行纸张尺寸'),
(36754, 2300, 11, '行使'),
(36755, 2301, 11, '运动模式'),
(36756, 2302, 11, '运动模式'),
(36757, 2303, 11, '存在'),
(36758, 2304, 11, '管理退出'),
(36759, 2305, 11, '进出口'),
(36760, 2306, 11, '扩大'),
(36761, 2307, 11, '扩大'),
(36762, 2308, 11, '全部展开'),
(36763, 2311, 11, '扩展视图'),
(36764, 2312, 11, '预计form_encounter.pid是 '),
(36765, 2313, 11, '过期'),
(36766, 2314, 11, '截止日期'),
(36767, 2315, 11, '过期'),
(36768, 2316, 11, '到期'),
(36769, 2317, 11, '出口'),
(36770, 2318, 11, '导出为CSV'),
(36771, 2319, 11, '导出配置'),
(36772, 2322, 11, '导出客户的人口统计资料'),
(36773, 2323, 11, '出口PQRI报告'),
(36774, 2325, 11, '出口为CSV选择'),
(36775, 2326, 11, '导出选定的集合'),
(36776, 2327, 11, '导出到CSV'),
(36777, 2328, 11, '导出到外部计费系统'),
(36778, 2329, 11, '暴露于国外'),
(36779, 2330, 11, '暴露到国外'),
(36780, 2331, 11, '分机时收取'),
(36781, 2332, 11, '外部'),
(36782, 2336, 11, '外部ID'),
(36783, 2337, 11, '外部ID'),
(36784, 2338, 11, '外部标识符'),
(36785, 2339, 11, '外部仅'),
(36786, 2342, 11, '对外推介'),
(36787, 2343, 11, '对外推介Followups'),
(36788, 2344, 11, '外部转介？'),
(36789, 2345, 11, '对外推介'),
(36790, 2346, 11, '解压zip文件'),
(36791, 2347, 11, '提取该文件。这将花费一些时间...'),
(36792, 2348, 11, '分泌物：'),
(36793, 2349, 11, '眼刺痛'),
(36794, 2350, 11, '眼睛疼痛'),
(36795, 2351, 11, '眼睛发红'),
(36796, 2352, 11, '双眼'),
(36797, 2353, 11, 'F'),
(36798, 2354, 11, 'F / H级的血液问题'),
(36799, 2355, 11, 'F / H级女性多毛症/皮纹'),
(36800, 2356, 11, '设备'),
(36801, 2357, 11, '设施'),
(36802, 2358, 11, '设施'),
(36803, 2359, 11, '基金管理'),
(36804, 2360, 11, '基金市'),
(36805, 2361, 11, '设备代码'),
(36806, 2362, 11, '设施的国家代码'),
(36807, 2363, 11, '设施传真'),
(36808, 2364, 11, '设施名称'),
(36809, 2365, 11, '基金的非营利机构'),
(36810, 2366, 11, '工厂电话'),
(36811, 2368, 11, '基金国'),
(36812, 2369, 11, '工厂街'),
(36813, 2370, 11, '基金邮编'),
(36814, 2372, 11, '设施：'),
(36815, 2373, 11, '失败'),
(36816, 2374, 11, '失败'),
(36817, 2375, 11, '失败'),
(36818, 2383, 11, '失败'),
(36819, 2390, 11, '家族史'),
(36820, 2391, 11, '青光眼家族史'),
(36821, 2392, 11, '家族病史：'),
(36822, 2394, 11, '家庭补助金'),
(36823, 2395, 11, '家庭规模'),
(36824, 2396, 11, '花式'),
(36825, 2398, 11, '波斯语'),
(36826, 2400, 11, '父亲'),
(36827, 2402, 11, '疲惫'),
(36828, 2403, 11, '疲惫'),
(36829, 2404, 11, '传真'),
(36830, 2405, 11, '传真计数'),
(36831, 2406, 11, '传真号码'),
(36832, 2408, 11, '传真/扫描'),
(36833, 2409, 11, '传真在'),
(36834, 2410, 11, '传真输出'),
(36835, 2411, 11, '特点'),
(36836, 2412, 11, '二月'),
(36837, 2413, 11, '二月'),
(36838, 2414, 11, 'FECA'),
(36839, 2415, 11, '联邦药品编号'),
(36840, 2416, 11, '联邦艾因'),
(36841, 2417, 11, '联邦税务ID'),
(36842, 2418, 11, '费用'),
(36843, 2419, 11, '费用'),
(36844, 2420, 11, '不允许使用的费用'),
(36845, 2421, 11, '收费表'),
(36846, 2422, 11, '费用表选项'),
(36847, 2423, 11, '费用'),
(36848, 2424, 11, '女性'),
(36849, 2425, 11, '女性怀孕'),
(36850, 2426, 11, '女用避孕套'),
(36851, 2427, 11, '女性G'),
(36852, 2428, 11, '女性LC'),
(36853, 2429, 11, '女性P级'),
(36854, 2430, 11, '女性症状'),
(36855, 2431, 11, '女性VSC'),
(36856, 2434, 11, '发烧：'),
(36857, 2435, 11, '发烧：'),
(36858, 2436, 11, '家族性高胆固醇血症血液问题'),
(36859, 2437, 11, '子宫肌瘤'),
(36860, 2441, 11, '在国家户口资料中单位或用户使用的字段类型'),
(36861, 2442, 11, '在省统计学中单位或用户使用的字段类型'),
(36862, 2443, 11, '字段（S）丢失！'),
(36863, 2447, 11, '档案'),
(36864, 2448, 11, '在“文档”目录中的档案，用来了解如何创建日志过程自动化'),
(36865, 2449, 11, '档案位置'),
(36866, 2450, 11, '档案处理'),
(36867, 2453, 11, '档案授权给LibreEHR用户'),
(36868, 2455, 11, '档案室'),
(36869, 2456, 11, '上传档案'),
(36870, 2458, 11, '具有相同名称的档案已经存在于：'),
(36871, 2459, 11, '档案名称'),
(36872, 2461, 11, '档案'),
(36873, 2462, 11, '菲律宾'),
(36874, 2463, 11, '填写以下所有'),
(36875, 2464, 11, '只有在这里填写发送电子邮件通知患者'),
(36876, 2465, 11, '填写以下内容'),
(36877, 2467, 11, '填写这一行'),
(36878, 2468, 11, '过滤器'),
(36879, 2469, 11, '过滤常量'),
(36880, 2470, 11, '过滤的定义'),
(36881, 2472, 11, '过滤器'),
(36882, 2473, 11, '过滤器'),
(36883, 2474, 11, '最后'),
(36884, 2475, 11, '最后诊断'),
(36885, 2476, 11, '最后诊断专家'),
(36886, 2478, 11, '财务'),
(36887, 2479, 11, '财务计算日期（年-月-日）'),
(36888, 2480, 11, '财务报告-所有'),
(36889, 2481, 11, '财务报告-我的治疗'),
(36890, 2482, 11, '财务审查日期'),
(36891, 2484, 11, '查找'),
(36892, 2485, 11, '寻找可用'),
(36893, 2486, 11, '寻找可用的任命'),
(36894, 2487, 11, '发现客户'),
(36895, 2488, 11, '查找客户教育资源'),
(36896, 2489, 11, '调查结果'),
(36897, 2490, 11, '专家诊断'),
(36898, 2491, 11, '罚款'),
(36899, 2492, 11, '完成付款'),
(36900, 2495, 11, '首先'),
(36901, 2497, 11, '一周的第一天'),
(36902, 2498, 11, '名字'),
(36903, 2499, 11, '名字'),
(36904, 2500, 11, '名字'),
(36905, 2503, 11, '健身'),
(36906, 2504, 11, '健身等级'),
(36907, 2505, 11, '这个球员在这一天的健身水平'),
(36908, 2507, 11, '健身游戏'),
(36909, 2508, 11, '解决治疗的日期 – 所有治疗'),
(36910, 2509, 11, '解决这个问题'),
(36911, 2510, 11, '福罗里达州'),
(36912, 2511, 11, '胀气'),
(36913, 2512, 11, '流量'),
(36914, 2514, 11, '流感季节'),
(36915, 2515, 11, '流感季节'),
(36916, 2516, 11, '接种流感疫苗'),
(36917, 2517, 11, '液体和电解质的问题'),
(36918, 2518, 11, '柔性制造系统'),
(36919, 2519, 11, '开纸大小'),
(36920, 2520, 11, '后续手动'),
(36921, 2522, 11, '追踪'),
(36922, 2524, 11, '追踪理由'),
(36923, 2525, 11, '下一个新的自定义常数'),
(36924, 2526, 11, '下一个新的自定义语言'),
(36925, 2527, 11, '以下是一个新的定义（语言，常数，定义）：'),
(36926, 2529, 11, '后续服务'),
(36927, 2530, 11, '追踪指示'),
(36928, 2531, 11, '偏食症'),
(36929, 2532, 11, '脚'),
(36930, 2533, 11, '足部问题'),
(36931, 2534, 11, '步行：'),
(36932, 2535, 11, '足球伤害'),
(36933, 2537, 11, '足球损伤报告'),
(36934, 2538, 11, '鞋型'),
(36935, 2539, 11, '针对'),
(36936, 2540, 11, '针对'),
(36937, 2541, 11, '针对编码'),
(36938, 2543, 11, '针对治疗索赔'),
(36939, 2544, 11, '例如'),
(36940, 2547, 11, '发票'),
(36941, 2548, 11, '医疗保险只，力指服务人员是一样的渲染服务人员。'),
(36942, 2552, 11, '所提的组织/执业'),
(36943, 2553, 11, '在过去的'),
(36944, 2554, 11, '可变的'),
(36945, 2555, 11, '针对：'),
(36946, 2556, 11, '计费部件打开'),
(36947, 2557, 11, '创建新的客户'),
(36948, 2559, 11, '前臂'),
(36949, 2560, 11, '表格'),
(36950, 2561, 11, '表格'),
(36951, 2564, 11, '格式'),
(36952, 2565, 11, '格式'),
(36953, 2567, 11, '格式不正确的伴侣'),
(36954, 2568, 11, '使用的格式显示日期。'),
(36955, 2569, 11, '格式用于显示的次数最多。'),
(36956, 2570, 11, '格式报告'),
(36957, 2571, 11, '曾吸烟者'),
(36958, 2572, 11, '形式'),
(36959, 2573, 11, '形式管理'),
(36960, 2575, 11, '当前'),
(36961, 2576, 11, '前页传真'),
(36962, 2577, 11, '转发'),
(36963, 2579, 11, '第四次'),
(36964, 2581, 11, '骨折'),
(36965, 2582, 11, '骨折在舟'),
(36966, 2583, 11, '外踝骨折'),
(36967, 2584, 11, '内踝骨折'),
(36968, 2585, 11, '骨折，第五跖骨基地（第五）'),
(36969, 2587, 11, '法文'),
(36970, 2588, 11, '法文（加拿大）'),
(36971, 2589, 11, '法文（标准）'),
(36972, 2590, 11, '频率'),
(36973, 2591, 11, '频发性感冒'),
(36974, 2592, 11, '频发性疾病'),
(36975, 2593, 11, '周五'),
(36976, 2594, 11, '周五'),
(36977, 2595, 11, '从'),
(36978, 2596, 11, '从'),
(36979, 2597, 11, '从'),
(36980, 2598, 11, '开始日期不能大于日期。'),
(36981, 2599, 11, '来自：'),
(36982, 2600, 11, '来自： '),
(36983, 2601, 11, '来自-城市'),
(36984, 2603, 11, '来自-名字'),
(36985, 2604, 11, '来自-姓氏'),
(36986, 2605, 11, '来自-中间名称'),
(36987, 2607, 11, '来自-电话'),
(36988, 2608, 11, '来自-邮编'),
(36989, 2609, 11, '来自-省'),
(36990, 2610, 11, '来自-街道'),
(36991, 2611, 11, '来自-标题'),
(36992, 2612, 11, '来自-告别'),
(36993, 2613, 11, '前台'),
(36994, 2614, 11, '前台收款'),
(36995, 2615, 11, '前台收款报表'),
(36996, 2616, 11, '接待记录'),
(36997, 2617, 11, '正面右：'),
(36998, 2619, 11, '全名'),
(36999, 2620, 11, '包含MySQL的全路径的可执行文件目录。'),
(37000, 2621, 11, '包含Perl的全路径的可执行文件目录。'),
(37001, 2622, 11, '完整的目录路径为事件日志备份。'),
(37002, 2623, 11, '全路径用于临时文件目录。'),
(37003, 2624, 11, '充分发挥'),
(37004, 2625, 11, '训练'),
(37005, 2626, 11, '全额支付'),
(37006, 2633, 11, 'G'),
(37007, 2634, 11, 'G/DL'),
(37008, 2636, 11, '胆囊条件'),
(37009, 2637, 11, '胆结石'),
(37010, 2638, 11, '运动时间'),
(37011, 2639, 11, '运动会'),
(37012, 2640, 11, '错过'),
(37013, 2641, 11, '运动/事件'),
(37014, 2642, 11, '运动/活动漏诊'),
(37015, 2644, 11, '胃炎'),
(37016, 2645, 11, '胃疼'),
(37017, 2646, 11, '胃肠道'),
(37018, 2647, 11, 'GCAC统计报告'),
(37019, 2648, 11, 'GCAC统计'),
(37020, 2649, 11, 'GCAC门诊形式丢失'),
(37021, 2650, 11, '性别'),
(37022, 2651, 11, '性别 '),
(37023, 2652, 11, '一般'),
(37024, 2655, 11, '一般事务类'),
(37025, 2657, 11, '生成和下载CMS 1500文件要求'),
(37026, 2658, 11, '生成和下载HCFA 1500年书面索赔'),
(37027, 2659, 11, '生成并下载X12批次'),
(37028, 2660, 11, '产生和下载x 12治疗索赔一批'),
(37029, 2663, 11, '生成和传输允许电子处方。'),
(37030, 2664, 11, '生成CMS 1500'),
(37031, 2665, 11, '生成CMS 1500PDF'),
(37032, 2666, 11, '生成CMS 1500文本'),
(37033, 2667, 11, '生成HCFA'),
(37034, 2669, 11, '生成信件'),
(37035, 2670, 11, '产生来信 '),
(37036, 2671, 11, '产生PQRI报告（方法A）'),
(37037, 2673, 11, '产生PQRI报告（方法E）'),
(37038, 2677, 11, '生成报告'),
(37039, 2678, 11, '生成的用户名和密码'),
(37040, 2679, 11, '生成X12'),
(37041, 2680, 11, '生成X12治疗'),
(37042, 2682, 11, '产生'),
(37043, 2683, 11, '生成'),
(37044, 2684, 11, '泌尿生殖'),
(37045, 2687, 11, '德语'),
(37046, 2691, 11, '获得HL7'),
(37047, 2692, 11, '青光眼'),
(37048, 2693, 11, '青光眼家族史'),
(37049, 2694, 11, '全局'),
(37050, 2696, 11, '全局编号'),
(37051, 2697, 11, '全局设置'),
(37052, 2698, 11, '全局'),
(37053, 2699, 11, 'GM/DL'),
(37054, 2700, 11, '离去'),
(37055, 2701, 11, '离去'),
(37056, 2704, 11, '到'),
(37057, 2705, 11, '转到周'),
(37058, 2706, 11, '今天去'),
(37059, 2711, 11, '外伤等级'),
(37060, 2712, 11, '等级：'),
(37061, 2713, 11, '克'),
(37062, 2714, 11, '总计'),
(37063, 2715, 11, '总计'),
(37064, 2718, 11, '图标'),
(37065, 2720, 11, '大于'),
(37066, 2721, 11, '大于或等于'),
(37067, 2722, 11, '希腊语'),
(37068, 2724, 11, '团体'),
(37069, 2725, 11, '团体名'),
(37070, 2726, 11, '团体名不能是空白的'),
(37071, 2727, 11, '团体名不能以数字或空格开始。'),
(37072, 2728, 11, '团体名不能以数字开始。'),
(37073, 2729, 11, '团体号码'),
(37074, 2730, 11, '团体付款'),
(37075, 2731, 11, '组：'),
(37076, 2732, 11, '群组'),
(37077, 2733, 11, '团体和门诊控制'),
(37078, 2734, 11, '生长图表'),
(37079, 2735, 11, '生长-图表'),
(37080, 2736, 11, '糖耐量（滴）'),
(37081, 2737, 11, '监护人'),
(37082, 2739, 11, '监护人姓名'),
(37083, 2741, 11, '妇科考试'),
(37084, 2742, 11, 'h'),
(37085, 2743, 11, 'h.s.'),
(37086, 2744, 11, 'H/O肝炎'),
(37087, 2745, 11, '已成功删除。如果存在任何分类别被移到下面'),
(37088, 2746, 11, '血肿/瘀伤'),
(37089, 2747, 11, 'HAI状态'),
(37090, 2750, 11, '手+手指'),
(37091, 2751, 11, '手部问题'),
(37092, 2753, 11, '艰难W / O型'),
(37093, 2754, 11, '已链接门诊'),
(37094, 2755, 11, '已过期'),
(37095, 2756, 11, '拼凑'),
(37096, 2757, 11, '不存在此文件的散列。生成新的哈希。'),
(37097, 2758, 11, '哈希不匹配。数据的完整性受到损害。'),
(37098, 2760, 11, '夏威夷语'),
(37099, 2761, 11, '危险活动'),
(37100, 2762, 11, '危险活动'),
(37101, 2763, 11, 'HCFA左边源点'),
(37102, 2764, 11, 'HCFA保证金'),
(37103, 2765, 11, 'HCFA顶部源点'),
(37104, 2767, 11, '他发布日历 '),
(37105, 2768, 11, '头'),
(37106, 2769, 11, '头围'),
(37107, 2770, 11, '头围'),
(37108, 2771, 11, '头痛'),
(37109, 2772, 11, '头痛'),
(37110, 2773, 11, '卫生保健'),
(37111, 2774, 11, '卫生保健'),
(37112, 2775, 11, '健康中心/诊所'),
(37113, 2776, 11, '健康维护组织'),
(37114, 2777, 11, '健康维护组织（健保组织）医疗风险'),
(37115, 2778, 11, '听力损耗'),
(37116, 2779, 11, '心脏病发作'),
(37117, 2780, 11, '心脏病'),
(37118, 2781, 11, '心力衰竭'),
(37119, 2782, 11, '心脏问题'),
(37120, 2783, 11, '心脏问题'),
(37121, 2784, 11, '心脏手术'),
(37122, 2785, 11, '心脏移植'),
(37123, 2786, 11, '心：'),
(37124, 2787, 11, '心痛'),
(37125, 2788, 11, '热或冷'),
(37126, 2789, 11, '热或冷'),
(37127, 2791, 11, '希伯来语'),
(37128, 2793, 11, '头眼耳鼻喉'),
(37129, 2794, 11, '身高'),
(37130, 2796, 11, '帮助'),
(37131, 2797, 11, '帮助'),
(37132, 2798, 11, '吐血'),
(37133, 2799, 11, '便血'),
(37134, 2800, 11, '血液学'),
(37135, 2801, 11, '血尿'),
(37136, 2802, 11, '血红蛋白'),
(37137, 2803, 11, '糖化血红蛋白'),
(37138, 2804, 11, '咳血'),
(37139, 2805, 11, '肝炎'),
(37140, 2806, 11, 'A型肝炎1'),
(37141, 2807, 11, 'A型肝炎2'),
(37142, 2808, 11, 'B型肝炎1'),
(37143, 2809, 11, 'B型肝炎2'),
(37144, 2810, 11, 'B型肝炎3'),
(37145, 2811, 11, '这里'),
(37146, 2813, 11, '疝修补术'),
(37147, 2814, 11, '腰椎间盘突出'),
(37148, 2815, 11, '疱疹'),
(37149, 2816, 11, '迟疑'),
(37150, 2817, 11, 'heyyo 。你在这里 '),
(37151, 2818, 11, 'B型流感嗜血杆菌结合疫苗 1'),
(37152, 2819, 11, 'B型流感嗜血杆菌结合疫苗 2'),
(37153, 2820, 11, 'B型流感嗜血杆菌结合疫苗 3'),
(37154, 2821, 11, 'B型流感嗜血杆菌结合疫苗 4'),
(37155, 2822, 11, '隐藏'),
(37156, 2823, 11, '隐藏活动管理'),
(37157, 2824, 11, '隐藏'),
(37158, 2825, 11, '隐藏详细信息'),
(37159, 2827, 11, '隐藏加密/解密方案文件管理'),
(37160, 2828, 11, '隐藏菜单'),
(37161, 2830, 11, '隐藏提醒'),
(37162, 2831, 11, '隐藏/显示列'),
(37163, 2833, 11, '高的'),
(37164, 2834, 11, '血压高'),
(37165, 2835, 11, '印地语'),
(37166, 2836, 11, '髋部+腹股沟'),
(37167, 2837, 11, '髋部和腹股沟'),
(37168, 2838, 11, '髋关节的问题'),
(37169, 2839, 11, '髋关节置换术'),
(37170, 2840, 11, 'HIPAA的公告收稿'),
(37171, 2842, 11, '多毛/皮纹'),
(37172, 2843, 11, '西班牙裔'),
(37173, 2844, 11, '西班牙语-其他（生的在美国）'),
(37174, 2845, 11, '西班牙语-其他（生的美国以外）'),
(37175, 2846, 11, '西班牙裔或拉丁裔'),
(37176, 2847, 11, '历史'),
(37177, 2848, 11, '历史数据'),
(37178, 2849, 11, '历史数据'),
(37179, 2851, 11, '心脏杂音病史'),
(37180, 2852, 11, '历史上没有授权'),
(37181, 2853, 11, '心脏杂音病史'),
(37182, 2854, 11, '次数'),
(37183, 2855, 11, '人体免疫缺损病毒，艾滋病病毒'),
(37184, 2858, 11, 'HL7标准浏览器'),
(37185, 2860, 11, 'HMOL/L'),
(37186, 2861, 11, '苗族'),
(37187, 2862, 11, '按住[ Ctrl键]以便进行多项选择或取消'),
(37188, 2863, 11, '按住CTRL键选择多个项目'),
(37189, 2864, 11, '按住CTRL键选择多个敢死队'),
(37190, 2865, 11, '首页'),
(37191, 2866, 11, '住宅电话'),
(37192, 2867, 11, '住宅电话'),
(37193, 2868, 11, '无家可归或类似？'),
(37194, 2869, 11, '无家可归，等'),
(37195, 2870, 11, '无家可归，等'),
(37196, 2872, 11, '主机名'),
(37197, 2873, 11, '主机名不能为空'),
(37198, 2875, 11, '小时'),
(37199, 2876, 11, '小时'),
(37200, 2878, 11, '如何受伤？'),
(37201, 2879, 11, '如何受伤？：'),
(37202, 2880, 11, '他们是如何知道我们的'),
(37203, 2881, 11, '有多少未来几个月来查询即将举行的活动？'),
(37204, 2882, 11, '液相色谱法：'),
(37205, 2883, 11, 'HT'),
(37206, 2884, 11, 'HTML'),
(37207, 2886, 11, '网页链接的LibreEHR支持实验室交流服务有限责任公司。'),
(37208, 2887, 11, '匈牙利语'),
(37209, 2888, 11, 'HylaFax目录'),
(37210, 2889, 11, 'HylaFax等Enscript指令'),
(37211, 2890, 11, 'HylaFax服务器'),
(37212, 2891, 11, 'HylaFax服务器主机名'),
(37213, 2892, 11, '活跃的'),
(37214, 2893, 11, '高血压'),
(37215, 2894, 11, '高血压：血压测量'),
(37216, 2895, 11, '高血压：血压测量（CQM）'),
(37217, 2896, 11, '甲状腺功能亢进症'),
(37218, 2897, 11, '甲状腺功能减退症'),
(37219, 2898, 11, '子宫切除术'),
(37220, 2899, 11, '我'),
(37221, 2900, 11, '我在这段时间里忙碌。'),
(37222, 2901, 11, '我没有权限读取 '),
(37223, 2902, 11, '国际疾病分类'),
(37224, 2905, 11, '国际疾病分类9'),
(37225, 2909, 11, '编号'),
(37226, 2910, 11, '编号'),
(37227, 2911, 11, '编号不能为空'),
(37228, 2912, 11, '身份证'),
(37229, 2913, 11, '身份证有效期'),
(37230, 2914, 11, '经鉴定为'),
(37231, 2915, 11, '标识符（一个字）'),
(37232, 2917, 11, '空闲会话超时秒'),
(37233, 2919, 11, '如果所有的数据都列有完整的这种形式'),
(37234, 2920, 11, '如果结算的理由是用来输入姓名的诊断代码类型。'),
(37235, 2921, 11, '如果输入的，只选择那些谁有这样的服务'),
(37236, 2922, 11, '如果任何一部分的名字，姓氏或姓氏，名字'),
(37237, 2923, 11, '如果支付'),
(37238, 2924, 11, '如果人已过世，输入逝世日期。'),
(37239, 2925, 11, '如果使用SMTP服务器，输入主机名或地址。'),
(37240, 2926, 11, '如果使用SMTP服务器，输入端口(通常25)。'),
(37241, 2927, 11, '如果失业，选择输入学生'),
(37242, 2929, 11, '如果你改变eprescription e-rx作用，它可能影响eprescription工作流。如果你面对任何困难，联系你的eprescription供应商。'),
(37243, 2931, 11, '如果你选择上传电子汇款，然后搜索窗口重新显示本身与匹配发票从X 12文件。你可以点击任何这些发票编号（如下所述）如果你希望做任何修正之前的汇款信息应用。应用更改，单击文件过程的时间'),
(37244, 2932, 11, '如果你输入了支付日期在搜索页'),
(37245, 2933, 11, '如果你想改变数据类型，或添加行或列'),
(37246, 2934, 11, '如果你想升级数据库，将数据库文件在以下目录'),
(37247, 2936, 11, '忽视'),
(37248, 2937, 11, '疾病'),
(37249, 2938, 11, '即时通讯'),
(37250, 2941, 11, '影像服务'),
(37251, 2942, 11, '免疫'),
(37252, 2943, 11, '免疫编号'),
(37253, 2945, 11, '免疫日期'),
(37254, 2947, 11, '免疫批号'),
(37255, 2948, 11, '免疫制造商'),
(37256, 2949, 11, '免疫登记'),
(37257, 2951, 11, '免疫接种服务'),
(37258, 2952, 11, '免疫标题'),
(37259, 2953, 11, '免疫接种'),
(37260, 2954, 11, '免疫接种'),
(37261, 2955, 11, '免疫学'),
(37262, 2956, 11, '种植体'),
(37263, 2957, 11, '导入'),
(37264, 2961, 11, '进口证书的浏览器。'),
(37265, 2962, 11, '导入配置'),
(37266, 2964, 11, '导入客户'),
(37267, 2965, 11, '导入客户统计数据'),
(37268, 2969, 11, '从会计导入'),
(37269, 2972, 11, '改良的'),
(37270, 2973, 11, '在'),
(37271, 2974, 11, '在'),
(37272, 2975, 11, '在每只眼睛'),
(37273, 2976, 11, '在左眼'),
(37274, 2977, 11, '在鼻孔'),
(37275, 2978, 11, '在办公室'),
(37276, 2979, 11, '在右眼'),
(37277, 2980, 11, '在内部'),
(37278, 2981, 11, '不活跃'),
(37279, 2982, 11, '无效天'),
(37280, 2983, 11, '收件箱'),
(37281, 2986, 11, '包括校验'),
(37282, 2987, 11, '包括完成'),
(37283, 2988, 11, '包括活跃用户'),
(37284, 2989, 11, '包括未分类'),
(37285, 2990, 11, '包括不活跃数据'),
(37286, 2991, 11, '包括生命迹象'),
(37287, 2992, 11, '包括生命迹象数据？'),
(37288, 2993, 11, '包括不活跃数据'),
(37289, 2994, 11, '收入'),
(37290, 2996, 11, '不完全'),
(37291, 2997, 11, '不完全流产治疗'),
(37292, 2998, 11, '失禁'),
(37293, 2999, 11, '将临床实验结果为认证的电子病历结构化数据的技术。'),
(37294, 3001, 11, '增加：'),
(37295, 3002, 11, '弥偿保险'),
(37296, 3003, 11, '不定'),
(37297, 3004, 11, '印第安'),
(37298, 3005, 11, '显示异常'),
(37299, 3006, 11, '表明，如果这个问题目前正在积极'),
(37300, 3008, 11, '使用专门的指标'),
(37301, 3009, 11, '贫困的患者'),
(37302, 3010, 11, '贫困患者报告'),
(37303, 3011, 11, '贫困'),
(37304, 3014, 11, '人工流产'),
(37305, 3016, 11, '不合格'),
(37306, 3017, 11, '感染/脓肿'),
(37307, 3018, 11, '感染'),
(37308, 3019, 11, '插入硬币'),
(37309, 3020, 11, '不孕症'),
(37310, 3021, 11, '1 型流感'),
(37311, 3022, 11, '2 型流感'),
(37312, 3023, 11, '接种流感患者> = 50岁'),
(37313, 3024, 11, '接种流感患者> = 50岁（CQM）'),
(37314, 3025, 11, '流感疫苗'),
(37315, 3026, 11, '信息'),
(37316, 3027, 11, '信息测试1'),
(37317, 3028, 11, '信息测试2'),
(37318, 3029, 11, '信息测试3'),
(37319, 3030, 11, '信息测试4'),
(37320, 3031, 11, '信息测试5'),
(37321, 3032, 11, '信息测试6'),
(37322, 3034, 11, '吸入'),
(37323, 3035, 11, 'inhilations'),
(37324, 3037, 11, '首位使用者'),
(37325, 3038, 11, '损伤/康复');
INSERT INTO `lang_definitions` VALUES
(37326, 3039, 11, '注射剂'),
(37327, 3040, 11, '注射剂'),
(37328, 3041, 11, '受伤的身体部位'),
(37329, 3042, 11, '受伤的'),
(37330, 3043, 11, '受伤'),
(37331, 3044, 11, '损伤机理'),
(37332, 3045, 11, '损伤报告'),
(37333, 3046, 11, '损伤监测'),
(37334, 3047, 11, '损伤类型'),
(37335, 3048, 11, '损伤/疾病有关'),
(37336, 3051, 11, '输入字段'),
(37337, 3052, 11, '印度卢比'),
(37338, 3056, 11, '插件调整'),
(37339, 3057, 11, '插件捆绑'),
(37340, 3058, 11, '插件代码'),
(37341, 3061, 11, '插件多缴'),
(37342, 3063, 11, '移民局退款'),
(37343, 3064, 11, '移民局摘要'),
(37344, 3065, 11, '移民局1'),
(37345, 3066, 11, '移民局2'),
(37346, 3067, 11, '移民局3'),
(37347, 3069, 11, '插入失败： '),
(37348, 3070, 11, '插入到表的旧事件'),
(37349, 3072, 11, '失眠'),
(37350, 3074, 11, '检查；视察'),
(37351, 3075, 11, '不全脱位'),
(37352, 3077, 11, '安装'),
(37353, 3079, 11, '安装数据库'),
(37354, 3081, 11, '指示'),
(37355, 3082, 11, '指示'),
(37356, 3084, 11, '介绍'),
(37357, 3086, 11, '胰岛素依赖型客户'),
(37358, 3087, 11, '保险'),
(37359, 3088, 11, '保险'),
(37360, 3093, 11, '保险训练班'),
(37361, 3094, 11, '保险公司'),
(37362, 3095, 11, '保险公司'),
(37363, 3096, 11, '保险公司搜索/添加'),
(37364, 3098, 11, '保险数据'),
(37365, 3099, 11, '保险信息文件'),
(37366, 3100, 11, '保险号码'),
(37367, 3101, 11, '支付保证金'),
(37368, 3103, 11, '保险提供者'),
(37369, 3107, 11, '摄入总量'),
(37370, 3108, 11, '摄入日期'),
(37371, 3109, 11, '智力下降'),
(37372, 3113, 11, '内部错误-无选定页面'),
(37373, 3114, 11, '内部错误-无客户身份证明'),
(37374, 3115, 11, '内部错误门诊上传的文件！'),
(37375, 3116, 11, '内部错误'),
(37376, 3117, 11, 'no drug ID specified!'),
(37377, 3119, 11, '内部错误：索赔 '),
(37378, 3120, 11, '内部错误：治疗'),
(37379, 3121, 11, '内部错误：控制或治疗丢失。'),
(37380, 3122, 11, '内部错误：我们不能进行治疗！'),
(37381, 3123, 11, '内部标识符（图）'),
(37382, 3126, 11, '内部转诊客户'),
(37383, 3127, 11, '内部时间收集'),
(37384, 3128, 11, '国际责任'),
(37385, 3129, 11, '译员，口译者'),
(37386, 3130, 11, '需要口译？'),
(37387, 3131, 11, '间质性肺炎'),
(37388, 3132, 11, '间隔'),
(37389, 3135, 11, '介入'),
(37390, 3137, 11, '耐受'),
(37391, 3139, 11, '肌肉的'),
(37392, 3140, 11, '静脉注射地'),
(37393, 3141, 11, '介绍'),
(37394, 3144, 11, '存在无效字符'),
(37395, 3147, 11, '无效的长度'),
(37396, 3148, 11, '无效的非数字字符'),
(37397, 3149, 11, '无效或者缺失支付人来源的代码 '),
(37398, 3151, 11, '无效服务代码'),
(37399, 3152, 11, '无效的源名称'),
(37400, 3154, 11, 'InvAmt'),
(37401, 3155, 11, '存货清单'),
(37402, 3156, 11, '清查活动'),
(37403, 3157, 11, '库存和销售药品和非处方药产品'),
(37404, 3158, 11, '存货和销售药物'),
(37405, 3159, 11, '此订单的详细目录不存在'),
(37406, 3160, 11, '盘存清单'),
(37407, 3161, 11, '库存事务'),
(37408, 3162, 11, '发票'),
(37409, 3163, 11, '发票'),
(37410, 3166, 11, '发票日期'),
(37411, 3167, 11, '发票无日期'),
(37412, 3168, 11, '发票号'),
(37413, 3169, 11, '发票的参考号码'),
(37414, 3170, 11, '如果有使用，发票的参考号码'),
(37415, 3171, 11, '发票的参考号码池'),
(37416, 3172, 11, '发票Refno池'),
(37417, 3173, 11, '发票：'),
(37418, 3174, 11, '计划生育'),
(37419, 3177, 11, '计划生育生殖健康数据'),
(37420, 3178, 11, '计生统计报告'),
(37421, 3179, 11, '计划生育统计'),
(37422, 3180, 11, '灭活脊髓灰质炎疫苗 1'),
(37423, 3181, 11, '灭活脊髓灰质炎疫苗 2'),
(37424, 3182, 11, '灭活脊髓灰质炎疫苗 3'),
(37425, 3183, 11, '灭活脊髓灰质炎疫苗 4'),
(37426, 3185, 11, '无规律心跳'),
(37427, 3186, 11, '兴奋性'),
(37428, 3187, 11, '刺激物'),
(37429, 3191, 11, '必填字段'),
(37430, 3192, 11, '是一个根节点和不可删除。'),
(37431, 3197, 11, '无效（十进制分数是好的）。'),
(37432, 3198, 11, '是使用安全模式？'),
(37433, 3200, 11, '是文本形式布局的翻译？'),
(37434, 3201, 11, '本文从列表翻译？'),
(37435, 3202, 11, '该文件是加密？'),
(37436, 3204, 11, '这是一个诊断的类型？'),
(37437, 3209, 11, '这是代码类型活动？'),
(37438, 3212, 11, '这是隐藏在收费表？'),
(37439, 3214, 11, '太长'),
(37440, 3216, 11, '发行；流出'),
(37441, 3217, 11, '发行物；争论点'),
(37442, 3218, 11, '签发日期'),
(37443, 3219, 11, '签发编号'),
(37444, 3220, 11, '签发标题'),
(37445, 3223, 11, '议题'),
(37446, 3224, 11, '问题（伤害/医疗/过敏）'),
(37447, 3225, 11, '议题（受伤/医疗/过敏）'),
(37448, 3226, 11, '问题和治疗'),
(37449, 3227, 11, '问题和治疗'),
(37450, 3228, 11, '问题没有授权'),
(37451, 3229, 11, '问题一部分'),
(37452, 3230, 11, '意大利语'),
(37453, 3231, 11, '项目'),
(37454, 3232, 11, '项目'),
(37455, 3234, 11, '项目负荷失败'),
(37456, 3235, 11, 'IU/L'),
(37457, 3236, 11, '宫内节育器'),
(37458, 3237, 11, '静脉点滴'),
(37459, 3238, 11, '一月'),
(37460, 3239, 11, '一月'),
(37461, 3240, 11, '日语'),
(37462, 3241, 11, '黄疸病'),
(37463, 3243, 11, '工作描述'),
(37464, 3244, 11, '工作卡'),
(37465, 3245, 11, '关节错位'),
(37466, 3246, 11, '关节疼痛'),
(37467, 3247, 11, '关节扭伤'),
(37468, 3248, 11, '七月'),
(37469, 3249, 11, '七月'),
(37470, 3250, 11, '六月'),
(37471, 3251, 11, '六月'),
(37472, 3252, 11, '在检查信息蓝色区域，你把你的搜索参数。您可以搜索的客户姓名，号码图表，遇到数字或日期的服务，或任何组合的这些。你也可以选择是否你想看到所有的发票，开发票，发票，或是由于（由客户）。点击搜索按钮进行搜索。'),
(37473, 3253, 11, '只是我'),
(37474, 3255, 11, '辩解'),
(37475, 3256, 11, '理由/保存'),
(37476, 3258, 11, 'K，这里是休息'),
(37477, 3264, 11, '关键'),
(37478, 3265, 11, '关键词'),
(37479, 3266, 11, '公斤'),
(37480, 3267, 11, '公斤/平方公尺'),
(37481, 3269, 11, '肾细胞癌'),
(37482, 3270, 11, '肾功能衰竭'),
(37483, 3271, 11, '肾脏感染'),
(37484, 3272, 11, '肾结石'),
(37485, 3273, 11, '肾移植'),
(37486, 3277, 11, '膝盖'),
(37487, 3278, 11, '膝盖问题'),
(37488, 3279, 11, '膝关节置换术'),
(37489, 3282, 11, '韩国'),
(37490, 3286, 11, '实验室'),
(37491, 3288, 11, '实验室交易所网站地址'),
(37492, 3289, 11, '实验室交易所网站编号'),
(37493, 3290, 11, '实验室外汇令牌ID'),
(37494, 3294, 11, '实验室查询状态'),
(37495, 3295, 11, '实验报告'),
(37496, 3296, 11, '实验结果'),
(37497, 3297, 11, '实验室检测结果'),
(37498, 3299, 11, '实验室检测结果报告'),
(37499, 3300, 11, '实验室服务'),
(37500, 3301, 11, '实验室测试结果'),
(37501, 3303, 11, '标签'),
(37502, 3304, 11, '标签不能空白'),
(37503, 3305, 11, '标签COLS'),
(37504, 3306, 11, '这种类型的标签'),
(37505, 3307, 11, 'LabelCols必须是一个数字1和999之间'),
(37506, 3308, 11, '标签'),
(37507, 3311, 11, '实验室'),
(37508, 3312, 11, '裂伤/皮肤状况'),
(37509, 3313, 11, '撕裂/磨损'),
(37510, 3316, 11, '语言'),
(37511, 3317, 11, '语言代码'),
(37512, 3318, 11, '语言定义的补充'),
(37513, 3319, 11, '语言界面工具'),
(37514, 3320, 11, '语言列表(可写、只许添加－可选项)'),
(37515, 3321, 11, '语言名称'),
(37516, 3322, 11, '语言：'),
(37517, 3324, 11, '老挝'),
(37518, 3325, 11, '上次'),
(37519, 3326, 11, '上次活动日期'),
(37520, 3328, 11, '最后发票日期：'),
(37521, 3330, 11, '上一个日历年'),
(37522, 3333, 11, '上次接触'),
(37523, 3343, 11, '上个月'),
(37524, 3344, 11, '姓'),
(37525, 3345, 11, '姓'),
(37526, 3346, 11, '姓氏：'),
(37527, 3350, 11, '最新评论'),
(37528, 3352, 11, '最后保存'),
(37529, 3356, 11, '最后更新'),
(37530, 3357, 11, '最后验证'),
(37531, 3358, 11, '最后门诊'),
(37532, 3360, 11, '晚期复发（2-12莫）'),
(37533, 3361, 11, '外踝'),
(37534, 3362, 11, '外踝：'),
(37535, 3363, 11, '偏侧'),
(37536, 3364, 11, '偏侧此过程中，如适用'),
(37537, 3365, 11, '横向流离失所的PMI：'),
(37538, 3373, 11, '布局的基础'),
(37539, 3374, 11, '布局编辑器'),
(37540, 3375, 11, '布局组'),
(37541, 3376, 11, '布局风格'),
(37542, 3378, 11, '基于布局的门诊形式'),
(37543, 3379, 11, '布局'),
(37544, 3380, 11, '磅'),
(37545, 3381, 11, '磅'),
(37546, 3382, 11, '低密度脂蛋白'),
(37547, 3383, 11, '留下空白，如果仍然活跃'),
(37548, 3384, 11, '留空以保持原有名'),
(37549, 3385, 11, '留空密码保持不变。'),
(37550, 3386, 11, '留言给'),
(37551, 3387, 11, '离开表格'),
(37552, 3388, 11, '离开通行短语留空将不加密文件'),
(37553, 3390, 11, '左'),
(37554, 3391, 11, '左耳'),
(37555, 3392, 11, '左耳'),
(37556, 3394, 11, '左：'),
(37557, 3395, 11, '左： '),
(37558, 3396, 11, '腿部疼痛/抽筋'),
(37559, 3397, 11, '法律'),
(37560, 3399, 11, '法律纸张尺寸'),
(37561, 3400, 11, '图例：'),
(37562, 3401, 11, '长度'),
(37563, 3402, 11, '如果没有修饰符的长度，0'),
(37564, 3403, 11, '小于'),
(37565, 3404, 11, '小于或等于'),
(37566, 3405, 11, '减的私人信息（写，addonly可选）'),
(37567, 3406, 11, '信函'),
(37568, 3407, 11, '信函生成器'),
(37569, 3408, 11, 'Letter纸张尺寸'),
(37570, 3409, 11, '信笺，医生迹象'),
(37571, 3410, 11, '信笺，客户的迹象'),
(37572, 3411, 11, '紧急级别'),
(37573, 3412, 11, '责任'),
(37574, 3413, 11, '责任医疗'),
(37575, 3414, 11, '牌照/ ID'),
(37576, 3419, 11, 'LicensedPrescriber最后的名字'),
(37577, 3420, 11, 'LicensedPrescriber非营利机构'),
(37578, 3421, 11, 'LicensedPrescriber的UPIN'),
(37579, 3423, 11, '生活方式'),
(37580, 3424, 11, '生活方式的地位'),
(37581, 3425, 11, '韧带撕裂或扭伤'),
(37582, 3428, 11, '极限活动'),
(37583, 3429, 11, '范围'),
(37584, 3431, 11, '链接'),
(37585, 3432, 11, '链接到客户'),
(37586, 3433, 11, '链接'),
(37587, 3436, 11, '链接文件'),
(37588, 3438, 11, '表'),
(37589, 3439, 11, '列表框'),
(37590, 3440, 11, '列表框'),
(37591, 3441, 11, '列表框瓦特/附加'),
(37592, 3442, 11, '列表框瓦特/附加'),
(37593, 3443, 11, '列表编辑器'),
(37594, 3444, 11, '名单中遇到'),
(37595, 3445, 11, '列表组'),
(37596, 3446, 11, '列表保险公司'),
(37597, 3448, 11, '列表中的项目，不能以数字开头。'),
(37598, 3449, 11, '列表项包含非法字符（S）。'),
(37599, 3451, 11, '名单列表'),
(37600, 3452, 11, '列表名称'),
(37601, 3453, 11, '与数字列表的名称不能启动。'),
(37602, 3454, 11, '名单处方'),
(37603, 3455, 11, '由上述国家的数据类型“选项列表。'),
(37604, 3456, 11, '由上述国家的数据类型“选项列表。'),
(37605, 3457, 11, '听力的RFC5425 TLS syslog服务器的端口。'),
(37606, 3458, 11, '列表'),
(37607, 3460, 11, '生前遗嘱'),
(37608, 3461, 11, '微光：'),
(37609, 3462, 11, '低熔点'),
(37610, 3464, 11, '负载定义'),
(37611, 3470, 11, 'LOADING'),
(37612, 3471, 11, '加载到数据库中的文件。这将花费一些时间...'),
(37613, 3472, 11, '组委会'),
(37614, 3473, 11, '当地'),
(37615, 3476, 11, '语言环境'),
(37616, 3477, 11, '地方'),
(37617, 3478, 11, '位置'),
(37618, 3479, 11, '位置的libreehr机，并可能包含敏感数据，因此建议手动删除后，其使用的文件'),
(37619, 3480, 11, '这个地段的位置'),
(37620, 3481, 11, '地点不详'),
(37621, 3482, 11, '位置HylaFax等商店传真。'),
(37622, 3483, 11, '扫描存储的位置。'),
(37623, 3484, 11, '地点：'),
(37624, 3485, 11, '锁'),
(37625, 3492, 11, '登录'),
(37626, 3493, 11, '登录'),
(37627, 3494, 11, '注销'),
(37628, 3495, 11, '登录'),
(37629, 3496, 11, '登录为'),
(37630, 3497, 11, '登录为： '),
(37631, 3498, 11, '注销。'),
(37632, 3500, 11, '登录'),
(37633, 3501, 11, '登录'),
(37634, 3505, 11, '登出'),
(37635, 3506, 11, '注销'),
(37636, 3507, 11, '日志'),
(37637, 3508, 11, '日志查看器'),
(37638, 3510, 11, '抬头'),
(37639, 3511, 11, '很多'),
(37640, 3512, 11, '地段编号失踪！'),
(37641, 3513, 11, '批号'),
(37642, 3514, 11, '低'),
(37643, 3516, 11, '小腿'),
(37644, 3519, 11, '腰椎'),
(37645, 3520, 11, '午餐'),
(37646, 3521, 11, '午餐'),
(37647, 3522, 11, '肺癌'),
(37648, 3523, 11, '肺癌手术'),
(37649, 3524, 11, '肺：'),
(37650, 3525, 11, '肺部：'),
(37651, 3526, 11, '狼疮'),
(37652, 3528, 11, '中号'),
(37653, 3529, 11, '马类'),
(37654, 3530, 11, '马端接受流产'),
(37655, 3531, 11, '马统计'),
(37656, 3533, 11, '邮件发送'),
(37657, 3534, 11, '主'),
(37658, 3535, 11, '主要地址'),
(37659, 3536, 11, '热门窗格屏幕'),
(37660, 3537, 11, '保持积极的药物过敏名单。'),
(37661, 3538, 11, '保持积极的药物清单。'),
(37662, 3539, 11, '保持最新的问题清单，目前活跃的诊断。'),
(37663, 3540, 11, '修改最近的分类'),
(37664, 3541, 11, '新的任命'),
(37665, 3542, 11, '确定'),
(37666, 3543, 11, '分批文本文件上传到结算帐单和标记'),
(37667, 3545, 11, '不舒服'),
(37668, 3548, 11, '男性'),
(37669, 3549, 11, '男性避孕套'),
(37670, 3550, 11, '男性输精管结扎术'),
(37671, 3552, 11, '乳房X线照片'),
(37672, 3553, 11, '处理'),
(37673, 3556, 11, '处理翻译'),
(37674, 3557, 11, '管理'),
(37675, 3558, 11, '强制性和指定的域'),
(37676, 3559, 11, '强制性或特定领域，重复检查，没有搜索'),
(37677, 3560, 11, '强制性或特定领域，搜索和重复检查'),
(37678, 3561, 11, '手册'),
(37679, 3562, 11, '手动记录'),
(37680, 3563, 11, '制造商'),
(37681, 3565, 11, '三月'),
(37682, 3568, 11, '三月'),
(37683, 3569, 11, '婚姻状况'),
(37684, 3571, 11, '标记为已出账单但是略过记账'),
(37685, 3572, 11, '标记为已清除'),
(37686, 3573, 11, '标记为未出账单'),
(37687, 3575, 11, '标记为未清除'),
(37688, 3576, 11, '已婚的'),
(37689, 3578, 11, '面罩'),
(37690, 3579, 11, '发票掩码'),
(37691, 3580, 11, '客户标示掩码'),
(37692, 3581, 11, '产品标示掩码'),
(37693, 3582, 11, '符合'),
(37694, 3591, 11, '最大'),
(37695, 3594, 11, '右侧颚骨'),
(37696, 3595, 11, '最大年龄'),
(37697, 3596, 11, '最大字符数'),
(37698, 3597, 11, '最大空闲时间内注销。默认值为7200（2小时）。'),
(37699, 3600, 11, '最大限度的合理库存，0不适用'),
(37700, 3603, 11, '五月'),
(37701, 3604, 11, '管委会'),
(37702, 3605, 11, '微克'),
(37703, 3607, 11, '最后三个密码手段不允许更改密码时。'),
(37704, 3609, 11, '测量组代码'),
(37705, 3611, 11, '测量组代码'),
(37706, 3612, 11, '内踝'),
(37707, 3613, 11, '医疗补助'),
(37708, 3614, 11, '医学的/内科的'),
(37709, 3615, 11, '药物堕胎'),
(37710, 3616, 11, '医疗管理'),
(37711, 3617, 11, '医疗史'),
(37712, 3618, 11, '医疗问题'),
(37713, 3619, 11, '医疗问题'),
(37714, 3620, 11, '医疗问题'),
(37715, 3623, 11, '医疗问题'),
(37716, 3624, 11, '医学'),
(37717, 3625, 11, '病案＃'),
(37718, 3626, 11, '病案'),
(37719, 3627, 11, '发送的医疗记录'),
(37720, 3629, 11, '给出病例摘要'),
(37721, 3630, 11, '医疗系统'),
(37722, 3631, 11, '医疗类型'),
(37723, 3632, 11, '医学史（写，只添加可选）'),
(37724, 3633, 11, '医疗保险的B部分'),
(37725, 3634, 11, '医疗保险受益人'),
(37726, 3635, 11, '药物'),
(37727, 3636, 11, '药物过敏列表'),
(37728, 3638, 11, '药物列表'),
(37729, 3639, 11, '药物和解？'),
(37730, 3640, 11, '药物'),
(37731, 3641, 11, '药物：'),
(37732, 3642, 11, '内科'),
(37733, 3643, 11, '媒体'),
(37734, 3645, 11, '会员协会数据报告'),
(37735, 3646, 11, '记忆问题'),
(37736, 3647, 11, '男性'),
(37737, 3648, 11, '男性和女性'),
(37738, 3649, 11, '只有男性'),
(37739, 3650, 11, '月经初潮'),
(37740, 3651, 11, '停经期，更年期'),
(37741, 3652, 11, '月经'),
(37742, 3653, 11, '月经频率'),
(37743, 3654, 11, '心理疾病'),
(37744, 3661, 11, '消息'),
(37745, 3662, 11, '信息和提醒中心'),
(37746, 3665, 11, '发送信息'),
(37747, 3666, 11, '信息状态'),
(37748, 3670, 11, '消息'),
(37749, 3671, 11, '信息'),
(37750, 3672, 11, '今天发送的信息'),
(37751, 3673, 11, '方法'),
(37752, 3674, 11, '方法和产品'),
(37753, 3675, 11, '发送电子邮件的方法。'),
(37754, 3676, 11, '破坏性方法'),
(37755, 3677, 11, '墨西哥/ MexAmer的/奇卡诺'),
(37756, 3679, 11, '毫克'),
(37757, 3680, 11, '毫克/1立方厘米'),
(37758, 3681, 11, '毫克/2立方厘米'),
(37759, 3682, 11, '毫克/3立方厘米'),
(37760, 3683, 11, '毫克/4立方厘米'),
(37761, 3684, 11, '毫克/5立方厘'),
(37762, 3685, 11, '毫克/升'),
(37763, 3686, 11, '中间'),
(37764, 3687, 11, '名和姓之间的名字'),
(37765, 3688, 11, '中间名字'),
(37766, 3690, 11, '中级处方分析'),
(37767, 3691, 11, '中级处方名'),
(37768, 3692, 11, '中级处方姓氏'),
(37769, 3693, 11, '中层处方前缀'),
(37770, 3694, 11, '中级处方的UPIN'),
(37771, 3695, 11, '风采'),
(37772, 3696, 11, '移民和季节性工人？'),
(37773, 3697, 11, '移民/季节'),
(37774, 3698, 11, 'MIL / CU.MM'),
(37775, 3702, 11, 'Mime类型'),
(37776, 3703, 11, '分'),
(37777, 3704, 11, '分'),
(37778, 3705, 11, '最低年龄'),
(37779, 3706, 11, '小关节劳损+ / -滑膜炎'),
(37780, 3708, 11, '分钟'),
(37781, 3709, 11, '分钟'),
(37782, 3710, 11, '分钟'),
(37783, 3712, 11, '其他类型'),
(37784, 3713, 11, '杂项帐单选项'),
(37785, 3714, 11, '其他结算方式的医疗卫生融资- 1500'),
(37786, 3715, 11, '杂项帐单选项相关'),
(37787, 3716, 11, '杂项'),
(37788, 3717, 11, '丢失'),
(37789, 3718, 11, '丢失'),
(37790, 3719, 11, '缺少必要的字段'),
(37791, 3720, 11, '遗失费用'),
(37792, 3721, 11, '丢失的MODS'),
(37793, 3722, 11, '丢失或无效'),
(37794, 3723, 11, '椎间盘脱出缺失'),
(37795, 3724, 11, '丢失报告日期'),
(37796, 3725, 11, '丢失斜线付款人源代码后 '),
(37797, 3726, 11, '混合'),
(37798, 3727, 11, '毫升'),
(37799, 3728, 11, '月/日/年'),
(37800, 3729, 11, '毫米/汞柱'),
(37801, 3730, 11, '毫米汞柱'),
(37802, 3731, 11, '孕产妇死亡率1'),
(37803, 3732, 11, '孕产妇死亡率2'),
(37804, 3733, 11, '移动'),
(37805, 3734, 11, '移动电话'),
(37806, 3735, 11, '修改'),
(37807, 3741, 11, '调节器'),
(37808, 3742, 11, '调节器'),
(37809, 3745, 11, '修改付款'),
(37810, 3746, 11, '修改长度'),
(37811, 3753, 11, '一'),
(37812, 3754, 11, '周一至周五'),
(37813, 3755, 11, 'Wed &amp; Fri'),
(37814, 3756, 11, '周一'),
(37815, 3758, 11, '月'),
(37816, 3759, 11, '月'),
(37817, 3760, 11, '按月查看'),
(37818, 3761, 11, '月'),
(37819, 3762, 11, '月收入'),
(37820, 3763, 11, '几个月'),
(37821, 3765, 11, '超过100的记录，发现。请缩小您的搜索标准。'),
(37822, 3766, 11, '超过50的结果，请让您的搜索更具体。'),
(37823, 3767, 11, '大多数列标题可以点击更改排序顺序'),
(37824, 3768, 11, '最近从'),
(37825, 3770, 11, '从最新的生命迹象：'),
(37826, 3771, 11, '母亲'),
(37827, 3772, 11, '母亲姓名'),
(37828, 3774, 11, '口'),
(37829, 3775, 11, '移动'),
(37830, 3776, 11, '移动文件类型'),
(37831, 3777, 11, '下移'),
(37832, 3779, 11, '移动客户'),
(37833, 3780, 11, '移动到'),
(37834, 3781, 11, '上移'),
(37835, 3783, 11, '先生'),
(37836, 3785, 11, '女士'),
(37837, 3786, 11, '小姐'),
(37838, 3794, 11, 'MSP代码'),
(37839, 3796, 11, '多语工具'),
(37840, 3797, 11, '多个地区'),
(37841, 3799, 11, '多个地段'),
(37842, 3800, 11, '多个修饰符可以由逗号分隔或空间，最大4（M 1：平方米：立方米：M 4）'),
(37843, 3802, 11, '多种族'),
(37844, 3803, 11, '杂音'),
(37845, 3804, 11, '肌肉疼痛'),
(37846, 3805, 11, '肌肉疼痛'),
(37847, 3806, 11, '肌肉发红'),
(37848, 3807, 11, '肌肉僵硬'),
(37849, 3808, 11, '肌肉肿胀'),
(37850, 3809, 11, '肌肉温度'),
(37851, 3810, 11, '肌肉'),
(37852, 3811, 11, '肌肉损伤'),
(37853, 3812, 11, '肌肉骨骼'),
(37854, 3813, 11, '如果不使用SM TP认证必须是空的。'),
(37855, 3814, 11, '共同定义'),
(37856, 3815, 11, '机械振荡分析'),
(37857, 3818, 11, '我自己的'),
(37858, 3821, 11, '不适合'),
(37859, 3822, 11, '不适合'),
(37860, 3823, 11, '名字'),
(37861, 3825, 11, '名称（查看更多）'),
(37862, 3826, 11, '名字1'),
(37863, 3827, 11, '名字2'),
(37864, 3828, 11, '姓名与头衔的免疫系统管理员'),
(37865, 3831, 11, '活动名称'),
(37866, 3832, 11, '保险公司名称'),
(37867, 3833, 11, '服务人员名称'),
(37868, 3834, 11, '客户提醒发件人名称'),
(37869, 3835, 11, '翻译名称'),
(37870, 3836, 11, '名称/内容'),
(37871, 3837, 11, '名称：'),
(37872, 3838, 11, '鼻腔：'),
(37873, 3839, 11, '鼻腔：右侧正常'),
(37874, 3840, 11, '鼻粘膜粉红色，隔中线'),
(37875, 3841, 11, '国家债券'),
(37876, 3842, 11, '国家债券配置'),
(37877, 3844, 11, '国籍'),
(37878, 3845, 11, '国家债券'),
(37879, 3847, 11, '夏威夷原住民和其他太平洋岛民'),
(37880, 3852, 11, '反胃恶心'),
(37881, 3854, 11, '导航'),
(37882, 3855, 11, '导航区包括遇到的形式'),
(37883, 3856, 11, '导航区采用全高框架'),
(37884, 3857, 11, '区域导航门诊'),
(37885, 3858, 11, '导航区宽度'),
(37886, 3859, 11, '导航菜单包括对单选按钮'),
(37887, 3860, 11, '导航菜单树视图'),
(37888, 3861, 11, '导航用滑动菜单'),
(37889, 3862, 11, '规格化设备坐标'),
(37890, 3864, 11, '规格化设备坐标号码'),
(37891, 3866, 11, '颈部'),
(37892, 3867, 11, '颈部问题'),
(37893, 3868, 11, '颈部柔软'),
(37894, 3869, 11, '需要输入一个描述'),
(37895, 3870, 11, '需要输入一个返回值'),
(37896, 3871, 11, '需要输入标识符'),
(37897, 3872, 11, '需要输入标题'),
(37898, 3873, 11, '需要验证'),
(37899, 3874, 11, '需要对齐'),
(37900, 3875, 11, '需要二次计费'),
(37901, 3876, 11, '阴性'),
(37902, 3877, 11, '阴性'),
(37903, 3880, 11, '神经损伤'),
(37904, 3881, 11, '神经/神经损害'),
(37905, 3882, 11, '神经麻木'),
(37906, 3883, 11, '神经虚弱'),
(37907, 3884, 11, '神经系统'),
(37908, 3885, 11, '从不'),
(37909, 3886, 11, '从不喝酒'),
(37910, 3887, 11, '从不吸烟'),
(37911, 3888, 11, '新'),
(37912, 3889, 11, '新=>'),
(37913, 3890, 11, '新的受体'),
(37914, 3892, 11, '新过敏'),
(37915, 3894, 11, '新的任命'),
(37916, 3895, 11, '新类型'),
(37917, 3896, 11, '新类型'),
(37918, 3897, 11, '新客户'),
(37919, 3898, 11, '新的咨询'),
(37920, 3899, 11, '新作物'),
(37921, 3900, 11, '新的定义设置添加'),
(37922, 3901, 11, '新建文档'),
(37923, 3904, 11, '新的治疗'),
(37924, 3905, 11, '创建新的治疗编号'),
(37925, 3906, 11, '新的治疗表格'),
(37926, 3907, 11, '新的治疗未授权'),
(37927, 3908, 11, '新Enctr'),
(37928, 3909, 11, '新的设施信息'),
(37929, 3912, 11, '新组'),
(37930, 3913, 11, '新组信息'),
(37931, 3914, 11, '新损伤/状态'),
(37932, 3916, 11, '事件新的限制'),
(37933, 3917, 11, '新表格'),
(37934, 3918, 11, '新医嘱'),
(37935, 3919, 11, '新段落'),
(37936, 3920, 11, '新密码'),
(37937, 3921, 11, '新客户'),
(37938, 3922, 11, '新客户'),
(37939, 3923, 11, '新客户治疗'),
(37940, 3924, 11, '新客户表格'),
(37941, 3925, 11, '新客户编号'),
(37942, 3926, 11, '新的付款方式'),
(37943, 3928, 11, '新客户'),
(37944, 3929, 11, '实验室新成果'),
(37945, 3930, 11, '新搜索'),
(37946, 3931, 11, '新的提名'),
(37947, 3932, 11, '新用户'),
(37948, 3934, 11, '新门诊'),
(37949, 3935, 11, '新/搜索'),
(37950, 3936, 11, 'NewCrop帐户状态'),
(37951, 3937, 11, 'NewCrop管理'),
(37952, 3938, 11, 'NewCrop呼叫失败'),
(37953, 3939, 11, 'NewCrop一声'),
(37954, 3944, 11, 'NewCrop ERX名字'),
(37955, 3945, 11, 'NewCrop ERX合作伙伴名字'),
(37956, 3946, 11, 'NewCrop ERX密码'),
(37957, 3947, 11, 'NewCrop ERX的角色'),
(37958, 3948, 11, 'NewCrop ERX的角色'),
(37959, 3949, 11, 'NewCrop ERX网站地址'),
(37960, 3954, 11, 'NewCrop ERX网络服务地址'),
(37961, 3955, 11, 'NewCrop ERX经理'),
(37962, 3956, 11, 'NewCrop ERX MedEntry'),
(37963, 3957, 11, 'NewCrop ERX中级处方'),
(37964, 3958, 11, 'NewCrop ERX护士'),
(37965, 3959, 11, 'NewCrop ERX监督医生'),
(37966, 3961, 11, '报纸'),
(37967, 3962, 11, '下一个'),
(37968, 3964, 11, '第二天'),
(37969, 3965, 11, '下个月'),
(37970, 3966, 11, '下个月（按住菜单）'),
(37971, 3968, 11, '下周'),
(37972, 3969, 11, '明年（按住菜单）'),
(37973, 3971, 11, '昵称'),
(37974, 3973, 11, '盗汗'),
(37975, 3975, 11, '否'),
(37976, 3976, 11, '否'),
(37977, 3977, 11, '禁止存取'),
(37978, 3978, 11, '没有启动疗程客户的提醒。'),
(37979, 3980, 11, '没有调整的原因类型的发现'),
(37980, 3983, 11, '没有预约'),
(37981, 3985, 11, '没有计费系统是目前活跃'),
(37982, 3987, 11, '没有发现包括在产品出口'),
(37983, 3989, 11, '没有代码指定！'),
(37984, 3992, 11, '没有诊断'),
(37985, 3993, 11, '没有诊断档案'),
(37986, 3995, 11, '没有结束日期'),
(37987, 3996, 11, '未找到任何条目，请使用下面的表格添加条目。'),
(37988, 3997, 11, '没有找到错误'),
(37989, 3998, 11, '没有事件'),
(37990, 4001, 11, '没有被选中'),
(37991, 4002, 11, '没有疝气'),
(37992, 4005, 11, '没有伤害/疾病'),
(37993, 4006, 11, '没有保险公司'),
(37994, 4007, 11, '没有问题'),
(37995, 4009, 11, '没有项目在选定的类别'),
(37996, 4010, 11, '没有一项被选中！'),
(37997, 4025, 11, '没有日志文件存在选定日期'),
(37998, 4027, 11, '没有肿块，压痛'),
(37999, 4028, 11, '对于所有在识别代码，没有发现符合的客户'),
(38000, 4030, 11, '没有发现匹配。'),
(38001, 4031, 11, '没有发现匹配。创建新的客户吗？'),
(38002, 4033, 11, '没有发现新的研究成果'),
(38003, 4034, 11, '没有备注'),
(38004, 4035, 11, '没有器官肿大'),
(38005, 4036, 11, '没有被发现的这一时期。'),
(38006, 4037, 11, '没有其他的电话号码列'),
(38007, 4039, 11, '没有找到合作伙伴'),
(38008, 4040, 11, '没有客户记录发现特定的选择标准'),
(38009, 4041, 11, '没有客户记录发现对于给定的重新识别代码'),
(38010, 4042, 11, '无周边水肿'),
(38011, 4043, 11, '没有找到药房'),
(38012, 4044, 11, '没有找到处方'),
(38013, 4045, 11, '没有呈现疾病/损伤'),
(38014, 4046, 11, '没有以前的作品。'),
(38015, 4047, 11, '没有经营实体，设施清单中选择'),
(38016, 4051, 11, '没有提供发现'),
(38017, 4052, 11, '没有皮疹或异常病变'),
(38018, 4053, 11, '没有找到记录'),
(38019, 4055, 11, '没有找到记录。请扩大您的搜索条件。'),
(38020, 4056, 11, '没有提醒'),
(38021, 4057, 11, '没有结果发现，上述搜索条件。'),
(38022, 4058, 11, '没有结果'),
(38023, 4060, 11, '对于搜索没有找到结果'),
(38024, 4061, 11, '找不到结果，请再试一次。'),
(38025, 4062, 11, '没有结果，请再次托盘。'),
(38026, 4063, 11, '没有结果，请再试一次。'),
(38027, 4065, 11, '没有展示'),
(38028, 4067, 11, '无窦嫩：'),
(38029, 4068, 11, '没有皮肤压痕或乳腺结节'),
(38030, 4069, 11, '没有这样的上下文名称'),
(38031, 4071, 11, '没有睾丸触痛，群众'),
(38032, 4072, 11, '没有惊险刺激或抛掷'),
(38033, 4075, 11, '没有门诊'),
(38034, 4076, 11, '命脉已被记录在案。'),
(38035, 4077, 11, '不，取消'),
(38036, 4078, 11, '包括自动的无过失保险是小学'),
(38037, 4079, 11, '编号：'),
(38038, 4080, 11, '夜尿'),
(38039, 4081, 11, '非付费'),
(38040, 4082, 11, '非报告的报告'),
(38041, 4083, 11, '非特异性损伤'),
(38042, 4084, 11, '非电子'),
(38043, 4085, 11, '非胰岛素依赖型糖尿病'),
(38044, 4087, 11, '非生殖健康医疗'),
(38045, 4088, 11, '非生殖健康的非医疗'),
(38046, 4089, 11, '没有'),
(38047, 4090, 11, '没有'),
(38048, 4091, 11, '没有定义'),
(38049, 4092, 11, '没有被记录在案'),
(38050, 4093, 11, '以上皆非'),
(38051, 4094, 11, '顶配行没有能够完全地空白。'),
(38052, 4095, 11, '非胰岛素依赖型'),
(38053, 4096, 11, '也不'),
(38054, 4097, 11, '正常'),
(38055, 4098, 11, '正常的“基本法”'),
(38056, 4099, 11, '心脏正常考试：'),
(38057, 4100, 11, '心脏正常考试： '),
(38058, 4101, 11, '正常肺组织考试：'),
(38059, 4102, 11, '正常肺组织考试： '),
(38060, 4103, 11, '普通办公室门诊'),
(38061, 4104, 11, '正常口咽：'),
(38062, 4105, 11, '正常吗'),
(38063, 4106, 11, '正常右：'),
(38064, 4107, 11, '普通视图'),
(38065, 4108, 11, '正常情况：'),
(38066, 4109, 11, '通常，这应该被选中。不相关的门诊控制。'),
(38067, 4112, 11, '挪威'),
(38068, 4115, 11, '鼻子'),
(38069, 4116, 11, '鼻血'),
(38070, 4117, 11, '不是一个字母或数字'),
(38071, 4119, 11, '并不是所有的领域都需要所有的代码或代码类型。'),
(38072, 4120, 11, '不允许'),
(38073, 4121, 11, '不允许删除Administrators组'),
(38074, 4122, 11, '不允许编辑'),
(38075, 4123, 11, '不允许灭活所有安全对象'),
(38076, 4124, 11, '不允许任何灭活从管理员ACL'),
(38077, 4125, 11, '不允许从Administrators组删除admin用户'),
(38078, 4126, 11, '不允许从Administrators组删除该用户'),
(38079, 4128, 11, '未经授权门诊PostCalendar模块'),
(38080, 4129, 11, '未经授权'),
(38081, 4130, 11, '未经授权'),
(38082, 4131, 11, '这支球队没有授权！'),
(38083, 4132, 11, '这支球队没有授权。'),
(38084, 4135, 11, '不提供'),
(38085, 4137, 11, '不收费'),
(38086, 4138, 11, '不检查'),
(38087, 4139, 11, '未签出'),
(38088, 4141, 11, '不因'),
(38089, 4143, 11, '不检查'),
(38090, 4144, 11, '不检查：'),
(38091, 4145, 11, '不检查： '),
(38092, 4146, 11, '未找到'),
(38093, 4148, 11, '没有找到！'),
(38094, 4149, 11, '非西班牙裔或拉丁裔'),
(38095, 4152, 11, '以来从未见过'),
(38096, 4154, 11, '不发了'),
(38097, 4156, 11, '未指定。'),
(38098, 4157, 11, '注意'),
(38099, 4158, 11, '注意代码'),
(38100, 4159, 11, '注意将需要5-10分钟充分处理后，你点击安装'),
(38101, 4160, 11, '注意将需要5-10分钟充分处理后，单击“升级”'),
(38102, 4161, 11, '请注意，审计记录需要启用以上'),
(38103, 4162, 11, '注类型'),
(38104, 4168, 11, '注：此代码没有被授权的用户。只有授权的代码可以被上传到开放的医疗帐单处理网络。如果你想上传这些代码，请选择一个授权的用户在这里。'),
(38105, 4170, 11, '注：上传文件和重复的名字将导致文件被自动地重新命名（例如，file.jpg将成为文件。1版。）。文件名被认为是独特的每个客户，而不是每类。'),
(38106, 4171, 11, '注：上传文件和重复的名字将导致文件被自动更名。例如“< >图片文件。< / > ''将成为“< >文件。2。1 < / > ''。文件名被认为是独特的每个客户，而不是每类。'),
(38107, 4172, 11, '笔记'),
(38108, 4173, 11, '注 – 任何接触（写，只添加可选）'),
(38109, 4174, 11, '注 – 我的治疗（写，只添加可选）'),
(38110, 4175, 11, '未授权的债券'),
(38111, 4177, 11, '没有记录'),
(38112, 4179, 11, '进口过敏无关'),
(38113, 4180, 11, '进口处方无关'),
(38114, 4182, 11, '被选中任何内容'),
(38115, 4184, 11, '通知:: PostCalendar提交/修改'),
(38116, 4185, 11, '通知'),
(38117, 4186, 11, '通知电子邮件地址'),
(38118, 4188, 11, '通知'),
(38119, 4189, 11, '关于事件提交/修改通知管理员吗？'),
(38120, 4190, 11, '十一月'),
(38121, 4191, 11, '十一月'),
(38122, 4192, 11, '现在张贴：'),
(38123, 4193, 11, '现在打印'),
(38124, 4194, 11, '现在印刷$ stmt_count报表和更新的治疗。'),
(38125, 4195, 11, '现在印刷$ stmt_count报表和更新的发票。'),
(38126, 4196, 11, '现在印刷$ stmt_count报表;交锋将不会被更新。'),
(38127, 4197, 11, '现在印刷$ stmt_count报表;发票将不会被更新。'),
(38128, 4198, 11, '非营利机构'),
(38129, 4199, 11, 'NQF'),
(38130, 4200, 11, '数'),
(38131, 4201, 11, '数实验室'),
(38132, 4204, 11, '今年视图中的列数。'),
(38133, 4211, 11, '客户端证书是有效的天数。'),
(38134, 4213, 11, '后小数点的货币，通常是0或2位数的号码。'),
(38135, 4214, 11, '数遇到每页显示。'),
(38136, 4215, 11, '游戏或事件的数量，如果错过了'),
(38137, 4216, 11, '提前发送电子邮件通知的小时数。'),
(38138, 4217, 11, '提前发送电话通知的小时数。'),
(38139, 4218, 11, '提前发送短信通知的小时数。'),
(38140, 4221, 11, '过去的历史，列数'),
(38141, 4223, 11, '麻木'),
(38142, 4224, 11, '分子'),
(38143, 4225, 11, '数字显示顺序'),
(38144, 4227, 11, '营养'),
(38145, 4229, 11, 'O.A.F.V.'),
(38146, 4230, 11, '氧气星期六'),
(38147, 4231, 11, '肥胖的我'),
(38148, 4232, 11, '肥胖二'),
(38149, 4233, 11, '肥胖三'),
(38150, 4234, 11, '目标'),
(38151, 4237, 11, '占用'),
(38152, 4239, 11, '发生'),
(38153, 4240, 11, '十月'),
(38154, 4241, 11, '十月'),
(38155, 4242, 11, '外径'),
(38156, 4243, 11, '的'),
(38157, 4244, 11, '数量'),
(38158, 4245, 11, '片剂'),
(38159, 4246, 11, '每月的'),
(38160, 4247, 11, 'OFC债券'),
(38161, 4248, 11, '关闭'),
(38162, 4249, 11, '办公室债券'),
(38163, 4250, 11, '办公室门诊'),
(38164, 4251, 11, '官方临床质量的措施（CQM）测量组'),
(38165, 4252, 11, '异地HTTPS链接的患者门户。'),
(38166, 4253, 11, '异地HTTPS链接，对客户的门户。（客户链接）'),
(38167, 4254, 11, '异地客户门户密码'),
(38168, 4255, 11, '异地患者门户密码（沽空白如果没有注册）。'),
(38169, 4258, 11, '异地患者门户网站地址'),
(38170, 4259, 11, '异地患者门户网站地址（客户链接）'),
(38171, 4260, 11, '异地患者门户网站用户名'),
(38172, 4261, 11, '异地患者门户用户名（沽空白如果没有注册）。'),
(38173, 4263, 11, '子孙'),
(38174, 4265, 11, '软膏'),
(38175, 4267, 11, '确定'),
(38176, 4269, 11, '确定连接GCAC发行日期'),
(38177, 4270, 11, '老'),
(38178, 4272, 11, '老客户'),
(38179, 4273, 11, '陈旧性骨折非/畸形愈合'),
(38180, 4274, 11, '没有左侧菜单中的旧风格布局'),
(38181, 4275, 11, '旧式的静态形式，没有搜索或重复检查'),
(38182, 4279, 11, '省略单位在客户的人口统计信息'),
(38183, 4280, 11, '省略单位'),
(38184, 4281, 11, '省略形式，路线和时间间隔，然后成为部分剂量'),
(38185, 4282, 11, '从人口统计表格省略保险和一些其他的事情'),
(38186, 4283, 11, '省略内部用户？'),
(38187, 4284, 11, '省略的共同薪酬面板付款方式'),
(38188, 4285, 11, '遗漏autoassign'),
(38189, 4286, 11, '上'),
(38190, 4287, 11, '上'),
(38191, 4288, 11, '手头上'),
(38192, 4289, 11, '关于订购'),
(38193, 4290, 11, '在现场'),
(38194, 4291, 11, '一旦主要的商业设施的设置，它不应该被改变。改变该设施将影响的工作NewCrop ePrescription。'),
(38195, 4292, 11, '一旦你改变你的密码，你将不得不重新登录。'),
(38196, 4297, 11, '在线支持'),
(38197, 4298, 11, '在线支持链接'),
(38198, 4299, 11, '只有活动'),
(38199, 4302, 11, '如果帐单位置'),
(38200, 4303, 11, '只有无效'),
(38201, 4304, 11, '只有矿'),
(38202, 4307, 11, '只上传积极的处方'),
(38203, 4310, 11, '疾病发作：'),
(38204, 4311, 11, '发病Ilness： '),
(38205, 4312, 11, '发病膨胀：'),
(38206, 4313, 11, '发病/ HOSP。日期：'),
(38207, 4314, 11, '上门客户门户网站地址'),
(38208, 4315, 11, '哎呀！'),
(38209, 4316, 11, '打开'),
(38210, 4321, 11, '今日访华'),
(38211, 4322, 11, 'LibreEHR已经配置证书颁发机构。'),
(38212, 4324, 11, 'LibreEHR数据库升级'),
(38213, 4325, 11, '德识别LibreEHR数据库升级'),
(38214, 4327, 11, 'LibreEHR必须配置使用证书之前，它可以创建客户端证书。'),
(38215, 4328, 11, 'LibreEHR需要Javascript执行用户身份验证。'),
(38216, 4329, 11, 'LibreEHR用户'),
(38217, 4330, 11, '开口'),
(38218, 4332, 11, '眼科'),
(38219, 4333, 11, '选项'),
(38220, 4335, 11, '选项，以支持产品的库存和销售'),
(38221, 4336, 11, '可选'),
(38222, 4337, 11, '身份证图像，可以从病人的摘要页面浏览可选的类别名称。'),
(38223, 4338, 11, '可选的类别名称，可以从病人的摘要页面浏览的照片图像。'),
(38224, 4339, 11, '从病人的摘要页面链接到一个文件可选的类别名称。让你点击一个病人的名字，看到他们的身份证。'),
(38225, 4340, 11, '结果手工录入可选的默认范围'),
(38226, 4341, 11, '可选的默认单位手工录入结果'),
(38227, 4342, 11, '可选的目的地名称'),
(38228, 4343, 11, '可选药物名称，使用％作为通配符'),
(38229, 4345, 11, '有关此事件的可选信息'),
(38230, 4346, 11, '可选的批号，使用一个通配符％'),
(38231, 4347, 11, '可选的数字病人ID'),
(38232, 4348, 11, '可选的程序代码'),
(38233, 4350, 11, '选项'),
(38234, 4351, 11, '或'),
(38235, 4352, 11, '或'),
(38236, 4353, 11, '或选择'),
(38237, 4354, 11, '或单击并拖动可进行快速选择。'),
(38238, 4356, 11, '或出'),
(38239, 4358, 11, '或Shift单击减少'),
(38240, 4359, 11, '或者自责文件上传：'),
(38241, 4360, 11, '口服'),
(38242, 4361, 11, '粉红色的口腔粘膜，咽喉明确'),
(38243, 4362, 11, '秩序'),
(38244, 4363, 11, '订购和结果类型'),
(38245, 4364, 11, '订购目录'),
(38246, 4365, 11, '订购日期'),
(38247, 4367, 11, '订购'),
(38248, 4369, 11, '顺序必须是一个数字1和999之间'),
(38249, 4370, 11, '订购产品名称'),
(38250, 4371, 11, '为了优先'),
(38251, 4372, 11, '订单处理'),
(38252, 4375, 11, '订单状态'),
(38253, 4378, 11, '订单类型'),
(38254, 4380, 11, '订单/结果类型'),
(38255, 4381, 11, '订购'),
(38256, 4384, 11, '排列提供商'),
(38257, 4386, 11, '器官损伤'),
(38258, 4387, 11, '组织'),
(38259, 4388, 11, '组织名称'),
(38260, 4389, 11, '组织单位名称'),
(38261, 4390, 11, '组织'),
(38262, 4391, 11, '面向×3'),
(38263, 4392, 11, '原'),
(38264, 4396, 11, '口咽： '),
(38265, 4397, 11, '端坐呼吸'),
(38266, 4398, 11, '操作系统'),
(38267, 4399, 11, '骨性关节炎'),
(38268, 4402, 11, '其他'),
(38269, 4403, 11, '其他'),
(38270, 4404, 11, '其他（请注明）'),
(38271, 4405, 11, '其他 - 指定'),
(38272, 4406, 11, '其他联邦计划'),
(38273, 4407, 11, '其他HCFA'),
(38274, 4408, 11, '其他未列明的损伤'),
(38275, 4409, 11, '其他责任保险是小学'),
(38276, 4410, 11, '其他月份'),
(38277, 4411, 11, '其他非联邦计划'),
(38278, 4412, 11, '其他注意事项'),
(38279, 4413, 11, '其他相关症状'),
(38280, 4414, 11, '其他相关症状：'),
(38281, 4415, 11, '其他PT RESP'),
(38282, 4416, 11, '其他压力/过度使用伤害'),
(38283, 4417, 11, '其他手术'),
(38284, 4418, 11, '其他/通用人工流产有关'),
(38285, 4420, 11, '他人'),
(38286, 4421, 11, '否则，你会破坏到/从现有的数据参考。'),
(38287, 4422, 11, '渥太华踝规则'),
(38288, 4423, 11, '地带'),
(38289, 4424, 11, '输出'),
(38290, 4425, 11, '不在办公室'),
(38291, 4426, 11, '出境转介'),
(38292, 4427, 11, '结果'),
(38293, 4428, 11, '展望'),
(38294, 4431, 11, '逾期'),
(38295, 4432, 11, '过度使用'),
(38296, 4434, 11, '超重'),
(38297, 4435, 11, '覆盖HIPAA的选择'),
(38298, 4437, 11, '血氧饱和度'),
(38299, 4439, 11, 'P级'),
(38300, 4440, 11, '饭后'),
(38301, 4441, 11, '下午'),
(38302, 4442, 11, '随时'),
(38303, 4443, 11, '太平洋岛民'),
(38304, 4444, 11, '儿科'),
(38305, 4445, 11, '页'),
(38306, 4446, 11, '页'),
(38307, 4447, 11, '支付'),
(38308, 4448, 11, '支付的金额，你将分配'),
(38309, 4450, 11, '支付通过'),
(38310, 4451, 11, '疼痛'),
(38311, 4453, 11, '心慌'),
(38312, 4455, 11, '子宫颈抹片检查'),
(38313, 4457, 11, '纸张尺寸'),
(38314, 4458, 11, '瘫痪'),
(38315, 4461, 11, '解析的HL7'),
(38316, 4463, 11, '伙伴'),
(38317, 4464, 11, '伙伴名称'),
(38318, 4467, 11, '口令短语'),
(38319, 4468, 11, '口令短语解密文件'),
(38320, 4469, 11, '通过患者'),
(38321, 4470, 11, '被动警报'),
(38322, 4471, 11, '被动警报规则'),
(38323, 4472, 11, '密码'),
(38324, 4473, 11, '更改密码'),
(38325, 4475, 11, '密码更改成功。'),
(38326, 4477, 11, '密码过期的宽限期'),
(38327, 4479, 11, '电话网关的密码。自动化由Maviq提供VOIP服务。更多信息，请门诊http://signup.maviq.com。'),
(38328, 4480, 11, '短信网关的密码'),
(38329, 4481, 11, '短信网关的密码。'),
(38330, 4483, 11, '密码的安全性最近已经升级。'),
(38331, 4486, 11, '密码：'),
(38332, 4490, 11, '逾期'),
(38333, 4491, 11, '逾期'),
(38334, 4492, 11, '过去由于区间（临床提醒）'),
(38335, 4493, 11, '过去由于区间（客户提醒）'),
(38336, 4494, 11, '过去遭遇名单'),
(38337, 4495, 11, '过去的遭遇'),
(38338, 4496, 11, '过去的遭遇和文件'),
(38339, 4497, 11, '对过去的遭遇'),
(38340, 4498, 11, '粘贴的HL7数据'),
(38341, 4499, 11, '粘贴的数据导入到文本区域：'),
(38342, 4500, 11, '拍'),
(38343, 4502, 11, '贴片'),
(38344, 4508, 11, '事件日志备份的路径'),
(38345, 4509, 11, 'CA证书文件的路径'),
(38346, 4510, 11, 'CA密钥文件的路径'),
(38347, 4511, 11, '到MySQL二进制代码的路径'),
(38348, 4512, 11, 'Perl的二进制代码的路径'),
(38349, 4513, 11, '临时文件的路径'),
(38350, 4514, 11, '客户'),
(38351, 4515, 11, '客户'),
(38352, 4516, 11, '客户'),
(38353, 4517, 11, '客户地址'),
(38354, 4518, 11, '客户地址丢失'),
(38355, 4521, 11, '客户过敏'),
(38356, 4522, 11, '客户过敏'),
(38357, 4523, 11, '客户预约'),
(38358, 4528, 11, '病历编号'),
(38359, 4529, 11, '客户结帐'),
(38360, 4530, 11, '客户结帐为 '),
(38361, 4531, 11, '客户城'),
(38362, 4532, 11, '客户城失踪'),
(38363, 4533, 11, '发送医患沟通'),
(38364, 4534, 11, '发送客户的交际'),
(38365, 4535, 11, '患者国家'),
(38366, 4536, 11, '耐心地失踪。你也没有设置全局设置的默认客户国家'),
(38367, 4539, 11, '客户的数据'),
(38368, 4541, 11, '客户出生日期失踪'),
(38369, 4542, 11, '客户的详细资料'),
(38370, 4543, 11, '客户出生日期'),
(38371, 4544, 11, '患者文件'),
(38372, 4545, 11, '客户教育'),
(38373, 4546, 11, '患者教育材料'),
(38374, 4547, 11, '客户的遭遇'),
(38375, 4548, 11, '患者遭遇表格'),
(38376, 4549, 11, '客户的遭遇'),
(38377, 4550, 11, '客户查找'),
(38378, 4551, 11, '客户首先名称'),
(38379, 4553, 11, '客户的名字是丢失'),
(38380, 4558, 11, '患者的性别'),
(38381, 4559, 11, '患者的性别缺失'),
(38382, 4560, 11, '客户并没有授权的患者门户。'),
(38383, 4561, 11, '病历'),
(38384, 4562, 11, '客户的历史/生活方式'),
(38385, 4563, 11, '患者家中电话'),
(38386, 4564, 11, '客户ID'),
(38387, 4566, 11, '客户ID卡'),
(38388, 4567, 11, '客户编号类别名称'),
(38389, 4568, 11, '客户免疫'),
(38390, 4569, 11, '客户信息'),
(38391, 4570, 11, '耐心的指导'),
(38392, 4571, 11, '客户保险销售'),
(38393, 4572, 11, '客户保险分布报告'),
(38394, 4573, 11, '客户的问题'),
(38395, 4575, 11, '客户姓'),
(38396, 4577, 11, '患者姓丢失'),
(38397, 4581, 11, '客户名单'),
(38398, 4586, 11, '客户查找错误'),
(38399, 4587, 11, '门诊医疗问题'),
(38400, 4588, 11, '客户的药物'),
(38401, 4589, 11, '客户姓名'),
(38402, 4590, 11, '客户姓名及地址'),
(38403, 4593, 11, '客户姓名必需'),
(38404, 4595, 11, '患者请注意'),
(38405, 4596, 11, '客户注意类型'),
(38406, 4597, 11, '患者注意事项'),
(38407, 4598, 11, '客户的注意事项（写，只添加可选）'),
(38408, 4599, 11, '客户数'),
(38409, 4600, 11, '客户付款'),
(38410, 4602, 11, '客户的照片分类名称'),
(38411, 4603, 11, '患者门户'),
(38412, 4605, 11, '客户门户网站被关闭'),
(38413, 4606, 11, '患者门户登录'),
(38414, 4607, 11, '患者门户网站地址'),
(38415, 4608, 11, '客户印制报告'),
(38416, 4609, 11, '病历报告'),
(38417, 4610, 11, '客户记录请求'),
(38418, 4611, 11, '客户记录的要求'),
(38419, 4613, 11, '客户提醒'),
(38420, 4614, 11, '客户提醒批处理作业'),
(38421, 4616, 11, '客户提醒规则'),
(38422, 4617, 11, '客户提醒发件人的电子邮件'),
(38423, 4618, 11, '客户提醒发件人名称'),
(38424, 4619, 11, '客户提醒'),
(38425, 4620, 11, '客户报告'),
(38426, 4621, 11, '客户要求'),
(38427, 4622, 11, '客户要求医疗记录'),
(38428, 4623, 11, '客户的结果'),
(38429, 4624, 11, '客户的搜索结果样式'),
(38430, 4625, 11, '客户搜索/添加屏幕'),
(38431, 4626, 11, '客户设置'),
(38432, 4627, 11, '客户状态'),
(38433, 4629, 11, '客户摘要'),
(38434, 4630, 11, '客户交易'),
(38435, 4631, 11, '客户邮编'),
(38436, 4632, 11, '客户在数据库中，你已经进入人口信息相匹配。'),
(38437, 4633, 11, '客户/客户端'),
(38438, 4634, 11, '客户：'),
(38439, 4635, 11, '客户编号'),
(38440, 4636, 11, '患者'),
(38441, 4638, 11, '付'),
(38442, 4639, 11, '要注意的复选框“完成”。后保险标记为完成，然后我们将开始要求客户支付余额;如果你失败了，以纪念所有的保险，然后完成剩余的金额将不会被收集！此外，如果有一个平衡，客户应支付，然后设置适当的截止日期，因为这会影响对客户报表中出现的语言。'),
(38443, 4640, 11, '支付日期：'),
(38444, 4641, 11, '支付状态'),
(38445, 4642, 11, '收款人名称'),
(38446, 4643, 11, '付款人'),
(38447, 4644, 11, '付款人类型'),
(38448, 4645, 11, '付款'),
(38449, 4646, 11, '支付实体'),
(38450, 4647, 11, '付款'),
(38451, 4648, 11, '付款'),
(38452, 4649, 11, '付款调整代码'),
(38453, 4651, 11, '付款金额'),
(38454, 4652, 11, '付款金额必须是数字'),
(38455, 4653, 11, '支付类别'),
(38456, 4654, 11, '付款日期'),
(38457, 4655, 11, '支付输入在'),
(38458, 4656, 11, '款项'),
(38459, 4658, 11, '支付插件'),
(38460, 4659, 11, '支付清单'),
(38461, 4660, 11, '付款方式'),
(38462, 4661, 11, '付款方式分类'),
(38463, 4662, 11, '付款状态'),
(38464, 4663, 11, '付款方式'),
(38465, 4664, 11, '支付价值为代码 '),
(38466, 4665, 11, '付款'),
(38467, 4667, 11, '五氯酚'),
(38468, 4669, 11, 'PDF格式'),
(38469, 4670, 11, 'PDF下载选中的语句'),
(38470, 4672, 11, '骨盆和臀部'),
(38471, 4673, 11, '天疱疮'),
(38472, 4674, 11, '有待'),
(38473, 4676, 11, '待F/ü'),
(38474, 4677, 11, '待后续'),
(38475, 4678, 11, '从结果有待随访'),
(38476, 4679, 11, '挂单'),
(38477, 4680, 11, '待水库'),
(38478, 4681, 11, '待审查'),
(38479, 4682, 11, '待Rx计数'),
(38480, 4684, 11, '彭宁顿事务所LibreEHR至五'),
(38481, 4685, 11, '消化性溃疡病'),
(38482, 4687, 11, '每分钟'),
(38483, 4688, 11, '每个鼻孔'),
(38484, 4689, 11, '每个鼻孔'),
(38485, 4690, 11, '每ORIS'),
(38486, 4691, 11, '每匝'),
(38487, 4692, 11, '每直肠'),
(38488, 4693, 11, '每直肠'),
(38489, 4694, 11, '百分之'),
(38490, 4697, 11, '百分'),
(38491, 4698, 11, '穿孔右：'),
(38492, 4699, 11, '执行搜索'),
(38493, 4700, 11, '执行此操作'),
(38494, 4701, 11, '性能百分比'),
(38495, 4703, 11, '执行实验室设施'),
(38496, 4705, 11, '期间'),
(38497, 4706, 11, '在天期间，用户可能过期的密码登录。'),
(38498, 4707, 11, '围手术期护理'),
(38499, 4708, 11, '外围设备'),
(38500, 4712, 11, '人'),
(38501, 4713, 11, '个性化'),
(38502, 4714, 11, '编辑器'),
(38503, 4715, 11, '医药'),
(38504, 4716, 11, '医药COM计数'),
(38505, 4717, 11, '药房'),
(38506, 4718, 11, '药房'),
(38507, 4719, 11, '药店药房'),
(38508, 4720, 11, '气胸'),
(38509, 4729, 11, '电话'),
(38510, 4730, 11, '手机通话清单'),
(38511, 4733, 11, '电话网关密码'),
(38512, 4734, 11, '电话网关的URL'),
(38513, 4735, 11, '电话网关的用户名'),
(38514, 4737, 11, '电话通知一小时'),
(38515, 4738, 11, '电话号码'),
(38516, 4740, 11, '畏光'),
(38517, 4741, 11, '照片'),
(38518, 4742, 11, 'PHP的压缩'),
(38519, 4743, 11, 'PHP的CURL模块应在您的服务器上启用。'),
(38520, 4744, 11, 'PHP的提取'),
(38521, 4745, 11, '关闭，php-GACL的门诊控制'),
(38522, 4746, 11, '未安装PHP的gacl'),
(38523, 4747, 11, '体检'),
(38524, 4749, 11, '医生要求'),
(38525, 4750, 11, '医师签名'),
(38526, 4752, 11, '医生'),
(38527, 4753, 11, '挑'),
(38528, 4754, 11, '挑'),
(38529, 4755, 11, '挑一个CSS主题。'),
(38530, 4756, 11, '骨腔炎疾病'),
(38531, 4757, 11, '盆腔炎（PID）'),
(38532, 4758, 11, '药片大小'),
(38533, 4759, 11, '丸'),
(38534, 4760, 11, '如果要安装的选项，将在以下目录数据库zip文件'),
(38535, 4765, 11, '占位符'),
(38536, 4766, 11, '占位符（保持空的ACL）'),
(38537, 4767, 11, '纯文本'),
(38538, 4768, 11, '计划'),
(38539, 4771, 11, '计划名称'),
(38540, 4775, 11, '计划集'),
(38541, 4779, 11, '计划：'),
(38542, 4782, 11, '计划'),
(38543, 4784, 11, '播放机'),
(38544, 4785, 11, '演奏位置'),
(38545, 4786, 11, '请拨打如果任何上述信息是不正确的'),
(38546, 4787, 11, '请更改您的密码。'),
(38547, 4788, 11, '请选择一个文件'),
(38548, 4789, 11, '请选择一个客户'),
(38549, 4790, 11, '请从列表中选择一个有效的选择。'),
(38550, 4791, 11, '请选择一个有效的选择。'),
(38551, 4792, 11, '请选择一个值'),
(38552, 4793, 11, '请选择日期范围标准以上，并单击“刷新”以查看结果。'),
(38553, 4794, 11, '请选择正确的格式文件的EDI-271'),
(38554, 4795, 11, '请点击下载按钮下载德查明的数据'),
(38555, 4796, 11, '请点击下载按钮下载数据重新鉴定'),
(38556, 4797, 11, '请关闭此窗口。'),
(38557, 4798, 11, '请比较新的名称'),
(38558, 4802, 11, '请不要接受这个处方除非是通过收到的传真。'),
(38559, 4803, 11, '请不要接受这个处方，除非它是通过传真收到。'),
(38560, 4804, 11, '请不要用你的浏览器的刷新按钮，该页面停止或运行超过10分钟过去了，这不会导致进程停止服务器上，会消耗一些资源。'),
(38561, 4805, 11, '请启用CURL扩展'),
(38562, 4806, 11, '请启用OpenSSL扩展'),
(38563, 4807, 11, '请启用SOAP扩展'),
(38564, 4808, 11, '请启用XML扩展'),
(38565, 4809, 11, '请输入点评日期。'),
(38566, 4810, 11, '请输入一个日期。'),
(38567, 4811, 11, '请输入截止日期'),
(38568, 4812, 11, '请输入信息'),
(38569, 4813, 11, '请输入货币金额只使用数字和小数点。'),
(38570, 4814, 11, '请输入新密码'),
(38571, 4815, 11, '请输入标题！'),
(38572, 4819, 11, '请输入正确的重新识别代码'),
(38573, 4821, 11, '请输入新的搜索字符串'),
(38574, 4822, 11, '请输入正确的重新识别代码'),
(38575, 4823, 11, '请输入密码'),
(38576, 4824, 11, '请填写支票号码'),
(38577, 4826, 11, '请填写日期'),
(38578, 4827, 11, '请填写支付金额'),
(38579, 4828, 11, '请填写付款类别'),
(38580, 4829, 11, '请填写支付'),
(38581, 4830, 11, '请填写邮政日'),
(38582, 4831, 11, '请填写，然后再继续。'),
(38583, 4832, 11, '请注明门诊原因'),
(38584, 4834, 11, '以上请输入搜索条件，然后点击提交查看结果。');
INSERT INTO `lang_definitions` VALUES
(38585, 4835, 11, '以上请输入搜索条件，然后点击提交查看结果。 （结果将显示在一个弹出窗口）'),
(38586, 4836, 11, '请重新登录。'),
(38587, 4837, 11, '请注意，这可能需要很长一段时间，长达数分钟，您的网页浏览器可能不会出现在此期间非常活跃，但产生了一项法案，是一个复杂的过程，您的网页浏览器只是等待更多的信息。'),
(38588, 4838, 11, '请注意：常量是区分大小写的，并允许任何字符串。'),
(38589, 4839, 11, '请只使用字母字符'),
(38590, 4840, 11, '请只使用不带空格的字母字符'),
(38591, 4841, 11, '请支付这笔款项'),
(38592, 4843, 11, '请参阅'),
(38593, 4844, 11, '请重设密码。'),
(38594, 4845, 11, '前打去识别，请重新启动Apache服务器'),
(38595, 4849, 11, '请选择一种语言'),
(38596, 4850, 11, '请选择一个客户。'),
(38597, 4851, 11, '请选择一个主要的商业设施税号的“税号”的实体设施。如果你是一个个体医生，用你的税号。这是用来确定你在NewCrop系统。'),
(38598, 4854, 11, '请选择一个收件人'),
(38599, 4855, 11, '请选择一个开始日期和结束日期'),
(38600, 4856, 11, '请选择一个有效的收件人'),
(38601, 4858, 11, '请选择一个代码调整原因 '),
(38602, 4859, 11, '请选择一个事件'),
(38603, 4860, 11, '请选择任何搜索选项。'),
(38604, 4863, 11, '请选择至少一个处方！'),
(38605, 4865, 11, '请选择所需的网页，复制或转发：'),
(38606, 4866, 11, '请选择付款方式'),
(38607, 4869, 11, '请选择X12的合作伙伴，需要创造的270批次'),
(38608, 4870, 11, '请设置'),
(38609, 4871, 11, '请设置de_identification_config变回零'),
(38610, 4873, 11, '请开始新德鉴定过程'),
(38611, 4874, 11, '请升级LibreEHR数据库，包括德鉴定程序，功能表'),
(38612, 4875, 11, '有关详细信息，请查看德识别错误日志表'),
(38613, 4876, 11, '经过一段时间后，请门诊德识别屏幕'),
(38614, 4877, 11, '请门诊一段时间后，重新标识屏幕'),
(38615, 4878, 11, '一段时间后，请门诊屏幕'),
(38616, 4882, 11, '下午'),
(38617, 4883, 11, '下午计划'),
(38618, 4884, 11, 'PMT方法'),
(38619, 4885, 11, '间隙性夜间呼吸困难'),
(38620, 4886, 11, '肺炎球菌1'),
(38621, 4887, 11, '肺炎球菌2'),
(38622, 4888, 11, '肺炎球菌3'),
(38623, 4889, 11, '肺炎球菌4'),
(38624, 4890, 11, '肺炎球菌疫苗'),
(38625, 4891, 11, '肺炎疫苗'),
(38626, 4892, 11, '针对老年人的肺炎疫苗接种状况'),
(38627, 4893, 11, '针对老年人的肺炎疫苗接种情况（CQM）'),
(38628, 4894, 11, '足部'),
(38629, 4896, 11, '服务点（POS）'),
(38630, 4897, 11, '政策'),
(38631, 4898, 11, '保单号码'),
(38632, 4899, 11, '保单号码'),
(38633, 4900, 11, '波兰语'),
(38634, 4901, 11, '烦渴'),
(38635, 4902, 11, '息肉'),
(38636, 4903, 11, '尿'),
(38637, 4904, 11, '食欲不佳'),
(38638, 4905, 11, '流通不畅'),
(38639, 4906, 11, '听力差'),
(38640, 4907, 11, '看到这些报告，需要启用弹出窗口'),
(38641, 4908, 11, '填充今年视图与事件？'),
(38642, 4909, 11, '弹出窗口'),
(38643, 4911, 11, '门户网站活动'),
(38644, 4917, 11, '葡萄牙'),
(38645, 4918, 11, '葡萄牙语（巴西）'),
(38646, 4919, 11, '葡萄牙（欧洲）'),
(38647, 4920, 11, 'POS机代号'),
(38648, 4922, 11, '积极'),
(38649, 4923, 11, '阳性'),
(38650, 4925, 11, '邮政'),
(38651, 4926, 11, '发表滴鼻'),
(38652, 4927, 11, '发表付款'),
(38653, 4928, 11, '发表手术'),
(38654, 4929, 11, '发布嘴会计和标志'),
(38655, 4930, 11, '发布日期'),
(38656, 4931, 11, '发布日期不能比今天更大的'),
(38657, 4932, 11, '发布日期必须大于财政关闭日期。'),
(38658, 4933, 11, '流产后保健'),
(38659, 4934, 11, '人工流产后避孕'),
(38660, 4935, 11, '堕胎后咨询'),
(38661, 4936, 11, '后流产跟帖'),
(38662, 4937, 11, '邮政'),
(38663, 4938, 11, '邮政编码'),
(38664, 4939, 11, '邮政编码'),
(38665, 4941, 11, '发布日历'),
(38666, 4942, 11, '发布日历管理'),
(38667, 4943, 11, '发布日历类别设置'),
(38668, 4944, 11, '发布日历全局设置'),
(38669, 4945, 11, '发表于'),
(38670, 4946, 11, '发布日期'),
(38671, 4948, 11, '技术支持'),
(38672, 4949, 11, '个人防护装备+预防医学/外科HX'),
(38673, 4950, 11, 'PQRI'),
(38674, 4951, 11, 'PQRI注册编号'),
(38675, 4952, 11, 'PQRI注册名称'),
(38676, 4953, 11, '实践'),
(38677, 4954, 11, '实践默认设置'),
(38678, 4955, 11, '实践设置'),
(38679, 4956, 11, '医生'),
(38680, 4959, 11, '预先付款'),
(38681, 4960, 11, '堕胎前协商'),
(38682, 4961, 11, '堕胎前辅导'),
(38683, 4962, 11, '县猫'),
(38684, 4964, 11, '喜好'),
(38685, 4965, 11, '首选事件类别'),
(38686, 4966, 11, '首选语言'),
(38687, 4967, 11, '首选药剂'),
(38688, 4968, 11, '优先提供者组织（PPO）'),
(38689, 4969, 11, '怀孕测试'),
(38690, 4970, 11, '初步'),
(38691, 4972, 11, '预付'),
(38692, 4973, 11, '处方'),
(38693, 4974, 11, '处方已达到极限'),
(38694, 4975, 11, '处方历史'),
(38695, 4976, 11, '处方历史进口顺利完成'),
(38696, 4977, 11, '处方标签'),
(38697, 4978, 11, '处方报告'),
(38698, 4979, 11, '处方'),
(38699, 4980, 11, '处方和特许'),
(38700, 4981, 11, '处方药和其他转介'),
(38701, 4982, 11, '处方药和/或专科转介'),
(38702, 4983, 11, '处方报告'),
(38703, 4984, 11, '处方/转介'),
(38704, 4985, 11, '目前'),
(38705, 4986, 11, '提出投诉'),
(38706, 4988, 11, '按继续进行'),
(38707, 4989, 11, '推定诊断'),
(38708, 4990, 11, '假定由专家诊断'),
(38709, 4991, 11, '上一页'),
(38710, 4992, 11, '预防医学/外科HX'),
(38711, 4993, 11, '上一页。本月（按住菜单）'),
(38712, 4994, 11, '上一页。一年（按住菜单）'),
(38713, 4995, 11, '预防保健'),
(38714, 4998, 11, '预览事件'),
(38715, 5000, 11, '预览'),
(38716, 5001, 11, '前'),
(38717, 5002, 11, '以往的磋商'),
(38718, 5003, 11, '前一天'),
(38719, 5004, 11, '以前的历史/筛选'),
(38720, 5005, 11, '前一个月'),
(38721, 5006, 11, '上星期'),
(38722, 5007, 11, '价格'),
(38723, 5008, 11, '价格折扣'),
(38724, 5009, 11, '价格水平'),
(38725, 5010, 11, '价格水平：'),
(38726, 5011, 11, '价格'),
(38727, 5012, 11, '主'),
(38728, 5013, 11, '主要业务实体'),
(38729, 5014, 11, '主要业务实体税号用于帐户编号 NewCrop处方。改变该设施将影响的工作NewCrop。'),
(38730, 5022, 11, '主要插件'),
(38731, 5023, 11, '原保险'),
(38732, 5024, 11, '原保险数据'),
(38733, 5025, 11, '主要保险提供商'),
(38734, 5026, 11, '主要服务人员'),
(38735, 5027, 11, '打印'),
(38736, 5028, 11, '打印（HTML）'),
(38737, 5029, 11, '打印（PDF）'),
(38738, 5031, 11, '打印任何相逢'),
(38739, 5032, 11, '打印空白推荐表格'),
(38740, 5033, 11, '打印命令'),
(38741, 5039, 11, '打印格式'),
(38742, 5040, 11, '打印四个小组'),
(38743, 5042, 11, '打印消息'),
(38744, 5043, 11, '打印多'),
(38745, 5044, 11, '打印多个传真'),
(38746, 5045, 11, '打印名称，标志和日期。'),
(38747, 5046, 11, '打印票据'),
(38748, 5047, 11, '打印第1页'),
(38749, 5048, 11, '打印第2页'),
(38750, 5051, 11, '通过提供打印收据'),
(38751, 5052, 11, '打印记录'),
(38752, 5053, 11, '打印选定报表'),
(38753, 5054, 11, '打印铅球纪录'),
(38754, 5056, 11, '打印这场遭遇战'),
(38755, 5057, 11, '打印说明'),
(38756, 5058, 11, '打印本说明'),
(38757, 5060, 11, '打印传真'),
(38758, 5061, 11, '打印查看'),
(38759, 5062, 11, '打印'),
(38760, 5063, 11, '打印版本'),
(38761, 5064, 11, '印'),
(38762, 5066, 11, '打印结果：'),
(38763, 5067, 11, '印刷跳过;看到测试输出'),
(38764, 5068, 11, '印刷跳过;看到测试输出 '),
(38765, 5069, 11, '在此之前验证'),
(38766, 5070, 11, '以前授权书'),
(38767, 5071, 11, '在此之前门诊'),
(38768, 5072, 11, '优先'),
(38769, 5073, 11, '优先 '),
(38770, 5074, 11, '私人'),
(38771, 5075, 11, '问题'),
(38772, 5076, 11, '问题的DX'),
(38773, 5077, 11, '问题列表'),
(38774, 5079, 11, '问题/问题'),
(38775, 5080, 11, '丙卡巴井棒'),
(38776, 5081, 11, '丙卡巴井貓'),
(38777, 5083, 11, '程序待定挂起'),
(38778, 5085, 11, '程序'),
(38779, 5086, 11, '程序'),
(38780, 5087, 11, '过程部位'),
(38781, 5088, 11, '程序布尔结果'),
(38782, 5089, 11, '刑事诉讼法'),
(38783, 5091, 11, '议事偏侧性'),
(38784, 5093, 11, '程序订购'),
(38785, 5095, 11, '程序订购'),
(38786, 5102, 11, '程序的报告'),
(38787, 5103, 11, '程序报告状态'),
(38788, 5104, 11, '过程的结果异常'),
(38789, 5105, 11, '过程的结果状态'),
(38790, 5106, 11, '程序的结果'),
(38791, 5107, 11, '议事路线'),
(38792, 5108, 11, '过程标本类型'),
(38793, 5109, 11, '议事统计报告'),
(38794, 5110, 11, '程序类型'),
(38795, 5111, 11, '过程类型'),
(38796, 5112, 11, '议事单位'),
(38797, 5114, 11, '程序'),
(38798, 5115, 11, '过程'),
(38799, 5117, 11, '程世代文件'),
(38800, 5121, 11, '处理'),
(38801, 5122, 11, '处理'),
(38802, 5123, 11, '处理日期'),
(38803, 5125, 11, '处理'),
(38804, 5129, 11, '产品'),
(38805, 5130, 11, '产品的避孕方法'),
(38806, 5132, 11, '产品'),
(38807, 5133, 11, '产品，但没有处方药和无模板'),
(38808, 5134, 11, '教授'),
(38809, 5135, 11, '病程记录'),
(38810, 5136, 11, '前列腺癌'),
(38811, 5137, 11, '前列腺癌筛查'),
(38812, 5138, 11, '前列腺检查'),
(38813, 5139, 11, '前列腺问题'),
(38814, 5140, 11, 'W / O enlrgmt，前列腺结节，招标'),
(38815, 5142, 11, '提供绝对路径'),
(38816, 5143, 11, '提供的文件的绝对路径'),
(38817, 5145, 11, '为每个办公室门诊患者的临床总结。'),
(38818, 5146, 11, '提供电子版本，他们的健康信息（包括诊断测试的结果，问题的清单，用药清单，药物过敏）的患者，要求。'),
(38819, 5147, 11, '提供及时的电子门诊信息的EP在四个工作日对他们的健康信息（包括实验室检测结果，问题的清单，用药清单，药物过敏）的患者。'),
(38820, 5148, 11, '参观患者提供记录'),
(38821, 5149, 11, '提供有效的电子邮件地址'),
(38822, 5150, 11, '提供临床总结？'),
(38823, 5151, 11, '提供教育资源（S）？'),
(38824, 5152, 11, '服务人员'),
(38825, 5154, 11, '服务人员ID'),
(38826, 5155, 11, '指定设施的服务人员ID'),
(38827, 5156, 11, '服务人员匹配错误'),
(38828, 5159, 11, '服务人员数目'),
(38829, 5162, 11, '服务人员：'),
(38830, 5163, 11, '服务人员'),
(38831, 5164, 11, '提供非营利机构'),
(38832, 5165, 11, '服务人员把整个日历'),
(38833, 5166, 11, '上一页'),
(38834, 5167, 11, '变压吸附'),
(38835, 5168, 11, '银屑病'),
(38836, 5169, 11, '精极度紧张的诊断'),
(38837, 5170, 11, '精极度紧张用药'),
(38838, 5171, 11, '精神科'),
(38839, 5172, 11, '精神科摘要字母'),
(38840, 5173, 11, '精神科诊断'),
(38841, 5174, 11, '精神病鉴定'),
(38842, 5175, 11, '有精神病史'),
(38843, 5176, 11, '精神科进'),
(38844, 5177, 11, '精神科药物'),
(38845, 5178, 11, '客户百分比'),
(38846, 5179, 11, '客户注释'),
(38847, 5180, 11, '客户注释/验证'),
(38848, 5181, 11, '客户多缴'),
(38849, 5182, 11, '客户付费'),
(38850, 5183, 11, '客户建议请求'),
(38851, 5184, 11, '客户退款'),
(38852, 5185, 11, '客户痊愈'),
(38853, 5186, 11, '客户报告'),
(38854, 5187, 11, '客户，或留空'),
(38855, 5188, 11, '客户_城市'),
(38856, 5189, 11, '客户_出生日期'),
(38857, 5191, 11, '客户_名字'),
(38858, 5192, 11, '客户_姓氏'),
(38859, 5193, 11, '客户_中间名字'),
(38860, 5196, 11, '客户_邮编'),
(38861, 5198, 11, '客户_省/市'),
(38862, 5199, 11, '客户_街道'),
(38863, 5201, 11, '公众'),
(38864, 5203, 11, '公共卫生服务（PHS）或其他联邦机构'),
(38865, 5204, 11, '波多黎各'),
(38866, 5205, 11, '肺'),
(38867, 5206, 11, '脉冲'),
(38868, 5207, 11, '旁遮普'),
(38869, 5208, 11, '采购'),
(38870, 5209, 11, '购买/返回'),
(38871, 5210, 11, '采购'),
(38872, 5213, 11, '每3小時'),
(38873, 5214, 11, '每4小時'),
(38874, 5215, 11, '每5小時'),
(38875, 5216, 11, '每6小時'),
(38876, 5217, 11, '每8小時'),
(38877, 5218, 11, '每天4次'),
(38878, 5219, 11, '每天4次'),
(38879, 5220, 11, '每隔1小時'),
(38880, 5221, 11, '每隔1小時是少於每月用量'),
(38881, 5222, 11, '数量'),
(38882, 5223, 11, '数量'),
(38883, 5224, 11, '质量'),
(38884, 5225, 11, '质量的措施（CQM）'),
(38885, 5226, 11, '数量'),
(38886, 5227, 11, 'NDC的数量'),
(38887, 5228, 11, '手边的数量'),
(38888, 5229, 11, '数量似乎不可用'),
(38889, 5231, 11, '问号'),
(38890, 5232, 11, '为HCFA批处理队列'),
(38891, 5233, 11, 'HCFA批量处理和印刷队列'),
(38892, 5234, 11, 'UB-92批量处理队列'),
(38893, 5235, 11, 'UB-92的批量处理和打印队列'),
(38894, 5236, 11, '排队'),
(38895, 5237, 11, '排队的事件管理'),
(38896, 5238, 11, '排队'),
(38897, 5240, 11, '排队提交管理'),
(38898, 5241, 11, '退出'),
(38899, 5242, 11, '戒烟酒'),
(38900, 5243, 11, 'ŕ'),
(38901, 5245, 11, '种族'),
(38902, 5246, 11, '种族和民族'),
(38903, 5247, 11, '种族/族裔'),
(38904, 5248, 11, '无线电'),
(38905, 5249, 11, '单选按钮'),
(38906, 5251, 11, '范围'),
(38907, 5252, 11, '皮疹'),
(38908, 5253, 11, '率'),
(38909, 5254, 11, '比'),
(38910, 5255, 11, '原报告'),
(38911, 5256, 11, '重新鉴定'),
(38912, 5257, 11, '重新鉴定过程完成'),
(38913, 5258, 11, '重新鉴定的过程是正在进行'),
(38914, 5259, 11, '重新鉴定的文件将被保存在'),
(38915, 5260, 11, '再度受伤？'),
(38916, 5261, 11, '重新开放'),
(38917, 5262, 11, '重新开放'),
(38918, 5263, 11, '反应'),
(38919, 5264, 11, '反应'),
(38920, 5265, 11, '阅读'),
(38921, 5268, 11, '真实姓名'),
(38922, 5269, 11, '真正删除'),
(38923, 5270, 11, '原因'),
(38924, 5271, 11, '原因死者'),
(38925, 5272, 11, '死亡原因'),
(38926, 5274, 11, '转介原因'),
(38927, 5275, 11, '门诊的原因'),
(38928, 5276, 11, '原因/表格'),
(38929, 5277, 11, '收据'),
(38930, 5278, 11, '付款收据'),
(38931, 5279, 11, '收据生成'),
(38932, 5280, 11, '预收付款方法报告'),
(38933, 5281, 11, '收款汇总'),
(38934, 5282, 11, '收到'),
(38935, 5283, 11, '收到'),
(38936, 5284, 11, '接收的传真'),
(38937, 5287, 11, '接收器'),
(38938, 5288, 11, '接收器的ID'),
(38939, 5289, 11, '接收器的ID（ISA08）'),
(38940, 5290, 11, '接收器的ID预选赛（ISA07）'),
(38941, 5292, 11, '近三个密码是不允许的。'),
(38942, 5293, 11, '接受者'),
(38943, 5294, 11, '收件人列表是空的'),
(38944, 5295, 11, '收件人姓名'),
(38945, 5296, 11, '收件人披露'),
(38946, 5298, 11, '建议'),
(38947, 5300, 11, '建议'),
(38948, 5301, 11, '建议和治疗'),
(38949, 5302, 11, '由专家的建议'),
(38950, 5303, 11, '记录'),
(38951, 5304, 11, '记录已经存在'),
(38952, 5310, 11, '记录和图表，在生命体征的变化。'),
(38953, 5311, 11, '记录人口统计。'),
(38954, 5312, 11, '记录披露'),
(38955, 5313, 11, '记录健身'),
(38956, 5314, 11, '记录付款'),
(38957, 5315, 11, '记录请求日期'),
(38958, 5316, 11, '纪录为13岁或以上的患者吸烟状况。'),
(38959, 5317, 11, '记录'),
(38960, 5318, 11, '找到记录'),
(38961, 5319, 11, '找到记录。'),
(38962, 5320, 11, '娱乐性药物的使用'),
(38963, 5321, 11, '娱乐性药物'),
(38964, 5322, 11, '直肠'),
(38965, 5323, 11, '直肠检查'),
(38966, 5324, 11, '直肠'),
(38967, 5325, 11, '重定向'),
(38968, 5326, 11, '发红'),
(38969, 5327, 11, '降低：'),
(38970, 5328, 11, '参考'),
(38971, 5329, 11, '指由'),
(38972, 5330, 11, '请参阅日期'),
(38973, 5331, 11, '指'),
(38974, 5332, 11, '参考分类（风险水平）'),
(38975, 5333, 11, '结果参考范围'),
(38976, 5334, 11, '参考的原因'),
(38977, 5336, 11, 'Referer的名称和签名'),
(38978, 5337, 11, '转诊'),
(38979, 5338, 11, '转介'),
(38980, 5339, 11, '转诊卡'),
(38981, 5340, 11, '转介日期'),
(38982, 5341, 11, '转介表'),
(38983, 5342, 11, '转学表'),
(38984, 5343, 11, '转诊的ID'),
(38985, 5345, 11, '转介来源'),
(38986, 5346, 11, '转介来源为遭遇'),
(38987, 5347, 11, '转诊到'),
(38988, 5348, 11, '介绍人'),
(38989, 5349, 11, '介绍人报告'),
(38990, 5350, 11, '所提'),
(38991, 5351, 11, '所提'),
(38992, 5352, 11, '简称'),
(38993, 5353, 11, '引荐'),
(38994, 5355, 11, '引荐诊断'),
(38995, 5356, 11, '引荐诊断'),
(38996, 5357, 11, '在谈到医生和实践'),
(38997, 5358, 11, '在谈到服务人员'),
(38998, 5359, 11, '笔芯'),
(38999, 5360, 11, '笔芯'),
(39000, 5361, 11, '笔芯'),
(39001, 5362, 11, '反射正常'),
(39002, 5363, 11, '刷新'),
(39003, 5365, 11, '清爽提醒'),
(39004, 5368, 11, '拒绝说明'),
(39005, 5369, 11, '注册'),
(39006, 5370, 11, '注册'),
(39007, 5372, 11, '注册'),
(39008, 5373, 11, '注册'),
(39009, 5375, 11, '注册日期'),
(39010, 5376, 11, '报名表'),
(39011, 5377, 11, '复原'),
(39012, 5381, 11, '涉及到'),
(39013, 5382, 11, '有关'),
(39014, 5383, 11, '相关问题'),
(39015, 5385, 11, '关系（S）/儿童'),
(39016, 5386, 11, '关系'),
(39017, 5387, 11, '关系'),
(39018, 5388, 11, '这个实体的相对顺序'),
(39019, 5389, 11, '亲属'),
(39020, 5399, 11, '继电器健康凭据丢失该用户帐户。'),
(39021, 5400, 11, '继电器健康ID'),
(39022, 5403, 11, '宗教'),
(39023, 5406, 11, '重新登录'),
(39024, 5407, 11, 'remdr'),
(39025, 5408, 11, '记住选择基金'),
(39026, 5409, 11, '提醒'),
(39027, 5410, 11, '提醒间隔'),
(39028, 5411, 11, '提醒不要发了'),
(39029, 5412, 11, '发送提醒'),
(39030, 5413, 11, '提醒'),
(39031, 5414, 11, '汇至'),
(39032, 5416, 11, '清除'),
(39033, 5419, 11, '删除组'),
(39034, 5420, 11, '删除组的形式'),
(39035, 5421, 11, '删除免疫支持'),
(39036, 5422, 11, '删除phpMyAdmin的支持'),
(39037, 5423, 11, '删除处方'),
(39038, 5425, 11, '删除图表跟踪功能'),
(39039, 5426, 11, '肾结石'),
(39040, 5427, 11, '重命名'),
(39041, 5428, 11, '重命名组'),
(39042, 5429, 11, '渲染'),
(39043, 5430, 11, '渲染提供商'),
(39044, 5431, 11, '渲染提供商的号码'),
(39045, 5432, 11, '重新排序'),
(39046, 5433, 11, '重新排列在'),
(39047, 5434, 11, '订货点已达到'),
(39048, 5435, 11, '重新排序来看，如果不适用'),
(39049, 5436, 11, '声望'),
(39050, 5438, 11, '重复事件'),
(39051, 5439, 11, '重复信息：'),
(39052, 5440, 11, '重复'),
(39053, 5444, 11, '回复日期'),
(39054, 5445, 11, '回复从'),
(39055, 5446, 11, '报告'),
(39056, 5447, 11, '报告 - 临床'),
(39057, 5449, 11, '的报告'),
(39058, 5457, 11, '报告状态'),
(39059, 5458, 11, '报告汇总'),
(39060, 5460, 11, '申报'),
(39061, 5461, 11, '报告'),
(39062, 5462, 11, '报告日期'),
(39063, 5463, 11, '报告'),
(39064, 5467, 11, '请求被忽略 - 索赔处理已经运行！'),
(39065, 5474, 11, '请求的服务'),
(39066, 5475, 11, '需要强有力的密码'),
(39067, 5476, 11, '需要独特的密码'),
(39068, 5477, 11, '需要'),
(39069, 5479, 11, '必填失踪：请选择的EDI-271要上传的文件'),
(39070, 5480, 11, '缺少必需的字段：请输入名字'),
(39071, 5481, 11, '缺少必需的字段：请输入姓氏'),
(39072, 5482, 11, '缺少必需的字段：请输入用户名'),
(39073, 5483, 11, '必填字段'),
(39074, 5484, 11, '要求'),
(39075, 5485, 11, '版权所有'),
(39076, 5486, 11, '版权所有'),
(39077, 5487, 11, '保留使用定义排定的休假时间'),
(39078, 5488, 11, '服务人员可能无法获得任命时，保留的定义。'),
(39079, 5489, 11, '保留定义事件没有发生时指定。'),
(39080, 5490, 11, '保留todefine当一个服务人员可能会haveavailable任命后。'),
(39081, 5491, 11, '重置'),
(39082, 5492, 11, '复位异地门户证书'),
(39083, 5493, 11, '复位上门门户全权证书'),
(39084, 5495, 11, 'resn'),
(39085, 5496, 11, '解决'),
(39086, 5497, 11, '呼吸'),
(39087, 5498, 11, '呼吸器努力unlabored'),
(39088, 5499, 11, '呼吸系统'),
(39089, 5501, 11, '限制非授权用户在用户管理中设置的附表设施。'),
(39090, 5502, 11, '限制用户设施'),
(39091, 5503, 11, '有限的培训'),
(39092, 5504, 11, '导致'),
(39093, 5506, 11, '结果状态'),
(39094, 5507, 11, '结果状态或异常丢失'),
(39095, 5508, 11, '因此，使用一个通配符％'),
(39096, 5510, 11, '结果和'),
(39097, 5511, 11, '结果发现搜索'),
(39098, 5512, 11, '结果A组'),
(39099, 5515, 11, '结果每页'),
(39100, 5516, 11, '结果/详细信息'),
(39101, 5517, 11, '视网膜考试'),
(39102, 5518, 11, '收回权：'),
(39103, 5519, 11, '返回'),
(39104, 5520, 11, '回到上面的一部分，与您的付款'),
(39105, 5521, 11, '返回到日历'),
(39106, 5527, 11, '返回值'),
(39107, 5528, 11, '复诊'),
(39108, 5529, 11, '返回到播放'),
(39109, 5534, 11, '玛嘉烈医院回顾：'),
(39110, 5535, 11, '系统回顾'),
(39111, 5536, 11, '审查系统的检查'),
(39112, 5537, 11, '评论'),
(39113, 5538, 11, '调整'),
(39114, 5541, 11, '权利'),
(39115, 5542, 11, '右耳'),
(39116, 5543, 11, '右耳'),
(39117, 5545, 11, '右：'),
(39118, 5546, 11, '言犹在耳'),
(39119, 5547, 11, '言犹在耳'),
(39120, 5549, 11, '风险因素'),
(39121, 5550, 11, '风险水平'),
(39122, 5551, 11, 'RLL的：'),
(39123, 5552, 11, '光盘'),
(39124, 5553, 11, '罗马尼亚'),
(39125, 5560, 11, '名册'),
(39126, 5561, 11, '路线'),
(39127, 5562, 11, '给药途径，如适用'),
(39128, 5563, 11, '路由'),
(39129, 5564, 11, '行'),
(39130, 5565, 11, '存款准备金率没有铁道部'),
(39131, 5566, 11, '擦：'),
(39132, 5567, 11, '搓：'),
(39133, 5568, 11, '排除'),
(39134, 5569, 11, '规则添加'),
(39135, 5570, 11, '规则详情'),
(39136, 5572, 11, '规则编辑'),
(39137, 5575, 11, '规则集'),
(39138, 5578, 11, '规则'),
(39139, 5580, 11, '规则配置'),
(39140, 5581, 11, '运行命令： '),
(39141, 5582, 11, '破裂'),
(39142, 5583, 11, '俄'),
(39143, 5584, 11, 'RX'),
(39144, 5585, 11, '接收'),
(39145, 5586, 11, 'RX底部边距（PX）'),
(39146, 5587, 11, 'RX启用DEA的＃'),
(39147, 5588, 11, 'RX启用非营利机构'),
(39148, 5589, 11, 'RX启用国家许可。 ＃'),
(39149, 5590, 11, 'RX左边界（PX）'),
(39150, 5591, 11, '接收纸张尺寸'),
(39151, 5592, 11, 'RX右边缘（PX）'),
(39152, 5593, 11, '接收显示DEA＃'),
(39153, 5594, 11, 'RX显示非营利机构'),
(39154, 5595, 11, '接收显示国家许可。 ＃'),
(39155, 5596, 11, 'RX边距（PX）'),
(39156, 5598, 11, 'RxNorm'),
(39157, 5599, 11, 'RxNorm数据库'),
(39158, 5600, 11, '小号'),
(39159, 5601, 11, 'S.S.'),
(39160, 5602, 11, '中三：'),
(39161, 5603, 11, '四至：'),
(39162, 5604, 11, 'SA**阅读许可请阅读DOCS / LICENSE.TXT或* http://www.gnu.org/copyleft/gpl.html门诊** / //============ ================================================== ===========// '),
(39163, 5605, 11, '出售'),
(39164, 5606, 11, '销售'),
(39165, 5607, 11, '主要项目的销售'),
(39166, 5608, 11, '销售产品报告'),
(39167, 5609, 11, '唾液'),
(39168, 5610, 11, '同一天'),
(39169, 5611, 11, '萨摩亚'),
(39170, 5612, 11, '样本'),
(39171, 5613, 11, '处罚种类'),
(39172, 5617, 11, '星期六'),
(39173, 5618, 11, '周六和周日'),
(39174, 5619, 11, '星期六'),
(39175, 5620, 11, '保存'),
(39176, 5621, 11, '保存'),
(39177, 5622, 11, '保存并关闭'),
(39178, 5624, 11, '保存和分配'),
(39179, 5626, 11, '另存为新'),
(39180, 5627, 11, '另存为新的笔记'),
(39181, 5628, 11, '保存证书设置'),
(39182, 5629, 11, '保存更改'),
(39183, 5630, 11, '保存表格'),
(39184, 5631, 11, '保存免疫'),
(39185, 5632, 11, '保存新领域'),
(39186, 5633, 11, '保存新组'),
(39187, 5634, 11, '保存新的列表'),
(39188, 5635, 11, '保存新模板'),
(39189, 5637, 11, '保存客户的人口统计资料'),
(39190, 5638, 11, '成功保存图表编号'),
(39191, 5639, 11, '节约交易'),
(39192, 5641, 11, '扫描'),
(39193, 5642, 11, '扫描遭遇注意'),
(39194, 5643, 11, '扫描仪指南'),
(39195, 5644, 11, '扫描器'),
(39196, 5645, 11, '时间表'),
(39197, 5646, 11, '附表设施：'),
(39198, 5647, 11, '校注'),
(39199, 5648, 11, '脊柱侧凸'),
(39200, 5651, 11, 'SEL'),
(39201, 5652, 11, 'SE的地址'),
(39202, 5653, 11, 'SE城'),
(39203, 5654, 11, 'SE地区'),
(39204, 5655, 11, 'SE方位'),
(39205, 5656, 11, 'SE邮政编码'),
(39206, 5657, 11, 'SE国'),
(39207, 5658, 11, 'SE邮编'),
(39208, 5659, 11, '搜索'),
(39209, 5661, 11, '搜索'),
(39210, 5662, 11, '再次搜索'),
(39211, 5664, 11, '搜寻：'),
(39212, 5665, 11, '搜索'),
(39213, 5666, 11, '搜索：'),
(39214, 5668, 11, '搜索'),
(39215, 5669, 11, '搜寻或新增客户'),
(39216, 5670, 11, '搜索付款'),
(39217, 5672, 11, '搜索结果：'),
(39218, 5673, 11, '搜索时选择'),
(39219, 5674, 11, '搜索字符串不匹配数据库中的名单'),
(39220, 5675, 11, '搜索字符串应该至少有三个字符'),
(39221, 5676, 11, '搜索文本'),
(39222, 5677, 11, '搜索事件'),
(39223, 5678, 11, '搜索/添加'),
(39224, 5679, 11, '搜索/加入保险'),
(39225, 5680, 11, '寻找约会'),
(39226, 5681, 11, '搜索...'),
(39227, 5682, 11, '安全带的使用'),
(39228, 5683, 11, '安全带的使用'),
(39229, 5684, 11, '第二'),
(39230, 5687, 11, '次要'),
(39231, 5688, 11, '中学保险'),
(39232, 5689, 11, '二级保险数据'),
(39233, 5690, 11, '二次保险提供商'),
(39234, 5691, 11, '二级医疗保险类型'),
(39235, 5698, 11, '安全'),
(39236, 5699, 11, '查看全部'),
(39237, 5700, 11, '看到授权'),
(39238, 5701, 11, '看到增长的走势'),
(39239, 5702, 11, '看到最后一组消息从生成的索赔'),
(39240, 5704, 11, '看到自'),
(39241, 5707, 11, '癫痫发作'),
(39242, 5708, 11, 'SEL'),
(39243, 5709, 11, '选择'),
(39244, 5710, 11, '选择'),
(39245, 5712, 11, '选择一个关联'),
(39246, 5714, 11, '选择一个时间跨度'),
(39247, 5715, 11, '选择一个用户'),
(39248, 5716, 11, '选择全部'),
(39250, 5720, 11, '选择类别'),
(39251, 5722, 11, '选择相应的复选框删除'),
(39252, 5723, 11, '选择要删除的标准'),
(39253, 5725, 11, '选择德鉴定所需的数据'),
(39254, 5726, 11, '选择在德中包含的数据标识数据'),
(39255, 5727, 11, '选择日期'),
(39256, 5728, 11, '选择所需的小队'),
(39257, 5729, 11, '选择诊断'),
(39258, 5730, 11, '选择诊断为德鉴定请求'),
(39259, 5731, 11, '选择药物'),
(39260, 5732, 11, '选择药物'),
(39261, 5733, 11, '选择药物为德鉴定请求'),
(39262, 5734, 11, '选择的EDI-271文件'),
(39263, 5736, 11, '选择字段'),
(39264, 5737, 11, '选择字段'),
(39265, 5738, 11, '选择打印'),
(39266, 5739, 11, '选择免疫'),
(39267, 5740, 11, '选择德鉴定要求的预防接种'),
(39268, 5741, 11, '选择保险，键入'),
(39269, 5742, 11, '选择发行'),
(39270, 5744, 11, '选择语言'),
(39271, 5746, 11, '选择一个或多个诊断代码来证明服务'),
(39272, 5754, 11, '选择导出的配置项'),
(39273, 5755, 11, '选择错过了这一天的任何事件负有主要责任的问题'),
(39274, 5759, 11, '选择用户'),
(39275, 5760, 11, '从下拉列表中选择用户'),
(39276, 5761, 11, '选择哪种语言，如果有的话，可能会在登录时选择。 （只有关，如果上述所有语言允许被关闭）'),
(39277, 5762, 11, '选择是确认组删除'),
(39278, 5765, 11, '选'),
(39279, 5766, 11, '选择治疗'),
(39280, 5767, 11, '选择这将创建一个消息，需要单独处理每个收件人（这不是一组的任务）。'),
(39281, 5768, 11, '自'),
(39282, 5769, 11, '自付费'),
(39283, 5771, 11, '发送'),
(39284, 5772, 11, '发送日的提醒'),
(39285, 5773, 11, '发送提醒'),
(39286, 5774, 11, '正在进行中发送'),
(39287, 5775, 11, '发送消息'),
(39288, 5776, 11, '发送提醒批次'),
(39289, 5777, 11, '发送提醒患者每预防/跟进护理客户的偏好。'),
(39290, 5778, 11, '发送介绍人摘要'),
(39291, 5779, 11, '发送此文件'),
(39292, 5780, 11, '发送此消息'),
(39293, 5781, 11, '发送到'),
(39294, 5784, 11, '向所有'),
(39295, 5788, 11, '寄件人'),
(39296, 5789, 11, '发件人ID'),
(39297, 5790, 11, '发件人ID（ISA06）'),
(39298, 5791, 11, 'Sender ID的预选赛（ISA05）'),
(39299, 5794, 11, '敏感性'),
(39300, 5795, 11, '灵敏度：'),
(39301, 5796, 11, '感官检查正常'),
(39302, 5799, 11, '发送留下的所有空白'),
(39303, 5801, 11, '发送日期'),
(39304, 5802, 11, '已发送邮件'),
(39305, 5803, 11, '发送病历？'),
(39306, 5804, 11, '发送成功'),
(39307, 5807, 11, '发送到打印机。'),
(39308, 5808, 11, '离开发送到所有空白'),
(39309, 5812, 11, '九月'),
(39310, 5813, 11, '分离'),
(39311, 5814, 11, '九月'),
(39312, 5815, 11, '序号'),
(39313, 5816, 11, '序列'),
(39314, 5821, 11, '服务'),
(39315, 5822, 11, '服务类别'),
(39316, 5823, 11, '服务守则'),
(39317, 5825, 11, '服务代码'),
(39318, 5826, 11, '服务日期'),
(39319, 5827, 11, '服务日期：'),
(39320, 5829, 11, '服务地点'),
(39321, 5831, 11, '由专家提供的服务'),
(39322, 5834, 11, '服务'),
(39323, 5835, 11, '服务类别'),
(39324, 5836, 11, '所提供的服务'),
(39325, 5837, 11, '提供的服务'),
(39326, 5838, 11, '服务/产品'),
(39327, 5839, 11, '会话类型'),
(39328, 5840, 11, '集'),
(39329, 5841, 11, '设施设置Cookie以记住登录之间的选定设施。'),
(39330, 5842, 11, '设置为已完成'),
(39331, 5845, 11, '设置这个完整的绝对路径。为创建HTTPS客户端SSL证书。'),
(39332, 5846, 11, '设置为'),
(39333, 5847, 11, '设置为默认'),
(39334, 5848, 11, '设置在数据库中的版本号...'),
(39335, 5849, 11, '设置'),
(39336, 5851, 11, '严重偏头痛'),
(39337, 5853, 11, '疼痛严重程度'),
(39338, 5854, 11, '疼痛严重程度：'),
(39339, 5855, 11, '性别'),
(39340, 5856, 11, '性病'),
(39341, 5858, 11, 'SHA-1哈希'),
(39342, 5859, 11, '共享'),
(39343, 5860, 11, '从打印服务器的shell命令。'),
(39344, 5864, 11, '气短'),
(39345, 5865, 11, '气短'),
(39346, 5866, 11, '急促的呼吸2'),
(39347, 5867, 11, '铅球纪录'),
(39348, 5868, 11, '作为拍摄记录：'),
(39349, 5870, 11, '应该类似于nnnnn-nnnn-nn'),
(39350, 5871, 11, '应该是两个字母'),
(39351, 5872, 11, '应包含10个数字'),
(39352, 5873, 11, '应该只包含10个数字'),
(39353, 5874, 11, '肩'),
(39354, 5875, 11, '肩+锁骨'),
(39355, 5876, 11, '肩部有问题'),
(39356, 5877, 11, '显示'),
(39357, 5880, 11, '显示所有'),
(39358, 5883, 11, '显示所有交易'),
(39359, 5884, 11, '显示为忙碌'),
(39360, 5885, 11, '显示唯一授权'),
(39361, 5886, 11, '显示可用的时间'),
(39362, 5887, 11, '显示美国和公制（主要单位是公制）'),
(39363, 5888, 11, '显示美国和公制（主要单位是美国）'),
(39364, 5889, 11, '显示详细信息'),
(39365, 5891, 11, '显示图形'),
(39366, 5892, 11, '徘徊在mouseover事件文本的显示？'),
(39367, 5893, 11, '管理页面上多少事件？'),
(39368, 5896, 11, '显示菜单'),
(39369, 5897, 11, '显示公制只'),
(39370, 5898, 11, '显示注释'),
(39371, 5901, 11, '客户笔记'),
(39372, 5904, 11, '显示初步完成'),
(39373, 5905, 11, '显示提醒'),
(39374, 5906, 11, '展后报告'),
(39375, 5907, 11, '显示搜索/块提交的联系？'),
(39376, 5910, 11, '显示附加列表部件的自定义状态的形式（要求标题和缩写）。'),
(39377, 5913, 11, '显示未入账只有'),
(39378, 5914, 11, '显示，美国只'),
(39379, 5920, 11, '兄弟姐妹'),
(39380, 5921, 11, '镰状细胞'),
(39381, 5922, 11, 'SIG'),
(39382, 5923, 11, '乙状结肠/大肠镜检查'),
(39383, 5925, 11, '注册实验室检测结果（写'),
(39384, 5926, 11, '签结果'),
(39385, 5927, 11, '签名'),
(39386, 5929, 11, '签名：'),
(39387, 5930, 11, '签名接收'),
(39388, 5932, 11, '显著膨胀：'),
(39389, 5934, 11, '简体有限公司支付'),
(39390, 5935, 11, '简化户口资料'),
(39391, 5936, 11, '简化处方'),
(39392, 5937, 11, '自'),
(39393, 5938, 11, '诚挚'),
(39394, 5940, 11, '单'),
(39395, 5941, 11, '单选择列表'),
(39396, 5942, 11, '单选择列表添加到列表的能力'),
(39397, 5946, 11, '窦问题'),
(39398, 5947, 11, '鼻窦手术'),
(39399, 5948, 11, '窦压痛：'),
(39400, 5949, 11, '鼻窦炎'),
(39401, 5951, 11, '站点ID'),
(39402, 5953, 11, '为LibreEHR支持LLC实验室Exchange服务的网站ID。'),
(39403, 5956, 11, '大小'),
(39404, 5957, 11, '尺寸必须介于1和999'),
(39405, 5958, 11, '尺寸/名单'),
(39406, 5959, 11, '皮肤'),
(39407, 5960, 11, '皮肤癌'),
(39408, 5961, 11, '皮肤病'),
(39409, 5962, 11, '皮肤的其他'),
(39410, 5963, 11, '跳过授权客户笔记'),
(39411, 5964, 11, '跳越区间'),
(39412, 5965, 11, '跳转sql-ledger转储-没有实施服务器'),
(39413, 5967, 11, '睡眠模式'),
(39414, 5968, 11, '睡眠模式'),
(39415, 5969, 11, '睡美人'),
(39416, 5970, 11, '斯洛伐克文'),
(39417, 5972, 11, '钐债务W / O型'),
(39418, 5973, 11, 'Smarty缓存已被清除'),
(39419, 5974, 11, '吸烟者的当前状态未知'),
(39420, 5976, 11, '吸烟状况'),
(39421, 5977, 11, '短信管理'),
(39422, 5978, 11, '短信网关'),
(39423, 5979, 11, '短信网关API密钥'),
(39424, 5980, 11, '短信网关API密钥'),
(39425, 5981, 11, '短信网关密码'),
(39426, 5982, 11, '短信网关用户名'),
(39427, 5983, 11, '短信通知'),
(39428, 5984, 11, '短信通知时间'),
(39429, 5985, 11, '发送短信之前'),
(39430, 5986, 11, '发送短信'),
(39431, 5987, 11, '短信文本使用标签：* * * * * * * * * * * * * * * * * * * *服务人员'),
(39432, 5988, 11, '短信/电子邮件警报设置'),
(39433, 5989, 11, '密码认证协议'),
(39434, 5992, 11, 'SMTP主机名'),
(39435, 5993, 11, 'SM TP服务器端口号'),
(39436, 5994, 11, '用户认证协议'),
(39437, 5995, 11, '医学分类命名法'),
(39438, 6001, 11, '术语数据库'),
(39439, 6004, 11, '打呼噜'),
(39440, 6005, 11, '肥皂'),
(39441, 6006, 11, '社会困难'),
(39442, 6009, 11, '社会史：'),
(39443, 6010, 11, '社会安全号码'),
(39444, 6011, 11, '解决方案'),
(39445, 6013, 11, '躯体方面'),
(39446, 6014, 11, '一些授权是不显示的。点击这里查看所有'),
(39447, 6015, 11, '一些代码不显示的。'),
(39448, 6016, 11, '有些遇到没有显示出来。点击这里查看所有。'),
(39449, 6017, 11, '一些时发生错误的识别过程'),
(39450, 6018, 11, '一些笔记不显示。'),
(39451, 6020, 11, '一些话'),
(39452, 6023, 11, '事情出了错。请再试一次。'),
(39453, 6024, 11, '不久由于区间（临床提醒）'),
(39454, 6025, 11, '不久由于区间（客户提醒）'),
(39455, 6026, 11, '喉咙痛'),
(39456, 6028, 11, '对不起，您的文件上传有问题'),
(39457, 6029, 11, '排序方式'),
(39458, 6030, 11, '排序'),
(39459, 6031, 11, '按校检排序'),
(39460, 6032, 11, '按意见排序'),
(39461, 6033, 11, '按CRT用户排序'),
(39462, 6034, 11, '按日期排序'),
(39463, 6035, 11, '按时间排序'),
(39464, 6036, 11, '按事件排序'),
(39465, 6037, 11, '按组排序'),
(39466, 6040, 11, '按客户编号排序'),
(39467, 6041, 11, '按成功排序'),
(39468, 6043, 11, '按用户排序'),
(39469, 6044, 11, '按疫苗排序'),
(39470, 6045, 11, '降序'),
(39471, 6046, 11, '排序结果'),
(39472, 6047, 11, '升序'),
(39473, 6048, 11, '来源'),
(39474, 6049, 11, '源文件'),
(39475, 6050, 11, '源文件路径'),
(39476, 6051, 11, '源代码是失踪 '),
(39477, 6052, 11, '源地段'),
(39478, 6057, 11, '来源：'),
(39479, 6060, 11, '空间'),
(39480, 6061, 11, '空间'),
(39481, 6062, 11, '西班牙语'),
(39482, 6063, 11, '西班牙语（拉丁美洲）'),
(39483, 6064, 11, '西班牙语（西班牙）'),
(39484, 6068, 11, '专家'),
(39485, 6069, 11, '专家的姓名和签名'),
(39486, 6071, 11, '专业'),
(39487, 6072, 11, '专业系统'),
(39488, 6073, 11, '专业：'),
(39489, 6074, 11, '特定'),
(39490, 6075, 11, '特定应用'),
(39491, 6076, 11, '特定的避孕服务'),
(39492, 6077, 11, '特定结果'),
(39493, 6078, 11, '特定服务'),
(39494, 6079, 11, '特定'),
(39495, 6080, 11, '指定格式代码。# =数字* =任何字符。如果不使用空。'),
(39496, 6081, 11, '指定格式代码。# =数字@ =α* =任何字符。如果不使用空。'),
(39497, 6082, 11, '指定格式的发票的参考号码。# =数字* =任何字符。如果不使用空。'),
(39498, 6083, 11, '指定格式的发票的参考号码。# =数字@ =α* =任何字符。如果不使用空。'),
(39499, 6084, 11, '指定格式领域产品控制器。# =数字* =任何字符。如果不使用空。'),
(39500, 6085, 11, '指定格式领域产品控制器。# =数字@ =α* =任何字符。如果不使用空。'),
(39501, 6086, 11, '指定格式的外部客户的ID。# =数字* =任何字符。如果不使用空。'),
(39502, 6087, 11, '指定格式的外部客户的ID。# =数字@ =α* =任何字符。如果不使用空。'),
(39503, 6088, 11, '标本'),
(39504, 6089, 11, '标本号/标识符'),
(39505, 6090, 11, '标本类型'),
(39506, 6092, 11, '语音听写'),
(39507, 6093, 11, '杀精剂'),
(39508, 6094, 11, '脾切除术'),
(39509, 6095, 11, '配偶'),
(39510, 6097, 11, '痰'),
(39511, 6098, 11, '痰：'),
(39512, 6099, 11, '倚强'),
(39513, 6102, 11, '队'),
(39514, 6103, 11, '小组成员'),
(39515, 6104, 11, '队'),
(39516, 6105, 11, '性健康和生殖健康'),
(39517, 6106, 11, '性健康和生殖健康-计划生育'),
(39518, 6107, 11, '非计划生育生殖健康'),
(39519, 6108, 11, '性健康和生殖健康推荐'),
(39520, 6109, 11, '性健康和生殖健康门诊表'),
(39521, 6110, 11, 'SRV日期'),
(39522, 6111, 11, '党卫军'),
(39523, 6112, 11, '证书管理'),
(39524, 6113, 11, '炙'),
(39525, 6114, 11, '稳定'),
(39526, 6116, 11, '标准'),
(39527, 6117, 11, '标准规定'),
(39528, 6118, 11, '标准措施'),
(39529, 6122, 11, '标准名称'),
(39530, 6124, 11, '开始'),
(39531, 6125, 11, '启动（年-月-日）： '),
(39532, 6128, 11, '开始日期'),
(39533, 6129, 11, '开始日期在这个诊所'),
(39534, 6130, 11, '开始日期不能大于结束日期'),
(39535, 6131, 11, '起始日期：'),
(39536, 6132, 11, '开始日期：'),
(39537, 6133, 11, '开始时间'),
(39538, 6134, 11, '起始日期'),
(39539, 6135, 11, '统计'),
(39540, 6136, 11, '状态'),
(39541, 6137, 11, '数据类型'),
(39542, 6138, 11, '状态编号。#'),
(39543, 6139, 11, '国家执照号码'),
(39544, 6140, 11, '国家名单'),
(39545, 6141, 11, '状态列表（写只添加可选）'),
(39546, 6142, 11, '自定义域状态部件清单'),
(39547, 6143, 11, '州或省'),
(39548, 6144, 11, '国家/地点'),
(39549, 6145, 11, '国家/帕里什'),
(39550, 6146, 11, '声明总结'),
(39551, 6147, 11, '报表和更新的发票。'),
(39552, 6148, 11, '报表发送：'),
(39553, 6149, 11, '报表；发票将不被更新。'),
(39554, 6150, 11, '静态文字'),
(39555, 6151, 11, '统计'),
(39556, 6152, 11, '统计'),
(39557, 6153, 11, '身份'),
(39558, 6156, 11, '现状'),
(39559, 6158, 11, '性病/艾滋病顾问'),
(39560, 6159, 11, '强度和空调'),
(39561, 6169, 11, '关节僵硬'),
(39562, 6170, 11, '僵硬'),
(39563, 6171, 11, '库存月'),
(39564, 6172, 11, '胃痛'),
(39565, 6174, 11, '存储的哈希'),
(39566, 6175, 11, '应变的肌肉'),
(39567, 6176, 11, '河流'),
(39568, 6177, 11, '街'),
(39569, 6178, 11, '街道地址'),
(39570, 6179, 11, '街及编号'),
(39571, 6180, 11, '实力'),
(39572, 6182, 11, '链球菌性喉炎'),
(39573, 6183, 11, '应力性骨折'),
(39574, 6184, 11, '应力测试'),
(39575, 6185, 11, '敲击'),
(39576, 6186, 11, '强大的密码是指至少8个字符和至少有三个：一个小写字母'),
(39577, 6188, 11, '风格的形式用于增加新的客户'),
(39578, 6189, 11, '子范畴'),
(39579, 6190, 11, '小计'),
(39580, 6191, 11, '分类'),
(39581, 6192, 11, '分类'),
(39582, 6193, 11, '皮下'),
(39583, 6194, 11, '科目'),
(39584, 6195, 11, '主观'),
(39585, 6196, 11, '舌下'),
(39586, 6197, 11, '舌下'),
(39587, 6198, 11, '提交'),
(39588, 6199, 11, '听从'),
(39589, 6200, 11, '提交的所有内容'),
(39590, 6202, 11, '提交事件'),
(39591, 6203, 11, '提交表格'),
(39592, 6204, 11, '将选定内容'),
(39593, 6205, 11, '听从'),
(39594, 6206, 11, '提交'),
(39595, 6207, 11, '提交电子数据交换接入号码（per06）'),
(39596, 6208, 11, '用户'),
(39597, 6209, 11, '用户地址'),
(39598, 6213, 11, '用户单位'),
(39599, 6214, 11, '用户单位（SE）'),
(39600, 6215, 11, '用户单位地址'),
(39601, 6216, 11, '用户单位市'),
(39602, 6217, 11, '用户单位国家'),
(39603, 6218, 11, '用户单位国'),
(39604, 6221, 11, '用户单位邮编'),
(39605, 6225, 11, '用户电话'),
(39606, 6226, 11, '客户关系'),
(39607, 6227, 11, '用户关系不是自己姓名相同！这是真的吗？'),
(39608, 6228, 11, '用户关系不是自我但相同数量！'),
(39609, 6229, 11, '用户的关系是自但是名字是不同的！这是真的吗？'),
(39610, 6230, 11, '用户关系自我但数是不同的！'),
(39611, 6231, 11, '用户性别'),
(39612, 6237, 11, '换人'),
(39613, 6238, 11, '替代允许'),
(39614, 6240, 11, '成功'),
(39615, 6241, 11, '成功'),
(39616, 6242, 11, '成功确认收到实验室结果'),
(39617, 6243, 11, '成功的实验结果'),
(39618, 6244, 11, '成功检索结果从实验室交换网络'),
(39619, 6246, 11, '成功添加分类'),
(39620, 6247, 11, '成功添加分类'),
(39621, 6248, 11, '成功删除'),
(39622, 6250, 11, '成功安装数据库'),
(39623, 6252, 11, '成功修改'),
(39624, 6253, 11, '成功保存。你想分配？'),
(39625, 6254, 11, '成功保存。您想发布？'),
(39626, 6256, 11, '成功储存。'),
(39627, 6257, 11, '成功升级数据库。'),
(39628, 6259, 11, '成功'),
(39629, 6260, 11, '自杀'),
(39630, 6261, 11, '摘要'),
(39631, 6262, 11, '摘要信息'),
(39632, 6265, 11, '太阳'),
(39633, 6267, 11, '星期日'),
(39634, 6268, 11, '超级账单'),
(39635, 6269, 11, '超级账单码'),
(39636, 6270, 11, '超级账单代码管理'),
(39637, 6271, 11, '超级账单报告'),
(39638, 6272, 11, '超级账单 /费用表'),
(39639, 6273, 11, '超级账单'),
(39640, 6274, 11, '超级账单有时称为遇到的形式或路由单是不可缺少的一部分，大多数医疗做法。'),
(39641, 6275, 11, '超级用户'),
(39642, 6276, 11, '监督'),
(39643, 6278, 11, '监督医生的数据包络分析'),
(39644, 6279, 11, '监督医生名字'),
(39645, 6280, 11, '监督医生姓氏'),
(39646, 6281, 11, '监督医生助理'),
(39647, 6282, 11, '医生在监督'),
(39648, 6283, 11, '供应商设施的名字'),
(39649, 6284, 11, '支持日历事件，适用于多个服务人员'),
(39650, 6285, 11, '支持出口/进口配置数据通过备份页面。'),
(39651, 6286, 11, '支持多服务人员的事件'),
(39652, 6288, 11, '支持Triple DES加密/解密只。'),
(39653, 6289, 11, '表面类型'),
(39654, 6290, 11, '外科手术'),
(39655, 6291, 11, '外科手术'),
(39656, 6293, 11, '暂停'),
(39657, 6294, 11, '暂停'),
(39658, 6295, 11, '日期的SVC'),
(39659, 6296, 11, '静止无功补偿器日期：'),
(39660, 6299, 11, '出汗：'),
(39661, 6300, 11, '瑞典文'),
(39662, 6301, 11, '肿胀'),
(39663, 6302, 11, '右侧溶胀'),
(39664, 6303, 11, '关节肿胀'),
(39665, 6304, 11, '淋巴结肿大'),
(39666, 6305, 11, '小数点符号用作货币。如果不使用小数位数是0。'),
(39667, 6306, 11, '用于分离数以千计的货币符号。'),
(39668, 6307, 11, '症状'),
(39669, 6308, 11, '同步'),
(39670, 6309, 11, '同步翻译与自定义语言表。'),
(39671, 6310, 11, '同步新的自定义常数：'),
(39672, 6311, 11, '同步新的自定义语言：'),
(39673, 6312, 11, '同步的新定义（语言常量定义）：'),
(39674, 6313, 11, '晕厥'),
(39675, 6314, 11, '症状监测'),
(39676, 6315, 11, '症状监测-非报告的问题'),
(39677, 6317, 11, 'impingement'),
(39678, 6318, 11, '系统'),
(39679, 6322, 11, 'Ť'),
(39680, 6323, 11, '每日三次'),
(39681, 6324, 11, '电视'),
(39682, 6325, 11, '表'),
(39683, 6327, 11, '表创建失败'),
(39684, 6328, 11, '表更新失败'),
(39685, 6330, 11, '片剂'),
(39686, 6332, 11, '菲律宾语'),
(39687, 6335, 11, '拿'),
(39688, 6336, 11, '以保险'),
(39689, 6337, 11, '参加付款'),
(39690, 6338, 11, '收回'),
(39691, 6339, 11, '持续时间较长'),
(39692, 6340, 11, '高导航区'),
(39693, 6347, 11, '预定日期'),
(39694, 6351, 11, '目标/行动组'),
(39695, 6354, 11, '税务编号'),
(39696, 6355, 11, '税率'),
(39697, 6356, 11, '税'),
(39698, 6357, 11, '分类'),
(39699, 6358, 11, '破伤风及白喉类毒素'),
(39700, 6359, 11, '小组损伤概况'),
(39701, 6360, 11, '小组名册'),
(39702, 6361, 11, '小组名册查看'),
(39703, 6362, 11, '团队/小队'),
(39704, 6363, 11, '电话'),
(39705, 6364, 11, '国家电话代码'),
(39706, 6366, 11, '临时'),
(39707, 6367, 11, '临时位置'),
(39708, 6368, 11, '温度的方法'),
(39709, 6369, 11, '温度'),
(39710, 6370, 11, '模板'),
(39711, 6371, 11, '模板名称'),
(39712, 6372, 11, '模板名称不能以数字开始。'),
(39713, 6373, 11, '模板：'),
(39714, 6374, 11, '模板'),
(39715, 6375, 11, '颞浅动脉'),
(39716, 6376, 11, '肌腱损伤'),
(39717, 6377, 11, '肌腱炎/尘埃沉着病/滑囊炎'),
(39718, 6378, 11, '暂定发票编号'),
(39719, 6379, 11, '第三纪'),
(39720, 6380, 11, '第三保险'),
(39721, 6381, 11, '第三保险数据'),
(39722, 6382, 11, '第三保险提供商'),
(39723, 6383, 11, '测试调度'),
(39724, 6384, 11, '测试系统'),
(39725, 6385, 11, '文本'),
(39726, 6386, 11, '文本诊断'),
(39727, 6387, 11, '文本字段'),
(39728, 6393, 11, '文字日期'),
(39729, 6394, 11, '文字日期'),
(39730, 6395, 11, '文本'),
(39731, 6396, 11, '文本'),
(39732, 6397, 11, '文本'),
(39733, 6398, 11, '文本'),
(39734, 6399, 11, '文本清单'),
(39735, 6400, 11, '文本清单'),
(39736, 6401, 11, '泰语'),
(39737, 6402, 11, '谢谢您'),
(39738, 6403, 11, '谢谢你的选择'),
(39739, 6404, 11, '明确''按钮将移除所有注解。'),
(39740, 6405, 11, '上述声明失败'),
(39741, 6406, 11, 'Apache服务器的证书和公钥'),
(39742, 6407, 11, '权威的证书'),
(39743, 6408, 11, '索赔文件： '),
(39744, 6410, 11, '相应的私钥'),
(39745, 6413, 11, '拒绝代码'),
(39746, 6414, 11, '否定组代码'),
(39747, 6415, 11, '目的地的形式被关闭'),
(39748, 6416, 11, '目的地形式封闭;我不能采取行动，您的选择。'),
(39749, 6418, 11, '专业资格的医院或肝炎谁收到客户从另一个设置的照顾或提供服务或认为遇到有关执行药物和解。'),
(39750, 6421, 11, '专业资格的医院或肝炎谁过渡到另一个的客户设置的照顾或提供服务或是指他们的客户到另一个服务人员的照顾应提供简要记录每一个过渡照顾或转介。'),
(39751, 6422, 11, '事件（县）已被批准。'),
(39752, 6423, 11, '事件（县）已被隐藏。'),
(39753, 6424, 11, '出口数据显示在文本区。你可以复制并粘贴到电子邮件或任何其他所需的目的地。'),
(39754, 6426, 11, '出口数据显示在文本区。你可以复制并粘贴到电子邮件或任何其他所需的目的地。'),
(39755, 6427, 11, '出口数据显示在文本区。你可以复制并粘贴到电子邮件或任何其他所需的目的地。'),
(39756, 6429, 11, '该文件可能不会被成功更名为这个错误通常是有关权限问题上的存储系统。'),
(39757, 6434, 11, '以下日历事件已新增：'),
(39758, 6435, 11, '以下日历事件已改性：'),
(39759, 6436, 11, '以下类别将被删除从您的列表类'),
(39760, 6437, 11, '下列数据库版本目前安装'),
(39761, 6439, 11, '下列文件已经上传'),
(39762, 6440, 11, '以下紧急登录用户激活：'),
(39763, 6441, 11, '发生了下列错误'),
(39764, 6444, 11, '以下领域的需要'),
(39765, 6446, 11, '以下领域必须填写发送请求。'),
(39766, 6449, 11, '主机的atna审计知识库机。'),
(39767, 6450, 11, '最初的窗口是发票搜索页。在上面你可以输入一个源（如支票号码）和支票的金额支付日期。原因的来源和日期，你不需要输入他们一遍又一遍，每个索赔。你的金额输入将减少每个发票是一部分付款'),
(39768, 6456, 11, '标签显示给用户的形式'),
(39769, 6457, 11, '长度不应超过下列字符数'),
(39770, 6460, 11, '新的分类将是一个分类别 '),
(39771, 6461, 11, '新密码不能同当前密码。'),
(39772, 6462, 11, '新密码领域是不一样的。'),
(39773, 6465, 11, '本页将被重定向到人口。你可以编辑领域和国家newcrop再次点击。'),
(39774, 6466, 11, '密码必须至少八个字符'),
(39775, 6468, 11, '客户记录的要求已被记录。'),
(39776, 6469, 11, '客户提醒已发送'),
(39777, 6470, 11, '客户提醒已更新'),
(39778, 6472, 11, '付款张贴不能超过这个日期。这将确保在最后报告中没有人后，以前的日期。'),
(39779, 6475, 11, '其余的信息只适用于如果您是张贴手动或如果你正在做手动更正。'),
(39780, 6477, 11, '请求的文件不在预期的位置上的文件或没有足够的门诊权限。'),
(39781, 6480, 11, '来源和日期列复制从第一页，通常你不需要触摸那些。你可以把付款金额的支付列调整量的调整列或两者。你也可以点击“瓦特”的权利，自动计算价值的调整，将其余的费用'),
(39782, 6484, 11, '时间粒度的日历和最小间隔分钟赴约槽。'),
(39783, 6485, 11, '翻译标签，会出现在当前的形式语言'),
(39784, 6486, 11, '翻译标题将出现在当前的语言'),
(39785, 6487, 11, '翻译的语言描述在当前'),
(39786, 6488, 11, '翻译表同步。'),
(39787, 6489, 11, '这个实体的类型'),
(39788, 6490, 11, '供应商特定的代码确定这一过程或结果'),
(39789, 6491, 11, '在X12的文件以及由此产生的HTML输出报告的存档中的“时代”子目录主要LibreEHR安装目录。您将要提及这些档案不时。网址是'),
(39790, 6492, 11, '压缩文件将包含下列项目'),
(39791, 6493, 11, '主题'),
(39792, 6495, 11, '注射治疗'),
(39793, 6496, 11, '有'),
(39794, 6497, 11, '目前还没有处方'),
(39795, 6498, 11, '有错误的意见。这些概述如下。'),
(39796, 6500, 11, '有没有图检查。'),
(39797, 6501, 11, '目前没有披露记录这个客户。'),
(39798, 6502, 11, '没有新的划界案'),
(39799, 6503, 11, '这里没有说明文件的客户。'),
(39800, 6504, 11, '有没有交易文件这个客户。'),
(39801, 6505, 11, '已经有送的邮件错误'),
(39802, 6506, 11, '已经有类别命名'),
(39803, 6507, 11, '已经有一个分类命名'),
(39804, 6508, 11, '已经有一个项目为'),
(39805, 6509, 11, '已经有一个开放的客户记录的要求。'),
(39806, 6510, 11, '有没有真品进入阿肯色州帐户 '),
(39807, 6511, 11, '有没有真品入境的现金帐户 '),
(39808, 6512, 11, '有没有真品入境的收入帐户 '),
(39809, 6513, 11, '目前没有耐心'),
(39810, 6515, 11, '没有匹配的发票编号'),
(39811, 6516, 11, '没有匹配的发票编号= '),
(39812, 6517, 11, '没有任何部分进入服务编号 '),
(39813, 6520, 11, '时发生错误处理您的请求。'),
(39814, 6523, 11, '增厚的权利：'),
(39815, 6524, 11, '大腿'),
(39816, 6525, 11, '大腿+腿筋'),
(39817, 6527, 11, '办公室人员可以阅读和输入但不能修改'),
(39818, 6528, 11, '办公室人员可以读取和修改'),
(39819, 6531, 11, '医生可以阅读和输入但不能修改'),
(39820, 6532, 11, '医生可以读取和修改'),
(39821, 6535, 11, '前台可以读取和修改'),
(39822, 6536, 11, '前台可以读取和修改');
INSERT INTO `lang_definitions` VALUES
(39823, 6539, 11, '医生可以阅读和输入但不能修改'),
(39824, 6540, 11, '医生可以读取和修改的东西'),
(39825, 6542, 11, '第三'),
(39826, 6544, 11, '此操作无法撤消。'),
(39827, 6545, 11, '此操作无法撤消。'),
(39828, 6547, 11, '这一行动将被记录'),
(39829, 6551, 11, '本历年'),
(39830, 6554, 11, '这个要求被拒绝的原因：—'),
(39831, 6555, 11, '这种说法已被转发到下一个水平。'),
(39832, 6556, 11, '此代码类型不接受关系。'),
(39833, 6557, 11, '这方面包含类别，它将被删除。你还想继续吗？'),
(39834, 6558, 11, '这是显示在日历约会。'),
(39835, 6559, 11, '这一决定哪些颜色模式用于预约'),
(39836, 6561, 11, '此次治疗'),
(39837, 6565, 11, '这个功能是非常实验和测试的不完全。使用你自己的风险！'),
(39838, 6566, 11, '这发票号码已变更为 '),
(39839, 6575, 11, '该模块在测试模式。该数据库将不会改变。'),
(39840, 6576, 11, '此模块促进有效入境EOB数据。'),
(39841, 6577, 11, '本月迄今'),
(39842, 6581, 11, '本页将内联包括登录页面，这样我们就不必每次点击重新登录。'),
(39843, 6582, 11, '这个客户没有活动。'),
(39844, 6583, 11, '这名患者已在使用中！'),
(39845, 6584, 11, '本产品只允许一个多每个仓库。'),
(39846, 6591, 11, '这一步将生成一个文件，你必须保存以供将来使用。不能将文件重新生成。你想继续吗？'),
(39847, 6592, 11, '这个用户不属于任何团体'),
(39848, 6595, 11, '这次门诊，开始新的避孕药具的使用'),
(39849, 6596, 11, '这将需要一个亚洲电玩研讨会的形式，转诊或服务的程序。'),
(39850, 6597, 11, '这是老年metric-only命脉，现在已不再使用。'),
(39851, 6598, 11, '本周迄今'),
(39852, 6600, 11, '这将启动重整（连续照护纪录）和（连续性的护理文件）报告。'),
(39853, 6602, 11, '这将允许选择调试（''dummy ''）语言。'),
(39854, 6606, 11, '这将创建一个备份中焦油的格式和发送到您的网页浏览器，这样你可以保存它'),
(39855, 6607, 11, '这将关闭文件的加密和解密功能，并隐藏他们的用户界面。'),
(39856, 6613, 11, '这将迫使计费部件在客户摘要屏幕总是开。'),
(39857, 6617, 11, '这将不会阻止你去网站的电子处方。'),
(39858, 6619, 11, '这将使用自定义免疫表而非标准雪佛龙免疫列表。'),
(39859, 6622, 11, '胸椎'),
(39860, 6623, 11, 'thous / CU.MM'),
(39861, 6625, 11, '咽喉'),
(39862, 6626, 11, '咽喉癌'),
(39863, 6627, 11, '咽喉癌手术'),
(39864, 6628, 11, '血栓/中风'),
(39865, 6629, 11, '星期四'),
(39866, 6630, 11, 'Thurdsay'),
(39867, 6631, 11, '星期四'),
(39868, 6632, 11, '甲状腺正常'),
(39869, 6633, 11, '甲状腺问题'),
(39870, 6634, 11, '短暂性缺血性发作'),
(39871, 6636, 11, '一天三次'),
(39872, 6638, 11, '时间'),
(39873, 6639, 11, '时间显示格式'),
(39874, 6640, 11, '时间增量的添加（分钟1-60 ）'),
(39875, 6641, 11, '选择时间'),
(39876, 6647, 11, '时间事件'),
(39877, 6648, 11, '时报阵列（ ñ /解放军）'),
(39878, 6649, 11, '时间戳和文字'),
(39879, 6650, 11, '锡'),
(39880, 6651, 11, '耳鸣'),
(39881, 6652, 11, '标题'),
(39882, 6653, 11, '第五章'),
(39883, 6654, 11, '标题COLS必须是一个数字1和999之间'),
(39884, 6655, 11, '标题'),
(39885, 6656, 11, '商标的：'),
(39886, 6657, 11, '颅/季风/电子，外鼻'),
(39887, 6658, 11, '至'),
(39888, 6659, 11, '至'),
(39889, 6660, 11, '至'),
(39890, 6661, 11, '绝对路径的文件'),
(39891, 6662, 11, '添加注释，请点击 '),
(39892, 6663, 11, '添加注释，请点击这里'),
(39893, 6664, 11, '受影响的地区'),
(39894, 6665, 11, '受影响的地区'),
(39895, 6666, 11, '自动打开指定的形式。一些运动队在这里的足球损伤'),
(39896, 6667, 11, '帐单视图'),
(39897, 6668, 11, '类'),
(39898, 6669, 11, '临床视图'),
(39899, 6670, 11, '以共付额'),
(39900, 6672, 11, '涉足'),
(39901, 6673, 11, '到数字高程模型'),
(39902, 6674, 11, '禁用客户端证书，上述评论线配置文件和设置'),
(39903, 6675, 11, '禁用网页，评论上述线路配置文件并重新启动服务器。'),
(39904, 6676, 11, '使客户端证书'),
(39905, 6677, 11, '使客户端证书认证，HTTPS应启用。'),
(39906, 6678, 11, '为了使只有一块，执行上述改动并重新启动服务器。如果你想配置客户端证书，请配置在下一节。'),
(39907, 6679, 11, '为了Enctr'),
(39908, 6680, 11, '按性别过滤'),
(39909, 6681, 11, '历史'),
(39910, 6682, 11, '问题'),
(39911, 6683, 11, '链接这遭遇/咨询到现有的问题，单击 '),
(39912, 6684, 11, '链接这遭遇/咨询到现有的问题，单击所需的问题突出，然后点击[保留]。按住[控制]按钮来选择多个问题。'),
(39913, 6685, 11, '重新登录'),
(39914, 6686, 11, '记录披露，请点击'),
(39915, 6687, 11, '经营'),
(39916, 6688, 11, '安装网页门诊客户端证书认证，做以下'),
(39917, 6689, 11, '皮肤'),
(39918, 6690, 11, '皮肤'),
(39919, 6691, 11, '这次门诊？'),
(39920, 6693, 11, '到：'),
(39921, 6694, 11, '到： '),
(39922, 6695, 11, '到-城市'),
(39923, 6696, 11, '到-传真'),
(39924, 6697, 11, '到-名字'),
(39925, 6698, 11, '到-姓氏'),
(39926, 6699, 11, '到-中间名字'),
(39927, 6700, 11, '到-组织'),
(39928, 6703, 11, '到-邮政编码'),
(39929, 6704, 11, '到-省市'),
(39930, 6705, 11, '到-街道'),
(39931, 6706, 11, '到-标题'),
(39932, 6707, 11, '到-告别'),
(39933, 6708, 11, '烟草'),
(39934, 6709, 11, '戒烟干预'),
(39935, 6710, 11, '戒烟干预（CQM）'),
(39936, 6712, 11, '烟草使用'),
(39937, 6713, 11, '烟草的使用评估'),
(39938, 6714, 11, '烟草的使用评估（CQM）'),
(39939, 6715, 11, '今天'),
(39940, 6716, 11, '今天'),
(39941, 6717, 11, '今天'),
(39942, 6718, 11, '今天 平衡'),
(39943, 6719, 11, '今天''的指控'),
(39944, 6720, 11, '今天的日期'),
(39945, 6721, 11, '今天的活动'),
(39946, 6724, 11, '令牌编号为libreehr支持实验室交流服务有限责任公司。'),
(39947, 6726, 11, '扁桃体'),
(39948, 6728, 11, '顶端'),
(39949, 6730, 11, '专题'),
(39950, 6731, 11, '共计'),
(39951, 6732, 11, '总'),
(39952, 6733, 11, '活跃活动的总数'),
(39953, 6734, 11, '更新后主动提示的总数'),
(39954, 6735, 11, '更新前主动提示的总数'),
(39955, 6737, 11, '总金额'),
(39956, 6738, 11, '所支付的款项总额'),
(39957, 6741, 11, '总费用'),
(39958, 6742, 11, '共计客户'),
(39959, 6743, 11, '总成本'),
(39960, 6744, 11, '支票号分布不完整的总数'),
(39961, 6746, 11, '没有提示发送邮件的总数'),
(39962, 6747, 11, '没有提示发送电话的总数'),
(39963, 6748, 11, '共计'),
(39964, 6749, 11, '共计 '),
(39965, 6750, 11, '总类'),
(39966, 6751, 11, '不活跃挺行总数'),
(39967, 6752, 11, '新的提示总数'),
(39968, 6755, 11, '免疫接种的总数'),
(39969, 6756, 11, '问题总数'),
(39970, 6758, 11, '患者总数'),
(39971, 6760, 11, '全部客户的平衡'),
(39972, 6761, 11, '客户人数'),
(39973, 6764, 11, '找到记录总数'),
(39974, 6765, 11, '共计生殖健康与计划生育'),
(39975, 6766, 11, '总成功的提示通过电子邮件发送'),
(39976, 6767, 11, '总的成功提醒发送通过电话'),
(39977, 6770, 11, '全不变的提醒'),
(39978, 6771, 11, '总发送提醒后，发送进程'),
(39979, 6772, 11, '总发送提醒后更新'),
(39980, 6773, 11, '总发送前提醒发送过程'),
(39981, 6774, 11, '总发送提醒前更新'),
(39982, 6775, 11, '完全更新提醒'),
(39983, 6776, 11, '总计'),
(39984, 6777, 11, '总计'),
(39985, 6778, 11, '总计 '),
(39986, 6785, 11, '培训类型'),
(39987, 6786, 11, '交易'),
(39988, 6787, 11, '交易'),
(39989, 6788, 11, '交易'),
(39990, 6789, 11, '交易失败，数量不足，在目的地的地段'),
(39991, 6790, 11, '交易失败，量小于0'),
(39992, 6791, 11, '交易类型'),
(39993, 6792, 11, '交易'),
(39994, 6793, 11, '交易'),
(39995, 6794, 11, '交易（写可选）'),
(39996, 6795, 11, '交易/推介'),
(39997, 6797, 11, '转换'),
(39998, 6799, 11, '传输失败，数量不足源地段'),
(39999, 6804, 11, '转换'),
(40000, 6806, 11, '过渡/转让照顾？'),
(40001, 6807, 11, '翻译的门诊控制组'),
(40002, 6808, 11, '翻译任用类别'),
(40003, 6809, 11, '翻译文件'),
(40004, 6810, 11, '翻译布局'),
(40005, 6811, 11, '翻译表'),
(40006, 6812, 11, '客户注意标题的翻译'),
(40007, 6813, 11, '把这种'),
(40008, 6814, 11, '翻译'),
(40009, 6815, 11, '翻译'),
(40010, 6819, 11, '外伤'),
(40011, 6820, 11, '治疗'),
(40012, 6822, 11, '治疗目标'),
(40013, 6823, 11, '治疗方案'),
(40014, 6826, 11, '治疗：'),
(40015, 6827, 11, '治疗： '),
(40016, 6828, 11, '趋势'),
(40017, 6829, 11, 'trftime（$ month_format，mktime（0，0，0，1，2000美元，month_value美元）））；'),
(40018, 6830, 11, '触发点/隔综合征/ DOMS /抽筋'),
(40019, 6831, 11, '三踝'),
(40020, 6832, 11, '躯干和腹部'),
(40021, 6837, 11, '小勺'),
(40022, 6839, 11, '语音合成'),
(40023, 6840, 11, '结核病'),
(40024, 6841, 11, '星期二'),
(40025, 6842, 11, '星期二及星期四'),
(40026, 6843, 11, '星期二'),
(40027, 6844, 11, '肿瘤'),
(40028, 6845, 11, '土耳其语'),
(40029, 6848, 11, '每天两次'),
(40030, 6850, 11, '鼓膜'),
(40031, 6851, 11, '类型'),
(40032, 6852, 11, '类型标识或名称。最少3个字符（包括空格）。'),
(40033, 6853, 11, '列类型显示客户的搜索结果'),
(40034, 6854, 11, '披露的类型'),
(40035, 6855, 11, '事件类型'),
(40036, 6856, 11, '类型的屏幕布局'),
(40037, 6857, 11, '输入或扫描客户标识符这里'),
(40038, 6858, 11, '在这里键入您的消息'),
(40039, 6859, 11, '指令的类型和结果'),
(40040, 6864, 11, 'UCSMC代码提供了卡尔加里大学运动医学中心'),
(40041, 6865, 11, '乌克兰语'),
(40042, 6866, 11, '溃疡'),
(40043, 6867, 11, '溃疡性结肠炎'),
(40044, 6868, 11, '溃疡：'),
(40045, 6871, 11, '无法创建'),
(40046, 6876, 11, '未使用'),
(40047, 6877, 11, '未指定'),
(40048, 6879, 11, '未经授权的门诊到e处方'),
(40049, 6880, 11, '未经授权的门诊。'),
(40050, 6882, 11, '未入账只有'),
(40051, 6884, 11, '根据舌'),
(40052, 6885, 11, '重量不足'),
(40053, 6886, 11, '确诊'),
(40054, 6887, 11, '未分配'),
(40055, 6888, 11, '未分配'),
(40056, 6889, 11, '未分配是'),
(40057, 6890, 11, '撤消结帐'),
(40058, 6892, 11, '独特的客户'),
(40059, 6893, 11, '这种独特的人类可读的标识符'),
(40060, 6894, 11, '独特的新客户'),
(40061, 6895, 11, '这种独特的数字标识符'),
(40062, 6896, 11, '独特的看客户'),
(40063, 6897, 11, '独特的看客户的报告'),
(40064, 6898, 11, '独特的警司'),
(40065, 6899, 11, '股'),
(40066, 6900, 11, '单位'),
(40067, 6901, 11, '单位'),
(40068, 6903, 11, '门诊表格单位'),
(40069, 6904, 11, '单位必须是一个数字'),
(40070, 6905, 11, '没有定义单位'),
(40071, 6906, 11, '单位/升'),
(40072, 6907, 11, '未知'),
(40073, 6910, 11, '未知是否吸烟'),
(40074, 6911, 11, '未知或N /阿'),
(40075, 6913, 11, '没有联系的客户'),
(40076, 6914, 11, '无名保险公司'),
(40077, 6915, 11, '未注册'),
(40078, 6918, 11, '取消所有选择'),
(40079, 6919, 11, '反选'),
(40080, 6920, 11, '不确定'),
(40081, 6921, 11, '非结构化'),
(40082, 6924, 11, '直到'),
(40083, 6925, 11, '过早备案'),
(40084, 6926, 11, '未使用'),
(40085, 6927, 11, '非正常事件报告'),
(40086, 6928, 11, '最多'),
(40087, 6929, 11, '即将到来的约会'),
(40088, 6930, 11, '即将举行的活动'),
(40089, 6931, 11, '更新'),
(40090, 6932, 11, '更新'),
(40091, 6933, 11, '主动更新'),
(40092, 6934, 11, '更新文件'),
(40093, 6935, 11, '更新信息'),
(40094, 6936, 11, '更新列表'),
(40095, 6937, 11, '更新服务提供者号码'),
(40096, 6938, 11, '更新选定项目'),
(40097, 6939, 11, '更新下列文件中的变数'),
(40098, 6940, 11, '更新用户资料'),
(40099, 6942, 11, '更新人口统计未授权'),
(40100, 6946, 11, '升级'),
(40101, 6947, 11, '升级数据库'),
(40102, 6948, 11, '升级libreehr数据库包括程序，功能和表所需的识别过程'),
(40103, 6949, 11, '升级将继续'),
(40104, 6950, 11, 'UPIN'),
(40105, 6951, 11, '上传'),
(40106, 6954, 11, '上传配置数据'),
(40107, 6955, 11, '上传文件'),
(40108, 6956, 11, '上传失败！'),
(40109, 6957, 11, '上传图片到'),
(40110, 6958, 11, '上传导入文件：'),
(40111, 6961, 11, '上传报告'),
(40112, 6963, 11, '上传此文件：'),
(40113, 6964, 11, '在点击发票号码“手动发布窗口”。在这里你可以更改日期和说明的发票，选择为你是谁张贴，并选择保险，所有预期的paymants已收到。最重要的是，对于每一个帐单代码的数量被指控，你可以进入巴勒斯坦权力机构'),
(40114, 6965, 11, '在搜索你提出一个清单，发票。你可以点击其中的发票号码，打开另一个窗口，数据输入页手工过帐。你也可以点击一个客户的名字，如果你想进入一个注意，前台的工作人员会看到当客户检查，你可以选择在发票上。'),
(40115, 6966, 11, '上臂'),
(40116, 6968, 11, '紧迫'),
(40117, 6970, 11, '尿液'),
(40118, 6971, 11, '尿不尽'),
(40119, 6972, 11, '频尿'),
(40120, 6973, 11, '尿犹豫不决'),
(40121, 6974, 11, '尿微量白蛋白'),
(40122, 6975, 11, '尿流'),
(40123, 6976, 11, '尿急'),
(40124, 6977, 11, '网址'),
(40125, 6979, 11, 'LibreEHR支持地址'),
(40126, 6981, 11, '电话网关。自动电话服务提供商maviq。门诊http://signup.maviq.com获得更多信息请门诊。'),
(40127, 6986, 11, '使用指标（isa15）'),
(40128, 6987, 11, '使用%单独在一场只是排序的列'),
(40129, 6988, 11, '使用24小时时间格式？'),
(40130, 6990, 11, '使用认证的电子病历技术识别特定的教育资源和提供这些资源的患者如果适当的。'),
(40131, 6991, 11, '使用收费小组'),
(40132, 6992, 11, '使用证据为药物的订单直接进入任何许可的医疗保健专业人士谁可以输入订单纳入医疗记录每个国家，地方和专业准则。'),
(40133, 6997, 11, '使用自定义免疫列表'),
(40134, 6999, 11, '使用日期范围'),
(40135, 7000, 11, '使用默认值'),
(40136, 7001, 11, '使用“删除”选项来删除。'),
(40137, 7002, 11, '利用国际最新的风格？'),
(40138, 7003, 11, '使用源文件名'),
(40139, 7004, 11, '使用域下购买或转让。'),
(40140, 7005, 11, '使用此功能只有新安装的网站， '),
(40141, 7006, 11, '使用主题？'),
(40142, 7007, 11, '用户'),
(40143, 7009, 11, '用户/组'),
(40144, 7010, 11, '用户管理'),
(40145, 7011, 11, '用户和基金管理'),
(40146, 7012, 11, '用户和组管理'),
(40147, 7014, 11, '用户证书验证被禁用'),
(40148, 7015, 11, '用户定义'),
(40149, 7016, 11, '用户定义的第11区'),
(40150, 7017, 11, '用户定义的第12区'),
(40151, 7018, 11, '用户定义字段'),
(40152, 7019, 11, '用户定义字段1'),
(40153, 7020, 11, '用户定义字段2'),
(40154, 7021, 11, '用户定义字段3'),
(40155, 7022, 11, '用户定义字段4'),
(40156, 7023, 11, '用户定义字段5'),
(40157, 7024, 11, '用户定义字段6'),
(40158, 7025, 11, '用户定义字段7'),
(40159, 7026, 11, '用户定义文本1'),
(40160, 7027, 11, '用户定义文本2'),
(40161, 7028, 11, '用户定义文本3'),
(40162, 7029, 11, '用户定义文本4'),
(40163, 7030, 11, '用户定义文本5'),
(40164, 7031, 11, '用户定义文本6'),
(40165, 7032, 11, '用户定义文本7'),
(40166, 7033, 11, '用户定义文本8'),
(40167, 7034, 11, '用户名字'),
(40168, 7039, 11, '用户手册'),
(40169, 7040, 11, '用户会员资格'),
(40170, 7041, 11, '用户名'),
(40171, 7042, 11, '用户名或主机名不能为空'),
(40172, 7043, 11, '用户和主机名'),
(40173, 7046, 11, '用户设置'),
(40174, 7047, 11, '用户特定设置'),
(40175, 7049, 11, '用户名'),
(40176, 7051, 11, '用户名电话网关。自动电话服务提供maviq。http://signup.maviq.com更多信息请门诊。'),
(40177, 7052, 11, '用户的短信网关'),
(40178, 7053, 11, '用户名的短信网关。'),
(40179, 7055, 11, '用户名：'),
(40180, 7056, 11, '用户'),
(40181, 7057, 11, '用户/组/日志管理'),
(40182, 7058, 11, '使用的PHP的<a href="http://php.net/strftime">它将“ / 1 ”的格式'),
(40183, 7059, 11, 'UTIs'),
(40184, 7062, 11, '假期'),
(40185, 7063, 11, '假期'),
(40186, 7064, 11, '疫苗'),
(40187, 7065, 11, '阴道环'),
(40188, 7066, 11, '告别'),
(40189, 7067, 11, '证实'),
(40190, 7068, 11, '值'),
(40191, 7069, 11, '值1'),
(40192, 7070, 11, '值2'),
(40193, 7072, 11, '值应该是数字'),
(40194, 7073, 11, '变数1'),
(40195, 7074, 11, '变数2'),
(40196, 7075, 11, '变量到一个跑去识别升级脚本'),
(40197, 7076, 11, '水痘1'),
(40198, 7077, 11, '水痘2'),
(40199, 7078, 11, '静脉曲张'),
(40200, 7079, 11, '血管条件'),
(40201, 7080, 11, '血管损伤'),
(40202, 7081, 11, '血管外科手术'),
(40203, 7083, 11, '供应商'),
(40204, 7084, 11, '版本'),
(40205, 7085, 11, '头晕'),
(40206, 7086, 11, '退伍军人管理'),
(40207, 7087, 11, '退伍军人管理局计划'),
(40208, 7088, 11, '心室功能曲线'),
(40209, 7089, 11, '越南人'),
(40210, 7090, 11, '查看'),
(40211, 7091, 11, '查看'),
(40212, 7092, 11, '查看过敏'),
(40213, 7097, 11, '查看综合客户报告'),
(40214, 7100, 11, '查看文档'),
(40215, 7101, 11, '查看治疗'),
(40216, 7103, 11, '鉴于事件的弹出一个窗口？'),
(40217, 7107, 11, '查看日志'),
(40218, 7108, 11, '第1页'),
(40219, 7109, 11, '第2页'),
(40220, 7110, 11, '查看过去和未来提醒'),
(40221, 7111, 11, '查看客户'),
(40222, 7116, 11, '查看相关的遭遇'),
(40223, 7121, 11, '查看/编辑过敏'),
(40224, 7122, 11, '查看/编辑问题'),
(40225, 7123, 11, '查看/打印'),
(40226, 7124, 11, '查看：'),
(40227, 7125, 11, '签证'),
(40228, 7126, 11, 'VISA卡/ MC / AMEX / DIS'),
(40229, 7127, 11, '内脏损害/损伤/外科手术'),
(40230, 7133, 11, '门诊类别：'),
(40231, 7134, 11, '门诊日期'),
(40232, 7135, 11, '门诊日期'),
(40233, 7137, 11, '门诊表格'),
(40234, 7138, 11, '门诊历史'),
(40235, 7140, 11, '门诊'),
(40236, 7141, 11, '门诊'),
(40237, 7142, 11, '健康状况征兆'),
(40238, 7143, 11, '要害'),
(40239, 7144, 11, '生命迹象（公制）'),
(40240, 7146, 11, '语音'),
(40241, 7147, 11, '语音发送'),
(40242, 7149, 11, '吐'),
(40243, 7151, 11, 'W'),
(40244, 7152, 11, '腰围'),
(40245, 7153, 11, '腰围'),
(40246, 7154, 11, '等待'),
(40247, 7155, 11, '门市'),
(40248, 7157, 11, '沃尔特·彭宁顿'),
(40249, 7158, 11, '仓库'),
(40250, 7159, 11, '仓库最大，0不适用'),
(40251, 7160, 11, '仓库最低，0不适用'),
(40252, 7161, 11, '仓库'),
(40253, 7162, 11, '暖和'),
(40254, 7163, 11, '警告'),
(40255, 7164, 11, '警告'),
(40256, 7166, 11, '警告，支票号码已经存在于数据库中'),
(40257, 7168, 11, '警告：门诊已创建的这个客户今天！'),
(40258, 7170, 11, '警告：客户的ID是不是唯一的！'),
(40259, 7171, 11, '警告：这将覆盖配置信息和数据的上传的文件！'),
(40260, 7173, 11, '警告'),
(40261, 7175, 11, '已上传'),
(40262, 7177, 11, '我们感谢及时付款的余额到期'),
(40263, 7178, 11, '我们已经看到你的上述客户的评估和治疗的门诊精神病诊所。感谢你为这个转诊。'),
(40264, 7179, 11, '软弱'),
(40265, 7181, 11, '网页搜索'),
(40266, 7182, 11, '网站'),
(40267, 7183, 11, '上门客户门户网站的链接。'),
(40268, 7184, 11, '星期三'),
(40269, 7185, 11, '星期三'),
(40270, 7186, 11, '周'),
(40271, 7187, 11, '周'),
(40272, 7188, 11, '周视图'),
(40273, 7189, 11, '本周（县）'),
(40274, 7190, 11, '周刊披露'),
(40275, 7192, 11, '周'),
(40276, 7193, 11, '体重'),
(40277, 7194, 11, '体重评估和辅导的儿童和青少年'),
(40278, 7195, 11, '体重评估和辅导的儿童和青少年（CQM）'),
(40279, 7196, 11, '体重变化'),
(40280, 7197, 11, '体重减轻'),
(40281, 7198, 11, '减肥诊所'),
(40282, 7199, 11, '欢迎'),
(40283, 7202, 11, '怎么计算？'),
(40284, 7203, 11, '哮鸣音：'),
(40285, 7204, 11, '哮喘'),
(40286, 7205, 11, '哮喘：'),
(40287, 7208, 11, '凡可能相关的纸质文件扫描或发现？'),
(40288, 7209, 11, '有无保险'),
(40289, 7212, 11, '白色'),
(40290, 7213, 11, '个人资料'),
(40291, 7214, 11, '谁回答？'),
(40292, 7215, 11, '丧偶'),
(40293, 7216, 11, '宽度'),
(40294, 7217, 11, '在像素宽度的左侧导航框架。'),
(40295, 7221, 11, '随着选择'),
(40296, 7222, 11, '与旧名称'),
(40297, 7224, 11, '其中我们可以留个口信吗？'),
(40298, 7225, 11, '隐瞒'),
(40299, 7226, 11, '在几个小时内'),
(40300, 7227, 11, '在几个小时内：'),
(40301, 7228, 11, '几分钟之内'),
(40302, 7229, 11, '几分钟之内：'),
(40303, 7232, 11, '没有更新'),
(40304, 7233, 11, '证人'),
(40305, 7234, 11, '周'),
(40306, 7235, 11, '在正常范围内'),
(40307, 7237, 11, '妇女'),
(40308, 7238, 11, '只有妇女'),
(40309, 7240, 11, '工作'),
(40310, 7241, 11, '工作说明'),
(40311, 7242, 11, '工作电话'),
(40312, 7243, 11, '工作电话'),
(40313, 7244, 11, '有关的工作？'),
(40314, 7245, 11, '工作/教育/爱好'),
(40315, 7246, 11, '工作/学校请注意'),
(40316, 7247, 11, '工作日'),
(40317, 7248, 11, '工人的补偿`'),
(40318, 7249, 11, '工人赔偿健康计划'),
(40319, 7250, 11, '工作年龄的受益人或配偶单位团体健康计划'),
(40320, 7252, 11, '更坏'),
(40321, 7253, 11, '你会喜欢平衡量适用于全局账户？'),
(40322, 7254, 11, '你会喜欢它们被标记为清除。'),
(40323, 7255, 11, '你想分配？'),
(40324, 7256, 11, '你愿意取消分配为客户？'),
(40325, 7257, 11, '你想删除分配？'),
(40326, 7258, 11, '要删除吗？'),
(40327, 7259, 11, '你想修改并完成付款？'),
(40328, 7260, 11, '你想修改付款？'),
(40329, 7261, 11, '你想完成付款？'),
(40330, 7262, 11, '你想付款？'),
(40331, 7263, 11, '你想保存？'),
(40332, 7264, 11, '手腕'),
(40333, 7265, 11, '手腕和手'),
(40334, 7266, 11, '手腕问题'),
(40335, 7267, 11, '写'),
(40336, 7268, 11, '注销'),
(40337, 7270, 11, 'wsome'),
(40338, 7271, 11, '重量'),
(40339, 7273, 11, 'X取消'),
(40340, 7274, 11, 'X取消'),
(40341, 7275, 11, '透视'),
(40342, 7276, 11, 'X射线释义：'),
(40343, 7277, 11, 'X射线释义：'),
(40344, 7278, 11, 'X12只：更换索赔 '),
(40345, 7279, 11, 'X12合作伙伴'),
(40346, 7280, 11, 'X12合作伙伴'),
(40347, 7284, 11, '年'),
(40348, 7285, 11, '年'),
(40349, 7286, 11, '年'),
(40350, 7287, 11, '今年查看'),
(40351, 7288, 11, '年份'),
(40352, 7289, 11, '岁'),
(40353, 7292, 11, '是'),
(40354, 7293, 11, '是'),
(40355, 7294, 11, '是'),
(40356, 7295, 11, '是！'),
(40357, 7296, 11, '是，删除和注销'),
(40358, 7298, 11, '是/否'),
(40359, 7299, 11, '是：'),
(40360, 7300, 11, '意第绪语'),
(40361, 7303, 11, '你将永久替换现有的模板。你确定你希望继续吗？'),
(40362, 7304, 11, '你在宽限登录时间。更改密码之前'),
(40363, 7305, 11, '您不可以删除此活动'),
(40364, 7306, 11, '不允许您编辑此事件'),
(40365, 7307, 11, '您未获授权的。'),
(40366, 7308, 11, '你没有被授权进入这个小队。'),
(40367, 7309, 11, '你没有被授权添加/编辑问题'),
(40368, 7310, 11, '你没有被授权安排约会。'),
(40369, 7311, 11, '你没有被授权看到这样的治疗。'),
(40370, 7313, 11, '您不能使用此功能直接。'),
(40371, 7314, 11, '您无法直接门诊此页。'),
(40372, 7315, 11, '您无法添加一个空白的价值范畴！'),
(40373, 7316, 11, '您无法添加一个空白的价值分类！'),
(40374, 7317, 11, '您无法添加一个空白的项目！'),
(40375, 7318, 11, '你不能进入一个将来的日期与完成的价值，是的。'),
(40376, 7319, 11, '你没有选择任何行动。'),
(40377, 7320, 11, '您没有权限查看/编辑笔记'),
(40378, 7321, 11, '你试图改变内容是锁定的。如果你想这样做，清解锁。解锁删除线'),
(40379, 7322, 11, '你已经登出。'),
(40380, 7323, 11, '你可能只是文件上传。'),
(40381, 7325, 11, '你可以把这里作为默认的投诉在新客户遇到形式。'),
(40382, 7326, 11, '你必须输入一个密码来加密文件'),
(40383, 7329, 11, '您必须先选择或添加一个客户。'),
(40384, 7330, 11, '您必须先选择或创建一个遇到。'),
(40385, 7331, 11, '你必须选择一个门诊类'),
(40386, 7332, 11, '你必须选择一个门诊类。'),
(40387, 7333, 11, '你必须选择一些领域继续。'),
(40388, 7334, 11, '你应该运行这个测试如果这个说法似乎产生成功但实际索赔文件不包含任何数据或只有一个未完成的部分的数据量，它应该包含。这是明显的医疗卫生融资声称因为他们是人类可读的X 12声称它是一个艰难的过程来确定是否'),
(40389, 7335, 11, '你必须至少选择一个背景'),
(40390, 7336, 11, '你必须至少选择一个服务人员'),
(40391, 7339, 11, '您的结束日期无效'),
(40392, 7340, 11, '您的活动已被删除。'),
(40393, 7341, 11, '您的活动已被修改。'),
(40394, 7342, 11, '您的活动已提交。'),
(40395, 7343, 11, '你的文件太大'),
(40396, 7345, 11, '你的名单上的名字已改为符合命名要求。'),
(40397, 7347, 11, '你的名字为这类程序或结果”'),
(40398, 7349, 11, '您的密码已过期。请更改您的密码。'),
(40399, 7350, 11, '您的密码过期'),
(40400, 7351, 11, '您的密码今天到期。请更改您的密码。'),
(40401, 7353, 11, '您PostCalendar配置已重置为使用默认值。'),
(40402, 7354, 11, '您PostCalendar配置已更新。'),
(40403, 7355, 11, '您的重复频率必须是整数。'),
(40404, 7356, 11, '您的重复频率必须至少为1 。'),
(40405, 7357, 11, '您的开始日期大于结束日期'),
(40406, 7358, 11, '您的开始日期是无效的'),
(40407, 7359, 11, '您提交失败。'),
(40408, 7360, 11, '格式年 - 月 -日'),
(40409, 7361, 11, '年-月-日'),
(40410, 7362, 11, '日期与此相关的文件（年 - 月 -日）'),
(40411, 7363, 11, '销毁日期（年 - 月 -日）'),
(40412, 7364, 11, '出生日期（年 - 月 -日）'),
(40413, 7365, 11, '出生日期（年 - 月 -日）'),
(40414, 7366, 11, '截止日期（年 - 月 -日）'),
(40415, 7367, 11, '发病日期或住院（年 - 月 -日）'),
(40416, 7368, 11, '发病日期（年 - 月 -日）'),
(40417, 7369, 11, '购买或者转让日期（年 - 月 -日）'),
(40418, 7370, 11, '恢复或结尾的药物起始日（年 - 月 -日）'),
(40419, 7371, 11, '返回日期发挥（年 - 月 -日）'),
(40420, 7372, 11, '送达日期（年 - 月 -日）'),
(40421, 7373, 11, '本函之日起（年 - 月 -日）'),
(40422, 7374, 11, '返回日期发挥（年 - 月 -日）'),
(40423, 7375, 11, '文件日期（年 - 月 -日）'),
(40424, 7376, 11, '活动日期或开始日期（年 - 月 -日）'),
(40425, 7381, 11, '年-月-日 时：分：秒'),
(40426, 7383, 11, '事件最后日期（年 - 月 -日）'),
(40427, 7387, 11, '零'),
(40428, 7389, 11, '邮编'),
(40429, 7390, 11, '邮编'),
(40430, 7391, 11, '邮编/国家：'),
(40431, 7392, 11, '祖鲁语'),
(40432, 7393, 11, ' 但却是 '),
(40433, 7394, 11, ' 不允许门诊'),
(40434, 7395, 11, '你真的想删除吗'),
(40435, 7396, 11, '药品'),
(40436, 7397, 11, '邮件没有送出'),
(40437, 7398, 11, '从'),
(40438, 7399, 11, '已创建 '),
(40439, 7400, 11, '已重新打开'),
(40440, 7401, 11, '历史'),
(40441, 7402, 11, '不是一个数字'),
(40442, 7403, 11, '可以重新送帐单了'),
(40443, 7404, 11, '左肺下叶'),
(40444, 7405, 11, '很多'),
(40445, 7406, 11, '医疗补助原始参考号码 '),
(40446, 7407, 11, '最小'),
(40447, 7408, 11, '没有找到'),
(40448, 7409, 11, '特点在许多浏览器可能意味着输出下面进入你的屏幕突然抽搐，有长时间的停顿几秒钟，它似乎事情可能坠毁。不是这样的，你最终会看到输出了一行行。有可能是连续的数字出现如下，这是表明，即使没有其他可显示有活动。这些数字会穿插内容的计费，这是正常的。'),
(40449, 7410, 11, '药方已达到限度'),
(40450, 7411, 11, '直到'),
(40451, 7412, 11, '更新失败，不是在数据库？'),
(40452, 7413, 11, '被标记为只送了帐单'),
(40453, 7414, 11, '被成功加入队列'),
(40454, 7415, 11, '! 没门诊就离开'),
(40455, 7417, 11, '" 记录在公布日历的配置中'),
(40456, 7418, 11, '# 保险/财务问题'),
(40457, 7419, 11, '片剂：'),
(40458, 7420, 11, '$'),
(40459, 7421, 11, '$ 已编好号'),
(40460, 7422, 11, '$标签（yyyy-mm-dd）： '),
(40461, 7423, 11, '%'),
(40462, 7424, 11, '% 已取消 < 24小时'),
(40463, 7425, 11, '% 已取消 < 24小时 '),
(40464, 7426, 11, '应该存在，但是不存在'),
(40465, 7427, 11, '_ matches any character)'),
(40466, 7428, 11, '（[ctrl]+单击选择更多收件人）'),
(40467, 7429, 11, '（返回）'),
(40468, 7430, 11, '（点击编辑）'),
(40469, 7431, 11, '（电子邮件立即送货，而自动电话发送到服务提供商进一步处理。）'),
(40470, 7432, 11, '（更多）'),
(40471, 7433, 11, '(新客户)'),
(40472, 7434, 11, '(备注和授权)'),
(40473, 7435, 11, '(客户备注)'),
(40474, 7436, 11, 'or type your own title)'),
(40475, 7437, 11, '（Shift）单机或拖动改变值'),
(40476, 7438, 11, '* 提醒'),
(40477, 7439, 11, '** 请将手术移到问题！'),
(40478, 7440, 11, '*要求的'),
(40479, 7441, 11, '+图表展开了'),
(40480, 7442, 11, '-空'),
(40481, 7445, 11, '.'),
(40482, 7446, 11, '0'),
(40483, 7447, 11, '0-10'),
(40484, 7448, 11, '0-24'),
(40485, 7451, 11, '1'),
(40486, 7452, 11, '1=北美。查看其它国家或地区请门诊 http://www.wtng.info/'),
(40487, 7453, 11, '从现在起一天'),
(40488, 7454, 11, '从现在起一个月'),
(40489, 7455, 11, '从现在起一周'),
(40490, 7456, 11, '从现在起一年'),
(40491, 7457, 11, '其余的2 1。冰天3。压缩，离开敷料除非脚发展麻木或苍白色4。提高脚和腿'),
(40492, 7458, 11, '11-14'),
(40493, 7459, 11, '12小時'),
(40494, 7460, 11, '15-19'),
(40495, 7462, 11, '2'),
(40496, 7463, 11, '从现在起两天'),
(40497, 7464, 11, '从现在起两个月'),
(40498, 7465, 11, '从现在起两周'),
(40499, 7466, 11, '从现在起两年'),
(40500, 7468, 11, '20-24'),
(40501, 7477, 11, '2011-13'),
(40502, 7478, 11, '24小时'),
(40503, 7479, 11, '25+'),
(40504, 7480, 11, '25-29'),
(40505, 7481, 11, '第二'),
(40506, 7482, 11, '从现在起三天'),
(40507, 7483, 11, '三个月'),
(40508, 7484, 11, '从现在起三个月'),
(40509, 7485, 11, '每天三次'),
(40510, 7486, 11, '从现在三周'),
(40511, 7487, 11, '30-34'),
(40512, 7488, 11, '35-39'),
(40513, 7489, 11, '第三'),
(40514, 7490, 11, '从现在起四天'),
(40515, 7491, 11, '四个月'),
(40516, 7492, 11, '从现在起四个月'),
(40517, 7493, 11, '每天四次'),
(40518, 7494, 11, '从现在四周'),
(40519, 7495, 11, '40-44'),
(40520, 7496, 11, '45+'),
(40521, 7497, 11, '465.9，上呼吸道感染'),
(40522, 7498, 11, '466.0，支氣管炎，急性一氧化氮合酶'),
(40523, 7499, 11, '486.0，肺炎，急性'),
(40524, 7500, 11, '491.21，慢性阻塞性肺病加重'),
(40525, 7501, 11, '491.8，支氣管炎，慢性'),
(40526, 7502, 11, '493.92，哮喘，急性惡化。'),
(40527, 7503, 11, '496.0，慢性阻塞性肺病'),
(40528, 7504, 11, '第四'),
(40529, 7505, 11, '从现在起五天'),
(40530, 7506, 11, '从现在起五个月'),
(40531, 7507, 11, '从现在起五周'),
(40532, 7508, 11, 'Bronchospasm'),
(40533, 7509, 11, '第五'),
(40534, 7510, 11, '从现在起六天'),
(40535, 7511, 11, '六个月'),
(40536, 7512, 11, '从现在起六个月'),
(40537, 7513, 11, '从现在起六周'),
(40538, 7514, 11, '第六'),
(40539, 7515, 11, '从现在起七个月'),
(40540, 7516, 11, '从现在起八个月'),
(40541, 7517, 11, '824.0骨折，內踝，閉鎖性'),
(40542, 7518, 11, '824.2骨折，外踝，閉鎖性'),
(40543, 7519, 11, '824.6骨折，三踝，閉鎖性'),
(40544, 7520, 11, '825.32骨折，舟（脚踝）'),
(40545, 7521, 11, '825.35骨折，第五跖骨基地（第五）'),
(40546, 7522, 11, '845.00 踝关节扭伤 NOS'),
(40547, 7523, 11, '845.00 踝关节三角韧带扭伤'),
(40548, 7524, 11, '845.02扭伤，跟骨腓骨'),
(40549, 7525, 11, '从现在起九个月'),
(40550, 7526, 11, '99212 已建立 - 简单的'),
(40551, 7527, 11, '99213 已建立 - 低复杂度'),
(40552, 7528, 11, '< 在检查室'),
(40553, 7529, 11, '>已结帐'),
(40554, 7531, 11, '? 没显示'),
(40555, 7532, 11, '@ 已到达'),
(40556, 7533, 11, '[转换显示]'),
(40557, 7534, 11, '[上一次看诊的日期]'),
(40558, 7535, 11, '[离上一次看诊的天数]'),
(40559, 7537, 11, '[导出OFX格式]'),
(40560, 7538, 11, '[不推荐]'),
(40561, 7539, 11, '[看诊的次数]'),
(40562, 7540, 11, '[报告]'),
(40563, 7541, 11, '[选择所有]'),
(40564, 7542, 11, '[数据库总帐]'),
(40565, 7543, 11, '[开始批量处理]'),
(40566, 7544, 11, '[查看记录]'),
(40567, 7545, 11, '[查看可打印的报告]'),
(40568, 1, 12, '一'),
(40569, 2, 12, '一個支票或申索號碼 用來查詢付款'),
(40570, 3, 12, '一個管理員用戶的客戶端證書'),
(40571, 7, 12, '需要一個經銷商'),
(40572, 8, 12, '一個GCAC參訪表格應該增加到這次的參訪'),
(40573, 9, 12, '需要很多的數字'),
(40574, 10, 12, '需要很多的數字﹗'),
(40575, 11, 12, '一個小寫字母'),
(40576, 12, 12, '一個數字'),
(40577, 14, 12, '一位有這個身分證的病人已經存在'),
(40578, 15, 12, '一位有這個名字的病人已經存在'),
(40579, 16, 12, '一位有這種沙門氏-志賀氏桿菌的病人已經存在'),
(40580, 19, 12, '每次訪問，可以指定轉介來源。'),
(40581, 20, 12, '需要一個相關國際計劃生育聯合會的代碼！'),
(40582, 21, 12, '特性'),
(40583, 22, 12, '一個獨特的價值來辨認此領域，使用者不可看見'),
(40584, 24, 12, 'a.c.'),
(40585, 25, 12, '上午'),
(40586, 26, 12, 'A/F Level右側：'),
(40587, 27, 12, '不正常 流產'),
(40588, 28, 12, '縮寫'),
(40589, 29, 12, '膿瘍'),
(40590, 30, 12, '腹部的'),
(40591, 31, 12, '能夠承受重量4個步驟：'),
(40592, 32, 12, '異常的'),
(40593, 33, 12, '不正常1'),
(40594, 34, 12, '不正常'),
(40595, 35, 12, '不正常的血液測試'),
(40596, 36, 12, '不正常的頭髮生長'),
(40597, 37, 12, '不正常的乳房攝影'),
(40598, 39, 12, '流產'),
(40599, 40, 12, '流產議題'),
(40600, 41, 12, '流產方法'),
(40601, 42, 12, '與流產有關的類別'),
(40602, 43, 12, '墮胎'),
(40603, 44, 12, '關於日曆'),
(40604, 46, 12, '診斷為失神'),
(40605, 47, 12, '接受指派'),
(40606, 49, 12, '接受付款為 '),
(40607, 50, 12, '接受指派 承擔任務'),
(40608, 51, 12, '存取控制'),
(40609, 52, 12, '存取控制表管理'),
(40610, 56, 12, '進入你的病人入口網站'),
(40611, 59, 12, '帳目名稱'),
(40612, 62, 12, '會計'),
(40613, 64, 12, '疼痛'),
(40614, 65, 12, '確認要求（ISA14）'),
(40615, 67, 12, '前十字韌帶'),
(40616, 68, 12, '訪問控制列表管理'),
(40617, 69, 12, '未授權訪問控制列表管理'),
(40618, 71, 12, '粉刺'),
(40619, 72, 12, '行動'),
(40620, 73, 12, '行動日期'),
(40621, 74, 12, '行動'),
(40622, 75, 12, '行動'),
(40623, 77, 12, '啟動CCR/ CCD的報表'),
(40624, 78, 12, '活躍'),
(40625, 79, 12, '活躍戒備'),
(40626, 80, 12, '主動警示規則'),
(40627, 81, 12, '活耀戒備/提示'),
(40628, 82, 12, '積極接觸 活躍遭遇'),
(40629, 84, 12, '活躍名單'),
(40630, 85, 12, '活躍患者'),
(40631, 86, 12, '活躍計畫'),
(40632, 87, 12, '活動'),
(40633, 88, 12, '活動類型'),
(40634, 92, 12, '急性 慢性'),
(40635, 93, 12, '增加'),
(40636, 94, 12, '增加'),
(40637, 95, 12, '腺苷酸去氨碁酵素 注意力缺乏障礙'),
(40638, 96, 12, '增加一家公司'),
(40639, 98, 12, '增加一家藥房'),
(40640, 100, 12, '增加一個事件為了 '),
(40641, 101, 12, '加入一個新的說明'),
(40642, 102, 12, '增加就像是新的'),
(40643, 104, 12, '增加按鈕'),
(40644, 105, 12, '添加特殊字符的按鈕，文本將顯示在編輯器的頂部，為的是到文本上點擊'),
(40645, 106, 12, '增加類別'),
(40646, 107, 12, '增加常數'),
(40647, 108, 12, '增加上下文'),
(40648, 109, 12, '加入共付額'),
(40649, 110, 12, '新增條件'),
(40650, 111, 12, '增加習慣按鈕'),
(40651, 112, 12, '增加診斷'),
(40652, 113, 12, '增加藥物'),
(40653, 114, 12, '增加遭遇'),
(40654, 115, 12, '增加遭遇/筆記'),
(40655, 116, 12, '增加設施'),
(40656, 117, 12, '增加領域'),
(40657, 118, 12, '增加下列幾行到亞帕契印地安人配置檔案中'),
(40658, 119, 12, '增加小組'),
(40659, 120, 12, '增加國際疾病分類碼'),
(40660, 121, 12, '增加免疫'),
(40661, 123, 12, '增加議題'),
(40662, 125, 12, '增加語言'),
(40663, 126, 12, '增加新'),
(40664, 127, 12, '增加新'),
(40665, 128, 12, '增加新的類別﹕ '),
(40666, 129, 12, '增加新的證明到亞帕契印地安人配置檔案中'),
(40667, 132, 12, '增加新的小組'),
(40668, 134, 12, '增加很多新的合約'),
(40669, 135, 12, '增加新的註解'),
(40670, 136, 12, '增加新的註解'),
(40671, 137, 12, '增加新的夥伴'),
(40672, 140, 12, '增加註解'),
(40673, 141, 12, '增加病患紀錄'),
(40674, 142, 12, '增加處方'),
(40675, 144, 12, '增加提供者數量'),
(40676, 145, 12, '增加康復'),
(40677, 146, 12, '增加規則'),
(40678, 147, 12, '加到'),
(40679, 148, 12, '加到藥物名單中'),
(40680, 149, 12, '加到最高層級'),
(40681, 150, 12, '增加交易'),
(40682, 151, 12, '增加使用者'),
(40683, 152, 12, '將使用者加入小組中'),
(40684, 153, 12, '添加/編輯eRX'),
(40685, 154, 12, '添加/編輯病人的交易'),
(40686, 155, 12, '增加'),
(40687, 156, 12, '加入人口統計沒有被授權。'),
(40688, 158, 12, '愛迪生症候群'),
(40689, 159, 12, '愛迪生症候群'),
(40690, 160, 12, '附加的屬性'),
(40691, 161, 12, '附加的診斷：'),
(40692, 162, 12, '附加的病史'),
(40693, 163, 12, '附加的病史紀錄'),
(40694, 164, 12, '附加的資訊'),
(40695, 165, 12, '額外的實驗室'),
(40696, 166, 12, '其他注意事項'),
(40697, 168, 12, '其他注意事項︰'),
(40698, 169, 12, '其他注意事項︰ '),
(40699, 170, 12, '另外的放射線紀錄'),
(40700, 172, 12, '沒有結果'),
(40701, 173, 12, 'Addr Bk'),
(40702, 174, 12, 'Addr Bk'),
(40703, 175, 12, '地址'),
(40704, 178, 12, '通訊簿'),
(40705, 179, 12, '執行此程序的公司的通訊簿條目'),
(40706, 180, 12, '經銷商的通訊簿條目'),
(40707, 181, 12, '對供應商的通訊簿條目'),
(40708, 182, 12, '通訊簿類型'),
(40709, 187, 12, '地址1'),
(40710, 188, 12, '地址2'),
(40711, 189, 12, '收信人'),
(40712, 190, 12, '形容詞'),
(40713, 191, 12, '可調節金額'),
(40714, 192, 12, '調整'),
(40715, 193, 12, '調整'),
(40716, 195, 12, '調整原因'),
(40717, 196, 12, '代碼的調整價值 '),
(40718, 197, 12, '調整'),
(40719, 198, 12, '行政調節'),
(40720, 199, 12, '用藥 管理'),
(40721, 200, 12, '管理電子郵件地址'),
(40722, 201, 12, '管理經'),
(40723, 202, 12, '管理'),
(40724, 203, 12, '管理工作由'),
(40725, 206, 12, '管理'),
(40726, 208, 12, '管理者'),
(40727, 209, 12, '管理者可以做任何事'),
(40728, 212, 12, '成人體重篩檢與追蹤'),
(40729, 213, 12, '成人體重篩檢與追蹤(CQM)'),
(40730, 214, 12, '事先指示'),
(40731, 215, 12, '事先指示'),
(40732, 216, 12, '事先指示警告'),
(40733, 218, 12, '進階的'),
(40734, 219, 12, '建議'),
(40735, 221, 12, '影響正常'),
(40736, 223, 12, '經過幾個小時通話'),
(40737, 225, 12, '執行上述配置後，管理客戶端證書導入到瀏覽器並重新啟動Apache服務器（密碼為空）。'),
(40738, 226, 12, '儲存PDF文件後，單擊[查看日誌]以檢查錯誤。'),
(40739, 227, 12, '儲存文本文件（S）後，點擊[查看日誌」來檢查錯誤。'),
(40740, 228, 12, '儲存你的批處理後，單擊[查看日誌]以檢查錯誤。'),
(40741, 230, 12, '資料輸入正確後，點擊儲存按鈕。'),
(40742, 233, 12, '再次'),
(40743, 234, 12, '年齡'),
(40744, 235, 12, '年齡由'),
(40745, 236, 12, '年齡分類'),
(40746, 237, 12, '年齡資料超出範圍'),
(40747, 239, 12, '年齡的格式為“年齡從”是無效的'),
(40748, 240, 12, '年齡的格式為“年齡直到”是無效的'),
(40749, 241, 12, '年齡從'),
(40750, 243, 12, '最大年齡'),
(40751, 244, 12, '最小年齡'),
(40752, 245, 12, '年齡範圍'),
(40753, 247, 12, '老化列：'),
(40754, 250, 12, '酒精'),
(40755, 251, 12, '酒類消費'),
(40756, 253, 12, '機警的計數'),
(40757, 255, 12, '警報'),
(40758, 258, 12, '阿留申'),
(40759, 259, 12, '全部'),
(40760, 260, 12, '急性淋巴性白血症'),
(40761, 261, 12, '全部(被校對的格式A)'),
(40762, 262, 12, '全部(被校對的格式B)'),
(40763, 263, 12, '全部(漸增)'),
(40764, 266, 12, '所有的分類'),
(40765, 268, 12, '所有的代碼'),
(40766, 269, 12, '整天'),
(40767, 270, 12, '整天的事件'),
(40768, 271, 12, '所有人口統計學領域，搜索和重複檢查'),
(40769, 272, 12, '所有設施'),
(40770, 273, 12, '所有傷害/問題/議題'),
(40771, 274, 12, '所有允許的語言'),
(40772, 276, 12, '全部或部分名字'),
(40773, 277, 12, '全部或部分姓氏'),
(40774, 280, 12, '所有產品'),
(40775, 281, 12, '所有提供者'),
(40776, 282, 12, '所有審查與拒絕：'),
(40777, 283, 12, '所有主題'),
(40778, 284, 12, '所有使用者'),
(40779, 285, 12, '過敏的'),
(40780, 286, 12, '過敏'),
(40781, 287, 12, '過敏：'),
(40782, 288, 12, '過敏'),
(40783, 289, 12, '過敏導入成功完成'),
(40784, 291, 12, '過敏反應'),
(40785, 294, 12, '分配'),
(40786, 295, 12, '允許'),
(40787, 296, 12, '允許在登錄選單選擇所有可用的語言。'),
(40788, 297, 12, '允許索賠創建包含診斷，但沒有程序或收費。大多數診所不想這樣。'),
(40789, 298, 12, '允許調試語言'),
(40790, 299, 12, '允許電子郵件'),
(40791, 300, 12, '允許電子郵件的訊息嗎?'),
(40792, 301, 12, '允許電子郵件嗎?'),
(40793, 302, 12, '允許遭遇索賠'),
(40794, 303, 12, '允許健康資訊交換'),
(40795, 304, 12, '允許分享免疫資訊'),
(40796, 305, 12, '允許使用免疫登記表'),
(40797, 306, 12, '允許郵件訊息'),
(40798, 308, 12, '允許病患門戶網站'),
(40799, 309, 12, '允許短訊'),
(40800, 310, 12, '允許短訊（文字信息）？'),
(40801, 311, 12, '允許立即主動作出提交事件了嗎？'),
(40802, 312, 12, '允許電話訊息嗎?'),
(40803, 313, 12, '允許用戶出版全球性事件'),
(40804, 314, 12, '允許用戶出版個人日曆'),
(40805, 315, 12, '允許語音訊息'),
(40806, 316, 12, '准許'),
(40807, 317, 12, '准許的語言'),
(40808, 318, 12, '准許©'),
(40809, 323, 12, '已經存在'),
(40810, 324, 12, '已經存在.'),
(40811, 325, 12, '已被使用，選擇另一個識別碼'),
(40812, 326, 12, '已被使用，選擇另一個標題'),
(40813, 327, 12, '替代地址'),
(40814, 328, 12, '改變'),
(40815, 329, 12, '另外，你可以使用搜索頁面上傳文件，您從您的付款人或票據交換所獲得的電子匯款業務（X12的835）。您可以通過點擊“瀏覽”按鈕，選擇要上傳的文件，然後點擊搜索執行上傳，並顯示相應的發票。上面提到的其他參數，在這種情況下不適用，將被忽略。上傳保存的文件，但還沒有處理它的內容 - 這是分別執行如下所述。'),
(40816, 330, 12, '航空醫學 上午'),
(40817, 331, 12, '航空醫學規劃'),
(40818, 332, 12, '先天多發性關節攣縮症'),
(40819, 333, 12, '先天多發性關節攣縮症追蹤'),
(40820, 338, 12, '修正現有的筆記'),
(40821, 343, 12, '美洲印地安人'),
(40822, 344, 12, '美洲印地安人或阿拉斯加原住民'),
(40823, 345, 12, '美國運通'),
(40824, 346, 12, '阿姆哈啦語'),
(40825, 347, 12, '數量'),
(40826, 349, 12, '收費總量'),
(40827, 350, 12, '過去平衡的數量'),
(40828, 351, 12, '這次看診的數量'),
(40829, 352, 12, '已付金額'),
(40830, 353, 12, '數量：'),
(40831, 357, 12, '棄置LibreEHR網頁目錄樹時發生錯誤'),
(40832, 358, 12, '棄置phpGACL網站目錄樹時發生錯誤'),
(40833, 359, 12, '棄置SQL總帳web目錄樹時發生錯誤'),
(40834, 360, 12, '一個不完整的GCAC問題已創建和連接。有人會需要稍後完成它。'),
(40835, 362, 12, '一個非預期的錯誤已經發生了'),
(40836, 363, 12, '一個大寫字母'),
(40837, 365, 12, '以及 和 並且'),
(40838, 366, 12, '以及 和 並且'),
(40839, 367, 12, '以及'),
(40840, 368, 12, '以及 '),
(40841, 369, 12, '以及所有輔助的資料?這次行動將被登錄'),
(40842, 370, 12, '以及修飾詞'),
(40843, 371, 12, '和處理。'),
(40844, 372, 12, '並且重新啟動阿帕契伺服器。'),
(40845, 373, 12, '並且原因是'),
(40846, 374, 12, '貧血'),
(40847, 375, 12, '腳踝'),
(40848, 376, 12, '腳踝加腳跟'),
(40849, 377, 12, '腳踝評估表'),
(40850, 378, 12, '腳踝問題'),
(40851, 379, 12, '強直性脊柱炎'),
(40852, 380, 12, '強直性脊柱炎'),
(40853, 381, 12, '厭食'),
(40854, 382, 12, '你可以在發布窗口做的另一件事是要求二次計費。如果你在儲存以前選擇此複選框，原索賠將被重新打開，並且在帳單頁排隊，將在未來計費運行期間進行處理。'),
(40855, 383, 12, '前廳 賭注'),
(40856, 384, 12, '肛門NL，沒有直腸壓痛/腫塊'),
(40857, 385, 12, '焦慮'),
(40858, 386, 12, '任何'),
(40859, 387, 12, '任何類別'),
(40860, 388, 12, '所需的代碼或說明的任何部分'),
(40861, 389, 12, '任何所需的專業'),
(40862, 390, 12, '任何藥物識別或藥物名稱的一部分'),
(40863, 391, 12, '免疫標識或免疫名稱的任何部分'),
(40864, 392, 12, '病患姓名的任何部分,或"最後,最初,或"X-Y"'),
(40865, 394, 12, '短信網關的API鍵。'),
(40866, 395, 12, '呼吸暫停'),
(40867, 396, 12, '外觀'),
(40868, 397, 12, '外觀：'),
(40869, 398, 12, '附加本說明'),
(40870, 399, 12, '附加到現有的說明'),
(40871, 400, 12, '附加到本說明'),
(40872, 401, 12, '附加到本說明'),
(40873, 402, 12, '闌尾切除術'),
(40874, 404, 12, '適用患者'),
(40875, 406, 12, '登錄頁面的應用程序的名稱和主窗口的標題。'),
(40876, 408, 12, '應用發件人代碼（GS02）'),
(40877, 409, 12, '應用標題'),
(40878, 410, 12, '使用在生命徵象表格與生長曲線圖'),
(40879, 412, 12, '只適用於目前事件，對這個和所有未來的事件，或所有事件的變化？'),
(40880, 413, 12, '使用在受影響的區域'),
(40881, 414, 12, '使用在皮膚'),
(40882, 415, 12, '提供'),
(40883, 417, 12, '約定 委任'),
(40884, 418, 12, '預約日期'),
(40885, 419, 12, '約會表現風格'),
(40886, 420, 12, '約會提醒規則'),
(40887, 421, 12, '預約狀況'),
(40888, 422, 12, '預約狀況'),
(40889, 423, 12, '預約之內'),
(40890, 424, 12, '預約/事件顏色'),
(40891, 425, 12, '預約'),
(40892, 426, 12, '任命(自選的寫)'),
(40893, 430, 12, '任命與遭遇'),
(40894, 431, 12, '任用報告'),
(40895, 432, 12, '任用–相遇報告'),
(40896, 434, 12, '批准'),
(40897, 436, 12, '批准'),
(40898, 437, 12, '批准的事件管理'),
(40899, 440, 12, '聘任-ENC'),
(40900, 441, 12, '聘任'),
(40901, 442, 12, '四月'),
(40902, 443, 12, '四月'),
(40903, 444, 12, '阿拉伯'),
(40904, 447, 12, '存取控制的組名要翻譯嗎?'),
(40905, 448, 12, '任命類別的名字要翻譯嗎?'),
(40906, 449, 12, '文件類別的名字要翻譯嗎?'),
(40907, 450, 12, '這個類型要收費嗎?'),
(40908, 451, 12, '病患說明標題要翻譯嗎?'),
(40909, 453, 12, '對這次訪問 你準備完成一個新的GCAC議題了嗎?'),
(40910, 455, 12, '你確定想要批准這些事件?'),
(40911, 457, 12, '你確定想要完全移除這個格式?'),
(40912, 459, 12, '你確定想要刪除這個發現嗎?'),
(40913, 460, 12, '你確定想要刪除這個事件?'),
(40914, 461, 12, '你確定想要從資料庫中刪除這個項目嗎?'),
(40915, 462, 12, '你確定要刪除本說明嗎？'),
(40916, 464, 12, '你確定想要編輯這些事件嗎?'),
(40917, 465, 12, '你確定想要隱藏這些事件嗎?'),
(40918, 467, 12, '你確定想要瀏覽這些事件嗎?'),
(40919, 468, 12, '你確定要刪除整個上榜的群體'),
(40920, 469, 12, '你確定要刪除全部表單'),
(40921, 470, 12, '你確定要刪除字段'),
(40922, 471, 12, '你確定要刪除選定的欄位嗎？'),
(40923, 472, 12, '你確定你''想繼續這些行動？'),
(40924, 473, 12, '區域未指定'),
(40925, 474, 12, '手臂'),
(40926, 475, 12, '亞美尼亞語'),
(40927, 477, 12, '心律不整'),
(40928, 478, 12, '關節炎'),
(40929, 479, 12, '關節炎/退化性關節疾病'),
(40930, 480, 12, '關節炎/退化性關節疾病'),
(40931, 481, 12, '如同'),
(40932, 482, 12, '自'),
(40933, 484, 12, '亞洲'),
(40934, 487, 12, '評估'),
(40935, 488, 12, '分配'),
(40936, 489, 12, '助理'),
(40937, 490, 12, '氣喘'),
(40938, 491, 12, '在'),
(40939, 492, 12, '如果你選擇全部，至少有一個搜索參數是必需的。'),
(40940, 493, 12, '在舟狀骨'),
(40941, 494, 12, '在舟狀骨：'),
(40942, 495, 12, '田徑隊'),
(40943, 497, 12, '運動的/傷害'),
(40944, 498, 12, 'ATNA審核CA證書'),
(40945, 499, 12, 'ATNA審核主持人'),
(40946, 500, 12, 'ATNA審核地區性證書'),
(40947, 501, 12, 'ATNA審核端口'),
(40948, 503, 12, '注意'),
(40949, 504, 12, '經辦人'),
(40950, 509, 12, '審計日誌備份'),
(40951, 510, 12, '審計日誌雜項'),
(40952, 511, 12, '審計日誌順序'),
(40953, 512, 12, '審計日誌病患紀錄'),
(40954, 513, 12, '審計日誌的安排'),
(40955, 514, 12, '審計日誌的安全管理'),
(40956, 515, 12, '稽核記錄SELECT查詢'),
(40957, 516, 12, '八月'),
(40958, 517, 12, '八月'),
(40959, 519, 12, '驗證'),
(40960, 520, 12, '驗證/註釋'),
(40961, 523, 12, '授權小組'),
(40962, 525, 12, '授權'),
(40963, 526, 12, '授權 核准'),
(40964, 527, 12, '批准-任何的交易'),
(40965, 528, 12, '批准-我的交易'),
(40966, 530, 12, '授權 核准'),
(40967, 531, 12, '只批准'),
(40968, 532, 12, '自動傳送'),
(40969, 535, 12, '自動創造新的遭遇'),
(40970, 536, 12, '自動產生'),
(40971, 537, 12, '自動化的測量演算(AMC)'),
(40972, 542, 12, '自動化的測量演算(AMC)追蹤'),
(40973, 543, 12, '自動化的措施(AMC)'),
(40974, 544, 12, '自動的'),
(40975, 546, 12, '自動的創造一個新的遭遇當約定的狀態是設定在"@"(到達)'),
(40976, 549, 12, '汽車醫療'),
(40977, 550, 12, '自動儲存'),
(40978, 551, 12, '可用類別'),
(40979, 552, 12, '可用時間'),
(40980, 557, 12, '平均每月'),
(40981, 558, 12, '撕裂/撕裂的骨折'),
(40982, 559, 12, '撕裂傷外踝'),
(40983, 560, 12, '撕裂傷內踝 '),
(40984, 561, 12, '基於了悟'),
(40985, 562, 12, '腋下'),
(40986, 565, 12, '一天兩次'),
(40987, 566, 12, '後面 背面'),
(40988, 567, 12, '後面 背面'),
(40989, 568, 12, '以前的八次訪問'),
(40990, 569, 12, '以前的拾壹次訪問'),
(40991, 570, 12, '以前的五次訪問'),
(40992, 571, 12, '以前的四次訪問'),
(40993, 572, 12, '以前的九次訪問'),
(40994, 573, 12, '以前的一次訪問'),
(40995, 574, 12, '背痛'),
(40996, 575, 12, '背部問題'),
(40997, 576, 12, '以前的七次訪問'),
(40998, 577, 12, '以前的六次訪問');
INSERT INTO `lang_definitions` VALUES
(40999, 578, 12, '背部手術'),
(41000, 579, 12, '以前的十次訪問'),
(41001, 580, 12, '以前的三次訪問'),
(41002, 584, 12, '支持病人'),
(41003, 586, 12, '回到查看'),
(41004, 587, 12, '以前的十二次訪問'),
(41005, 588, 12, '以前的兩次訪問'),
(41006, 590, 12, '備份'),
(41007, 591, 12, '已創建的備份文件。現在將傳送下載。'),
(41008, 593, 12, '順利地使用的備份'),
(41009, 594, 12, '空頭支票'),
(41010, 595, 12, '重債'),
(41011, 596, 12, '印度尼西亞語'),
(41012, 597, 12, '平衡'),
(41013, 598, 12, '平衡'),
(41014, 599, 12, '平衡'),
(41015, 601, 12, '到期餘額'),
(41016, 603, 12, '銀行匯票'),
(41017, 607, 12, '第五(第5) Metarsal基地'),
(41018, 608, 12, '第五(第5) Metarsal基地︰'),
(41019, 612, 12, '一批通訊工具'),
(41020, 613, 12, '一批付款條目'),
(41021, 615, 12, '批次處理啟動，這可能需要一段時間。'),
(41022, 616, 12, '一批結果'),
(41023, 617, 12, 'BatchCom'),
(41024, 619, 12, '因為那個身份證不存在'),
(41025, 620, 12, '開始'),
(41026, 621, 12, '開始日期'),
(41027, 623, 12, '服務開始日期年年年年-月月-日日'),
(41028, 624, 12, '日曆事件一天開始的時間'),
(41029, 626, 12, '噯氣'),
(41030, 630, 12, '兩者之間'),
(41031, 633, 12, '雙側'),
(41032, 634, 12, '雙側︰'),
(41033, 636, 12, '帳單日期︰'),
(41034, 637, 12, '帳單/收集'),
(41035, 638, 12, '帳單'),
(41036, 640, 12, '帳單'),
(41037, 641, 12, '廣告(自選的寫)'),
(41038, 642, 12, '廣告經辦人'),
(41039, 644, 12, '要求服務的廣告代碼'),
(41040, 645, 12, '帳單代碼'),
(41041, 646, 12, '帳單日期'),
(41042, 647, 12, '廣告部門'),
(41043, 648, 12, '廣告設施'),
(41044, 649, 12, '廣告資訊'),
(41045, 650, 12, '廣告地點'),
(41046, 655, 12, '廣告經理'),
(41047, 656, 12, '計費筆記'),
(41048, 657, 12, '計費筆記為 '),
(41049, 658, 12, '計費筆記︰'),
(41050, 659, 12, '計費隊列結果：'),
(41051, 660, 12, '計費報告'),
(41052, 662, 12, '計費狀態=未入帳'),
(41053, 663, 12, '入賬到 '),
(41054, 665, 12, '切片'),
(41055, 666, 12, '出生日期'),
(41056, 669, 12, '黑'),
(41057, 671, 12, '黑人或非裔美國人'),
(41058, 672, 12, '膀胱癌'),
(41059, 673, 12, '膀胱感染'),
(41060, 674, 12, '空白表格'),
(41061, 675, 12, '流血問題'),
(41062, 676, 12, '盲點'),
(41063, 677, 12, '腹脹'),
(41064, 678, 12, '封鎖 阻斷'),
(41065, 679, 12, '血液'),
(41066, 680, 12, '血壓'),
(41067, 681, 12, '血壓'),
(41068, 682, 12, '流鼻血'),
(41069, 683, 12, '藍十字藍盾'),
(41070, 684, 12, '本報告中的藍線都是資訊。黑線顯示原有資訊。綠線顯示已成功應用的變化。紅線顯示錯誤，或不適用的變化;這些必須人工處理。目前拒絕索賠和支付撥回不自動處理，所以會出現紅色。'),
(41071, 685, 12, '視覺模糊'),
(41072, 686, 12, '身體質量指數'),
(41073, 687, 12, '身體質量指數狀態'),
(41074, 689, 12, '身體部位'),
(41075, 690, 12, '身體位置'),
(41076, 691, 12, '身體位置，如果適用'),
(41077, 692, 12, '骨頭壓痛︰'),
(41078, 693, 12, '骨頭壓痛︰內側內踝'),
(41079, 694, 12, '部爾'),
(41080, 696, 12, '博特 機器人'),
(41081, 697, 12, '雙耳'),
(41082, 698, 12, '雙耳'),
(41083, 699, 12, '臀部'),
(41084, 701, 12, '框10A.與就業相關 '),
(41085, 702, 12, '框10B.車禍 '),
(41086, 703, 12, '框10C.其他意外 '),
(41087, 708, 12, '框16.無法工作的日期從(年年年年-月月-日日)'),
(41088, 709, 12, '框16.無法工作的日期至(年年年年-月月-日日)'),
(41089, 710, 12, '框18.住院日期從(年年年年-月月-日日) '),
(41090, 711, 12, '框18.住院日期至(年年年年-月月-日日) '),
(41091, 712, 12, '框20.使用外面的檢驗室嗎?'),
(41092, 713, 12, '框22.醫療補助重新提交代碼(ICD-9) '),
(41093, 714, 12, '框23.事先授權號 '),
(41094, 715, 12, '血壓'),
(41095, 716, 12, '收縮壓'),
(41096, 717, 12, '舒張壓'),
(41097, 719, 12, 'Bpd'),
(41098, 721, 12, 'Bps'),
(41099, 722, 12, '巴西葡萄牙語'),
(41100, 723, 12, '乳房'),
(41101, 724, 12, '乳房切片'),
(41102, 725, 12, '乳房分泌物'),
(41103, 726, 12, '乳房疾病'),
(41104, 727, 12, '乳房檢查'),
(41105, 728, 12, '乳房腫塊'),
(41106, 730, 12, '呼吸音︰'),
(41107, 732, 12, '斷裂的骨頭'),
(41108, 734, 12, '支氣管炎表單'),
(41109, 735, 12, '瀏覽'),
(41110, 736, 12, '瀏覽記錄'),
(41111, 737, 12, '瘀青/血腫'),
(41112, 739, 12, '右側膨出︰'),
(41113, 741, 12, '排尿時燒灼感'),
(41114, 742, 12, '排尿時燒灼感'),
(41115, 744, 12, '忙碌'),
(41116, 745, 12, '但尚未處理'),
(41117, 746, 12, '臀部'),
(41118, 747, 12, '臀部+ S.I.'),
(41119, 748, 12, '通過 由'),
(41120, 749, 12, '通過 由'),
(41121, 750, 12, '由口'),
(41122, 751, 12, '由/來源'),
(41123, 752, 12, '由︰'),
(41124, 754, 12, 'CA證書驗證RFC5425 TLS syslog服務器。'),
(41125, 755, 12, '緩存生存期(秒)'),
(41126, 756, 12, '快取範本輸出？'),
(41127, 757, 12, '咖啡因消耗量'),
(41128, 758, 12, '日曆'),
(41129, 759, 12, '日曆結束時間'),
(41130, 760, 12, '日曆間隔'),
(41131, 761, 12, '日曆畫面'),
(41132, 762, 12, '日曆設置'),
(41133, 763, 12, '日曆開始時間'),
(41134, 764, 12, '日曆的用戶介面'),
(41135, 765, 12, '日曆視圖'),
(41136, 766, 12, '呼叫添加表格去這裡參考。'),
(41137, 767, 12, '卡路里'),
(41138, 768, 12, '柬埔寨'),
(41140, 774, 12, '取消'),
(41141, 775, 12, '取消變更'),
(41142, 776, 12, '取消'),
(41143, 777, 12, '癌症'),
(41144, 778, 12, '癌症篩檢︰直腸癌篩檢'),
(41145, 779, 12, '癌症篩檢︰乳房攝影'),
(41146, 780, 12, '癌症篩檢︰子宮頸抹片'),
(41147, 781, 12, '癌症篩檢︰攝護腺癌篩檢'),
(41148, 782, 12, '不能添加此項因為它已經存在!'),
(41149, 783, 12, '不能添加/更新這個條目，因為重複已經存在！'),
(41150, 785, 12, '不能轉換為 JPEG。也許 ImageMagick是沒有安裝？'),
(41151, 787, 12, '不能顯示內聯，因為它的類型不是由瀏覽器支持。'),
(41152, 788, 12, '不能顯示內聯，因為它的類型是不是由瀏覽器支持。'),
(41153, 789, 12, '不能顯示內聯，因為它的類型是不是由瀏覽器支持。'),
(41154, 790, 12, '無法創造'),
(41155, 795, 12, '找不到 '),
(41156, 796, 12, '無法找到目標檔案名稱'),
(41157, 799, 12, '從 SQL總客戶名單中無法找到病人'),
(41158, 800, 12, '找不到PostScript文件參考 '),
(41159, 801, 12, '不能從SQL總帳僱員找到提供者= '),
(41160, 802, 12, '不能修改付款方式。未分配利潤是負的。'),
(41161, 803, 12, '無法打開 '),
(41162, 804, 12, '不能為保險張貼。付款實體選擇是病人'),
(41163, 805, 12, '不能為病人張貼。付款實體選擇是保險'),
(41164, 806, 12, '不能張貼付款方式，未分配利潤是負的。'),
(41165, 807, 12, '無法讀取'),
(41166, 808, 12, '不能讀目錄'),
(41167, 809, 12, '無法更新因為你不是編輯現有的條目'),
(41168, 810, 12, '大寫'),
(41169, 812, 12, '膠囊'),
(41170, 813, 12, '卡片'),
(41171, 814, 12, '心導管置入術'),
(41172, 815, 12, '心臟超音波'),
(41173, 816, 12, '心臟血管的'),
(41174, 821, 12, '軟骨組織/軟骨面/椎間盤損傷'),
(41175, 822, 12, '軟骨損傷'),
(41176, 823, 12, '頸動脈搏動nl，足的脈搏 nl'),
(41177, 824, 12, '現金'),
(41178, 825, 12, '現金'),
(41179, 826, 12, '現金紀錄'),
(41180, 827, 12, '供應商提供現金收據'),
(41181, 829, 12, '白內障手術'),
(41182, 830, 12, '白內障'),
(41183, 831, 12, '類別'),
(41184, 832, 12, '類別為'),
(41185, 833, 12, '類別'),
(41186, 834, 12, '類別'),
(41187, 835, 12, '類別 '),
(41188, 836, 12, '類別細節'),
(41189, 837, 12, '類別限制'),
(41190, 838, 12, '類別名稱'),
(41191, 839, 12, '類別名字是空的'),
(41192, 840, 12, '類別或標題'),
(41193, 841, 12, '高加索 白種人'),
(41194, 842, 12, '造成收入列印至遭遇/主要提供者資訊'),
(41195, 853, 12, '手機'),
(41196, 855, 12, '手機號碼'),
(41197, 856, 12, '中央證明'),
(41198, 857, 12, '中央或南美'),
(41199, 858, 12, '認證授權crt檔案位置不可能是空的'),
(41200, 859, 12, '認證授權關鍵檔案位置不可能是空的'),
(41201, 860, 12, '發送RFC5425 TLS的syslog服務器的證書。'),
(41202, 861, 12, '證明用戶'),
(41203, 862, 12, '證明'),
(41204, 864, 12, 'ChampUS'),
(41205, 865, 12, 'ChampUSVA'),
(41206, 866, 12, '改變'),
(41207, 867, 12, '改變'),
(41208, 868, 12, '改變活動'),
(41209, 870, 12, '視力改變'),
(41210, 871, 12, '視力改變'),
(41211, 874, 12, '改變'),
(41212, 875, 12, '改變的腸子'),
(41213, 877, 12, '特徵'),
(41214, 879, 12, '負責 收費 充電'),
(41215, 880, 12, '調整收費'),
(41216, 882, 12, '充電'),
(41217, 883, 12, '病歷'),
(41218, 884, 12, '圖表活動'),
(41219, 885, 12, '病力借入/借出活動報告'),
(41220, 886, 12, '病歷編號'),
(41221, 887, 12, '病歷編號：'),
(41222, 889, 12, '圖表位置活動'),
(41223, 890, 12, '病歷附註'),
(41224, 891, 12, '病歷號碼'),
(41225, 892, 12, '病歷存放位置'),
(41226, 893, 12, '病歷追蹤者'),
(41227, 894, 12, 'Chart Trk'),
(41228, 895, 12, '病歷借出'),
(41229, 896, 12, '圖表輸出'),
(41230, 898, 12, '檢查'),
(41231, 899, 12, '檢查'),
(41232, 900, 12, '檢查全部'),
(41233, 902, 12, '檢查量'),
(41234, 903, 12, '檢查日期'),
(41235, 904, 12, '用習慣語言表檢查翻譯的不同處'),
(41236, 906, 12, '簽入到'),
(41237, 907, 12, '檢查輸入資料'),
(41238, 909, 12, '檢查實驗室結果'),
(41239, 912, 12, '支票號碼'),
(41240, 915, 12, '檢查付款'),
(41241, 916, 12, '如果這是一個被加密的文件，檢查箱子'),
(41242, 917, 12, '如果你想在默認情況下，供應商看到所有預約而不只是他們自己的，檢查這個。'),
(41243, 919, 12, '檢查/EOB日期：'),
(41244, 920, 12, '檢查/EOB編號：'),
(41245, 921, 12, '檢查或參考數目'),
(41246, 922, 12, '檢查或參考數目'),
(41247, 923, 12, '複選框名單'),
(41248, 924, 12, '複選框名單'),
(41249, 925, 12, '複選框W /文字'),
(41250, 926, 12, '複選框W /文字'),
(41251, 928, 12, '檢查'),
(41252, 929, 12, '複選框=是，空的=沒有'),
(41253, 932, 12, '結算離開'),
(41254, 933, 12, '校驗'),
(41255, 934, 12, '胸部'),
(41256, 935, 12, '胸部鯨蠟基三甲基銨溴化物'),
(41257, 936, 12, '胸痛'),
(41258, 937, 12, '胸痛：'),
(41259, 938, 12, '胸痛'),
(41260, 940, 12, 'Chg'),
(41261, 942, 12, '主訴'),
(41262, 943, 12, '兒童'),
(41263, 945, 12, '兒童時期預防注射狀況(CQM)'),
(41264, 946, 12, '寒顫'),
(41265, 947, 12, '中文'),
(41266, 948, 12, '中文(簡體字)'),
(41267, 949, 12, '中文(繁體字)'),
(41268, 951, 12, '選擇'),
(41269, 952, 12, '膽囊摘除術'),
(41270, 954, 12, '膽囊摘除術'),
(41271, 955, 12, '選擇'),
(41272, 956, 12, '選擇一節並且點擊此節內的項目，然後在其他節你會看到相關的項目突出，您可以在那節中點擊來添加和刪除的關係。'),
(41273, 957, 12, '選擇標準'),
(41274, 962, 12, '選擇表單'),
(41275, 965, 12, '選擇這個遭遇報告的列印格式。'),
(41276, 967, 12, '慢性支氣管炎'),
(41277, 968, 12, '慢性關節痛'),
(41278, 969, 12, '慢性腎臟病(CKD)'),
(41279, 970, 12, '慢性滑膜炎/滲出液/關節痛/痛風'),
(41280, 971, 12, '慢性的/復發的'),
(41281, 973, 12, '肝硬化'),
(41282, 974, 12, '肝硬化'),
(41283, 975, 12, '城市'),
(41284, 976, 12, '城市名'),
(41285, 977, 12, '城市，州'),
(41286, 978, 12, '城市，州郵編'),
(41287, 979, 12, '城市/州'),
(41288, 980, 12, '要求 索賠 應用'),
(41289, 981, 12, '要求 索賠 應用 '),
(41290, 983, 12, '索賠測試已完成運行'),
(41291, 986, 12, '索賠產生的文件 '),
(41292, 988, 12, '分類'),
(41293, 989, 12, '清晰'),
(41294, 991, 12, '清除所有'),
(41295, 992, 12, '清除HL7的資料'),
(41296, 993, 12, '明確的理由'),
(41297, 994, 12, '清除Smarty的快取記憶體'),
(41298, 995, 12, 'EDI的270批次創建需要的交換所資訊。'),
(41299, 996, 12, 'CLIA 號碼'),
(41300, 997, 12, '點擊'),
(41301, 998, 12, '點擊“出口”以出口你的分類，子類別，項目，內容數據到一個文本文件。這個文件與XML文件任何的相似之處，純屬巧合。開始和結束標記必須在同一行上，他們必須是不帶空格的小寫。導入，瀏覽一個文件，並單擊“導入”。如果數據是完全不同的，它會與您現有的數據合併。如果有類似的項目名稱，舊的將被保存和新的一個會以一個添加到末尾的數字儲存。'),
(41302, 999, 12, '點擊圖形上的點，以增加一個新的註釋，再次點擊將其刪除'),
(41303, 1000, 12, '點擊下載證書，以下載在ssl.zip文件的憑證'),
(41304, 1001, 12, '更多的點擊'),
(41305, 1005, 12, '點擊這裡'),
(41306, 1006, 12, '點擊這裡來增加新病人'),
(41307, 1007, 12, '點擊這裡以增加新的傷害變動狀態和編輯每日活動'),
(41308, 1008, 12, '點擊這裡來選擇日期'),
(41309, 1009, 12, '點擊這裡來選擇日期和時間'),
(41310, 1010, 12, '點擊這裡來選擇開始日期'),
(41311, 1020, 12, '點擊這裡來搜尋'),
(41312, 1021, 12, '點擊這裡更新優先權、類別和暱稱設置'),
(41313, 1022, 12, '點擊這裡觀看全部'),
(41314, 1023, 12, '點擊這裡觀看和註標'),
(41315, 1025, 12, '點擊這裡觀看和註標所有命脈'),
(41316, 1026, 12, '點擊這裡觀看病人細節'),
(41317, 1027, 12, '點擊這裡觀看他們全部'),
(41318, 1029, 12, '點擊儲存按鈕以儲存從下列日期釋出的資料庫'),
(41319, 1030, 12, '點擊任何一個時間部份以增加它'),
(41320, 1032, 12, '點擊“刷新”查看所有結果，或請輸入上述的搜索條件來查看具體的成果。'),
(41321, 1034, 12, '點擊以增加新的組分'),
(41322, 1035, 12, '點擊以增加新的諮詢'),
(41323, 1037, 12, '點擊來下載'),
(41324, 1038, 12, '點擊來編輯'),
(41325, 1040, 12, '點擊來編輯這個事件'),
(41326, 1041, 12, '點擊來產生報告'),
(41327, 1043, 12, '點擊來列印'),
(41328, 1044, 12, '點擊以接受(增加)新的全部'),
(41329, 1045, 12, '點擊以選擇'),
(41330, 1046, 12, '點擊以選擇'),
(41331, 1047, 12, '為這個過程點擊以選擇一個工業標準的代碼'),
(41332, 1050, 12, '點擊以選擇或改變CVX代碼'),
(41333, 1051, 12, '點擊以選擇或改變診斷'),
(41334, 1052, 12, '點擊以選擇或改變服務代碼'),
(41335, 1053, 12, '點擊以選擇病人'),
(41336, 1054, 12, '點擊以選擇相關代碼'),
(41337, 1055, 12, '如果這個結果是不正常的，點擊以選擇服務以執行'),
(41338, 1056, 12, '點擊以選擇希望的步驟'),
(41339, 1058, 12, '點擊以流覽'),
(41340, 1059, 12, '點擊以流覽或編輯'),
(41341, 1060, 12, '點擊以流覽/編輯'),
(41342, 1061, 12, '點擊升級按鈕以升級從下列日期釋出的資料庫'),
(41343, 1063, 12, '點擊：'),
(41344, 1064, 12, '客戶證書失效日'),
(41345, 1065, 12, '客戶證書驗證期間'),
(41346, 1066, 12, '客户證書有效性應該是一個合法的數字'),
(41347, 1067, 12, '客戶副本'),
(41348, 1069, 12, '客戶醫療史摘要'),
(41349, 1072, 12, '客戶簡介-新客戶'),
(41350, 1073, 12, '客戶簡介-獨特的客戶'),
(41351, 1074, 12, '客戶'),
(41352, 1075, 12, '臨床學 診所'),
(41353, 1076, 12, '診所副本'),
(41354, 1077, 12, '診所日誌'),
(41355, 1078, 12, '診所證件'),
(41356, 1079, 12, '臨床的'),
(41357, 1080, 12, '臨床决定規則機敏的經理'),
(41358, 1083, 12, '臨床計劃'),
(41359, 1084, 12, '臨床品質測量(CQM)'),
(41360, 1087, 12, '臨床提示'),
(41361, 1088, 12, '臨床報告'),
(41362, 1089, 12, '臨床規則行動類別'),
(41363, 1090, 12, '臨床規則行動項目'),
(41364, 1091, 12, '臨床規則篩選方法'),
(41365, 1092, 12, '臨床規則目標方法'),
(41366, 1093, 12, '臨床規則'),
(41367, 1094, 12, '臨床規則年齡間隔時間'),
(41368, 1095, 12, '臨床規則比較'),
(41369, 1096, 12, '臨床規則遭遇類型'),
(41370, 1097, 12, '臨床規則提示會費選項'),
(41371, 1098, 12, '臨床規則提示鈍化作用選項'),
(41372, 1099, 12, '臨床規則提示間隔時間'),
(41373, 1100, 12, '臨床規則提示方法'),
(41374, 1101, 12, '臨床規則目標間隔時間'),
(41375, 1102, 12, '臨床目標'),
(41376, 1106, 12, '臨床工作者'),
(41377, 1107, 12, '同本生物 無性繁殖'),
(41378, 1108, 12, '複製過去的訪問'),
(41379, 1109, 12, '關閉'),
(41380, 1111, 12, '關窗'),
(41381, 1112, 12, '關閉'),
(41382, 1113, 12, '公分'),
(41383, 1114, 12, 'CMS 1500 Margins'),
(41384, 1118, 12, '可拉德心境評量表憑證'),
(41385, 1127, 12, 'CN2-12 intact'),
(41386, 1130, 12, '共付額'),
(41387, 1131, 12, '代碼'),
(41388, 1132, 12, '代碼'),
(41389, 1133, 12, '編碼發現者'),
(41390, 1134, 12, '代碼必須是兩個字母的小寫'),
(41391, 1135, 12, '表明貨幣的代碼或標誌'),
(41392, 1136, 12, '代碼文本'),
(41393, 1138, 12, '代碼類型'),
(41394, 1141, 12, '代碼類型'),
(41395, 1144, 12, '代碼'),
(41396, 1145, 12, '編碼'),
(41397, 1147, 12, '編碼 - 任何接觸（寫一些可選）'),
(41398, 1148, 12, '編碼 - 我的接觸（寫一些可選）'),
(41399, 1149, 12, '沒授權的編碼'),
(41400, 1150, 12, '咖啡'),
(41401, 1152, 12, '共同擔保'),
(41402, 1153, 12, 'Coll w/o'),
(41403, 1154, 12, '虛脫 崩潰'),
(41404, 1155, 12, '虛脫 崩潰'),
(41405, 1156, 12, '全部崩潰'),
(41406, 1157, 12, '全部崩潰'),
(41407, 1158, 12, '全部崩潰'),
(41408, 1161, 12, '收集'),
(41409, 1162, 12, '彙集報告'),
(41410, 1163, 12, '大腸癌'),
(41411, 1164, 12, '大腸癌篩檢'),
(41412, 1165, 12, '大腸癌手術'),
(41413, 1166, 12, '大腸鏡檢'),
(41414, 1167, 12, '大腸鏡檢'),
(41415, 1168, 12, '顏色'),
(41416, 1169, 12, '顏色：縮寫'),
(41417, 1170, 12, '欄 列'),
(41418, 1171, 12, '專欄'),
(41419, 1172, 12, '結合全部'),
(41420, 1173, 12, '逗號'),
(41421, 1174, 12, '評論'),
(41422, 1175, 12, '評論'),
(41423, 1176, 12, '這個結果或建議的評論'),
(41424, 1177, 12, '商業保險有限公司'),
(41425, 1178, 12, '承諾改變'),
(41426, 1180, 12, '溝通'),
(41427, 1182, 12, '公司'),
(41428, 1183, 12, '公司名稱'),
(41429, 1184, 12, '完全 全部'),
(41430, 1186, 12, '完全 全部'),
(41431, 1188, 12, '完全 全部?'),
(41432, 1190, 12, '服務提供商的合併症'),
(41433, 1191, 12, '流產合併症'),
(41434, 1192, 12, '組件'),
(41435, 1193, 12, '電腦輔助醫囑系統'),
(41436, 1194, 12, '結論'),
(41437, 1199, 12, '配置'),
(41438, 1200, 12, '配置出口或進口'),
(41439, 1202, 12, '配置Apache和LibreEHR以使用客戶端的SSL證書。'),
(41440, 1203, 12, '配置Apache以使用客戶端的SSL證書'),
(41441, 1204, 12, '配置Apache以使用HTTPS。'),
(41442, 1205, 12, '配置LIBREEHR以使用客戶端SSL證書'),
(41443, 1208, 12, '證實創造新的患者'),
(41444, 1209, 12, '證實新的密碼'),
(41445, 1210, 12, '證實付款'),
(41446, 1214, 12, '先天性'),
(41447, 1215, 12, '結膜，瞳孔'),
(41448, 1218, 12, '常數 常量'),
(41449, 1219, 12, '恆定的名字'),
(41450, 1220, 12, '恆定的名字是空白的'),
(41451, 1221, 12, '常數 常量'),
(41452, 1222, 12, '便秘'),
(41453, 1223, 12, '構成 合法'),
(41454, 1226, 12, '諮詢簡要說明'),
(41455, 1227, 12, '連絡接觸'),
(41456, 1228, 12, '往來電子郵件'),
(41457, 1229, 12, '聯繫人電子郵件地址'),
(41458, 1231, 12, '聯絡信息'),
(41459, 1232, 12, '隱形眼鏡'),
(41460, 1236, 12, '聯繫人姓名'),
(41461, 1237, 12, '聯繫人'),
(41462, 1239, 12, '聯繫的電話號碼'),
(41463, 1240, 12, '聯繫ZMG，LLC（zmghealth@gmail.com）為簽署ERX的服務'),
(41464, 1241, 12, '下列4項至少要包含3項'),
(41465, 1243, 12, '內容'),
(41466, 1244, 12, '內容'),
(41467, 1245, 12, '上下文 前後關係'),
(41468, 1246, 12, '上下文名稱不能是空的'),
(41469, 1247, 12, '繼續'),
(41470, 1248, 12, '連續性照顧文件(CCD)'),
(41471, 1249, 12, '連續性照顧紀錄(CCR)'),
(41472, 1250, 12, '針對客戶'),
(41473, 1251, 12, '避孕'),
(41474, 1252, 12, '避孕議題'),
(41475, 1253, 12, '避孕合併症(指定)'),
(41476, 1254, 12, '避孕方法'),
(41477, 1255, 12, '避孕的產品'),
(41478, 1256, 12, '避孕服務以前就開始了'),
(41479, 1257, 12, '避孕藥開始'),
(41480, 1258, 12, '控制身分'),
(41481, 1259, 12, '控制序號'),
(41482, 1262, 12, '共付額'),
(41483, 1263, 12, '共付額'),
(41484, 1264, 12, '共付額非主動'),
(41485, 1266, 12, '共付額'),
(41486, 1267, 12, '慢性阻塞性肺部疾病'),
(41487, 1268, 12, '複製網頁到病歷'),
(41488, 1269, 12, '複製價值'),
(41489, 1270, 12, '複製資料庫檔案。這會花些時間'),
(41490, 1271, 12, '版權須知'),
(41491, 1273, 12, '冠狀動脈分流'),
(41492, 1274, 12, '冠狀動脈分流移植'),
(41493, 1275, 12, '矯正'),
(41494, 1289, 12, '咳嗽'),
(41495, 1290, 12, '咳嗽：'),
(41496, 1294, 12, '無法讀取檔案'),
(41497, 1296, 12, '不能傳送電子郵件由於伺服器問題， '),
(41498, 1298, 12, '不能創造備份子目錄：'),
(41499, 1299, 12, '不能移除子目錄:'),
(41500, 1300, 12, '不能移除舊的備份檔案：'),
(41501, 1301, 12, '不能移除舊的出口檔案：'),
(41502, 1302, 12, '香豆管理- INR監測'),
(41503, 1303, 12, 'Couns by Method'),
(41504, 1304, 12, '諮商'),
(41505, 1305, 12, '諮商活動'),
(41506, 1306, 12, '案子轉介表格'),
(41507, 1307, 12, '案子轉介'),
(41508, 1308, 12, '國家'),
(41509, 1309, 12, '國家資料類型'),
(41510, 1310, 12, '國家名單'),
(41511, 1311, 12, '國家名單(寫， 任意可選)'),
(41512, 1312, 12, '國名應該用2個字母代表(如:美國是US)'),
(41513, 1313, 12, '縣'),
(41514, 1315, 12, '優惠卷'),
(41515, 1318, 12, '胸腔物理治療'),
(41516, 1319, 12, '胸腔物理治療代碼'),
(41517, 1320, 12, '胸腔物理治療代碼'),
(41518, 1323, 12, 'CQM'),
(41519, 1324, 12, '爆裂聲：'),
(41520, 1325, 12, '奶油'),
(41521, 1326, 12, '為每個用戶或客戶機上創建一個客戶端SSL證書。'),
(41522, 1327, 12, '創建一個客戶端SSL證書用戶或客戶端主機名。'),
(41523, 1329, 12, '創造一個事件'),
(41524, 1330, 12, '創造並且下載一個完全備份'),
(41525, 1332, 12, '創造備份'),
(41526, 1333, 12, '創建批量'),
(41527, 1334, 12, '創造客户端憑證'),
(41528, 1335, 12, '創建客戶端SSL證書'),
(41529, 1336, 12, '創造複製品'),
(41530, 1338, 12, '創造事件日誌備份'),
(41531, 1339, 12, '創造新的議題'),
(41532, 1340, 12, '創造新的患者'),
(41533, 1342, 12, '建立異地門戶證書'),
(41534, 1343, 12, '建立就地門戶證書'),
(41535, 1344, 12, '創建患者附註'),
(41536, 1345, 12, '創建SSL憑證授權單位的及伺服器證書。'),
(41537, 1346, 12, '創建訪問'),
(41538, 1347, 12, '創造'),
(41539, 1348, 12, '創造出口文件'),
(41540, 1351, 12, '創作者'),
(41541, 1352, 12, '信用'),
(41542, 1353, 12, '信用卡'),
(41543, 1354, 12, '信用'),
(41544, 1356, 12, '標準'),
(41545, 1358, 12, '克隆氏疾病 局部性迴腸炎'),
(41546, 1359, 12, '克隆氏疾病 局部性迴腸炎'),
(41547, 1360, 12, 'CSV Export'),
(41548, 1361, 12, 'CSV 檔案'),
(41549, 1363, 12, 'CU.MM'),
(41550, 1364, 12, '古巴人'),
(41551, 1365, 12, '貨幣的小數位'),
(41552, 1366, 12, '貨幣的小數點符號'),
(41553, 1367, 12, '貨幣的標誌符'),
(41554, 1368, 12, '貨幣的千位分隔符'),
(41555, 1369, 12, '當前'),
(41556, 1370, 12, '目前酒精'),
(41557, 1371, 12, '目前諮詢'),
(41558, 1372, 12, '當前標準'),
(41559, 1373, 12, '目前每天標明顏色'),
(41560, 1374, 12, '目前每天的吸煙者'),
(41561, 1375, 12, '目前檔案更名為'),
(41562, 1376, 12, '當前哈希'),
(41563, 1377, 12, '當前位置'),
(41564, 1378, 12, '目前的藥物'),
(41565, 1379, 12, '目前的密碼'),
(41566, 1380, 12, '目前患者'),
(41567, 1382, 12, '目前的娛樂性藥物'),
(41568, 1383, 12, '目前某些每天吸煙者'),
(41569, 1386, 12, '當前活動'),
(41570, 1388, 12, '目前沒有任何設施。'),
(41571, 1389, 12, '庫欣症候群'),
(41572, 1390, 12, '庫欣症候群'),
(41573, 1392, 12, '風俗'),
(41574, 1393, 12, '自定義的輸入？'),
(41575, 1394, 12, '自定義表'),
(41576, 1396, 12, 'CVX代碼'),
(41577, 1397, 12, 'CVX代碼繪圖'),
(41578, 1399, 12, '週期'),
(41579, 1400, 12, '色素'),
(41580, 1401, 12, '色素因素'),
(41581, 1402, 12, '色素報告'),
(41582, 1405, 12, '子宮頸擴張與子宮內膜刮除術'),
(41583, 1406, 12, '擴張與排除'),
(41584, 1407, 12, '出生日期'),
(41585, 1408, 12, '每天'),
(41586, 1409, 12, '每日紀錄'),
(41587, 1410, 12, '丹麥語'),
(41588, 1411, 12, '一樣的數據是已經在數據庫中，請更改代碼和/或描述'),
(41589, 1412, 12, '一樣的數據是已經在數據庫中，請更改常數名稱'),
(41590, 1413, 12, '資料列'),
(41591, 1420, 12, '資料形式'),
(41592, 1421, 12, '資料庫'),
(41593, 1422, 12, '資料庫沒有儲存'),
(41594, 1424, 12, '資料庫報告'),
(41595, 1425, 12, '資料庫升級完成了'),
(41596, 1426, 12, '資料列必須是從1到999之間的數字'),
(41597, 1427, 12, '日期'),
(41598, 1428, 12, '日期'),
(41599, 1431, 12, '入院日期'),
(41600, 1432, 12, '樣本收集的日期與時間'),
(41601, 1435, 12, '樣本被收集的日期與時間'),
(41602, 1436, 12, '日期不能大於今天'),
(41603, 1437, 12, '最初提供的避孕服務日期'),
(41604, 1438, 12, '被創造的日期'),
(41605, 1439, 12, '死亡的日期'),
(41606, 1440, 12, '被毀壞的日期'),
(41607, 1441, 12, '日期顯示格式'),
(41608, 1442, 12, '“預約結束”的日期格式無效'),
(41609, 1443, 12, '“預約開始”的日期格式無效'),
(41610, 1444, 12, '“下次預約”的日期格式無效'),
(41611, 1445, 12, '“沒有看到自從”的日期格式無效'),
(41612, 1446, 12, '“看到自從”的日期格式無效'),
(41613, 1447, 12, '日期免疫資訊報表給定'),
(41614, 1448, 12, '提供給代碼的日期遺失了 '),
(41615, 1449, 12, '日期主要標準'),
(41616, 1450, 12, '銀行存款日期年年年年/月月/日日'),
(41617, 1452, 12, '生日'),
(41618, 1453, 12, '生日'),
(41619, 1454, 12, '生日'),
(41620, 1456, 12, '受傷日期'),
(41621, 1458, 12, '付款日期年年年年/月月/日日'),
(41622, 1459, 12, '推舉日期'),
(41623, 1460, 12, '回復日期'),
(41624, 1463, 12, '服務日期'),
(41625, 1464, 12, '服務日期是今天'),
(41626, 1465, 12, '服務日期月月/日日/年年年年'),
(41627, 1466, 12, '服務日期：'),
(41628, 1467, 12, '簽名日期'),
(41629, 1469, 12, '這個醫囑的日期'),
(41630, 1470, 12, '這個報告的日期'),
(41631, 1471, 12, '可見聲明的日期'),
(41632, 1472, 12, '訂購的日期'),
(41633, 1475, 12, '日期選擇器'),
(41634, 1476, 12, '發送的日期'),
(41635, 1479, 12, '日期價值不可能是空白的。'),
(41636, 1480, 12, '可見聲明日期'),
(41637, 1481, 12, '日期或附註'),
(41638, 1482, 12, '日期或最後的附註'),
(41639, 1483, 12, '日期或時間'),
(41640, 1484, 12, '日期：'),
(41641, 1486, 12, '天'),
(41642, 1487, 12, '天'),
(41643, 1489, 12, '日視圖'),
(41644, 1490, 12, '幾天'),
(41645, 1491, 12, '天（S）M - F'),
(41646, 1492, 12, '幾天'),
(41647, 1493, 12, '幾天'),
(41648, 1494, 12, '幾天以前'),
(41649, 1495, 12, '錯過的幾天和比賽'),
(41650, 1496, 12, '最後遭遇天'),
(41651, 1497, 12, '錯過的幾天'),
(41652, 1498, 12, '幾天每個專欄：'),
(41653, 1500, 12, '幾天或關口：'),
(41654, 1501, 12, '安裝的資料庫'),
(41655, 1502, 12, '日日/月月/年年年年'),
(41656, 1503, 12, '去辨識'),
(41657, 1504, 12, '去識別過程完成'),
(41658, 1505, 12, '去識別過程正在進行'),
(41659, 1506, 12, '去識別過程啟動並在後台運行'),
(41660, 1507, 12, '去識別的數據可能無法完成'),
(41661, 1508, 12, '去識別文件將儲存在'),
(41662, 1511, 12, '聾'),
(41663, 1512, 12, '調試信息'),
(41664, 1515, 12, '十二月'),
(41665, 1516, 12, '死者 已故'),
(41666, 1517, 12, '十二月'),
(41667, 1520, 12, '扣稅'),
(41668, 1521, 12, '可扣除會面'),
(41669, 1522, 12, '預設 默認'),
(41670, 1523, 12, '預設日曆視圖'),
(41671, 1524, 12, '預設遭遇表格'),
(41672, 1526, 12, '預設設備'),
(41673, 1527, 12, '預設語言'),
(41674, 1528, 12, '預設語言，如果沒有其他的允許或選擇。'),
(41675, 1529, 12, '預設列表（寫，addonly可選）'),
(41676, 1530, 12, '預設方法'),
(41677, 1531, 12, '預設密碼到期日'),
(41678, 1532, 12, '預設密碼在幾天的有效期間。 0表示禁用此功能。'),
(41679, 1536, 12, '預設提供者'),
(41680, 1537, 12, '預設範圍'),
(41681, 1538, 12, '預設訪問的原因'),
(41682, 1540, 12, '預設設定'),
(41683, 1542, 12, '預設範本'),
(41684, 1546, 12, '預設單位'),
(41685, 1547, 12, '預設值'),
(41686, 1548, 12, '預設倉庫'),
(41687, 1549, 12, '默認的值X12的合作夥伴'),
(41688, 1550, 12, '默認/全球'),
(41689, 1551, 12, 'DEL鍵'),
(41690, 1552, 12, 'DEL鍵'),
(41691, 1553, 12, '延遲復發(超過12個月)'),
(41692, 1554, 12, '刪除'),
(41693, 1555, 12, '刪除'),
(41694, 1556, 12, '用身分證刪除類別 '),
(41695, 1557, 12, '刪除類別'),
(41696, 1560, 12, '刪除群組'),
(41697, 1561, 12, '刪除表單'),
(41698, 1562, 12, '刪除頁數'),
(41699, 1563, 12, '刪除患者、遭遇、形式、問題、文件、付款、布告或者交易'),
(41700, 1565, 12, '刪除行'),
(41701, 1566, 12, '刪除選擇的項目'),
(41702, 1568, 12, '成功的刪除'),
(41703, 1569, 12, '刪除此文件'),
(41704, 1570, 12, '刪除這個形式'),
(41705, 1571, 12, '刪除這個筆記'),
(41706, 1573, 12, '成功的刪除'),
(41707, 1581, 12, '老年癡呆'),
(41708, 1582, 12, '人口統計學'),
(41709, 1583, 12, '人口統計學（寫，addonly可選）'),
(41710, 1585, 12, '人口統計學篩選標準'),
(41711, 1586, 12, '沒授權的人口統計學'),
(41712, 1587, 12, '沒授權的人口統計學。'),
(41713, 1589, 12, '分母'),
(41714, 1590, 12, '牙齒的'),
(41715, 1592, 12, '牙齒問題'),
(41716, 1595, 12, '根據您正在測試的帳單類型，你將會看到HCFA像在為HCFA帳單空白頁的輸出，你會看到許多行有點亂碼的文字和信息，如果你正在測試一個X12索賠。這亂碼的文字是X12的EDI4010A格式。偶爾你會看到奇怪的字符，看起來像多米諾骨牌或squiglies，這些都是控制字符，如頁面提要，都是正常的。'),
(41717, 1596, 12, '存款日期'),
(41718, 1597, 12, '存款日期不能大於今天'),
(41719, 1598, 12, '存款日期：'),
(41720, 1599, 12, '抑鬱的'),
(41721, 1600, 12, '抑鬱'),
(41722, 1602, 12, '描述'),
(41723, 1603, 12, '描述'),
(41724, 1605, 12, '透露的描述'),
(41725, 1606, 12, '這個過程或結果編碼的描述'),
(41726, 1607, 12, '描述翻譯'),
(41727, 1609, 12, '目的地'),
(41728, 1610, 12, '目的地文件名'),
(41729, 1611, 12, '毀壞全部'),
(41730, 1612, 12, '毀壞…'),
(41731, 1613, 12, '毀壞的'),
(41732, 1614, 12, '被毀壞的藥物'),
(41733, 1615, 12, '被毀壞的藥物報告'),
(41734, 1616, 12, '詳情'),
(41735, 1617, 12, '詳情'),
(41736, 1619, 12, '發展上的異常'),
(41737, 1620, 12, '糖尿病'),
(41738, 1621, 12, '糖尿病'),
(41739, 1622, 12, '糖尿病：血壓處理(CQM)'),
(41740, 1623, 12, '糖尿病：眼睛檢查'),
(41741, 1624, 12, '糖尿病：眼睛檢查(CQM)'),
(41742, 1625, 12, '糖尿病：腳的檢查'),
(41743, 1626, 12, '糖尿病：腳的檢查(CQM)'),
(41744, 1627, 12, '糖尿病：醣化血色素控制不良(CQM)'),
(41745, 1628, 12, '糖尿病：糖化血紅蛋白'),
(41746, 1629, 12, '糖尿病：低密度脂蛋白處理與控制'),
(41747, 1630, 12, '糖尿病：尿中微小白蛋白'),
(41748, 1631, 12, '診斷'),
(41749, 1633, 12, '診斷'),
(41750, 1634, 12, '診斷代碼'),
(41751, 1636, 12, '診斷日期'),
(41752, 1637, 12, '診斷必須編碼置入一個連結的遭遇'),
(41753, 1638, 12, '診斷名稱'),
(41754, 1639, 12, '診斷報告'),
(41755, 1642, 12, '診斷標題'),
(41756, 1643, 12, '診斷：'),
(41757, 1644, 12, '診斷： '),
(41758, 1645, 12, '診斷試驗：'),
(41759, 1646, 12, '撥號'),
(41760, 1647, 12, '膜片或蓋帽'),
(41761, 1648, 12, '腹瀉'),
(41762, 1650, 12, '口述'),
(41763, 1651, 12, '口述： '),
(41764, 1652, 12, '您是否接到了HIPAA通知的影本？'),
(41765, 1653, 12, '擴散：'),
(41766, 1654, 12, '數字的簽署'),
(41767, 1657, 12, '直接的郵件'),
(41768, 1663, 12, '主任的名字'),
(41769, 1665, 12, '殘疾'),
(41770, 1667, 12, '功能失效的日曆'),
(41771, 1668, 12, '功能失效的病歷追蹤儀'),
(41772, 1669, 12, '功能失效的免疫作用'),
(41773, 1670, 12, '停用舊的生命徵象格式表'),
(41774, 1672, 12, '禁用的phpMyAdmin'),
(41775, 1673, 12, '禁用處方'),
(41776, 1674, 12, '禁止使用者群組'),
(41777, 1675, 12, '禁止 停用'),
(41778, 1676, 12, '禁止 停用'),
(41779, 1678, 12, '唱片'),
(41780, 1681, 12, '分泌物 出院'),
(41781, 1682, 12, '尿道分泌物'),
(41782, 1684, 12, '右側分泌物'),
(41783, 1685, 12, '右側分泌物：'),
(41784, 1689, 12, '公開信息'),
(41785, 1690, 12, '公開形式'),
(41786, 1691, 12, '公開形式'),
(41787, 1692, 12, '披露'),
(41788, 1694, 12, '折扣'),
(41789, 1695, 12, '折扣量'),
(41790, 1696, 12, '折扣程度'),
(41791, 1697, 12, '折扣百分比'),
(41792, 1698, 12, '貨幣金額的折扣'),
(41793, 1699, 12, '在結賬時輸入折扣作為貨幣金額，而不是百分比。'),
(41794, 1700, 12, '離散的結果'),
(41795, 1701, 12, '疾病'),
(41796, 1702, 12, '脫臼 錯位'),
(41797, 1703, 12, 'DISP＃'),
(41798, 1704, 12, '派遣'),
(41799, 1705, 12, '分派接收到的文件'),
(41800, 1706, 12, '免除'),
(41801, 1707, 12, '在人口統計頁顯示的預先指示'),
(41802, 1709, 12, '在區塊顯示事件的日期嗎？'),
(41803, 1711, 12, '顯示多少事件'),
(41804, 1713, 12, '顯示區塊的位置嗎？'),
(41805, 1714, 12, '顯示姓名'),
(41806, 1715, 12, '顯示日曆嗎？'),
(41807, 1718, 12, '在區塊顯示今天的事件嗎？'),
(41808, 1719, 12, '在區塊顯示主題嗎？'),
(41809, 1720, 12, '在區塊顯示即將到來的活動嗎？'),
(41810, 1721, 12, '顯示的列'),
(41811, 1722, 12, '顯示最近期披露的數目如下：'),
(41812, 1723, 12, '顯示最近期筆記的下列號碼'),
(41813, 1724, 12, '顯示最近期筆記的下列號碼：'),
(41814, 1725, 12, '分布'),
(41815, 1726, 12, '分布'),
(41816, 1727, 12, '經銷商'),
(41817, 1729, 12, '憩室炎'),
(41818, 1730, 12, '憩室炎手術'),
(41819, 1731, 12, '憩室炎'),
(41820, 1732, 12, '憩室炎手術'),
(41821, 1733, 12, '離婚'),
(41822, 1734, 12, '暈眩：'),
(41823, 1735, 12, '不要改變'),
(41824, 1742, 12, '不要顯示日曆。'),
(41825, 1744, 12, '不要庫存和銷售任何產品'),
(41826, 1745, 12, '不需要病人筆記被授權'),
(41827, 1746, 12, '不需要復甦術醫囑'),
(41828, 1747, 12, '不要儲存'),
(41829, 1748, 12, '不能取代'),
(41830, 1749, 12, '什麼都不做'),
(41831, 1751, 12, '你真的要刪除'),
(41832, 1752, 12, '妳真的要刪除所選的嗎？'),
(41833, 1753, 12, '妳真的要刪除此群組'),
(41834, 1755, 12, '妳想要繼續嗎？'),
(41835, 1756, 12, '妳想要刪除這個嗎？'),
(41836, 1757, 12, '妳想要刪除嗎'),
(41837, 1758, 12, '妳想要移除這個紀錄嗎'),
(41838, 1759, 12, '妳希望繼續加這個新病人嗎'),
(41839, 1760, 12, '你想繼續用新的名稱嗎？'),
(41840, 1761, 12, '你想永久刪除這個免疫記錄嗎？'),
(41841, 1762, 12, '出生日期'),
(41842, 1763, 12, '出生日期不見了， 如果可能請輸入'),
(41843, 1764, 12, '文件'),
(41844, 1765, 12, '醫師'),
(41845, 1766, 12, '醫師：'),
(41846, 1767, 12, '醫師的姓名與簽名'),
(41847, 1768, 12, '文件'),
(41848, 1769, 12, '文件'),
(41849, 1770, 12, '文件類別'),
(41850, 1775, 12, '文件無法移到病人的身分證明'),
(41851, 1777, 12, '文件日期'),
(41852, 1778, 12, '成功更新文件的日期和問題'),
(41853, 1779, 12, '文件辨識'),
(41854, 1780, 12, '文件移到新的類別'),
(41855, 1781, 12, '文件移到病人的身份證'),
(41856, 1783, 12, '文件通過完整性檢查'),
(41857, 1785, 12, '文件成功的重新命名'),
(41858, 1790, 12, '文檔/影像店'),
(41859, 1791, 12, '文檔/影像店'),
(41860, 1792, 12, '文件（寫，只添加可選）'),
(41861, 1794, 12, '運動時(用力時)呼吸困難'),
(41862, 1798, 12, '是否允許這種類型的相關代碼？'),
(41863, 1799, 12, '國內合作夥伴'),
(41864, 1800, 12, '不要儲存'),
(41865, 1801, 12, '不要儲存'),
(41866, 1802, 12, '不要儲存更改'),
(41867, 1803, 12, '完成'),
(41868, 1804, 12, '以….完成：'),
(41869, 1805, 12, '完成。現在將傳送下載。'),
(41870, 1806, 12, 'DOS'),
(41871, 1807, 12, '劑量'),
(41872, 1809, 12, '雙擊編輯'),
(41873, 1810, 12, '複視'),
(41874, 1811, 12, '下載'),
(41875, 1814, 12, '下載無論如何'),
(41876, 1815, 12, '下載計費文件，發佈到會計部門並以帳單型式標記'),
(41877, 1817, 12, '下載證書'),
(41878, 1818, 12, '下載配置數據'),
(41879, 1820, 12, '下載加密文件'),
(41880, 1827, 12, '下載選中的語句'),
(41881, 1828, 12, '醫師檢查'),
(41882, 1829, 12, '醫師巡房'),
(41883, 1830, 12, '醫師'),
(41884, 1831, 12, '拖曳以移動'),
(41885, 1832, 12, '運球'),
(41886, 1833, 12, '駕照或州身分證'),
(41887, 1834, 12, '藥物'),
(41888, 1835, 12, '藥品搜索'),
(41889, 1836, 12, '藥品形式'),
(41890, 1837, 12, '藥品證明遺失'),
(41891, 1838, 12, '藥品警告'),
(41892, 1839, 12, '藥品庫存'),
(41893, 1840, 12, '藥品名稱'),
(41894, 1841, 12, '販毒路線'),
(41895, 1845, 12, '藥品單位'),
(41896, 1846, 12, '藥物'),
(41897, 1847, 12, '藥物和產品'),
(41898, 1848, 12, '口乾'),
(41899, 1850, 12, '白喉，破傷風混合疫苗 1'),
(41900, 1851, 12, '白喉，破傷風混合疫苗 2'),
(41901, 1852, 12, '白喉，破傷風混合疫苗3'),
(41902, 1853, 12, '白喉，破傷風混合疫苗 4'),
(41903, 1854, 12, '白喉，破傷風混合疫苗5'),
(41904, 1855, 12, '新型三合一疫苗1'),
(41905, 1856, 12, '新型三合一疫苗2'),
(41906, 1857, 12, '新型三合一疫苗3'),
(41907, 1858, 12, '新型三合一疫苗4'),
(41908, 1859, 12, '新型三合一疫苗5'),
(41909, 1860, 12, '由於 因為'),
(41910, 1861, 12, '截止日期'),
(41911, 1862, 12, '截止日期月月/日日/年年年年或年年年年-月月-日日'),
(41912, 1863, 12, '截止日期：'),
(41913, 1864, 12, '由於慣性'),
(41914, 1865, 12, '由於病人'),
(41915, 1866, 12, '即將到期'),
(41916, 1867, 12, '應有的地位'),
(41917, 1868, 12, '應有的地位更新'),
(41918, 1869, 12, '傾銷LibreEHR數據庫'),
(41919, 1870, 12, '傾銷LibreEHR web目錄樹'),
(41920, 1871, 12, '傾銷phpGACL數據庫'),
(41921, 1872, 12, '傾銷phpGACL Web目錄樹'),
(41922, 1873, 12, '傾銷SQL的總帳數據庫'),
(41923, 1874, 12, '傾銷SQL總帳web目錄樹'),
(41924, 1875, 12, 'DUP檢查'),
(41925, 1876, 12, '重複的身分證明上線'),
(41926, 1877, 12, '重複的名字上線'),
(41927, 1878, 12, '重複的警告'),
(41928, 1879, 12, '檢察長的持久動力'),
(41929, 1880, 12, '持續時間'),
(41930, 1881, 12, '期間'),
(41931, 1882, 12, '荷蘭人'),
(41932, 1884, 12, '吞嚥困難'),
(41933, 1885, 12, '呼吸困難：'),
(41934, 1886, 12, '排尿困難'),
(41935, 1888, 12, '電子處方？'),
(41936, 1894, 12, '早期復發（<2個月）'),
(41937, 1895, 12, '耳朵'),
(41938, 1896, 12, '心電圖'),
(41939, 1898, 12, '水腫'),
(41940, 1902, 12, 'EDI的271檔案上傳'),
(41941, 1903, 12, 'EDI的271回應檔案上傳'),
(41942, 1904, 12, '編輯'),
(41943, 1905, 12, '編輯'),
(41944, 1906, 12, '編輯過敏'),
(41945, 1907, 12, '編輯類別'),
(41946, 1908, 12, '編輯定義'),
(41947, 1909, 12, '編輯定義'),
(41948, 1910, 12, '編輯診斷為'),
(41949, 1911, 12, '編輯披露'),
(41950, 1912, 12, '編輯設施'),
(41951, 1913, 12, '編輯設備'),
(41952, 1914, 12, '編輯設施資訊'),
(41953, 1916, 12, '編輯檔案在'),
(41954, 1917, 12, '編輯表單'),
(41955, 1918, 12, '編輯全球設置'),
(41956, 1920, 12, '編輯佈局'),
(41957, 1921, 12, '編輯清單'),
(41958, 1922, 12, '編輯付款'),
(41959, 1923, 12, '編輯結構'),
(41960, 1924, 12, '編輯使用者'),
(41961, 1925, 12, '編輯使用者設定'),
(41962, 1928, 12, '教育'),
(41963, 1929, 12, '教育日期'),
(41964, 1931, 12, 'EE* GNU通用公共許可證詳細信息。 **你應該已經收到隨著這一計劃的GNU通用公共許可證的副本;如果沒有，寫信給自由 '),
(41965, 1932, 12, '生效日期'),
(41966, 1934, 12, '效用'),
(41967, 1935, 12, 'EIN'),
(41968, 1936, 12, '射精'),
(41969, 1937, 12, '手肘'),
(41970, 1938, 12, '手肘問題'),
(41971, 1939, 12, '電子'),
(41972, 1942, 12, '電子匯款'),
(41973, 1944, 12, '合格'),
(41974, 1945, 12, '資格270詢問批次'),
(41975, 1946, 12, '資格回應'),
(41976, 1947, 12, '為兒童提供疫苗的疫苗資格獲得狀況'),
(41977, 1948, 12, '合格'),
(41978, 1949, 12, '電子郵件'),
(41979, 1951, 12, '電郵地址'),
(41980, 1953, 12, '病人提醒發件人的電子郵件地址。病人提醒的回覆將被引導到這個地址。使用您的診所的網域地址是很重要的，從去到垃圾郵件文件夾以避免幫助預防病人提醒。'),
(41981, 1954, 12, '電子郵件地址，如果有的話，收到行政通知。'),
(41982, 1955, 12, '電子郵件地址，如果有的話，接受緊急登錄使用者激活郵件。'),
(41983, 1956, 12, '電子郵件驗證'),
(41984, 1957, 12, '從批次COM的電子郵件'),
(41985, 1958, 12, '電子郵件通知'),
(41986, 1959, 12, '電子郵件通知時間'),
(41987, 1961, 12, '電子郵件發送之前'),
(41988, 1962, 12, '電子郵件發送者'),
(41989, 1963, 12, '發送電子郵件'),
(41990, 1965, 12, '電子郵件主題'),
(41991, 1966, 12, '電子郵件的文本，可用標籤：***姓名***，例如親愛的***姓名***'),
(41992, 1968, 12, '電子郵件傳送方式'),
(41993, 1969, 12, '電子郵件發送到以下地址'),
(41994, 1971, 12, '緊急聯絡'),
(41995, 1972, 12, '緊急聯絡人'),
(41996, 1973, 12, '緊急聯絡電話號碼'),
(41997, 1974, 12, '緊急避孕'),
(41998, 1975, 12, '緊急登錄'),
(41999, 1976, 12, '緊急登錄ACL被選擇。用戶仍處於活躍狀態，請取消激活用戶和在緊急情況下需要時激活相同。訪問管理“ - >”激活或去激活的用戶。'),
(42000, 1977, 12, '緊急登錄激活電子郵件將傳閱如果在接口/ globals.php文件配置符合以下設置：'),
(42001, 1978, 12, '緊急登錄的電郵地址'),
(42002, 1979, 12, '緊急登錄的用戶可以做任何事情'),
(42003, 1980, 12, '緊急電話'),
(42004, 1982, 12, '肺氣腫'),
(42005, 1983, 12, '雇員'),
(42006, 1984, 12, '单位'),
(42007, 1985, 12, '单位地址'),
(42008, 1986, 12, '单位資料'),
(42009, 1987, 12, '单位姓名'),
(42010, 1988, 12, '空的'),
(42011, 1989, 12, '空的'),
(42012, 1991, 12, '在“電子郵件時間”為空值'),
(42013, 1992, 12, '在“電子郵件發件人”為空值'),
(42014, 1993, 12, '在“郵件主題”為空值'),
(42015, 1994, 12, '在“電子郵件文本”為空值'),
(42016, 1995, 12, '在“提供者名稱”為空值'),
(42017, 1996, 12, '在“密碼”為空值'),
(42018, 1997, 12, '在“短訊時間”為空值'),
(42019, 1998, 12, '在“短訊文字”為空值'),
(42020, 1999, 12, '在“用戶名”為空值'),
(42021, 2006, 12, '允許資產管理公司的激勵'),
(42022, 2008, 12, '允許資產管理報告'),
(42023, 2009, 12, '允許資產管理公司追踪'),
(42024, 2011, 12, '允許ATNA審核'),
(42025, 2013, 12, '啟用審核日誌記錄'),
(42026, 2014, 12, '允許審計追踪和節點認證（ATNA）。'),
(42027, 2015, 12, '允許自動測量計算（AMC）的報告'),
(42028, 2016, 12, '允許客戶端SSL'),
(42029, 2017, 12, '允許客戶端SSL證書認證。'),
(42030, 2019, 12, '允許臨床決策規則“（CDR）'),
(42031, 2022, 12, '允許臨床質量測量（CQM）報告'),
(42032, 2023, 12, '允許臨床提醒彈出式視窗'),
(42033, 2024, 12, '允許臨床提醒構件'),
(42034, 2027, 12, '允許CQM報告'),
(42035, 2031, 12, '允許HylaFax等支持'),
(42036, 2037, 12, '允許實驗室交流'),
(42037, 2040, 12, '允許所有的SQL SELECT查詢的記錄。'),
(42038, 2041, 12, '允許日誌記錄備份的相關活動。'),
(42039, 2043, 12, '允許雜項活動的記錄。'),
(42040, 2044, 12, '允許排序活動的記錄。'),
(42041, 2045, 12, '允許病歷修改的記錄。'),
(42042, 2046, 12, '允許調度活動的記錄。'),
(42043, 2047, 12, '允許安全和管理活動的記錄。'),
(42044, 2049, 12, '允許NewCrop ERX服務'),
(42045, 2051, 12, '允許非現場患者門戶'),
(42046, 2052, 12, '允許非現場患者門戶'),
(42047, 2053, 12, '允許非現場患者門戶'),
(42048, 2055, 12, '允許非現場患者門戶'),
(42049, 2056, 12, '允許病人提醒構件'),
(42050, 2058, 12, '允許自動測量計算所需的數據（AMC）的激勵'),
(42051, 2060, 12, '允許自動測量計算日期（AMC）的追踪報告'),
(42052, 2061, 12, '允許掃描儀支持'),
(42053, 2065, 12, '允許LibreEHR支持LLC實驗室交流服務。'),
(42054, 2066, 12, '允許用戶證書驗證'),
(42055, 2067, 12, '允許ZMG，ERX服務有限責任公司'),
(42056, 2068, 12, '使能'),
(42057, 2070, 12, '使老費面板進入計費代碼和支付。不推薦使用收費表代替。'),
(42058, 2072, 12, '電子海圖'),
(42059, 2073, 12, '遭遇'),
(42060, 2074, 12, '遭遇'),
(42061, 2075, 12, '遭遇 '),
(42062, 2076, 12, '遇到急性住院或急診'),
(42063, 2081, 12, '遇到日期'),
(42064, 2086, 12, '遇到表格'),
(42065, 2087, 12, '遇到健康和行為評估'),
(42066, 2088, 12, '遇到歷史'),
(42067, 2089, 12, '遇到識別碼'),
(42068, 2090, 12, '遇到流感'),
(42069, 2091, 12, '遇到號碼'),
(42070, 2093, 12, '遇到護理出院'),
(42071, 2094, 12, '遇到護理設施'),
(42072, 2095, 12, '遇到職業治療'),
(42073, 2096, 12, '遇到辦公室訪問'),
(42074, 2097, 12, '遇到門診'),
(42075, 2098, 12, '遇到門診W / PCP及婦產科'),
(42076, 2099, 12, '遇到頁面大小'),
(42077, 2101, 12, '遇到懷孕'),
(42078, 2102, 12, '遇到預防醫學 - 個別諮商'),
(42079, 2103, 12, '遇到預防醫學40歲及以上'),
(42080, 2104, 12, '遇到預防醫學團體諮商'),
(42081, 2105, 12, '遇到預防醫學的其他服務'),
(42082, 2106, 12, '遇到預防醫學服務，18歲及以上'),
(42083, 2107, 12, '遇到精神與心理'),
(42084, 2108, 12, '遇到統計'),
(42085, 2109, 12, '遇到摘要'),
(42086, 2110, 12, '遇到編碼'),
(42087, 2111, 12, '遇到：'),
(42088, 2112, 12, '遇到：遇到非急性住院，門診，或眼科'),
(42089, 2113, 12, '遇到'),
(42090, 2114, 12, '遭遇與表格'),
(42091, 2115, 12, '遭遇與amp︰表格'),
(42092, 2116, 12, '遇到不授權'),
(42093, 2117, 12, '遭遇舉報'),
(42094, 2118, 12, '遭遇節'),
(42095, 2120, 12, '加密'),
(42096, 2121, 12, '結束'),
(42097, 2122, 12, '結束(年年年年-月月-日日) '),
(42098, 2123, 12, '結束日期'),
(42099, 2124, 12, '結束日期'),
(42100, 2126, 12, '結束日期應該大於開始日期'),
(42101, 2127, 12, '結束日期︰'),
(42102, 2131, 12, '結束時間'),
(42103, 2133, 12, '服務結束日期年年年年-月月-日日'),
(42104, 2134, 12, '如果你想進入一個範圍結束DOS月月/日日/年年年年'),
(42105, 2135, 12, '結束一天的小時日曆事件。'),
(42106, 2136, 12, '內膜不正常出血'),
(42107, 2137, 12, '內分泌'),
(42108, 2138, 12, '內視鏡'),
(42109, 2141, 12, '英文'),
(42110, 2142, 12, '英文 '),
(42111, 2143, 12, '英語（印度）'),
(42112, 2144, 12, '英語（標準）'),
(42113, 2145, 12, 'enscript命令由HylaFax使用'),
(42114, 2146, 12, '確保LibreEHR有寫權限的目錄'),
(42115, 2147, 12, '耳鼻喉分泌物'),
(42116, 2148, 12, '耳鼻喉疼痛'),
(42117, 2149, 12, '輸入診斷代碼排除所有不包含發票'),
(42118, 2151, 12, '在此處輸入信件的正文'),
(42119, 2152, 12, '輸入數據庫根密碼'),
(42120, 2153, 12, '輸入數據庫根的用戶名'),
(42121, 2154, 12, '輸入診斷'),
(42122, 2155, 12, '輸入藥物'),
(42123, 2158, 12, '輸入預防注射'),
(42124, 2159, 12, '輸入鍵'),
(42125, 2161, 12, '輸入新的國家'),
(42126, 2164, 12, '輸入再識別代碼'),
(42127, 2165, 12, '輸入您的上述搜索標準'),
(42128, 2168, 12, '環境的'),
(42129, 2169, 12, 'EOB資料條目'),
(42130, 2170, 12, '平等機會條例草案發帖 - 電子匯款'),
(42131, 2171, 12, '平等機會條例草案發帖 - 說明'),
(42132, 2172, 12, '平等機會條例草案發帖 - 發票'),
(42133, 2173, 12, '平等機會條例草案發帖 - 患者請注意'),
(42134, 2174, 12, '平等機會條例草案發帖 - 搜索'),
(42135, 2176, 12, '癲癇'),
(42136, 2178, 12, '自責 紀元 年代'),
(42137, 2180, 12, '年代發帖'),
(42138, 2181, 12, '刪除'),
(42139, 2182, 12, '勃起'),
(42140, 2183, 12, '錯誤'),
(42141, 2185, 12, '實驗室結果的錯誤確認收到'),
(42142, 2187, 12, '從實驗室交換網絡得到錯誤的實驗室結果'),
(42143, 2188, 12, '在“性別”選擇錯誤'),
(42144, 2189, 12, '“HIPAA法案”中的錯誤選擇'),
(42145, 2190, 12, '在“過程”選擇錯誤'),
(42146, 2191, 12, '在“短信網關”選擇錯誤'),
(42147, 2192, 12, '在“排序方式”的選擇錯誤'),
(42148, 2193, 12, '在GZIP壓縮文件中的錯誤： '),
(42149, 2194, 12, '在是或不是選項的錯誤'),
(42150, 2195, 12, '錯誤閱讀啟用上傳檔案'),
(42151, 2199, 12, '從實驗室交換網絡的錯誤檢索結果'),
(42152, 2202, 12, '授予LibreEHR使用者檔案權限時的錯誤。'),
(42153, 2205, 12, '在註冊表格的錯誤！'),
(42154, 2206, 12, '儲存檔案時出錯'),
(42155, 2208, 12, '寫入檔案時出錯'),
(42156, 2210, 12, '錯誤，檔案不存在'),
(42157, 2211, 12, '錯誤，無法從伺服器收集資料'),
(42158, 2212, 12, '錯誤，無法創建客戶端證書。'),
(42159, 2213, 12, '錯誤，無法創建admin.p12證書。'),
(42160, 2214, 12, '錯誤，無法創建的證書頒發機構證書。'),
(42161, 2215, 12, '錯誤，無法創建伺服器憑證。'),
(42162, 2216, 12, '錯誤，無法打開檔案'),
(42163, 2217, 12, '錯誤，用戶證書驗證無法在LibreEHR啟用'),
(42164, 2218, 12, '錯誤，你需要安裝存檔/ Tar.php的PHP模組。'),
(42165, 2219, 12, '錯誤：無法打開table.sql，破碎的形式？'),
(42166, 2220, 12, '錯誤：重複的識別碼上線'),
(42167, 2221, 12, '錯誤：重複的名稱上線'),
(42168, 2222, 12, '錯誤：字段'),
(42169, 2223, 12, '錯誤：缺少ZipArchive PHP模組'),
(42170, 2225, 12, '錯誤：密碼不符合。請檢查您的打字。'),
(42171, 2226, 12, '錯誤：密碼不符合。請檢查您的打字。'),
(42172, 2227, 12, '錯誤：檔案不存在'),
(42173, 2229, 12, '錯誤：無法複製檔案。'),
(42174, 2230, 12, '錯誤：無法創建下載的存檔'),
(42175, 2231, 12, '錯誤：無法創建Zip存檔。'),
(42176, 2232, 12, '錯誤：無法解壓縮檔案。'),
(42177, 2233, 12, '錯誤：無法將檔案載入到數據庫中。'),
(42178, 2234, 12, '錯誤：無法設置版本編號。'),
(42179, 2235, 12, '錯誤'),
(42180, 2236, 12, 'ERX帳戶狀態'),
(42181, 2238, 12, 'ERX的名稱'),
(42182, 2239, 12, 'ERX的密碼'),
(42183, 2240, 12, 'ERX的作用'),
(42184, 2241, 12, 'ERX使用者'),
(42185, 2242, 12, '紅斑：'),
(42186, 2245, 12, '愛斯基摩人');
INSERT INTO `lang_definitions` VALUES
(42187, 2247, 12, '建立病人'),
(42188, 2249, 12, '種族'),
(42189, 2250, 12, '民族或種族'),
(42190, 2251, 12, '種族劃分比賽名單（寫，addonly可選）'),
(42191, 2252, 12, '肉類'),
(42192, 2253, 12, '事件'),
(42193, 2254, 12, '活動開始'),
(42194, 2255, 12, '事件類別'),
(42195, 2256, 12, '事件的日期'),
(42196, 2257, 12, '事件描述'),
(42197, 2258, 12, '事件細節'),
(42198, 2259, 12, '事件無法重複'),
(42199, 2260, 12, '事件的持續時間'),
(42200, 2261, 12, '事件的持續時間在幾分鐘內'),
(42201, 2262, 12, '活動費用'),
(42202, 2263, 12, '活動地點'),
(42203, 2264, 12, '事件重複一次'),
(42204, 2265, 12, '事件重複在'),
(42205, 2266, 12, '事件的開始時間'),
(42206, 2267, 12, '事件標題'),
(42207, 2268, 12, '事件標題'),
(42208, 2269, 12, '活動網站'),
(42209, 2270, 12, '活動'),
(42210, 2271, 12, '對於事件'),
(42211, 2272, 12, '在新視窗開啟事件'),
(42212, 2273, 12, '每一個'),
(42213, 2274, 12, '每一個'),
(42214, 2275, 12, '每3小時'),
(42215, 2276, 12, '每4小時'),
(42216, 2277, 12, '每5小時'),
(42217, 2278, 12, '每6小時'),
(42218, 2279, 12, '每8小時'),
(42219, 2280, 12, '每四次'),
(42220, 2281, 12, '每隔'),
(42221, 2282, 12, '每三次'),
(42222, 2283, 12, '每一個，每次，每3個等'),
(42223, 2285, 12, '檢查和測試結果'),
(42224, 2286, 12, '檢查結果'),
(42225, 2289, 12, '檢查'),
(42226, 2290, 12, '檢查日期'),
(42227, 2291, 12, '舉例'),
(42228, 2292, 12, '舉例'),
(42229, 2293, 12, '檢查/測試'),
(42230, 2295, 12, '過多的流淚'),
(42231, 2296, 12, '排除患者'),
(42232, 2297, 12, '排除'),
(42233, 2298, 12, '獨家供應商組織（紅血球生成素）'),
(42234, 2300, 12, '運動'),
(42235, 2301, 12, '運動型態'),
(42236, 2302, 12, '運動型態'),
(42237, 2303, 12, '存在'),
(42238, 2304, 12, '由(當局)政府退出'),
(42239, 2305, 12, '進出口'),
(42240, 2306, 12, '擴大'),
(42241, 2307, 12, '擴大'),
(42242, 2308, 12, '全部展開'),
(42243, 2311, 12, '擴展視圖'),
(42244, 2312, 12, '預期form_encounter.pid是 '),
(42245, 2313, 12, '過期 吐氣'),
(42246, 2314, 12, '過期日期'),
(42247, 2315, 12, '過期'),
(42248, 2316, 12, '到期'),
(42249, 2317, 12, '出口 輸出'),
(42250, 2318, 12, '以CSV格式輸出'),
(42251, 2319, 12, '導出配置'),
(42252, 2322, 12, '輸出病人的人口統計資料'),
(42253, 2323, 12, '輸出PQRI報告'),
(42254, 2325, 12, '以CSV格式選擇的輸出'),
(42255, 2326, 12, '導出選定的集合'),
(42256, 2327, 12, '導出到CSV'),
(42257, 2328, 12, '導出到外部計費系統'),
(42258, 2329, 12, '暴露於國外'),
(42259, 2330, 12, '暴露於國外'),
(42260, 2331, 12, '分機時收取'),
(42261, 2332, 12, '外部 表面'),
(42262, 2336, 12, '外用辨認器'),
(42263, 2337, 12, '外用辨認器'),
(42264, 2338, 12, '外用辨認器'),
(42265, 2339, 12, '外部只有'),
(42266, 2342, 12, '外部轉診'),
(42267, 2343, 12, '外部轉診追踪'),
(42268, 2344, 12, '外部轉診'),
(42269, 2345, 12, '外部轉診'),
(42270, 2346, 12, '解壓zip檔案'),
(42271, 2347, 12, '解壓縮檔案。這將花費一些時間...'),
(42272, 2348, 12, '滲出液：'),
(42273, 2349, 12, '眼睛刺痛'),
(42274, 2350, 12, '眼睛疼痛'),
(42275, 2351, 12, '眼睛發红'),
(42276, 2352, 12, '眼睛'),
(42277, 2354, 12, 'F / H級的血液問題'),
(42278, 2355, 12, 'F / H級女性多毛症/皮紋'),
(42279, 2356, 12, '設備'),
(42280, 2357, 12, '設備'),
(42281, 2358, 12, '設備'),
(42282, 2359, 12, '基金管理'),
(42283, 2360, 12, '設施的城市'),
(42284, 2361, 12, '設備代碼'),
(42285, 2362, 12, '設施的的國家代碼'),
(42286, 2363, 12, '設施的傳真'),
(42287, 2364, 12, '設施的名稱'),
(42288, 2365, 12, '設施的非營利機構'),
(42289, 2366, 12, '設施的電話'),
(42290, 2368, 12, '設施的狀態'),
(42291, 2369, 12, '設施的街道'),
(42292, 2370, 12, '設施的郵遞區號'),
(42293, 2372, 12, '設施：'),
(42294, 2373, 12, '失敗'),
(42295, 2374, 12, '失敗的'),
(42296, 2375, 12, '失敗的'),
(42297, 2383, 12, '失敗'),
(42298, 2390, 12, '家族史'),
(42299, 2391, 12, '青光眼家族史'),
(42300, 2392, 12, '家族史：'),
(42301, 2394, 12, '家庭補助金'),
(42302, 2395, 12, '家庭規模'),
(42303, 2396, 12, '幻想'),
(42304, 2398, 12, '波斯語'),
(42305, 2400, 12, '父親'),
(42306, 2402, 12, '疲勞'),
(42307, 2403, 12, '疲勞'),
(42308, 2404, 12, '傳真'),
(42309, 2405, 12, '傳真計數'),
(42310, 2406, 12, '傳真號碼'),
(42311, 2408, 12, '傳真/掃描'),
(42312, 2409, 12, '在傳真'),
(42313, 2410, 12, '傳真輸出'),
(42314, 2411, 12, '特點'),
(42315, 2412, 12, '二月'),
(42316, 2413, 12, '二月'),
(42317, 2414, 12, 'FECA'),
(42318, 2415, 12, '聯邦藥物證明'),
(42319, 2416, 12, '聯邦的EIN'),
(42320, 2417, 12, '聯邦稅號'),
(42321, 2418, 12, '費用'),
(42322, 2419, 12, '費用'),
(42323, 2420, 12, '費用是不允許使用'),
(42324, 2421, 12, '收費表'),
(42325, 2422, 12, '費用表選項'),
(42326, 2423, 12, '費用'),
(42327, 2424, 12, '女性'),
(42328, 2425, 12, '女性懷孕'),
(42329, 2426, 12, '女用避孕套'),
(42330, 2427, 12, '女性G'),
(42331, 2428, 12, '女性立法'),
(42332, 2429, 12, '女性P級'),
(42333, 2430, 12, '女性的症狀'),
(42334, 2431, 12, '女性VSC'),
(42335, 2434, 12, '發燒'),
(42336, 2435, 12, '發燒：'),
(42337, 2436, 12, '家族性高膽固醇血症血液問題'),
(42338, 2437, 12, '子宮肌瘤'),
(42339, 2441, 12, '在國家人口統計學中单位或用戶使用的字段類型。'),
(42340, 2442, 12, '在州人口統計學中单位或用戶使用的字段類型。'),
(42341, 2443, 12, '場（S）失踪了！'),
(42342, 2447, 12, '檔案'),
(42343, 2448, 12, '在“文檔”目錄中的檔案，以了解如何創建日誌備份過程自動化'),
(42344, 2449, 12, '檔案的位置'),
(42345, 2450, 12, '檔案處理'),
(42346, 2453, 12, '檔案授予權限給LibreEHR用戶'),
(42347, 2455, 12, '檔案室'),
(42348, 2456, 12, '上傳檔案'),
(42349, 2458, 12, '具有相同名稱的檔案已經存在在位置：'),
(42350, 2459, 12, '檔案名稱'),
(42351, 2461, 12, '檔案'),
(42352, 2462, 12, '菲律賓'),
(42353, 2463, 12, '填寫下行所有'),
(42354, 2464, 12, '只有發送電子郵件通知病人在這裡填寫'),
(42355, 2465, 12, '填寫以下的值'),
(42356, 2467, 12, '填充這一行。'),
(42357, 2468, 12, '過濾'),
(42358, 2469, 12, '過濾常量'),
(42359, 2470, 12, '過濾的定義'),
(42360, 2473, 12, '過濾'),
(42361, 2474, 12, '最後'),
(42362, 2475, 12, '最後診斷'),
(42363, 2476, 12, '專家下的最後診斷'),
(42364, 2478, 12, '金融'),
(42365, 2479, 12, '財務結算日期(年年年年/月月/日日)'),
(42366, 2480, 12, '任何財務報告'),
(42367, 2481, 12, '財務報告 - 我的遭遇'),
(42368, 2482, 12, '財務審查日期'),
(42369, 2484, 12, '發現'),
(42370, 2485, 12, '找到可用的'),
(42371, 2486, 12, '找到可用的預約'),
(42372, 2487, 12, '找到病人'),
(42373, 2488, 12, '病患教育資源'),
(42374, 2489, 12, '發現'),
(42375, 2490, 12, '由專家發現'),
(42376, 2491, 12, '罰款'),
(42377, 2492, 12, '完成付款'),
(42378, 2495, 12, '第一'),
(42379, 2497, 12, '一週的第一天'),
(42380, 2498, 12, '名字'),
(42381, 2499, 12, '名字'),
(42382, 2500, 12, '名字：'),
(42383, 2503, 12, '適用性'),
(42384, 2504, 12, '體能程度'),
(42385, 2505, 12, '這個球員在這一天的體能程度'),
(42386, 2507, 12, '是否適合播放'),
(42387, 2508, 12, '修正遇到的日期 - 任何遭遇'),
(42388, 2509, 12, '解決這個問題'),
(42389, 2510, 12, '佛羅里達州'),
(42390, 2511, 12, '脹氣'),
(42391, 2512, 12, '流量'),
(42392, 2514, 12, '流感季節'),
(42393, 2515, 12, '流感季節'),
(42394, 2516, 12, '流感疫苗注射'),
(42395, 2517, 12, '液體與電解質問題'),
(42396, 2518, 12, '柔性製造系統'),
(42397, 2520, 12, '按照手動方式'),
(42398, 2522, 12, '追蹤'),
(42399, 2524, 12, '追蹤理由'),
(42400, 2525, 12, '下面是一個新的自訂常數：'),
(42401, 2526, 12, '下面是一個新的自訂語言：'),
(42402, 2527, 12, '下面是一個新的定義（語言，常數，定義）：'),
(42403, 2529, 12, '後續服務'),
(42404, 2530, 12, '追踪指示'),
(42405, 2531, 12, '食物不耐症'),
(42406, 2532, 12, '腳'),
(42407, 2533, 12, '足部問題'),
(42408, 2534, 12, '腳：'),
(42409, 2535, 12, '足球傷害'),
(42410, 2537, 12, '足球傷亡報告'),
(42411, 2538, 12, '鞋類類型'),
(42412, 2539, 12, '為 針對'),
(42413, 2540, 12, '為 針對'),
(42414, 2541, 12, '對於代碼'),
(42415, 2543, 12, '對於遭遇索賠'),
(42416, 2544, 12, '例如：'),
(42417, 2547, 12, '發票'),
(42418, 2548, 12, '為了醫療保險，強迫 提供者要和 提供者一樣。'),
(42419, 2552, 12, '所提的組織/實踐者'),
(42420, 2553, 12, '在過去'),
(42421, 2554, 12, '為可變'),
(42422, 2555, 12, '為：'),
(42423, 2556, 12, '部隊帳單控件開啟'),
(42424, 2557, 12, '迫使建立新病人'),
(42425, 2559, 12, '前臂'),
(42426, 2560, 12, '表格'),
(42427, 2561, 12, '表格'),
(42428, 2564, 12, '格式化'),
(42429, 2565, 12, '格式化'),
(42430, 2567, 12, '格式化不正確的國防委員會'),
(42431, 2568, 12, '格式化用於顯示最多的日期'),
(42432, 2569, 12, '格式化用於顯示最多的時間'),
(42433, 2570, 12, '格式化的報告'),
(42434, 2571, 12, '原吸煙者'),
(42435, 2572, 12, '形式 表單'),
(42436, 2573, 12, '表格管理'),
(42437, 2576, 12, '向前頁經由傳真'),
(42438, 2577, 12, '轉發 送交'),
(42439, 2579, 12, '第四個 四次'),
(42440, 2581, 12, '骨折'),
(42441, 2582, 12, '舟狀骨骨折'),
(42442, 2583, 12, '外踝骨折'),
(42443, 2584, 12, '內踝骨折'),
(42444, 2585, 12, '骨折，第五（五）蹠骨底'),
(42445, 2587, 12, '法國人'),
(42446, 2590, 12, '頻率'),
(42447, 2591, 12, '經常感冒'),
(42448, 2592, 12, '經常生病'),
(42449, 2593, 12, '星期五'),
(42450, 2594, 12, '星期五'),
(42451, 2595, 12, '從'),
(42452, 2596, 12, '從'),
(42453, 2597, 12, '從'),
(42454, 2598, 12, '從不能比迄今為止更大的日期。'),
(42455, 2599, 12, '來自：'),
(42456, 2600, 12, '來自： '),
(42457, 2601, 12, '來自城市'),
(42458, 2613, 12, '前台辦公室'),
(42459, 2614, 12, '前台辦公室收據'),
(42460, 2615, 12, '前台辦公室收益報告'),
(42461, 2616, 12, '接待記錄'),
(42462, 2617, 12, '右額葉：'),
(42463, 2619, 12, '全名'),
(42464, 2620, 12, '包含MySQL可執行程序的目錄得完整路徑。'),
(42465, 2621, 12, '包含Perl可執行程序的目錄的完整路徑。'),
(42466, 2622, 12, '事件日誌備份目錄的完整路徑。'),
(42467, 2623, 12, '用於暫存檔案的目錄的完整路徑。'),
(42468, 2624, 12, '充分發揮'),
(42469, 2625, 12, '完整的訓練'),
(42470, 2626, 12, '全數支付'),
(42471, 2634, 12, 'G/DL'),
(42472, 2636, 12, '膽囊情況'),
(42473, 2637, 12, '膽結石'),
(42474, 2638, 12, '比賽期間'),
(42475, 2639, 12, '遊戲 運動會'),
(42476, 2640, 12, '遊戲錯過'),
(42477, 2641, 12, '遊戲/事件'),
(42478, 2642, 12, '遊戲/事件錯過'),
(42479, 2644, 12, '胃炎'),
(42480, 2645, 12, '胃痛'),
(42481, 2646, 12, '腸胃道的'),
(42482, 2647, 12, 'GCAC統計報告'),
(42483, 2648, 12, 'GCAC統計'),
(42484, 2649, 12, 'GCAC訪問表單失踪'),
(42485, 2650, 12, '性別'),
(42486, 2651, 12, '性別 '),
(42487, 2652, 12, '性別的'),
(42488, 2655, 12, '一般服務類別'),
(42489, 2657, 12, '創造和下載CMS1500文件索賠'),
(42490, 2658, 12, '創造和下載HCFA1500文件索賠'),
(42491, 2659, 12, '生成並下載X12的批次'),
(42492, 2660, 12, '生成並下載X12的遭遇索賠批次'),
(42493, 2663, 12, '以電子方式生成和傳輸允許的處方。'),
(42494, 2664, 12, '創造CMS1500'),
(42495, 2665, 12, '創造CMS1500PDF'),
(42496, 2666, 12, '創造CMS1500案文'),
(42497, 2667, 12, '創造HCFA'),
(42498, 2669, 12, '創造的信'),
(42499, 2670, 12, '創造的信有關 '),
(42500, 2671, 12, '創造PQRI報告（A法）'),
(42501, 2673, 12, '創造PQRI報告（E法）'),
(42502, 2677, 12, '創造的報告'),
(42503, 2678, 12, '創造用戶名和密碼'),
(42504, 2679, 12, '創造X12的'),
(42505, 2680, 12, '創造X12的遭遇'),
(42506, 2682, 12, '製作於'),
(42507, 2683, 12, '產生'),
(42508, 2684, 12, '泌尿生殖系統'),
(42509, 2687, 12, '德國人'),
(42510, 2691, 12, '得到的HL7'),
(42511, 2692, 12, '青光眼'),
(42512, 2693, 12, '青光眼家族史'),
(42513, 2694, 12, '全球'),
(42514, 2696, 12, '全球認證'),
(42515, 2697, 12, '全球設置'),
(42516, 2698, 12, '全局數據'),
(42517, 2699, 12, 'GM/DL'),
(42518, 2700, 12, '去'),
(42519, 2701, 12, '去'),
(42520, 2704, 12, '到'),
(42521, 2705, 12, '轉到星期的'),
(42522, 2706, 12, '今天去'),
(42523, 2711, 12, '受傷程度'),
(42524, 2712, 12, '程度：'),
(42525, 2713, 12, '公克'),
(42526, 2714, 12, '累計'),
(42527, 2715, 12, '總計'),
(42528, 2718, 12, 'Graphable'),
(42529, 2720, 12, '大於'),
(42530, 2721, 12, '大於或等於'),
(42531, 2722, 12, '希臘語'),
(42532, 2724, 12, '團體 組'),
(42533, 2725, 12, '組名'),
(42534, 2726, 12, '組名不能空白'),
(42535, 2727, 12, '團體名稱不能用數字開始或空格。'),
(42536, 2728, 12, '團體名稱不能用數字開始。'),
(42537, 2729, 12, '團體號碼'),
(42538, 2730, 12, '團體支付'),
(42539, 2731, 12, '組：'),
(42540, 2732, 12, '組的名稱'),
(42541, 2733, 12, '團體和存取控制'),
(42542, 2734, 12, '生長曲線圖'),
(42543, 2735, 12, '生長曲線圖'),
(42544, 2736, 12, '滴'),
(42545, 2737, 12, 'Guamanian'),
(42546, 2739, 12, '監護人的姓名'),
(42547, 2741, 12, '婦科檢查'),
(42548, 2743, 12, '睡前'),
(42549, 2744, 12, '肝癌病史'),
(42550, 2745, 12, '已經成功刪除。如果存在任何次類別已被移到下面'),
(42551, 2746, 12, '血腫/瘀傷'),
(42552, 2747, 12, '紅血球凝集抑制作用情形'),
(42553, 2750, 12, '手+手指'),
(42554, 2751, 12, '手的問題'),
(42555, 2753, 12, '無困難'),
(42556, 2754, 12, '已經與訪視連結'),
(42557, 2755, 12, '已過期'),
(42558, 2756, 12, '散列'),
(42559, 2757, 12, '哈希不存在於此文件。產生一個新的哈希。'),
(42560, 2758, 12, '哈希不匹配。資料的完整性被破壞。'),
(42561, 2760, 12, '夏威夷'),
(42562, 2761, 12, '危險活動'),
(42563, 2762, 12, '危險活動'),
(42564, 2763, 12, '以點為HCFA左邊距'),
(42565, 2764, 12, 'HCFA保證金'),
(42566, 2765, 12, '以點為HCFA上邊距'),
(42567, 2767, 12, '他張貼日曆 '),
(42568, 2768, 12, '頭'),
(42569, 2769, 12, '頭圍'),
(42570, 2770, 12, '頭圍'),
(42571, 2771, 12, '頭痛'),
(42572, 2772, 12, '頭痛'),
(42573, 2773, 12, '醫療保健業務'),
(42574, 2774, 12, '醫療保健業務'),
(42575, 2775, 12, '健康中心/診所'),
(42576, 2776, 12, '健康維護組織'),
(42577, 2777, 12, '健康維護組織（HMO）醫療保險風險'),
(42578, 2778, 12, '聽力喪失'),
(42579, 2779, 12, '心臟病發作'),
(42580, 2780, 12, '心臟疾病'),
(42581, 2781, 12, '心衰竭'),
(42582, 2782, 12, '心臟問題'),
(42583, 2783, 12, '心臟問題'),
(42584, 2784, 12, '心臟手術'),
(42585, 2785, 12, '心臟移植'),
(42586, 2786, 12, '心臟：'),
(42587, 2787, 12, '胃灼熱'),
(42588, 2788, 12, '熱或冷'),
(42589, 2789, 12, '熱或冷'),
(42590, 2791, 12, '希伯來文'),
(42591, 2793, 12, '頭眼睛耳朵鼻子喉嚨'),
(42592, 2794, 12, '身高'),
(42593, 2796, 12, '幫助'),
(42594, 2797, 12, '幫助'),
(42595, 2798, 12, '吐血'),
(42596, 2799, 12, '便血'),
(42597, 2800, 12, '血液學'),
(42598, 2801, 12, '血尿'),
(42599, 2802, 12, '血色素'),
(42600, 2803, 12, '糖化血紅蛋白'),
(42601, 2804, 12, '咯血'),
(42602, 2805, 12, '肝炎'),
(42603, 2806, 12, 'A型肝炎1'),
(42604, 2807, 12, 'A型肝炎2'),
(42605, 2808, 12, 'B型肝炎1'),
(42606, 2809, 12, 'B型肝炎2'),
(42607, 2810, 12, 'B型肝炎3'),
(42608, 2811, 12, '這裡'),
(42609, 2813, 12, '疝氣修補'),
(42610, 2814, 12, '椎間盤突出'),
(42611, 2815, 12, '皰疹'),
(42612, 2816, 12, '猶豫'),
(42613, 2817, 12, 'heyyo。你一直在這裡為 '),
(42614, 2818, 12, 'B型嗜血桿菌疫苗1'),
(42615, 2819, 12, 'B型嗜血桿菌疫苗2'),
(42616, 2820, 12, 'B型嗜血桿菌疫苗3'),
(42617, 2821, 12, 'B型嗜血桿菌疫苗4'),
(42618, 2822, 12, '隱藏'),
(42619, 2823, 12, '政務隱藏事件'),
(42620, 2824, 12, '隱藏'),
(42621, 2825, 12, '隱藏的詳情'),
(42622, 2827, 12, '隱藏在文檔管理的加密/解密選項'),
(42623, 2828, 12, '隱藏菜單'),
(42624, 2831, 12, '隱藏/顯示列'),
(42625, 2833, 12, '高'),
(42626, 2834, 12, '高血壓'),
(42627, 2835, 12, '印地文'),
(42628, 2836, 12, '髖部+腹股溝'),
(42629, 2837, 12, '髖部與腹股溝'),
(42630, 2838, 12, '髖部問題'),
(42631, 2839, 12, '髖關節置換'),
(42632, 2840, 12, 'HIPAA收到的通知'),
(42633, 2842, 12, '多毛/皮紋'),
(42634, 2843, 12, '西班牙裔美國人'),
(42635, 2844, 12, '其他拉美裔（生於美國）'),
(42636, 2845, 12, '西班牙裔美國人 - （美國以外出生）'),
(42637, 2846, 12, '西班牙裔或拉丁裔'),
(42638, 2847, 12, '歷史'),
(42639, 2848, 12, '歷史數據'),
(42640, 2849, 12, '歷史數據'),
(42641, 2851, 12, '雜音史'),
(42642, 2852, 12, '無授權史'),
(42643, 2853, 12, '心臟雜音史'),
(42644, 2854, 12, '次數'),
(42645, 2855, 12, '人類免疫缺失病毒'),
(42646, 2858, 12, 'HL7的瀏覽器'),
(42647, 2860, 12, 'HMOL/L'),
(42648, 2861, 12, '苗族'),
(42649, 2862, 12, '按住[Ctrl]鍵可多重選擇或取消選擇'),
(42650, 2863, 12, '按住Ctrl鍵選取多個項目'),
(42651, 2864, 12, '按住Ctrl鍵選擇多個小隊'),
(42652, 2865, 12, '首頁'),
(42653, 2866, 12, '家裡電話'),
(42654, 2867, 12, '家裡電話號碼'),
(42655, 2868, 12, '無家可歸者或類似的嗎？'),
(42656, 2869, 12, '無家可歸者，等等'),
(42657, 2870, 12, '無家可歸者，等等。'),
(42658, 2872, 12, '主機名稱'),
(42659, 2873, 12, '主機名稱不能是空白'),
(42660, 2875, 12, '小時'),
(42661, 2876, 12, '小時'),
(42662, 2878, 12, '傷害是怎麼發生？'),
(42663, 2879, 12, '傷害是怎麼發生？'),
(42664, 2880, 12, '他們是如何得知我們'),
(42665, 2881, 12, '多少個月提前為即將到來的事件查詢？'),
(42666, 2882, 12, '華能國際：'),
(42667, 2883, 12, '羥色胺 高溫'),
(42668, 2884, 12, 'HTML'),
(42669, 2886, 12, 'HTTPS連結LibreEHR支持LLC實驗室交換服務。'),
(42670, 2888, 12, 'HylaFax目錄'),
(42671, 2889, 12, 'HylaFax等Enscript指令'),
(42672, 2890, 12, 'HylaFAX服務器'),
(42673, 2891, 12, 'HylaFAX服務器的主機名。'),
(42674, 2892, 12, '亢進 過度活躍'),
(42675, 2893, 12, '高血壓'),
(42676, 2894, 12, '高血壓：血壓測量'),
(42677, 2895, 12, '高血壓：血壓測量（CQM）'),
(42678, 2896, 12, '甲狀腺功能亢進症'),
(42679, 2897, 12, '甲狀腺功能過低症'),
(42680, 2898, 12, '子宮切除術'),
(42681, 2900, 12, '我這段時間忙。'),
(42682, 2901, 12, '我沒有權限讀取 '),
(42683, 2902, 12, '國際疾病分類'),
(42684, 2905, 12, '國際疾病分類9'),
(42685, 2909, 12, '身份證 識別碼'),
(42686, 2910, 12, '身份證 識別碼'),
(42687, 2911, 12, '身份證 不能空白'),
(42688, 2912, 12, '身分證'),
(42689, 2913, 12, 'IDays'),
(42690, 2914, 12, '確定為'),
(42691, 2915, 12, '標識符（一個字）'),
(42692, 2917, 12, '閒置工作階段逾秒'),
(42693, 2919, 12, '如果所有列的所有數據都完成這種形式'),
(42694, 2920, 12, '如果使用計費的理由是輸入診斷代碼類型的名稱。'),
(42695, 2921, 12, '如果進入，只能選擇有此服務的那些'),
(42696, 2922, 12, '如果名稱，任何部分姓氏或姓氏，名字'),
(42697, 2923, 12, '如果支付'),
(42698, 2924, 12, '如果人去世了，那麼輸入死亡日期。'),
(42699, 2925, 12, '如果使用SMTP，服務器的主機名或IP位址。'),
(42700, 2926, 12, '如果使用SMTP，服務器的TCP連接埠號碼（通常為25）。'),
(42701, 2927, 12, '如果無業 輸入學生'),
(42702, 2929, 12, '如果您更改E-RX對ePrescription的角色，它可能會影響ePrescription工作流程。如果您遇到任何困難，請聯繫您ePrescription供應商'),
(42703, 2931, 12, '如果您已選擇上傳電子匯款，然後從X12檔案在搜索窗口重新顯示匹配的發票。你可以點擊任何這些發票號碼（如下所述）如果你想在已經使用匯款信息之前進行任何修改，請單擊頁面底部的過程ERA檔案按鈕，這將產生一份有詳細的報告的新窗口。'),
(42704, 2932, 12, '如果你在搜索頁面輸入付費的日期，這將覆蓋付費的張貼的日期，否則要從X12檔案取得，調整過帳日期。這可能是有用的報告目的，如果你想你的收益報告使用您張貼的日期，而不是保險公司“處理日期。注意，這也將影響到二次索賠事先支付和調整的日期。'),
(42705, 2933, 12, '如果你想改變數據類型，或添加行或列'),
(42706, 2934, 12, '如果你要升級資料庫，然後將資料庫zip檔案放置如果你要升級的資料庫，然後將其放置資料庫zip文件在以下目錄中在以下目錄中'),
(42707, 2936, 12, '忽略'),
(42708, 2937, 12, '疾病'),
(42709, 2938, 12, '肌肉注射'),
(42710, 2941, 12, '影像服務'),
(42711, 2942, 12, '免疫'),
(42712, 2943, 12, '免疫編碼'),
(42713, 2945, 12, '免疫日期'),
(42714, 2947, 12, '免疫批號'),
(42715, 2948, 12, '免疫製造商'),
(42716, 2949, 12, '免疫登記'),
(42717, 2951, 12, '免疫服務'),
(42718, 2952, 12, '免疫標題'),
(42719, 2953, 12, '免疫接種'),
(42720, 2954, 12, '免疫接種'),
(42721, 2955, 12, '免疫'),
(42722, 2956, 12, '植入'),
(42723, 2957, 12, '進口'),
(42724, 2961, 12, '證書導入到瀏覽器。'),
(42725, 2962, 12, '導入配置'),
(42726, 2964, 12, '導入病人'),
(42727, 2965, 12, '導入病人的人口統計資料'),
(42728, 2969, 12, '從會計導入'),
(42729, 2972, 12, '改善'),
(42730, 2973, 12, '在'),
(42731, 2974, 12, '在'),
(42732, 2975, 12, '在每隻眼睛'),
(42733, 2976, 12, '在左眼'),
(42734, 2977, 12, '在鼻孔'),
(42735, 2978, 12, '在辦公室'),
(42736, 2979, 12, '在右眼'),
(42737, 2980, 12, '在內部'),
(42738, 2981, 12, '不活動 無效'),
(42739, 2982, 12, '不活躍的日子'),
(42740, 2983, 12, '收件箱'),
(42741, 2986, 12, '包括校驗'),
(42742, 2987, 12, '包括完成'),
(42743, 2988, 12, '包括不活躍用戶'),
(42744, 2989, 12, '包括未分類'),
(42745, 2990, 12, '包括非結構化資料'),
(42746, 2991, 12, '包括生命徵象'),
(42747, 2992, 12, '包括生命徵象資料？'),
(42748, 2993, 12, '列入'),
(42749, 2994, 12, '收入'),
(42750, 2996, 12, '不完全'),
(42751, 2997, 12, '不完全流產治療'),
(42752, 2998, 12, '失禁'),
(42753, 2999, 12, '將臨床實驗室的測試結果納入認證的電子病歷技術當成結構化資料。'),
(42754, 3001, 12, '增加：'),
(42755, 3002, 12, '賠償保險'),
(42756, 3003, 12, '不確定'),
(42757, 3004, 12, '印度'),
(42758, 3005, 12, '顯示異常'),
(42759, 3006, 12, '顯示，如果這個問題目前是積極的'),
(42760, 3008, 12, '使用專門的指標'),
(42761, 3009, 12, '貧困的病人'),
(42762, 3010, 12, '貧困的病人報告'),
(42763, 3011, 12, '貧民'),
(42764, 3014, 12, '人工流產'),
(42765, 3016, 12, '不合格'),
(42766, 3017, 12, '感染/膿腫'),
(42767, 3018, 12, '感染'),
(42768, 3019, 12, '插入硬幣'),
(42769, 3020, 12, '不孕症'),
(42770, 3021, 12, '流感1'),
(42771, 3022, 12, '流感2'),
(42772, 3023, 12, '流感疫苗接種的病人>= 50歲'),
(42773, 3024, 12, '流感疫苗接種的病人>= 50歲(CQM)'),
(42774, 3025, 12, '流感疫苗'),
(42775, 3026, 12, '信息'),
(42776, 3027, 12, '信息測試1'),
(42777, 3028, 12, '信息測試2'),
(42778, 3029, 12, '信息測試3'),
(42779, 3030, 12, '信息測試4'),
(42780, 3031, 12, '信息測試5'),
(42781, 3032, 12, '信息測試6'),
(42782, 3034, 12, '吸入'),
(42783, 3035, 12, 'inhilations'),
(42784, 3037, 12, '最初的用戶'),
(42785, 3038, 12, '損傷/康復'),
(42786, 3039, 12, '注射劑'),
(42787, 3040, 12, '注射劑'),
(42788, 3041, 12, '受傷的身體部位'),
(42789, 3042, 12, '受傷的'),
(42790, 3043, 12, '傷害'),
(42791, 3044, 12, '損傷機轉'),
(42792, 3045, 12, '損傷的概述報告'),
(42793, 3046, 12, '傷害監測'),
(42794, 3047, 12, '損傷類型'),
(42795, 3048, 12, '傷害/疾病相關'),
(42796, 3051, 12, '輸入字段'),
(42797, 3052, 12, '印度盧比'),
(42798, 3056, 12, '插件調整'),
(42799, 3057, 12, '插件捆綁'),
(42800, 3058, 12, '插件代碼'),
(42801, 3061, 12, '插件多繳'),
(42802, 3063, 12, '移民局退款'),
(42803, 3064, 12, '移民局摘要'),
(42804, 3065, 12, '移民局1'),
(42805, 3066, 12, '移民局2'),
(42806, 3067, 12, '移民局3'),
(42807, 3069, 12, '插入失敗： '),
(42808, 3070, 12, '插入到表中的舊事件'),
(42809, 3072, 12, '失眠'),
(42810, 3074, 12, '檢查'),
(42811, 3075, 12, '不穩定/半脫位'),
(42812, 3077, 12, '安裝'),
(42813, 3079, 12, '安裝數據庫'),
(42814, 3081, 12, '指示'),
(42815, 3082, 12, '指示'),
(42816, 3084, 12, '說明：'),
(42817, 3086, 12, '胰島素依賴型糖尿病'),
(42818, 3087, 12, '保險'),
(42819, 3088, 12, '保險'),
(42820, 3093, 12, '保險訓練班'),
(42821, 3094, 12, '保險公司'),
(42822, 3095, 12, '保險公司'),
(42823, 3096, 12, '保險公司的搜尋/添加'),
(42824, 3098, 12, '保險數據'),
(42825, 3099, 12, '文件上的保險資料'),
(42826, 3100, 12, '保險號碼'),
(42827, 3101, 12, '給付保險金'),
(42828, 3103, 12, '保險提供者'),
(42829, 3107, 12, '攝入結論'),
(42830, 3108, 12, '攝入日期'),
(42831, 3109, 12, '智力下降'),
(42832, 3113, 12, '內部錯誤 - 沒有頁面選擇！'),
(42833, 3114, 12, '內部錯誤 - 沒有提供病人身份！'),
(42834, 3115, 12, '內部錯誤存取上傳的文件！'),
(42835, 3116, 12, '內部錯誤'),
(42836, 3117, 12, '內部錯誤，沒有指定的藥物編號！'),
(42837, 3119, 12, '內部錯誤：索賠 '),
(42838, 3120, 12, '內部錯誤：遇到'''),
(42839, 3121, 12, '內部錯誤：pid或遇到遺漏。'),
(42840, 3123, 12, '內部標識符（PID）'),
(42841, 3126, 12, '內部轉介'),
(42842, 3127, 12, '內部時間收集'),
(42843, 3128, 12, '國際義務'),
(42844, 3129, 12, '口譯員'),
(42845, 3130, 12, '需要口譯員嗎？'),
(42846, 3131, 12, '間質性肺疾病'),
(42847, 3132, 12, '間隔'),
(42848, 3135, 12, '介入'),
(42849, 3137, 12, '無法耐受'),
(42850, 3139, 12, '肌肉注射的'),
(42851, 3140, 12, '靜脈注射的'),
(42852, 3141, 12, '簡介'),
(42853, 3144, 12, '無效的字符在'),
(42854, 3147, 12, '無效的長度'),
(42855, 3148, 12, '無效的非數字字符'),
(42856, 3149, 12, '無效或遺失的付款人在代碼源 '),
(42857, 3151, 12, '無效的服務代碼'),
(42858, 3152, 12, '指定無效的源“'),
(42859, 3154, 12, 'InvAmt'),
(42860, 3155, 12, '庫存'),
(42861, 3156, 12, '清查活動'),
(42862, 3157, 12, '庫存和銷售兩種藥物和非藥物產品'),
(42863, 3158, 12, '僅清點和推銷藥品'),
(42864, 3159, 12, '庫存是不是按此順序。'),
(42865, 3160, 12, '庫存清單'),
(42866, 3161, 12, '庫存交易'),
(42867, 3162, 12, '發票'),
(42868, 3163, 12, '發票'),
(42869, 3166, 12, '發票日期'),
(42870, 3167, 12, '發票沒有日期'),
(42871, 3168, 12, '發票號碼'),
(42872, 3169, 12, '發票參考編號'),
(42873, 3170, 12, '如果有使用，發票參考號碼池'),
(42874, 3171, 12, '發票參考號碼池'),
(42875, 3172, 12, '只是發票Refno池'),
(42876, 3173, 12, '發票'),
(42877, 3174, 12, '國際計劃生育聯合會'),
(42878, 3177, 12, '國際計劃生育聯合會生殖健康數據'),
(42879, 3178, 12, '國際計劃生育聯合會統計報告'),
(42880, 3179, 12, '國際計劃生育聯合會統計'),
(42881, 3180, 12, '注射式小兒麻痺疫苗(沙克疫苗)1'),
(42882, 3181, 12, '注射式小兒麻痺疫苗(沙克疫苗)2'),
(42883, 3182, 12, '注射式小兒麻痺疫苗(沙克疫苗)3'),
(42884, 3183, 12, '注射式小兒麻痺疫苗(沙克疫苗)4'),
(42885, 3185, 12, '心跳不規則'),
(42886, 3186, 12, '易怒'),
(42887, 3187, 12, '刺激'),
(42888, 3191, 12, '是必填字段。'),
(42889, 3192, 12, '是一個根節點，並不能刪除。'),
(42890, 3197, 12, '是無效的（小數都OK）。'),
(42891, 3198, 12, 'PHP是使用安全模式？'),
(42892, 3200, 12, '是要翻譯的文字形式佈局？'),
(42893, 3201, 12, '是從清單的文字進行翻譯？'),
(42894, 3202, 12, '是文件加密？'),
(42895, 3204, 12, '這是一個診斷類型嗎？'),
(42896, 3212, 12, '這種類型是隱藏在收費表？'),
(42897, 3214, 12, '太長'),
(42898, 3216, 12, '問題'),
(42899, 3217, 12, '問題'),
(42900, 3218, 12, '發行日期'),
(42901, 3219, 12, '問題編號'),
(42902, 3220, 12, '問題標題'),
(42903, 3223, 12, '問題'),
(42904, 3224, 12, '問題（傷害/醫療/過敏）'),
(42905, 3225, 12, '問題（傷害/醫療/過敏）：'),
(42906, 3226, 12, '問題和遭遇'),
(42907, 3227, 12, '問題和遭遇的'),
(42908, 3228, 12, '未經授權的議題'),
(42909, 3229, 12, '問題部分'),
(42910, 3230, 12, '意大利的'),
(42911, 3231, 12, '項目'),
(42912, 3232, 12, '項目'),
(42913, 3234, 12, '項目負荷失敗'),
(42914, 3235, 12, '子宮內的/L'),
(42915, 3236, 12, '子宮內避孕器'),
(42916, 3237, 12, '經靜脈'),
(42917, 3238, 12, '一月'),
(42918, 3239, 12, '一月'),
(42919, 3240, 12, '日本人'),
(42920, 3241, 12, '黃疸'),
(42921, 3243, 12, '職位描述'),
(42922, 3244, 12, '作業識別碼'),
(42923, 3245, 12, '關節脫位'),
(42924, 3246, 12, '關節疼痛'),
(42925, 3247, 12, '關節扭傷'),
(42926, 3248, 12, '七月'),
(42927, 3249, 12, '七月'),
(42928, 3250, 12, '六月'),
(42929, 3251, 12, '六月'),
(42930, 3252, 12, '就在檢查信息的下面，是您把您的搜索參數放在一個藍色的區域。您可以按病人的姓名，病歷號碼，遇到號碼或服務的日期，或這些的任意組合進行搜索。你也可以選擇是否要看到所有的發票，開的發票，或者是由病人的唯一發票。點擊“搜索”按鈕進行搜索。'),
(42931, 3253, 12, '只是我'),
(42932, 3255, 12, '辯解'),
(42933, 3256, 12, '理由/保存'),
(42934, 3258, 12, 'K，這裡是其餘的'),
(42935, 3265, 12, '關鍵字'),
(42936, 3266, 12, '公斤'),
(42937, 3267, 12, '公斤/平方公尺'),
(42938, 3269, 12, '腎臟癌'),
(42939, 3270, 12, '腎臟衰竭'),
(42940, 3271, 12, '腎炎'),
(42941, 3272, 12, '腎結石'),
(42942, 3273, 12, '腎臟移植'),
(42943, 3277, 12, '膝 膝關節'),
(42944, 3278, 12, '膝蓋問題'),
(42945, 3279, 12, '膝關節置換術'),
(42946, 3282, 12, '韓國'),
(42947, 3286, 12, '實驗室'),
(42948, 3288, 12, '實驗室交換網站地址'),
(42949, 3289, 12, '實驗室交換網站編號'),
(42950, 3290, 12, '實驗室交換憑證識別碼'),
(42951, 3294, 12, '實驗室查詢狀態'),
(42952, 3295, 12, '實驗報告'),
(42953, 3296, 12, '實驗結果'),
(42954, 3297, 12, '實驗結果'),
(42955, 3299, 12, '實驗結果報告'),
(42956, 3300, 12, '實驗室服務'),
(42957, 3301, 12, '實驗室測試結果'),
(42958, 3303, 12, '標籤'),
(42959, 3304, 12, '標籤不能空白'),
(42960, 3305, 12, 'Label Cols'),
(42961, 3307, 12, 'LabelCols必須是1和999之間的一個數字'),
(42962, 3308, 12, '標籤'),
(42963, 3311, 12, '實驗室'),
(42964, 3312, 12, '裂傷/皮膚狀況'),
(42965, 3313, 12, '撕裂/磨損'),
(42966, 3316, 12, '語言'),
(42967, 3317, 12, '語言代碼'),
(42968, 3318, 12, '語言定義的補充'),
(42969, 3319, 12, '語言界面工具'),
(42970, 3320, 12, '語言列表（寫，addonly可選）'),
(42971, 3321, 12, '語言名稱'),
(42972, 3322, 12, '語言：'),
(42973, 3324, 12, '老撾語'),
(42974, 3325, 12, '最後'),
(42975, 3326, 12, '上次活動日期'),
(42976, 3328, 12, '最後法案日期：'),
(42977, 3330, 12, '上一歷年'),
(42978, 3333, 12, '最後相逢'),
(42979, 3343, 12, '上個月'),
(42980, 3344, 12, '姓'),
(42981, 3345, 12, '姓'),
(42982, 3346, 12, '姓：'),
(42983, 3350, 12, '最新評論'),
(42984, 3352, 12, '最後保存'),
(42985, 3356, 12, '最後更新'),
(42986, 3357, 12, '最後驗證'),
(42987, 3358, 12, '最後訪問'),
(42988, 3360, 12, '晚期復發（2-12莫）'),
(42989, 3361, 12, '外踝'),
(42990, 3362, 12, '外踝：'),
(42991, 3363, 12, '偏側'),
(42992, 3364, 12, '此過程中偏側化，如適用'),
(42993, 3365, 12, '側面取代採購經理指數：'),
(42994, 3373, 12, '版式的基礎'),
(42995, 3374, 12, '佈局編輯器'),
(42996, 3375, 12, '版式組'),
(42997, 3376, 12, '佈局樣式'),
(42998, 3378, 12, '基於佈局的訪問表格'),
(42999, 3379, 12, '佈局'),
(43000, 3380, 12, '磅'),
(43001, 3381, 12, '磅'),
(43002, 3382, 12, '低密度脂蛋白'),
(43003, 3383, 12, '留下空白，如果仍然活躍'),
(43004, 3384, 12, '留空以保持原有檔名'),
(43005, 3385, 12, '留空密碼保持不變。'),
(43006, 3386, 12, '留下訊息'),
(43007, 3387, 12, '留下表單'),
(43008, 3388, 12, '留下通行短語留空將不能加密文件'),
(43009, 3390, 12, '左側 離開 留下'),
(43010, 3391, 12, '左耳'),
(43011, 3392, 12, '左耳'),
(43012, 3394, 12, '左側：'),
(43013, 3395, 12, '左側： '),
(43014, 3396, 12, '腿部疼痛/痙攣'),
(43015, 3397, 12, '法律'),
(43016, 3400, 12, '圖例：'),
(43017, 3401, 12, '長度'),
(43018, 3402, 12, '如果沒有修飾符的長度，0'),
(43019, 3403, 12, '小於'),
(43020, 3404, 12, '小於或等於'),
(43021, 3405, 12, '較少的私人信息（寫，addonly可選）'),
(43022, 3406, 12, '信件 字母'),
(43023, 3407, 12, '字母產生器'),
(43024, 3409, 12, '醫生簽名的信紙'),
(43025, 3410, 12, '病人簽名的信紙'),
(43026, 3411, 12, '緊急級別'),
(43027, 3412, 12, '責任'),
(43028, 3413, 12, '責任醫療'),
(43029, 3414, 12, '執照/ 識別碼 身分證'),
(43030, 3419, 12, '有執照處方者姓氏'),
(43031, 3420, 12, '有執照處方者新產品引進'),
(43032, 3421, 12, '有執照處方者的UPIN'),
(43033, 3423, 12, '生活方式'),
(43034, 3424, 12, '生活方式的狀態'),
(43035, 3425, 12, '韌帶撕裂或扭傷'),
(43036, 3428, 12, '極限活動'),
(43037, 3431, 12, '連接'),
(43038, 3433, 12, '連接'),
(43039, 3436, 12, '連接文件'),
(43040, 3438, 12, '名單'),
(43041, 3439, 12, '列表框'),
(43042, 3440, 12, '列表框'),
(43043, 3441, 12, '列表框瓦特/附加'),
(43044, 3442, 12, '列表框瓦特/附加'),
(43045, 3443, 12, '列表編輯器'),
(43046, 3444, 12, '名單中遇到'),
(43047, 3445, 12, '列表組'),
(43048, 3446, 12, '列表保險公司'),
(43049, 3448, 12, '列表中的項目，不能以數字開頭。'),
(43050, 3449, 12, '列表中的項目包含不合法的字元（S）。'),
(43051, 3451, 12, '列出名單'),
(43052, 3452, 12, '列表名稱'),
(43053, 3453, 12, '列表的名稱不能以數字啟動。'),
(43054, 3454, 12, '列表處方'),
(43055, 3455, 12, '由上述國家的數據類型選項列表。'),
(43056, 3456, 12, '由上述州的數據類型選項列表。'),
(43057, 3457, 12, '聽力的RFC5425 TLS syslog服務器的端口。'),
(43058, 3458, 12, '列表'),
(43059, 3460, 12, '生前遺囑'),
(43060, 3461, 12, '微光：'),
(43061, 3462, 12, '低熔點'),
(43062, 3464, 12, '負載定義'),
(43063, 3470, 12, '加載'),
(43064, 3471, 12, '檔案加載到數據庫中。這將花費一些時間...'),
(43065, 3472, 12, '組委會'),
(43066, 3473, 12, '當地'),
(43067, 3476, 12, '區域設置'),
(43068, 3477, 12, '方位'),
(43069, 3478, 12, '位置'),
(43070, 3479, 12, 'libreehr機的位置，並可能包含敏感數據，因此建議在使用後手動刪除該文件'),
(43071, 3480, 12, '這個地段的位置'),
(43072, 3481, 12, '地點不詳'),
(43073, 3482, 12, '位置HylaFax等商店傳真。'),
(43074, 3483, 12, '掃描存儲的位置。'),
(43075, 3484, 12, '地點：'),
(43076, 3485, 12, '鎖'),
(43077, 3492, 12, '登錄'),
(43078, 3494, 12, '註銷'),
(43079, 3495, 12, '登錄'),
(43080, 3496, 12, '登錄為'),
(43081, 3497, 12, '登錄為： '),
(43082, 3498, 12, '註銷。'),
(43083, 3500, 12, '登錄'),
(43084, 3501, 12, '登錄'),
(43085, 3505, 12, '註銷'),
(43086, 3506, 12, '註銷'),
(43087, 3507, 12, '日誌'),
(43088, 3508, 12, '日誌查看器'),
(43089, 3510, 12, '查找'),
(43090, 3511, 12, '很多'),
(43091, 3512, 12, '地段識別碼失踪！'),
(43092, 3513, 12, '批號'),
(43093, 3514, 12, '低'),
(43094, 3516, 12, '下肢'),
(43095, 3519, 12, '腰椎'),
(43096, 3520, 12, '午餐'),
(43097, 3521, 12, '午餐'),
(43098, 3522, 12, '肺癌'),
(43099, 3523, 12, '肺癌手術'),
(43100, 3524, 12, '肺的：'),
(43101, 3525, 12, '肺的：'),
(43102, 3526, 12, '狼瘡'),
(43103, 3529, 12, '專員類別'),
(43104, 3530, 12, '專員客戶接受流產'),
(43105, 3531, 12, '專員統計'),
(43106, 3533, 12, '郵件發送'),
(43107, 3534, 12, '主要'),
(43108, 3535, 12, '主要地址'),
(43109, 3536, 12, '熱門面板顯示屏'),
(43110, 3537, 12, '保持積極的藥物過敏名單。'),
(43111, 3538, 12, '保持積極的藥物名單。'),
(43112, 3539, 12, '保持當前和積極的診斷的最新問題清單。'),
(43113, 3540, 12, '當前類別作出修改。'),
(43114, 3541, 12, '作出新的預約'),
(43115, 3542, 12, '確保“'),
(43116, 3543, 12, '上傳結算所批處理文本文件，將標誌著作為帳單'),
(43117, 3545, 12, '身體不適：'),
(43118, 3548, 12, '男性'),
(43119, 3549, 12, '男性保險套'),
(43120, 3550, 12, '男性輸精管結紮術'),
(43121, 3552, 12, '乳房X光檢查'),
(43122, 3553, 12, '處理'),
(43123, 3556, 12, '處理翻譯'),
(43124, 3557, 12, '管理'),
(43125, 3558, 12, '強制性和指定的領域'),
(43126, 3559, 12, '只有強制性或指定字段，DUP檢查，沒有搜尋'),
(43127, 3560, 12, '只有強制或指定領域，搜尋和dup檢查'),
(43128, 3561, 12, '手冊'),
(43129, 3562, 12, '手冊紀錄'),
(43130, 3563, 12, '製造商'),
(43131, 3565, 12, '三月'),
(43132, 3568, 12, '三月'),
(43133, 3569, 12, '婚姻狀態'),
(43134, 3571, 12, '標記為已開帳單，但略過計費'),
(43135, 3572, 12, '標記為已清除'),
(43136, 3573, 12, '標記為未開帳單'),
(43137, 3575, 12, '標記為已清除'),
(43138, 3576, 12, '已婚的'),
(43139, 3578, 12, '面罩'),
(43140, 3579, 12, '發票號碼的掩碼'),
(43141, 3580, 12, '為病人標識掩碼'),
(43142, 3581, 12, '掩碼的產品標識'),
(43143, 3582, 12, '符合'),
(43144, 3591, 12, '最大'),
(43145, 3594, 12, '右上頜：'),
(43146, 3595, 12, '最大年齡'),
(43147, 3597, 12, '在註銷之前幾秒鐘的最大閒置時間。默認值是7200（2小時）。'),
(43148, 3603, 12, '五月'),
(43149, 3604, 12, '管委會'),
(43150, 3605, 12, '微克'),
(43151, 3607, 12, '當更改密碼時，是指最後三個密碼都不允許。'),
(43152, 3609, 12, '測量群組代碼'),
(43153, 3611, 12, '測量'),
(43154, 3612, 12, '內踝：'),
(43155, 3613, 12, '醫療補助'),
(43156, 3614, 12, '醫學'),
(43157, 3615, 12, '藥物流產'),
(43158, 3616, 12, '醫療管理'),
(43159, 3617, 12, '醫學史'),
(43160, 3618, 12, '醫療問題'),
(43161, 3619, 12, '醫療問題'),
(43162, 3620, 12, '醫療問題'),
(43163, 3623, 12, '醫療問題'),
(43164, 3624, 12, '醫療紀錄'),
(43165, 3625, 12, '醫療記錄＃'),
(43166, 3626, 12, '醫療紀錄'),
(43167, 3627, 12, '發送的醫療記錄'),
(43168, 3629, 12, '給出病歷摘要'),
(43169, 3630, 12, '醫療系統'),
(43170, 3631, 12, '醫療型態'),
(43171, 3632, 12, '醫學/歷史（寫，addonly可選）'),
(43172, 3633, 12, '醫療保險B部分'),
(43173, 3634, 12, '醫療保險轉介者是呈現程序'),
(43174, 3635, 12, '藥物'),
(43175, 3636, 12, '藥物過敏清單'),
(43176, 3638, 12, '藥物清單'),
(43177, 3639, 12, '服藥調節執行嗎？'),
(43178, 3640, 12, '藥物'),
(43179, 3641, 12, '藥物：'),
(43180, 3642, 12, '醫學單位'),
(43181, 3643, 12, '中等 媒介'),
(43182, 3645, 12, '會員協會統計報告'),
(43183, 3646, 12, '記憶體問題'),
(43184, 3647, 12, '男性'),
(43185, 3648, 12, '男性與女性'),
(43186, 3649, 12, '只有男性'),
(43187, 3650, 12, '初潮'),
(43188, 3651, 12, '停經'),
(43189, 3652, 12, '月經量'),
(43190, 3653, 12, '月經頻率'),
(43191, 3654, 12, '精神疾病'),
(43192, 3661, 12, '訊息'),
(43193, 3666, 12, '訊息狀態'),
(43194, 3670, 12, '訊息：'),
(43195, 3671, 12, '訊息'),
(43196, 3673, 12, '方法'),
(43197, 3674, 12, '方法和特定產品'),
(43198, 3675, 12, '傳出的電子郵件發送方法。'),
(43199, 3676, 12, '銷毀方法'),
(43200, 3677, 12, '墨西哥/ MexAmer的/墨裔美國人'),
(43201, 3679, 12, '毫克'),
(43202, 3680, 12, '毫克/1毫升'),
(43203, 3681, 12, '毫克/2毫升'),
(43204, 3682, 12, '毫克/3毫升'),
(43205, 3683, 12, '毫克/4毫升'),
(43206, 3684, 12, '毫克/5毫升'),
(43207, 3685, 12, '毫克/升'),
(43208, 3686, 12, '中間'),
(43209, 3687, 12, '中間名字'),
(43210, 3688, 12, '中間名字'),
(43211, 3690, 12, '中級處方DEA'),
(43212, 3691, 12, '中級處方名'),
(43213, 3692, 12, '中級處方姓氏'),
(43214, 3693, 12, '中級處方首碼'),
(43215, 3694, 12, '中級處方的UPIN'),
(43216, 3695, 12, '風采'),
(43217, 3696, 12, '農民或季節性工人嗎？'),
(43218, 3697, 12, '移民/季節'),
(43219, 3698, 12, 'Mil/立方公釐'),
(43220, 3702, 12, 'Mime類型'),
(43221, 3703, 12, '分'),
(43222, 3704, 12, '分'),
(43223, 3705, 12, '最小年紀'),
(43224, 3706, 12, '輕微的關節扭傷+/ - 滑膜炎'),
(43225, 3708, 12, '分鐘'),
(43226, 3709, 12, '分鐘'),
(43227, 3710, 12, '分鐘'),
(43228, 3712, 12, '其他類別'),
(43229, 3713, 12, '其他類別帳單選項'),
(43230, 3714, 12, '其他類別結算方式HCFA-1500'),
(43231, 3715, 12, '其他類別帳單選項HCFA'),
(43232, 3716, 12, '雜項'),
(43233, 3717, 12, '錯過'),
(43234, 3718, 12, '失踪'),
(43235, 3719, 12, '缺少必要的字段'),
(43236, 3720, 12, '遺失費用'),
(43237, 3721, 12, '只遺失MODS'),
(43238, 3722, 12, '遺失或無效'),
(43239, 3723, 12, '椎間盤脫出缺失。'),
(43240, 3724, 12, '遺失報告的日期'),
(43241, 3725, 12, '代碼源的付款人之後遺失斜線 '),
(43242, 3726, 12, '混合'),
(43243, 3727, 12, '毫升'),
(43244, 3728, 12, '月月/日日/年年年年'),
(43245, 3729, 12, '毫米/汞柱'),
(43246, 3730, 12, '毫米汞柱'),
(43247, 3731, 12, '麻疹德國麻疹腮腺炎疫苗1'),
(43248, 3732, 12, '麻疹德國麻疹腮腺炎疫苗2'),
(43249, 3733, 12, '移動'),
(43250, 3734, 12, '行動電話'),
(43251, 3735, 12, '按付款當日價格計算 國防部'),
(43252, 3741, 12, '修改器'),
(43253, 3745, 12, '修改付款方式'),
(43254, 3746, 12, '中期長度'),
(43255, 3753, 12, '星期一'),
(43256, 3754, 12, '週一至週五'),
(43257, 3755, 12, '逢星期一，三，五'),
(43258, 3756, 12, '星期一'),
(43259, 3758, 12, '月'),
(43260, 3759, 12, '月'),
(43261, 3760, 12, '按月查看'),
(43262, 3761, 12, '月'),
(43263, 3762, 12, '月收入'),
(43264, 3763, 12, '幾個月'),
(43265, 3765, 12, '超過100筆記錄。請縮小您的搜尋條件。'),
(43266, 3766, 12, '超過50筆的結果，請讓你的搜尋更具體。'),
(43267, 3768, 12, '最近從'),
(43268, 3770, 12, '從最近期的生命徵象：'),
(43269, 3771, 12, '母親'),
(43270, 3772, 12, '母親的姓名'),
(43271, 3774, 12, '嘴'),
(43272, 3775, 12, '移動'),
(43273, 3776, 12, '移動文件類別：'),
(43274, 3777, 12, '向下移動'),
(43275, 3779, 12, '移至病人'),
(43276, 3780, 12, '移動到...'),
(43277, 3781, 12, '向上移動'),
(43278, 3783, 12, '先生'),
(43279, 3785, 12, '女士'),
(43280, 3786, 12, '小姐'),
(43281, 3796, 12, '多語言工具'),
(43282, 3797, 12, '多個領域'),
(43283, 3799, 12, '多個地段'),
(43284, 3802, 12, '多種族'),
(43285, 3803, 12, '雜音：'),
(43286, 3804, 12, '肌肉酸痛'),
(43287, 3805, 12, '肌肉酸痛'),
(43288, 3806, 12, '肌肉發紅'),
(43289, 3807, 12, '肌肉僵硬'),
(43290, 3808, 12, '肌肉腫脹'),
(43291, 3809, 12, '肌肉溫暖'),
(43292, 3810, 12, '肌肉'),
(43293, 3811, 12, '肌肉傷害'),
(43294, 3812, 12, '肌肉骨骼的'),
(43295, 3813, 12, '如果不使用SMTP身份驗證，必須是空的。'),
(43296, 3814, 12, '共同定義'),
(43297, 3815, 12, '製造業增加值'),
(43298, 3821, 12, '不適合的'),
(43299, 3822, 12, '不適合的'),
(43300, 3823, 12, '名字 名稱'),
(43301, 3825, 12, '名稱（點擊查看更多）'),
(43302, 3826, 12, '名稱1'),
(43303, 3827, 12, '名稱2'),
(43304, 3828, 12, '免疫系統管理員的名稱和標題'),
(43305, 3831, 12, '活動名稱'),
(43306, 3832, 12, '保險公司名稱'),
(43307, 3833, 12, '供應商名稱'),
(43308, 3834, 12, '病人提醒發件人的名稱。'),
(43309, 3835, 12, '翻譯名稱'),
(43310, 3836, 12, '名稱/價值'),
(43311, 3837, 12, '名稱：'),
(43312, 3838, 12, '鼻腔： 鼻孔'),
(43313, 3839, 12, '鼻孔：右側正常'),
(43314, 3840, 12, '鼻腔粘膜粉紅色，鼻中隔正中'),
(43315, 3841, 12, '國家債券'),
(43316, 3842, 12, '國家債券配置'),
(43317, 3844, 12, '國籍'),
(43318, 3845, 12, '國家債券'),
(43319, 3847, 12, '夏威夷原住民或其他太平洋島民'),
(43320, 3852, 12, '噁心'),
(43321, 3854, 12, '導航'),
(43322, 3855, 12, '導航區域包括相遇形式'),
(43323, 3856, 12, '導航區域採用全高度的框架'),
(43324, 3857, 12, '導航區參觀形式'),
(43325, 3858, 12, '導航區域寬度'),
(43326, 3859, 12, '導航菜單包括配對單選按鈕'),
(43327, 3860, 12, '導航菜單是一個樹視圖'),
(43328, 3861, 12, '導航採用的是滑動菜單'),
(43329, 3862, 12, '國家數據中心'),
(43330, 3864, 12, '國家數據中心編號'),
(43331, 3866, 12, '頸部'),
(43332, 3867, 12, '頸部問題'),
(43333, 3868, 12, '頸部柔軟'),
(43334, 3869, 12, '需要輸入一個描述'),
(43335, 3870, 12, '需要輸入一個返回值'),
(43336, 3871, 12, '需要輸入標識符'),
(43337, 3872, 12, '需要輸入標題'),
(43338, 3873, 12, '需要驗證'),
(43339, 3874, 12, '需要對齊'),
(43340, 3875, 12, '需要二次計費'),
(43341, 3876, 12, '陰性'),
(43342, 3877, 12, '陰性'),
(43343, 3880, 12, '神經受損'),
(43344, 3881, 12, '神經情況/神經損傷'),
(43345, 3882, 12, '神經麻木'),
(43346, 3883, 12, '神經虛弱'),
(43347, 3884, 12, '神經系統的'),
(43348, 3885, 12, '從不'),
(43349, 3886, 12, '從不喝酒'),
(43350, 3887, 12, '從不抽菸'),
(43351, 3888, 12, '新'),
(43352, 3889, 12, '新 =>'),
(43353, 3890, 12, '新的受體'),
(43354, 3892, 12, '新的過敏'),
(43355, 3894, 12, '新的任命'),
(43356, 3895, 12, '新類別'),
(43357, 3896, 12, '新類別'),
(43358, 3897, 12, '新個案'),
(43359, 3898, 12, '新的諮詢'),
(43360, 3899, 12, '新作物'),
(43361, 3900, 12, '新的定義設置添加'),
(43362, 3901, 12, '新文檔'),
(43363, 3904, 12, '相遇'),
(43364, 3906, 12, '相遇表'),
(43365, 3907, 12, '新的遭遇未授權'),
(43366, 3908, 12, 'New Enctr'),
(43367, 3909, 12, '新設施資訊'),
(43368, 3912, 12, '新群組'),
(43369, 3913, 12, '新群組資訊'),
(43370, 3914, 12, '新的損傷/狀態'),
(43371, 3916, 12, '事件的新限制'),
(43372, 3917, 12, '新表單'),
(43373, 3918, 12, '新醫囑'),
(43374, 3919, 12, '新段落'),
(43375, 3920, 12, '新密碼'),
(43376, 3921, 12, '新病人'),
(43377, 3922, 12, '新病人'),
(43378, 3923, 12, '新病人遭遇'),
(43379, 3924, 12, '新病人表單'),
(43380, 3925, 12, '新病人身分證'),
(43381, 3926, 12, '新的付款方式'),
(43382, 3928, 12, '新病人'),
(43383, 3929, 12, '來自實驗室交易所的新結果'),
(43384, 3930, 12, '新的搜尋'),
(43385, 3931, 12, '新的提名'),
(43386, 3932, 12, '新用戶'),
(43387, 3934, 12, '新的訪問'),
(43388, 3935, 12, '新/搜索'),
(43389, 3936, 12, 'NewCrop帳戶狀態'),
(43390, 3937, 12, 'NewCrop管理'),
(43391, 3938, 12, 'NewCrop呼叫失敗'),
(43392, 3939, 12, 'NewCrop醫生'),
(43393, 3944, 12, 'NewCrop ERX名字'),
(43394, 3945, 12, 'NewCrop ERX合作夥伴名字'),
(43395, 3946, 12, 'NewCrop ERX密碼'),
(43396, 3947, 12, 'NewCrop ERX的的角色'),
(43397, 3948, 12, 'NewCrop ERX的的角色'),
(43398, 3949, 12, 'NewCrop ERX網站地址'),
(43399, 3954, 12, 'NewCrop的ERX網絡服務地址'),
(43400, 3955, 12, 'NewCrop經理'),
(43401, 3956, 12, 'NewCrop MedEntry'),
(43402, 3957, 12, 'NewCrop中層處方'),
(43403, 3958, 12, 'NewCrop護士'),
(43404, 3959, 12, 'NewCrop監督醫生'),
(43405, 3961, 12, '報紙'),
(43406, 3962, 12, '下一個'),
(43407, 3964, 12, '第二天'),
(43408, 3965, 12, '下個月'),
(43409, 3966, 12, '下個月（持有選單）'),
(43410, 3968, 12, '下週'),
(43411, 3969, 12, '明年（持有選單）'),
(43412, 3971, 12, '暱稱'),
(43413, 3973, 12, '夜間盜汗'),
(43414, 3974, 12, 'nL的外生殖器，陰道粘膜，子宮頸'),
(43415, 3975, 12, '不'),
(43416, 3976, 12, '不'),
(43417, 3977, 12, '禁止存取'),
(43418, 3978, 12, '患者沒有主動提醒。'),
(43419, 3979, 12, '無淋巴結腫大（​​需要2個區域）'),
(43420, 3980, 12, '沒有調整的原因類型發現'),
(43421, 3981, 12, '沒有皮膚附屬器壓痛/腫塊'),
(43422, 3983, 12, '沒有預約'),
(43423, 3985, 12, '目前沒有計費系統是主動的'),
(43424, 3987, 12, '沒有找到文件包括氧氟沙星出口參考'),
(43425, 3989, 12, '沒有指定代碼！'),
(43426, 3992, 12, '沒有診斷'),
(43427, 3993, 12, '沒有找到檔案'),
(43428, 3995, 12, '沒有結束日期'),
(43429, 3996, 12, '沒有內容，使用下面的表格添加一個條目。'),
(43430, 3997, 12, '沒有找到錯誤'),
(43431, 3998, 12, '沒有事件'),
(43432, 4001, 12, '沒有群組被選中'),
(43433, 4002, 12, '沒有疝氣'),
(43434, 4005, 12, '沒有傷害/疾病'),
(43435, 4006, 12, '沒有保險公司發現'),
(43436, 4007, 12, '沒有問題'),
(43437, 4009, 12, '根據所選的類別沒有項目'),
(43438, 4010, 12, '沒有項目被選中！'),
(43439, 4027, 12, '沒有腫塊，壓痛'),
(43440, 4028, 12, '對於所給再識別代碼，沒有發現符合的病人紀錄'),
(43441, 4031, 12, '沒有找到任何相符。創建新的病人嗎？'),
(43442, 4033, 12, '沒有找到新的研究結果'),
(43443, 4034, 12, '沒有注意到'),
(43444, 4035, 12, '沒有器官腫大'),
(43445, 4036, 12, '發現此期間沒有開口。'),
(43446, 4037, 12, '沒有其他的電話號碼'),
(43447, 4039, 12, '沒有找到合作夥伴'),
(43448, 4040, 12, '對於給的選擇標準中，沒有符合的病人記錄'),
(43449, 4041, 12, '對於給的再識別代碼，沒有符合的病人記錄'),
(43450, 4042, 12, '無周邊水腫'),
(43451, 4043, 12, '沒有找到藥房'),
(43452, 4044, 12, '沒有找到處方'),
(43453, 4045, 12, '沒有呈現疾病/損傷'),
(43454, 4046, 12, '沒有以前的條目。'),
(43455, 4051, 12, '沒有找到提供者'),
(43456, 4052, 12, '沒有皮疹或異常病變'),
(43457, 4053, 12, '沒有找到記錄。'),
(43458, 4055, 12, '沒有找到記錄。請擴大您的搜尋條件。'),
(43459, 4057, 12, '對於上述搜索條件，沒有發現結果。'),
(43460, 4058, 12, '沒有結果'),
(43461, 4060, 12, '搜尋沒有發現結果'),
(43462, 4062, 12, '沒有結果，請再試一次。'),
(43463, 4063, 12, '沒有結果，請再試試看'),
(43464, 4065, 12, '無顯示'),
(43465, 4067, 12, '無竇壓痛：'),
(43466, 4068, 12, '沒有皮膚壓痕或乳腺結節'),
(43467, 4069, 12, '沒有這樣的上下文名稱'),
(43468, 4071, 12, '沒有睾丸壓痛，腫塊'),
(43469, 4072, 12, '沒有驚險刺激或拋擲'),
(43470, 4075, 12, '沒有訪問'),
(43471, 4076, 12, '沒有已被記錄的生命徵象。'),
(43472, 4077, 12, '不，取消'),
(43473, 4079, 12, '不：'),
(43474, 4080, 12, '夜尿'),
(43475, 4081, 12, '非付費'),
(43476, 4082, 12, '非已報告的報告'),
(43477, 4083, 12, '非特異性損傷'),
(43478, 4084, 12, '非電子化的'),
(43479, 4085, 12, '非胰島素依賴型糖尿病'),
(43480, 4087, 12, '非生殖健康醫療'),
(43481, 4088, 12, '非生殖健康的非醫療'),
(43482, 4089, 12, '沒有'),
(43483, 4090, 12, '沒有'),
(43484, 4091, 12, '沒有定義'),
(43485, 4092, 12, '沒有被記錄在案');
INSERT INTO `lang_definitions` VALUES
(43486, 4093, 12, '以上皆非'),
(43487, 4094, 12, '沒有頂端分布行能夠完全地空白。'),
(43488, 4095, 12, '非胰島素依賴型糖尿病'),
(43489, 4096, 12, '也不'),
(43490, 4097, 12, '正常'),
(43491, 4098, 12, '正常的“基本法”'),
(43492, 4099, 12, '正常心臟檢查：'),
(43493, 4100, 12, '正常心臟檢查： '),
(43494, 4101, 12, '正常肺臟檢查：'),
(43495, 4102, 12, '正常肺臟檢查： '),
(43496, 4103, 12, '普通辦公室訪問'),
(43497, 4104, 12, '正常口咽：'),
(43498, 4105, 12, '右側正常'),
(43499, 4106, 12, '右側正常：'),
(43500, 4107, 12, '普通視圖'),
(43501, 4108, 12, '正常：'),
(43502, 4109, 12, '通常，這應該要檢查。與存取控制無關。'),
(43503, 4112, 12, '挪威'),
(43504, 4115, 12, '鼻子'),
(43505, 4116, 12, '流鼻血'),
(43506, 4117, 12, '不是一個字母或數字'),
(43507, 4119, 12, '並不是所有的領域都需要所有代碼或代碼類型。'),
(43508, 4120, 12, '不允許'),
(43509, 4121, 12, '不允許刪除管理員群組'),
(43510, 4122, 12, '不允許編輯'),
(43511, 4123, 12, '不允許鈍化所有保障對象'),
(43512, 4124, 12, '不允許從管理員訪問控制列表鈍化任何事情'),
(43513, 4125, 12, '不允許從管理員群組刪除管理員用戶'),
(43514, 4126, 12, '不允許從管理員群組刪除此用戶'),
(43515, 4128, 12, '未經授權存取郵政日曆模塊'),
(43516, 4129, 12, '未經授權'),
(43517, 4130, 12, '未經授權'),
(43518, 4132, 12, '這支球隊沒有授權。'),
(43519, 4135, 12, '不提供'),
(43520, 4137, 12, '不收費'),
(43521, 4138, 12, '不檢查'),
(43522, 4139, 12, '未簽出'),
(43523, 4141, 12, '不是因為'),
(43524, 4143, 12, '沒有檢查'),
(43525, 4144, 12, '沒有檢查：'),
(43526, 4145, 12, '沒有檢查： '),
(43527, 4146, 12, '沒有找到'),
(43528, 4148, 12, '沒有找到！'),
(43529, 4149, 12, '非西班牙裔或拉丁裔'),
(43530, 4152, 12, '以來從未見過'),
(43531, 4154, 12, '尚未發送'),
(43532, 4156, 12, '未指定。'),
(43533, 4157, 12, '注意 筆記 註解'),
(43534, 4159, 12, '你點擊安裝後，注意將需要5-10分鐘充分處理'),
(43535, 4160, 12, '你點擊更新後，注意將需要5-10分鐘充分處理'),
(43536, 4161, 12, '請注意，審計記錄需要能啟用上方'),
(43537, 4162, 12, '紀錄形式'),
(43538, 4168, 12, '注意：此代碼沒有被授權的用戶進入。只有經授權的代碼可能會被上傳到公開處理醫療帳單網絡。如果你想上傳這些代碼，請在這裡選擇一個授權用戶。'),
(43539, 4170, 12, '注意：上傳文件名稱重複會導致文件自動改名（例如，file.jpg將成為file.1.jpg）。文件名每名患者被認為是獨特的，不是每個類別。'),
(43540, 4171, 12, '注意：上傳文件名稱重複會導致文件自動改名。例如“<I> file.jpg</ I>''將成為''<I> file.jpg.1</ I>”。文件名每名患者被認為是獨特的，不是每個類別。'),
(43541, 4172, 12, '筆記'),
(43542, 4173, 12, '注意 - 任何遭遇（寫，addonly可選）'),
(43543, 4174, 12, '注意 - 我的遭遇（寫，addonly可選）'),
(43544, 4175, 12, '未授權的筆記'),
(43545, 4177, 12, '沒有記錄'),
(43546, 4179, 12, '沒有什麼導入過敏'),
(43547, 4180, 12, '沒有什麼導入處方'),
(43548, 4182, 12, '沒有什麼被選中'),
(43549, 4184, 12, '公告::張貼日曆提交/修改'),
(43550, 4185, 12, '通知'),
(43551, 4186, 12, '通知電子郵件地址'),
(43552, 4188, 12, '通知'),
(43553, 4189, 12, '關於事件提交/修改通知管理員了嗎？'),
(43554, 4190, 12, '十一月'),
(43555, 4191, 12, '十一月'),
(43556, 4192, 12, '現在張貼：'),
(43557, 4193, 12, '現在列印'),
(43558, 4194, 12, '現在列印$ stmt的計數報表和更新遭遇。'),
(43559, 4195, 12, '現在列印$ stmt的計數報表和更新發票。'),
(43560, 4196, 12, '現在列印$ stmt的計數報表;遭遇將不會被更新。'),
(43561, 4197, 12, '現在列印$ stmt的計數報表;發票將不會被更新。'),
(43562, 4198, 12, '非營利機構'),
(43563, 4199, 12, 'NQF'),
(43564, 4200, 12, '數目 號碼'),
(43565, 4201, 12, '號碼實驗室'),
(43566, 4204, 12, '年度視圖中的列號碼。'),
(43567, 4211, 12, '客戶端證書的天號碼是有效的。'),
(43568, 4213, 12, '在貨幣的小數點後面，通常是0或2位數的號碼。'),
(43569, 4214, 12, '每頁顯示遇到的數目。'),
(43570, 4215, 12, '如果有遊戲或事件的號碼遺漏'),
(43571, 4216, 12, '提前發送電子郵件通知的時數。'),
(43572, 4217, 12, '提前發送電話通知的時數。'),
(43573, 4218, 12, '提前發送短信通知的時數。'),
(43574, 4221, 12, '過去歷史列的號碼'),
(43575, 4223, 12, '麻木'),
(43576, 4224, 12, '分子 計算者'),
(43577, 4225, 12, '數字顯示順序'),
(43578, 4227, 12, '營養'),
(43579, 4229, 12, 'O.A.F.V.'),
(43580, 4230, 12, '氧氣飽和度'),
(43581, 4231, 12, '第一度肥胖'),
(43582, 4232, 12, '第二度肥胖'),
(43583, 4233, 12, '第三度肥胖'),
(43584, 4234, 12, '目標'),
(43585, 4237, 12, '職業'),
(43586, 4239, 12, '發生'),
(43587, 4240, 12, '十月'),
(43588, 4241, 12, '十月'),
(43589, 4242, 12, '右眼 外徑'),
(43590, 4243, 12, '的'),
(43591, 4244, 12, '的數量'),
(43592, 4245, 12, '片劑'),
(43593, 4246, 12, '每月的'),
(43594, 4247, 12, '光纜筆記'),
(43595, 4248, 12, '關閉'),
(43596, 4249, 12, '辦公室筆記'),
(43597, 4250, 12, '辦公室訪問'),
(43598, 4251, 12, '官方臨床質量測量（CQM）測量組'),
(43599, 4252, 12, '關閉網站的HTTPS連結的患者門戶。'),
(43600, 4254, 12, '非本網站的患者門戶密碼'),
(43601, 4255, 12, '非本網站患者門戶密碼（放空白如果沒有註冊）。'),
(43602, 4258, 12, '非本網站患者門戶網站地址'),
(43603, 4260, 12, '非本網站患者門戶網站用戶名'),
(43604, 4261, 12, '非本網站患者門戶用戶名（放空白如果沒有註冊）。'),
(43605, 4263, 12, '子孫'),
(43606, 4265, 12, '軟膏'),
(43607, 4267, 12, '確定'),
(43608, 4269, 12, '確定連接GCAC發行日期'),
(43609, 4270, 12, '年老'),
(43610, 4272, 12, '年老病人'),
(43611, 4273, 12, '陳舊性骨折非/畸形癒合'),
(43612, 4274, 12, '沒有左側菜單的舊風格版面'),
(43613, 4275, 12, '舊式的靜態形式，沒有搜尋或重複檢查'),
(43614, 4279, 12, '在病人的人口統計資料中省略单位'),
(43615, 4280, 12, '省略单位'),
(43616, 4281, 12, '省略形式，路線和時間間隔，然後成為部分劑量'),
(43617, 4282, 12, '從人口統計表格省略保險和一些其他的事情'),
(43618, 4283, 12, '省略內部用戶？'),
(43619, 4284, 12, '省略共同薪酬面板付款方式'),
(43620, 4285, 12, '省略來自動分配'),
(43621, 4286, 12, '關於 上'),
(43622, 4287, 12, '關於 上'),
(43623, 4288, 12, '在手上'),
(43624, 4289, 12, '關於訂購'),
(43625, 4290, 12, '在現場'),
(43626, 4291, 12, '一旦主要的商業設施已設置，它不應該被改變。改變該設施將影響自在NewCrop ePrescription的工作。'),
(43627, 4292, 12, '一旦你改變你的密碼，你將不得不重新登錄。'),
(43628, 4297, 12, '線上支援'),
(43629, 4298, 12, '線上支援連結'),
(43630, 4299, 12, '只有活動'),
(43631, 4302, 12, '如果帳單位置'),
(43632, 4303, 12, '只有無效'),
(43633, 4304, 12, '只有我的'),
(43634, 4310, 12, '疾病發作：'),
(43635, 4311, 12, '疾病發作： '),
(43636, 4312, 12, '開始腫脹：'),
(43637, 4313, 12, '發病/ HOSP。日期：'),
(43638, 4314, 12, '上門病患門戶網站地址'),
(43639, 4315, 12, '哎呀！'),
(43640, 4316, 12, '打開'),
(43641, 4321, 12, '今日來訪'),
(43642, 4322, 12, '打開電子病歷已經有一個證書頒發機構配置。'),
(43643, 4324, 12, '打開電子病歷數據庫升級'),
(43644, 4325, 12, '為了去識別，打開電子病歷數據庫升級'),
(43645, 4327, 12, '打開電子病歷必須配置使用證書之前，它可以創建客戶端證書。'),
(43646, 4328, 12, '打開電子病歷需要Javascript執行用戶身份驗證。'),
(43647, 4329, 12, '打開電子病歷使用者'),
(43648, 4330, 12, '開口'),
(43649, 4332, 12, '眼科'),
(43650, 4333, 12, '選項'),
(43651, 4335, 12, '選項，以支持產品的庫存和銷售'),
(43652, 4336, 12, '可選的'),
(43653, 4337, 12, '身份證圖像可選的的類別名稱，可以從病人的摘要頁面瀏覽。'),
(43654, 4338, 12, '照片圖像可選的類別名稱，可以從病人的摘要頁面瀏覽。'),
(43655, 4339, 12, '從病人的摘要頁面鏈接到一個文件可選的的類別名稱。讓你點擊一個病人的名字，看到他們的身份證。'),
(43656, 4340, 12, '手動輸入結果可選的預設範圍'),
(43657, 4341, 12, '手動輸入結果可選的預設單位'),
(43658, 4342, 12, '可選的的目的地名稱'),
(43659, 4343, 12, '可選的藥物名稱，使用％作為萬用字元'),
(43660, 4345, 12, '有關此事件的可選的資訊'),
(43661, 4346, 12, '可選的批號，使用％作為萬用字元'),
(43662, 4347, 12, '可選的數字病人身份'),
(43663, 4348, 12, '可選的的程序代碼'),
(43664, 4350, 12, '選項'),
(43665, 4351, 12, '或'),
(43666, 4352, 12, '手術室'),
(43667, 4353, 12, '或選擇'),
(43668, 4354, 12, '或點擊並拖拽可進行快速選擇。'),
(43669, 4356, 12, '或出去'),
(43670, 4358, 12, '或Shift點擊以減少它'),
(43671, 4359, 12, '或者上傳ERA檔案：'),
(43672, 4360, 12, '口腔'),
(43673, 4361, 12, '粉紅色的口腔粘膜，咽喉清澈'),
(43674, 4362, 12, '醫囑'),
(43675, 4363, 12, '訂單和結果類型'),
(43676, 4364, 12, '訂購目錄'),
(43677, 4365, 12, '訂購日期'),
(43678, 4367, 12, '訂購從'),
(43679, 4369, 12, '順序必須是一個1到999之間的數字'),
(43680, 4370, 12, '訂購名稱'),
(43681, 4371, 12, '訂購優先順序'),
(43682, 4372, 12, '訂單處理'),
(43683, 4375, 12, '訂單狀態'),
(43684, 4378, 12, '訂單型態'),
(43685, 4380, 12, '訂單/結果類型'),
(43686, 4381, 12, '訂購'),
(43687, 4384, 12, '訂購提供商'),
(43688, 4386, 12, '器官損傷'),
(43689, 4387, 12, '組織'),
(43690, 4388, 12, '組織名稱'),
(43691, 4389, 12, '組織單位名稱'),
(43692, 4390, 12, '組織'),
(43693, 4391, 12, '面向×3'),
(43694, 4392, 12, '原本'),
(43695, 4396, 12, '口咽： '),
(43696, 4397, 12, '端坐呼吸'),
(43697, 4398, 12, '左眼'),
(43698, 4399, 12, '骨性關節炎'),
(43699, 4402, 12, '其他'),
(43700, 4403, 12, '其他'),
(43701, 4404, 12, '其他（請註明）'),
(43702, 4405, 12, '其他-請註明'),
(43703, 4406, 12, '其他聯邦計劃'),
(43704, 4407, 12, '其他HCFA'),
(43705, 4408, 12, '其他未列明的損傷'),
(43706, 4410, 12, '其他月份'),
(43707, 4411, 12, '其他非聯邦計劃'),
(43708, 4412, 12, '其他注意事項'),
(43709, 4413, 12, '其他相關症狀'),
(43710, 4414, 12, '其他相關症狀：'),
(43711, 4415, 12, '其他PT RESP賬戶'),
(43712, 4416, 12, '其他壓力/過度使用傷害'),
(43713, 4417, 12, '其他手術'),
(43714, 4418, 12, '其他/通用人工流產有關'),
(43715, 4420, 12, '他人'),
(43716, 4421, 12, '否則，你將會破壞參考文獻到/從現有的數據。'),
(43717, 4422, 12, '渥太華踝規則'),
(43718, 4423, 12, '雙眼'),
(43719, 4424, 12, '輸出 趕出'),
(43720, 4425, 12, '走出辦公室'),
(43721, 4426, 12, '出境轉介'),
(43722, 4427, 12, '結果'),
(43723, 4428, 12, '展望 意見'),
(43724, 4432, 12, '過度使用'),
(43725, 4434, 12, '過重'),
(43726, 4435, 12, '覆蓋HIPAA的選擇'),
(43727, 4437, 12, '氧氣飽和度'),
(43728, 4440, 12, '飯後'),
(43729, 4441, 12, '下午'),
(43730, 4442, 12, '隨時'),
(43731, 4443, 12, '太平洋島民'),
(43732, 4444, 12, '兒科'),
(43733, 4445, 12, '頁'),
(43734, 4446, 12, '頁數'),
(43735, 4447, 12, '支付'),
(43736, 4448, 12, '你將分配支付的金額'),
(43737, 4450, 12, '支付透過'),
(43738, 4451, 12, '疼痛'),
(43739, 4453, 12, '叩診'),
(43740, 4455, 12, '子宮頸抹片'),
(43741, 4458, 12, '麻痺'),
(43742, 4461, 12, '解析的HL7'),
(43743, 4463, 12, '夥伴'),
(43744, 4464, 12, '夥伴名字'),
(43745, 4467, 12, '通關密語'),
(43746, 4468, 12, '密碼解密文件'),
(43747, 4469, 12, '傳遞患者'),
(43748, 4470, 12, '被動警報'),
(43749, 4471, 12, '被動警報規則'),
(43750, 4472, 12, '密碼'),
(43751, 4473, 12, '密碼改變'),
(43752, 4475, 12, '成功的改變密碼'),
(43753, 4477, 12, '密碼過期的寬限期'),
(43754, 4479, 12, '電話網關的密碼。由Maviq提供自動化VOIP服務。更多信息，請訪問http://signup.maviq.com。'),
(43755, 4480, 12, '短信網關的密碼'),
(43756, 4481, 12, '短信網關的密碼'),
(43757, 4483, 12, '密碼的安全性最近已經升級。'),
(43758, 4486, 12, '密碼：'),
(43759, 4490, 12, '逾期'),
(43760, 4491, 12, '逾期'),
(43761, 4492, 12, '逾期間隔（臨床提醒）'),
(43762, 4493, 12, '逾期間隔（病人提醒）'),
(43763, 4494, 12, '過去遭遇名單'),
(43764, 4495, 12, '過去遭遇'),
(43765, 4496, 12, '過去遭遇與文件'),
(43766, 4497, 12, '對過去遭遇'),
(43767, 4498, 12, '貼上HL7數據'),
(43768, 4499, 12, '貼上數據導入到下列文本區域：'),
(43769, 4500, 12, '輕拍'),
(43770, 4502, 12, '貼片'),
(43771, 4508, 12, '事件日誌備份的路徑'),
(43772, 4509, 12, 'CA憑證檔案的路徑'),
(43773, 4510, 12, 'CA密鑰文件的路徑'),
(43774, 4511, 12, '到MySQL二進制代碼的路徑'),
(43775, 4512, 12, '到Perl二進制代碼的路徑'),
(43776, 4513, 12, '到暫存檔的路徑'),
(43777, 4514, 12, '病人'),
(43778, 4515, 12, '病人'),
(43779, 4516, 12, '病人'),
(43780, 4521, 12, '病人過敏'),
(43781, 4522, 12, '病人過敏'),
(43782, 4523, 12, '病人預約'),
(43783, 4528, 12, '病歷編號'),
(43784, 4529, 12, '病人結帳'),
(43785, 4530, 12, '病人結帳為 '),
(43786, 4531, 12, '病人城市'),
(43787, 4533, 12, '發送醫患溝通'),
(43788, 4534, 12, '發送醫患溝通'),
(43789, 4535, 12, '病人國家'),
(43790, 4539, 12, '病人資料'),
(43791, 4542, 12, '病人詳情'),
(43792, 4543, 12, '病人出生日期'),
(43793, 4544, 12, '病人資料'),
(43794, 4545, 12, '病人教育'),
(43795, 4546, 12, '病患教育資源'),
(43796, 4547, 12, '病人遭遇'),
(43797, 4548, 12, '病人遭遇表格'),
(43798, 4549, 12, '病人遭遇'),
(43799, 4550, 12, '病人查找程序'),
(43800, 4551, 12, '病人的名字'),
(43801, 4558, 12, '病人性別'),
(43802, 4560, 12, '病人並沒有授權的患者門戶。'),
(43803, 4561, 12, '病歷'),
(43804, 4562, 12, '病人的歷史/生活方式'),
(43805, 4563, 12, '患者家中電話'),
(43806, 4564, 12, '病人身分'),
(43807, 4566, 12, '病人身分証'),
(43808, 4567, 12, '病人身份類別名稱'),
(43809, 4568, 12, '病人免疫'),
(43810, 4569, 12, '病人資訊'),
(43811, 4570, 12, '耐心的指導'),
(43812, 4571, 12, '病人保險銷售'),
(43813, 4572, 12, '病人保險銷售報告'),
(43814, 4573, 12, '病人的問題'),
(43815, 4575, 12, '病人的姓'),
(43816, 4581, 12, '病人表單'),
(43817, 4586, 12, '病人查詢錯誤'),
(43818, 4587, 12, '病人醫療問題'),
(43819, 4588, 12, '病人的藥物'),
(43820, 4589, 12, '病人姓名'),
(43821, 4590, 12, '病人姓名與住址'),
(43822, 4593, 12, '所需的病人姓名'),
(43823, 4595, 12, '病人附註'),
(43824, 4596, 12, '病人附註形式'),
(43825, 4597, 12, '病人附註'),
(43826, 4598, 12, '病人的注意事項（寫，addonly可選）'),
(43827, 4599, 12, '病人數'),
(43828, 4600, 12, '病人付款'),
(43829, 4602, 12, '病人的照片分類名稱'),
(43830, 4603, 12, '患者門戶'),
(43831, 4605, 12, '病人門戶網站被關閉'),
(43832, 4606, 12, '患者門戶登錄'),
(43833, 4607, 12, '病人門戶網站地址'),
(43834, 4608, 12, '病人印製報告'),
(43835, 4609, 12, '病人印製報告'),
(43836, 4610, 12, '病人記錄請求'),
(43837, 4611, 12, '病人記錄請求'),
(43838, 4613, 12, '病人提醒'),
(43839, 4614, 12, '病人提醒批次工作'),
(43840, 4616, 12, '病人提醒規則'),
(43841, 4617, 12, '病人提醒發件人的電子郵件'),
(43842, 4618, 12, '病人提醒發件人名稱'),
(43843, 4619, 12, '病人提醒'),
(43844, 4620, 12, '病人報告'),
(43845, 4621, 12, '病人請求'),
(43846, 4622, 12, '病人要求醫療記錄'),
(43847, 4623, 12, '病人結果'),
(43848, 4624, 12, '病人搜索結果類型'),
(43849, 4625, 12, '病人搜索/添加螢幕'),
(43850, 4626, 12, '病人設置'),
(43851, 4627, 12, '病人狀態'),
(43852, 4629, 12, '病人摘要'),
(43853, 4630, 12, '病人事務'),
(43854, 4631, 12, '病人郵編'),
(43855, 4632, 12, '在資料庫中的病人，符合你已經進入的人口統計資訊。'),
(43856, 4633, 12, '病人/客戶'),
(43857, 4634, 12, '病人：'),
(43858, 4635, 12, '病人身分'),
(43859, 4636, 12, '病人'),
(43860, 4638, 12, '付'),
(43861, 4639, 12, '要注意複選框“完成”。保險標記為完成後，然後我們將開始要求病人支付餘額;如果你完整標記所有的保險失敗，然後完成剩餘的金額將不會被收集！此外，如果有一個病人應支付的平衡，然後設置適當的截止日期，因為這會影響對病人報表中出現的語言。'),
(43862, 4640, 12, '支付日期：'),
(43863, 4641, 12, '支付狀態'),
(43864, 4642, 12, '收款人名稱'),
(43865, 4643, 12, '付款人'),
(43866, 4644, 12, '付款人類型'),
(43867, 4645, 12, '付款'),
(43868, 4646, 12, '支付實體'),
(43869, 4647, 12, '付款'),
(43870, 4648, 12, '付款'),
(43871, 4649, 12, '付款調整代碼'),
(43872, 4651, 12, '付款金額'),
(43873, 4652, 12, '付款金額必須是數字'),
(43874, 4653, 12, '付款類別'),
(43875, 4654, 12, '付款日期'),
(43876, 4655, 12, '付款輸入在'),
(43877, 4656, 12, '款項'),
(43878, 4658, 12, '付款插件'),
(43879, 4659, 12, '付款清單'),
(43880, 4660, 12, '付款方法'),
(43881, 4661, 12, '付款方式分類'),
(43882, 4662, 12, '付款情況'),
(43883, 4663, 12, '付款型態'),
(43884, 4664, 12, '付款價值為代碼 '),
(43885, 4665, 12, '付款'),
(43886, 4667, 12, '主治醫生'),
(43887, 4669, 12, 'PDF格式'),
(43888, 4670, 12, 'PDF下載選中的語句'),
(43889, 4672, 12, '骨盆和臀部'),
(43890, 4673, 12, '天皰瘡'),
(43891, 4674, 12, '掛起的'),
(43892, 4676, 12, '有待追蹤'),
(43893, 4677, 12, '有待追蹤'),
(43894, 4678, 12, '從結果有待追蹤'),
(43895, 4679, 12, '等待處理的醫囑'),
(43896, 4680, 12, '掛起分辨率'),
(43897, 4681, 12, '待審查'),
(43898, 4682, 12, '待Rx計數'),
(43899, 4684, 12, '彭寧頓事務所LibreEHR至五'),
(43900, 4685, 12, '胃潰瘍疾病'),
(43901, 4687, 12, '每分鐘'),
(43902, 4688, 12, '每個鼻孔'),
(43903, 4689, 12, '每個鼻孔'),
(43904, 4690, 12, 'Per Oris'),
(43905, 4691, 12, 'per oris'),
(43906, 4692, 12, '由直腸'),
(43907, 4693, 12, '由直腸'),
(43908, 4694, 12, '百分比'),
(43909, 4697, 12, '百分位'),
(43910, 4698, 12, '穿孔的右側：'),
(43911, 4699, 12, '執行搜尋'),
(43912, 4700, 12, '執行這個動作'),
(43913, 4701, 12, '績效百分比'),
(43914, 4703, 12, '執行實驗室設施'),
(43915, 4705, 12, '期間'),
(43916, 4706, 12, '在幾天的期間有一個用戶可能用過期的密碼登錄。'),
(43917, 4707, 12, '手術全期照顧'),
(43918, 4708, 12, '周邊的'),
(43919, 4712, 12, '人'),
(43920, 4713, 12, '個性化'),
(43921, 4714, 12, '編程器'),
(43922, 4715, 12, '藥理學'),
(43923, 4716, 12, '藥理學COM計數'),
(43924, 4717, 12, '藥房'),
(43925, 4718, 12, '藥房'),
(43926, 4719, 12, '藥房配藥'),
(43927, 4720, 12, '氣胸'),
(43928, 4729, 12, '電話'),
(43929, 4730, 12, '手機通話清單'),
(43930, 4733, 12, '電話網關密碼'),
(43931, 4734, 12, '電話網關的網址'),
(43932, 4735, 12, '電話網關的用戶名'),
(43933, 4737, 12, '電話通知一小時'),
(43934, 4738, 12, '電話號碼'),
(43935, 4740, 12, '畏光'),
(43936, 4741, 12, '照片'),
(43937, 4742, 12, 'PHP的壓縮'),
(43938, 4743, 12, 'PHP的CURL模塊應在您的服務器上啟用。'),
(43939, 4744, 12, 'PHP的提取'),
(43940, 4745, 12, 'php-GACL的存取控制是關閉的'),
(43941, 4746, 12, 'PHPgacl沒有安裝'),
(43942, 4747, 12, '身體檢查'),
(43943, 4749, 12, '醫師要求'),
(43944, 4750, 12, '醫師簽名'),
(43945, 4752, 12, '醫師'),
(43946, 4753, 12, '選擇'),
(43947, 4754, 12, '選擇'),
(43948, 4755, 12, '挑一個CSS主題。'),
(43949, 4756, 12, '骨盆腔發炎疾病'),
(43950, 4757, 12, '骨盆腔發炎疾病（PID）'),
(43951, 4758, 12, '藥片大小'),
(43952, 4759, 12, '藥丸'),
(43953, 4760, 12, '如果要安裝此選項，將數據庫zip檔案放在以下目錄'),
(43954, 4765, 12, '佔位'),
(43955, 4766, 12, '佔位（保持空的ACL）'),
(43956, 4767, 12, '純文字'),
(43957, 4768, 12, '計劃'),
(43958, 4771, 12, '計畫名稱'),
(43959, 4775, 12, '計劃設定'),
(43960, 4779, 12, '計劃：'),
(43961, 4782, 12, '計劃'),
(43962, 4784, 12, '播放機'),
(43963, 4785, 12, '演奏位置'),
(43964, 4786, 12, '如果任何上述信息是不正確的請呼叫'),
(43965, 4787, 12, '請更改您的密碼。'),
(43966, 4788, 12, '請選擇一個檔案'),
(43967, 4789, 12, '請選擇一個病人'),
(43968, 4790, 12, '請從列表中選擇一個有效的選擇。'),
(43969, 4791, 12, '請選擇一個有效的選擇。'),
(43970, 4792, 12, '請選擇一個值為'),
(43971, 4793, 12, '請選擇以上日期範圍標準，並單擊“刷新”以查看結果。'),
(43972, 4794, 12, '請選擇適當格式化的EDI-271檔案'),
(43973, 4795, 12, '請點擊下載按鈕下載去識別的數據'),
(43974, 4796, 12, '請點擊下載按鈕下載再識別的數據'),
(43975, 4797, 12, '請關閉此視窗。'),
(43976, 4798, 12, '請比較新的名稱'),
(43977, 4802, 12, '請不要接受這個處方，除非它是通過facimile被接收。'),
(43978, 4803, 12, '請不要接受這個處方，除非它是通過facimile被接收。'),
(43979, 4804, 12, '請不要使用您的瀏覽器停止或重新載入按鈕，當此頁正在運行時，除非已經過去了10多分鐘，這不會導致在服務器上的過程停止，以及將消耗uneccesary資源。'),
(43980, 4809, 12, '請輸入最新評論日期。'),
(43981, 4810, 12, '請輸入一個日期。'),
(43982, 4813, 12, '請輸入貨幣金額只使用數字和小數點。'),
(43983, 4814, 12, '請輸入新密碼'),
(43984, 4815, 12, '請輸入標題！'),
(43985, 4819, 12, '請輸入正確的重新識別代碼'),
(43986, 4821, 12, '請輸入新的搜索字符串'),
(43987, 4822, 12, '請輸入這個正確的重新識別代碼'),
(43988, 4823, 12, '請輸入密碼'),
(43989, 4824, 12, '請填寫支票號碼'),
(43990, 4826, 12, '請填寫日期'),
(43991, 4827, 12, '請填寫支付金額'),
(43992, 4828, 12, '請填寫付款類別'),
(43993, 4829, 12, '請填寫從哪裡支付'),
(43994, 4830, 12, '請填寫發佈日期'),
(43995, 4831, 12, '在繼續之前請填寫他們。'),
(43996, 4832, 12, '請註明訪問原因'),
(43997, 4834, 12, '請輸入以上搜索條件，然後點擊提交查看結果。'),
(43998, 4835, 12, '以上請輸入搜索條件，然後點擊提交查看結果。（結果將顯示在一個彈出窗口）'),
(43999, 4836, 12, '請重新登錄。'),
(44000, 4837, 12, '請注意，這可能需要很長一段時間，長達數分鐘，您的網頁瀏覽器在此期間可能不會出現非常活躍，但產生了一項法案，是一個複雜的過程，您的網頁瀏覽器只是等待更多的信息。'),
(44001, 4838, 12, '請注意：常數是區分大小寫的，並允許任何字符串。'),
(44002, 4839, 12, '只使用字母字符'),
(44003, 4840, 12, '請只使用不帶空格的字母字符'),
(44004, 4841, 12, '請支付這筆款項'),
(44005, 4843, 12, '請參考'),
(44006, 4844, 12, '請重設密碼。'),
(44007, 4845, 12, '在以去識別遊戲之前，請重新啟動Apache服務器'),
(44008, 4849, 12, '請選擇一種語言'),
(44009, 4850, 12, '請選擇一個病人'),
(44010, 4851, 12, '請用“稅號”選擇一個主要的商業實體設施當成你的設施稅號。如果你是一個個體從業員，使用你的稅號。這是在NewCrop系統中用來識別你的。'),
(44011, 4855, 12, '請選擇一個開始日期和結束日期'),
(44012, 4858, 12, '請選擇一個代碼調整原因 '),
(44013, 4859, 12, '請選擇一個事件'),
(44014, 4860, 12, '請選擇任何搜索選項。'),
(44015, 4863, 12, '請選擇至少一個處方！'),
(44016, 4865, 12, '請選擇所需的網頁，複製或轉發：'),
(44017, 4866, 12, '請選擇付款方式'),
(44018, 4869, 12, '請選擇X12的合作夥伴，需要創造270批次'),
(44019, 4870, 12, '請設置'),
(44020, 4871, 12, '請設置de_identification_config變數回到零'),
(44021, 4873, 12, '請開始新的去識別過程'),
(44022, 4874, 12, '請升級LibreEHR數據庫，包括去識別程序，功能，表'),
(44023, 4875, 12, '有關詳細信息，請查看去識別錯誤日誌表'),
(44024, 4876, 12, '經過一段時間後，請瀏覽去識別螢幕'),
(44025, 4877, 12, '經過一段時間後，請瀏覽再識別螢幕'),
(44026, 4878, 12, '一段時間後，請瀏覽螢幕'),
(44027, 4882, 12, '下午'),
(44028, 4883, 12, '下午計劃'),
(44029, 4884, 12, 'PMT方法'),
(44030, 4885, 12, '陣發性夜間呼吸困難'),
(44031, 4886, 12, '肺炎球菌1'),
(44032, 4887, 12, '肺炎球菌2'),
(44033, 4888, 12, '肺炎球菌3'),
(44034, 4889, 12, '肺炎球菌4'),
(44035, 4890, 12, '肺炎球菌疫苗'),
(44036, 4891, 12, '肺炎球菌疫苗'),
(44037, 4892, 12, '針對老年人的肺炎疫苗接種狀況'),
(44038, 4893, 12, '針對老年人的肺炎疫苗接種情況（CQM）'),
(44039, 4894, 12, '足部'),
(44040, 4896, 12, '服務點（POS）'),
(44041, 4897, 12, '保單號碼'),
(44042, 4898, 12, '保單號碼'),
(44043, 4899, 12, '保單號碼'),
(44044, 4900, 12, '波蘭語 拋光'),
(44045, 4901, 12, '煩渴'),
(44046, 4902, 12, '息肉'),
(44047, 4903, 12, '多尿'),
(44048, 4904, 12, '食慾不振'),
(44049, 4905, 12, '循環不佳'),
(44050, 4906, 12, '聽力差'),
(44051, 4907, 12, '需要啟用彈出式窗口來看這些報告'),
(44052, 4908, 12, '用事件填充今年視圖？'),
(44053, 4909, 12, '彈出式窗口'),
(44054, 4911, 12, '入口網站活動'),
(44055, 4917, 12, '葡萄牙'),
(44056, 4918, 12, '葡萄牙語（巴西）'),
(44057, 4919, 12, '葡萄牙（歐洲）'),
(44058, 4920, 12, 'POS機代碼'),
(44059, 4922, 12, '積極的 正向 陽性'),
(44060, 4923, 12, '積極的 正向 陽性'),
(44061, 4925, 12, '職位以'),
(44062, 4926, 12, '鼻涕倒流'),
(44063, 4927, 12, '上傳付款'),
(44064, 4928, 12, '手術後'),
(44065, 4929, 12, '發布會計和標記為帳單'),
(44066, 4930, 12, '發布日期'),
(44067, 4931, 12, '發布日期不能大於今天'),
(44068, 4932, 12, '發布日期必須大於財務關閉日期。'),
(44069, 4933, 12, '流產後照顧'),
(44070, 4934, 12, '人工流產後避孕'),
(44071, 4935, 12, '墮胎後諮詢'),
(44072, 4936, 12, '人工流產後追蹤'),
(44073, 4937, 12, '郵政'),
(44074, 4938, 12, '郵政編碼'),
(44075, 4939, 12, '郵政編碼'),
(44076, 4941, 12, '張貼日曆'),
(44077, 4942, 12, '張貼日曆管理'),
(44078, 4943, 12, '張貼日曆類別設置'),
(44079, 4944, 12, '張貼全球設置日曆'),
(44080, 4945, 12, '發表於'),
(44081, 4946, 12, '發布日期'),
(44082, 4948, 12, '技術支持'),
(44083, 4949, 12, '個人防護裝備+預防醫學/外科HX'),
(44084, 4950, 12, 'PQRI'),
(44085, 4951, 12, 'PQRI註冊編號'),
(44086, 4952, 12, 'PQRI註冊名稱'),
(44087, 4953, 12, '實務'),
(44088, 4954, 12, '實務預設設定'),
(44089, 4955, 12, '實務設定'),
(44090, 4956, 12, '執業者'),
(44091, 4959, 12, '預先付款'),
(44092, 4960, 12, '墮胎前諮詢'),
(44093, 4961, 12, '墮胎前輔導'),
(44094, 4962, 12, '縣貓'),
(44095, 4964, 12, '喜好'),
(44096, 4965, 12, '首選事件類別'),
(44097, 4966, 12, '首選語言'),
(44098, 4967, 12, '首選藥房'),
(44099, 4968, 12, '優先提供者組織（PPO）'),
(44100, 4969, 12, '懷孕測試'),
(44101, 4970, 12, '初步'),
(44102, 4972, 12, '預付'),
(44103, 4973, 12, '處方'),
(44104, 4974, 12, '處方已達到極限'),
(44105, 4975, 12, '處方史'),
(44106, 4976, 12, '處方史進口順利完成'),
(44107, 4977, 12, '處方標籤'),
(44108, 4978, 12, '處方報告'),
(44109, 4979, 12, '處方'),
(44110, 4980, 12, '處方和特許'),
(44111, 4981, 12, '處方藥和其他轉介'),
(44112, 4982, 12, '處方藥和/或專科轉介'),
(44113, 4983, 12, '處方報告'),
(44114, 4984, 12, '處方/轉介'),
(44115, 4985, 12, '目前'),
(44116, 4986, 12, '表現抱怨'),
(44117, 4988, 12, '按下繼續以進行'),
(44118, 4989, 12, '假設的診斷'),
(44119, 4990, 12, '由專家下的假設診斷'),
(44120, 4991, 12, '前頁'),
(44121, 4992, 12, '預防醫學/外科HX'),
(44122, 4993, 12, '上一頁。每月（持有選單）'),
(44123, 4994, 12, '上一頁。每年（持有選單）'),
(44124, 4995, 12, '預防保健'),
(44125, 4998, 12, '預覽事件'),
(44126, 5000, 12, '預覽'),
(44127, 5001, 12, '以前'),
(44128, 5002, 12, '事前協商'),
(44129, 5003, 12, '前一天'),
(44130, 5004, 12, '過去史/篩選'),
(44131, 5005, 12, '前一個月'),
(44132, 5006, 12, '上星期'),
(44133, 5007, 12, '價格'),
(44134, 5008, 12, '價格折扣'),
(44135, 5009, 12, '價格等級'),
(44136, 5010, 12, '價格等級：'),
(44137, 5011, 12, '價格'),
(44138, 5012, 12, '初級 主要'),
(44139, 5013, 12, '主要商業實體'),
(44140, 5014, 12, '主要業務實體稅號用於 NewCrop ePrescription帳戶編號。改變該設施將影響在NewCrop的工作。'),
(44141, 5022, 12, '原保險'),
(44142, 5023, 12, '原保險'),
(44143, 5024, 12, '原保險日期'),
(44144, 5025, 12, '原保險提供者'),
(44145, 5026, 12, '主要提供者'),
(44146, 5027, 12, '列印'),
(44147, 5028, 12, '列印（HTML）'),
(44148, 5029, 12, '列印(PDF)'),
(44149, 5031, 12, '列印任何遭遇'),
(44150, 5032, 12, '列印空白推薦表格'),
(44151, 5033, 12, '列印命令'),
(44152, 5039, 12, '列印格式'),
(44153, 5040, 12, '列印四個小組'),
(44154, 5042, 12, '列印訊息'),
(44155, 5043, 12, '列印多個'),
(44156, 5044, 12, '列印多個傳真'),
(44157, 5045, 12, '列印名稱，標誌和日期。'),
(44158, 5046, 12, '列印註釋'),
(44159, 5047, 12, '列印第一頁'),
(44160, 5048, 12, '列印第二頁'),
(44161, 5051, 12, '提供者列印收據'),
(44162, 5052, 12, '列印紀錄'),
(44163, 5053, 12, '列印選定的報表'),
(44164, 5054, 12, '列印射擊紀錄'),
(44165, 5056, 12, '列印這次遭遇'),
(44166, 5057, 12, '列印說明'),
(44167, 5058, 12, '列印說明'),
(44168, 5060, 12, '列印傳真'),
(44169, 5061, 12, '列印查看'),
(44170, 5062, 12, '可列印的'),
(44171, 5063, 12, '列印版本'),
(44172, 5064, 12, '印刷的'),
(44173, 5066, 12, '列印結果：'),
(44174, 5067, 12, '列印略過;請參閱測試輸出'),
(44175, 5068, 12, '列印略過;請參閱測試輸出 '),
(44176, 5069, 12, '在此之前驗證'),
(44177, 5070, 12, '以前授權書'),
(44178, 5072, 12, '優先'),
(44179, 5073, 12, '優先 '),
(44180, 5074, 12, '私人'),
(44181, 5075, 12, '問題'),
(44182, 5076, 12, '問題診斷'),
(44183, 5077, 12, '問題表單'),
(44184, 5079, 12, '問題/議題'),
(44185, 5080, 12, '丙卡巴井棒'),
(44186, 5081, 12, '丙卡巴井貓'),
(44187, 5083, 12, 'Proc Pending Rev'),
(44188, 5085, 12, 'Proc Res'),
(44189, 5086, 12, '程序'),
(44190, 5087, 12, '過程部位'),
(44191, 5088, 12, '程序布林結果'),
(44192, 5089, 12, '程序代碼'),
(44193, 5091, 12, 'Procedure Lateralities'),
(44194, 5093, 12, '程序順序'),
(44195, 5095, 12, '程序順序為了'),
(44196, 5102, 12, '過程報告'),
(44197, 5103, 12, '過程報告狀態'),
(44198, 5104, 12, '過程結果異常'),
(44199, 5105, 12, '過程結果狀態'),
(44200, 5106, 12, '過程結果'),
(44201, 5107, 12, '過程路線'),
(44202, 5108, 12, '過程標本類型'),
(44203, 5109, 12, '過程統計報告'),
(44204, 5110, 12, '過程類型'),
(44205, 5111, 12, '過程類型'),
(44206, 5112, 12, '過程單位'),
(44207, 5114, 12, '過程'),
(44208, 5115, 12, '過程'),
(44209, 5117, 12, '過程年代檔案'),
(44210, 5125, 12, '過程'),
(44211, 5129, 12, '產品'),
(44212, 5130, 12, '產品的避孕方法'),
(44213, 5132, 12, '產品'),
(44214, 5133, 12, '產品，但沒有處方藥和無範本'),
(44215, 5134, 12, '教授'),
(44216, 5135, 12, '病程記錄'),
(44217, 5136, 12, '攝護腺癌'),
(44218, 5137, 12, '攝護腺癌篩檢'),
(44219, 5138, 12, '攝護腺檢查'),
(44220, 5139, 12, '攝護腺問題'),
(44221, 5140, 12, '前列腺W / O變大，結節，柔軟'),
(44222, 5142, 12, '提供絕對路徑'),
(44223, 5143, 12, '提供檔案的絕對路徑'),
(44224, 5145, 12, '為每個辦公室訪問患者提供臨床摘要。'),
(44225, 5146, 12, '依據要求提供患者，他們健康信息的電子影本（包括診斷測試的結果，問題的清單，用藥清單，藥物過敏）要求。'),
(44226, 5147, 12, '在四個工作日內，以電子存取信息提供患者及時的健康信息（包括實驗室檢測結果，問題的清單，用藥清單，藥物過敏）EP對他們的。'),
(44227, 5148, 12, '提供患者參觀記錄'),
(44228, 5149, 12, '提供有效的電子郵件地址'),
(44229, 5150, 12, '提供臨床摘要？'),
(44230, 5151, 12, '提供教育資源？'),
(44231, 5152, 12, '提供者列印收據'),
(44232, 5156, 12, '提供者配對錯誤'),
(44233, 5159, 12, '提供者編號'),
(44234, 5162, 12, '提供者：'),
(44235, 5163, 12, '提供者'),
(44236, 5164, 12, '提供者的新產品引進'),
(44237, 5165, 12, '供應商把整個日曆'),
(44238, 5166, 12, '上一頁'),
(44239, 5167, 12, '變壓吸附'),
(44240, 5168, 12, '牛皮癬'),
(44241, 5169, 12, '精神科診斷'),
(44242, 5170, 12, '精神科藥物'),
(44243, 5171, 12, '精神科的'),
(44244, 5172, 12, '精神科摘要函件'),
(44245, 5173, 12, '精神科診斷'),
(44246, 5174, 12, '精神病鑑定'),
(44247, 5175, 12, '精神病史'),
(44248, 5176, 12, '精神科攝入'),
(44249, 5177, 12, '精神科藥物'),
(44250, 5178, 12, '病人百分比'),
(44251, 5179, 12, '病人註释'),
(44252, 5180, 12, '病人註釋/驗證'),
(44253, 5181, 12, '病人多繳'),
(44254, 5182, 12, '病人付費'),
(44255, 5183, 12, '病人建議請求'),
(44256, 5184, 12, '病人退款'),
(44257, 5185, 12, '病人釋放'),
(44258, 5186, 12, '病人報告'),
(44259, 5187, 12, '太平洋學生，或留空白'),
(44260, 5188, 12, '太平洋-城市'),
(44261, 5189, 12, '太平洋-出生日期'),
(44262, 5191, 12, '太平洋-FNAME'),
(44263, 5192, 12, '太平洋-LNAME'),
(44264, 5193, 12, '太平洋-MNAME'),
(44265, 5196, 12, '太平洋-郵政'),
(44266, 5198, 12, '太平洋-州'),
(44267, 5199, 12, '太平洋-街'),
(44268, 5201, 12, '公眾'),
(44269, 5204, 12, '波多黎各'),
(44270, 5205, 12, '肺的'),
(44271, 5206, 12, '脈搏'),
(44272, 5207, 12, '旁遮普'),
(44273, 5208, 12, 'Purchase'),
(44274, 5209, 12, '購買/返回'),
(44275, 5210, 12, '採購'),
(44276, 5213, 12, '每3小時'),
(44277, 5214, 12, '每4小時'),
(44278, 5215, 12, '每5小時'),
(44279, 5216, 12, '每6小時'),
(44280, 5217, 12, '每8小時'),
(44281, 5218, 12, '每天4次'),
(44282, 5219, 12, '每天4次'),
(44283, 5220, 12, '每隔1小時'),
(44284, 5221, 12, '每隔1小時是少於每月用量'),
(44285, 5222, 12, '品質'),
(44286, 5223, 12, '品質'),
(44287, 5224, 12, '品質'),
(44288, 5225, 12, '質量測量（CQM）'),
(44289, 5226, 12, '數量'),
(44290, 5227, 12, 'NDC的數量'),
(44291, 5228, 12, '手邊的數量'),
(44292, 5229, 12, '數量似乎無法使用'),
(44293, 5231, 12, '問號'),
(44294, 5232, 12, '為HCFA成批處理隊列'),
(44295, 5233, 12, '為HCFA成批處理隊列與印刷'),
(44296, 5234, 12, '為UB-92成批處理隊列'),
(44297, 5235, 12, '為UB-92成批處理隊列與印刷'),
(44298, 5236, 12, '排隊'),
(44299, 5237, 12, '排隊的事件管理'),
(44300, 5238, 12, '排隊等候'),
(44301, 5240, 12, '排隊提交管理'),
(44302, 5241, 12, '退出'),
(44303, 5242, 12, '戒酒'),
(44304, 5245, 12, '種族'),
(44305, 5246, 12, '種族和民族'),
(44306, 5247, 12, '種族/族裔'),
(44307, 5248, 12, '收音機'),
(44308, 5249, 12, '單選按鈕'),
(44309, 5251, 12, '範圍'),
(44310, 5252, 12, '皮疹'),
(44311, 5253, 12, '速率'),
(44312, 5254, 12, '比率'),
(44313, 5255, 12, '原報告'),
(44314, 5256, 12, '重新鑑定'),
(44315, 5257, 12, '重新鑑定過程完成'),
(44316, 5258, 12, '重新鑑定的過程是正在進行'),
(44317, 5259, 12, '重新鑑定的文件將被保存在'),
(44318, 5260, 12, '再度受傷？'),
(44319, 5261, 12, '重新開放'),
(44320, 5262, 12, '重新開放'),
(44321, 5263, 12, '反應'),
(44322, 5264, 12, '反應'),
(44323, 5265, 12, '讀'),
(44324, 5268, 12, '真實姓名'),
(44325, 5269, 12, '真正刪除'),
(44326, 5270, 12, '理由'),
(44327, 5271, 12, '死亡原因'),
(44328, 5272, 12, '死亡原因'),
(44329, 5274, 12, '轉介原因'),
(44330, 5275, 12, '訪問的原因'),
(44331, 5276, 12, '原因/表格'),
(44332, 5277, 12, '收據'),
(44333, 5278, 12, '付款收據'),
(44334, 5279, 12, '收據產生'),
(44335, 5280, 12, '預收付款方法報告'),
(44336, 5281, 12, '收據摘要'),
(44337, 5282, 12, '接受'),
(44338, 5283, 12, '收到的'),
(44339, 5284, 12, '接收的傳真'),
(44340, 5287, 12, '接收器'),
(44341, 5288, 12, '接收器的編號'),
(44342, 5289, 12, '接收器的編號（ISA08）'),
(44343, 5290, 12, '接收器的ID限定符（ISA07）'),
(44344, 5292, 12, '最近三個密碼是不允許的。'),
(44345, 5293, 12, '接受者'),
(44346, 5294, 12, '收件人列表是空的'),
(44347, 5295, 12, '收件人姓名'),
(44348, 5296, 12, '收件人披露'),
(44349, 5298, 12, '建議'),
(44350, 5300, 12, '建議'),
(44351, 5301, 12, '建議與治療'),
(44352, 5302, 12, '專家的建議'),
(44353, 5303, 12, '紀錄'),
(44354, 5310, 12, '生命徵象的紀錄與圖表改變'),
(44355, 5311, 12, '記錄人口統計。'),
(44356, 5312, 12, '記錄披露'),
(44357, 5313, 12, '健身記錄'),
(44358, 5314, 12, '記錄付款'),
(44359, 5315, 12, '記錄請求日期'),
(44360, 5316, 12, '為13歲或以上的患者紀錄吸煙狀況。'),
(44361, 5317, 12, '紀錄'),
(44362, 5318, 12, '找到記錄'),
(44363, 5319, 12, '找到記錄。'),
(44364, 5320, 12, '娛樂性藥物的使用'),
(44365, 5321, 12, '娛樂性藥物'),
(44366, 5322, 12, '直腸的'),
(44367, 5323, 12, '直腸檢查'),
(44368, 5324, 12, '直腸的'),
(44369, 5325, 12, '重新定向'),
(44370, 5326, 12, '發紅'),
(44371, 5327, 12, '降低：'),
(44372, 5328, 12, '參考'),
(44373, 5329, 12, '指由'),
(44374, 5330, 12, '參考日期'),
(44375, 5331, 12, '參考'),
(44376, 5332, 12, '參考分類（風險等級）'),
(44377, 5333, 12, '結果參考範圍'),
(44378, 5334, 12, '參考原因'),
(44379, 5336, 12, '參考姓名與簽名'),
(44380, 5337, 12, '轉診'),
(44381, 5338, 12, '所提及'),
(44382, 5339, 12, '轉診卡'),
(44383, 5340, 12, '轉診日期'),
(44384, 5341, 12, '轉診表格'),
(44385, 5342, 12, '轉診表格'),
(44386, 5343, 12, '轉診編號'),
(44387, 5345, 12, '轉診來源'),
(44388, 5346, 12, '轉介來源為遭遇'),
(44389, 5347, 12, '轉診到'),
(44390, 5348, 12, '轉診'),
(44391, 5349, 12, '轉診報告'),
(44392, 5350, 12, '所提及'),
(44393, 5351, 12, '所提及'),
(44394, 5352, 12, '轉診到'),
(44395, 5353, 12, '轉診'),
(44396, 5355, 12, '轉介診斷'),
(44397, 5356, 12, '轉介診斷'),
(44398, 5357, 12, '在談到醫生和實踐'),
(44399, 5358, 12, '在談到提供者'),
(44400, 5359, 12, '補充'),
(44401, 5360, 12, '補充'),
(44402, 5361, 12, '補充'),
(44403, 5362, 12, '反射正常'),
(44404, 5363, 12, '重新整理'),
(44405, 5368, 12, '拒絕說明'),
(44406, 5369, 12, 'reg_re'),
(44407, 5370, 12, '註冊'),
(44408, 5372, 12, '註冊'),
(44409, 5373, 12, '註冊'),
(44410, 5375, 12, '註冊日期'),
(44411, 5376, 12, '報名表'),
(44412, 5377, 12, '復健'),
(44413, 5381, 12, '有關的'),
(44414, 5382, 12, '有關'),
(44415, 5383, 12, '相關問題'),
(44416, 5385, 12, '關係（S）/兒童'),
(44417, 5386, 12, '關係'),
(44418, 5387, 12, '關係'),
(44419, 5388, 12, '這個實體的相對順序'),
(44420, 5389, 12, '親屬'),
(44421, 5399, 12, '替換健康憑據由該用戶帳戶遺漏。'),
(44422, 5400, 12, '替換健康憑證'),
(44423, 5403, 12, '信仰'),
(44424, 5406, 12, '重新登錄'),
(44425, 5407, 12, 'Remdr'),
(44426, 5408, 12, '記住選定的設備'),
(44427, 5409, 12, '提醒'),
(44428, 5410, 12, '提醒間隔'),
(44429, 5411, 12, '提醒不要發了'),
(44430, 5412, 12, '發送提醒'),
(44431, 5414, 12, '匯至'),
(44432, 5416, 12, '移除'),
(44433, 5419, 12, '移除群組'),
(44434, 5420, 12, '移除群組型式'),
(44435, 5421, 12, '刪除免疫支持'),
(44436, 5422, 12, '刪除phpMyAdmin的支持'),
(44437, 5423, 12, '刪除處方'),
(44438, 5425, 12, '刪除圖表追踪功能'),
(44439, 5426, 12, '腎結石'),
(44440, 5427, 12, '重新命名'),
(44441, 5428, 12, '重新命名群組'),
(44442, 5429, 12, '呈現'),
(44443, 5430, 12, '呈現提供者'),
(44444, 5431, 12, '呈現提供者編號'),
(44445, 5432, 12, '重新排序'),
(44446, 5433, 12, '重新排列在'),
(44447, 5434, 12, '訂貨點已達到'),
(44448, 5436, 12, '重複'),
(44449, 5438, 12, '重複事件'),
(44450, 5439, 12, '重複資訊：'),
(44451, 5440, 12, '重複'),
(44452, 5444, 12, '回復日期'),
(44453, 5445, 12, '回復從'),
(44454, 5446, 12, '報告'),
(44455, 5447, 12, '報告 - 臨床'),
(44456, 5449, 12, '報告由'),
(44457, 5457, 12, '報告情況'),
(44458, 5458, 12, '報告匯總'),
(44459, 5460, 12, '申報的'),
(44460, 5461, 12, '申報的'),
(44461, 5462, 12, '申報日期'),
(44462, 5463, 12, '申報'),
(44463, 5467, 12, '請求被忽略 - 索賠處理已經運行！'),
(44464, 5474, 12, '請求服務'),
(44465, 5475, 12, '需要強有力的密碼'),
(44466, 5476, 12, '需要獨特的密碼'),
(44467, 5477, 12, '需要'),
(44468, 5479, 12, '缺少必填欄位：請選擇的EDI-271要上傳的文件'),
(44469, 5480, 12, '缺少必填欄位：請輸入名字'),
(44470, 5481, 12, '缺少必填欄位：請輸入姓'),
(44471, 5482, 12, '缺少必填欄位：請輸入使用者姓名'),
(44472, 5483, 12, '需要的欄位'),
(44473, 5484, 12, '需要'),
(44474, 5485, 12, '保留'),
(44475, 5486, 12, '保留'),
(44476, 5487, 12, '預留使用確定排定的休假時間'),
(44477, 5488, 12, '當供應商之後可能無法獲得任命時，保留定義。'),
(44478, 5489, 12, '當事件沒有按指定發生時，保留定義。'),
(44479, 5490, 12, '當提供者之後可能獲得任命時，保留定義。'),
(44480, 5491, 12, '重新設置'),
(44481, 5492, 12, '重新設定場外入口網站憑證'),
(44482, 5493, 12, '重新設定場內入口網站憑證'),
(44483, 5495, 12, 'Resn'),
(44484, 5496, 12, '解決這個問題'),
(44485, 5497, 12, '呼吸'),
(44486, 5498, 12, '用力呼吸不費力'),
(44487, 5499, 12, '呼吸的'),
(44488, 5501, 12, '限制非授權用戶在用戶管理中設置的附表設施。'),
(44489, 5502, 12, '限制用戶到設施'),
(44490, 5503, 12, '受限制的訓練'),
(44491, 5504, 12, '結果'),
(44492, 5506, 12, '結果狀態'),
(44493, 5507, 12, '結果狀態或異常遺漏'),
(44494, 5508, 12, '因此，使用萬用字元％'),
(44495, 5510, 12, '結果與'),
(44496, 5511, 12, '找到研究結果'),
(44497, 5512, 12, '結果組'),
(44498, 5515, 12, '每頁結果'),
(44499, 5516, 12, '結果/細節'),
(44500, 5517, 12, '視網膜檢查'),
(44501, 5518, 12, '回縮右惻：'),
(44502, 5519, 12, '返回'),
(44503, 5520, 12, '用您的付款，回到上述的一部分'),
(44504, 5521, 12, '返回到日曆'),
(44505, 5527, 12, '返回值'),
(44506, 5528, 12, '回訪'),
(44507, 5529, 12, '返回到播放'),
(44508, 5534, 12, '瑪嘉烈醫院回顧：'),
(44509, 5535, 12, '系統回顧'),
(44510, 5536, 12, '系統回顧檢查'),
(44511, 5537, 12, '回顧'),
(44512, 5538, 12, '調整'),
(44513, 5539, 12, '類風濕性關節炎'),
(44514, 5540, 12, '類風濕性關節炎'),
(44515, 5541, 12, '右側'),
(44516, 5542, 12, '右耳'),
(44517, 5543, 12, '右耳'),
(44518, 5545, 12, '右側：'),
(44519, 5546, 12, '言猶在耳'),
(44520, 5547, 12, '言猶在耳'),
(44521, 5549, 12, '風險因素'),
(44522, 5550, 12, '風險等級'),
(44523, 5551, 12, '右下葉肺炎：'),
(44524, 5552, 12, '右側中耳炎'),
(44525, 5560, 12, '名冊'),
(44526, 5561, 12, '路徑'),
(44527, 5562, 12, '給藥途徑，如適用'),
(44528, 5563, 12, '佈線'),
(44529, 5564, 12, '行'),
(44530, 5565, 12, '存款準備金沒有靜曲強度'),
(44531, 5566, 12, '擦：'),
(44532, 5567, 12, '擦：'),
(44533, 5568, 12, '規則'),
(44534, 5569, 12, '規則加'),
(44535, 5570, 12, '規則詳情'),
(44536, 5572, 12, '規則編輯'),
(44537, 5575, 12, '規則設置'),
(44538, 5578, 12, '規則'),
(44539, 5580, 12, '規則配置'),
(44540, 5581, 12, '運行命令： '),
(44541, 5582, 12, '破裂'),
(44542, 5583, 12, '俄國'),
(44543, 5584, 12, '接收'),
(44544, 5585, 12, '接收'),
(44545, 5598, 12, 'RxNorm'),
(44546, 5599, 12, 'RxNorm資料庫'),
(44547, 5601, 12, 'S.S.'),
(44548, 5602, 12, 'S3:'),
(44549, 5603, 12, 'S4:'),
(44550, 5604, 12, 'SA**閱讀許可請閱讀DOCS / LICENSE.TXT或訪問* http://www.gnu.org/copyleft/gpl.html '),
(44551, 5605, 12, '銷售'),
(44552, 5606, 12, '銷售量'),
(44553, 5607, 12, '主要項目的銷售量'),
(44554, 5608, 12, '銷售量產品報告'),
(44555, 5609, 12, '唾液'),
(44556, 5610, 12, '同一天'),
(44557, 5611, 12, '薩摩亞人'),
(44558, 5612, 12, '樣本 標本'),
(44559, 5613, 12, '處罰種類'),
(44560, 5617, 12, '星期六'),
(44561, 5618, 12, '週六和週日'),
(44562, 5619, 12, '星期六'),
(44563, 5620, 12, '儲存'),
(44564, 5621, 12, '儲存'),
(44565, 5624, 12, '保存和分配'),
(44566, 5626, 12, '另存為新的'),
(44567, 5627, 12, '另存為新的筆記'),
(44568, 5628, 12, '保存證書設置'),
(44569, 5629, 12, '保存更改'),
(44570, 5630, 12, '保存形式'),
(44571, 5631, 12, '保存免疫接種'),
(44572, 5632, 12, '保存新領域'),
(44573, 5633, 12, '保存新群組'),
(44574, 5634, 12, '保存新的列表'),
(44575, 5635, 12, '保存新範本'),
(44576, 5637, 12, '保存病人的人口統計資料'),
(44577, 5638, 12, '成功的保存圖表編號'),
(44578, 5639, 12, '保存事務'),
(44579, 5641, 12, '掃描'),
(44580, 5642, 12, '掃描遭遇筆記'),
(44581, 5643, 12, '掃瞄器目錄'),
(44582, 5644, 12, '掃描程序在'),
(44583, 5645, 12, '日程表'),
(44584, 5646, 12, '進度設施：'),
(44585, 5647, 12, '校注'),
(44586, 5648, 12, '脊柱側彎'),
(44587, 5651, 12, 'SE'),
(44588, 5652, 12, 'SE地址'),
(44589, 5653, 12, 'SE城市'),
(44590, 5654, 12, 'SE國家'),
(44591, 5655, 12, '東南方位'),
(44592, 5656, 12, 'SE郵政編碼'),
(44593, 5657, 12, 'SE州'),
(44594, 5658, 12, 'SE郵編'),
(44595, 5659, 12, '搜尋'),
(44596, 5661, 12, '搜尋'),
(44597, 5662, 12, '再搜尋'),
(44598, 5664, 12, '搜尋被：'),
(44599, 5665, 12, '搜索'),
(44600, 5666, 12, '搜索：'),
(44601, 5668, 12, '相關搜索'),
(44602, 5669, 12, '搜尋或新增病人'),
(44603, 5670, 12, '搜索付款'),
(44604, 5672, 12, '搜索結果：'),
(44605, 5673, 12, '搜索時選擇'),
(44606, 5674, 12, '搜索字符串沒有與數據庫中的名單相符'),
(44607, 5675, 12, '搜索字符串應該至少有三個字元'),
(44608, 5676, 12, '搜索文字'),
(44609, 5677, 12, '搜索事件'),
(44610, 5678, 12, '搜索/添加'),
(44611, 5679, 12, '搜索/加入保險人'),
(44612, 5680, 12, '尋找約會'),
(44613, 5681, 12, '搜索...'),
(44614, 5682, 12, '使用安全帶'),
(44615, 5683, 12, '使用安全帶'),
(44616, 5684, 12, '第二'),
(44617, 5687, 12, '續發的'),
(44618, 5688, 12, '次要保險'),
(44619, 5689, 12, '次要保險日期'),
(44620, 5690, 12, '次要保險提供者'),
(44621, 5698, 12, '安全性'),
(44622, 5699, 12, '查看全部'),
(44623, 5700, 12, '看到授權'),
(44624, 5701, 12, '看生長曲線圖'),
(44625, 5702, 12, '從最後一組產生的索賠看到消息'),
(44626, 5704, 12, '看到自'),
(44627, 5707, 12, '痙攣'),
(44628, 5708, 12, 'SEL'),
(44629, 5709, 12, '選擇'),
(44630, 5710, 12, '選擇'),
(44631, 5712, 12, '選擇一個關聯'),
(44632, 5715, 12, '選擇一個用戶'),
(44633, 5716, 12, '選擇全部'),
(44635, 5720, 12, '選擇類別'),
(44636, 5722, 12, '選擇對應的的複選框以刪除'),
(44637, 5723, 12, '選擇要刪除的標準'),
(44638, 5725, 12, '選擇去識別所需的資料'),
(44639, 5726, 12, '選擇的數據將在包含在去識別的資料中'),
(44640, 5727, 12, '選擇的日期'),
(44641, 5728, 12, '選擇所需的陣容'),
(44642, 5729, 12, '選擇診斷'),
(44643, 5730, 12, '為去識別請求選擇診斷'),
(44644, 5731, 12, '選擇藥物'),
(44645, 5732, 12, '選擇藥物'),
(44646, 5733, 12, '為去識別請求選擇藥物'),
(44647, 5734, 12, '選擇EDI-271文件'),
(44648, 5736, 12, '選擇字段'),
(44649, 5737, 12, '選擇字段'),
(44650, 5738, 12, '選擇列印'),
(44651, 5739, 12, '選擇免疫'),
(44652, 5740, 12, '為去識別請求選擇免疫'),
(44653, 5741, 12, '藉由輸入選擇保險'),
(44654, 5742, 12, '選擇目錄'),
(44655, 5744, 12, '選擇語言'),
(44656, 5754, 12, '選擇導出的配置項'),
(44657, 5755, 12, '選擇在這一天任何錯過了的事件負有主要責任的問題'),
(44658, 5759, 12, '選擇用戶'),
(44659, 5760, 12, '從下載表單中選擇客戶'),
(44660, 5761, 12, '選擇哪種語言，如果有的話，可能會在登錄時選擇。 （只有相關，如果上述所有語言允許被關閉）'),
(44661, 5762, 12, '選擇“是”以確認群組刪除'),
(44662, 5765, 12, '選擇的'),
(44663, 5766, 12, '選擇遭遇'),
(44664, 5768, 12, '自己'),
(44665, 5769, 12, '自付費'),
(44666, 5771, 12, '發送'),
(44667, 5774, 12, '發送正在進行中'),
(44668, 5775, 12, '發送消息'),
(44669, 5776, 12, '發送提醒批次'),
(44670, 5777, 12, '發送提醒患者每個病人對預防/追蹤照顧的偏好。'),
(44671, 5778, 12, '發送轉介摘要'),
(44672, 5779, 12, '發送此文件'),
(44673, 5788, 12, '寄件人'),
(44674, 5789, 12, '寄件者識別碼'),
(44675, 5790, 12, '寄件者識別碼（ISA06）'),
(44676, 5791, 12, '寄件者識別碼限定符（ISA05）'),
(44677, 5794, 12, '敏感性'),
(44678, 5795, 12, '敏感性：'),
(44679, 5796, 12, '感官檢查正常'),
(44680, 5802, 12, '已發送郵件'),
(44681, 5803, 12, '發送病歷？'),
(44682, 5804, 12, '成功的發送'),
(44683, 5807, 12, '發送到印表機。'),
(44684, 5812, 12, '九月'),
(44685, 5813, 12, '分離'),
(44686, 5814, 12, '九月'),
(44687, 5815, 12, '順序'),
(44688, 5816, 12, '順序'),
(44689, 5821, 12, '服務'),
(44690, 5822, 12, '服務類別'),
(44691, 5823, 12, '服務代碼'),
(44692, 5825, 12, '服務代碼'),
(44693, 5826, 12, '服務日期'),
(44694, 5827, 12, '服務日期：'),
(44695, 5829, 12, '服務地點'),
(44696, 5831, 12, '專家提供的服務'),
(44697, 5834, 12, '服務'),
(44698, 5835, 12, '服務類別'),
(44699, 5836, 12, '提供的服務'),
(44700, 5837, 12, '提供的服務'),
(44701, 5838, 12, '服務/產品'),
(44702, 5839, 12, '工作階段類型'),
(44703, 5840, 12, '設置'),
(44704, 5841, 12, '設施設置Cookie以記住登錄之間的選定設施。'),
(44705, 5845, 12, '設置這個完整的絕對路徑。為創建HTTPS客戶端SSL證書。'),
(44706, 5846, 12, '設置到'),
(44707, 5847, 12, '設為默認值'),
(44708, 5848, 12, '設置在數據庫中的版本編號...'),
(44709, 5849, 12, '設置'),
(44710, 5851, 12, '嚴重偏頭痛'),
(44711, 5853, 12, '疼痛嚴重程度'),
(44712, 5854, 12, '疼痛嚴重程度：'),
(44713, 5855, 12, '性別'),
(44714, 5856, 12, '性病'),
(44715, 5858, 12, 'SHA-1哈希'),
(44716, 5859, 12, '分享'),
(44717, 5860, 12, '從伺服器發出的列印shell命令'),
(44718, 5864, 12, '呼吸短促'),
(44719, 5865, 12, '呼吸短促'),
(44720, 5866, 12, '呼吸短促2'),
(44721, 5867, 12, '拍攝紀錄'),
(44722, 5868, 12, '作為拍攝記錄：');
INSERT INTO `lang_definitions` VALUES
(44723, 5870, 12, '應該像NNNNN-NNNN-NN'),
(44724, 5871, 12, '應該是兩個字母'),
(44725, 5872, 12, '應包含10個數字'),
(44726, 5873, 12, '應包含只有10個數字'),
(44727, 5874, 12, '肩膀'),
(44728, 5875, 12, '肩膀+鎖骨'),
(44729, 5876, 12, '肩膀問題'),
(44730, 5877, 12, '顯示'),
(44731, 5880, 12, '顯示全部'),
(44732, 5883, 12, '顯示所有事務'),
(44733, 5884, 12, '顯示為忙碌'),
(44734, 5885, 12, '只顯示授權'),
(44735, 5886, 12, '顯示可用的時間'),
(44736, 5887, 12, '顯示美元和公制（主要單位是公制）'),
(44737, 5888, 12, '顯示美元和公制（主要單位是公制）'),
(44738, 5889, 12, '顯示詳細信息'),
(44739, 5891, 12, '顯示圖形'),
(44740, 5893, 12, '顯示管理頁面上有多少事件？'),
(44741, 5896, 12, '顯示菜單'),
(44742, 5897, 12, '只顯示公制'),
(44743, 5898, 12, '顯示註釋'),
(44744, 5901, 12, '顯示病人筆記'),
(44745, 5904, 12, '顯示初步完成'),
(44746, 5906, 12, '顯示報告'),
(44747, 5907, 12, '在區塊中顯示搜索/提交的連結？'),
(44748, 5910, 12, '顯示附加列表部件的自訂定義狀態的形式（要求標題和縮寫）。'),
(44749, 5913, 12, '只顯示未入賬'),
(44750, 5914, 12, '只顯示美國'),
(44751, 5920, 12, '手足'),
(44752, 5921, 12, '鎌狀細胞'),
(44753, 5922, 12, '加標記'),
(44754, 5923, 12, '乙狀結腸/大腸鏡檢查'),
(44755, 5925, 12, '簽署實驗室檢測結果（寫，addonly可選）'),
(44756, 5926, 12, '簽署結果'),
(44757, 5927, 12, '簽名'),
(44758, 5929, 12, '簽名：'),
(44759, 5930, 12, '簽名接收'),
(44760, 5932, 12, '顯著腫脹：'),
(44761, 5934, 12, '簡化的共同付款'),
(44762, 5935, 12, '簡化的人口統計學'),
(44763, 5936, 12, '簡化的處方'),
(44764, 5937, 12, '自從'),
(44765, 5938, 12, '真誠的，'),
(44766, 5940, 12, '單一'),
(44767, 5941, 12, '單選擇列表'),
(44768, 5942, 12, '單選擇列表與能力添加到列表'),
(44769, 5946, 12, '竇問題'),
(44770, 5947, 12, '竇手術'),
(44771, 5948, 12, '竇壓痛：'),
(44772, 5949, 12, '鼻竇炎'),
(44773, 5951, 12, '網站憑證'),
(44774, 5953, 12, '為LibreEHR支持LLC實驗室交換服務的網站憑證。'),
(44775, 5956, 12, '大小'),
(44776, 5957, 12, '大小必須是一個介於1和999之間的數字'),
(44777, 5958, 12, '尺寸/名單'),
(44778, 5959, 12, '皮膚'),
(44779, 5960, 12, '皮膚癌'),
(44780, 5961, 12, '皮膚疾病'),
(44781, 5962, 12, '皮膚其他'),
(44782, 5963, 12, '跳過病人註釋的授權'),
(44783, 5964, 12, '略過一節'),
(44784, 5965, 12, '略過SQL總帳轉儲 - 沒有為Windows服務器實施'),
(44785, 5967, 12, '睡眠形態'),
(44786, 5968, 12, '睡眠形態'),
(44787, 5969, 12, '睡眠形態'),
(44788, 5970, 12, '斯洛伐克'),
(44789, 5972, 12, '釤債務W / O'),
(44790, 5973, 12, '醒目的快取記憶體已被清除'),
(44791, 5974, 12, '吸煙者，目前狀態未知'),
(44792, 5976, 12, '吸煙情形'),
(44793, 5977, 12, '短訊驗證'),
(44794, 5978, 12, '短訊網關'),
(44795, 5979, 12, '短訊網關API鍵'),
(44796, 5980, 12, '短信網關API鍵'),
(44797, 5981, 12, '短訊網關密碼'),
(44798, 5982, 12, '短訊網關用戶名稱'),
(44799, 5983, 12, '短訊通知'),
(44800, 5984, 12, '短訊通知時間'),
(44801, 5985, 12, '短訊發送前'),
(44802, 5986, 12, '短訊發送'),
(44803, 5987, 12, '短訊，可用標籤：***姓名***，***提供商***，***日期***，*** STARTTIME***，*** ENDTIME***參考，即親愛的***姓名***'),
(44804, 5988, 12, '短訊/電子郵件警報設置'),
(44805, 5989, 12, 'SMTP密碼身份驗證'),
(44806, 5992, 12, 'SMTP服務器的主機名'),
(44807, 5993, 12, 'SMTP服務器端口號碼'),
(44808, 5994, 12, 'SMTP用戶身份驗證'),
(44809, 6001, 12, 'SNOMED的資料庫'),
(44810, 6004, 12, '打鼾'),
(44811, 6005, 12, '主觀資料客觀資料評估計畫'),
(44812, 6006, 12, '社交困難'),
(44813, 6009, 12, '社會史：'),
(44814, 6010, 12, '社會安全號碼'),
(44815, 6011, 12, '解決'),
(44816, 6013, 12, '語義上下文'),
(44817, 6014, 12, '一些授權不顯示。點擊此處查看全部'),
(44818, 6015, 12, '有些代碼不顯示。'),
(44819, 6016, 12, '一些遭遇不顯示。點擊此處查看全部。'),
(44820, 6017, 12, '去識別過程中出現一些錯誤'),
(44821, 6018, 12, '不顯示一些注意事項。'),
(44822, 6020, 12, '有些話'),
(44823, 6023, 12, '出了錯。請再試一次。'),
(44824, 6024, 12, '不久，由於時間間隔（臨床提醒）'),
(44825, 6025, 12, '不久，由於時間間隔（病人提醒）'),
(44826, 6026, 12, '喉嚨痛'),
(44827, 6028, 12, '很抱歉，上傳您的檔案有問題'),
(44828, 6029, 12, '排序'),
(44829, 6030, 12, '排序'),
(44830, 6031, 12, '通過校驗和排序'),
(44831, 6032, 12, '排序意見'),
(44832, 6033, 12, '按CRT用戶排序'),
(44833, 6034, 12, '按日期排序'),
(44834, 6035, 12, '按日期/時間排序'),
(44835, 6036, 12, '按事件排序'),
(44836, 6037, 12, '按群組排序'),
(44837, 6040, 12, '按病人身分排序'),
(44838, 6041, 12, '按成功排序'),
(44839, 6043, 12, '按用戶排序'),
(44840, 6044, 12, '按疫苗排序'),
(44841, 6045, 12, '降序'),
(44842, 6046, 12, '排序結果'),
(44843, 6047, 12, '升序'),
(44844, 6048, 12, '來源'),
(44845, 6049, 12, '來源檔案'),
(44846, 6050, 12, '來源檔案路徑'),
(44847, 6051, 12, '來源遺漏的代碼 '),
(44848, 6052, 12, '來源批次'),
(44849, 6057, 12, '來源：'),
(44850, 6060, 12, '空間'),
(44851, 6061, 12, '空間'),
(44852, 6062, 12, '西班牙'),
(44853, 6068, 12, '專家'),
(44854, 6069, 12, '專家姓名和簽名'),
(44855, 6071, 12, '專業'),
(44856, 6072, 12, '專業系統'),
(44857, 6073, 12, '專業：'),
(44858, 6074, 12, '具體'),
(44859, 6075, 12, '具體應用'),
(44860, 6076, 12, '具體避孕服務'),
(44861, 6077, 12, '具體結果'),
(44862, 6078, 12, '具體服務'),
(44863, 6079, 12, '具體的'),
(44864, 6080, 12, '指定的編碼格式。 ＃=數字，* =任意字符。空如果不使用。'),
(44865, 6081, 12, '指定的編碼格式。＃=數字，@=阿爾法，* =任意字符。空如果不使用。'),
(44866, 6082, 12, '指定格式化發票參考號碼。 ＃=數字，* =任意字符。空如果不使用。'),
(44867, 6083, 12, '指定格式化發票參考號碼。＃=數字，@=阿爾法，* =任意字符。空如果不使用。'),
(44868, 6084, 12, '指定格式化產品NDC的領域。 ＃=數字，* =任意字符。空如果不使用。'),
(44869, 6085, 12, '指定格式化產品NDC的領域。＃=數字，@=阿爾法，* =任意字符。空如果不使用。'),
(44870, 6086, 12, '指定格式為外部的病人ID。 ＃=數字，* =任意字符。空如果不使用。'),
(44871, 6087, 12, '指定格式為外部的病人ID。＃=數字，@=阿爾法，* =任意字符。空如果不使用。'),
(44872, 6088, 12, '標本'),
(44873, 6089, 12, '標本數/標識符'),
(44874, 6090, 12, '標本類型'),
(44875, 6092, 12, '語音聽寫'),
(44876, 6093, 12, '殺精劑'),
(44877, 6094, 12, '脾臟切除術'),
(44878, 6095, 12, '配偶'),
(44879, 6097, 12, '痰'),
(44880, 6098, 12, '痰：'),
(44881, 6099, 12, '倚'),
(44882, 6102, 12, '陣容'),
(44883, 6103, 12, '陣容成員'),
(44884, 6104, 12, '小隊'),
(44885, 6105, 12, '生殖健康'),
(44886, 6106, 12, '生殖健康 - 計劃生育'),
(44887, 6107, 12, '生殖健康非計劃生育'),
(44888, 6108, 12, '生殖健康轉介'),
(44889, 6109, 12, '生殖健康訪問表'),
(44890, 6110, 12, 'SRV日期'),
(44891, 6111, 12, '不銹鋼'),
(44892, 6112, 12, 'SSL證書管理'),
(44893, 6113, 12, '社會安全號碼'),
(44894, 6114, 12, '穩定度'),
(44895, 6116, 12, '標準'),
(44896, 6117, 12, '標準代碼'),
(44897, 6118, 12, '標準測量'),
(44898, 6122, 12, '標準名稱'),
(44899, 6124, 12, '開始'),
(44900, 6125, 12, '開始(年年年年/月月/日日) '),
(44901, 6128, 12, '開始日期'),
(44902, 6129, 12, '在這診所的開始日期'),
(44903, 6130, 12, '開始日期不應該大於結束日期'),
(44904, 6131, 12, '開始日期︰'),
(44905, 6132, 12, '開始日期︰'),
(44906, 6133, 12, '開始時間'),
(44907, 6134, 12, '開始日期'),
(44908, 6135, 12, '統計'),
(44909, 6136, 12, '國家'),
(44910, 6137, 12, '國家數據類型'),
(44911, 6139, 12, '國家許可證編號'),
(44912, 6140, 12, '狀態列表'),
(44913, 6141, 12, '國家名單（寫，addonly可選）'),
(44914, 6142, 12, '國家列表部件的自定義字段'),
(44915, 6143, 12, '州或省'),
(44916, 6144, 12, '國家/產地'),
(44917, 6145, 12, '國家/教區'),
(44918, 6146, 12, '發言摘要'),
(44919, 6147, 12, '報表和更新發票。'),
(44920, 6148, 12, '報表發送：'),
(44921, 6149, 12, '報表;發票將不會被更新。'),
(44922, 6150, 12, '靜態文字'),
(44923, 6151, 12, '統計'),
(44924, 6152, 12, '統計'),
(44925, 6153, 12, '狀態'),
(44926, 6156, 12, '現狀'),
(44927, 6158, 12, '性病/愛滋病Couns'),
(44928, 6159, 12, '實力和調節'),
(44929, 6169, 12, '關節僵硬'),
(44930, 6170, 12, '僵硬'),
(44931, 6171, 12, '庫存月份'),
(44932, 6172, 12, '胃痛'),
(44933, 6174, 12, '儲存的散列'),
(44934, 6175, 12, '肌肉緊張'),
(44935, 6176, 12, '流'),
(44936, 6177, 12, '街道'),
(44937, 6178, 12, '街道地址'),
(44938, 6179, 12, '街道與號碼'),
(44939, 6180, 12, '強度'),
(44940, 6182, 12, '咽喉炎'),
(44941, 6183, 12, '壓迫性骨折'),
(44942, 6184, 12, '壓力試驗'),
(44943, 6185, 12, '中風'),
(44944, 6186, 12, '強密碼是指至少8個字符，並至少有三個：一個數字，小寫字母，大寫字母，特殊字符。'),
(44945, 6188, 12, '添加新患者使用的形式風格'),
(44946, 6189, 12, '子類'),
(44947, 6190, 12, '小計'),
(44948, 6191, 12, '子類'),
(44949, 6192, 12, '子類'),
(44950, 6193, 12, '皮下'),
(44951, 6194, 12, '主題'),
(44952, 6195, 12, '主題的'),
(44953, 6196, 12, '舌下'),
(44954, 6197, 12, '舌下'),
(44955, 6198, 12, '提交'),
(44956, 6199, 12, '提交'),
(44957, 6200, 12, '提交全部內容'),
(44958, 6202, 12, '提交事件'),
(44959, 6203, 12, '提交表單'),
(44960, 6204, 12, '提交選擇的內容'),
(44961, 6205, 12, '提交'),
(44962, 6206, 12, '提交被'),
(44963, 6207, 12, '發表者EDI存取號碼（PER06）'),
(44964, 6208, 12, '訂閱者'),
(44965, 6209, 12, '訂閱者住址'),
(44966, 6213, 12, '訂閱者单位'),
(44967, 6214, 12, '訂閱者单位(SE)'),
(44968, 6215, 12, '訂閱者单位地址'),
(44969, 6216, 12, '訂閱者单位城市'),
(44970, 6217, 12, '訂閱者单位國家'),
(44971, 6218, 12, '訂閱者单位州'),
(44972, 6221, 12, '訂閱者单位郵編'),
(44973, 6225, 12, '訂閱者電話'),
(44974, 6226, 12, '訂閱者關係'),
(44975, 6227, 12, '訂閱者的關係不是自封，但名稱是相同的！這是真的確定嗎？'),
(44976, 6228, 12, '訂閱者的關係不是自封，但SS名稱是相同的！'),
(44977, 6229, 12, '訂閱者的關係是自封，但名稱不一樣！這是真的確定嗎？'),
(44978, 6230, 12, '訂閱者的關係是自封，但SS名稱不一樣！'),
(44979, 6231, 12, '訂閱者性別'),
(44980, 6237, 12, '替換'),
(44981, 6238, 12, '允許替換'),
(44982, 6240, 12, '成功'),
(44983, 6241, 12, '成功'),
(44984, 6242, 12, '成功確認收到實驗室的結果'),
(44985, 6243, 12, '成功收到實驗室的結果'),
(44986, 6244, 12, '從實驗室交換網絡的成功檢索結果'),
(44987, 6246, 12, '成功添加類別'),
(44988, 6247, 12, '成功添加到類別'),
(44989, 6248, 12, '成功刪除'),
(44990, 6250, 12, '成功安裝了資料庫。'),
(44991, 6252, 12, '修改成功'),
(44992, 6253, 12, '成功儲存，你想分配嗎？'),
(44993, 6254, 12, '成功儲存，你想分發嗎？'),
(44994, 6256, 12, '成功儲存。'),
(44995, 6257, 12, '成功升級資料庫。'),
(44996, 6259, 12, '成功地'),
(44997, 6260, 12, '自殺'),
(44998, 6261, 12, '總結'),
(44999, 6262, 12, '總結'),
(45000, 6265, 12, '太陽'),
(45001, 6267, 12, '星期日'),
(45002, 6268, 12, 'Superbill'),
(45003, 6269, 12, 'superbill代碼'),
(45004, 6270, 12, 'superbill代碼管理'),
(45005, 6271, 12, 'Superbill報告'),
(45006, 6274, 12, 'superbills，有時也被稱為遇到表格或路線簡，是大多數醫療實踐的重要組成部分。'),
(45007, 6275, 12, '超級用戶'),
(45008, 6276, 12, '監督'),
(45009, 6278, 12, '監督醫生DEA方法'),
(45010, 6279, 12, '監督醫生姓名'),
(45011, 6280, 12, '監督醫生的姓氏'),
(45012, 6281, 12, '監督醫生新產品引進'),
(45013, 6282, 12, '監督醫生的UPIN'),
(45014, 6283, 12, '供應商設施的名稱'),
(45015, 6284, 12, '適用於多個供應商的支持日曆事件'),
(45016, 6285, 12, '經由備份頁面支持出口/進口配置數據。'),
(45017, 6286, 12, '支持多種供應商的活動'),
(45018, 6288, 12, '支持三重DES加密/解密。'),
(45019, 6289, 12, '表面類型'),
(45020, 6290, 12, '手術'),
(45021, 6291, 12, '手術'),
(45022, 6293, 12, '懸浮'),
(45023, 6294, 12, '懸掛'),
(45024, 6295, 12, 'SVC的日期'),
(45025, 6296, 12, 'SVC的日期：'),
(45026, 6299, 12, '流汗：'),
(45027, 6300, 12, '瑞典'),
(45028, 6301, 12, '腫脹'),
(45029, 6302, 12, '右側腫脹'),
(45030, 6303, 12, '關節腫脹'),
(45031, 6304, 12, '淋巴節腫脹'),
(45032, 6305, 12, '作為貨幣的小數點符號使用。如果小數位數為0則不使用。'),
(45033, 6306, 12, '用符號分開成千上萬貨幣。'),
(45034, 6307, 12, '症狀'),
(45035, 6308, 12, '同步'),
(45036, 6309, 12, '自定義語言表的同步翻譯。'),
(45037, 6310, 12, '同步新的自定義常數：'),
(45038, 6311, 12, '同步新的自定義的語言：'),
(45039, 6312, 12, '同步的新定義（語言，常數，定義）：'),
(45040, 6313, 12, '昏厥'),
(45041, 6314, 12, '症狀監測'),
(45042, 6315, 12, '症狀監測 - 非報告的問題'),
(45043, 6317, 12, '滑膜炎，撞擊，滑囊炎'),
(45044, 6318, 12, '系統'),
(45045, 6323, 12, '一天三次'),
(45046, 6324, 12, 'T.V.'),
(45047, 6325, 12, '表'),
(45048, 6327, 12, '創建表失敗'),
(45049, 6328, 12, '表更新失敗'),
(45050, 6330, 12, '錠劑'),
(45051, 6332, 12, '菲律賓語'),
(45052, 6335, 12, '拿'),
(45053, 6336, 12, '參加保險，從下拉'),
(45054, 6337, 12, '採取付款從，從下拉'),
(45055, 6338, 12, '收回'),
(45056, 6339, 12, '需要長時間'),
(45057, 6340, 12, '高大導航區'),
(45058, 6347, 12, '預定日期'),
(45059, 6351, 12, '目標/行動組'),
(45060, 6354, 12, '稅籍編號'),
(45061, 6355, 12, '稅率'),
(45062, 6356, 12, '稅'),
(45063, 6357, 12, '分類'),
(45064, 6358, 12, '運輸署'),
(45065, 6359, 12, '團隊損傷概述'),
(45066, 6360, 12, '隊員名單'),
(45067, 6361, 12, '隊員名單查看'),
(45068, 6362, 12, '團隊/隊'),
(45069, 6363, 12, '電話'),
(45070, 6364, 12, '電話國家代碼'),
(45071, 6366, 12, '溫度'),
(45072, 6367, 12, '臨時位置'),
(45073, 6368, 12, '溫度方法'),
(45074, 6369, 12, '溫度'),
(45075, 6370, 12, '範本'),
(45076, 6371, 12, '範本名稱'),
(45077, 6372, 12, '範本名稱不能以數字開始'),
(45078, 6373, 12, '範本：'),
(45079, 6374, 12, '範本'),
(45080, 6375, 12, '顳動脈'),
(45081, 6376, 12, '肌腱損傷'),
(45082, 6377, 12, '肌腱/塵埃沉著病/滑囊炎'),
(45083, 6378, 12, '暫行發票編號無'),
(45084, 6379, 12, '第三'),
(45085, 6380, 12, '第三保險'),
(45086, 6381, 12, '第三保險資料'),
(45087, 6382, 12, '第三保險提供者'),
(45088, 6383, 12, '測試排程'),
(45089, 6384, 12, '測試系統'),
(45090, 6385, 12, '文字'),
(45091, 6386, 12, '文字診斷'),
(45092, 6387, 12, '文字欄位'),
(45093, 6393, 12, '文字-日期'),
(45094, 6394, 12, '文字-日期'),
(45095, 6395, 12, '文本區域'),
(45096, 6396, 12, '文本區域'),
(45097, 6397, 12, '文字方塊'),
(45098, 6398, 12, '文字方塊'),
(45099, 6399, 12, '文字方塊名單'),
(45100, 6400, 12, '文字方塊名單'),
(45101, 6401, 12, '泰國'),
(45102, 6402, 12, '謝謝你'),
(45103, 6403, 12, '感謝您選擇'),
(45104, 6404, 12, '“清除”按鈕，將刪除所有註釋。'),
(45105, 6405, 12, '上述聲明失敗'),
(45106, 6406, 12, 'Apache的SSL服務器證書和公鑰'),
(45107, 6407, 12, '證書頒發機構的證書'),
(45108, 6408, 12, '索賠文件： '),
(45109, 6410, 12, '相應的私鑰'),
(45110, 6413, 12, '拒絕代碼是'),
(45111, 6414, 12, '拒絕群組代碼是'),
(45112, 6415, 12, '目標的形式被關閉'),
(45113, 6416, 12, '目標的形式被關閉，對你的選擇我不能採取行動。'),
(45114, 6418, 12, 'EP，合資格的醫院或CAH從其他照顧機構或護理服務提供者接受病人，或者認為遭遇是應執行有關藥物核對。'),
(45115, 6421, 12, 'EP，合資格的醫院或CAH轉送他們的病人到其他照顧機構或護理服務提供者或轉送他們的病人到其他照顧機構，應該提供每個過渡期照顧或轉介的照顧紀錄的摘要。'),
(45116, 6422, 12, '事件（S）已獲得批准。'),
(45117, 6423, 12, '事件（S）已被隱藏。'),
(45118, 6424, 12, '導出的數據將出現在下面的文本區域。您可以複製並粘貼到電子郵件或任何其他所需的目的地。'),
(45119, 6426, 12, '導出的數據將出現在下面的文本區域。您可以複製並粘貼到電子郵件或任何其他所需的目的地。'),
(45120, 6427, 12, '導出的數據將出現在下面的文本區域。您可以複製並粘貼到電子郵件或任何其他所需的目的地。'),
(45121, 6429, 12, '檔案無法成功更名，此錯誤通常與存儲系統上的權限問題有關。'),
(45122, 6434, 12, '已加入以下的日曆事件：'),
(45123, 6435, 12, '以下的日曆事件已被修改：'),
(45124, 6436, 12, '以下類別將從您的類別列表刪除'),
(45125, 6437, 12, '下列發布的資料庫是最近安裝的'),
(45126, 6439, 12, '下列EDI檔案已上載'),
(45127, 6440, 12, '下列緊急登錄用戶被激活：'),
(45128, 6441, 12, '發生以下錯誤'),
(45129, 6444, 12, '需要以下領域'),
(45130, 6446, 12, '以下字段必須填寫發送請求。'),
(45131, 6449, 12, 'ATNA審計倉庫機器的主機名稱。'),
(45132, 6450, 12, '初始窗口是發票的搜索頁面。在頂部，你可以輸入源碼（如支票號碼），支付日期，支票金額。來源及收費日期的原因是使你不必為每一項索賠一次又一次的鍵入他們。給的每個發票是付款的一部分，你輸入的金額將減少，並希望當你做的時候能以零結束。'),
(45133, 6456, 12, '出現在表單上的用戶的標籤'),
(45134, 6457, 12, '長度不應超過以下數量的字符'),
(45135, 6460, 12, '新的類別，將是一個子類 '),
(45136, 6461, 12, '新密碼不能和目前的密碼相同。'),
(45137, 6462, 12, '新密碼字段是不一樣的。'),
(45138, 6466, 12, '密碼必須至少為八個字符，並應'),
(45139, 6468, 12, '已記錄病人的記錄請求。'),
(45140, 6469, 12, '病人提醒已發送'),
(45141, 6470, 12, '病人提醒已更新'),
(45142, 6472, 12, '支付發布不能低於這個日期.這確保拿了最終報告以後，沒有人發布以前的資料。'),
(45143, 6475, 12, '其餘以下的信息僅適用於您手工張貼，或者如果你正在做手工更正。'),
(45144, 6477, 12, '要求的文件是不存在文件系統上預期的位置，或者有沒有足夠的權限進入它。'),
(45145, 6480, 12, '從第一頁被複製的來源和日期列，所以通常你不需要接觸這些。你可以把薪酬支付的金額放在支付列，調整金額放在調整列，或兩者兼而有之。您也可以點擊右側的“W”自動計算調整值，為該行的項目寫入了收費的其餘部分。'),
(45146, 6484, 12, '日曆的時間粒度和預約時隙的間隔以分鐘為最小。'),
(45147, 6485, 12, '翻譯的標籤將出現用當前的語言形式'),
(45148, 6486, 12, '翻譯的標題將以當前的語言出現'),
(45149, 6487, 12, '用當前的語言描述的翻譯'),
(45150, 6488, 12, '翻譯表是同步的。'),
(45151, 6489, 12, '這個實體的類型'),
(45152, 6490, 12, '供應商特定的代碼，識別此過程或結果'),
(45153, 6491, 12, '這個X12的文件，就像由此產生的HTML輸出報告，存檔在“時代”的主要LibreEHR安裝目錄的子目錄。你將要不時對這些檔案存檔。 URL是'),
(45154, 6492, 12, 'zip文件將包含以下項目'),
(45155, 6493, 12, '主題'),
(45156, 6495, 12, '治療性注射'),
(45157, 6496, 12, '有'),
(45158, 6497, 12, '目前沒有處方'),
(45159, 6498, 12, '您提交有錯誤。這些概述如下。'),
(45160, 6500, 12, '沒有病歷簽出'),
(45161, 6501, 12, '這個病人的記錄沒有披露。'),
(45162, 6502, 12, '沒有新的提交的文件'),
(45163, 6503, 12, '這個病人檔案中沒有註釋。'),
(45164, 6504, 12, '這個病人檔案中沒有任何交易。'),
(45165, 6505, 12, '已經有一個郵件錯誤發送到'),
(45166, 6506, 12, '已經有一個類別命名為'),
(45167, 6507, 12, '已經有一個次類別命名為'),
(45168, 6508, 12, '已經有一個項目命名為'),
(45169, 6509, 12, '已經有一個開放的病歷請求。'),
(45170, 6510, 12, '沒有農委會條目的AR帳戶 '),
(45171, 6511, 12, '沒有COA條目的現金帳戶 '),
(45172, 6512, 12, '沒有COA條目的收入帳戶 '),
(45173, 6513, 12, '沒有當前的病人'),
(45174, 6515, 12, '沒有符合的發票編號'),
(45175, 6516, 12, '沒有符合的發票編號＝ '),
(45176, 6517, 12, '服務編號沒有零件條目 '),
(45177, 6520, 12, '正當處理您的請求時，有一個錯誤。'),
(45178, 6523, 12, '增厚，右：'),
(45179, 6524, 12, '大腿'),
(45180, 6525, 12, '大腿+腿筋'),
(45181, 6527, 12, '就是後台辦公室可以閱讀和進入，但不能修改'),
(45182, 6528, 12, '就是後台辦公室可以閱讀和修改'),
(45183, 6531, 12, '就是臨床醫師可以讀取和進入，但不能修改'),
(45184, 6532, 12, '就是臨床醫師可以讀取和修改'),
(45185, 6535, 12, '就是前台辦公室可以閱讀和進入，但不能修改'),
(45186, 6536, 12, '就是前台辦公室可以閱讀和修改'),
(45187, 6539, 12, '就是醫師可以讀取和進入，但不能修改'),
(45188, 6540, 12, '就是醫師可以讀取和修改'),
(45189, 6542, 12, '第三'),
(45190, 6544, 12, '這一行動不可撤消'),
(45191, 6545, 12, '這一行動不可撤消'),
(45192, 6547, 12, '這個行動將被記錄'),
(45193, 6551, 12, '本日曆年度'),
(45194, 6554, 12, '這種說法一直否認.原因： -'),
(45195, 6555, 12, '這項索賠已被轉發到下一級別。'),
(45196, 6556, 12, '此代碼類型不接受關係。'),
(45197, 6557, 12, '這個上下文包含的類別，將被刪除。你仍然要繼續嗎？'),
(45198, 6558, 12, '這就決定任命如何在日曆上顯示。'),
(45199, 6559, 12, '這就決定任命配色方案'),
(45200, 6561, 12, '這場遭遇戰'),
(45201, 6565, 12, '此功能是非常實驗性，並沒有完全測試。使用需要您自擔風險！'),
(45202, 6566, 12, '該發票號碼已變更為 '),
(45203, 6575, 12, '這個模塊是處於測試模式。該數據庫將不能更改。'),
(45204, 6576, 12, '此模塊，促進有效的進入EOB資料。'),
(45205, 6577, 12, '這個日期的月份'),
(45206, 6581, 12, '這頁的內聯將包括登錄頁面，使我們不必每次點擊重新登錄。'),
(45207, 6582, 12, '這個病人沒有活動。'),
(45208, 6583, 12, '這名病人身份證已在使用！'),
(45209, 6584, 12, '此產品只允許每個倉庫的一個地段。'),
(45210, 6591, 12, '這一步將生成一個文件，你必須儲存以供將來使用。該文件不能再次產生。你要繼續嗎？'),
(45211, 6592, 12, '該用戶是不屬於任何團體的成員'),
(45212, 6595, 12, '這次訪問開始新的使用避孕方法'),
(45213, 6596, 12, '這次訪問將需要一個GCAC形式，轉介或程序服務。'),
(45214, 6597, 12, '這是舊的指標只有生命徵象表單，現在已經過時。'),
(45215, 6598, 12, '本週迄今'),
(45216, 6600, 12, '這將激活CCR（照顧記錄連續性）和CCD（護理文件的連續性）的報告。'),
(45217, 6602, 12, '這將允許選擇調試（“虛擬”）的語言。'),
(45218, 6606, 12, '這將創建一個tar格式備份，然後將它發送到您的網頁瀏覽器，所以你可以把它保存'),
(45219, 6607, 12, '這將禁用文件加密和解密功能，並隱藏在UI。'),
(45220, 6613, 12, '這將迫使病人摘要“屏幕中的帳單部件始終是開放的。'),
(45221, 6619, 12, '這將使用自定義免疫名單，而不是標準的CVX免疫名單。'),
(45222, 6622, 12, '胸椎'),
(45223, 6623, 12, 'Thous/立方釐米'),
(45224, 6625, 12, '喉嚨'),
(45225, 6626, 12, '喉癌'),
(45226, 6627, 12, '喉癌手術'),
(45227, 6628, 12, '血栓形成/中風'),
(45228, 6629, 12, '星期二'),
(45229, 6630, 12, '星期二'),
(45230, 6631, 12, '星期二'),
(45231, 6632, 12, '甲狀腺正常'),
(45232, 6633, 12, '甲狀腺問題'),
(45233, 6634, 12, '短暫性缺血性發作'),
(45234, 6636, 12, '一天三次'),
(45235, 6638, 12, '時間'),
(45236, 6639, 12, '時間顯示格式'),
(45237, 6640, 12, '時間增量為新增（分鐘1-60）'),
(45238, 6641, 12, '時間選擇'),
(45239, 6647, 12, '時間事件'),
(45240, 6648, 12, '時代陣列（N / A）'),
(45241, 6649, 12, '時間戳和文字'),
(45242, 6650, 12, '錫'),
(45243, 6651, 12, '耳鳴'),
(45244, 6652, 12, '標題'),
(45245, 6653, 12, '標題五'),
(45246, 6654, 12, '標題COLS必須是一個介於1和999之間的數字'),
(45247, 6655, 12, '標題'),
(45248, 6656, 12, '商標“S：'),
(45249, 6657, 12, 'TMS/ EAMS/ EE，外鼻子'),
(45250, 6658, 12, '至'),
(45251, 6659, 12, '至'),
(45252, 6660, 12, '至'),
(45253, 6661, 12, '到文件的絕對路徑'),
(45254, 6662, 12, '添加註釋，請點擊 '),
(45255, 6663, 12, '添加註釋，請點擊這裡'),
(45256, 6664, 12, '患處'),
(45257, 6665, 12, '患處'),
(45258, 6666, 12, '到自動打開指定的表單。一些運動隊在這裡使用football_injury_audit。'),
(45259, 6667, 12, '到帳單查看'),
(45260, 6668, 12, '到類別'),
(45261, 6669, 12, '到臨床查看'),
(45262, 6670, 12, '以共付額'),
(45263, 6672, 12, '涉足'),
(45264, 6673, 12, '到數字高程模型'),
(45265, 6674, 12, '禁用客戶端的SSL證書，在Apache配置文件發表評論上述行，並設置'),
(45266, 6675, 12, '禁用HTTPS，在Apache配置文件發表評論上述行，並重新啟動Apache服務器。'),
(45267, 6676, 12, '為了使客戶端SSL證書'),
(45268, 6677, 12, '啟用客戶端SSL證書驗證，HTTPS應該被啟用。'),
(45269, 6678, 12, '啟用只有HTTPS的，執行上述更改並重新啟動Apache服務器。如果你要配置客戶端證書，請他們在下一節配置。'),
(45270, 6679, 12, '為了Enctr'),
(45271, 6680, 12, '按性別篩選'),
(45272, 6681, 12, '到歷史'),
(45273, 6682, 12, '問題'),
(45274, 6683, 12, '連結此相遇/以現有的問題進行磋商，請按一下 '),
(45275, 6684, 12, '連結此相遇/以現有的問題進行磋商，單擊以上所需的問題，選中它，然後單擊[保存]。按住[Ctrl]鍵按鈕來選擇多個問題。'),
(45276, 6685, 12, '再次登錄'),
(45277, 6686, 12, '要記錄的信息披露，請點擊'),
(45278, 6687, 12, '運行'),
(45279, 6688, 12, '設置客戶端證書身份驗證的HTTPS訪問，請執行以下'),
(45280, 6689, 12, '對皮膚'),
(45281, 6690, 12, '對皮膚'),
(45282, 6691, 12, '對這次參訪？'),
(45283, 6693, 12, '到：'),
(45284, 6694, 12, '到： '),
(45285, 6695, 12, '到-城市'),
(45286, 6696, 12, '到-傳真'),
(45287, 6697, 12, 'TO_FNAME'),
(45288, 6698, 12, 'TO_LNAME'),
(45289, 6699, 12, 'TO_MNAME'),
(45290, 6700, 12, '到-組織'),
(45291, 6703, 12, '到-郵政'),
(45292, 6704, 12, '到-國家'),
(45293, 6705, 12, '到-街道'),
(45294, 6706, 12, '到-標題'),
(45295, 6707, 12, '到-告別'),
(45296, 6708, 12, '煙草'),
(45297, 6709, 12, '戒菸措施'),
(45298, 6710, 12, '戒菸措施(CQM)'),
(45299, 6712, 12, '煙草使用'),
(45300, 6713, 12, '煙草使用評估'),
(45301, 6714, 12, '煙草使用評估(CQM)'),
(45302, 6715, 12, '今天'),
(45303, 6717, 12, '今天'),
(45304, 6720, 12, '今天的日期'),
(45305, 6721, 12, '今天的活動'),
(45306, 6724, 12, '標記ID的LibreEHR支持LLC實驗室交流中心。'),
(45307, 6726, 12, '扁桃腺切除術'),
(45308, 6728, 12, '頂部'),
(45309, 6730, 12, '主題'),
(45310, 6731, 12, '全部'),
(45311, 6732, 12, '全部'),
(45312, 6733, 12, '總活性行動'),
(45313, 6734, 12, '更新後的總主動提醒'),
(45314, 6735, 12, '更新前的總主動提醒'),
(45315, 6737, 12, '總金額'),
(45316, 6738, 12, '支付的款項總額'),
(45317, 6741, 12, '總費用'),
(45318, 6742, 12, '總客戶'),
(45319, 6743, 12, '總成本'),
(45320, 6744, 12, '下列支票號碼總的分佈是不完全的'),
(45321, 6746, 12, '透過電子郵件發送所有失敗的提醒'),
(45322, 6747, 12, '透過電話發送所有失敗的提醒'),
(45323, 6748, 12, '總計'),
(45324, 6749, 12, '總計 '),
(45325, 6750, 12, '總計類別'),
(45326, 6751, 12, '總計不活化的提醒'),
(45327, 6752, 12, '新提醒總計'),
(45328, 6755, 12, '免疫接種的總數'),
(45329, 6756, 12, '問題總數'),
(45330, 6758, 12, '病人總數'),
(45331, 6760, 12, '總病人平衡'),
(45332, 6761, 12, '總病人'),
(45333, 6764, 12, '找到記錄總計'),
(45334, 6765, 12, '總計生殖健康與計劃生育'),
(45335, 6766, 12, '通過電子郵件發送的總成功提醒'),
(45336, 6767, 12, '通過電話發送的總成功提醒'),
(45337, 6770, 12, '整體不變的提醒'),
(45338, 6771, 12, '發送過程以後全部未發送提醒'),
(45339, 6772, 12, '更新以後全部未發送提醒'),
(45340, 6773, 12, '發送過程以前全部未發送提醒'),
(45341, 6774, 12, '更新以前全部未發送提醒'),
(45342, 6775, 12, '全部更新的提醒'),
(45343, 6776, 12, '總計'),
(45344, 6777, 12, '為匯總'),
(45345, 6778, 12, '為匯總 '),
(45346, 6785, 12, '培訓種類'),
(45347, 6786, 12, '進行交易'),
(45348, 6787, 12, '進行交易'),
(45349, 6788, 12, '進行交易'),
(45350, 6789, 12, '交易失敗，在許多目的地數量不足'),
(45351, 6790, 12, '交易失敗，數量小於零'),
(45352, 6791, 12, '交易類型'),
(45353, 6792, 12, '進行交易'),
(45354, 6793, 12, '進行交易'),
(45355, 6794, 12, '交易（寫可選）'),
(45356, 6795, 12, '交易/轉介'),
(45357, 6797, 12, '轉讓'),
(45358, 6799, 12, '傳輸失敗，在源代碼數量不足'),
(45359, 6804, 12, '轉讓'),
(45360, 6806, 12, '轉型/轉移護理？'),
(45361, 6807, 12, '翻譯訪問控制組'),
(45362, 6808, 12, '翻譯委任分類'),
(45363, 6809, 12, '翻譯文件分類'),
(45364, 6810, 12, '翻譯版面'),
(45365, 6811, 12, '翻譯名單'),
(45366, 6812, 12, '翻譯病人附註標題'),
(45367, 6813, 12, '翻譯這個'),
(45368, 6814, 12, '翻譯'),
(45369, 6815, 12, '翻譯'),
(45370, 6819, 12, '創傷'),
(45371, 6820, 12, '治療'),
(45372, 6822, 12, '治療目標'),
(45373, 6823, 12, '治療計畫'),
(45374, 6826, 12, '治療：'),
(45375, 6827, 12, '治療： '),
(45376, 6828, 12, '趨勢'),
(45377, 6829, 12, 'strftime（個月美元的格式，mktime（0，0，0，$ I，1，2000）））;元一個月的價值'),
(45378, 6830, 12, '觸發點/腔室症候群/延遲性肌肉酸痛/抽筋'),
(45379, 6831, 12, '三踝'),
(45380, 6832, 12, '軀幹與腹部'),
(45381, 6837, 12, '茶匙'),
(45382, 6839, 12, '語音合成'),
(45383, 6840, 12, '肺結核'),
(45384, 6841, 12, '星期二'),
(45385, 6842, 12, '星期二及四'),
(45386, 6843, 12, '星期二'),
(45387, 6844, 12, '腫瘤'),
(45388, 6845, 12, '土耳其'),
(45389, 6848, 12, '每天兩次'),
(45390, 6850, 12, '鼓膜'),
(45391, 6851, 12, '類型'),
(45392, 6852, 12, '類型標識或Name.3最小字符（包括空格）。'),
(45393, 6853, 12, '列類型顯示病人的搜索結果'),
(45394, 6854, 12, '披露的類型'),
(45395, 6855, 12, '事件類型'),
(45396, 6856, 12, '屏幕佈局類型'),
(45397, 6857, 12, '在這裡鍵入或掃描病人標識'),
(45398, 6859, 12, '醫囑類型與結果'),
(45399, 6864, 12, '卡爾加里大學體育醫學中心所提供的UCSMC代碼'),
(45400, 6866, 12, '潰瘍'),
(45401, 6867, 12, '潰瘍性結腸炎'),
(45402, 6868, 12, '潰瘍：'),
(45403, 6871, 12, '無法創建'),
(45404, 6876, 12, '未應用'),
(45405, 6877, 12, '未分配'),
(45406, 6878, 12, '未授权'),
(45407, 6879, 12, '未獲授權下取用e處方'),
(45408, 6880, 12, '未獲授權下取用'),
(45409, 6882, 12, '未入賬只有'),
(45410, 6884, 12, '舌下'),
(45411, 6885, 12, '體重過輕'),
(45412, 6886, 12, '未診斷出的'),
(45413, 6887, 12, '未經分派'),
(45414, 6888, 12, '未經分派'),
(45415, 6889, 12, '未經分派的是'),
(45416, 6890, 12, '撤消簽出'),
(45417, 6892, 12, '獨特的客戶'),
(45418, 6893, 12, '獨特的人類可讀的這種類型的標識符'),
(45419, 6894, 12, '獨特的新客戶'),
(45420, 6895, 12, '這種類型的唯一的數字標識符'),
(45421, 6896, 12, '獨特的病人'),
(45422, 6897, 12, '獨特的所見的患者報告'),
(45423, 6898, 12, '獨特的收縮壓'),
(45424, 6899, 12, '單位'),
(45425, 6900, 12, '單位'),
(45426, 6901, 12, '單位'),
(45427, 6903, 12, '訪問表格的單位'),
(45428, 6904, 12, '單位必須是一個數字'),
(45429, 6905, 12, '單位沒有定義'),
(45430, 6906, 12, '單位/ L'),
(45431, 6907, 12, '未知的'),
(45432, 6910, 12, '不知過去曾否吸煙'),
(45433, 6911, 12, '未知的或N / A'),
(45434, 6914, 12, '未命名的保險公司'),
(45435, 6915, 12, '未註冊'),
(45436, 6918, 12, '取消選擇所有'),
(45437, 6919, 12, '未選定'),
(45438, 6920, 12, '不確定'),
(45439, 6921, 12, '非結構化'),
(45440, 6924, 12, '直到'),
(45441, 6925, 12, '不合時宜的申請'),
(45442, 6926, 12, '未使用'),
(45443, 6927, 12, 'UOR'),
(45444, 6928, 12, '最多'),
(45445, 6929, 12, '即將到來的約會'),
(45446, 6930, 12, '即將舉行的活動'),
(45447, 6931, 12, '更新'),
(45448, 6932, 12, '更新'),
(45449, 6933, 12, '主動更新'),
(45450, 6934, 12, '更新文件'),
(45451, 6935, 12, '更新資料'),
(45452, 6936, 12, '更新列表'),
(45453, 6937, 12, '更新服務提供者號碼'),
(45454, 6938, 12, '更新選定的項目'),
(45455, 6939, 12, '更新下列文件中的變數'),
(45456, 6940, 12, '更新用戶資料'),
(45457, 6942, 12, '更新人口統計未被授權。'),
(45458, 6946, 12, '升級'),
(45459, 6947, 12, '升級資料庫'),
(45460, 6948, 12, '升級LibreEHR資料庫，包括過程，函數和去識別過程中所需的表格'),
(45461, 6949, 12, '升級將繼續'),
(45462, 6950, 12, 'UPIN'),
(45463, 6951, 12, '上載'),
(45464, 6954, 12, '上傳配置數據'),
(45465, 6955, 12, '上傳文件'),
(45466, 6956, 12, '上傳失敗！'),
(45467, 6957, 12, '上傳圖片到'),
(45468, 6958, 12, '上傳導入文件：'),
(45469, 6961, 12, '上傳報告'),
(45470, 6963, 12, '上傳這個文件：'),
(45471, 6964, 12, '當點擊發票號碼“手冊的發布窗口”出現。在這裡，你可以改變發票的截止日期和票據，選擇你張貼的黨，並選擇保險，所有預期的付款已經收到。最重要的是，收費金額為每個計費代碼，您可以輸入支付和調整資訊。'),
(45472, 6965, 12, '根據搜索，你與發票清單一起出現。你可以點擊一個發票號碼打開第二個窗口，這是手冊發布的數據條目頁面上的發票號碼之一。您也可以點擊上病人的名字，如果你想輸入一個音符，前台人員會看到病人檢查時，您可以選擇的發票出現在病人的報表和打印這些報表。'),
(45473, 6966, 12, '上臂'),
(45474, 6968, 12, '迫切性'),
(45475, 6970, 12, '尿液'),
(45476, 6971, 12, '尿液滴落'),
(45477, 6972, 12, '頻尿'),
(45478, 6973, 12, '尿猶豫不決'),
(45479, 6974, 12, '尿微量白蛋白'),
(45480, 6975, 12, '尿流'),
(45481, 6976, 12, '尿急'),
(45482, 6977, 12, '網址'),
(45483, 6979, 12, '網址為LibreEHR支持。'),
(45484, 6981, 12, '電話網關的URL。由Maviq提供自動化的VOIP服務。更多信息，請訪問http://signup.maviq.com。'),
(45485, 6986, 12, '使用指標（ISA15）'),
(45486, 6988, 12, '使用24小時時間格式？'),
(45487, 6990, 12, '使用認證的電子病歷技術，以確定病人具體的教育資源，並提供這些資源給病人，如果適當。'),
(45488, 6991, 12, '使用收費小組'),
(45489, 6992, 12, '使用CPOE系統直接輸入醫囑任何有執照的的醫療專業人士，可以將醫囑輸入進入醫療記錄，每個國家，地方和專業指引。'),
(45490, 6997, 12, '使用自訂的免疫名單'),
(45491, 6999, 12, '使用日期範圍'),
(45492, 7000, 12, '使用預設值'),
(45493, 7001, 12, '使用刪除選項去刪除。'),
(45494, 7002, 12, '使用國際日期的樣式？'),
(45495, 7003, 12, '使用來源檔名'),
(45496, 7004, 12, '使用下面的字段購買或轉讓。'),
(45497, 7005, 12, '此功能只能使用新安裝的站點， '),
(45498, 7006, 12, '使用主題？'),
(45499, 7007, 12, '使用者'),
(45500, 7009, 12, '用戶/組'),
(45501, 7010, 12, '用戶管理'),
(45502, 7011, 12, '使用者和設備管理'),
(45503, 7012, 12, '用戶和群組管理'),
(45504, 7014, 12, '已停用使用者證書驗證'),
(45505, 7015, 12, '用戶定義'),
(45506, 7016, 12, '用戶定義的第11區'),
(45507, 7017, 12, '用戶定義的第12區'),
(45508, 7018, 12, '使用者定義的字段'),
(45509, 7019, 12, '用戶定義的列表1'),
(45510, 7020, 12, '用戶定義的列表2'),
(45511, 7021, 12, '用戶定義的列表3'),
(45512, 7022, 12, '用戶定義的列表4'),
(45513, 7023, 12, '用戶定義的列表5'),
(45514, 7024, 12, '用戶定義的列表6'),
(45515, 7025, 12, '用戶定義的列表7'),
(45516, 7026, 12, '使用者定義的文字1'),
(45517, 7027, 12, '使用者定義的文字2'),
(45518, 7028, 12, '使用者定義的文字3'),
(45519, 7029, 12, '使用者定義的文字4'),
(45520, 7030, 12, '使用者定義的文字5'),
(45521, 7031, 12, '使用者定義的文字6'),
(45522, 7032, 12, '使用者定義的文字7'),
(45523, 7033, 12, '使用者定義的文字8'),
(45524, 7034, 12, '使用者名字'),
(45525, 7039, 12, '用戶手冊'),
(45526, 7040, 12, '用戶成員'),
(45527, 7041, 12, '用戶名稱'),
(45528, 7042, 12, '用戶名或主機名不能是空白'),
(45529, 7043, 12, '使用者或主機名'),
(45530, 7046, 12, '用戶設置'),
(45531, 7047, 12, '用戶特定設置'),
(45532, 7049, 12, '用戶名稱'),
(45533, 7051, 12, '電話網關的用戶名。由Maviq提供自動化的VOIP服務。更多信息，請訪問http://signup.maviq.com。'),
(45534, 7052, 12, '短訊網關的用戶名'),
(45535, 7053, 12, '短信網關的用戶名'),
(45536, 7055, 12, '用戶名稱：'),
(45537, 7056, 12, '用戶'),
(45538, 7057, 12, '用戶/組/日誌管理'),
(45539, 7058, 12, '使用PHP<a href="http://php.net/strftime">strftime</ a>的格式'),
(45540, 7059, 12, '尿路感染'),
(45541, 7062, 12, '度假'),
(45542, 7063, 12, '度假'),
(45543, 7064, 12, '疫苗'),
(45544, 7065, 12, '陰道環'),
(45545, 7066, 12, '告別'),
(45546, 7067, 12, '驗證'),
(45547, 7068, 12, '價值'),
(45548, 7069, 12, '價值1'),
(45549, 7070, 12, '價值2'),
(45550, 7072, 12, '值應該是數字'),
(45551, 7073, 12, '變數1'),
(45552, 7074, 12, '變數2'),
(45553, 7075, 12, '一個變數去運行識別升級指令碼'),
(45554, 7076, 12, '水痘1'),
(45555, 7077, 12, '水痘2'),
(45556, 7078, 12, '靜脈曲張'),
(45557, 7079, 12, '血管情況'),
(45558, 7080, 12, '血管損傷'),
(45559, 7081, 12, '血管手術'),
(45560, 7083, 12, '供應商'),
(45561, 7084, 12, '版本'),
(45562, 7085, 12, '眩暈'),
(45563, 7087, 12, '退伍軍人管理局計劃'),
(45564, 7088, 12, 'VFC'),
(45565, 7089, 12, '越南人'),
(45566, 7090, 12, '查看'),
(45567, 7091, 12, '查看'),
(45568, 7092, 12, '查看過敏'),
(45569, 7097, 12, '查看全面的病人報告'),
(45570, 7100, 12, '查看文件'),
(45571, 7101, 12, '查看遭遇'),
(45572, 7103, 12, '查看在彈出窗口中的事件嗎？'),
(45573, 7108, 12, '看第1頁'),
(45574, 7109, 12, '看第2頁'),
(45575, 7111, 12, '查看病人'),
(45576, 7116, 12, '查看相關的遭遇'),
(45577, 7121, 12, '查看/編輯過敏'),
(45578, 7122, 12, '查看/編輯問題'),
(45579, 7123, 12, '查看/列印'),
(45580, 7124, 12, '查看：'),
(45581, 7125, 12, '簽證'),
(45582, 7126, 12, 'VISA卡/ MC/ AMEX/ DIS'),
(45583, 7127, 12, '內臟損害/外傷/手術'),
(45584, 7133, 12, '訪問類別：'),
(45585, 7134, 12, '訪問日期'),
(45586, 7137, 12, '訪問表格'),
(45587, 7138, 12, '訪問歷史'),
(45588, 7140, 12, '訪問'),
(45589, 7141, 12, '從訪問'),
(45590, 7142, 12, '生命徵象的紀錄與圖表改變'),
(45591, 7143, 12, '命脈'),
(45592, 7144, 12, '生命徵象（公制）'),
(45593, 7146, 12, '聲音'),
(45594, 7147, 12, '聲音傳送'),
(45595, 7149, 12, '嘔吐'),
(45596, 7152, 12, '腰圍'),
(45597, 7153, 12, '腰圍'),
(45598, 7154, 12, '等候'),
(45599, 7155, 12, '步入式'),
(45600, 7157, 12, '沃爾特·彭寧頓'),
(45601, 7158, 12, '倉庫'),
(45602, 7161, 12, '倉庫'),
(45603, 7162, 12, '溫暖'),
(45604, 7163, 12, '警告'),
(45605, 7164, 12, '警告'),
(45606, 7166, 12, '警告，支票號碼已經存在於數據庫中'),
(45607, 7168, 12, '警告：這個病人今天已經有一次訪問了！'),
(45608, 7170, 12, '警告：病人識別不是唯一的！'),
(45609, 7171, 12, '警告：這將覆蓋從上傳的文件資料的配置信息！'),
(45610, 7173, 12, '警告'),
(45611, 7175, 12, '已經上傳'),
(45612, 7177, 12, '我們感謝及時支付到期的結餘'),
(45613, 7178, 12, '我們已經看到在我們的門診精神病診所的評估和治療你的上述病人。謝謝你這個轉介。'),
(45614, 7179, 12, '軟弱'),
(45615, 7181, 12, '網頁搜索'),
(45616, 7182, 12, '網站'),
(45617, 7183, 12, '上門患者門戶網站連結。'),
(45618, 7184, 12, '星期三'),
(45619, 7185, 12, '星期三'),
(45620, 7186, 12, '週'),
(45621, 7187, 12, '週'),
(45622, 7188, 12, '週視圖'),
(45623, 7189, 12, '週'),
(45624, 7190, 12, '周刊披露'),
(45625, 7192, 12, '週'),
(45626, 7193, 12, '體重'),
(45627, 7194, 12, '兒童和青少年體重的評估和諮詢'),
(45628, 7195, 12, '兒童和青少年體重的評估和諮詢CQM)'),
(45629, 7196, 12, '體重改變'),
(45630, 7197, 12, '減重'),
(45631, 7198, 12, '減肥診所'),
(45632, 7199, 12, '歡迎'),
(45633, 7202, 12, '要計算什麼？'),
(45634, 7203, 12, '哮鳴音：'),
(45635, 7204, 12, '哮鳴音'),
(45636, 7205, 12, '哮鳴音：'),
(45637, 7208, 12, '哪裡可能找到有關掃描或紙張文件？'),
(45638, 7211, 12, '頸椎過度屈伸'),
(45639, 7212, 12, '白色'),
(45640, 7213, 12, '誰'),
(45641, 7214, 12, '誰回答？'),
(45642, 7215, 12, '喪偶'),
(45643, 7217, 12, '在左側導航框架的像素寬度。'),
(45644, 7221, 12, '隨著選擇：'),
(45645, 7222, 12, '與舊名稱'),
(45646, 7224, 12, '我們留個口信給誰？'),
(45647, 7225, 12, '隱瞞'),
(45648, 7226, 12, '在幾個小時內'),
(45649, 7227, 12, '在幾個小時內：'),
(45650, 7228, 12, '在幾分鐘之內'),
(45651, 7229, 12, '在幾分鐘之內：'),
(45652, 7232, 12, '沒有更新'),
(45653, 7233, 12, '見證'),
(45654, 7234, 12, '週'),
(45655, 7235, 12, '在正常範圍內'),
(45656, 7237, 12, '婦女'),
(45657, 7238, 12, '只有婦女'),
(45658, 7240, 12, '工作'),
(45659, 7241, 12, '工作的說明'),
(45660, 7242, 12, '工作電話'),
(45661, 7243, 12, '工作電話號碼'),
(45662, 7244, 12, '相關的工作嗎？'),
(45663, 7245, 12, '工作/教育/愛好'),
(45664, 7246, 12, '工作/學校筆記'),
(45665, 7247, 12, '工作日'),
(45666, 7249, 12, '工人補償健康計劃'),
(45667, 7252, 12, '更壞'),
(45668, 7253, 12, '你想將餘額應用到全局帳戶？'),
(45669, 7254, 12, '你想把他們標記為清除。'),
(45670, 7255, 12, '你想分配？'),
(45671, 7256, 12, '你想取消這名病人的分發？'),
(45672, 7257, 12, '你想刪除收入分配？'),
(45673, 7258, 12, '你想刪除收入？'),
(45674, 7259, 12, '你想修改並完成付款？'),
(45675, 7260, 12, '你想修改付款？'),
(45676, 7261, 12, '你想發表和完成付款？'),
(45677, 7262, 12, '你想發表付款？'),
(45678, 7263, 12, '你想保存？'),
(45679, 7264, 12, '手腕'),
(45680, 7265, 12, '手腕與手'),
(45681, 7266, 12, '手腕問題'),
(45682, 7267, 12, '寫'),
(45683, 7268, 12, '註銷'),
(45684, 7270, 12, 'wsome'),
(45685, 7271, 12, '寬廣的型態'),
(45686, 7273, 12, 'x取消'),
(45687, 7274, 12, 'x取消'),
(45688, 7275, 12, 'X-射線'),
(45689, 7276, 12, 'X射線解讀：'),
(45690, 7277, 12, 'X射線解讀：'),
(45691, 7278, 12, 'X12的只有：更換索賠 '),
(45692, 7279, 12, 'X12的合作夥伴'),
(45693, 7280, 12, 'X12的合作夥伴們'),
(45694, 7285, 12, '年'),
(45695, 7286, 12, '年'),
(45696, 7287, 12, '年視圖'),
(45697, 7288, 12, '年'),
(45698, 7289, 12, '年'),
(45699, 7292, 12, '年'),
(45700, 7293, 12, '是'),
(45701, 7294, 12, '是'),
(45702, 7295, 12, '是的﹗'),
(45703, 7296, 12, '是的，刪除和註銷'),
(45704, 7298, 12, '是/否'),
(45705, 7299, 12, '是：'),
(45706, 7300, 12, '意第緒語'),
(45707, 7303, 12, '你是要永久取代現有的範本。你確定要繼續嗎？'),
(45708, 7304, 12, '你是在格雷斯登錄期間。改變你以前的密碼'),
(45709, 7305, 12, '不允許您刪除此事件'),
(45710, 7306, 12, '不允許您編輯此事件'),
(45711, 7307, 12, '這個你沒有被授權。'),
(45712, 7308, 12, '您未被授權訪問此小隊。'),
(45713, 7309, 12, '您沒有被授權去添加/編輯問題'),
(45714, 7310, 12, '您沒有被授權來安排約會。'),
(45715, 7311, 12, '您沒有被授權去看這個遭遇。'),
(45716, 7313, 12, '你不能直接進入這個功能。'),
(45717, 7314, 12, '你不能直接進入這頁。'),
(45718, 7315, 12, '你不可以添加空白值對一個類別！'),
(45719, 7316, 12, '你不可以添加空白值對一個次類別！'),
(45720, 7317, 12, '你不可以添加空白值對一個項目！'),
(45721, 7318, 12, '你不能用一個完成值YES輸入一個未來的日期。'),
(45722, 7319, 12, '你不能選擇的任何行動。'),
(45723, 7320, 12, '你不必進入去查看/編輯本說明'),
(45724, 7321, 12, '您試圖改變的內容已被鎖定。如果你想解除鎖定，要解鎖。刪除行“，/*鎖::* /'''),
(45725, 7322, 12, '您已經成功註銷。'),
(45726, 7323, 12, '你只可以上傳。文本文件'),
(45727, 7325, 12, '你可以把文本放在這裡作為在新的病人遭遇形式的默認投訴。'),
(45728, 7326, 12, '您必須輸入一個密碼短語來加密文件'),
(45729, 7329, 12, '你必須先選擇或添加一個病人。'),
(45730, 7330, 12, '你必須先選擇或創建一個遭遇。'),
(45731, 7331, 12, '你必須選擇一個訪問類別'),
(45732, 7332, 12, '你必須選擇一個訪問類別。'),
(45733, 7333, 12, '你必須選擇一些領域以繼續。'),
(45734, 7334, 12, '你應該運行這個測試，如果這種說法似乎成功地生成，但實際的索賠文件不包含任何數據或僅僅只有一個它應該包含的未完成部分的數據量。與HCFA索賠是很明顯的，因為它們是人類可讀的X12的索賠，這是一個比較多的艱難過程，以確定是否正確完整的索賠。'),
(45735, 7335, 12, '你應該至少選擇一個上下文'),
(45736, 7336, 12, '你應該至少選擇一個提供者'),
(45737, 7339, 12, '您的結束日期是無效的'),
(45738, 7340, 12, '您的事件已被刪除。'),
(45739, 7341, 12, '您的事件已被修改。'),
(45740, 7342, 12, '已提交您的事件。'),
(45741, 7343, 12, '你的檔案太大'),
(45742, 7345, 12, '列表的名稱已被更改，以滿足命名要求。'),
(45743, 7347, 12, '你的姓名對這一類別，過程或結果'),
(45744, 7349, 12, '你的密碼已過期。請更改您的密碼。'),
(45745, 7350, 12, '你的密碼過期'),
(45746, 7351, 12, '今天您的密碼過期。請更改您的密碼。'),
(45747, 7353, 12, '你PostCalendar配置已經重置為使用默認值。'),
(45748, 7354, 12, '你PostCalendar配置已更新。'),
(45749, 7355, 12, '你的重複頻率必須是一個整數。'),
(45750, 7356, 12, '你的重複頻率必須至少有1。'),
(45751, 7357, 12, '你的開始日期大於你的結束日期'),
(45752, 7358, 12, '你的起始日期是無效的'),
(45753, 7359, 12, '你的提交失敗。'),
(45754, 7360, 12, '年年年年-月月-日日'),
(45755, 7361, 12, '年年年年-月月-日日'),
(45756, 7362, 12, '年年年年-月月-日日日期與此檔案相關'),
(45757, 7363, 12, '年年年年-月月-日日日期破壞'),
(45758, 7364, 12, '年年年年-月月-日日出生日期'),
(45759, 7365, 12, '年年年年-月月-日日出生日期'),
(45760, 7366, 12, '年年年年-月月-日日死亡日期'),
(45761, 7367, 12, '年年年年-月月-日日發病或住院日期'),
(45762, 7368, 12, '年年年年-月月-日日發病，手術或藥物開始日期'),
(45763, 7369, 12, '年年年年-月月-日日購買或轉讓日期'),
(45764, 7370, 12, '年年年年-月月-日日恢復或藥物停止日期'),
(45765, 7371, 12, '年年年年-月月-日日回播日期'),
(45766, 7372, 12, '年年年年-月月-日日服務日期'),
(45767, 7373, 12, '年年年年-月月-日日這封信的日期'),
(45768, 7374, 12, '年年年年-月月-日日回播日期'),
(45769, 7375, 12, '年年年年-月月-日日文件日期'),
(45770, 7376, 12, '年年年年-月月-日日事件日期或開始日期'),
(45771, 7381, 12, '年年年年-月月-日日時時︰分分︰秒秒'),
(45772, 7383, 12, '年年年年-月月-日日這事件的最後日期'),
(45773, 7387, 12, '零'),
(45774, 7389, 12, '郵政編碼'),
(45775, 7390, 12, '郵政編碼'),
(45776, 7391, 12, '郵編/國家：'),
(45777, 7392, 12, '祖魯'),
(45778, 7393, 12, ' 但被 '),
(45779, 7394, 12, ' 無法存取。'),
(45780, 7395, 12, '你真的要刪除'),
(45781, 7396, 12, '藥'),
(45782, 7397, 12, '沒有發送的電子郵件'),
(45783, 7398, 12, '從'),
(45784, 7399, 12, '已創建。 '),
(45785, 7400, 12, '已經重新開放'),
(45786, 7401, 12, '歷史'),
(45787, 7402, 12, '不是一個數字'),
(45788, 7403, 12, '準備好重新計費。'),
(45789, 7404, 12, '左肺下葉：'),
(45790, 7405, 12, '很多'),
(45791, 7406, 12, '醫療原始參考號碼 '),
(45792, 7407, 12, '分'),
(45793, 7408, 12, '沒有找到！'),
(45794, 7409, 12, '許多瀏覽器中的pecularities可能表示，以突然急跳的方式鍵入你的屏幕下面的輸出，並且有好幾秒鐘的長時間停頓，這看起來好像事情可能已墜毀。情況並非如此，你最終會看到輸出一行一行的出來。有可能出現下面的序列號，這是表事，即使沒有別的可顯示，但是活動仍進行。這些號碼將與計費內容夾雜在一起，這是正常的。'),
(45795, 7410, 12, '處方已達到極限'),
(45796, 7411, 12, '直到'),
(45797, 7412, 12, '更新失敗，不是在數據庫中？'),
(45798, 7413, 12, '被標記為只收費。'),
(45799, 7414, 12, '成功地排隊。'),
(45800, 7415, 12, '！左W / O訪問'),
(45801, 7416, 12, '“為代碼'),
(45802, 7418, 12, '＃INS /魚翅問題'),
(45803, 7419, 12, '＃片劑：'),
(45804, 7420, 12, '$'),
(45805, 7421, 12, '$編碼完成'),
(45806, 7422, 12, '﹩標籤（年年年年 -月 月 -日日）： '),
(45807, 7423, 12, '%'),
(45808, 7424, 12, '％取消<24小時'),
(45809, 7425, 12, '％取消<24小時 '),
(45810, 7426, 12, '應該存在，但是沒有。'),
(45811, 7427, 12, '（％匹配任何字符串，_匹配任何字符）'),
(45812, 7429, 12, '（返回）'),
(45813, 7430, 12, '（點擊來編輯）'),
(45814, 7431, 12, '（電子郵件傳遞是立即的，而自動化的VOIP被發送到服務供應商進行進一步的處理。）'),
(45815, 7432, 12, '（更多）');
INSERT INTO `lang_definitions` VALUES
(45816, 7433, 12, '（新病人）'),
(45817, 7434, 12, '（附註和授權）'),
(45818, 7435, 12, '（病人註釋）'),
(45819, 7436, 12, '（選擇其中之一，或鍵入自己的標題）'),
(45820, 7437, 12, '（移位）點擊或拖動來改變值'),
(45821, 7438, 12, '*提示完成'),
(45822, 7439, 12, '**請移動手術的事項！'),
(45823, 7440, 12, '*必填'),
(45824, 7441, 12, '+圖表拉出'),
(45825, 7442, 12, '- 沒有'),
(45826, 7447, 12, '0-10'),
(45827, 7448, 12, '0-24'),
(45828, 7452, 12, '1=北美。看到http://www.wtng.info/~~V其他國家或地區代碼列表。'),
(45829, 7457, 12, '1.休息2冰敷兩天3。壓迫，敷料留在原處，除非腳發展麻木或蒼白色4抬高腿和腳'),
(45830, 7458, 12, '11-14'),
(45831, 7459, 12, '12小時'),
(45832, 7460, 12, '15-19'),
(45833, 7468, 12, '20-24'),
(45834, 7477, 12, '2111-13'),
(45835, 7478, 12, '24小時'),
(45836, 7479, 12, '25+'),
(45837, 7480, 12, '25-29'),
(45838, 7481, 12, '第二'),
(45839, 7483, 12, '三個月'),
(45840, 7485, 12, '每天三次'),
(45841, 7487, 12, '30-34'),
(45842, 7488, 12, '35-39'),
(45843, 7489, 12, '第三'),
(45844, 7491, 12, '4個月'),
(45845, 7493, 12, '每天四次'),
(45846, 7495, 12, '40-44'),
(45847, 7496, 12, '45+'),
(45848, 7497, 12, '465.9，上呼吸道感染'),
(45849, 7498, 12, '466.0，支氣管炎，急性一氧化氮合酶'),
(45850, 7499, 12, '486.0，肺炎，急性'),
(45851, 7500, 12, '491.21，慢性阻塞性肺病加重'),
(45852, 7501, 12, '491.8，支氣管炎，慢性'),
(45853, 7502, 12, '493.92，哮喘，急性惡化。'),
(45854, 7503, 12, '496.0，慢性阻塞性肺病'),
(45855, 7504, 12, '第四'),
(45856, 7508, 12, '519.7支氣管痙攣'),
(45857, 7509, 12, '第五'),
(45858, 7511, 12, '6個月'),
(45859, 7514, 12, '第六'),
(45860, 7517, 12, '824.0骨折，內踝，閉鎖性'),
(45861, 7518, 12, '824.2骨折，外踝，閉鎖性'),
(45862, 7519, 12, '824.6骨折，三踝，閉鎖性'),
(45863, 7520, 12, '825.32的舟狀骨骨折，（腳踝）'),
(45864, 7521, 12, '825.35骨折，第五（5）蹠骨基部'),
(45865, 7522, 12, '845.00踝關節扭傷的一氧化氮合酶'),
(45866, 7523, 12, '845.01扭傷內側（三角肌）韌帶。'),
(45867, 7524, 12, '845.02扭傷，跟骨腓骨'),
(45868, 7526, 12, '99212成立 - 單純性'),
(45869, 7527, 12, '99213成立 - 低複雜度'),
(45870, 7528, 12, '<在診療室'),
(45871, 7529, 12, '>檢查'),
(45872, 7531, 12, '？無顯示'),
(45873, 7532, 12, '@抵達'),
(45874, 7533, 12, '[更改視圖]'),
(45875, 7534, 12, '[最後相遇的日期]'),
(45876, 7535, 12, '[自從最後相遇的天數]'),
(45877, 7536, 12, '平等機會條例草案]'),
(45878, 7537, 12, '[出口氧氟沙星]'),
(45879, 7538, 12, '[不推薦]'),
(45880, 7539, 12, '[邂逅的號碼]'),
(45881, 7540, 12, '[報告]'),
(45882, 7541, 12, '[全選]'),
(45883, 7542, 12, '[SQL總帳]'),
(45884, 7543, 12, '[開始批次處理]'),
(45885, 7544, 12, '[查看日誌]'),
(45886, 7545, 12, '[查看列印報告]'),
(45887, 7546, 12, '_PC_DUR_小時'),
(45888, 7547, 12, '_PC_DUR_分鐘'),
(45889, 7548, 12, '_PC_LOCALE'),
(45890, 7549, 12, '〜遲到'),
(45891, 1, 13, 'A'),
(45892, 2, 13, 'Регистрация номера или требования для идентификации оплаты'),
(45893, 3, 13, 'Сертификат клиента для пользователя admin'),
(45894, 7, 13, 'Специалист является обязательным'),
(45895, 8, 13, 'Для этого посещения необходимо добавить форму GCAC.'),
(45896, 9, 13, 'Номер партии является обязательным'),
(45897, 10, 13, 'Номер партии обязателен!'),
(45898, 11, 13, 'Прописная буква'),
(45899, 12, 13, 'Номер'),
(45900, 14, 13, 'Пациент с этим ID уже существует.'),
(45901, 15, 13, 'Пациент под этим именем уже существует'),
(45902, 16, 13, 'Пациент с этим SS уже существует.'),
(45903, 19, 13, 'Источник направления может быть указан для каждого посещения.'),
(45904, 20, 13, 'Требуется cвязанный код IPPF!'),
(45905, 21, 13, 'специальный символ'),
(45906, 22, 13, 'Для пользователя уникальное значение идентификации этого поля не видно'),
(45907, 24, 13, 'до еды'),
(45908, 25, 13, 'до полудня'),
(45909, 26, 13, 'Равное право при пожаре или несчастном случае:'),
(45910, 27, 13, 'Астматический бронхит'),
(45911, 28, 13, 'Сокращение'),
(45912, 29, 13, 'Абсцесс:'),
(45913, 30, 13, 'Абдоминальный'),
(45914, 31, 13, 'Способен переносить вес на четыре (4) шага'),
(45915, 32, 13, 'Откл.'),
(45916, 33, 13, 'Откл.1'),
(45917, 34, 13, 'Отклонение от нормы'),
(45918, 35, 13, 'Анализ крови с отклонением от нормы'),
(45919, 36, 13, 'Патология роста волос'),
(45920, 37, 13, 'Маммограмма с отклонением от нормы'),
(45921, 39, 13, 'Аборт'),
(45922, 40, 13, 'Проблемы аборта'),
(45923, 41, 13, 'Метод прерывания беременности'),
(45924, 42, 13, 'Категории, связанные с абортом'),
(45925, 43, 13, 'Аборты'),
(45926, 44, 13, 'Согласно регистрации'),
(45927, 46, 13, 'Отсутствие диагноза'),
(45928, 47, 13, 'Принять назначение'),
(45929, 48, 13, 'Принять оплату за'),
(45930, 49, 13, 'Принять оплату за '),
(45931, 50, 13, 'Принимать назначение'),
(45932, 51, 13, 'Управление конролем'),
(45933, 52, 13, 'Администрирование через список управления доступом (ACL)'),
(45934, 54, 13, 'Доступ не разрешен'),
(45935, 55, 13, 'Доступ не разрешен'),
(45936, 56, 13, 'Портал для доступа вашего пациента'),
(45937, 59, 13, 'Имя учетной записи'),
(45938, 62, 13, 'Учёт'),
(45939, 64, 13, 'Боли'),
(45940, 65, 13, 'Запрошено подтверждение'),
(45941, 66, 13, 'Подтверждение получения, лицензирование и сертификация'),
(45942, 67, 13, 'ACL'),
(45943, 68, 13, 'Администрирование ACL'),
(45944, 69, 13, 'Администрирование ACL не разрешено.'),
(45945, 71, 13, 'Боль'),
(45946, 72, 13, 'Контракт'),
(45947, 73, 13, 'Дата подписания контракта'),
(45948, 74, 13, 'Действие'),
(45949, 75, 13, 'Действия'),
(45950, 77, 13, 'Активировать сообщения CCR/CCD'),
(45951, 78, 13, 'Активный'),
(45952, 79, 13, 'Активное извещение'),
(45953, 80, 13, 'Правила активных извещений'),
(45954, 81, 13, 'Активные извещения/ напоминания'),
(45955, 82, 13, 'Активированное обращение'),
(45956, 84, 13, 'Активные списки'),
(45957, 85, 13, 'Активированный пациент'),
(45958, 86, 13, 'Активные программы'),
(45959, 87, 13, 'Активность'),
(45960, 88, 13, 'Тип активности'),
(45961, 92, 13, 'Острый или хронический'),
(45962, 93, 13, 'добавить'),
(45963, 94, 13, 'Добавить'),
(45964, 95, 13, 'ДОБАВИТЬ'),
(45965, 96, 13, 'Добавить компанию'),
(45966, 98, 13, 'Добавить аптеку'),
(45967, 100, 13, 'добавить событие для '),
(45968, 101, 13, 'Добавить как новую запись'),
(45969, 102, 13, 'Добавить как новая'),
(45970, 104, 13, 'Добавить кнопки'),
(45971, 105, 13, 'Добавьте кнопки для специальных литеров, текстов, чтобы отображать вверху редактора для включения в текст при щелчке'),
(45972, 106, 13, 'Добавить категорию'),
(45973, 107, 13, 'Добавить константу'),
(45974, 108, 13, 'Добавить контекст'),
(45975, 109, 13, 'Добавить оплату пациента'),
(45976, 110, 13, 'Добавить критерий'),
(45977, 111, 13, 'Добавить собственную кнопку'),
(45978, 112, 13, 'Добавить диагноз'),
(45979, 113, 13, 'Добавить лекарство'),
(45980, 114, 13, 'Добавить обращение'),
(45981, 115, 13, 'Добавить обращение/запись'),
(45982, 116, 13, 'Добавить услугу'),
(45983, 117, 13, 'Добавить поле'),
(45984, 118, 13, 'Добавьте следующие строки в конфигурационный файл Apache'),
(45985, 119, 13, 'Добавить группу'),
(45986, 120, 13, 'Добавляет код ICD'),
(45987, 121, 13, 'Добавить вакцинацию'),
(45988, 122, 13, 'Добавление не разрешено!'),
(45989, 123, 13, 'Добавить аспекты'),
(45990, 125, 13, 'Добавить язык'),
(45991, 126, 13, 'Добавить новое'),
(45992, 127, 13, 'Добавить новое'),
(45993, 128, 13, 'Добавить новую категорию '),
(45994, 129, 13, 'Добавьте новые сертификаты в конфигурационный файл Apache'),
(45995, 130, 13, 'Добавить новый компонент'),
(45996, 131, 13, 'Добавить новые компоненты'),
(45997, 132, 13, 'Добавить новую группу'),
(45998, 134, 13, 'Добавить новую партию или товарооборот'),
(45999, 135, 13, 'Добавить новую запись'),
(46000, 136, 13, 'Добавить новую запись'),
(46001, 137, 13, 'Добавить нового партнера'),
(46002, 140, 13, 'Добавить запись'),
(46003, 141, 13, 'Добавить запись для пациента'),
(46004, 142, 13, 'Добавить назначение'),
(46005, 143, 13, 'Добавить анализ'),
(46006, 144, 13, 'Добавить номер поставщика'),
(46007, 145, 13, 'Добавить реабилитацию'),
(46008, 146, 13, 'Добавить правило'),
(46009, 147, 13, 'Добавить к'),
(46010, 148, 13, 'Добавить к списку препаратов'),
(46011, 149, 13, 'Добавить основной уровень'),
(46012, 150, 13, 'Добавить транзакцию'),
(46013, 151, 13, 'Добавить пользователя'),
(46014, 152, 13, 'Добавить пользователя в группу'),
(46015, 153, 13, 'Добавить/изменить eRx'),
(46016, 154, 13, 'Добавить/изменить транзакцию по пациенту'),
(46017, 155, 13, 'дополнено'),
(46018, 156, 13, 'Добавление персональных данных не разрешено.'),
(46019, 158, 13, 'Синдром Эддисона'),
(46020, 159, 13, 'Синдром Эддисона'),
(46021, 160, 13, 'Дополнительные атрибуты'),
(46022, 161, 13, 'Дополнительный диагноз:'),
(46023, 162, 13, 'Дополнительный анамнез'),
(46024, 163, 13, 'Дополнительные записи в историю'),
(46025, 164, 13, 'Дополнительная информация'),
(46026, 165, 13, 'Дополнительные лабораторные исследования'),
(46027, 166, 13, 'Дополнительные записи'),
(46028, 167, 13, 'Дополнительные записи для этого результата или рекомендации'),
(46029, 168, 13, 'Дополнительные записи:'),
(46030, 169, 13, 'Дополнительные записи: '),
(46031, 170, 13, 'Дополнительные записи к рентген-исследованию:'),
(46032, 172, 13, 'только добавление'),
(46033, 173, 13, 'Адр. кн.'),
(46034, 174, 13, 'Адр. книга'),
(46035, 175, 13, 'Адрес'),
(46036, 178, 13, 'Адресная книга'),
(46037, 179, 13, 'Запись в адресную книгу для компании, выполняющей эту методику'),
(46038, 180, 13, 'Запись в адресную книгу для специалиста'),
(46039, 181, 13, 'Запись в адресную книгу для производителя'),
(46040, 182, 13, 'Типы адресной книги'),
(46041, 187, 13, 'Адрес1'),
(46042, 188, 13, 'Адрес2'),
(46043, 189, 13, 'АДРЕС'),
(46044, 190, 13, 'Корр.'),
(46045, 191, 13, 'Количество корр.'),
(46046, 192, 13, 'Корректировать'),
(46047, 193, 13, 'Корректировка'),
(46048, 194, 13, 'Итоговая корректировка'),
(46049, 195, 13, 'Причины корректировки'),
(46050, 196, 13, 'Значение корректировки для кода '),
(46051, 197, 13, 'Исправления'),
(46052, 198, 13, 'Настройка адм.'),
(46053, 199, 13, 'Админ.'),
(46054, 200, 13, 'Электронный адрес admin'),
(46055, 201, 13, 'Выполнять через'),
(46056, 202, 13, 'Настроен'),
(46057, 203, 13, 'Настроен через'),
(46058, 206, 13, 'Администрирование'),
(46059, 208, 13, 'Администраторы'),
(46060, 209, 13, 'Администраторы могут делать всё'),
(46061, 212, 13, 'Всплывающее отображение веса взрослого'),
(46062, 213, 13, 'Всплывающее отображение веса взрослого (CQM)'),
(46063, 214, 13, 'Предварительная инструкция'),
(46064, 215, 13, 'Предварительные инструкции'),
(46065, 216, 13, 'Предупреждение о предварительной инструкции'),
(46066, 218, 13, 'Усовершенствованный'),
(46067, 219, 13, 'Совет'),
(46068, 221, 13, 'Повлиять на норму'),
(46069, 223, 13, 'После час. вызовов'),
(46070, 225, 13, 'После завершения указанных настроек импортируйте сертификат клиента admin в браузер и перезапустите сервер Apache (пустой пароль).'),
(46071, 226, 13, 'После сохранения PDF нажмите [Просмотр журнала] для проверки ошибок.'),
(46072, 227, 13, 'Просле сохранения файла(в) TEXT нажмите [Просмотр журнала] для проверки ошибок.'),
(46073, 228, 13, 'После сохранения пакета кликните [Просмотр журнала] для проверки ошибок.'),
(46074, 230, 13, 'После правильного ввода информации нажмите кнопку Сохранить.'),
(46075, 231, 13, 'После загрузки нажмите кнопку "Импорт"'),
(46076, 233, 13, 'Повторно'),
(46077, 234, 13, 'Возраст'),
(46078, 235, 13, 'Возраст по'),
(46079, 236, 13, 'Возрастная категория'),
(46080, 237, 13, 'Данные возраста вне диапазона.'),
(46081, 238, 13, 'Формат отображения возраста'),
(46082, 239, 13, 'Формат возраста " возраст от" не действителен'),
(46083, 240, 13, 'Формат возраста " возраст до" не действителен'),
(46084, 241, 13, 'Возраст от'),
(46085, 243, 13, 'Возраст макс'),
(46086, 244, 13, 'Возраст мин'),
(46087, 245, 13, 'Возрастной диапазон'),
(46088, 247, 13, 'Столбцы возрастов:'),
(46089, 249, 13, 'Албанский'),
(46090, 250, 13, 'Алкоголь'),
(46091, 251, 13, 'Употребление алкоголя'),
(46092, 253, 13, 'Количество извещений'),
(46093, 255, 13, 'Оповещения'),
(46094, 258, 13, 'АЛЕУТ'),
(46095, 259, 13, 'Все'),
(46096, 260, 13, 'Все'),
(46097, 261, 13, 'Все (формат сопоставления A)'),
(46098, 262, 13, 'Все (формат сопоставления B)'),
(46099, 263, 13, 'Все (совокупный)'),
(46100, 266, 13, 'Все категории'),
(46101, 268, 13, 'Все коды'),
(46102, 269, 13, 'Весь день'),
(46103, 270, 13, 'Событие на весь день'),
(46104, 271, 13, 'Все поля по персональным данным с поиском и двойной проверкой'),
(46105, 272, 13, 'Все услуги'),
(46106, 273, 13, 'Все травмы/проблемы/аспекты'),
(46107, 274, 13, 'Разрешены все языки'),
(46108, 276, 13, 'Имя или его часть'),
(46109, 277, 13, 'Фамилия или её часть'),
(46110, 278, 13, 'Вся или часть организации'),
(46111, 280, 13, 'Вся продукция'),
(46112, 281, 13, 'Все специалисты'),
(46113, 282, 13, 'Все были рассмотрены и отрицательные'),
(46114, 283, 13, 'Все разделы'),
(46115, 284, 13, 'Все пользователи'),
(46116, 285, 13, 'Аллергология'),
(46117, 286, 13, 'Аллергия'),
(46118, 287, 13, 'Аллергия:'),
(46119, 288, 13, 'Аллергия'),
(46120, 289, 13, 'Импорт аллергии успешно завершен'),
(46121, 291, 13, 'Аллергическая реакция'),
(46122, 294, 13, 'Внести'),
(46123, 295, 13, 'Разрешить'),
(46124, 296, 13, 'Разрешить выбирать все доступные языки в меню входа в систему.'),
(46125, 297, 13, 'Разрешает создание требований, содержащих диагнозы, но не процедуры или оплату. Большинству клиник это не требуется.'),
(46126, 298, 13, 'Разрешить язык отладки'),
(46127, 299, 13, 'Разрешить e-mail'),
(46128, 300, 13, 'Разрешить сообщения по e-mail?'),
(46129, 301, 13, 'Разрешить e-mail?'),
(46130, 302, 13, 'Разрешить запрос обращения'),
(46131, 303, 13, 'Разрешить обмен информации о здоровье'),
(46132, 304, 13, 'Разрешить обмен информации о вакцинации'),
(46133, 305, 13, 'Разрешить использование реестра вакцинации'),
(46134, 306, 13, 'Разрешить передачу сообщений почтой'),
(46135, 308, 13, 'Разрешить портал пациентов'),
(46136, 309, 13, 'Разрешить СМС'),
(46137, 310, 13, 'Разрешить СМС (текстовое сообщение)'),
(46138, 311, 13, 'Разрешить немедленную активацию подчиненных событий?'),
(46139, 312, 13, 'Разрешить телефонные сообщения?'),
(46140, 313, 13, 'Разрешает пользователям публиковывать общие мероприятия'),
(46141, 314, 13, 'Разрешает пользователям опубликовывать персональный календарь'),
(46142, 315, 13, 'Разрешить голосовые сообщения'),
(46143, 316, 13, 'Разрешено'),
(46144, 317, 13, 'Разрешённые языки'),
(46145, 318, 13, 'Разрешено (c)'),
(46146, 323, 13, 'уже существует'),
(46147, 324, 13, 'уже существует.'),
(46148, 325, 13, 'Уже используется, выберите другой идентификатор'),
(46149, 326, 13, 'Уже используется, выберите другой заголовок'),
(46150, 327, 13, 'Альтернативный адрес'),
(46151, 328, 13, 'другой'),
(46152, 329, 13, 'Также можно использовать страницу поиска для загрузки файла электронного денежного перевода (X12 835), который вы получили от плательщика или расчетного центра. Это можно сделать, нажав кнопку "Обзор" и выбрав файл для загрузки, а затем нажав Поиск, чтобы выполнить загрузку и отображение соответствующих счетов-фактур. В этом случае другие параметры, указанные выше, не применяются, и будут игнорированы. Загрузка сохраняет файл, но еще не обрабатывает его содержимое - это будет сделано отдельно, как описано ниже.'),
(46153, 330, 13, 'до полудня'),
(46154, 331, 13, 'Утренняя программа'),
(46155, 332, 13, 'AMC'),
(46156, 333, 13, 'Отслеживание AMC'),
(46157, 338, 13, 'Исправить существующую запись'),
(46158, 343, 13, 'Американский индеец'),
(46159, 344, 13, 'Американский индеец или уроженец Аляски'),
(46160, 345, 13, 'Американская фондовая биржа'),
(46161, 346, 13, 'Амхарский'),
(46162, 347, 13, 'Итог'),
(46163, 349, 13, 'Итоговый платеж'),
(46164, 350, 13, 'Итог прошлого баланса'),
(46165, 351, 13, 'Итог для этого посещения'),
(46166, 352, 13, 'Итоговая оплата'),
(46167, 353, 13, 'Итог:'),
(46168, 354, 13, 'Оплаченный итог'),
(46169, 355, 13, 'Для повторных событий требуется, чтобы дата окончания была позднее, чем дата начала'),
(46170, 357, 13, 'При формировании дампа дерева веб-каталога LibreEHR произошла ошибка'),
(46171, 358, 13, 'Во время формирования дампа дерева веб-каталога phpGACL произошла ошибка'),
(46172, 359, 13, 'Во время форирования дампа по дереву веб-каталога для регистра SQL произошла ошибка'),
(46173, 360, 13, 'Создана и связана неполная проблема GCAC. Позже потребуется ее заполение.'),
(46174, 362, 13, 'Непредвиденная ошибка.'),
(46175, 363, 13, 'Заглавная буква'),
(46176, 365, 13, 'и'),
(46177, 366, 13, 'И'),
(46178, 367, 13, 'и'),
(46179, 368, 13, 'и '),
(46180, 369, 13, 'и все нижестоящие данные? Эти действия будут записываться'),
(46181, 370, 13, 'и модификатор'),
(46182, 371, 13, 'и обработан.'),
(46183, 372, 13, 'и перезагрузите сервер Apache.'),
(46184, 373, 13, 'и причина'),
(46185, 374, 13, 'Анемия'),
(46186, 375, 13, 'Лодыжка'),
(46187, 376, 13, 'Лодыжка + пятка'),
(46188, 377, 13, 'Форма оценки голеностопа'),
(46189, 378, 13, 'Проблемы голеностопного сустава'),
(46190, 379, 13, 'Анкилозирующий спондилит'),
(46191, 380, 13, 'Анкилозирующий спондилит'),
(46192, 381, 13, 'Анорексия'),
(46193, 382, 13, 'В окне отправки также можно сделать повторный запрос счета. Если выберите этот переключатель перед сохранением, то на странице счетов будет вновь открыто первоначальное требование и поставлено в очередь, и при следующем запуске биллинга оно будет обработано.'),
(46194, 383, 13, 'ставка'),
(46195, 384, 13, 'Тонус анального сфинктера обычный, безболезненный, опухолевых образований нет'),
(46196, 385, 13, 'Тревожность'),
(46197, 386, 13, 'Любой'),
(46198, 387, 13, 'Любая категория'),
(46199, 388, 13, 'Любая часть искомого кода или его описания'),
(46200, 389, 13, 'Любая часть искомой специальности'),
(46201, 390, 13, 'Любая часть медикамента или его наименование'),
(46202, 391, 13, 'Любая часть id или имени вакцинации'),
(46203, 392, 13, 'Любая часть именования пациента, или "фамилия,имя", или "X-Y"'),
(46204, 394, 13, 'Ключ API для шлюза СМС'),
(46205, 395, 13, 'Апноэ'),
(46206, 396, 13, 'Внешний вид'),
(46207, 397, 13, 'Внешний вид:'),
(46208, 398, 13, 'Приложить эту запись'),
(46209, 399, 13, 'Приложить к существующей записи'),
(46210, 400, 13, 'Приложить к этой записи'),
(46211, 401, 13, 'Приложить к этой записи'),
(46212, 402, 13, 'Аппендэктомия'),
(46213, 404, 13, 'Подходящие пациенты'),
(46214, 406, 13, 'Применение имени для страницы логина основного заголовка окна.'),
(46215, 407, 13, 'Принимающий код приложения (GS03 - при пустом будет использоваться ISA08)'),
(46216, 408, 13, 'Код отправителя заявки (GS02)'),
(46217, 409, 13, 'Название приложения'),
(46218, 410, 13, 'Применяется в форме жизненно важных показателей и карте физического развития'),
(46219, 412, 13, 'Применить изменения только к текущему событию, к текущему и всем будущим или ко всем?'),
(46220, 413, 13, 'нанести на пораженные участки'),
(46221, 414, 13, 'нанести на кожу'),
(46222, 415, 13, 'Нанесение'),
(46223, 417, 13, 'Запись на прием'),
(46224, 418, 13, 'Дата приема'),
(46225, 419, 13, 'Стиль отображения записи на прием'),
(46226, 420, 13, 'Правило напоминания о приеме'),
(46227, 421, 13, 'Статус приема'),
(46228, 422, 13, 'Статусы для приема'),
(46229, 423, 13, 'запись на прием за период между'),
(46230, 424, 13, 'Цвет записи/мероприятия'),
(46231, 425, 13, 'Записи на прием'),
(46232, 426, 13, 'Записи на прием (write необязательно)'),
(46233, 427, 13, 'Записи на прием (write, wsome необязательно)'),
(46234, 430, 13, 'Записи на прием и обращения'),
(46235, 431, 13, 'Отчет по приему'),
(46236, 432, 13, 'Отчет по приему-обращениям'),
(46237, 434, 13, 'Подтвердить'),
(46238, 436, 13, 'Подтверждено'),
(46239, 437, 13, 'Управление утверждёнными событиями'),
(46240, 440, 13, 'Назн-обр.'),
(46241, 441, 13, 'Назн.'),
(46242, 442, 13, 'Апр'),
(46243, 443, 13, 'Апрель'),
(46244, 444, 13, 'Арабский'),
(46245, 447, 13, 'Переводить имена для групп управления доступом?'),
(46246, 448, 13, 'Переводить имена для категорий приема?'),
(46247, 449, 13, 'Переводить имена для категорий документов?'),
(46248, 450, 13, 'Для этого типа оплата предусмотрена?'),
(46249, 451, 13, 'Переводить заголовки для записи по пациенту?'),
(46250, 452, 13, 'Эти кодировки сохранены во внешних таблицах sql (0-нет, 1-МКБ-10, 2-SNOMED(RF1), 3-SNOMED(RF2))?'),
(46251, 453, 13, 'Готовы завершить новую проблему GCAC для этого посещения?'),
(46252, 454, 13, 'Действительно назначить на сегодня?'),
(46253, 455, 13, 'Действительно, нужно утвердить эти события?'),
(46254, 457, 13, 'Действительно нужно полностью удалить эту форму?'),
(46255, 459, 13, 'Действительно, нужно удалить эту публикацию?'),
(46256, 460, 13, 'Действительно, нужно удалить это событие?'),
(46257, 461, 13, 'Действительно нужно удалить этот пункт из базы данных?'),
(46258, 462, 13, 'Действительно нужно удалить эту запись?'),
(46259, 464, 13, 'Действительно, нужно изменить эти события?'),
(46260, 465, 13, 'Действительно, нужно скрыть эти события?'),
(46261, 467, 13, 'Действительно, нужно открыть эти события?'),
(46262, 468, 13, 'Действительно, нужно удалить всю группу'),
(46263, 469, 13, 'Действительно, нужно удалить список целиком'),
(46264, 470, 13, 'Действительно, нужно удалить поля в'),
(46265, 471, 13, 'Действительно, нужно удалить выбранные поля?'),
(46266, 472, 13, 'Действительно хотите продолжить эти действия?'),
(46267, 473, 13, 'Не указана область'),
(46268, 474, 13, 'Рука'),
(46269, 475, 13, 'Армянский'),
(46270, 477, 13, 'Аритмия'),
(46271, 478, 13, 'Артрит'),
(46272, 479, 13, 'Артрит / деструктивное заболевание суставов'),
(46273, 480, 13, 'Артрит / деструктивное заболевание суставов'),
(46274, 481, 13, 'как'),
(46275, 482, 13, 'Как из'),
(46276, 484, 13, 'Азиатский'),
(46277, 487, 13, 'Оценка'),
(46278, 488, 13, 'Назначено'),
(46279, 489, 13, 'Ассистент'),
(46280, 490, 13, 'Астма'),
(46281, 491, 13, 'в'),
(46282, 492, 13, 'При выборе всех требуется хотя бы один параметр поиска.'),
(46283, 493, 13, 'В ладьевидной'),
(46284, 494, 13, 'В ладьевидной:'),
(46285, 495, 13, 'Спортивная команда'),
(46286, 497, 13, 'Спортивная/травма'),
(46287, 498, 13, 'Сертификат CA аудита ATNA'),
(46288, 499, 13, 'Хост аудита ATNA'),
(46289, 500, 13, 'Местный сертификат для аудита ATNA'),
(46290, 501, 13, 'Порт аудита ATNA'),
(46291, 503, 13, 'Внимание'),
(46292, 504, 13, 'Вним.'),
(46293, 509, 13, 'Аудит журналирования резервного копирования'),
(46294, 510, 13, 'Аудит смешанного журналирования'),
(46295, 511, 13, 'Аудит журналирования назначения'),
(46296, 512, 13, 'Аудит журналирования записи по пациенту'),
(46297, 513, 13, 'Аудит журналирования планирования'),
(46298, 514, 13, 'Аудит журналирования управления безопасностью'),
(46299, 515, 13, 'Аудит журналирования запроса SELECT'),
(46300, 516, 13, 'Авг'),
(46301, 517, 13, 'Август'),
(46302, 519, 13, 'Разр.'),
(46303, 520, 13, 'Разр./записи'),
(46304, 523, 13, 'Группа полномочий'),
(46305, 524, 13, 'Статус полномочий'),
(46306, 525, 13, 'Полномочия'),
(46307, 526, 13, 'Разрешить'),
(46308, 527, 13, 'Разрешить - любые обращения'),
(46309, 528, 13, 'Разрешить - мои обращения'),
(46310, 530, 13, 'Уполномоченный'),
(46311, 531, 13, 'Только уполномоченный'),
(46312, 532, 13, 'Автоматическая отправка'),
(46313, 535, 13, 'Создать новое обращение автоматически'),
(46314, 536, 13, 'Авто-созданные'),
(46315, 537, 13, 'Автоматическое вычисление единицы измерения (AMC)'),
(46316, 542, 13, 'Отслеживание автоматического вычисления единицы измерения (AMC)'),
(46317, 543, 13, 'Автоматическая единица измерения (AMC)'),
(46318, 544, 13, 'Автоматически'),
(46319, 546, 13, 'Создает новое обращение автоматически, когда статус приема устанавливается на "@" (проведенный).'),
(46320, 549, 13, 'Медицина автокатастроф'),
(46321, 550, 13, 'автосохранен'),
(46322, 551, 13, 'Доступные категории'),
(46323, 552, 13, 'Доступное время'),
(46324, 557, 13, 'Каждый август'),
(46325, 558, 13, 'Разрыв / перелом с отрывом'),
(46326, 559, 13, 'Отрыв латеральной лодыжки'),
(46327, 560, 13, 'Отрыв медиальной лодыжки '),
(46328, 561, 13, 'На основе информированности'),
(46329, 562, 13, 'Подмышечно'),
(46330, 565, 13, 'дважды в день'),
(46331, 566, 13, 'Назад'),
(46332, 567, 13, 'назад'),
(46333, 568, 13, 'Восемь посещений назад'),
(46334, 569, 13, 'Одиннадцать посещений назад'),
(46335, 570, 13, 'Пять посещений назад'),
(46336, 571, 13, 'Четыре посещения назад'),
(46337, 572, 13, 'Девять посещений назад'),
(46338, 573, 13, 'Одно посещение назад'),
(46339, 574, 13, 'Боли в спине'),
(46340, 575, 13, 'Спинальные проблемы'),
(46341, 576, 13, 'Семь посещений назад'),
(46342, 577, 13, 'Шесть посещений назад'),
(46343, 578, 13, 'Хирургия позвоночника'),
(46344, 579, 13, 'Десять посещений назад'),
(46345, 580, 13, 'Три посещения назад'),
(46346, 581, 13, 'Назад на страницу Администрирования'),
(46347, 584, 13, 'Назад к пациенту'),
(46348, 585, 13, 'Назад к пользователям'),
(46349, 586, 13, 'Назад к просмотру'),
(46350, 587, 13, 'Двенадцать посещений назад'),
(46351, 588, 13, 'Два посещения назад'),
(46352, 590, 13, 'Резервная копия'),
(46353, 591, 13, 'Файл резервного копированя создан.Теперь будет  отправлена загрузка.'),
(46354, 593, 13, 'Резервная копия принята'),
(46355, 594, 13, 'Неправильная регистрация'),
(46356, 595, 13, 'Наибольший долг'),
(46357, 596, 13, 'Бахаса Индонезия'),
(46358, 597, 13, 'Бал.'),
(46359, 598, 13, 'Баланс'),
(46360, 599, 13, 'баланс'),
(46361, 600, 13, 'Итог баланса'),
(46362, 601, 13, 'Остаток причитающихся средств'),
(46363, 603, 13, 'Банковский расчет'),
(46364, 607, 13, 'Основание пятого (5-го) метатарсального'),
(46365, 608, 13, 'Основание пятого (5-го) метатарсального:'),
(46366, 612, 13, 'Средство пакетной передачи данных'),
(46367, 613, 13, 'Ввод групповой оплаты'),
(46368, 614, 13, 'Групповая оплата'),
(46369, 615, 13, 'Инициирована пакетная обработка; она может занят время.'),
(46370, 616, 13, 'Пакетные результаты'),
(46371, 617, 13, 'Пакетная передача'),
(46372, 619, 13, 'из-за того, что id не существует.'),
(46373, 620, 13, 'Начало'),
(46374, 621, 13, 'Начальная дата'),
(46375, 623, 13, 'Начальная дата обслуживания yyyy-mm-dd'),
(46376, 624, 13, 'Начальный час дня для календарных событий.'),
(46377, 626, 13, 'Отрыжка'),
(46378, 628, 13, 'Бенгальский'),
(46379, 630, 13, 'между'),
(46380, 633, 13, 'Билатерально'),
(46381, 634, 13, 'Билатерально:'),
(46382, 636, 13, 'Дата подсчета:'),
(46383, 637, 13, 'Счета/подсчет'),
(46384, 638, 13, 'Оплаченный'),
(46385, 640, 13, 'Счета'),
(46386, 641, 13, 'Счета (write необязательно)'),
(46387, 642, 13, 'Предупреждение по платежу'),
(46388, 644, 13, 'Биллинговый код для запрашиваемой услуги'),
(46389, 645, 13, 'Биллинговые коды'),
(46390, 646, 13, 'Дата платежа'),
(46391, 647, 13, 'Экономический отдел'),
(46392, 648, 13, 'Биллинговая услуга'),
(46393, 649, 13, 'Биллинговая информация'),
(46394, 650, 13, 'Размещение бухгалтерии'),
(46395, 655, 13, 'Менеджер по платежам'),
(46396, 656, 13, 'Биллинговая запись'),
(46397, 657, 13, 'Биллинговая запись для '),
(46398, 658, 13, 'Биллинговая запись:'),
(46399, 659, 13, 'Результаты биллингового запроса'),
(46400, 660, 13, 'Биллинговый отчет'),
(46401, 661, 13, 'Биллинговый статус'),
(46402, 662, 13, 'Статус счета = не оплачен'),
(46403, 663, 13, 'счет в '),
(46404, 665, 13, 'Биопсия'),
(46405, 666, 13, 'Дата рождения'),
(46406, 669, 13, 'Черный'),
(46407, 670, 13, 'Затемненное легкое'),
(46408, 671, 13, 'Черный или афро-американец'),
(46409, 672, 13, 'Рак мочевого пузыря'),
(46410, 673, 13, 'Инфекция мочевого пузыря'),
(46411, 674, 13, 'Пустые формы'),
(46412, 675, 13, 'Жалобы на кровотечение'),
(46413, 676, 13, 'Выпадение зрения'),
(46414, 677, 13, 'Вздутие живота'),
(46415, 678, 13, 'Блокированный'),
(46416, 679, 13, 'Кровь'),
(46417, 680, 13, 'Артериальное давление'),
(46418, 681, 13, 'Артериальное давление'),
(46419, 682, 13, 'Носовое кровотечение'),
(46420, 683, 13, 'Медицинское страховое общество Синий Щит'),
(46421, 684, 13, 'Синии строки в этом отчете являются информационными.  Черные строки показывают ранее существовавшую  информацию. Зеленые строки показывают изменения,  которые были успешно применены. Красные строки  обозначают ошибки или изменения, которые не были  применены; они должны быть обработаны вручную.  В настоящее время отклоненные требования и откат  оплаты автоматически не обрабатываются, и поэтому  будут отображаться красным.'),
(46422, 685, 13, 'Нечеткое зрение'),
(46423, 686, 13, 'ИМТ'),
(46424, 687, 13, 'Статус ИМТ'),
(46425, 689, 13, 'Область тела'),
(46426, 690, 13, 'Участок тела'),
(46427, 691, 13, 'Участок тела, если применимо'),
(46428, 692, 13, 'Болезненность в костях:'),
(46429, 693, 13, 'Болезненность в костях: медиальная лодыжка'),
(46430, 694, 13, 'Булевый'),
(46431, 696, 13, 'Нижняя часть'),
(46432, 697, 13, 'Оба уха'),
(46433, 698, 13, 'оба глаза'),
(46434, 699, 13, 'Нижний'),
(46435, 701, 13, 'BOX 10 A. Производственная '),
(46436, 702, 13, 'BOX 10 B. Автомобильная травма '),
(46437, 703, 13, 'BOX 10 C. Другие повреждения '),
(46438, 706, 13, 'ПОЛЕ 18. Дата того же или похожего заболевания (yyyy-mm-dd):'),
(46439, 708, 13, 'ПОЛЕ 16. Нетрудоспособен с даты (yyyy-mm-dd):'),
(46440, 709, 13, 'ПОЛЕ 16. Нетрудоспособен до даты (yyyy-mm-dd):'),
(46441, 710, 13, 'ПОЛЕ 18. Дата госпитализации с (yyyy-mm-dd): '),
(46442, 711, 13, 'ПОЛЕ 18. Госпитализация до даты (yyyy-mm-dd): '),
(46443, 712, 13, 'BOX 20. Внешняя лаборатория используется?'),
(46444, 713, 13, 'BOX 22. Код повторно оказанной медпомощи (ICD-9) '),
(46445, 714, 13, 'BOX 23. Прежних полномочий нет. '),
(46446, 715, 13, 'АД'),
(46447, 716, 13, 'Диастолическое АД'),
(46448, 717, 13, 'Систолическое АД'),
(46449, 719, 13, 'АДд'),
(46450, 721, 13, 'АДс'),
(46451, 722, 13, 'Португалец бразильского происхождения'),
(46452, 723, 13, 'Молочная железа'),
(46453, 724, 13, 'Бипсия молочной железы'),
(46454, 725, 13, 'Отделяемое из соска'),
(46455, 726, 13, 'Заболевание молочной железы'),
(46456, 727, 13, 'Обследование молочной железы'),
(46457, 728, 13, 'Новообразование молочной железы'),
(46458, 730, 13, 'Шумы при дыхании:'),
(46459, 732, 13, 'Повреждение скелета'),
(46460, 734, 13, 'Форма для бронхита'),
(46461, 735, 13, 'Просмотреть'),
(46462, 736, 13, 'Просмотреть для записи'),
(46463, 737, 13, 'Ушиб/гематома'),
(46464, 739, 13, 'Выбухание справа:'),
(46465, 741, 13, 'Жжение при мочеиспускании'),
(46466, 742, 13, 'Жжение при мочеиспускании'),
(46467, 744, 13, 'Занят'),
(46468, 745, 13, 'но еще не обработано.'),
(46469, 746, 13, 'Ягодицы'),
(46470, 747, 13, 'Ягодицы + S.I.'),
(46471, 748, 13, 'через'),
(46472, 749, 13, 'Через'),
(46473, 750, 13, 'перорально'),
(46474, 751, 13, 'Через/поиск'),
(46475, 752, 13, 'Через:'),
(46476, 753, 13, 'C'),
(46477, 754, 13, 'Сертификат CA для подтверждения сервера syslog TLS RFC 5425.'),
(46478, 755, 13, 'Время жизни кэша (в секундах)'),
(46479, 756, 13, 'Шаблон кэша выполнен?'),
(46480, 757, 13, 'Употребление кофеина'),
(46481, 758, 13, 'Календарь'),
(46482, 759, 13, 'Календарный час окончания'),
(46483, 760, 13, 'Календарный период'),
(46484, 761, 13, 'Отображение календаря'),
(46485, 762, 13, 'Настройки календаря'),
(46486, 763, 13, 'Час начала регистрации'),
(46487, 764, 13, 'Пользовательский вид календаря'),
(46488, 765, 13, 'Просмотр календаря'),
(46489, 766, 13, 'Вызов addForm() делается здесь.<br>'),
(46490, 767, 13, 'Калории'),
(46491, 768, 13, 'Кампучиец'),
(46493, 774, 13, 'Отменить'),
(46494, 775, 13, 'Отменить изменения'),
(46495, 776, 13, 'Отменено'),
(46496, 777, 13, 'Рак'),
(46497, 778, 13, 'Скрининг рака: скрининг рака толстого кишечника'),
(46498, 779, 13, 'Скрининг рака: маммография'),
(46499, 780, 13, 'Скрининг рака: мазок Папаникалау'),
(46500, 781, 13, 'Скрининг рака: скрининг рака предстательной железы'),
(46501, 782, 13, 'Не удалось добавить эту запись, потому что она уже имеется!'),
(46502, 783, 13, 'Не удалось добавить/обновить эту запись, потому что уже имеется дубликат!'),
(46503, 785, 13, 'не удалось преобразовать в JPEG. Возможно не установлен ImageMagick?'),
(46504, 787, 13, 'не может быть отображен в сети потому, что его тип не поддерживается браузером.'),
(46505, 788, 13, 'не может быть отображен в сети потому, что его тип не поддерживается браузером.'),
(46506, 789, 13, 'не может быть отображен в сети потому, что его тип не поддерживается браузером.'),
(46507, 790, 13, 'Не удалось создать'),
(46508, 795, 13, 'Не удалось найти '),
(46509, 796, 13, 'Не удается найти предназначенное имя файла'),
(46510, 799, 13, 'Не удалось найти пациента в пользовательском id реестре SQL'),
(46511, 800, 13, 'Не удалось найти ссылку на документ postscript в '),
(46512, 801, 13, 'Не удалось найти специалиста из реестра SQL служащий = '),
(46513, 802, 13, 'Не удается изменить платежи. Остаток отрицательный.'),
(46514, 803, 13, 'Невозможно отрыть '),
(46515, 804, 13, 'Не удалось отправить для страховки. Выбранным лицом для платежа является пациент.'),
(46516, 805, 13, 'Не удалось отправить для пациента. Выбранным лицом для платежа является страховка.'),
(46517, 806, 13, 'Не удается отправить платежи. Остаток отрицательный.'),
(46518, 807, 13, 'Невозможно прочесть'),
(46519, 808, 13, 'Невозможно прочесть директорию'),
(46520, 809, 13, 'Не удалось обновить, потому что вы не редактировали существующую запись!'),
(46521, 810, 13, 'Заглавная'),
(46522, 812, 13, 'капсула'),
(46523, 813, 13, 'Карта'),
(46524, 814, 13, 'Коронарное зондирование'),
(46525, 815, 13, 'ЭхоКГ'),
(46526, 816, 13, 'Сердечно-сосудистая'),
(46527, 821, 13, 'Повреждение хряща / сустава / диска'),
(46528, 822, 13, 'Травма хряща'),
(46529, 823, 13, 'Каротидная пульсация nl, пульс на стопах nl'),
(46530, 824, 13, 'наличные'),
(46531, 825, 13, 'Наличные'),
(46532, 826, 13, 'Пол. нал.'),
(46533, 827, 13, 'Наличные, полученные по специалисту'),
(46534, 829, 13, 'Хирургия катаракты'),
(46535, 830, 13, 'Катаракта'),
(46536, 831, 13, 'Категории'),
(46537, 832, 13, 'Категории для'),
(46538, 833, 13, 'Категория'),
(46539, 834, 13, 'категория'),
(46540, 835, 13, 'категория '),
(46541, 836, 13, 'Сведения о категории'),
(46542, 837, 13, 'Ограничения по категории'),
(46543, 838, 13, 'Наименование категории'),
(46544, 839, 13, 'Наименование категории пустое'),
(46545, 840, 13, 'Категория/заголовок'),
(46546, 841, 13, 'Кавказец'),
(46547, 842, 13, 'Подтвержденные причины для вывода информации по обращению или основному специалисту'),
(46548, 850, 13, 'CDR'),
(46549, 852, 13, 'Cell'),
(46550, 853, 13, 'Сотовый телефон'),
(46551, 855, 13, 'Номер сотового телефона'),
(46552, 856, 13, 'Основной сертификат'),
(46553, 857, 13, 'Уроженец центральной или южной Америки'),
(46554, 858, 13, 'Файл crt доверенного сертификата не может быть пустым'),
(46555, 859, 13, 'Файл ключа доверенного сертификата не может быть пустым'),
(46556, 860, 13, 'Сертификат для отправки на сервер syslog RFC 5425 TLS'),
(46557, 861, 13, 'Сертификат пользователя'),
(46558, 862, 13, 'Сертификаты'),
(46559, 864, 13, 'Программа медицинского обслуживания членов семей военнослужащих'),
(46560, 865, 13, 'ChampUSVA'),
(46561, 866, 13, 'изменение'),
(46562, 867, 13, 'Изменение'),
(46563, 868, 13, 'Изменить активность'),
(46564, 870, 13, 'Ухудшение зрения'),
(46565, 871, 13, 'Ухудшение зрения'),
(46566, 874, 13, 'Измененный'),
(46567, 875, 13, 'Измененный кишечник'),
(46568, 877, 13, 'Особенности'),
(46569, 878, 13, 'Оставшиеся символы'),
(46570, 879, 13, 'Оплата'),
(46571, 880, 13, 'Корректировка оплаты'),
(46572, 881, 13, 'Кодированная оплата'),
(46573, 882, 13, 'Оплата'),
(46574, 883, 13, 'Карта'),
(46575, 884, 13, 'Активность карты'),
(46576, 885, 13, 'Отчет об интенсивности зарегистрированных/неактивных карт'),
(46577, 886, 13, 'ID карты'),
(46578, 887, 13, 'ID карты:'),
(46579, 889, 13, 'Активность размещения карты'),
(46580, 890, 13, 'Запись в карту'),
(46581, 891, 13, 'Номер карты'),
(46582, 892, 13, 'Место хранения карты'),
(46583, 893, 13, 'Отслеживание карты');
INSERT INTO `lang_definitions` VALUES
(46584, 894, 13, 'Отслеж. карты'),
(46585, 895, 13, 'Закрытые карты'),
(46586, 896, 13, 'Закрытые карты'),
(46587, 898, 13, 'Проверить'),
(46588, 899, 13, 'чек'),
(46589, 900, 13, 'Отметить всё'),
(46590, 902, 13, 'Итог регистрации'),
(46591, 903, 13, 'Внести дату'),
(46592, 904, 13, 'Зарегистрировать различия переводов с пользовательской языковой таблицей.'),
(46593, 906, 13, 'Отметьте по'),
(46594, 907, 13, 'Отметьте данные ввода'),
(46595, 909, 13, 'Лабораторные результаты'),
(46596, 912, 13, 'Отметьте номер'),
(46597, 915, 13, 'Отметьте оплату'),
(46598, 916, 13, 'Если файл является шифрованным, отметьте это поле'),
(46599, 917, 13, 'Отметьте здесь, если нужно, чтобы специалисты видели все записи на прием по умолчанию, а не только свои собственные.'),
(46600, 919, 13, 'Дата регистрации или EOB:'),
(46601, 920, 13, 'Номер регистрации или EOB:'),
(46602, 921, 13, 'Номер рег./напр.'),
(46603, 922, 13, 'Номер регистрации или направления'),
(46604, 923, 13, 'Список переключателей'),
(46605, 924, 13, 'список переключателей'),
(46606, 925, 13, 'переключатель с текстом'),
(46607, 926, 13, 'Переключатель с текстом'),
(46608, 928, 13, 'Отмеченный'),
(46609, 929, 13, 'Отмеченное поле = да, пустое = нет'),
(46610, 932, 13, 'Расчет'),
(46611, 933, 13, 'Контрольная сумма'),
(46612, 934, 13, 'Грудь'),
(46613, 935, 13, 'CTAB груди'),
(46614, 936, 13, 'Боль в груди'),
(46615, 937, 13, 'Боль в груди:'),
(46616, 938, 13, 'Боли в груди'),
(46617, 940, 13, 'Изм.'),
(46618, 942, 13, 'Основная жалоба'),
(46619, 943, 13, 'Ребенок'),
(46620, 945, 13, 'Статус детской вакцинации (CQM)'),
(46621, 946, 13, 'Ознобы'),
(46622, 947, 13, 'Китайский'),
(46623, 948, 13, 'Китайский (упрощенный)'),
(46624, 949, 13, 'Китайский (традиционный)'),
(46625, 951, 13, 'Выборочно'),
(46626, 952, 13, 'Холецистэктомия'),
(46627, 954, 13, 'Холецистэктомия'),
(46628, 955, 13, 'Выберите'),
(46629, 956, 13, 'Выберите раздел и кликните в нем на пункте; затем в другом разделе увидете связанные выделенные пункты, и сможете кликнуть в этом разделе для добавления или удаления отношений.'),
(46630, 957, 13, 'Выберите критерий'),
(46631, 962, 13, 'Выберите список'),
(46632, 965, 13, 'Изменяет формат печати для отчета по этому обращению.'),
(46633, 967, 13, 'Хронический бронхит'),
(46634, 968, 13, 'Хронические суставные боли'),
(46635, 969, 13, 'Хроническая почечная недостаточность (ХПН)'),
(46636, 970, 13, 'Хронический синовиит / выпот / суставная боль / подагра'),
(46637, 971, 13, 'Хронический/текущий'),
(46638, 973, 13, 'Цирроз печени'),
(46639, 974, 13, 'Цирроз печени'),
(46640, 975, 13, 'Город'),
(46641, 976, 13, 'Название города'),
(46642, 977, 13, 'Город, область'),
(46643, 978, 13, 'Город, почтовый индекс'),
(46644, 979, 13, 'Город/область'),
(46645, 980, 13, 'Заявка'),
(46646, 981, 13, 'Заявка '),
(46647, 983, 13, 'Затребованный анализ выполнен'),
(46648, 984, 13, 'Тип требования'),
(46649, 985, 13, 'Требование сгенерировано в файл'),
(46650, 986, 13, 'Требование было генерировано в файл '),
(46651, 987, 13, 'Требования'),
(46652, 988, 13, 'Классификация'),
(46653, 989, 13, 'Очистить'),
(46654, 991, 13, 'Очистить всё'),
(46655, 992, 13, 'Очистить HL7 данные'),
(46656, 993, 13, 'Полная реабилитация'),
(46657, 994, 13, 'Очистить кэш Smarty'),
(46658, 995, 13, 'Для создания пакета EDI 270 требуется точная домашняя информация'),
(46659, 996, 13, 'Номер CLIA'),
(46660, 997, 13, 'Нажмите'),
(46661, 998, 13, 'Нажмите "Экспорт", чтобы экспортировать категорию, подкатегорию, пункт, данные содержания в текстовый файл. Любое сходство этого файла с файлом XML является чисто случайным. Открывающий и закрывающий теги должны быть в одной строке, в нижнем регистре без пробелов. Для импорта найдите файл и нажмите "Импорт". Если данные совершенно другие, он объединится с существующими данными. Если есть похожие наименования пунктов, старый будет оставлен, а новый сохранен с добавлением в конце номера.'),
(46662, 999, 13, 'Кликните место в графике для добавления новой аннотации, кликните его еще раз для удаления'),
(46663, 1000, 13, 'Нажмите Загрузить сертификат для загрузки сертификатов в файл ssl.zip'),
(46664, 1001, 13, 'кликните для подробностей'),
(46665, 1005, 13, 'Нажмите здесь'),
(46666, 1006, 13, 'Нажмите здесь для добавления нового пациента.'),
(46667, 1007, 13, 'Кликните здесь для добавления измененного статуса новой травмы и измените ежедневную активность'),
(46668, 1008, 13, 'Нажмите здесь для выбора даты'),
(46669, 1009, 13, 'Нажмите здесь для выбора даты и времени'),
(46670, 1010, 13, 'Нажмите здесь для выбора начальной даты'),
(46671, 1020, 13, 'нажмите здесь для поиска'),
(46672, 1021, 13, 'кликните здесь, чтобы обновить приоритет, категорию и параметры настройки никнейма'),
(46673, 1022, 13, 'Нажмите здесь, чтобы просмотреть всё'),
(46674, 1023, 13, 'Нажмите здесь для просмотра и графики'),
(46675, 1025, 13, 'Нажмите здесь для просмотра и графики всех жизненно важных показателей.'),
(46676, 1026, 13, 'Кликните здесь для просмотра сведений о пациенте'),
(46677, 1027, 13, 'Нажмите здесь для просмотра их всех.'),
(46678, 1029, 13, 'Нажмите кнопку Установить для установки версии базы данных с указанной даты'),
(46679, 1030, 13, 'Кликните по любой части времени для ее увеличения'),
(46680, 1031, 13, 'Кликните фамилию пациента для открытия его файла'),
(46681, 1032, 13, 'Нажмите Обновить для обзора всех результатов, или введите выше критерий поиска для просмотра отдельных результатов.'),
(46682, 1034, 13, 'Нажмите для добавления новых компонентов'),
(46683, 1035, 13, 'Кликните для добавления новой консультации'),
(46684, 1037, 13, 'Нажмите для загрузки'),
(46685, 1038, 13, 'Нажмите для редактирования'),
(46686, 1040, 13, 'Кликните для изменения этого события'),
(46687, 1041, 13, 'Нажмите чтоб генерировать отчет'),
(46688, 1043, 13, 'Нажмите для печати'),
(46689, 1044, 13, 'Кликните для получения (добавления) новой партии'),
(46690, 1045, 13, 'Нажмите для выбора'),
(46691, 1046, 13, 'Нажмите для выбора'),
(46692, 1047, 13, 'Кликните для выбора кода отраслевого стандарта для этой методики'),
(46693, 1048, 13, 'Кликните для выбора необязательного процедурного кода'),
(46694, 1050, 13, 'Кликните для выбора или изменения кода CVX'),
(46695, 1051, 13, 'Кликните для выбора или изменения диагноза'),
(46696, 1052, 13, 'Кликните для выбора или изменения кодов услуг'),
(46697, 1053, 13, 'Нажмите для выбора пациента'),
(46698, 1054, 13, 'Кликните для выбора связанного кода'),
(46699, 1055, 13, 'Если этот результат дает отклонение от нормы, кликните для выбора оказания помощи'),
(46700, 1056, 13, 'Кликните для выбора необходимой методики'),
(46701, 1058, 13, 'Нажмите для просмотра'),
(46702, 1059, 13, 'Нажмите для просмотра или изменения'),
(46703, 1060, 13, 'Нажмите для просмотра/изменения'),
(46704, 1061, 13, 'Нажмите кнопку Модернизировать для модернизации версии базы данных с указанной даты'),
(46705, 1063, 13, 'Нажмите:'),
(46706, 1064, 13, 'Срок действия сертификата клиента в днях'),
(46707, 1065, 13, 'Допустимый период срока действия сертификата клиента'),
(46708, 1066, 13, 'Действительный сертификат клиента должен быть допустимым номером.'),
(46709, 1067, 13, 'Копия для пациента'),
(46710, 1069, 13, 'Выписка из истории болезни пациента'),
(46711, 1072, 13, 'Клиентский профиль - новые клиенты'),
(46712, 1073, 13, 'Клиентский профиль - уникальные клиенты'),
(46713, 1074, 13, 'Клиенты'),
(46714, 1075, 13, 'Клиника'),
(46715, 1076, 13, 'Копия для клиники'),
(46716, 1077, 13, 'Ежедневная регистрация по клинике'),
(46717, 1078, 13, 'ID клиники'),
(46718, 1079, 13, 'Клинический'),
(46719, 1080, 13, 'Менеджер извещений для клинических правил заключений'),
(46720, 1081, 13, 'Клиника'),
(46721, 1083, 13, 'Клинические программы'),
(46722, 1084, 13, 'Клиническая единица измерения качества (CQM)'),
(46723, 1087, 13, 'Клинические напоминания'),
(46724, 1088, 13, 'Клинические отчеты'),
(46725, 1089, 13, 'Категория деятельности для клинических правил'),
(46726, 1090, 13, 'Объект воздействия для клинических правил'),
(46727, 1091, 13, 'Методы фильтрации для клинических правил'),
(46728, 1092, 13, 'Планируемые методы для клинических правил'),
(46729, 1093, 13, 'Клинические правила'),
(46730, 1094, 13, 'Возрастные интервалы для клинических правил'),
(46731, 1095, 13, 'Сравнения для клинических правил'),
(46732, 1096, 13, 'Типы обращений для клинических правил'),
(46733, 1097, 13, 'Варианты выполнения напоминаний для клинических правил'),
(46734, 1098, 13, 'Варианты снятия напоминаний для клинических правил'),
(46735, 1099, 13, 'Интервалы напоминаний для клинических правил'),
(46736, 1100, 13, 'Методы напоминаний для клинических правил'),
(46737, 1101, 13, 'Планируемые интервалы для клинических правил'),
(46738, 1102, 13, 'Клинические задачи'),
(46739, 1106, 13, 'Клиницисты'),
(46740, 1107, 13, 'Клонировать'),
(46741, 1108, 13, 'Клонировать прошлое посещение'),
(46742, 1109, 13, 'Закрыть'),
(46743, 1111, 13, 'закрыть окно'),
(46744, 1112, 13, 'Закрытый'),
(46745, 1113, 13, 'см'),
(46746, 1114, 13, 'Поля CMS 1500'),
(46747, 1118, 13, 'ID для CMS'),
(46748, 1127, 13, 'Невридимый CN2-12'),
(46749, 1128, 13, 'Доплата'),
(46750, 1129, 13, 'Выполнена доплата'),
(46751, 1130, 13, 'ДОПЛАТА'),
(46752, 1131, 13, 'Код'),
(46753, 1132, 13, 'код'),
(46754, 1133, 13, 'Поиск кода'),
(46755, 1134, 13, 'Код должен иметь две буквы в нижнем регистре'),
(46756, 1135, 13, 'Код или символ для денежного обозначения'),
(46757, 1136, 13, 'Текст кода'),
(46758, 1138, 13, 'тип кода'),
(46759, 1141, 13, 'Типы кодов'),
(46760, 1143, 13, 'Кодировано'),
(46761, 1144, 13, 'Коды'),
(46762, 1145, 13, 'Индексация'),
(46763, 1147, 13, 'Индексация - любые обращения (write,wsome необязательно)'),
(46764, 1148, 13, 'Индексация - мои обращения (write,wsome необязательно)'),
(46765, 1149, 13, 'Доступ к шифрованию не разрешен'),
(46766, 1150, 13, 'Кофе'),
(46767, 1152, 13, 'Совместное страхование'),
(46768, 1153, 13, 'Бесплатно'),
(46769, 1154, 13, 'Свернуть'),
(46770, 1155, 13, 'скрыть'),
(46771, 1156, 13, 'Свернуть всё'),
(46772, 1157, 13, 'Свернуть всё'),
(46773, 1158, 13, 'свернуть всё'),
(46774, 1161, 13, 'Сборы'),
(46775, 1162, 13, 'Отчет по сборам'),
(46776, 1163, 13, 'Рак толстого кишечника'),
(46777, 1164, 13, 'Скрининг рака толстого кишечника'),
(46778, 1165, 13, 'Хирургия рака толстого кишечника'),
(46779, 1166, 13, 'Колоноскопия'),
(46780, 1167, 13, 'колоноскопия'),
(46781, 1168, 13, 'Цвет'),
(46782, 1169, 13, 'Цвет:сокр.'),
(46783, 1170, 13, 'Столбец'),
(46784, 1171, 13, 'Столбцы'),
(46785, 1172, 13, 'Объединенные партии'),
(46786, 1173, 13, 'Запятая'),
(46787, 1174, 13, 'Коментарий'),
(46788, 1175, 13, 'Коментарии'),
(46789, 1176, 13, 'Комментарии для этого результата или рекомендации'),
(46790, 1177, 13, 'Компания коммерческого страхования.'),
(46791, 1178, 13, 'Завершенные изменения'),
(46792, 1180, 13, 'Связь'),
(46793, 1182, 13, 'Компания'),
(46794, 1183, 13, 'Наименование компании'),
(46795, 1184, 13, 'Завершить'),
(46796, 1186, 13, 'Завершенное'),
(46797, 1188, 13, 'Завершенное?'),
(46798, 1190, 13, 'Осложнения по специалистам, предоставляющим помощь'),
(46799, 1191, 13, 'Осложнения аборта'),
(46800, 1192, 13, 'Компоненты'),
(46801, 1193, 13, 'Автоматизированная система медицинских назначений'),
(46802, 1194, 13, 'Заключения'),
(46803, 1199, 13, 'Настройки'),
(46804, 1200, 13, 'Экспорт/импорт настроек'),
(46805, 1202, 13, 'Настройте Apache и LibreEHR для использования сертификатов SSL на стороне клиента.'),
(46806, 1203, 13, 'Настройка Apache для использования сертификатов SSL на стороне клиента'),
(46807, 1204, 13, 'Настраивает Apache для использования HTTPS.'),
(46808, 1205, 13, 'Настройка LibreEHR для использования сертификатов SSL на стороне клиента.'),
(46809, 1208, 13, 'Подтвердите регистрацию нового пациента'),
(46810, 1209, 13, 'Подтвердите новый пароль'),
(46811, 1210, 13, 'Подтвердите оплату'),
(46812, 1214, 13, 'Врожденный'),
(46813, 1215, 13, 'Коньюктива, зрачки'),
(46814, 1218, 13, 'Константа'),
(46815, 1219, 13, 'наименование константы'),
(46816, 1220, 13, 'Наименование константы пустое'),
(46817, 1221, 13, 'константы'),
(46818, 1222, 13, 'Запоры'),
(46819, 1223, 13, 'Общесистемное'),
(46820, 1226, 13, 'Короткое описание консультации'),
(46821, 1227, 13, 'Контакт'),
(46822, 1228, 13, 'Контактный e-mail'),
(46823, 1229, 13, 'Контактный адрес e-mail'),
(46824, 1231, 13, 'контактная иформация'),
(46825, 1232, 13, 'Контактные линзы'),
(46826, 1236, 13, 'Фамилия для связи'),
(46827, 1237, 13, 'Человек для связи'),
(46828, 1239, 13, 'Номер телефона для связи'),
(46829, 1240, 13, 'Обратитесь на ZMG, LLC (zmghealth@gmail.com) для подписки на услугу eRx'),
(46830, 1241, 13, 'содержит, по крайней мере, три из четырех следующих пункта:'),
(46831, 1243, 13, 'Содержание'),
(46832, 1244, 13, 'содержание'),
(46833, 1245, 13, 'Контекст'),
(46834, 1246, 13, 'Наименование контекста не может быть пустым'),
(46835, 1247, 13, 'Продолжить'),
(46836, 1248, 13, 'Продолжение медицинского документа (CCD)'),
(46837, 1249, 13, 'Продолжение медицинской записи (CCD)'),
(46838, 1250, 13, 'Взаимные клиенты'),
(46839, 1251, 13, 'Контрацепция'),
(46840, 1252, 13, 'Аспекты контрацепции'),
(46841, 1253, 13, 'Осложнение контрацепции (указать)'),
(46842, 1254, 13, 'Способ контрацепции'),
(46843, 1255, 13, 'Контрацептивные изделия'),
(46844, 1256, 13, 'Предварительно включенные услуги по контрацепции'),
(46845, 1257, 13, 'Начало контрацепции'),
(46846, 1258, 13, 'ID настройки'),
(46847, 1259, 13, 'Номер настройки'),
(46848, 1261, 13, 'Доплата'),
(46849, 1262, 13, 'Доплата'),
(46850, 1263, 13, 'Доплата'),
(46851, 1264, 13, 'Доплата не предполагается'),
(46852, 1266, 13, 'Доплаты'),
(46853, 1267, 13, 'ХОБЛ'),
(46854, 1268, 13, 'Копировать страницы в карту пациента'),
(46855, 1269, 13, 'Копировать значения'),
(46856, 1270, 13, 'Копирование файла базы данных. Это займёт некоторое время...'),
(46857, 1271, 13, 'Уведомление об авторских правах'),
(46858, 1273, 13, 'Коронарное шунтирование'),
(46859, 1274, 13, 'Коронарное шунтирование трансплантантом (CABG)'),
(46860, 1275, 13, 'Исправленное'),
(46861, 1277, 13, 'CouchDB'),
(46862, 1278, 13, 'Подключение CouchDB дало сбой.'),
(46863, 1279, 13, 'База данных CouchDB'),
(46864, 1280, 13, 'Имя базы данных CouchDB'),
(46865, 1281, 13, 'Хост CouchDB'),
(46866, 1282, 13, 'Имя хоста CouchDB'),
(46867, 1283, 13, 'Включить журналирование CouchDB'),
(46868, 1284, 13, 'Пароль CouchDB'),
(46869, 1285, 13, 'Порт CouchDB'),
(46870, 1286, 13, 'Порт CouchDB'),
(46871, 1288, 13, 'Имя пользователя CouchDB'),
(46872, 1289, 13, 'Кашель'),
(46873, 1290, 13, 'Кашель:'),
(46874, 1294, 13, 'Не удалось прочитать файл'),
(46875, 1296, 13, 'Не удалось отправить email из-за проблемы сервера, '),
(46876, 1297, 13, 'Не удалось отправить email из-за проблемы сервера. '),
(46877, 1298, 13, 'Не удалось создать директорию резервного копирования:'),
(46878, 1299, 13, 'Не удалось удалить директорию:'),
(46879, 1300, 13, 'Не удалось удалить старый файл резервного копирования:'),
(46880, 1301, 13, 'Не удалось удалить старый файл экспорта:'),
(46881, 1302, 13, 'Управление Coumadin - контроль международного нормализационного индекса'),
(46882, 1303, 13, 'Реком. по способу'),
(46883, 1304, 13, 'Рекомендация'),
(46884, 1305, 13, 'Консультативная работа'),
(46885, 1306, 13, 'УЧЕТНАЯ ФОРМА НАПРАВЛЕНИЯ'),
(46886, 1307, 13, 'Учетное направления'),
(46887, 1308, 13, 'Страна'),
(46888, 1309, 13, 'Тип данных для страны'),
(46889, 1310, 13, 'Список стран'),
(46890, 1311, 13, 'Список стран (write,addonly не обязателен)'),
(46891, 1312, 13, 'Наименование страны должно быть представлено двумя буквами. (Например: Соединенные штаты обозначено US)'),
(46892, 1313, 13, 'республика'),
(46893, 1315, 13, 'Купон'),
(46894, 1318, 13, 'Клиническое обследование больного (CPT)'),
(46895, 1319, 13, 'Код CPT'),
(46896, 1320, 13, 'Коды CPT'),
(46897, 1321, 13, 'Процедура/служба CPT4'),
(46898, 1322, 13, 'Измерение эффективности CPTII'),
(46899, 1323, 13, 'CQM'),
(46900, 1324, 13, 'Влажные хрипы:'),
(46901, 1325, 13, 'крем'),
(46902, 1326, 13, 'Создает сертификат SSL на стороне клиента для каждого пользователя или клиентской машины.'),
(46903, 1327, 13, 'Создает сертификат SSL на стороне клиента либо для пользователя, либо для имени узла клиента.'),
(46904, 1329, 13, 'Создать событие'),
(46905, 1330, 13, 'Создает и загружает полную резервную копию'),
(46906, 1332, 13, 'Создать резервную копию'),
(46907, 1333, 13, 'Создать партию'),
(46908, 1334, 13, 'Создать клиентский сертификат'),
(46909, 1335, 13, 'Создает сертификаты SSL на стороне клиента.'),
(46910, 1336, 13, 'Создать дубликат'),
(46911, 1338, 13, 'Создает журнал событий резервного копирования'),
(46912, 1339, 13, 'Создать новую проблему'),
(46913, 1340, 13, 'Оформить нового пациента'),
(46914, 1342, 13, 'Создать мандаты для внешнего портала'),
(46915, 1343, 13, 'Создать мандаты для внутреннего портала'),
(46916, 1344, 13, 'Создать запись по пациенту'),
(46917, 1345, 13, 'Создает доверенный сертификат SSL и сертификаты сервера.'),
(46918, 1346, 13, 'Создать посещение'),
(46919, 1347, 13, 'Создано'),
(46920, 1348, 13, 'Создание файла экспорта'),
(46921, 1351, 13, 'Создатель'),
(46922, 1352, 13, 'кредит'),
(46923, 1353, 13, 'Кредитная карта'),
(46924, 1354, 13, 'Кредитовать'),
(46925, 1356, 13, 'Критерий'),
(46926, 1358, 13, 'Болезнь Крона'),
(46927, 1359, 13, 'Болезнь Крона'),
(46928, 1360, 13, 'Экспорт CSV'),
(46929, 1361, 13, 'Файл CSV'),
(46930, 1363, 13, 'куб.мм'),
(46931, 1364, 13, 'Кубинец'),
(46932, 1365, 13, 'Размещение десятичных для денег'),
(46933, 1366, 13, 'Символ десятичной запятой для денег'),
(46934, 1367, 13, 'Денежный указатель'),
(46935, 1368, 13, 'Разделитель тысяч для денег'),
(46936, 1369, 13, 'Текущее'),
(46937, 1370, 13, 'Текущее употребление алкоголя'),
(46938, 1371, 13, 'Текущая констультация'),
(46939, 1372, 13, 'Текущий критерий'),
(46940, 1373, 13, 'Цвет выделения для текущего дня'),
(46941, 1374, 13, 'В настоящее время курит каждый день'),
(46942, 1375, 13, 'Текущее имя файла было изменено на'),
(46943, 1376, 13, 'Текущий хэш'),
(46944, 1377, 13, 'Текущее нахождение'),
(46945, 1378, 13, 'Принимаемые препараты'),
(46946, 1379, 13, 'Текущий пароль'),
(46947, 1380, 13, 'Текущий пациент'),
(46948, 1382, 13, 'Принимаемые рекреационные наркотики'),
(46949, 1383, 13, 'В настоящее время курит не каждый день'),
(46950, 1386, 13, 'Текущая деятельность'),
(46951, 1388, 13, 'В настоящее время помощь не оказывается'),
(46952, 1389, 13, 'Синдром Кушинга'),
(46953, 1390, 13, 'болезнь Иценко-Кушинга'),
(46954, 1392, 13, 'Пользовательский'),
(46955, 1393, 13, 'Пользовательский ввод?'),
(46956, 1394, 13, 'Пользовательская таблица'),
(46957, 1396, 13, 'Код CVX'),
(46958, 1397, 13, 'Отображение кода CVX'),
(46959, 1398, 13, 'Вакцинация CVX'),
(46960, 1399, 13, 'Цикл'),
(46961, 1400, 13, 'Цитохром P450'),
(46962, 1401, 13, 'Фактор цитохрома P450'),
(46963, 1402, 13, 'Сообщение о цитохроме P450'),
(46964, 1403, 13, 'Чешский'),
(46965, 1404, 13, 'D'),
(46966, 1405, 13, 'Расширение и кюретаж'),
(46967, 1406, 13, 'D&E'),
(46968, 1407, 13, 'Дата рожд.'),
(46969, 1408, 13, 'ежедневно'),
(46970, 1409, 13, 'Ежедневная запись'),
(46971, 1410, 13, 'Датский'),
(46972, 1411, 13, 'Подобные данные уже имеются в базе данных, измените код и/или описание'),
(46973, 1412, 13, 'Подобные данные уже имеются в базе данных, измените имя константы'),
(46974, 1413, 13, 'Столб. данных'),
(46975, 1416, 13, 'Ошибка даты'),
(46976, 1420, 13, 'Тип данных'),
(46977, 1421, 13, 'База данных'),
(46978, 1422, 13, 'База данных не установлена.'),
(46979, 1423, 13, 'Группа баз данных'),
(46980, 1424, 13, 'Сообщение базы данных'),
(46981, 1425, 13, 'Обновление базы данных завершено.'),
(46982, 1426, 13, 'Столбцы данных должны быть числом между 1 и 999'),
(46983, 1427, 13, 'Дата'),
(46984, 1428, 13, 'ДАТА'),
(46985, 1431, 13, 'Управление датой'),
(46986, 1432, 13, 'Дата и время взятия образца'),
(46987, 1433, 13, 'Дата и время этого исследования'),
(46988, 1435, 13, 'Дата и время, когда биообразец был собран'),
(46989, 1436, 13, 'Дата не может быть больше сегодняшней'),
(46990, 1437, 13, 'Дата первоначально предоставленной услуги по контрацепции'),
(46991, 1438, 13, 'Дата создания'),
(46992, 1439, 13, 'Дата смерти'),
(46993, 1440, 13, 'Дата уничтожения'),
(46994, 1441, 13, 'Отображаемый формат даты'),
(46995, 1442, 13, 'Формат даты для "Окончание приема" не допустим'),
(46996, 1443, 13, 'Формат даты для "Начало приема" не допустим'),
(46997, 1444, 13, 'Формат даты для "Следующий прием" не допустим'),
(46998, 1445, 13, 'Формат даты для "не видел с" не допустим'),
(46999, 1446, 13, 'Формат даты для "с тех пор видел" не допустим'),
(47000, 1447, 13, 'Предоставленные информационные заявки о дате проведения вакцинации'),
(47001, 1448, 13, 'Дата для кода пропущена '),
(47002, 1449, 13, 'Основной критерий даты'),
(47003, 1450, 13, 'Дата банковского взноса yyyy-mm-dd'),
(47004, 1451, 13, 'Дата платежа'),
(47005, 1452, 13, 'Дата рождения'),
(47006, 1453, 13, 'Дата рождения'),
(47007, 1454, 13, 'Дата рождения'),
(47008, 1455, 13, 'Дата ввода'),
(47009, 1456, 13, 'Дата травмы'),
(47010, 1458, 13, 'Дата оплаты yyyy-mm-dd'),
(47011, 1459, 13, 'Дата направления'),
(47012, 1460, 13, 'Дата ответа'),
(47013, 1462, 13, 'Дата оказания помощи'),
(47014, 1463, 13, 'Дата услуги'),
(47015, 1464, 13, 'Дата услуги = сегодня'),
(47016, 1465, 13, 'Дата услуги мм/дд/гггг'),
(47017, 1466, 13, 'Дата услуги:'),
(47018, 1467, 13, 'Дата подписания'),
(47019, 1469, 13, 'Дата этого назначения'),
(47020, 1470, 13, 'Дата этого отчета'),
(47021, 1471, 13, 'Дата заявки по видимому набору информации'),
(47022, 1472, 13, 'Назначение даты'),
(47023, 1475, 13, 'Селектор даты'),
(47024, 1476, 13, 'Дата отправки'),
(47025, 1477, 13, 'Дата сообщения была отправлена'),
(47026, 1479, 13, 'Значение даты не может быть пустым.'),
(47027, 1480, 13, 'Дата/назн.'),
(47028, 1481, 13, 'Дата/записи'),
(47029, 1482, 13, 'Последняя дата или записи'),
(47030, 1483, 13, 'Дата/время'),
(47031, 1484, 13, 'Дата:'),
(47032, 1485, 13, 'Устаревший журнал сообщений'),
(47033, 1486, 13, 'День'),
(47034, 1487, 13, 'день'),
(47035, 1489, 13, 'Обзор за день'),
(47036, 1490, 13, 'дней'),
(47037, 1491, 13, 'Дни Пн-Пт'),
(47038, 1492, 13, 'дни'),
(47039, 1493, 13, 'Дни'),
(47040, 1494, 13, 'дней назад'),
(47041, 1495, 13, 'Дни и проекты пропущены'),
(47042, 1496, 13, 'Дней от последнего обращения'),
(47043, 1497, 13, 'Пропущенные дни'),
(47044, 1498, 13, 'Дней в столбце:'),
(47045, 1500, 13, 'Дни/столб.:'),
(47046, 1501, 13, 'БД установлена'),
(47047, 1502, 13, 'DD/MM/YYYY'),
(47048, 1503, 13, 'Предотвращение дублирования идентификации'),
(47049, 1504, 13, 'Обработка деидентификации завершена'),
(47050, 1505, 13, 'Продолжается обработка деидентификации'),
(47051, 1506, 13, 'Обработка деидентификации запущена и идет в фоновом режиме'),
(47052, 1507, 13, 'Данные деидентификации не могут быть выполнены'),
(47053, 1508, 13, 'Файлы деидентификации будут сохранены в'),
(47054, 1509, 13, 'Управление по борьбе с наркотиками'),
(47055, 1511, 13, 'Глухой'),
(47056, 1512, 13, 'Отладочная информация'),
(47057, 1515, 13, 'Дек'),
(47058, 1516, 13, 'УМЕРШИЙ'),
(47059, 1517, 13, 'Декабрь'),
(47060, 1520, 13, 'Отчисление'),
(47061, 1521, 13, 'Выполнение отчислений'),
(47062, 1522, 13, 'По умолчанию'),
(47063, 1523, 13, 'Вид календаря по умолчанию'),
(47064, 1524, 13, 'ID формы обращения по умолчанию'),
(47065, 1526, 13, 'Услуга по умолчанию'),
(47066, 1527, 13, 'Язык по умолчанию'),
(47067, 1528, 13, 'Язык по умолчанию если другой не разрешен или не выбран.'),
(47068, 1529, 13, 'Список по умолчанию (write,addonly не обязателен)'),
(47069, 1530, 13, 'Метод по умолчанию'),
(47070, 1531, 13, 'Истечение срока пароля по умолчанию.'),
(47071, 1532, 13, 'Истечение срока пароля в днях по умолчанию. 0 означает, что эта функция отключена.'),
(47072, 1533, 13, 'Страна пациента по умолчанию'),
(47073, 1536, 13, 'Специалист по умолчанию'),
(47074, 1537, 13, 'Диапазон по умолчанию'),
(47075, 1538, 13, 'Причина посещения по умолчанию'),
(47076, 1540, 13, 'Настройка по умолчанию'),
(47077, 1541, 13, 'Статус по умолчанию нового окна поля-флажка в списке пациентов.'),
(47078, 1542, 13, 'Шаблон по умолчанию'),
(47079, 1546, 13, 'Единицы измерения по умолчанию'),
(47080, 1547, 13, 'Значение по умолчанию'),
(47081, 1548, 13, 'Склад по умолчанию'),
(47082, 1549, 13, 'Партнер X12 по умолчанию'),
(47083, 1550, 13, 'По умолчанию/глобально'),
(47084, 1551, 13, 'Удалить'),
(47085, 1552, 13, 'удалить'),
(47086, 1553, 13, 'Прибегнуть к удалению (> 12 мес.)'),
(47087, 1554, 13, 'Удалить'),
(47088, 1555, 13, 'удалить'),
(47089, 1556, 13, 'Удалить категории с ID: '),
(47090, 1557, 13, 'Удалить категорию'),
(47091, 1560, 13, 'Удалить группу'),
(47092, 1561, 13, 'Удалить список'),
(47093, 1562, 13, 'Удалить страницы'),
(47094, 1563, 13, 'Удаляет пациента, обращение, форму, проблему, документ, оплату, счет или транзакцию'),
(47095, 1565, 13, 'Удалить строку'),
(47096, 1566, 13, 'Удалить выбранные пункты'),
(47097, 1568, 13, 'Удаление завершено.'),
(47098, 1569, 13, 'Удалить этот документ'),
(47099, 1570, 13, 'Удалить эту форму'),
(47100, 1571, 13, 'Удалить эту запись'),
(47101, 1573, 13, 'Удаление успешно выполнено.'),
(47102, 1575, 13, 'Удаление этого события не может быть выполнено. Его невозможно изменить, так как оно продолжается. Действительно, нужно удалить это событие?'),
(47103, 1581, 13, 'Деменция'),
(47104, 1582, 13, 'Персональные данные'),
(47105, 1583, 13, 'Персональные данные (write,addonly не обязателен)'),
(47106, 1585, 13, 'Критерий отбора персональных данных'),
(47107, 1586, 13, 'Нет разрешения на доступ к персональным данным'),
(47108, 1587, 13, 'Нет разрешения на доступ к персональным данным.'),
(47109, 1588, 13, 'Отказано'),
(47110, 1589, 13, 'Знаменатель'),
(47111, 1590, 13, 'Стоматология'),
(47112, 1592, 13, 'Стоматологические проблемы'),
(47113, 1595, 13, 'При проверке требования X 12, в зависимости от типа, счета HCFA будут выглядеть как вывод пустой страницы, увидите многие строки с несколько искаженным текстом и информацией. Этот искаженный текст является форматом X 12 EDI 4010A. Иногда будете видеть странные символы, которые выглядят как домино или волнисто, это управляющие символы, такие как подача страницы и являются обычными.'),
(47114, 1596, 13, 'Дата внесения'),
(47115, 1597, 13, 'Дата внесения не может быть позднее сегодняшней'),
(47116, 1598, 13, 'Дата внесения:'),
(47117, 1599, 13, 'Снижено'),
(47118, 1600, 13, 'Депрессия'),
(47119, 1602, 13, 'Описание'),
(47120, 1603, 13, 'описание'),
(47121, 1605, 13, 'Описание публикации'),
(47122, 1606, 13, 'Описание этой методики или код результата'),
(47123, 1607, 13, 'Перевод описания'),
(47124, 1609, 13, 'Место назначения'),
(47125, 1610, 13, 'Предназначенное имя файла'),
(47126, 1611, 13, 'Уничтожить партию'),
(47127, 1612, 13, 'Уничтожить...'),
(47128, 1613, 13, 'Уничтоженно'),
(47129, 1614, 13, 'Уничтоженные препараты'),
(47130, 1615, 13, 'Отчет по уничтожению препаратов'),
(47131, 1616, 13, 'Подробнее'),
(47132, 1617, 13, 'Подробности'),
(47133, 1619, 13, 'Прогрессирующее отклонение от нормы'),
(47134, 1620, 13, 'Диабет'),
(47135, 1621, 13, 'Сахарный диабет'),
(47136, 1622, 13, 'Диабет: контроль артериального давления (CQM)'),
(47137, 1623, 13, 'Диабет: офтальм. иссл.'),
(47138, 1624, 13, 'Диабет: офтальм. иссл. (CQM)'),
(47139, 1625, 13, 'Диабет: иссл. стоп'),
(47140, 1626, 13, 'Диабет: иссл. стоп (CQM)'),
(47141, 1627, 13, 'Диабет: надзор за бедными HbA1c (CQM)'),
(47142, 1628, 13, 'Диабет: гемоглобин A1C'),
(47143, 1629, 13, 'Диабет: контроль липопротеина низкой плотности (CQM)'),
(47144, 1630, 13, 'Диабет: микроальбумин мочи'),
(47145, 1631, 13, 'Д-з'),
(47146, 1633, 13, 'Диагноз'),
(47147, 1634, 13, 'Код диагноза'),
(47148, 1636, 13, 'Дата диагноза'),
(47149, 1637, 13, 'Для связи с обращением диагноз должен быть кодирован'),
(47150, 1638, 13, 'Наименование диагноза'),
(47151, 1639, 13, 'Отчет о диагнозе'),
(47152, 1640, 13, 'Отчетность о диагнозе'),
(47153, 1641, 13, 'Только отчетность о диагнозе'),
(47154, 1642, 13, 'Название диагноза'),
(47155, 1643, 13, 'Диагноз:'),
(47156, 1644, 13, 'Диагноз: '),
(47157, 1645, 13, 'Диагностические тесты:'),
(47158, 1646, 13, 'Диализ'),
(47159, 1647, 13, 'Колпачки/капсулы'),
(47160, 1648, 13, 'Диарея'),
(47161, 1650, 13, 'Диктовка'),
(47162, 1651, 13, 'Диктовка: '),
(47163, 1652, 13, 'Вы получили копию уведомления HIPAA?'),
(47164, 1653, 13, 'Распространить:'),
(47165, 1654, 13, 'Цифровые знаки'),
(47166, 1657, 13, 'Отправить письмо'),
(47167, 1663, 13, 'Фамилия руководителя'),
(47168, 1665, 13, 'Нетрудоспособность'),
(47169, 1667, 13, 'Отключить календарь'),
(47170, 1668, 13, 'Отключить отслеживание карты'),
(47171, 1669, 13, 'Отключить вакцинацию'),
(47172, 1670, 13, 'Отключить старую метрическую форму для ЖВП'),
(47173, 1672, 13, 'Отключить phpMyAdmin'),
(47174, 1673, 13, 'Отключить назначения'),
(47175, 1674, 13, 'Отключить пользовательские группы'),
(47176, 1675, 13, 'отключено'),
(47177, 1676, 13, 'Отключено'),
(47178, 1677, 13, 'Инвалиды в возрасте до 65 лет с большим планом групповой охраны здоровья (LGHP)'),
(47179, 1678, 13, 'Сигнальный комплекс, индуцирующий смерть'),
(47180, 1681, 13, 'Отделяемое'),
(47181, 1682, 13, 'Выделения из уретры'),
(47182, 1684, 13, 'Выписан с выздоровлением'),
(47183, 1685, 13, 'Выписан с выздоровлением:'),
(47184, 1689, 13, 'Опубликованная информация'),
(47185, 1690, 13, 'Тип публикования'),
(47186, 1691, 13, 'Типы публикования'),
(47187, 1692, 13, 'Публикации'),
(47188, 1694, 13, 'Скидка'),
(47189, 1695, 13, 'Размер скидки'),
(47190, 1696, 13, 'Уровень скидки'),
(47191, 1697, 13, 'Процент скидки'),
(47192, 1698, 13, 'Скидка как денежная величина'),
(47193, 1699, 13, 'Скидка на расчетный час вводится как денежная сумма, а не проценты.'),
(47194, 1700, 13, 'Отдельный результат'),
(47195, 1701, 13, 'Болезнь'),
(47196, 1702, 13, 'Вывих'),
(47197, 1703, 13, 'Отпр. #'),
(47198, 1704, 13, 'Отправка'),
(47199, 1705, 13, 'Отправка полученного документа'),
(47200, 1706, 13, 'Предоставлено'),
(47201, 1707, 13, 'Отображение инструкций по заполнению на странице персональных данных.'),
(47202, 1709, 13, 'Отображать даты событий в блоке?'),
(47203, 1711, 13, 'Сколько событий отображать?'),
(47204, 1713, 13, 'Отображать размещение в блоке?'),
(47205, 1714, 13, 'Отображаемое наименование'),
(47206, 1715, 13, 'Отображать календарь?'),
(47207, 1718, 13, 'Отображать сегодняшние события в блоке?'),
(47208, 1719, 13, 'Отображать раздел в блоке?'),
(47209, 1720, 13, 'Отображать предстоящие события в блоке?'),
(47210, 1721, 13, 'Показать колонки'),
(47211, 1722, 13, 'Отображать это количество самых последних публикаций:'),
(47212, 1723, 13, 'Отображение указанного количества самых последних записей'),
(47213, 1724, 13, 'Отображать это количество самых последних записей:'),
(47214, 1725, 13, 'Распределение'),
(47215, 1726, 13, 'Распределения'),
(47216, 1727, 13, 'Поставщик'),
(47217, 1729, 13, 'Дивертикулит'),
(47218, 1730, 13, 'Хирургия дивертикулита'),
(47219, 1731, 13, 'Дивертикулит'),
(47220, 1732, 13, 'Хирургия дивертикулита'),
(47221, 1733, 13, 'Разведен'),
(47222, 1734, 13, 'Головокружения:'),
(47223, 1735, 13, 'Не менять'),
(47224, 1737, 13, 'Не отображать загрузку аллергии в NewCrop'),
(47225, 1739, 13, 'Не отображать загрузку медикаментов в NewCrop'),
(47226, 1742, 13, 'Не показывать календарь.'),
(47227, 1744, 13, 'Не инвентаризировать и не реализовывать никакую продукцию'),
(47228, 1745, 13, 'Не требует полномочий для записей по пациенту'),
(47229, 1746, 13, 'Указано не реанимировать'),
(47230, 1747, 13, 'не сохранять'),
(47231, 1748, 13, 'не заменять'),
(47232, 1749, 13, 'ничего не делать'),
(47233, 1751, 13, 'Действительно нужно удалить'),
(47234, 1752, 13, 'Действительно нужно удалить выбранное?'),
(47235, 1753, 13, 'Действительно нужно удалить эту группу'),
(47236, 1755, 13, 'Продолжить?'),
(47237, 1756, 13, 'Это нужно далить?'),
(47238, 1757, 13, 'Удалить?'),
(47239, 1758, 13, 'Удалить эту запись?'),
(47240, 1759, 13, 'Продолжить добавление нового пациента?'),
(47241, 1760, 13, 'Продолжить с новым наименованием?'),
(47242, 1761, 13, 'Эту запись по вакциинации нужно удалить НАВСЕГДА?'),
(47243, 1762, 13, 'Дата/рожд.'),
(47244, 1763, 13, 'Дата рождения пропущена, при возможности укажите'),
(47245, 1764, 13, 'Вр.'),
(47246, 1765, 13, 'Врач'),
(47247, 1766, 13, 'Врач:'),
(47248, 1767, 13, 'Фамилия и подпись врача'),
(47249, 1768, 13, 'Документ'),
(47250, 1769, 13, 'документ'),
(47251, 1770, 13, 'Категории документа'),
(47252, 1775, 13, 'Документ не может быть перемещен для пациента с id'),
(47253, 1777, 13, 'Дата регистрации'),
(47254, 1778, 13, 'Данные по регистрации и проблема обновлены успешно'),
(47255, 1779, 13, 'ID регистрации'),
(47256, 1780, 13, 'Документ перемещен в новую категорию'),
(47257, 1781, 13, 'Документ перемещен для пациента с id'),
(47258, 1783, 13, 'Документ проходит проверку целостности.'),
(47259, 1785, 13, 'Документ успешно переименован.'),
(47260, 1790, 13, 'Сохранение документа/изображения'),
(47261, 1791, 13, 'Документы'),
(47262, 1792, 13, 'Документы (write,addonly не обязателен)'),
(47263, 1794, 13, 'Одышка при физической нагрузке'),
(47264, 1798, 13, 'Этот тип допускает связанные коды?'),
(47265, 1799, 13, 'Отечественный партнер'),
(47266, 1800, 13, 'Не сохранять'),
(47267, 1801, 13, 'Не сохранять'),
(47268, 1802, 13, 'Не сохранять изменения'),
(47269, 1803, 13, 'Готово'),
(47270, 1804, 13, 'Выполнено с:'),
(47271, 1805, 13, 'Готово. Теперь будет отправлена загрузка.'),
(47272, 1806, 13, 'DOS'),
(47273, 1807, 13, 'Дозировка'),
(47274, 1809, 13, 'двойной щелчок для редактирования'),
(47275, 1810, 13, 'Двоение в глазах'),
(47276, 1811, 13, 'Загрузить'),
(47277, 1814, 13, 'Загрузить в любом случае'),
(47278, 1815, 13, 'Загружает файл счета, вносит для учетной записи и маркирует как оплату'),
(47279, 1817, 13, 'Загрузить сертификаты'),
(47280, 1818, 13, 'Загрузить данные настроек'),
(47281, 1820, 13, 'загружает шифрованный файл'),
(47282, 1827, 13, 'Загрузить выбранные заявки'),
(47283, 1828, 13, 'Регистрация д-ра'),
(47284, 1829, 13, 'Посещение д-ра'),
(47285, 1830, 13, 'Д-р'),
(47286, 1831, 13, 'Препарат для перемещения'),
(47287, 1832, 13, 'Подтекание мочи'),
(47288, 1833, 13, 'Водительские права или государственный ID'),
(47289, 1834, 13, 'Препарат'),
(47290, 1835, 13, 'Поисковик препаратов'),
(47291, 1836, 13, 'Формы препаратов'),
(47292, 1837, 13, 'ID препарата пропущен!'),
(47293, 1838, 13, 'Частота приема препарата'),
(47294, 1839, 13, 'Учет препарата'),
(47295, 1840, 13, 'Наименование препарата'),
(47296, 1841, 13, 'Способ введения препарата'),
(47297, 1845, 13, 'Единицы измерения препарата'),
(47298, 1846, 13, 'Препараты'),
(47299, 1847, 13, 'Препараты и изделия'),
(47300, 1848, 13, 'Сухость во рту'),
(47301, 1849, 13, 'Диагноз DSMIV'),
(47302, 1850, 13, 'Дифтеритический тетанус 1'),
(47303, 1851, 13, 'Дифтеритический тетанус 2'),
(47304, 1852, 13, 'Дифтеритический тетанус 3'),
(47305, 1853, 13, 'Дифтеритический тетанус 4'),
(47306, 1854, 13, 'Дифтеритический тетанус 5'),
(47307, 1855, 13, 'АКДС 1'),
(47308, 1856, 13, 'АКДС 2'),
(47309, 1857, 13, 'АКДС 3'),
(47310, 1858, 13, 'АКДС 4'),
(47311, 1859, 13, 'АКДС 5'),
(47312, 1860, 13, 'Подлежит выплате'),
(47313, 1861, 13, 'Дата оплаты'),
(47314, 1862, 13, 'Дата оплаты mm/dd/yyyy или yyyy-mm-dd'),
(47315, 1863, 13, 'Дата оплаты:'),
(47316, 1864, 13, 'Подлежит страх.'),
(47317, 1865, 13, 'Подлежит оплате'),
(47318, 1866, 13, 'Подлежит вскоре'),
(47319, 1867, 13, 'Назначенный статус');
INSERT INTO `lang_definitions` VALUES
(47320, 1868, 13, 'Обновление статуса оплаты'),
(47321, 1869, 13, 'Формирование дампа базы данных LibreEHR'),
(47322, 1870, 13, 'Формирование дампа дерева веб-каталога LibreEHR'),
(47323, 1871, 13, 'Формирование дампа базы данных phpGACL'),
(47324, 1872, 13, 'Формирование дампа дерева веб-каталога phpGACL'),
(47325, 1873, 13, 'Формирование дампа базы данных регистра SQL'),
(47326, 1874, 13, 'Формирование дампа дерева веб-каталога регистра SQL'),
(47327, 1875, 13, 'Проверка на дублирование'),
(47328, 1876, 13, 'Он-лайн дублирование ID'),
(47329, 1877, 13, 'Двойное имя в строке'),
(47330, 1878, 13, 'ПРЕДУПРЕЖДЕНИЕ О ДУБЛИРОВАНИИ'),
(47331, 1879, 13, 'Постоянный поверенный'),
(47332, 1880, 13, 'продолжительность'),
(47333, 1881, 13, 'Продолжительность'),
(47334, 1882, 13, 'Голландский'),
(47335, 1883, 13, 'Dx Rep'),
(47336, 1884, 13, 'Дисфагия'),
(47337, 1885, 13, 'Одышка:'),
(47338, 1886, 13, 'Дизурия'),
(47339, 1888, 13, 'Е-назначение?'),
(47340, 1890, 13, 'e-Rx'),
(47341, 1892, 13, 'Возобновление e-лечения'),
(47342, 1893, 13, 'Каждый получатель должен устанавливать свои собственные сообщения как выполненные.'),
(47343, 1894, 13, 'Ранний возврат (< 2 мес.)'),
(47344, 1895, 13, 'Уши'),
(47345, 1896, 13, 'ЭКГ'),
(47346, 1897, 13, 'e-требования'),
(47347, 1898, 13, 'Отек'),
(47348, 1902, 13, 'Файл EDI-271 обновлен'),
(47349, 1903, 13, 'Соответствующий файл EDI-271 обновлен'),
(47350, 1904, 13, 'Редактировать'),
(47351, 1905, 13, 'редактировать'),
(47352, 1906, 13, 'Редактировать аллергию'),
(47353, 1907, 13, 'Редактировать категории'),
(47354, 1908, 13, 'Редактировать определения'),
(47355, 1909, 13, 'Редактировать определения'),
(47356, 1910, 13, 'Редактировать диагнозы для'),
(47357, 1911, 13, 'Редактировать опубликование'),
(47358, 1912, 13, 'Редактировать услуги'),
(47359, 1913, 13, 'Редактировать услугу'),
(47360, 1914, 13, 'Редактировать информацию об услугах'),
(47361, 1915, 13, 'Редактировать информацию об услугах для отдельного пользователя'),
(47362, 1916, 13, 'Редактировать файл в'),
(47363, 1917, 13, 'Редактировать форму'),
(47364, 1918, 13, 'Редактировать глобальные настройки'),
(47365, 1919, 13, 'Редактирование не разрешено!'),
(47366, 1920, 13, 'Редактировать макет'),
(47367, 1921, 13, 'Редактировать список'),
(47368, 1922, 13, 'Редактировать платеж'),
(47369, 1923, 13, 'Редактировать структуру'),
(47370, 1924, 13, 'Редактировать пользователя'),
(47371, 1925, 13, 'Изменение параметров настройки пользователя'),
(47372, 1928, 13, 'Образование'),
(47373, 1929, 13, 'Дата получения образования'),
(47374, 1931, 13, 'эл. ред. * Подробнее см. Лицензию на свободное программное  обеспечение GNU. ** Вместе с этой программой вы должны  были получить экземпляр GPL GNU *; Если нет,  то пишите в свободном '),
(47375, 1932, 13, 'Фактическая дата'),
(47376, 1934, 13, 'Эффективность'),
(47377, 1935, 13, 'Идентификационный номер работодателя'),
(47378, 1936, 13, 'Эякуляции'),
(47379, 1937, 13, 'Локоть'),
(47380, 1938, 13, 'Проблемы локтя'),
(47381, 1939, 13, 'Электронный'),
(47382, 1942, 13, 'Электронные переводы'),
(47383, 1944, 13, 'Срок годности'),
(47384, 1945, 13, 'Срок годности запрошенной партии 270'),
(47385, 1946, 13, 'Преемственный ответ'),
(47386, 1947, 13, 'Статус пригодности для детской вакцины, имеющей срок годности'),
(47387, 1948, 13, 'Годная'),
(47388, 1949, 13, 'e-mail'),
(47389, 1951, 13, 'Адрес e-mail'),
(47390, 1953, 13, 'Адрес электронной почты отправителя для напоминаний о пациенте. Внесите, чтобы напоминания о пациенте направлялись на этот адрес. Важно использовать адрес домена вашей клиники во избежание предотвращения сбора напоминаний пациенту в папке нежелательной почты.'),
(47391, 1954, 13, 'Адрес e-mail, если имеется, для получения административных уведомлений.'),
(47392, 1955, 13, 'Адрес e-mail, если имеется, для получения экстренных сообщений об активации логин пользователя.'),
(47393, 1956, 13, 'Разр. email'),
(47394, 1957, 13, 'E-mail от пакетной обработки'),
(47395, 1958, 13, 'Уведомление об e-mail'),
(47396, 1959, 13, 'Часы уведомление об e-mail'),
(47397, 1960, 13, 'Отчет уведомлений об e-mail'),
(47398, 1961, 13, 'Отправить e-mail до'),
(47399, 1962, 13, 'Отправитель e-mail'),
(47400, 1963, 13, 'Отправка e-mail'),
(47401, 1964, 13, 'E-mail отправлено к'),
(47402, 1965, 13, 'Тема e-mail'),
(47403, 1966, 13, 'текст e-mail, употребляемый тэг: ***НАИМЕНОВАНИЕ*** , т.е. Уважаемый ***ИМЯ***'),
(47404, 1967, 13, 'Текст e-mail, употребляемый тэг: ***NAME*** , т.е. Уважаемый ***NAME***{{Не переводите элементы ***NAME*** этой константы.}}'),
(47405, 1968, 13, 'Метод передачи e-mail'),
(47406, 1969, 13, 'E-mail отправлен по следующим адресам'),
(47407, 1971, 13, 'Дополнительный контакт'),
(47408, 1972, 13, 'Дополнительный контакт'),
(47409, 1973, 13, 'Номер телефона для экстренной связи'),
(47410, 1974, 13, 'Вспомогательная контрацепция'),
(47411, 1975, 13, 'Вход в систему в чрезвычайной ситуации'),
(47412, 1976, 13, 'Выбран чрезвычайный вход в систему ACL. Пользователь все еще в активном состоянии, просьба деактивировать этого пользователя и также активировать, когда потребуется при чрезвычайной ситуации. Для активации или деактивации см. Администрирование-> Пользователи.'),
(47413, 1977, 13, 'Чрезвычайный e-mail активации входа в систему будет задействован, только если в файле interface/globals.php заданы следующие параметры:'),
(47414, 1978, 13, 'Адрес e-mail чрезвычайного входа в систему'),
(47415, 1979, 13, 'Пользователь чрезвычайного входа в систему может делать все'),
(47416, 1980, 13, 'Дополнительный телефон'),
(47417, 1982, 13, 'Эмфизема'),
(47418, 1983, 13, 'Служащий'),
(47419, 1984, 13, 'Место работы'),
(47420, 1985, 13, 'Адрес места работы'),
(47421, 1986, 13, 'Дата приема на работу'),
(47422, 1987, 13, 'Наименование места работы'),
(47423, 1988, 13, 'ПУСТОЕ'),
(47424, 1989, 13, 'Пустое'),
(47425, 1991, 13, 'Пустое значение в "Час e-mail"'),
(47426, 1992, 13, 'Пустое значение в "Отправитель e-mail"'),
(47427, 1993, 13, 'Пустое значение в "Субъект e-mail"'),
(47428, 1994, 13, 'Пустое значение в "Текст e-mail"'),
(47429, 1995, 13, 'Пустое значение для "Фамилия специалиста"'),
(47430, 1996, 13, 'Пустое значение в "Пароль"'),
(47431, 1997, 13, 'Пустое значение в "Час SMS"'),
(47432, 1998, 13, 'Пустое значение в "Текст SMS"'),
(47433, 1999, 13, 'Пустое значение для "Имя пользователя"'),
(47434, 2006, 13, 'Включить вызов AMC'),
(47435, 2008, 13, 'Включить отчет AMC'),
(47436, 2009, 13, 'Включить отслеживание AMC'),
(47437, 2011, 13, 'Включить аудит ATNA'),
(47438, 2013, 13, 'Включить аудит журналирования'),
(47439, 2014, 13, 'Включает отслеживание аудита и аутентификацию узла (ATNA).'),
(47440, 2015, 13, 'Включить отчетность автоматического вычисления единицы измерения (AMC)'),
(47441, 2016, 13, 'Включить клиентский SSL'),
(47442, 2017, 13, 'Включает аутентификацию сертификата SSL для клиента.'),
(47443, 2019, 13, 'Включить клинические правила заключений (CDR)'),
(47444, 2022, 13, 'Включить отчетность о клинической оценке качества (CQM)'),
(47445, 2023, 13, 'Включить всплывающие клинические напоминания'),
(47446, 2024, 13, 'Включить виджет для клинических напоминаний'),
(47447, 2027, 13, 'Включить отчетность CQM'),
(47448, 2031, 13, 'Включить поддержку Hylafax'),
(47449, 2033, 13, 'Включить сообщение статуса импорта для erx NewCrop'),
(47450, 2037, 13, 'Включить лабораторный обмен'),
(47451, 2040, 13, 'Включить журналирование всех запросов SELECT для SQL.'),
(47452, 2041, 13, 'Включить журналирование активности, связанной с резервным копированием.'),
(47453, 2043, 13, 'Включить журналирование смешанной активности.'),
(47454, 2044, 13, 'Включить журналирование активности назначений.'),
(47455, 2045, 13, 'Включить журналирование модификаций записей по пациентам.'),
(47456, 2046, 13, 'Включить журналирование активности планирования.'),
(47457, 2047, 13, 'Включить журналирование активности безопасности и администрирования.'),
(47458, 2049, 13, 'Включить службу eRx для NewCrop'),
(47459, 2051, 13, 'Включить портал для внешних пациентов'),
(47460, 2052, 13, 'Включает портал для внешних пациентов.'),
(47461, 2053, 13, 'Включить портал для внутренних пациентов'),
(47462, 2055, 13, 'Включает портал для внутренних пациентов.'),
(47463, 2056, 13, 'Включить виджет напоминаний для пациентов'),
(47464, 2058, 13, 'Включить приглашение ввода даты для автоматического вычисления единицы измерения (AMC)'),
(47465, 2060, 13, 'Включить отчетность об отслеживании даты для автоматического вычисления единицы измерения (AMC)'),
(47466, 2061, 13, 'Включить поддержку сканера'),
(47467, 2065, 13, 'Включает поддержку LibreEHR службой лабораторного обмена LLC.'),
(47468, 2066, 13, 'Включить аутентификацию пользовательского сертификата'),
(47469, 2067, 13, 'Включить службу eRx для ZMG, LLC'),
(47470, 2068, 13, 'включено'),
(47471, 2070, 13, 'Включает старую панель с оплатой для ввода кодов оплаты и платежей. Не рекомендуется, лучше используйте список оплаты.'),
(47472, 2071, 13, 'Обр.'),
(47473, 2072, 13, 'Обращ.'),
(47474, 2073, 13, 'Обращение'),
(47475, 2074, 13, 'обращение'),
(47476, 2075, 13, 'Обращение '),
(47477, 2076, 13, 'экстренное поступление пациента в стационар или ED'),
(47478, 2081, 13, 'Дата обращения'),
(47479, 2086, 13, 'Формы обращения'),
(47480, 2087, 13, 'Обращение по поводу здоровья и состояния'),
(47481, 2088, 13, 'Хронология обращений'),
(47482, 2089, 13, 'ID обращения'),
(47483, 2090, 13, 'обращение по поводу гриппа'),
(47484, 2091, 13, 'Количество обращений'),
(47485, 2093, 13, 'обращение к медсестре по поводу выписки'),
(47486, 2094, 13, 'обращение по поводу медсестринских услуг'),
(47487, 2095, 13, 'обращение по поводу трудотерапии'),
(47488, 2096, 13, 'обращение для посещения кабинете'),
(47489, 2097, 13, 'амбулаторное обращение'),
(47490, 2098, 13, 'амбулаторное обращение w/PCP & obgyn'),
(47491, 2099, 13, 'Размер страницы обращения'),
(47492, 2101, 13, 'Обращение по поводу беременности'),
(47493, 2102, 13, 'обращение по поводу профосмотра - индивидуальное собеседование'),
(47494, 2103, 13, 'обращение по поводу профсмотра в 40 лет и старше'),
(47495, 2104, 13, 'обращение по поводу профосмотра для группового собеседования'),
(47496, 2105, 13, 'обращение по поводу профосмотра для других услуг'),
(47497, 2106, 13, 'обращение по поводу профосмотра в 18 лет и старше'),
(47498, 2107, 13, 'обращение к психиатру и психологу'),
(47499, 2108, 13, 'Статистика по обращению'),
(47500, 2109, 13, 'Итог по обращению'),
(47501, 2110, 13, 'Обращение было шифровано'),
(47502, 2111, 13, 'Обращение:'),
(47503, 2112, 13, 'Обращение: при плановом поступлении пациента в стационар, амбулаторное или к окулисту'),
(47504, 2113, 13, 'Обращения'),
(47505, 2114, 13, 'Обращения и формы'),
(47506, 2115, 13, 'Обращения &amp; Формы'),
(47507, 2116, 13, 'Доступ к обращениям не разрешен'),
(47508, 2117, 13, 'Отчет по обращениям'),
(47509, 2118, 13, 'Раздел обращений'),
(47510, 2120, 13, 'Шифрование'),
(47511, 2121, 13, 'Конец'),
(47512, 2122, 13, 'Окончание (yyyy-mm-dd): '),
(47513, 2123, 13, 'Конечная дата'),
(47514, 2124, 13, 'Конечная дата'),
(47515, 2126, 13, 'Конечная дата должна быть позднее начальной'),
(47516, 2127, 13, 'Конечная дата:'),
(47517, 2131, 13, 'Конечное время'),
(47518, 2132, 13, 'Лицо с терминальной стадией ХПН в MCP с групповым планом работодателя'),
(47519, 2133, 13, 'Конечная дата оказания услуги yyyy-mm-dd'),
(47520, 2134, 13, 'Если нужно ввести диапазон, завершите mm/dd/yyyy DOS'),
(47521, 2135, 13, 'Завершающий час дня для календарных событий.'),
(47522, 2136, 13, 'Глубокое отклонение от нормы крови'),
(47523, 2137, 13, 'Эндокринная'),
(47524, 2138, 13, 'Эндоскопия'),
(47525, 2141, 13, 'Английский'),
(47526, 2142, 13, 'Английский '),
(47527, 2143, 13, 'Английский (индийский)'),
(47528, 2144, 13, 'Английский (стандартный)'),
(47529, 2145, 13, 'Шифровать команду, используя Hylafax.'),
(47530, 2146, 13, 'Убедитесь, что LibreEHR имеет права записи в каталог'),
(47531, 2147, 13, 'Отделяемое ЛОР'),
(47532, 2148, 13, 'Отоларингологические боли'),
(47533, 2149, 13, 'Введите код диагноза для исключения всех счетов, не содержащих его'),
(47534, 2151, 13, 'Введите здесь тело письма'),
(47535, 2152, 13, 'Введите пароль для root базы данных'),
(47536, 2153, 13, 'Введите имя пользователя root базы данных'),
(47537, 2154, 13, 'Введите диагноз'),
(47538, 2155, 13, 'Введите препараты'),
(47539, 2158, 13, 'Введите вакцинацию'),
(47540, 2159, 13, 'Введите ключ'),
(47541, 2161, 13, 'Введите новую область (край)'),
(47542, 2164, 13, 'Введите этот код повторной идентификации'),
(47543, 2165, 13, 'Выше введите критерий поиска'),
(47544, 2168, 13, 'Окружение'),
(47545, 2169, 13, 'Ввод данных EOB'),
(47546, 2170, 13, 'Отправка EOB - электронные переводы'),
(47547, 2171, 13, 'Отправка EOB - инструкции'),
(47548, 2172, 13, 'Отправка EOB - счет'),
(47549, 2173, 13, 'Отправка EOB - запись по пациенту'),
(47550, 2174, 13, 'Отправка EOB - поиск'),
(47551, 2176, 13, 'Эпилепсия'),
(47552, 2178, 13, 'Европейская ассоциация специалистов в области заболеваний почек'),
(47553, 2180, 13, 'Отправка в ERA'),
(47554, 2181, 13, 'Аннулировать'),
(47555, 2182, 13, 'Эрекции'),
(47556, 2183, 13, 'Ошибка'),
(47557, 2185, 13, 'Подтверждение ошибки при получении лабораторных результатов'),
(47558, 2187, 13, 'Ошибка получения лабораторных результатов из Lab Exchange Network'),
(47559, 2188, 13, 'Ошибка в выборе "Пол"'),
(47560, 2189, 13, 'Ошибка в выборе "HIPAA"'),
(47561, 2190, 13, 'Ошибка в выборе "Обработка"'),
(47562, 2191, 13, 'Ошибка в выборе "Шлюз SMS"'),
(47563, 2192, 13, 'Ошибка в выборе "Сортировать по"'),
(47564, 2193, 13, 'Ошибка gzip-сжатия файла: '),
(47565, 2194, 13, 'Ошибка для опции ДА или НЕТ'),
(47566, 2195, 13, 'Ошибка открытия на чтение загруженного файла'),
(47567, 2198, 13, 'Удаленное сообщение об ошибке'),
(47568, 2199, 13, 'Ошибка исправления результатов из Lab Exchange Network'),
(47569, 2202, 13, 'Ошибка при предоставлении прав доступа к файлу для пользователя LibreEHR.'),
(47570, 2205, 13, 'ошибка при регистрации формы!'),
(47571, 2206, 13, 'Ошибка сохранения в файл'),
(47572, 2208, 13, 'Ошибка записи в файл'),
(47573, 2210, 13, 'Ошибка, файл не существует'),
(47574, 2211, 13, 'ОШИБКА, невозможно собрать данные с сервера'),
(47575, 2212, 13, 'Ошибка, невозможно создать клиентский сертификат'),
(47576, 2213, 13, 'Ошибка, невозможно создать сертификат admin.p12.'),
(47577, 2214, 13, 'Ошибка, невозможно создать доверенный сертификат Certificate.'),
(47578, 2215, 13, 'Ошибка, невозможно создать сертификат сервера.'),
(47579, 2216, 13, 'Ошибка, невозможно открыть файл'),
(47580, 2217, 13, 'Ошибка, в LibreEHR не включена аутентификация сертификата пользователя'),
(47581, 2218, 13, 'Ошибка, необходимо установить модуль php Archive/Tar.php.'),
(47582, 2219, 13, 'ОШИБКА: не удалось открыть table.sql, поврежденная форма?'),
(47583, 2220, 13, 'Ошибка: в строке дублированный ID'),
(47584, 2221, 13, 'Ошибка: в строке дублированное имя'),
(47585, 2222, 13, 'ОШИБКА: поле'),
(47586, 2223, 13, 'ОШИБКА: пропущенный модуль PHP для ZipArchive'),
(47587, 2225, 13, 'Ошибка: пароль не соответствует. Проверьте свой ввод.'),
(47588, 2226, 13, 'Ошибка: пароль не соответствует. Проверьте свой ввод.'),
(47589, 2227, 13, 'Ошибка: файл не существует'),
(47590, 2229, 13, 'ОШИБКА: невозможно копировать этот файл.'),
(47591, 2230, 13, 'Ошибка: создание архива загрузки не доступно'),
(47592, 2231, 13, 'Ошибка: создание архива Zip не доступно.'),
(47593, 2232, 13, 'ОШИБКА: извлечение этого файла не доступно.'),
(47594, 2233, 13, 'ОШИБКА: загрузка этого файла в базу данных не доступна.'),
(47595, 2234, 13, 'ОШИБКА: установка номера версии не доступна.'),
(47596, 2235, 13, 'Ошибки'),
(47597, 2236, 13, 'Статус аккаунта eRx'),
(47598, 2237, 13, 'Журналы eRx'),
(47599, 2238, 13, 'Имя ERX'),
(47600, 2239, 13, 'Пароль ERX'),
(47601, 2240, 13, 'Уровень доступа ERX'),
(47602, 2241, 13, 'Пользователь ERX'),
(47603, 2242, 13, 'Эритема:'),
(47604, 2245, 13, 'Эскимосский'),
(47605, 2247, 13, 'Зарегистрированный пациент'),
(47606, 2249, 13, 'Этническая принадлежность'),
(47607, 2250, 13, 'Этническая принадлежность или раса'),
(47608, 2251, 13, 'Список этносов-рас (write,addonly не обязателен)'),
(47609, 2252, 13, 'ETIN'),
(47610, 2253, 13, 'Событие'),
(47611, 2254, 13, 'Начало события'),
(47612, 2255, 13, 'Категория события'),
(47613, 2256, 13, 'Дата события'),
(47614, 2257, 13, 'Описание события'),
(47615, 2258, 13, 'Сведения о событии'),
(47616, 2259, 13, 'Событие не повторяется'),
(47617, 2260, 13, 'Продолжительность события'),
(47618, 2261, 13, 'Продолжительность события в минутах'),
(47619, 2262, 13, 'Оплата по факту'),
(47620, 2263, 13, 'Место проведения'),
(47621, 2264, 13, 'Событие повторяется каждые'),
(47622, 2265, 13, 'Событие повторяется в'),
(47623, 2266, 13, 'Начальное время события'),
(47624, 2267, 13, 'Обозначение события'),
(47625, 2268, 13, 'Обозначение события'),
(47626, 2269, 13, 'Фактический веб-сайт'),
(47627, 2270, 13, 'События'),
(47628, 2271, 13, 'События для'),
(47629, 2272, 13, 'Открывать события в новом окне'),
(47630, 2273, 13, 'каждый'),
(47631, 2274, 13, 'Каждые'),
(47632, 2275, 13, 'каждые 3 часа'),
(47633, 2276, 13, 'каждые 4 часа'),
(47634, 2277, 13, 'каждые 5 часа'),
(47635, 2278, 13, 'каждые 6 часа'),
(47636, 2279, 13, 'каждые 8 часа'),
(47637, 2280, 13, 'Каждый четвертый'),
(47638, 2281, 13, 'Каждый второй'),
(47639, 2282, 13, 'Каждый третий'),
(47640, 2283, 13, 'Каждый, каждый второй, каждый третий и т.д.'),
(47641, 2285, 13, 'Результаты исследований и анализов'),
(47642, 2286, 13, 'Результаты обследования'),
(47643, 2289, 13, 'Обследование'),
(47644, 2290, 13, 'Дата обследования'),
(47645, 2291, 13, 'Пример'),
(47646, 2292, 13, 'Примеры'),
(47647, 2293, 13, 'Исследования/анализы'),
(47648, 2294, 13, 'кроме'),
(47649, 2295, 13, 'Слезоточивость'),
(47650, 2296, 13, 'Исключенный пациент'),
(47651, 2297, 13, 'Исключение'),
(47652, 2298, 13, 'Лицензированное специализированное учреждение (EPO)'),
(47653, 2299, 13, 'Рабочий размер бумаги'),
(47654, 2300, 13, 'Упражнение'),
(47655, 2301, 13, 'Примеры упражнений'),
(47656, 2302, 13, 'Примеры упражнений'),
(47657, 2303, 13, 'Сущестествующее'),
(47658, 2304, 13, 'Выйти из администрирования'),
(47659, 2305, 13, 'Расш.'),
(47660, 2306, 13, 'Развернуть'),
(47661, 2307, 13, 'развернуть'),
(47662, 2308, 13, 'Развернуть всё'),
(47663, 2311, 13, 'Развёрнутый вид'),
(47664, 2312, 13, 'Отметьте form_encounter.pid для '),
(47665, 2313, 13, 'Срок действия'),
(47666, 2314, 13, 'Дата годности'),
(47667, 2315, 13, 'Просрочено'),
(47668, 2316, 13, 'просрочено на'),
(47669, 2317, 13, 'Экспорт'),
(47670, 2318, 13, 'Экспортировать как CSV'),
(47671, 2319, 13, 'Экспорт конфигурации'),
(47672, 2322, 13, 'Экспорт персональных данных пациента'),
(47673, 2323, 13, 'Экспорт отчета PQRI'),
(47674, 2325, 13, 'Экспортировать выбранное, как CSV'),
(47675, 2326, 13, 'Экспортировать выбранное для сбора'),
(47676, 2327, 13, 'Экспорт в CSV'),
(47677, 2328, 13, 'Экспорт во внешнюю биллинговую систему'),
(47678, 2329, 13, 'Поездки за рубеж'),
(47679, 2330, 13, 'Поездки за рубеж'),
(47680, 2331, 13, 'Внеш. время сбора'),
(47681, 2332, 13, 'Внешний'),
(47682, 2336, 13, 'Внешний ID'),
(47683, 2337, 13, 'Внешний id'),
(47684, 2338, 13, 'Внешний идентификатор'),
(47685, 2339, 13, 'Только внешний'),
(47686, 2342, 13, 'Внешнее направление'),
(47687, 2343, 13, 'Контроль внешнего направления'),
(47688, 2344, 13, 'Направление внешнее?'),
(47689, 2345, 13, 'Внешние направления'),
(47690, 2346, 13, 'Извлечение файла zip'),
(47691, 2347, 13, 'Извлечение этого файла. Займет некоторое время...'),
(47692, 2348, 13, 'Отделяемое:'),
(47693, 2349, 13, 'Раздражение глаз'),
(47694, 2350, 13, 'Боль в глазах'),
(47695, 2351, 13, 'Гиперемия глаз'),
(47696, 2352, 13, 'Зрение'),
(47697, 2353, 13, 'F'),
(47698, 2354, 13, 'Гематологические проблемы F/H'),
(47699, 2355, 13, 'Женский F/H гирсутизм или стрии'),
(47700, 2356, 13, 'Учреждения'),
(47701, 2357, 13, 'Учреждение'),
(47702, 2358, 13, 'учреждение'),
(47703, 2359, 13, 'Управление услугами'),
(47704, 2360, 13, 'Город оказания услуги'),
(47705, 2361, 13, 'Код услуги'),
(47706, 2362, 13, 'Код страны оказания помощи'),
(47707, 2363, 13, 'Возможность факса'),
(47708, 2364, 13, 'Наименование услуги'),
(47709, 2365, 13, 'Общегосударственный номер-идентификатор агента, предоставляющего медицинские услуги'),
(47710, 2366, 13, 'Телефон службы'),
(47711, 2368, 13, 'Область (край) для службы'),
(47712, 2369, 13, 'Улица для службы'),
(47713, 2370, 13, 'Почтовый индекс для службы'),
(47714, 2372, 13, 'Учреждение:'),
(47715, 2373, 13, 'ДАЕТ СБОЙ'),
(47716, 2374, 13, 'давшее сбой'),
(47717, 2375, 13, 'Давшее сбой'),
(47718, 2383, 13, 'сбой'),
(47719, 2390, 13, 'Семейный анамнез'),
(47720, 2391, 13, 'Семейный анамнез по глаукоме'),
(47721, 2392, 13, 'Семейный анамнез:'),
(47722, 2394, 13, 'Семейная оплата'),
(47723, 2395, 13, 'Размер семьи'),
(47724, 2396, 13, 'Представить'),
(47725, 2398, 13, 'Фарси'),
(47726, 2400, 13, 'Отец'),
(47727, 2402, 13, 'Утомляемость'),
(47728, 2403, 13, 'Утомленный'),
(47729, 2404, 13, 'Факс'),
(47730, 2405, 13, 'Количество факсов'),
(47731, 2406, 13, 'Номер факса'),
(47732, 2408, 13, 'Факс/сканер'),
(47733, 2409, 13, 'Принять через факс'),
(47734, 2410, 13, 'Отправить через факс'),
(47735, 2411, 13, 'Возможности'),
(47736, 2412, 13, 'Фев'),
(47737, 2413, 13, 'Февраль'),
(47738, 2414, 13, 'FECA'),
(47739, 2415, 13, 'Государственный ID препарата'),
(47740, 2416, 13, 'Государственный EIN'),
(47741, 2417, 13, 'Государственный налоговый идентификатор'),
(47742, 2418, 13, 'Плата'),
(47743, 2419, 13, 'плата'),
(47744, 2420, 13, 'Плата не разрешена'),
(47745, 2421, 13, 'Платежный лист'),
(47746, 2422, 13, 'Варианты платежных ведомостей'),
(47747, 2423, 13, 'Платежи'),
(47748, 2424, 13, 'женский'),
(47749, 2425, 13, 'Женская стенокардия'),
(47750, 2426, 13, 'Женские кондомы'),
(47751, 2427, 13, 'Женский G'),
(47752, 2428, 13, 'Женский LC'),
(47753, 2429, 13, 'Женский P'),
(47754, 2430, 13, 'Женские симптомы'),
(47755, 2431, 13, 'Женский VSC'),
(47756, 2434, 13, 'Лихорадка'),
(47757, 2435, 13, 'Лихорадка:'),
(47758, 2436, 13, 'Проблемы крови FH'),
(47759, 2437, 13, 'Фибромы'),
(47760, 2441, 13, 'Тип поля для использования страны работодателя или потребителя в персональных данных.'),
(47761, 2442, 13, 'Тип поля для использования области (края) места работы или потребителя в персональных данных.'),
(47762, 2443, 13, 'Пропущено поле(я)!'),
(47763, 2447, 13, 'Файл'),
(47764, 2448, 13, 'файл в директории Documentation для изучения, как автоматизировать процесс создания журнала резервного копирования'),
(47765, 2449, 13, 'расположение файла'),
(47766, 2450, 13, 'Управление файлом'),
(47767, 2453, 13, 'Право на файл, предоставленное пользователю LibreEHR.'),
(47768, 2455, 13, 'Регистратура'),
(47769, 2456, 13, 'Файл для загрузки'),
(47770, 2458, 13, 'В этом месте уже имеется файл с таким именем:'),
(47771, 2459, 13, 'Имя файла'),
(47772, 2461, 13, 'Файлы'),
(47773, 2462, 13, 'Филиппинский'),
(47774, 2463, 13, 'Заполните ниже любую из строк'),
(47775, 2464, 13, 'Заполните здесь, только если отправляете пациенту сообщение через e-mail'),
(47776, 2465, 13, 'Заполните ниже значения'),
(47777, 2467, 13, 'Заполните эту строку.'),
(47778, 2468, 13, 'Фильтр'),
(47779, 2469, 13, 'Фильтр для констант'),
(47780, 2470, 13, 'Фильтр для определений'),
(47781, 2472, 13, 'фильтры'),
(47782, 2473, 13, 'Фильтры'),
(47783, 2474, 13, 'Конечный'),
(47784, 2475, 13, 'Окончательный диагноз'),
(47785, 2476, 13, 'Окончательный диагноз специалиста'),
(47786, 2478, 13, 'Финансовый'),
(47787, 2479, 13, 'Дата финансового закрытия (yyyy-mm-dd)'),
(47788, 2480, 13, 'Финансовое сообщение - любое'),
(47789, 2481, 13, 'Финансовое сообщение - мои обращения'),
(47790, 2482, 13, 'Дата финансового рассмотрения'),
(47791, 2484, 13, 'Найти'),
(47792, 2485, 13, 'Найти доступные'),
(47793, 2486, 13, 'Найти доступные записи на прием'),
(47794, 2487, 13, 'Найти пациента'),
(47795, 2488, 13, 'Найти рекомендательные материалы для пациента'),
(47796, 2489, 13, 'Найденное'),
(47797, 2490, 13, 'Найденное по специалисту'),
(47798, 2491, 13, 'Штраф'),
(47799, 2492, 13, 'Окончательные платежи'),
(47800, 2495, 13, 'Впервые'),
(47801, 2497, 13, 'Первый день недели'),
(47802, 2498, 13, 'Имя'),
(47803, 2499, 13, 'Имя'),
(47804, 2500, 13, 'Имя:'),
(47805, 2503, 13, 'Физическая подготовка'),
(47806, 2504, 13, 'Уровень физической подготовки'),
(47807, 2505, 13, 'Уровень физической подготовки для этого игрока в этот день'),
(47808, 2507, 13, 'Физическая подготовка к игре'),
(47809, 2508, 13, 'Установленные даты обращения - любые обращения'),
(47810, 2509, 13, 'Установите это'),
(47811, 2510, 13, 'Длина бедер'),
(47812, 2511, 13, 'Метеоризм'),
(47813, 2512, 13, 'Менструация'),
(47814, 2514, 13, 'Эпидемический сезон'),
(47815, 2515, 13, 'эпидемический сезон'),
(47816, 2516, 13, 'Прививка от гриппа'),
(47817, 2517, 13, 'Проблема водно-электролитного баланса'),
(47818, 2518, 13, 'Синдром фибромиалгии'),
(47819, 2519, 13, 'Книжный размер бумаги'),
(47820, 2520, 13, 'Выполнить вручную'),
(47821, 2522, 13, 'Последующее'),
(47822, 2524, 13, 'Выявленная причина'),
(47823, 2525, 13, 'Вот новая пользовательская константа:'),
(47824, 2526, 13, 'Вот новый пользовательский язык:'),
(47825, 2527, 13, 'Вот новое определение (язык, константа, определение):'),
(47826, 2529, 13, 'Оказываемые виды помощи'),
(47827, 2530, 13, 'Указываемые в последующем'),
(47828, 2531, 13, 'Отвращение к пище'),
(47829, 2532, 13, 'Нога'),
(47830, 2533, 13, 'Проблемы ног'),
(47831, 2534, 13, 'Нога:'),
(47832, 2535, 13, 'Футбольные травмы'),
(47833, 2537, 13, 'Сообщение о футбольной травме'),
(47834, 2538, 13, 'Тип обуви'),
(47835, 2539, 13, 'для'),
(47836, 2540, 13, 'Для'),
(47837, 2541, 13, 'Для кода'),
(47838, 2543, 13, 'Для требований по обращению'),
(47839, 2544, 13, 'Например:'),
(47840, 2547, 13, 'для счета'),
(47841, 2548, 13, 'Только для бесплатной медицинской помощи, вызывает консультанта как назначенного врача.'),
(47842, 2552, 13, 'Для направляющих учреждений/практикующих врачей'),
(47843, 2553, 13, 'для прошлых'),
(47844, 2554, 13, 'для переменных'),
(47845, 2555, 13, 'для:'),
(47846, 2556, 13, 'Вызывает открытие биллингового виджета'),
(47847, 2557, 13, 'Вызывает оформление нового пациента'),
(47848, 2559, 13, 'Предплечье'),
(47849, 2560, 13, 'Форма'),
(47850, 2561, 13, 'форма'),
(47851, 2564, 13, 'Формат'),
(47852, 2565, 13, 'формат'),
(47853, 2567, 13, 'Неправильный формат для NDC'),
(47854, 2568, 13, 'Формат, используемый для отображения большинства дат.'),
(47855, 2569, 13, 'Формат, используемый для отображения большей части временного интервала суток.'),
(47856, 2570, 13, 'Отформатированное сообщение'),
(47857, 2571, 13, 'Бывший курильщик'),
(47858, 2572, 13, 'Формы'),
(47859, 2573, 13, 'Управление формами'),
(47860, 2575, 13, 'Далее'),
(47861, 2576, 13, 'Направить страницы через факс'),
(47862, 2577, 13, 'Отправленный'),
(47863, 2579, 13, 'Четвертый'),
(47864, 2581, 13, 'Перелом'),
(47865, 2582, 13, 'Перелом ладьевидной кости'),
(47866, 2583, 13, 'Перелом латеральной лодыжки'),
(47867, 2584, 13, 'Перелом медиальной лодыжки'),
(47868, 2585, 13, 'Перелом основания пятой (5-й) метатарсальной кости'),
(47869, 2587, 13, 'Французский'),
(47870, 2588, 13, 'Французский (Канадский)'),
(47871, 2589, 13, 'Французский (стандартный)'),
(47872, 2590, 13, 'Учащенное мочеиспускание'),
(47873, 2591, 13, 'Частые простуды'),
(47874, 2592, 13, 'Частые заболевания'),
(47875, 2593, 13, 'Пт'),
(47876, 2594, 13, 'Пятница'),
(47877, 2595, 13, 'с'),
(47878, 2596, 13, 'с'),
(47879, 2597, 13, 'от'),
(47880, 2598, 13, 'Дата "с" не может быть позднее даты "по".'),
(47881, 2599, 13, 'с:'),
(47882, 2600, 13, 'с: '),
(47883, 2601, 13, 'FROM_CITY'),
(47884, 2603, 13, 'FROM_FNAME'),
(47885, 2604, 13, 'FROM_LNAME'),
(47886, 2605, 13, 'FROM_MNAME'),
(47887, 2607, 13, 'FROM_PHONECELL'),
(47888, 2608, 13, 'FROM_POSTAL'),
(47889, 2609, 13, 'FROM_STATE'),
(47890, 2610, 13, 'FROM_STREET'),
(47891, 2611, 13, 'FROM_TITLE'),
(47892, 2612, 13, 'FROM_VALEDICTORY'),
(47893, 2613, 13, 'Регистратура'),
(47894, 2614, 13, 'Прием в регистратуре'),
(47895, 2615, 13, 'Отчет о приеме в регистратуре'),
(47896, 2616, 13, 'Прием рег.'),
(47897, 2617, 13, 'Прямое право:'),
(47898, 2619, 13, 'Полное имя'),
(47899, 2620, 13, 'Полный путь в директорию, содержащую исполняемые MySQL.'),
(47900, 2621, 13, 'Полный путь в директорию, содержащую исполняемые Perl.'),
(47901, 2622, 13, 'Полный путь в директорию для журнала резервного копирования события.'),
(47902, 2623, 13, 'Для временных файлов использован полный путь в директорию.'),
(47903, 2624, 13, 'Полное воспроизведение'),
(47904, 2625, 13, 'Полное обучение'),
(47905, 2626, 13, 'Полная оплата'),
(47906, 2633, 13, 'G'),
(47907, 2634, 13, 'г/дл'),
(47908, 2636, 13, 'Состояние желчного пузыря'),
(47909, 2637, 13, 'ЖКБ'),
(47910, 2638, 13, 'Длительность воспроизведения'),
(47911, 2639, 13, 'Игры'),
(47912, 2640, 13, 'Воспроизведение пропущено'),
(47913, 2641, 13, 'воспроизведение/события'),
(47914, 2642, 13, 'Воспроизведение/события пропущено'),
(47915, 2644, 13, 'Гастрит'),
(47916, 2645, 13, 'Гастритическая боль'),
(47917, 2646, 13, 'Органы ЖКТ'),
(47918, 2647, 13, 'Статистический отчет GCAC'),
(47919, 2648, 13, 'Статистика GCAC'),
(47920, 2649, 13, 'Форма посещения GCAC пропущена'),
(47921, 2650, 13, 'Пол'),
(47922, 2651, 13, 'Пол '),
(47923, 2652, 13, 'общее'),
(47924, 2655, 13, 'Категория основной услуги'),
(47925, 2657, 13, 'Создать и загрузить бумажное требование CMS 1500'),
(47926, 2658, 13, 'Создать и загрузить бумажное требование HCFA 1500'),
(47927, 2659, 13, 'Создать и загрузить пакет X12'),
(47928, 2660, 13, 'Создать и загрузить затребованный пакет X12 для обращения'),
(47929, 2663, 13, 'Создает и передает в электронном виде разрешенные назначения.'),
(47930, 2664, 13, 'Создать CMS 1500'),
(47931, 2665, 13, 'Создать CMS 1500 PDF'),
(47932, 2666, 13, 'Создать CMS 1500 TEXT'),
(47933, 2667, 13, 'Создать HCFA'),
(47934, 2669, 13, 'Создать письмо'),
(47935, 2670, 13, 'Создать письмо по вопросу '),
(47936, 2671, 13, 'Создать отчет PQRI (Метод A)'),
(47937, 2673, 13, 'Создать отчет PQRI (Метод E)'),
(47938, 2677, 13, 'Генерировать отчет'),
(47939, 2678, 13, 'Создает имя пользователя и пароль для'),
(47940, 2679, 13, 'Генерировать X12'),
(47941, 2680, 13, 'Генерировать обращение X12'),
(47942, 2682, 13, 'Создать в'),
(47943, 2683, 13, 'Создано'),
(47944, 2684, 13, 'Мочеполовая'),
(47945, 2687, 13, 'Немецкий'),
(47946, 2691, 13, 'Получить HL7'),
(47947, 2692, 13, 'Глаукома'),
(47948, 2693, 13, 'Семейный анамнез по глаукоме'),
(47949, 2694, 13, 'Глобальное'),
(47950, 2696, 13, 'Глобальный ID'),
(47951, 2697, 13, 'Глобальные настройки'),
(47952, 2698, 13, 'Глобальные переменные'),
(47953, 2699, 13, 'гр/дл'),
(47954, 2700, 13, 'далее'),
(47955, 2701, 13, 'Далее'),
(47956, 2704, 13, 'Перейти в'),
(47957, 2705, 13, 'Перейти к неделе'),
(47958, 2706, 13, 'Перейти к сегодня'),
(47959, 2711, 13, 'Тяжесть травмы'),
(47960, 2712, 13, 'Степень'),
(47961, 2713, 13, 'граммы'),
(47962, 2714, 13, 'Общее количество'),
(47963, 2715, 13, 'Общее количество'),
(47964, 2718, 13, 'Отображаемое графически'),
(47965, 2720, 13, 'Больше, чем'),
(47966, 2721, 13, 'Больше, чем или равно'),
(47967, 2722, 13, 'Греческий'),
(47968, 2724, 13, 'Группа'),
(47969, 2725, 13, 'Имя группы'),
(47970, 2726, 13, 'Имена групп не могут быть пустым'),
(47971, 2727, 13, 'Имена группы не могут начинаться с числа или пробела.'),
(47972, 2728, 13, 'Имена группы не могут начинаться с чисел.'),
(47973, 2729, 13, 'Номер группы'),
(47974, 2730, 13, 'Групповая оплата'),
(47975, 2731, 13, 'Группа:'),
(47976, 2732, 13, 'Имя группы'),
(47977, 2733, 13, 'Группы и управление доступом'),
(47978, 2734, 13, 'Кривая роста'),
(47979, 2735, 13, 'Диаграмма роста'),
(47980, 2736, 13, 'gtts (капли)'),
(47981, 2737, 13, 'Гуамский'),
(47982, 2739, 13, 'Фамилия опекуна'),
(47983, 2741, 13, 'Гинекологическое обследование'),
(47984, 2742, 13, 'ч'),
(47985, 2743, 13, 'время сна'),
(47986, 2744, 13, 'Гепатиты H/O'),
(47987, 2745, 13, 'был успешно удален. Любые подкатегории, если представлены, были перемещены ниже'),
(47988, 2746, 13, 'Гематома / ушиб'),
(47989, 2747, 13, 'Состояние ингибирования гемагглютинации'),
(47990, 2750, 13, 'Рука + пальцы'),
(47991, 2751, 13, 'Проблемы рук'),
(47992, 2753, 13, 'Без затруднений'),
(47993, 2754, 13, 'было связано с посещением'),
(47994, 2755, 13, 'с истекшим сроком'),
(47995, 2756, 13, 'Хэш'),
(47996, 2757, 13, 'Для этого файла хеш не существует. Будет создан новый хеш.'),
(47997, 2758, 13, 'Хэш не соответствует. Целостность данных скомпроментирована.'),
(47998, 2760, 13, 'Гавайский'),
(47999, 2761, 13, 'Опасная деятельность'),
(48000, 2762, 13, 'Опасная деятельность'),
(48001, 2763, 13, 'Левое поле HCFA в точках'),
(48002, 2764, 13, 'Поля HCFA'),
(48003, 2765, 13, 'Верхнее поле HCFA в точках'),
(48004, 2767, 13, 'he PostCalendar '),
(48005, 2768, 13, 'Голова'),
(48006, 2769, 13, 'Окр. головы'),
(48007, 2770, 13, 'Окружность головы'),
(48008, 2771, 13, 'Головная боль'),
(48009, 2772, 13, 'Головные боли'),
(48010, 2773, 13, 'Медицинские операции'),
(48011, 2774, 13, 'Мероприятия по охране здоровья'),
(48012, 2775, 13, 'Медицинский центр/клиника'),
(48013, 2776, 13, 'Учреждение по оказанию медицинской помощи'),
(48014, 2777, 13, 'Страховой риск для учреждений по оказанию медицинской помощи (HMO)'),
(48015, 2778, 13, 'Потеря слуха'),
(48016, 2779, 13, 'Инфаркт миокарда'),
(48017, 2780, 13, 'Порок сердца'),
(48018, 2781, 13, 'Сердечная недостаточность'),
(48019, 2782, 13, 'Кардиальная проблема'),
(48020, 2783, 13, 'Кардиальные проблемы'),
(48021, 2784, 13, 'Кардиохирургия'),
(48022, 2785, 13, 'Пересадка сердца'),
(48023, 2786, 13, 'СЕРДЦЕ:'),
(48024, 2787, 13, 'Изжога'),
(48025, 2788, 13, 'Жар или озноб'),
(48026, 2789, 13, 'Жар или озноб'),
(48027, 2791, 13, 'Иврит'),
(48028, 2793, 13, 'ЛОР'),
(48029, 2794, 13, 'Рост'),
(48030, 2796, 13, 'Справка'),
(48031, 2797, 13, 'справка'),
(48032, 2798, 13, 'Рвота кровью'),
(48033, 2799, 13, 'Кровавый стул'),
(48034, 2800, 13, 'Гематология'),
(48035, 2801, 13, 'Гематурия'),
(48036, 2802, 13, 'Гемоглобин'),
(48037, 2803, 13, 'Гемоглобин A1C'),
(48038, 2804, 13, 'Кровохарканье'),
(48039, 2805, 13, 'Гепатит'),
(48040, 2806, 13, 'Гепатит A 1'),
(48041, 2807, 13, 'Гепатит A 2'),
(48042, 2808, 13, 'Гепатит B 1'),
(48043, 2809, 13, 'Гепатит B 2'),
(48044, 2810, 13, 'Гепатит B 3'),
(48045, 2811, 13, 'здесь'),
(48046, 2813, 13, 'Герниопластика'),
(48047, 2814, 13, 'Грыжа диска'),
(48048, 2815, 13, 'Герпес'),
(48049, 2816, 13, 'Затрудненное начало мочеиспускания'),
(48050, 2817, 13, 'эй. вы здесь для '),
(48051, 2818, 13, 'Hib-вакцина 1'),
(48052, 2819, 13, 'Hib-вакцина 2'),
(48053, 2820, 13, 'Hib-вакцина 3'),
(48054, 2821, 13, 'Hib-вакцина 4'),
(48055, 2822, 13, 'Скрытый'),
(48056, 2823, 13, 'Управление скрытыми событиями'),
(48057, 2824, 13, 'Скрыть'),
(48058, 2825, 13, 'Скрыть сведения'),
(48059, 2827, 13, 'Скрыть опции шифрования/дешифрования в управлении документом'),
(48060, 2828, 13, 'Скрыть меню'),
(48061, 2830, 13, 'Скрыть напоминания'),
(48062, 2831, 13, 'Скрыть/показать столбцы'),
(48063, 2833, 13, 'высокая'),
(48064, 2834, 13, 'Повышенное артериальное давление'),
(48065, 2835, 13, 'Хинди'),
(48066, 2836, 13, 'Бедро + пах'),
(48067, 2837, 13, 'Бедро и пах'),
(48068, 2838, 13, 'Проблемы бедра'),
(48069, 2839, 13, 'Замещение тазобедренного сустава'),
(48070, 2840, 13, 'Полученное уведомление об отчетности и безопасности медицинского страхования'),
(48071, 2842, 13, 'Гирсутизм/стрии'),
(48072, 2843, 13, 'Латиноамериканец'),
(48073, 2844, 13, 'Латиноамериканец - прочее (уроженец США)'),
(48074, 2845, 13, 'Латиноамериканец - прочее (уроженец не США)'),
(48075, 2846, 13, 'Латиноамериканец или латино'),
(48076, 2847, 13, 'Хронология'),
(48077, 2848, 13, 'Дата сбора анамнеза'),
(48078, 2849, 13, 'Дата анамнеза'),
(48079, 2851, 13, 'Шумы в анамнезе'),
(48080, 2852, 13, 'Хронология не разрешена'),
(48081, 2853, 13, 'Анамнез сердечных шумов'),
(48082, 2854, 13, 'Ответные справки'),
(48083, 2855, 13, 'ВИЧ');
INSERT INTO `lang_definitions` VALUES
(48084, 2858, 13, 'Обозреватель HL7'),
(48085, 2860, 13, 'нмоль/л'),
(48086, 2861, 13, 'Хмонг'),
(48087, 2862, 13, 'Удерживайте Ctrl для выбора нескольких элементов'),
(48088, 2863, 13, 'Удерживайте Ctrl для выбора нескольких групп'),
(48089, 2864, 13, 'Удерживайте [Ctrl] для множественного выбора или для снятия выбора'),
(48090, 2865, 13, 'Домой'),
(48091, 2866, 13, 'Домашний телефон'),
(48092, 2867, 13, 'Номер домашнего телефона'),
(48093, 2868, 13, 'Бездомный или подобное?'),
(48094, 2869, 13, 'Бездомный и т.д.'),
(48095, 2870, 13, 'Бездомный и т.д.'),
(48096, 2872, 13, 'Имя узла'),
(48097, 2873, 13, 'Имя узла не может быть пустым'),
(48098, 2875, 13, 'Час'),
(48099, 2876, 13, 'Часы'),
(48100, 2878, 13, 'Как произошла травма?'),
(48101, 2879, 13, 'Как произошла травма?:'),
(48102, 2880, 13, 'Как они узнали о нас'),
(48103, 2881, 13, 'На сколько месяцев вперед для предстоящих мероприятий?'),
(48104, 2882, 13, 'Анамнез сопутствующих заболеваний:'),
(48105, 2883, 13, 'Пересадка сердца'),
(48106, 2884, 13, 'HTML'),
(48107, 2886, 13, 'Ссылка https для поддержки LibreEHR службой лабораторного обмена LLC.'),
(48108, 2888, 13, 'Направление в Hylafax'),
(48109, 2889, 13, 'Команда шифрования Hylafax'),
(48110, 2890, 13, 'Сервер Hylafax'),
(48111, 2891, 13, 'Имя узла сервера Hylafax'),
(48112, 2892, 13, 'Гиперактивный'),
(48113, 2893, 13, 'Гипертензия'),
(48114, 2894, 13, 'Артериальная гипертензия: единица измерения артериального давления'),
(48115, 2895, 13, 'Артериальная гипертензия: единица измерения артериального давления (CQM)'),
(48116, 2896, 13, 'Гипертиреоз'),
(48117, 2897, 13, 'Гипотиреоз'),
(48118, 2898, 13, 'Гистерэктомия'),
(48119, 2899, 13, 'Я'),
(48120, 2900, 13, 'Я занят в этот период времени'),
(48121, 2901, 13, 'У меня нет доступа на чтение '),
(48122, 2902, 13, 'МКБ'),
(48123, 2905, 13, 'МКБ 9'),
(48124, 2909, 13, 'ID'),
(48125, 2910, 13, 'id'),
(48126, 2911, 13, 'ID не может быть пустым'),
(48127, 2912, 13, 'ID карты'),
(48128, 2913, 13, 'IDays'),
(48129, 2914, 13, 'идентифицировать как'),
(48130, 2915, 13, 'идентификатор (одно слово)'),
(48131, 2917, 13, 'Секунд сессионного простоя'),
(48132, 2919, 13, 'Если для этой формы все данные для всех столбцов заполнены'),
(48133, 2920, 13, 'При использовании биллинговой реабилитации введите наименование типа кода для диагноза.'),
(48134, 2921, 13, 'если вводите, то выбирайте только те, которые имеют эту службу'),
(48135, 2922, 13, 'Если именование, то любая часть фамилии или фамилия, имя'),
(48136, 2923, 13, 'если оплачено через'),
(48137, 2924, 13, 'Если человек умер, то введите дату смерти.'),
(48138, 2925, 13, 'При использовании SMTP имя узла сервера или адрес IP'),
(48139, 2926, 13, 'При использовании SMTP номер порта TCP сервера (обычно 25).'),
(48140, 2927, 13, 'если не работает, то введите студент'),
(48141, 2929, 13, 'При изменении правила e-RX для е-назначения может вызываться технология ePrescription. При затруднениях обратитесь к своему поставщику ePrescription.'),
(48142, 2931, 13, 'Если выбираете загрузку электронных денежных переводов, то окно поиска повторно отображает себя с соответствующими счетами из файла X 12. Можете кликнуть любой номер этого счета (как описано ниже), если нужно сделать какую-либо корректировку перед ...'),
(48143, 2932, 13, 'Если вводите дату оплаты на странице поиска, это переопределит дату учета платежей и корректировки, которые иначе взяты из файла X12. Может оказаться удобным для отчетности, если нужно, чтобы ваша отчетность использовала ваше сообщение'),
(48144, 2933, 13, 'Если требуется изменить типы данных или добавить строки или столбцы'),
(48145, 2934, 13, 'Если нужно модернизировать базу данных, то переместите файл zip базы данных в следующую директорию'),
(48146, 2936, 13, 'Игнорировать'),
(48147, 2937, 13, 'Заболевание'),
(48148, 2938, 13, 'Терапевт'),
(48149, 2941, 13, 'Средство отображения'),
(48150, 2942, 13, 'Вакцинация'),
(48151, 2943, 13, 'Код вакцинации'),
(48152, 2945, 13, 'Дата вакцинации'),
(48153, 2947, 13, 'Номер партии вакцины'),
(48154, 2948, 13, 'Изготовитель вакцины'),
(48155, 2949, 13, 'Регистрация вакцинации'),
(48156, 2951, 13, 'Услуга вакцинации'),
(48157, 2952, 13, 'Название вакцинации'),
(48158, 2953, 13, 'Вакцинации'),
(48159, 2954, 13, 'Вакцинировать'),
(48160, 2955, 13, 'Иммунология'),
(48161, 2956, 13, 'Имплантанты'),
(48162, 2957, 13, 'Импорт'),
(48163, 2961, 13, 'Импортировать сертификат в браузер.'),
(48164, 2962, 13, 'Настройка импорта'),
(48165, 2964, 13, 'Импортировать пациента'),
(48166, 2965, 13, 'Импорт персональных данных пациента'),
(48167, 2969, 13, 'Импортирован с аккаунта'),
(48168, 2972, 13, 'Нормализованный'),
(48169, 2973, 13, 'в'),
(48170, 2974, 13, 'в'),
(48171, 2975, 13, 'в каждый глаз'),
(48172, 2976, 13, 'в левый глаз'),
(48173, 2977, 13, 'назально'),
(48174, 2978, 13, 'В кабинете'),
(48175, 2979, 13, 'в правый глаз'),
(48176, 2980, 13, 'на дому'),
(48177, 2981, 13, 'бездействующий'),
(48178, 2982, 13, 'Нерабочие дни'),
(48179, 2983, 13, 'Входящий почтовый ящик'),
(48180, 2986, 13, 'Включить защиту контрольной суммой'),
(48181, 2987, 13, 'Включить полностью'),
(48182, 2988, 13, 'Включить неактивных пользователей'),
(48183, 2989, 13, 'Включить некатегоризированных'),
(48184, 2990, 13, 'Включить неструктуированные данные'),
(48185, 2991, 13, 'Включить жизненно важные показатели'),
(48186, 2992, 13, 'Включить данные жизненно важных параметров?'),
(48187, 2993, 13, 'Включение'),
(48188, 2994, 13, 'Доход'),
(48189, 2996, 13, 'Неполный'),
(48190, 2997, 13, 'Незавершенное прерванное лечение'),
(48191, 2998, 13, 'Неудержание'),
(48192, 2999, 13, 'Включить результаты клинических лабораторных анализов в сертифицированную технологию EHR, как структурированные данные.'),
(48193, 3001, 13, 'увеличено:'),
(48194, 3002, 13, 'Компенсационное страхование'),
(48195, 3003, 13, 'Неопределенный'),
(48196, 3004, 13, 'Индийский'),
(48197, 3005, 13, 'Указывает отклонение от нормы'),
(48198, 3006, 13, 'Отметьте, если эта проблема в настоящее время активна'),
(48199, 3008, 13, 'Указатель для специализированного использования'),
(48200, 3009, 13, 'Недействительные пациенты'),
(48201, 3010, 13, 'Отчет о недействительных пациентах'),
(48202, 3011, 13, 'Неимущие'),
(48203, 3014, 13, 'Вызывающие аборт'),
(48204, 3016, 13, 'Неподходящий'),
(48205, 3017, 13, 'Инфекция/абсцесс'),
(48206, 3018, 13, 'Инфекция'),
(48207, 3019, 13, 'Конс. по беспл.'),
(48208, 3020, 13, 'Бесплодие'),
(48209, 3021, 13, 'Грипп 1'),
(48210, 3022, 13, 'Грипп 2'),
(48211, 3023, 13, 'Противогриппозная вакцинация для пациентов возраста >= 50 лет'),
(48212, 3024, 13, 'Противогриппозная вакцинация для пациентов возраста >= 50 лет (CQM)'),
(48213, 3025, 13, 'Противогриппозная вакцинация'),
(48214, 3026, 13, 'Инф.'),
(48215, 3027, 13, 'Инф. тест. 1'),
(48216, 3028, 13, 'Инф. тест. 2'),
(48217, 3029, 13, 'Инф. тест. 3'),
(48218, 3030, 13, 'Инф. тест. 4'),
(48219, 3031, 13, 'Инф. тест. 5'),
(48220, 3032, 13, 'Инф. тест. 6'),
(48221, 3034, 13, 'ингаляции'),
(48222, 3035, 13, 'вдыхания'),
(48223, 3037, 13, 'Начальный пользователь'),
(48224, 3038, 13, 'Травм./реаб.'),
(48225, 3039, 13, 'Вводимый'),
(48226, 3040, 13, 'Инъекция'),
(48227, 3041, 13, 'Поврежденная часть тела'),
(48228, 3042, 13, 'Последствие повреждения'),
(48229, 3043, 13, 'Травма'),
(48230, 3044, 13, 'Механизм травмы'),
(48231, 3045, 13, 'Обзорный отчет о травме'),
(48232, 3046, 13, 'Травматологическое исследование'),
(48233, 3047, 13, 'Тип травмы'),
(48234, 3048, 13, 'Травма или связанное заболевание'),
(48235, 3051, 13, 'Поля ввода'),
(48236, 3052, 13, 'Международный нормализационный индекс (МНИ)'),
(48237, 3056, 13, 'Вст. корр.'),
(48238, 3057, 13, 'Вст. связывание'),
(48239, 3058, 13, 'Вст. код'),
(48240, 3061, 13, 'Вст. переплату'),
(48241, 3063, 13, 'Вст. возмещение'),
(48242, 3064, 13, 'Вст. итоговый'),
(48243, 3065, 13, 'Вст.1'),
(48244, 3066, 13, 'Вст.2'),
(48245, 3067, 13, 'Вст.3'),
(48246, 3069, 13, 'Вставка дала сбой '),
(48247, 3070, 13, 'Вставка старых событий в таблицы'),
(48248, 3072, 13, 'Бессоница'),
(48249, 3074, 13, 'Экспертиза'),
(48250, 3075, 13, 'Неустойчивый / подвывих'),
(48251, 3077, 13, 'Установить'),
(48252, 3079, 13, 'Установить БД'),
(48253, 3081, 13, 'Инструктирован'),
(48254, 3082, 13, 'Инструкция'),
(48255, 3084, 13, 'Инструкции:'),
(48256, 3086, 13, 'Инсулинозависимый диабет'),
(48257, 3087, 13, 'Страховка'),
(48258, 3088, 13, 'страхование'),
(48259, 3093, 13, 'Страховая компания'),
(48260, 3094, 13, 'Страховые компании'),
(48261, 3095, 13, 'Страховая компания'),
(48262, 3096, 13, 'Поиск/добавление страховой компании'),
(48263, 3098, 13, 'Дата страхования'),
(48264, 3099, 13, 'Информация по страхованию в файле'),
(48265, 3100, 13, 'Страховые номера'),
(48266, 3101, 13, 'Страховая оплата'),
(48267, 3103, 13, 'Страхователь'),
(48268, 3107, 13, 'Результат приема'),
(48269, 3108, 13, 'Дата приема'),
(48270, 3109, 13, 'Снижение интеллекта'),
(48271, 3113, 13, 'Внутренняя ошибка - не выбраны страницы!'),
(48272, 3114, 13, 'Внутренняя ошибка - не предоставлен ID пациента!'),
(48273, 3115, 13, 'Внутренняя ошибка обновленного файла прав доступа!'),
(48274, 3116, 13, 'Внутренняя ошибка!'),
(48275, 3117, 13, 'Внутренняя ошибка, не указан ID препарата!'),
(48276, 3119, 13, 'Внутренняя ошибка: требование '),
(48277, 3120, 13, 'Внутренняя ошибка: обращение '''),
(48278, 3121, 13, 'Внутренняя ошибка: пропущен pid или обращение.'),
(48279, 3122, 13, 'Внутренняя ошибка: мы, кажется, вне обращения'),
(48280, 3123, 13, 'Внутренний идентификатор (pid)'),
(48281, 3126, 13, 'Внутренние направления'),
(48282, 3127, 13, 'Потраченное внутреннее время'),
(48283, 3128, 13, 'Международное обязательство'),
(48284, 3129, 13, 'Переводчик'),
(48285, 3130, 13, 'Переводчик нужен?'),
(48286, 3131, 13, 'Интерстициальный пневмокониоз'),
(48287, 3132, 13, 'Интервал'),
(48288, 3135, 13, 'Вмешательство'),
(48289, 3137, 13, 'Непереносимость'),
(48290, 3139, 13, 'внутримышечно'),
(48291, 3140, 13, 'внутривенно'),
(48292, 3141, 13, 'введение'),
(48293, 3144, 13, 'Недопустимый символ в'),
(48294, 3147, 13, 'Недопустимый символ для'),
(48295, 3148, 13, 'Недопустимый нецифровой символ в'),
(48296, 3149, 13, 'Недопустимый или пропущенный плательщик в источнике для кода '),
(48297, 3151, 13, 'Недействительные коды услуг'),
(48298, 3152, 13, 'Недопустимый обозначение источника "'),
(48299, 3154, 13, 'Инвент.кол.'),
(48300, 3155, 13, 'Товарно-материальные ценности'),
(48301, 3156, 13, 'Задействованные товарно-материальные ценности'),
(48302, 3157, 13, 'Учитывается и реализуется как лекарственная, так и нелекарственная продукция'),
(48303, 3158, 13, 'Только товарно-материальные ценности и препараты для выдачи'),
(48304, 3159, 13, 'Для этого назначения склад недоступен.'),
(48305, 3160, 13, 'Список товарно-материальных ценностей'),
(48306, 3161, 13, 'Транзакции по инвентаризации'),
(48307, 3162, 13, 'Счет'),
(48308, 3163, 13, 'счет'),
(48309, 3166, 13, 'Дата выставления счета'),
(48310, 3167, 13, 'Счет не имеет даты!'),
(48311, 3168, 13, 'Номер счета'),
(48312, 3169, 13, 'Ссылочный номер счета'),
(48313, 3170, 13, 'Объединение ссылочного номера счета, если используется'),
(48314, 3171, 13, 'Объединение ссылочного номера счета'),
(48315, 3172, 13, 'Объединение исх. номера счета'),
(48316, 3173, 13, 'Счет:'),
(48317, 3174, 13, 'МФПС'),
(48318, 3177, 13, 'Данные сексуального и репродуктивного здоровья МФПС для'),
(48319, 3178, 13, 'Статистический отчет МФПС'),
(48320, 3179, 13, 'Статистика МФПС'),
(48321, 3180, 13, 'ИПВ 1'),
(48322, 3181, 13, 'ИПВ 2'),
(48323, 3182, 13, 'ИПВ 3'),
(48324, 3183, 13, 'ИПВ 4'),
(48325, 3185, 13, 'Аритмия'),
(48326, 3186, 13, 'Раздражительность'),
(48327, 3187, 13, 'Болезненная чувствительность'),
(48328, 3191, 13, 'является обязательным полем.'),
(48329, 3192, 13, 'является узлом root и не может быть удален.'),
(48330, 3197, 13, 'не действителен (десятичная часть OK).'),
(48331, 3198, 13, 'PHP использует безопасный режим?'),
(48332, 3200, 13, 'Является текстом из макетов форм для перевода?'),
(48333, 3201, 13, 'Является текстом из списков для перевода?'),
(48334, 3202, 13, 'Этот файл шифрован?'),
(48335, 3204, 13, 'Это тип диагноза?'),
(48336, 3209, 13, 'Этот тип кода активен?'),
(48337, 3212, 13, 'Этот тип в листе оплаты невидим?'),
(48338, 3214, 13, 'слишком длинный'),
(48339, 3216, 13, 'Проблема'),
(48340, 3217, 13, 'проблема'),
(48341, 3218, 13, 'Дата появления'),
(48342, 3219, 13, 'ID проблемы'),
(48343, 3220, 13, 'Обозначение проблемы'),
(48344, 3223, 13, 'Проблемы'),
(48345, 3224, 13, 'Аспекты (травмы/терапия/аллергия)'),
(48346, 3225, 13, 'Аспекты (травмы/терапия/аллергия):'),
(48347, 3226, 13, 'Аспекты и обращения'),
(48348, 3227, 13, 'Аспекты и обращения для'),
(48349, 3228, 13, 'Доступ к проблемам не разрешен'),
(48350, 3229, 13, 'Раздел проблем'),
(48351, 3230, 13, 'Итальянский'),
(48352, 3231, 13, 'Пункт'),
(48353, 3232, 13, 'пункт'),
(48354, 3234, 13, 'Загрузка пунктов дала сбой'),
(48355, 3235, 13, 'МЕ/л'),
(48356, 3236, 13, 'ВМС'),
(48357, 3237, 13, 'В/в'),
(48358, 3238, 13, 'Янв'),
(48359, 3239, 13, 'Январь'),
(48360, 3240, 13, 'Японский'),
(48361, 3241, 13, 'Желтуха'),
(48362, 3243, 13, 'Описание работы'),
(48363, 3244, 13, 'ID работы'),
(48364, 3245, 13, 'Вывих сустава'),
(48365, 3246, 13, 'Суставная боль'),
(48366, 3247, 13, 'Растяжение сустава'),
(48367, 3248, 13, 'Июл'),
(48368, 3249, 13, 'Июль'),
(48369, 3250, 13, 'Июн'),
(48370, 3251, 13, 'Июнь'),
(48371, 3252, 13, 'Чуть ниже регистрационная информация находится в синей области, куда вы поместили параметры поиска. Можете искать по имени пациента, номеру карты, номеру обращения или дате оказания помощи, или любой их комбинации. Также можете выбрать, хотите ли видеть все счета, открытые или только выставленные (по пациенту). Кликните кнопку поиска для его выполнения.'),
(48372, 3253, 13, 'Только для меня'),
(48373, 3255, 13, 'Подтвердить'),
(48374, 3256, 13, 'Подтвердить/сохранить'),
(48375, 3258, 13, 'k, вот остальные'),
(48376, 3264, 13, 'Ключ'),
(48377, 3265, 13, 'Ключевые слова'),
(48378, 3266, 13, 'кг'),
(48379, 3267, 13, 'кг/м^2'),
(48380, 3269, 13, 'Рак почки'),
(48381, 3270, 13, 'Почечная недостаточность'),
(48382, 3271, 13, 'Почечная инфекция'),
(48383, 3272, 13, 'ПКБ'),
(48384, 3273, 13, 'Пересадка почки'),
(48385, 3277, 13, 'Колено'),
(48386, 3278, 13, 'Проблемы колена'),
(48387, 3279, 13, 'Замещение коленного сустава'),
(48388, 3282, 13, 'Корейский'),
(48389, 3286, 13, 'Лаборатория'),
(48390, 3288, 13, 'Адрес сайта лабораторного обмена'),
(48391, 3289, 13, 'Id сайта лабораторного обмена'),
(48392, 3290, 13, 'Символьный id лабораторного обмена'),
(48393, 3294, 13, 'Статус лабораторного запроса'),
(48394, 3295, 13, 'Лабораторный отчет'),
(48395, 3296, 13, 'Результат лаборатории'),
(48396, 3297, 13, 'Результаты лаборатории'),
(48397, 3299, 13, 'Отчет о лабораторных результатах'),
(48398, 3300, 13, 'Лабораторная услуга'),
(48399, 3301, 13, 'Результаты лабораторных анализов'),
(48400, 3303, 13, 'Метка'),
(48401, 3304, 13, 'Метка не должна быть пустой'),
(48402, 3305, 13, 'Столбцы метки'),
(48403, 3306, 13, 'Метка для этого типа'),
(48404, 3307, 13, 'Столбцы метки должно быть числом между 1 и 999'),
(48405, 3308, 13, 'Метки'),
(48406, 3311, 13, 'Лаборатории'),
(48407, 3312, 13, 'Рваная рана / состояние кожи'),
(48408, 3313, 13, 'Разрыв/ссадина'),
(48409, 3316, 13, 'Язык'),
(48410, 3317, 13, 'Код языка'),
(48411, 3318, 13, 'Добавлено определение языка'),
(48412, 3319, 13, 'Интерфейсный инструмент языка'),
(48413, 3320, 13, 'Список языков (write,addonly необязателен)'),
(48414, 3321, 13, 'Название языка'),
(48415, 3322, 13, 'Язык:'),
(48416, 3324, 13, 'Лаосский'),
(48417, 3325, 13, 'Последний'),
(48418, 3326, 13, 'Дата последней активности'),
(48419, 3328, 13, 'Дата последнего счета:'),
(48420, 3330, 13, 'Предыдущий календарный год'),
(48421, 3333, 13, 'Последнее обращение'),
(48422, 3343, 13, 'Предыдущий месяц'),
(48423, 3344, 13, 'Фамилия'),
(48424, 3345, 13, 'Фамилия'),
(48425, 3346, 13, 'Фамилия:'),
(48426, 3350, 13, 'Последнее рассмотрение'),
(48427, 3352, 13, 'Последнее сохранение'),
(48428, 3356, 13, 'Последнее обновление через'),
(48429, 3357, 13, 'Последняя проверка в'),
(48430, 3358, 13, 'Предыдущее посещение'),
(48431, 3360, 13, 'Поздний возврат (2-12 мес.)'),
(48432, 3361, 13, 'Латеральная лодыжка'),
(48433, 3362, 13, 'Латеральная лодыжка:'),
(48434, 3363, 13, 'Латеральность'),
(48435, 3364, 13, 'Сторона этой методики, если применимо'),
(48436, 3365, 13, 'Латеральная дисплазия после ОИМ:'),
(48437, 3373, 13, 'На основе макета'),
(48438, 3374, 13, 'Редактор макета'),
(48439, 3375, 13, 'Группы макета'),
(48440, 3376, 13, 'Стиль макета'),
(48441, 3378, 13, 'Формы посещений на основе макета'),
(48442, 3379, 13, 'Макеты'),
(48443, 3380, 13, 'фунт'),
(48444, 3381, 13, 'фунты'),
(48445, 3382, 13, 'ЛПНП'),
(48446, 3383, 13, 'если продолжается, то оставьте пустым'),
(48447, 3384, 13, 'Для сохранения исходного имени файла оставьте поле пустым'),
(48448, 3385, 13, 'Для сохранения прежнего пароля оставьте поле пустым.'),
(48449, 3386, 13, 'Оставьте сообщение с'),
(48450, 3387, 13, 'Выйдите из этой формы'),
(48451, 3388, 13, 'Пустая контрольная фраза не шифрует этот документ'),
(48452, 3390, 13, 'Слева'),
(48453, 3391, 13, 'Левое ухо'),
(48454, 3392, 13, 'левое ухо'),
(48455, 3394, 13, 'Слева:'),
(48456, 3395, 13, 'Слева: '),
(48457, 3396, 13, 'Боль/судорога в ногах'),
(48458, 3397, 13, 'Законный'),
(48459, 3399, 13, 'Утвержденный размер страницы'),
(48460, 3400, 13, 'Легенда:'),
(48461, 3401, 13, 'Длина'),
(48462, 3402, 13, 'Длина модификатора, если не задана, то 0'),
(48463, 3403, 13, 'Меньше чем'),
(48464, 3404, 13, 'Меньше чем или равно'),
(48465, 3405, 13, 'Менее закрытая информация (write,addonly необязателен)'),
(48466, 3406, 13, 'Письмо'),
(48467, 3407, 13, 'Генератор письма'),
(48468, 3408, 13, 'Размер бумаги Письмо'),
(48469, 3409, 13, 'Фирменный бланк, подписываемый врачом'),
(48470, 3410, 13, 'Фирменный бланк, подписываемый пациентом'),
(48471, 3411, 13, 'Степень срочности'),
(48472, 3412, 13, 'Ответственность'),
(48473, 3413, 13, 'Медицина генетической предрасположенности'),
(48474, 3414, 13, 'Лицензия или ID'),
(48475, 3419, 13, 'Фамилия лицензированного ответственного'),
(48476, 3420, 13, 'NPI лицензированного ответственного'),
(48477, 3421, 13, 'UPIN лицензированного ответственного'),
(48478, 3423, 13, 'Образ жизни'),
(48479, 3424, 13, 'Статус образа жизни'),
(48480, 3425, 13, 'Разрыв или растяжение связки'),
(48481, 3428, 13, 'Ограничение событий'),
(48482, 3429, 13, 'Ограничения'),
(48483, 3431, 13, 'Ссылка'),
(48484, 3432, 13, 'Ссылка на пациента'),
(48485, 3433, 13, 'Связанный'),
(48486, 3436, 13, 'связанный с документом'),
(48487, 3438, 13, 'Список'),
(48488, 3439, 13, 'Поле со списком'),
(48489, 3440, 13, 'поле со списком'),
(48490, 3441, 13, 'поле со списком с доб.'),
(48491, 3442, 13, 'Поле со списком с доб.'),
(48492, 3443, 13, 'Редактор списка'),
(48493, 3444, 13, 'Вывести обращения'),
(48494, 3445, 13, 'Вывести группы'),
(48495, 3446, 13, 'Вывести страховые компании'),
(48496, 3448, 13, 'Элементы списка не могут начинаться с числа.'),
(48497, 3449, 13, 'Элементы списка содержат запрещенный символ(ы).'),
(48498, 3451, 13, 'Вывести списки'),
(48499, 3452, 13, 'Наименование списка'),
(48500, 3453, 13, 'Наименование списка не может начинаться с чисел.'),
(48501, 3454, 13, 'Вывести назначения'),
(48502, 3455, 13, 'Список используется через вышеуказанный вариант типа данных для страны.'),
(48503, 3456, 13, 'Список используется через вышеуказанный вариант типа данных для области.'),
(48504, 3457, 13, 'Прослушиваемый порт сервера syslog TLS RFC 5425.'),
(48505, 3458, 13, 'Списки'),
(48506, 3460, 13, 'Прижизненное завещание'),
(48507, 3461, 13, 'Левая нижняя конечность:'),
(48508, 3462, 13, 'Последняя менструация'),
(48509, 3464, 13, 'Загрузить определения'),
(48510, 3470, 13, 'ЗАГРУЗКА'),
(48511, 3471, 13, 'Загрузка файлов в базу данных. Займет некоторое врем...'),
(48512, 3472, 13, 'Сниженное понимание'),
(48513, 3473, 13, 'Локально'),
(48514, 3476, 13, 'Локальный'),
(48515, 3477, 13, 'Местоположение'),
(48516, 3478, 13, 'Размещение'),
(48517, 3479, 13, 'расположение машины libreehr и может содержать секретные данные, поэтому рекомендуется вручную удалить их после использования'),
(48518, 3480, 13, 'Размещение этой партии'),
(48519, 3481, 13, 'Неопределенное размещение'),
(48520, 3482, 13, 'Место, где Hylafax сохраняет факсы.'),
(48521, 3483, 13, 'Место сохранения сканнограмм'),
(48522, 3484, 13, 'Размещение:'),
(48523, 3485, 13, 'Заблокировать'),
(48524, 3492, 13, 'Войти'),
(48525, 3494, 13, 'Выйти'),
(48526, 3495, 13, 'Зарегистрирован'),
(48527, 3496, 13, 'Зарегистрирован как'),
(48528, 3497, 13, 'Зарегистрирован как: '),
(48529, 3498, 13, 'Регистрация снята.'),
(48530, 3500, 13, 'Войти'),
(48531, 3501, 13, 'логин'),
(48532, 3505, 13, 'Выйти'),
(48533, 3506, 13, 'выйти'),
(48534, 3507, 13, 'Журналы'),
(48535, 3508, 13, 'Обозреватель журналов'),
(48536, 3510, 13, 'Найти'),
(48537, 3511, 13, 'Партия'),
(48538, 3512, 13, 'Пропущен ID партии'),
(48539, 3513, 13, 'Номер партии'),
(48540, 3514, 13, 'Низкий'),
(48541, 3516, 13, 'Укороченная нога'),
(48542, 3519, 13, 'Поясничный отдел позвоночника'),
(48543, 3520, 13, 'Обед'),
(48544, 3521, 13, 'обед'),
(48545, 3522, 13, 'Рак легкого'),
(48546, 3523, 13, 'Хирургия рака легкого'),
(48547, 3524, 13, 'ЛЕГКИЕ:'),
(48548, 3525, 13, 'Легкие:'),
(48549, 3526, 13, 'Волчанка'),
(48550, 3528, 13, 'M'),
(48551, 3529, 13, 'Категория MA'),
(48552, 3530, 13, 'Отказ приема клиента MA'),
(48553, 3531, 13, 'Статистика MA'),
(48554, 3533, 13, 'Отправка почты'),
(48555, 3534, 13, 'Основной'),
(48556, 3535, 13, 'Основной адрес'),
(48557, 3536, 13, 'Основная область экрана'),
(48558, 3537, 13, 'Список основной активной медикаментозной аллергии.'),
(48559, 3538, 13, 'Список основного активного медикаментозного лечения.'),
(48560, 3539, 13, 'Поддерживает обновленный список проблем для текущих и активных диагнозов.'),
(48561, 3540, 13, 'Создает изменения в текущих категориях.'),
(48562, 3541, 13, 'Создать новую запись на прием для'),
(48563, 3542, 13, 'Убедитесь, что "'),
(48564, 3543, 13, 'Создание пакетных текстовых файлов для загрузки в информационный центр, и пометит как счет'),
(48565, 3545, 13, 'Дискомфорт:'),
(48566, 3548, 13, 'мужской'),
(48567, 3549, 13, 'Мужские кондомы'),
(48568, 3550, 13, 'Мужской VSC'),
(48569, 3552, 13, 'Маммография'),
(48570, 3553, 13, 'Управление'),
(48571, 3556, 13, 'Управление переводами'),
(48572, 3557, 13, 'Управление'),
(48573, 3558, 13, 'Обязательные и устанавливаемые поля'),
(48574, 3559, 13, 'Только обязательные и устанавливаемые поля, отметьте дважды, не просматривайте'),
(48575, 3560, 13, 'Только обязательные и устанавливаемые поля, найдите и отметьте дважды'),
(48576, 3561, 13, 'Руководство'),
(48577, 3562, 13, 'Отправка вручную'),
(48578, 3563, 13, 'Производитель'),
(48579, 3565, 13, 'Мар'),
(48580, 3568, 13, 'Март'),
(48581, 3569, 13, 'Семейное положение'),
(48582, 3571, 13, 'Отметьте как оплаченное, но пропустите выставленный счет'),
(48583, 3572, 13, 'Маркировать как очищенное'),
(48584, 3573, 13, 'Маркировать как неоплаченное'),
(48585, 3575, 13, 'Маркировано, как очищенное'),
(48586, 3576, 13, 'Женат'),
(48587, 3578, 13, 'Маска'),
(48588, 3579, 13, 'Маска для номеров счетов'),
(48589, 3580, 13, 'Маска для ID пациента'),
(48590, 3581, 13, 'Маска для ID продукции'),
(48591, 3582, 13, 'Соответствие'),
(48592, 3591, 13, 'Максимум'),
(48593, 3594, 13, 'Подмышечная область справа:'),
(48594, 3595, 13, 'Максимальный возраст'),
(48595, 3596, 13, 'Символы максимума'),
(48596, 3597, 13, 'Максимальный простой в секундах до входа в систему.'),
(48597, 3600, 13, 'Максимальный разумный запас, если не применяется - 0'),
(48598, 3603, 13, 'Май'),
(48599, 3604, 13, 'Микроскопия и выделение культуры'),
(48600, 3605, 13, 'мкг'),
(48601, 3607, 13, 'Означает, что ни один из трех последних паролей не разрешен для изменения пароля.'),
(48602, 3609, 13, 'Код группы единиц измерения'),
(48603, 3611, 13, 'Система мер'),
(48604, 3612, 13, 'Внутренняя область лодыжки'),
(48605, 3613, 13, 'Медпомощь'),
(48606, 3614, 13, 'Медицинский'),
(48607, 3615, 13, 'Медицинский аборт'),
(48608, 3616, 13, 'Врачебное администрирование'),
(48609, 3617, 13, 'Анамнез'),
(48610, 3618, 13, 'Медицинский результат'),
(48611, 3619, 13, 'Медицинский результат'),
(48612, 3620, 13, 'Медицинская проблема'),
(48613, 3623, 13, 'Медицинские проблемы'),
(48614, 3624, 13, 'Медицинская запись'),
(48615, 3625, 13, 'История болезни #'),
(48616, 3626, 13, 'Медицинские записи'),
(48617, 3627, 13, 'Медицинские записи отправлены'),
(48618, 3629, 13, 'Предоставленное медицинское резюме'),
(48619, 3630, 13, 'Медицинская система'),
(48620, 3631, 13, 'Тип лечения'),
(48621, 3632, 13, 'Заболевание/анамнез (write, addonly необязателен)'),
(48622, 3633, 13, 'Часть B бесплатной медицинской помощи'),
(48623, 3634, 13, 'Реферрер Medicare является средством визуализации'),
(48624, 3635, 13, 'Препарат'),
(48625, 3636, 13, 'Список медикаментозной аллергии'),
(48626, 3638, 13, 'Список лекарств'),
(48627, 3639, 13, 'Согласование лечения выполнено?'),
(48628, 3640, 13, 'Медикаменты'),
(48629, 3641, 13, 'Медикаменты:'),
(48630, 3642, 13, 'Единицы выпуска медикамента'),
(48631, 3643, 13, 'Средний'),
(48632, 3645, 13, 'Статистический отчет члена Ассоциации'),
(48633, 3646, 13, 'Проблемы памяти'),
(48634, 3647, 13, 'Мужчина'),
(48635, 3648, 13, 'Мужчина и женщина'),
(48636, 3649, 13, 'Только мужчины'),
(48637, 3650, 13, 'Менархе'),
(48638, 3651, 13, 'Менопауза'),
(48639, 3652, 13, 'Обильная менструация'),
(48640, 3653, 13, 'Менструальный цикл'),
(48641, 3654, 13, 'Психическое заболевание'),
(48642, 3661, 13, 'Сообщение'),
(48643, 3662, 13, 'Центр сообщений и напоминаний'),
(48644, 3665, 13, 'Сообщение отправлено'),
(48645, 3666, 13, 'Состояние сообщения'),
(48646, 3670, 13, 'СООБЩЕНИЕ:'),
(48647, 3671, 13, 'Сообщения'),
(48648, 3672, 13, 'Сообщения для сегодняшней отправки'),
(48649, 3673, 13, 'Метод'),
(48650, 3674, 13, 'Метод и определенный результат'),
(48651, 3675, 13, 'Метод отправки исходящих e-mail.'),
(48652, 3676, 13, 'Метод уничтожения'),
(48653, 3677, 13, 'Мексиканец/американец мексиканского происхождения/чикано'),
(48654, 3679, 13, 'мг'),
(48655, 3680, 13, 'мг/1куб.см.'),
(48656, 3681, 13, 'мг/2куб.см.'),
(48657, 3682, 13, 'мг/3куб.см.'),
(48658, 3683, 13, 'мг/4куб.см.'),
(48659, 3684, 13, 'мг/5куб.см.'),
(48660, 3685, 13, 'мг/дл'),
(48661, 3686, 13, 'Средний'),
(48662, 3687, 13, 'Отчество'),
(48663, 3688, 13, 'Отчество'),
(48664, 3690, 13, 'Специалист DEA среднего уровня'),
(48665, 3691, 13, 'Имя ответственного среднего уровня'),
(48666, 3692, 13, 'Фамилия ответственного среднего уровня'),
(48667, 3693, 13, 'Инициалы ответственного среднего уровня'),
(48668, 3694, 13, 'UPIN ответственного среднего уровня'),
(48669, 3695, 13, 'Выражение лица'),
(48670, 3696, 13, 'Мигрант или сезонный рабочий?'),
(48671, 3697, 13, 'Мигрант/сезонный рабочий'),
(48672, 3698, 13, 'млн/куб.мм'),
(48673, 3702, 13, 'MimeType'),
(48674, 3703, 13, 'мин'),
(48675, 3704, 13, 'мин'),
(48676, 3705, 13, 'Минимальный возраст'),
(48677, 3706, 13, 'Легкое растяжение сустава +/- синовиит'),
(48678, 3708, 13, 'Минута'),
(48679, 3709, 13, 'минуты'),
(48680, 3710, 13, 'Минуты'),
(48681, 3712, 13, 'Прочее'),
(48682, 3713, 13, 'Варианты прочих счетов'),
(48683, 3714, 13, 'Варианты прочих счетов для HCFA-1500'),
(48684, 3715, 13, 'Варианты прочих счетов для HCFA'),
(48685, 3716, 13, 'Разное'),
(48686, 3717, 13, 'Пропущенный'),
(48687, 3718, 13, 'пропущенный'),
(48688, 3719, 13, 'Пропущено обязательное поле'),
(48689, 3720, 13, 'Пропущена оплата'),
(48690, 3721, 13, 'Пропущен только модификатор'),
(48691, 3722, 13, 'Пропущен или не действителен'),
(48692, 3723, 13, 'Пропущен PID.'),
(48693, 3724, 13, 'Пропущена дата отчета'),
(48694, 3725, 13, 'Пропущен слеш после плательщика в исходнике для кода '),
(48695, 3726, 13, 'Смешанное'),
(48696, 3727, 13, 'мл'),
(48697, 3728, 13, 'MM/DD/YYYY'),
(48698, 3729, 13, 'мм. рт. ст.'),
(48699, 3730, 13, 'мм. рт. ст.'),
(48700, 3731, 13, 'Частота материнской смертности 1'),
(48701, 3732, 13, 'Частота материнской смертности 2'),
(48702, 3733, 13, 'Мобильный'),
(48703, 3734, 13, 'Мобильный телефон'),
(48704, 3735, 13, 'Модиф.'),
(48705, 3741, 13, 'Модификатор'),
(48706, 3742, 13, 'Модификаторы'),
(48707, 3745, 13, 'Измененный платеж'),
(48708, 3746, 13, 'Дл.модиф.'),
(48709, 3753, 13, 'Пн.'),
(48710, 3754, 13, 'с Пн по Пт'),
(48711, 3755, 13, 'Пн, Ср &amp; Пт'),
(48712, 3756, 13, 'Понедельник'),
(48713, 3758, 13, 'Месяц'),
(48714, 3759, 13, 'месяц'),
(48715, 3760, 13, 'Обзор за месяц'),
(48716, 3761, 13, 'Месяц(ы)'),
(48717, 3762, 13, 'Ежемесячный доход'),
(48718, 3763, 13, 'Месяцы'),
(48719, 3765, 13, 'Найдено более 100 записей. Уточните критерий поиска.'),
(48720, 3766, 13, 'Более 50 результатов, конкретизируйте поиск.'),
(48721, 3767, 13, 'Большинство заголовков столбцов можно кликнуть для изменения порядка сортировки'),
(48722, 3768, 13, 'Самый последний из'),
(48723, 3770, 13, 'Самые последние жизненно важные показатели от:'),
(48724, 3771, 13, 'Мать'),
(48725, 3772, 13, 'Фамилия матери'),
(48726, 3774, 13, 'Рот'),
(48727, 3775, 13, 'Переместить'),
(48728, 3776, 13, 'Переместить документ в категорию:'),
(48729, 3777, 13, 'Переместить ниже'),
(48730, 3779, 13, 'Переместить в пациента'),
(48731, 3780, 13, 'Переместить в...'),
(48732, 3781, 13, 'Переместить выше'),
(48733, 3783, 13, 'Mr.'),
(48734, 3785, 13, 'Mrs.'),
(48735, 3786, 13, 'Ms.'),
(48736, 3794, 13, 'Код MSP'),
(48737, 3796, 13, 'Инструментарий перевода'),
(48738, 3797, 13, 'Несколько областей'),
(48739, 3799, 13, 'Несколько партий'),
(48740, 3800, 13, 'Несколько модификаторов можно разделить двоеточиями или пробелами, максимум 4 (M1:M2:M3:M4)'),
(48741, 3802, 13, 'Многонациональный'),
(48742, 3803, 13, 'Шум:'),
(48743, 3804, 13, 'Мыш. боль'),
(48744, 3805, 13, 'Мыш. боли'),
(48745, 3806, 13, 'Кожная гиперемия над мышцей'),
(48746, 3807, 13, 'Мыш. ригидность'),
(48747, 3808, 13, 'Припухлость мышцы'),
(48748, 3809, 13, 'Гипертермия в области мышцы'),
(48749, 3810, 13, 'Мышечные'),
(48750, 3811, 13, 'Повреждение мышцы'),
(48751, 3812, 13, 'Костно-мышечная'),
(48752, 3813, 13, 'Если аутентификация SMTP не используется, то должен быть пустым'),
(48753, 3814, 13, 'Определяемые совместно'),
(48754, 3815, 13, 'ДТП'),
(48755, 3818, 13, 'Самостоятельно'),
(48756, 3821, 13, 'NA'),
(48757, 3822, 13, 'na'),
(48758, 3823, 13, 'Именование'),
(48759, 3825, 13, 'Наименование (кликните для уточнения)'),
(48760, 3826, 13, 'Наименование 1'),
(48761, 3827, 13, 'Наименование 2'),
(48762, 3828, 13, 'Наименование и заголовок для управления вакцинацией'),
(48763, 3831, 13, 'Наименование события'),
(48764, 3832, 13, 'Наименование страховой компании'),
(48765, 3833, 13, 'Фамилия специалиста'),
(48766, 3834, 13, 'Фамилия отправителя напоминаний для пациента.'),
(48767, 3835, 13, 'Перевод наименования'),
(48768, 3836, 13, 'Наименование/значение'),
(48769, 3837, 13, 'Наименование:'),
(48770, 3838, 13, 'НОЗДРИ:'),
(48771, 3839, 13, 'НОЗДРИ: справа обычная'),
(48772, 3840, 13, 'Слизистая носа розовая, перегородка по средней линии'),
(48773, 3841, 13, 'Записи по национальности'),
(48774, 3842, 13, 'Настройка записей по национальности'),
(48775, 3844, 13, 'Национальность'),
(48776, 3845, 13, 'Зап. по нац.'),
(48777, 3847, 13, 'Гавайский или другой островной'),
(48778, 3852, 13, 'Тошнота'),
(48779, 3854, 13, 'Навигация'),
(48780, 3855, 13, 'Область навигации содержит формы обращения'),
(48781, 3856, 13, 'Область навигации использует всю высоту окна'),
(48782, 3857, 13, 'Формы посещения для области навигации'),
(48783, 3858, 13, 'Ширина области навигации'),
(48784, 3859, 13, 'Навигационное меню состоит из пар переключателей'),
(48785, 3860, 13, 'Навигационное меню в виде дерева'),
(48786, 3861, 13, 'Навигация использует скользящее меню'),
(48787, 3862, 13, 'NDC'),
(48788, 3864, 13, 'Номер NDC'),
(48789, 3866, 13, 'Шея'),
(48790, 3867, 13, 'Проблемы шеи'),
(48791, 3868, 13, 'Подвижность шеи'),
(48792, 3869, 13, 'Необходимо ввести описание'),
(48793, 3870, 13, 'Необходимо ввести возвращаемое значение'),
(48794, 3871, 13, 'Необходимо ввести идентификатор'),
(48795, 3872, 13, 'Необходимо ввести название'),
(48796, 3873, 13, 'Требуется разр.'),
(48797, 3874, 13, 'Требуется подтверждение'),
(48798, 3875, 13, 'Требуется повторное выставление счета'),
(48799, 3876, 13, 'Отрицательное'),
(48800, 3877, 13, 'Отрицание'),
(48801, 3880, 13, 'Повреждение нерва'),
(48802, 3881, 13, 'Неврологический статус / повреждение нерва'),
(48803, 3882, 13, 'Онемение'),
(48804, 3883, 13, 'Слабость'),
(48805, 3884, 13, 'Неврологическая'),
(48806, 3885, 13, 'Никогда'),
(48807, 3886, 13, 'Не употреблял алкоголь'),
(48808, 3887, 13, 'Никогда не курил'),
(48809, 3888, 13, 'Новое'),
(48810, 3889, 13, 'Новое =>'),
(48811, 3890, 13, 'Новые получатели'),
(48812, 3892, 13, 'Новая аллергия'),
(48813, 3894, 13, 'Новая запись на прием'),
(48814, 3895, 13, 'Новые категории'),
(48815, 3896, 13, 'Новая категория'),
(48816, 3897, 13, 'Новые клиенты'),
(48817, 3898, 13, 'Новая консультация'),
(48818, 3899, 13, 'Новая группа'),
(48819, 3900, 13, 'Добавлен новый набор определений'),
(48820, 3901, 13, 'Новый документ'),
(48821, 3904, 13, 'Новое обращение'),
(48822, 3905, 13, 'Новое обращение, созданное с id'),
(48823, 3906, 13, 'Форма нового обращения'),
(48824, 3907, 13, 'Доступ к новым обращениям не разрешен'),
(48825, 3908, 13, 'Новое обращ.'),
(48826, 3909, 13, 'Информация по новой услуге'),
(48827, 3912, 13, 'Новая группа'),
(48828, 3913, 13, 'Информация по новой группе'),
(48829, 3914, 13, 'Новый ввод/статус'),
(48830, 3916, 13, 'Новое ограничение событий'),
(48831, 3917, 13, 'Новый список'),
(48832, 3918, 13, 'Новые назначения'),
(48833, 3919, 13, 'Новый подраздел'),
(48834, 3920, 13, 'Новый пароль'),
(48835, 3921, 13, 'Новый пациент'),
(48836, 3922, 13, 'НОВЫЙ ПАЦИЕНТ'),
(48837, 3923, 13, 'Обращение нового пациента'),
(48838, 3924, 13, 'Форма для нового пациента'),
(48839, 3925, 13, 'ID нового пациента'),
(48840, 3926, 13, 'Новая оплата'),
(48841, 3928, 13, 'Новый пункт'),
(48842, 3929, 13, 'Новые результаты из Lab Exchange'),
(48843, 3930, 13, 'Новый поиск'),
(48844, 3931, 13, 'Новое рассмотрение'),
(48845, 3932, 13, 'Новый пользователь'),
(48846, 3934, 13, 'Новое посещение'),
(48847, 3935, 13, 'Новый или поиск'),
(48848, 3936, 13, 'Состояние аккаунта NewCrop'),
(48849, 3937, 13, 'Администрирование NewCrop'),
(48850, 3938, 13, 'Вызов NewCrop дал сбой'),
(48851, 3939, 13, 'Врач NewCrop'),
(48852, 3944, 13, 'Наименование eRx NewCrop'),
(48853, 3945, 13, 'Наименование партнера eRx NewCrop'),
(48854, 3946, 13, 'Пароль eRx NewCrop'),
(48855, 3947, 13, 'Уровень доступа eRx NewCrop'),
(48856, 3948, 13, 'Уровень доступа eRx NewCrop'),
(48857, 3949, 13, 'Адрес узла eRx NewCrop'),
(48858, 3954, 13, 'Адрес веб-службы eRx NewCrop'),
(48859, 3955, 13, 'Менеджер NewCrop'),
(48860, 3956, 13, 'Мед. запись для NewCrop'),
(48861, 3957, 13, 'Врач с правом назначения рецептурных препаратов среднего уровня для NewCrop'),
(48862, 3958, 13, 'Медсестра NewCrop'),
(48863, 3959, 13, 'Контролирующий врач для NewCrop'),
(48864, 3961, 13, 'Газета'),
(48865, 3962, 13, 'Следующий'),
(48866, 3964, 13, 'Следующий день'),
(48867, 3965, 13, 'Следующий месяц'),
(48868, 3966, 13, 'Следующий месяц (фиксация для меню)'),
(48869, 3968, 13, 'Следующая неделя'),
(48870, 3969, 13, 'Следующий год (фиксация для меню)'),
(48871, 3971, 13, 'Псевдоним'),
(48872, 3973, 13, 'Ночная потливость'),
(48873, 3974, 13, 'Nl наружных половых органов, слизистой влагалища, шейки матки'),
(48874, 3975, 13, 'Нет'),
(48875, 3976, 13, 'НЕТ'),
(48876, 3977, 13, 'Нет доступа'),
(48877, 3978, 13, 'Активных напоминаний для пациента нет.'),
(48878, 3979, 13, 'Аденопатии нет (обязательно 2 области)'),
(48879, 3980, 13, 'Не найден тип причины корректировки для'),
(48880, 3981, 13, 'Болезненность/новообразование придатков'),
(48881, 3983, 13, 'Записи на прием нет'),
(48882, 3985, 13, 'В настоящее время биллинговая система неактивна'),
(48883, 3987, 13, 'Для включения в экспорт OFX счетов не выявлено<br>'),
(48884, 3989, 13, 'Не указан код!'),
(48885, 3992, 13, 'Нет диагноза'),
(48886, 3993, 13, 'Никаких документов не найдено'),
(48887, 3995, 13, 'Нет даты окончания');
INSERT INTO `lang_definitions` VALUES
(48888, 3996, 13, 'Ни одной записи не выявлено, для добавления записи используйте форму ниже.'),
(48889, 3997, 13, 'Ошибок не найдено'),
(48890, 3998, 13, 'Событий нет'),
(48891, 4001, 13, 'Никакая группа не выбрана'),
(48892, 4002, 13, 'Грыжевых выпячиваний нет'),
(48893, 4005, 13, 'Без травмы/заболевания'),
(48894, 4006, 13, 'Не найдено страховых компаний'),
(48895, 4007, 13, 'Результатов нет'),
(48896, 4009, 13, 'В выбранной категории нет пунктов'),
(48897, 4010, 13, 'Не выбран ни один пункт!'),
(48898, 4025, 13, 'Для выбранной даты лог-файла нет'),
(48899, 4027, 13, 'Безболезненно, новообразований нет'),
(48900, 4028, 13, 'Для предоставленного кода повторной идентификации соответствующей записи по пациенту нет.'),
(48901, 4030, 13, 'Соответствий не найдено.'),
(48902, 4031, 13, 'Совпадений не найдено. Оформить нового пациента?'),
(48903, 4033, 13, 'Новых результатов не найдено'),
(48904, 4034, 13, 'Нет записей'),
(48905, 4035, 13, 'No ogrganomegoly'),
(48906, 4036, 13, 'За этот период открытых не найдено.'),
(48907, 4037, 13, 'Никаких других телефонных номеров нет.'),
(48908, 4039, 13, 'Партнеры не найдены'),
(48909, 4040, 13, 'Для предоставленного критерия выбора записи по пациенту не нейдено.'),
(48910, 4041, 13, 'Для предоставленного кода повторной идентификации записи по пациенту не нейдено.'),
(48911, 4042, 13, 'Периферических отеков нет'),
(48912, 4043, 13, 'Ни одной аптеки не найдено'),
(48913, 4044, 13, 'Назначений не найдено'),
(48914, 4045, 13, 'Заболевание/травма не представлено'),
(48915, 4046, 13, 'Предыдущих вводов не было'),
(48916, 4047, 13, 'В списке услуг нет выбранного основного юридического лица'),
(48917, 4051, 13, 'Специалисты не найдены'),
(48918, 4052, 13, 'Сыпи или необычных телесных изменения нет'),
(48919, 4053, 13, 'Записей не найдено'),
(48920, 4055, 13, 'Ни одной записи не найдено. Расширьте критерий поиска.'),
(48921, 4056, 13, 'Напоминаний нет'),
(48922, 4057, 13, 'Для указанного критерия поиска результатов не найдено.'),
(48923, 4058, 13, 'Результатов нет'),
(48924, 4060, 13, 'При поиске результатов не найдено.'),
(48925, 4062, 13, 'Результатов нет, попытайтесь еще раз.'),
(48926, 4063, 13, 'Результатов нет, попробуйте снова.'),
(48927, 4065, 13, 'Не показывать'),
(48928, 4067, 13, 'Пазухи безболезненны:'),
(48929, 4068, 13, 'Без кожной лимонной корочки или узлов молочной железы'),
(48930, 4069, 13, 'ТАКОГО КОНТЕКСТНОГО ИМЕНИ НЕТ'),
(48931, 4071, 13, 'Яички безболезненны, новообразований нет'),
(48932, 4072, 13, 'Без дрожания грудной стенки или выбухания'),
(48933, 4075, 13, 'Нет посещений'),
(48934, 4076, 13, 'Жизненно важные показатели не были зарегистрированы.'),
(48935, 4077, 13, 'Нет, отменить'),
(48936, 4078, 13, 'Безошибочное страхование, включая автоматическое, будет основным'),
(48937, 4079, 13, 'Нет:'),
(48938, 4080, 13, 'Ноктурия'),
(48939, 4081, 13, 'Не оплачено'),
(48940, 4082, 13, 'Несообщенный отчет'),
(48941, 4083, 13, 'Нет конкретного повреждения'),
(48942, 4084, 13, 'Неэлектронный'),
(48943, 4085, 13, 'Инсулинонезависимый диабет'),
(48944, 4087, 13, 'Медицинское сексуальное и репродуктивное здоровье'),
(48945, 4088, 13, 'Немедицинское сексуальное и репродуктивное здоровье'),
(48946, 4089, 13, 'Нет'),
(48947, 4090, 13, 'нет'),
(48948, 4091, 13, 'Не определено'),
(48949, 4092, 13, 'Не зарегистрировано'),
(48950, 4093, 13, 'Нет из вышеуказанного'),
(48951, 4094, 13, 'Ни одна основная строка предоставления не может быть полностью пустой.'),
(48952, 4095, 13, 'Инсулинонезависимый диабет'),
(48953, 4096, 13, 'Также не'),
(48954, 4097, 13, 'Обычная'),
(48955, 4098, 13, 'Обычный BL'),
(48956, 4099, 13, 'Обычное кардиологическое обследование:'),
(48957, 4100, 13, 'Обычное кардиологическое обследование: '),
(48958, 4101, 13, 'Обычное пульмонологическое обследование:'),
(48959, 4102, 13, 'Обычное пульмонологическое обследование: '),
(48960, 4103, 13, 'Обычное посещение в кабинете'),
(48961, 4104, 13, 'Обычный Oropharynx:'),
(48962, 4105, 13, 'Обычный справа'),
(48963, 4106, 13, 'Обычный справа:'),
(48964, 4107, 13, 'Обычный вид'),
(48965, 4108, 13, 'обычный:'),
(48966, 4109, 13, 'Обычно, должно быть проверено. Не связано с управлением доступом.'),
(48967, 4112, 13, 'Норвежский'),
(48968, 4115, 13, 'Нос'),
(48969, 4116, 13, 'Носовое кровотечение'),
(48970, 4117, 13, 'нет буквы или цифры'),
(48971, 4119, 13, 'Не все поля требуются для всех кодов или типов кодов.'),
(48972, 4120, 13, 'Не разрешено'),
(48973, 4121, 13, 'Группу администраторов удалять не разрешено'),
(48974, 4122, 13, 'Редактирование не разрешено'),
(48975, 4123, 13, 'Инактивация всех объектов безопасности не разрешена'),
(48976, 4124, 13, 'Ничего из ACL администраторов инактивировать не разрешено'),
(48977, 4125, 13, 'Удалять пользователя из группы администраторов не разрешено'),
(48978, 4126, 13, 'Удалять этого пользователя из группы администраторов не разрешено'),
(48979, 4128, 13, 'Доступ к модулю PostCalendar не разрешен'),
(48980, 4129, 13, 'Нет доступа'),
(48981, 4130, 13, 'Доступ не разрешен'),
(48982, 4131, 13, 'Для этой команды нет доступа!'),
(48983, 4132, 13, 'Для этой группы доступ не разрешен'),
(48984, 4135, 13, 'Не доступно'),
(48985, 4137, 13, 'Счет не выставлен'),
(48986, 4138, 13, 'Не зарегистрировано'),
(48987, 4139, 13, 'Не проверено'),
(48988, 4141, 13, 'Не подлежит'),
(48989, 4143, 13, 'Не обследован'),
(48990, 4144, 13, 'Не обследован:'),
(48991, 4145, 13, 'Не обследован: '),
(48992, 4146, 13, 'не найден'),
(48993, 4148, 13, 'не найден!'),
(48994, 4149, 13, 'Не выходец из Латинской Америки или латино'),
(48995, 4152, 13, 'Не отправлен'),
(48996, 4153, 13, 'Не отправлен'),
(48997, 4154, 13, 'Еще не отправлено'),
(48998, 4156, 13, 'Без указания.'),
(48999, 4157, 13, 'Примечание'),
(49000, 4158, 13, 'Кодировка записи'),
(49001, 4159, 13, 'Учтите, что это займет 5-10 минут для полной обработки после того, как вы нажмете Установить'),
(49002, 4160, 13, 'Учтите, что это займет 5-10 минут для полной обработки после того, как вы нажмете Модернизировать'),
(49003, 4161, 13, 'Учтите, что аудит журналирования должен быть включен выше'),
(49004, 4162, 13, 'Тип записи'),
(49005, 4168, 13, 'Примечание: этот код был введен пользователем без разрешенного доступа. Только разрешенные коды могут быть загружены для обработки в Открытую Биллинговую Медицинскую Сеть. Если хотите загрузить эти коды, выберите здесь авторизованого пользователя.'),
(49006, 4170, 13, 'Примечание: загрузка файлов с одинаковыми именами приведет к автоматическому измененению файлов (к примеру, file.jpg станет file.1.jpg). Имена файлов считаются уникальными для одного пациента, а не для каждой категории.'),
(49007, 4171, 13, 'Примечание: загрузка файлов с одинаковыми именами приведет к автоматическому переименованию файлов. К примеру '' file.jpg'' станет '' file.jpg.1''. Имена файлов считаются уникальными для одного пациента, а не для каждой категории.'),
(49008, 4172, 13, 'Записи'),
(49009, 4173, 13, 'Записи - любые обращения (write,addonly необязательно)'),
(49010, 4174, 13, 'Записи - мои обращения (write,addonly необязательно)'),
(49011, 4175, 13, 'Доступ к записям не разрешен'),
(49012, 4177, 13, 'Ничего не записано'),
(49013, 4179, 13, 'Ничего не импортировано для аллергии'),
(49014, 4180, 13, 'Ничего не импортировано для назначения'),
(49015, 4182, 13, 'Ничего не выбрано'),
(49016, 4184, 13, 'УВЕДОМЛЕНИЕ:: предоставление или изменение PostCalendar'),
(49017, 4185, 13, 'Уведомление'),
(49018, 4186, 13, 'Адрес e-mail для уведомления'),
(49019, 4188, 13, 'Уведомления'),
(49020, 4189, 13, 'Уведомлять администратора об оказанных или измененных событиях?'),
(49021, 4190, 13, 'Нояб'),
(49022, 4191, 13, 'Ноябрь'),
(49023, 4192, 13, 'Новая отправка для:'),
(49024, 4193, 13, 'Идет печать'),
(49025, 4194, 13, 'Теперь печать заявки $stmt_count и обновленные обращения.'),
(49026, 4195, 13, 'Теперь печать заявки $stmt_count и обновленные счета.'),
(49027, 4196, 13, 'Теперь печать заявки $stmt_count; обращения не будут обновлены.'),
(49028, 4197, 13, 'Теперь печать заявки $stmt_count; счета не будут обновлены.'),
(49029, 4198, 13, 'NPI'),
(49030, 4199, 13, 'NQF'),
(49031, 4200, 13, 'Номер'),
(49032, 4201, 13, 'Номер лаб.'),
(49033, 4204, 13, 'Количество столбцов в обзоре за год.'),
(49034, 4211, 13, 'Количество дней, на протяжении которых сертификат клиента действителен.'),
(49035, 4213, 13, 'Количество цифр после десятичной запятой для денег, обычно 0 или 2.'),
(49036, 4214, 13, 'Количество отображаемых обращений на странице.'),
(49037, 4215, 13, 'Количество воспроизведений или событий пропущено, если применимо'),
(49038, 4216, 13, 'Количество часов на выполнение отправки уведомления e-mail.'),
(49039, 4217, 13, 'Количество часов на выполнение телефонограммы.'),
(49040, 4218, 13, 'Количество часов на выполнение отправки SMS-уведомления.'),
(49041, 4221, 13, 'Количество столбцов для анамнеза'),
(49042, 4223, 13, 'Нечувствительность'),
(49043, 4224, 13, 'Нумератор'),
(49044, 4225, 13, 'Порядок цифрового отображения'),
(49045, 4227, 13, 'Питание'),
(49046, 4229, 13, 'O.A.F.V.'),
(49047, 4230, 13, 'O2 Sat'),
(49048, 4231, 13, 'Ожирение I ст.'),
(49049, 4232, 13, 'Ожирение II ст.'),
(49050, 4233, 13, 'Ожирение III ст.'),
(49051, 4234, 13, 'Объективно'),
(49052, 4237, 13, 'Профессия'),
(49053, 4239, 13, 'Проявление'),
(49054, 4240, 13, 'Окт'),
(49055, 4241, 13, 'Октябрь'),
(49056, 4242, 13, 'OD'),
(49057, 4243, 13, 'из'),
(49058, 4244, 13, 'из количества'),
(49059, 4245, 13, 'таблеток'),
(49060, 4246, 13, 'месяца каждый'),
(49061, 4247, 13, 'Служ. записи'),
(49062, 4248, 13, 'вне'),
(49063, 4249, 13, 'Служебные записи'),
(49064, 4250, 13, 'Посещение кабинета'),
(49065, 4251, 13, 'Группы сравнения для официальной клинической единицы измерения качества (CQM)'),
(49066, 4252, 13, 'Внешняя связь Https для этого портала пациента.'),
(49067, 4253, 13, 'Внешняя связь Https для портала пациента. (Ссылка пациента)'),
(49068, 4254, 13, 'Пароль портала для сторонних пациентов'),
(49069, 4255, 13, 'Пароль портала для сторонних пациентов (если не зарегестрированы, то введите пустой),'),
(49070, 4258, 13, 'Адрес сайта для портала сторонних пациентов'),
(49071, 4259, 13, 'Внешний адрес портала пациента. (Ссылка пациента)'),
(49072, 4260, 13, 'Имя пользователя порталом для сторонних пациентов'),
(49073, 4261, 13, 'Имя пользователя порталом для сторонних пациентов (оставьте пустым, если незарегистрирован)'),
(49074, 4263, 13, 'Потомство'),
(49075, 4265, 13, 'мазь'),
(49076, 4267, 13, 'OK'),
(49077, 4269, 13, 'OK для связи этой датированной проблемы GCAC'),
(49078, 4270, 13, 'Старый'),
(49079, 4272, 13, 'Бывшие клиенты'),
(49080, 4273, 13, 'Нестарый перелом / неправильно сросшийся'),
(49081, 4274, 13, 'Макет старого стиля без меню слева'),
(49082, 4275, 13, 'Статичная форма старого стиля без поиска или двойной проверки'),
(49083, 4279, 13, 'Пропускает информацию о месте работы в персональных данных пациента'),
(49084, 4280, 13, 'Пропустить место работы'),
(49085, 4281, 13, 'Форма, способ и частота введения,которые затем станут частью дозировки, пропущены'),
(49086, 4282, 13, 'Страховка и некоторые другие пункты формы персональных данных пропущены'),
(49087, 4283, 13, 'Исключить внутренних пользователей?'),
(49088, 4284, 13, 'Исключение способа оплаты из панели доплаты'),
(49089, 4285, 13, 'пропустить для автоматического назначения'),
(49090, 4286, 13, 'в'),
(49091, 4287, 13, 'в'),
(49092, 4288, 13, 'на руках'),
(49093, 4289, 13, 'В назначении'),
(49094, 4290, 13, 'на месте'),
(49095, 4291, 13, 'После установки компонента основного бизнеса ее нельзя изменять. Изменение компонента повлияет на работающих в ePrescription NewCrop.'),
(49096, 4292, 13, 'После изменения своего пароля вы должны повторно войти в систему.'),
(49097, 4297, 13, 'Поддержка он-лайн'),
(49098, 4298, 13, 'Ссылка поддержки он-лайн'),
(49099, 4299, 13, 'Только активные'),
(49100, 4302, 13, 'только для размещения счетов'),
(49101, 4303, 13, 'Только неактивные'),
(49102, 4304, 13, 'Только мои'),
(49103, 4307, 13, 'Только загруженные активные предписания'),
(49104, 4310, 13, 'Начало заболевания:'),
(49105, 4311, 13, 'Начало заболевания: '),
(49106, 4312, 13, 'Появление новообразования:'),
(49107, 4313, 13, 'Дата нач./госп.'),
(49108, 4314, 13, 'Адрес сайта для портала внутренних пациентов'),
(49109, 4315, 13, 'Оплошность!'),
(49110, 4316, 13, 'Открыть'),
(49111, 4321, 13, 'Открыть посещение за сегодня'),
(49112, 4322, 13, 'LibreEHR уже имеет настроенный доверенный сертификат.'),
(49113, 4324, 13, 'Модернизация базы данных LibreEHR'),
(49114, 4325, 13, 'Модернизация базы данных LibreEHR для исключения дублирования идентификации'),
(49115, 4327, 13, 'До того, как LibreEHR сможет создавать клиентские сертификаты, он должен быть настроен для использования сертификатов.'),
(49116, 4328, 13, 'Для выполнения аутентификации пользователя LibreEHR необходим Javascript.'),
(49117, 4329, 13, 'Пользователи LibreEHR'),
(49118, 4330, 13, 'Вступление'),
(49119, 4332, 13, 'Глазной'),
(49120, 4333, 13, 'Опция'),
(49121, 4335, 13, 'Опция для поддержки инвентаризации и реализации материальных ценностей'),
(49122, 4336, 13, 'Необязательное'),
(49123, 4337, 13, 'Необязательное имя категории для ID-карты изображения, которое можно просмотреть на странице сводки по пациенту.'),
(49124, 4338, 13, 'Необязательное имя категории для фото-изображений, которое можно просмотреть на странице сводки по пациенту.'),
(49125, 4339, 13, 'Необязательное имя категории документа для связывания со страницы сводки по пациенту. Кликните на имени пациента, чтобы увидеть ее ID-карту.'),
(49126, 4340, 13, 'Необязательный диапазан по умолчанию для ввода результатов вручную'),
(49127, 4341, 13, 'Необязательные единицы измерения для ввода результатов вручную'),
(49128, 4342, 13, 'Необязательное наименование места назначения'),
(49129, 4343, 13, 'Необязательное наименование препарата, используйте % как знак подстановки'),
(49130, 4345, 13, 'Необязательная информация об этом событии'),
(49131, 4346, 13, 'Необязательное количество партии, используйте % как знак подстановки'),
(49132, 4347, 13, 'Необязательный номер ID пациента'),
(49133, 4348, 13, 'Необязательный код методики'),
(49134, 4350, 13, 'Опции'),
(49135, 4351, 13, 'или'),
(49136, 4352, 13, 'ИЛИ'),
(49137, 4353, 13, 'или измените'),
(49138, 4354, 13, 'или нажмите и проведите для быстрого выделения.'),
(49139, 4356, 13, 'или для'),
(49140, 4358, 13, 'или кликните с Shift для его выделения'),
(49141, 4359, 13, 'или обновите файл ERA:'),
(49142, 4360, 13, 'Перорально'),
(49143, 4361, 13, 'Слизистая полости рта розовая, глотка чистая'),
(49144, 4362, 13, 'Порядок'),
(49145, 4363, 13, 'Типы назначения и выполнения'),
(49146, 4364, 13, 'Каталог назначений'),
(49147, 4365, 13, 'Дата назначения'),
(49148, 4367, 13, 'Назначение от'),
(49149, 4369, 13, 'Порядок должен быть номером от 1 до 999'),
(49150, 4370, 13, 'Наименование назначения'),
(49151, 4371, 13, 'Приоритет назначения'),
(49152, 4372, 13, 'Обработчик предписаний'),
(49153, 4375, 13, 'Статус порядка следования'),
(49154, 4378, 13, 'Тип назначения'),
(49155, 4380, 13, 'Тип назначения/выполнения'),
(49156, 4381, 13, 'Назначено'),
(49157, 4384, 13, 'Назначающий специалист'),
(49158, 4386, 13, 'Повреждение органа'),
(49159, 4387, 13, 'Организация'),
(49160, 4388, 13, 'Наименование организации'),
(49161, 4389, 13, 'Наименование подразделения организации'),
(49162, 4390, 13, 'Организации'),
(49163, 4391, 13, 'Ориентированный x 3'),
(49164, 4392, 13, 'Оригинал'),
(49165, 4396, 13, 'РОТОГЛОТКА: '),
(49166, 4397, 13, 'Ортопное'),
(49167, 4398, 13, 'OS'),
(49168, 4399, 13, 'Остеоартриты'),
(49169, 4402, 13, 'Другое'),
(49170, 4403, 13, 'другое'),
(49171, 4404, 13, 'Другое (указать)'),
(49172, 4405, 13, 'Другое - указанное'),
(49173, 4406, 13, 'Другая государственная программа'),
(49174, 4407, 13, 'Другая Финансовая Администрация здравоохранения'),
(49175, 4408, 13, 'Другие неуказанные повреждения'),
(49176, 4409, 13, 'Основной является другая ответственная страховка'),
(49177, 4410, 13, 'другой месяц'),
(49178, 4411, 13, 'Другая негосударственная программа'),
(49179, 4412, 13, 'Прочие записи'),
(49180, 4413, 13, 'Другие уместные симптомы'),
(49181, 4414, 13, 'Другие уместные симптомы:'),
(49182, 4415, 13, 'Др. соотв. пун.'),
(49183, 4416, 13, 'Другие воздействия или общее повреждение'),
(49184, 4417, 13, 'Другие оперативные вмешательства'),
(49185, 4418, 13, 'Другие/связанные с прерыванием беременности'),
(49186, 4420, 13, 'Другие'),
(49187, 4421, 13, 'в противном случае вы нарушите ссылки в/из существующей даты.'),
(49188, 4422, 13, 'Правила Ottawa Ankle'),
(49189, 4423, 13, 'В оба глаза'),
(49190, 4424, 13, 'НЕ РАБОТАЕТ'),
(49191, 4425, 13, 'НЕ НА МЕСТЕ'),
(49192, 4426, 13, 'Направление за рубеж'),
(49193, 4427, 13, 'Исход'),
(49194, 4428, 13, 'Наблюдение'),
(49195, 4431, 13, 'OVERDUE'),
(49196, 4432, 13, 'Злоупотребление'),
(49197, 4434, 13, 'Избыточный вес'),
(49198, 4435, 13, 'Переписать выбор HIPAA (Закон об отчетности и безопасности медицинского страхования)'),
(49199, 4437, 13, 'Сатурация кислорода'),
(49200, 4439, 13, 'P'),
(49201, 4440, 13, 'проц.'),
(49202, 4441, 13, 'после полудня'),
(49203, 4442, 13, 'по необх.'),
(49204, 4443, 13, 'Тихоокеанский островитянин'),
(49205, 4444, 13, 'Педиатрический'),
(49206, 4445, 13, 'Страница'),
(49207, 4446, 13, 'Страницы'),
(49208, 4447, 13, 'Оплатить'),
(49209, 4448, 13, 'Сумма оплаты, которую вы внесете'),
(49210, 4450, 13, 'Оплатить через'),
(49211, 4451, 13, 'Боль'),
(49212, 4453, 13, 'Сердцебиения'),
(49213, 4455, 13, 'Мазок Папаниколау'),
(49214, 4457, 13, 'Размер бумаги'),
(49215, 4458, 13, 'Паралич'),
(49216, 4461, 13, 'Обработать HL7'),
(49217, 4463, 13, 'Партнерское'),
(49218, 4464, 13, 'Наименование партнера'),
(49219, 4467, 13, 'Пароль'),
(49220, 4468, 13, 'Пароль для шифрования документа'),
(49221, 4469, 13, 'Переданные пациенты'),
(49222, 4470, 13, 'Пассивное извещение'),
(49223, 4471, 13, 'Правила пассивных извещений'),
(49224, 4472, 13, 'Пароль'),
(49225, 4473, 13, 'Изменение пароля'),
(49226, 4475, 13, 'Изменение пароля выполнено успешно.'),
(49227, 4477, 13, 'Период действия пароля'),
(49228, 4479, 13, 'Пароль для телефонного шлюза. Автоматизированная служба VOIP предоставлена через Maviq. Посетите http://signup.maviq.com для получения дополнительной информации.'),
(49229, 4480, 13, 'Пароль для шлюза SMS'),
(49230, 4481, 13, 'Пароль для шлюза SMS.'),
(49231, 4483, 13, 'Надежность пароля недавно была улучшена.'),
(49232, 4486, 13, 'Пароль:'),
(49233, 4490, 13, 'Просроченный'),
(49234, 4491, 13, 'Просроченный'),
(49235, 4492, 13, 'Наивысший интервал ожидания (клинические напоминания)'),
(49236, 4493, 13, 'Наивысший интервал ожидания (напоминания для пациента)'),
(49237, 4494, 13, 'Список прошлых обращений'),
(49238, 4495, 13, 'Прошлые обращения'),
(49239, 4496, 13, 'Прошлые обращения и документы'),
(49240, 4497, 13, 'Прошлые обращения для'),
(49241, 4498, 13, 'Вставить данные HL7'),
(49242, 4499, 13, 'Вставьте в текстовую область ниже данные для импорта:'),
(49243, 4500, 13, 'Подходящий'),
(49244, 4502, 13, 'Исправление'),
(49245, 4508, 13, 'Путь для журнала резервного копирования событий'),
(49246, 4509, 13, 'Путь к файлу сертификата CA'),
(49247, 4510, 13, 'Путь к файлу ключа CA'),
(49248, 4511, 13, 'Путь к бинарникам MySQL'),
(49249, 4512, 13, 'Путь к бинарникам Perl'),
(49250, 4513, 13, 'Путь к временным файлам'),
(49251, 4514, 13, 'Пациент'),
(49252, 4515, 13, 'пациент'),
(49253, 4516, 13, 'ПАЦИЕНТ'),
(49254, 4517, 13, 'Адрес пациента'),
(49255, 4518, 13, 'Пропущен адрес пациента'),
(49256, 4521, 13, 'Аллергия у пациента'),
(49257, 4522, 13, 'Аллергия у пациента'),
(49258, 4523, 13, 'Запись на прием для пациента'),
(49259, 4528, 13, 'ID карты пациента'),
(49260, 4529, 13, 'Исполнительный расчет'),
(49261, 4530, 13, 'Исполнительный расчет для _ '),
(49262, 4531, 13, 'Город пациента'),
(49263, 4532, 13, 'Пропущен город пациента'),
(49264, 4533, 13, 'Установка связи с пациентом'),
(49265, 4534, 13, 'Установка связи с пациентом'),
(49266, 4535, 13, 'Страна пациента'),
(49267, 4536, 13, 'Пропущена страна пациента. И в глобальных настройках она не установлена по умолчанию'),
(49268, 4539, 13, 'Данные по пациенту'),
(49269, 4541, 13, 'Пропущена дата рождения пациента'),
(49270, 4542, 13, 'Сведения о пациенте'),
(49271, 4543, 13, 'Дата рожд. пациента'),
(49272, 4544, 13, 'Документ пациента'),
(49273, 4545, 13, 'Образование пациента'),
(49274, 4546, 13, 'Сведения об образовании пациента'),
(49275, 4547, 13, 'Обращение пациента'),
(49276, 4548, 13, 'Форма обращения пациента'),
(49277, 4549, 13, 'Обращения пациента'),
(49278, 4550, 13, 'Указатель для поиска пациента'),
(49279, 4551, 13, 'Имя пациента'),
(49280, 4553, 13, 'Пропущено имя пациента'),
(49281, 4558, 13, 'Пол пациента'),
(49282, 4559, 13, 'Пропущен пол пациента'),
(49283, 4560, 13, 'Пациенту доступ к порталу не разрешен.'),
(49284, 4561, 13, 'Анамнез пациента'),
(49285, 4562, 13, 'Анамнез/образ жизни пациента'),
(49286, 4563, 13, 'Домашний телефон пациента'),
(49287, 4564, 13, 'ID пациента'),
(49288, 4566, 13, 'ID карты пациента'),
(49289, 4567, 13, 'Наименование категории для ID пациента'),
(49290, 4568, 13, 'Вакцинация пациента'),
(49291, 4569, 13, 'Информация о пациенте'),
(49292, 4570, 13, 'Инструкции для пациента'),
(49293, 4571, 13, 'Реализация страхования пациента'),
(49294, 4572, 13, 'Отчет о предоставленной страховке пациента'),
(49295, 4573, 13, 'Проблемы пациента'),
(49296, 4575, 13, 'Фамилия пациента'),
(49297, 4577, 13, 'Пропущена фамилия пациента'),
(49298, 4581, 13, 'Список пациента'),
(49299, 4586, 13, 'Ошибки поиска пациента'),
(49300, 4587, 13, 'Медицинские проблемы пациента'),
(49301, 4588, 13, 'Медикаменты для пациента'),
(49302, 4589, 13, 'Наименование пациента'),
(49303, 4590, 13, 'Фамилия и адрес пациента'),
(49304, 4593, 13, 'Наименование пациента обязательно'),
(49305, 4595, 13, 'Запись по пациенту'),
(49306, 4596, 13, 'Типы записей по пациенту'),
(49307, 4597, 13, 'Записи по пациенту'),
(49308, 4598, 13, 'Записи по пациенту (write,addonly необязательно)'),
(49309, 4599, 13, 'Номер пациента'),
(49310, 4600, 13, 'Исполнительная оплата по пациенту'),
(49311, 4602, 13, 'Наименование категории для фотографии пациента'),
(49312, 4603, 13, 'Портал пациента'),
(49313, 4605, 13, 'Портал пациента отключен'),
(49314, 4606, 13, 'Вход в портал пациента'),
(49315, 4607, 13, 'Веб-адрес портала пациента'),
(49316, 4608, 13, 'Печатный отчет о пациенте'),
(49317, 4609, 13, 'Регистрационный отчет о пациенте'),
(49318, 4610, 13, 'Регистрационный запрос о пациенте'),
(49319, 4611, 13, 'Регистрационные запросы о пациенте'),
(49320, 4613, 13, 'Напоминание о пациенте'),
(49321, 4614, 13, 'Групповое использование напоминания о пациенте'),
(49322, 4616, 13, 'Правила напоминания о пациенте'),
(49323, 4617, 13, 'E-mail отправителя напоминаний о пациенте'),
(49324, 4618, 13, 'Фамилия отправителя напоминаний о пациенте'),
(49325, 4619, 13, 'Напоминания о пациенте'),
(49326, 4620, 13, 'Отчет о пациенте'),
(49327, 4621, 13, 'Запрос о пациенте'),
(49328, 4622, 13, 'Запрошенные истории болезни пациента'),
(49329, 4623, 13, 'Результаты по пациенту'),
(49330, 4624, 13, 'Стиль выполнения поиска пациента'),
(49331, 4625, 13, 'Отображение поиска/добавления пациента'),
(49332, 4626, 13, 'Настройка по пациенту'),
(49333, 4627, 13, 'Состояние пациента'),
(49334, 4629, 13, 'Итог по пациенту'),
(49335, 4630, 13, 'Транзакции по пациенту'),
(49336, 4631, 13, 'Почтовый индекс пациента'),
(49337, 4632, 13, 'пациент(ы) в базе данных, которому соответствует информация по введенным персональным данным.'),
(49338, 4633, 13, 'Пациент/посетитель'),
(49339, 4634, 13, 'Пациент:'),
(49340, 4635, 13, 'ID пац.'),
(49341, 4636, 13, 'Пациенты'),
(49342, 4638, 13, 'Оплата'),
(49343, 4639, 13, 'Обратите внимание на флажки "Готово с". После завершения заполнения страхования мы будем просить пациента оплатить остаток; если не заполните всю страховку, то оставшаяся сумма не будет собрана! Также, если имеется оставшаяся сумма, которую пациент должен оплатить, установите положенный срок надлежащим образом, так как это скажется на формулировке, которая предоставляется по калькуляции пациента.'),
(49344, 4640, 13, 'Дата оплаты:'),
(49345, 4641, 13, 'Статус платы'),
(49346, 4642, 13, 'Наименование получателя платежа'),
(49347, 4643, 13, 'Плательщик'),
(49348, 4644, 13, 'Тип плательщика'),
(49349, 4645, 13, 'Платеж'),
(49350, 4646, 13, 'Оплачивающее лицо'),
(49351, 4647, 13, 'Оплата'),
(49352, 4648, 13, 'оплата'),
(49353, 4649, 13, 'Код корректировки оплаты'),
(49354, 4651, 13, 'Сумма к оплате'),
(49355, 4652, 13, 'Сумма к оплате должна быть цифровой'),
(49356, 4653, 13, 'Категория оплаты'),
(49357, 4654, 13, 'Дата платежа'),
(49358, 4655, 13, 'оплата, внесенная на'),
(49359, 4656, 13, 'Оплата от'),
(49360, 4658, 13, 'Вст. оплаты'),
(49361, 4659, 13, 'Список оплаты'),
(49362, 4660, 13, 'Метод оплаты'),
(49363, 4661, 13, 'Сортировка оплаты по'),
(49364, 4662, 13, 'Статус оплаты'),
(49365, 4663, 13, 'Тип оплаты'),
(49366, 4664, 13, 'Значение оплаты для кода '),
(49367, 4665, 13, 'Платежи'),
(49368, 4667, 13, 'PCP'),
(49369, 4669, 13, 'PDF'),
(49370, 4670, 13, 'Загруженные в PDF выбранные заявки'),
(49371, 4672, 13, 'Область таза и ягодиц'),
(49372, 4673, 13, 'Пузырчатка'),
(49373, 4674, 13, 'Ожидающий'),
(49374, 4676, 13, 'Ожидающий прод.'),
(49375, 4677, 13, 'Ожидающий продолжения'),
(49376, 4678, 13, 'Ожидание ответа результатов'),
(49377, 4679, 13, 'Ожидающие назначения'),
(49378, 4680, 13, 'Ожидающие иссл.'),
(49379, 4681, 13, 'Ожидающий просмотра'),
(49380, 4682, 13, 'Ожидающий подсчета Rx'),
(49381, 4684, 13, 'LibreEHR для фирмы Pennington v'),
(49382, 4687, 13, 'Язвенная болезнь'),
(49383, 4688, 13, 'в мин.'),
(49384, 4689, 13, 'В ноздрю'),
(49385, 4690, 13, 'Перорально'),
(49386, 4691, 13, 'перорально'),
(49387, 4692, 13, 'Ректально'),
(49388, 4693, 13, 'ректально'),
(49389, 4694, 13, 'Процент'),
(49390, 4697, 13, 'Процентиль'),
(49391, 4698, 13, 'Перфорированный справа:'),
(49392, 4699, 13, 'Выполнить поиск'),
(49393, 4700, 13, 'Выполняет это действие'),
(49394, 4701, 13, 'Предоставить в процентах'),
(49395, 4703, 13, 'Выполнение лабораторной услуги'),
(49396, 4705, 13, 'Период'),
(49397, 4706, 13, 'Период в днях, когда пользователь может войти в систему с истекшим паролем.'),
(49398, 4707, 13, 'Периоперационное лечение'),
(49399, 4708, 13, 'Периферический'),
(49400, 4712, 13, 'Человек'),
(49401, 4713, 13, 'Персонализация'),
(49402, 4714, 13, 'PG'),
(49403, 4715, 13, 'Апт.'),
(49404, 4716, 13, 'Общ. апт. счет'),
(49405, 4717, 13, 'Аптеки'),
(49406, 4718, 13, 'Аптека'),
(49407, 4719, 13, 'Аптечное отделение'),
(49408, 4720, 13, 'Пневмоторакс'),
(49409, 4729, 13, 'Телефон'),
(49410, 4730, 13, 'Список телефонных звонков'),
(49411, 4733, 13, 'Пароль для телефонного шлюза'),
(49412, 4734, 13, 'URL для телефонного шлюза'),
(49413, 4735, 13, 'Имя пользователя для шлюза телефона'),
(49414, 4737, 13, 'Время телефонограммы'),
(49415, 4738, 13, 'Номер телефона'),
(49416, 4740, 13, 'Светобоязнь'),
(49417, 4741, 13, 'Фото'),
(49418, 4742, 13, 'PHP сжат'),
(49419, 4743, 13, 'Модуль CURL для PHP на вашем сервере должен быть включен.'),
(49420, 4744, 13, 'PHP извлечен'),
(49421, 4745, 13, 'управление доступом php-GACL отключено'),
(49422, 4746, 13, 'PHP-gacl не установлен'),
(49423, 4747, 13, 'Физикальное обследование'),
(49424, 4749, 13, 'Врачебный запрос'),
(49425, 4750, 13, 'Подпись врача'),
(49426, 4752, 13, 'Терапевты'),
(49427, 4753, 13, 'выбрать'),
(49428, 4754, 13, 'Выбрать'),
(49429, 4755, 13, 'Выберите тему CSS.'),
(49430, 4756, 13, 'ВЗМТ'),
(49431, 4757, 13, 'ВЗМТ (Воспалительные заболевания малого таза)'),
(49432, 4758, 13, 'Размер пилюли'),
(49433, 4759, 13, 'Пилюли'),
(49434, 4760, 13, 'Если нужна эта опция для установки, то разместите файл zip базы данных в следующую директорию'),
(49435, 4765, 13, 'Метка-заполнитель'),
(49436, 4766, 13, 'Метка-заполнитель (поддерживает пустой ACLs)'),
(49437, 4767, 13, 'Простой текст'),
(49438, 4768, 13, 'План'),
(49439, 4771, 13, 'Название программы'),
(49440, 4775, 13, 'Установка программы'),
(49441, 4779, 13, 'План:'),
(49442, 4782, 13, 'Программы'),
(49443, 4784, 13, 'Участник'),
(49444, 4785, 13, 'Размещение участника'),
(49445, 4786, 13, 'Позвоните, если любое из указанной информации неверно'),
(49446, 4787, 13, 'Измените свой пароль.'),
(49447, 4788, 13, 'Выберите файл'),
(49448, 4789, 13, 'Выберите пациента'),
(49449, 4790, 13, 'Отметьте нужное из списка.'),
(49450, 4791, 13, 'Отметьте нужное.'),
(49451, 4792, 13, 'Назначьте значение для'),
(49452, 4793, 13, 'Отметьте выше критерий диапазона для даты и нажмите Обновить для просмотра результатов.'),
(49453, 4794, 13, 'Выберите файл EDI-271 с нужным форматированием'),
(49454, 4795, 13, 'Нажмите кнопку загрузки для загрузки данных де-идентификации'),
(49455, 4796, 13, 'Нажмите кнопку загрузки для загрузки данных повторной иденификации'),
(49456, 4797, 13, 'Закройте это окно.'),
(49457, 4798, 13, 'Сравните на соответствие новое наименование'),
(49458, 4802, 13, 'Не признавайте это назначение, пока не получите его через факсимиле.'),
(49459, 4803, 13, 'Не признавайте это назначение, пока не получите его через факсимиле.'),
(49460, 4804, 13, 'НЕ используйте кнопку остановки или перезагрузки браузера, пока выполняется эта страница, если не прошло более 10 минут, это не вызовет остановку этого процесса на сервере и будет расходовать ненужные ресурсы.'),
(49461, 4805, 13, 'ВКЛЮЧИТЕ РАСШИРЕНИЕ CURL'),
(49462, 4806, 13, 'ВКЛЮЧИТЕ РАСШИРЕНИЕ OPENSSL'),
(49463, 4807, 13, 'ВКЛЮЧИТЕ РАСШИРЕНИЕ SOAP'),
(49464, 4808, 13, 'ВКЛЮЧИТЕ РАСШИРЕНИЕ XML'),
(49465, 4809, 13, 'Введите дату для последнего рассмотрения.'),
(49466, 4810, 13, 'Введите дату.'),
(49467, 4811, 13, 'Введите надлежащую дату'),
(49468, 4812, 13, 'Введите сообщение'),
(49469, 4813, 13, 'Введите денежную сумму, используя только числа и десятичную точку.'),
(49470, 4814, 13, 'Введите новый пароль'),
(49471, 4815, 13, 'Введите название!'),
(49472, 4819, 13, 'Введите правильный код повторной идентификации'),
(49473, 4821, 13, 'Введите новую строку поиска'),
(49474, 4822, 13, 'Введите этот правильный код повторной идентификации'),
(49475, 4823, 13, 'Введите новый пароль.'),
(49476, 4824, 13, 'Введите номер чека'),
(49477, 4826, 13, 'Введите дату'),
(49478, 4827, 13, 'Введите сумму оплаты'),
(49479, 4828, 13, 'Введите категорию оплаты'),
(49480, 4829, 13, 'Введите оплату от'),
(49481, 4830, 13, 'Введите отправку до даты'),
(49482, 4831, 13, 'Заполните их перед продолжением.'),
(49483, 4832, 13, 'Укажите причину посещения'),
(49484, 4834, 13, 'Введите выше критерий поиска и кликните Предоставить для обзора результатов.'),
(49485, 4835, 13, 'Введите выше критерий поиска и кликните Предоставить для обзора результатов. (Результаты будут отображены во всплывающем окне)'),
(49486, 4836, 13, 'Войдите в систему повторно.'),
(49487, 4837, 13, 'Обратите внимание, что это может занять очень долгое время, вплоть до нескольких минут, браузер может казаться зависшим в течение этого времени, но создание счета является сложным процессом и веб-браузер просто ждет получения дополнительной информации.'),
(49488, 4838, 13, 'Обратите внимание: константы являются регистрочувствительными и допускаются любые строки.'),
(49489, 4839, 13, 'Используйте только алфавитные символы'),
(49490, 4840, 13, 'Используйте только алфавитные символы без пробелов'),
(49491, 4841, 13, 'Оплатите эту сумму'),
(49492, 4843, 13, 'Обратитесь к'),
(49493, 4844, 13, 'Сбросьте пароль.'),
(49494, 4845, 13, 'Перезапустите сервер apache до исполнения исключения дублирования идентификации'),
(49495, 4849, 13, 'Выберите язык'),
(49496, 4850, 13, 'Выберите пациента.'),
(49497, 4851, 13, 'Выберите услугу основного коммерческого юридического лица с «ИНН» в качестве налогового кода. Если вы являетесь частным врачом, используйте свой ИНН. Он используется для идентификации вас в системе NewCrop.'),
(49498, 4854, 13, 'Выберите получателя'),
(49499, 4855, 13, 'Выберите начальную и конечную даты'),
(49500, 4856, 13, 'Выберите допустимого получателя'),
(49501, 4858, 13, 'Выберите причину корректировки для кода '),
(49502, 4859, 13, 'Выберите событие'),
(49503, 4860, 13, 'Выберите любой вариант поиска.'),
(49504, 4863, 13, 'Выберите, по крайней мере, одно назначение!'),
(49505, 4865, 13, 'Выберите нужные страницы для копирования или далее:'),
(49506, 4866, 13, 'Выберите метод оплаты'),
(49507, 4869, 13, 'Выберите партнера X12, требуемого для создания пакета 270'),
(49508, 4870, 13, 'Установите'),
(49509, 4871, 13, 'Установите переменную de_identification_config обратно на ноль'),
(49510, 4873, 13, 'Запустите новую обработку исключения дублирования идентификации'),
(49511, 4874, 13, 'Модернизируйте базу данных LibreEHR для включения методик де-идентификации, функции, таблиц'),
(49512, 4875, 13, 'За дополнительными сведениями обратитесь к лог-таблице по ошибкам де-идентификации'),
(49513, 4876, 13, 'Через некоторое время перейдите на экран снятия идентификации'),
(49514, 4877, 13, 'Через некоторое время перейдите на экран повторной идентификации'),
(49515, 4878, 13, 'Через некоторое время перейдите на экран'),
(49516, 4882, 13, 'после полудня'),
(49517, 4883, 13, 'Послеполуденная программа'),
(49518, 4884, 13, 'Способ Pmt'),
(49519, 4885, 13, 'Синдром ночного апноэ'),
(49520, 4886, 13, 'Коньюгированный с пневмококком 1'),
(49521, 4887, 13, 'Коньюгированный с пневмококком 2'),
(49522, 4888, 13, 'Коньюгированный с пневмококком 3'),
(49523, 4889, 13, 'Коньюгированный с пневмококком 4'),
(49524, 4890, 13, 'Пневмококковая вакцина'),
(49525, 4891, 13, 'Противопневмококковая прививка'),
(49526, 4892, 13, 'Статус прививки от пневмонии для пожилых взрослых'),
(49527, 4893, 13, 'Статус прививки от пневмонии для пожилых взрослых (CQM)'),
(49528, 4894, 13, 'Ортопедический'),
(49529, 4896, 13, 'Место оказания помощи (POS)'),
(49530, 4897, 13, 'Полис'),
(49531, 4898, 13, '№ полиса'),
(49532, 4899, 13, 'Номер полиса'),
(49533, 4900, 13, 'Польский'),
(49534, 4901, 13, 'Полидипсия'),
(49535, 4902, 13, 'Полипы'),
(49536, 4903, 13, 'Полиурия'),
(49537, 4904, 13, 'Плохой аппетит'),
(49538, 4905, 13, 'Нарушение кровообращения'),
(49539, 4906, 13, 'Снижение слуха'),
(49540, 4907, 13, 'Всплывающие заметки должны быть включены, чтобы отобразиться в этих отчетах'),
(49541, 4908, 13, 'Заполнить обзор года событиями?'),
(49542, 4909, 13, 'Всплывающее меню'),
(49543, 4911, 13, 'Активность портала'),
(49544, 4917, 13, 'Португальский'),
(49545, 4918, 13, 'Португальский (бразильский)'),
(49546, 4919, 13, 'Португальский (европейский)'),
(49547, 4920, 13, 'Код POS'),
(49548, 4922, 13, 'Положительное'),
(49549, 4923, 13, 'Точно'),
(49550, 4925, 13, 'Отправить для'),
(49551, 4926, 13, 'Капли в нос'),
(49552, 4927, 13, 'Отправить платеж');
INSERT INTO `lang_definitions` VALUES
(49553, 4928, 13, 'Послеоперационный'),
(49554, 4929, 13, 'Отправить для аккаунта и пометить как оплаченное'),
(49555, 4930, 13, 'Оплачено на дату'),
(49556, 4931, 13, 'Оплачено на дату не может быть позже сегодняшнего дня'),
(49557, 4932, 13, 'Оплатить на дату должно быть позже даты финансового закрытия.'),
(49558, 4933, 13, 'Послеабортное лечение'),
(49559, 4934, 13, 'Контрацепция после аборта'),
(49560, 4935, 13, 'Консультация после аборта'),
(49561, 4936, 13, 'Последствия аборта'),
(49562, 4937, 13, 'Почтовый'),
(49563, 4938, 13, 'Почтовый индекс'),
(49564, 4939, 13, 'Почтовый индекс'),
(49565, 4941, 13, 'PostCalendar'),
(49566, 4942, 13, 'Администрирование PostCalendar'),
(49567, 4943, 13, 'Настройка категории PostCalendar'),
(49568, 4944, 13, 'Глобальные параметры настройки PostCalendar'),
(49569, 4945, 13, 'Опубликовано в'),
(49570, 4946, 13, 'Дата отправки'),
(49571, 4948, 13, 'Задействовано через'),
(49572, 4949, 13, 'PPE + Prev Med/Surg Hx'),
(49573, 4950, 13, 'PQRI'),
(49574, 4951, 13, 'Регистрационный ID для PQRI'),
(49575, 4952, 13, 'Регистрационный имя для PQRI'),
(49576, 4953, 13, 'Лечебная практика'),
(49577, 4954, 13, 'Настройка врачебной деятельности по умолчанию'),
(49578, 4955, 13, 'Окружение врачебной деятельности'),
(49579, 4956, 13, 'Исполнитель'),
(49580, 4959, 13, 'Предоплата'),
(49581, 4960, 13, 'Консультация перед прерыванием беременности'),
(49582, 4961, 13, 'Консилиум перед прерыванием беременности'),
(49583, 4962, 13, 'Предп. кат.'),
(49584, 4964, 13, 'Предпочтения'),
(49585, 4965, 13, 'Предпочитаемая категория события'),
(49586, 4966, 13, 'Предпочитаемый язык'),
(49587, 4967, 13, 'Предпочитаемая аптека'),
(49588, 4968, 13, 'Предпочитаемое медицинское учреждение (PPO)'),
(49589, 4969, 13, 'Тест на беременность'),
(49590, 4970, 13, 'Предварительное'),
(49591, 4972, 13, 'Предоплата'),
(49592, 4973, 13, 'Назначение'),
(49593, 4974, 13, 'назначение достигло своего предела'),
(49594, 4975, 13, 'Хронология назначений'),
(49595, 4976, 13, 'Импорт хронологии назначений завершен успешно'),
(49596, 4977, 13, 'Метка назначения'),
(49597, 4978, 13, 'Отчет о назначениях'),
(49598, 4979, 13, 'Назначения'),
(49599, 4980, 13, 'Назначения и выполнение'),
(49600, 4981, 13, 'Назначения и другие направления'),
(49601, 4982, 13, 'Назначения и/или направление по специалистам'),
(49602, 4983, 13, 'Отчет о назначениях'),
(49603, 4984, 13, 'Назначения/направления'),
(49604, 4985, 13, 'Имеется'),
(49605, 4986, 13, 'Имеющаяся жалоба'),
(49606, 4988, 13, 'Нажмите Продолжить для перехода'),
(49607, 4989, 13, 'Предполагаемый диагноз'),
(49608, 4990, 13, 'Предполагаемый диагноз по специалисту'),
(49609, 4991, 13, 'Пред.'),
(49610, 4992, 13, 'Пред. тер./хир. Hx'),
(49611, 4993, 13, 'Пред. месяц (фиксация в меню)'),
(49612, 4994, 13, 'Пред. год (фиксация в меню)'),
(49613, 4995, 13, 'Профилактическое лечение'),
(49614, 4998, 13, 'Предпросмотр события'),
(49615, 5000, 13, 'Предпросмотр для'),
(49616, 5001, 13, 'Предыдущий'),
(49617, 5002, 13, 'Предыдущие консультации'),
(49618, 5003, 13, 'Предыдущий день'),
(49619, 5004, 13, 'Предыдущие хронология/отображение'),
(49620, 5005, 13, 'Предыдущий месяц'),
(49621, 5006, 13, 'Предыдущая неделя'),
(49622, 5007, 13, 'Цена'),
(49623, 5008, 13, 'Скидка на цену'),
(49624, 5009, 13, 'Уровень цены'),
(49625, 5010, 13, 'Уровень цены:'),
(49626, 5011, 13, 'Цены'),
(49627, 5012, 13, 'Основное'),
(49628, 5013, 13, 'Основное юридическое лицо'),
(49629, 5014, 13, 'ИНН основного юридического лица используется как id учетной записи для NewCrop ePrescription. Изменение услуги вызовет обработку в NewCrop.'),
(49630, 5022, 13, 'Основное страх.'),
(49631, 5023, 13, 'Основное страхование'),
(49632, 5024, 13, 'Дата основного страхования'),
(49633, 5025, 13, 'Основной страховщик'),
(49634, 5026, 13, 'Основной специалист'),
(49635, 5027, 13, 'Печать'),
(49636, 5028, 13, 'Печать (HTML)'),
(49637, 5029, 13, 'Печать (PDF)'),
(49638, 5031, 13, 'Печатать любое обращение'),
(49639, 5032, 13, 'Вывести пустую форму направления'),
(49640, 5033, 13, 'Команда печати'),
(49641, 5039, 13, 'Формат печати'),
(49642, 5040, 13, 'Вывод панели четверки'),
(49643, 5042, 13, 'Печать сообщения'),
(49644, 5043, 13, 'Многократная печать'),
(49645, 5044, 13, 'Многократный вывод на факс'),
(49646, 5045, 13, 'Выводит фамилию, подпись и дату.'),
(49647, 5046, 13, 'Печать записей'),
(49648, 5047, 13, 'Печать страницы 1'),
(49649, 5048, 13, 'Печать страницы 2'),
(49650, 5051, 13, 'Вывести рецепты по специалисту'),
(49651, 5052, 13, 'Печать записи'),
(49652, 5053, 13, 'Печать выбранных заявок'),
(49653, 5054, 13, 'Печать части записи'),
(49654, 5056, 13, 'Печатать это обращение'),
(49655, 5057, 13, 'Печатать эту запись'),
(49656, 5058, 13, 'Печатать эту запись'),
(49657, 5060, 13, 'Вывод на факс'),
(49658, 5061, 13, 'Вид печати'),
(49659, 5062, 13, 'для печати'),
(49660, 5063, 13, 'Версия для печати'),
(49661, 5064, 13, 'Печатный'),
(49662, 5066, 13, 'Результаты для печати:'),
(49663, 5067, 13, 'Печать пропущена; см. тестовый вывод в'),
(49664, 5068, 13, 'Печать пропущена; см. тестовый вывод в '),
(49665, 5069, 13, 'Осн. разр.'),
(49666, 5070, 13, 'Форма основных разрешений'),
(49667, 5071, 13, 'Предварительное посещение'),
(49668, 5072, 13, 'Приоритет'),
(49669, 5073, 13, 'Приоритет '),
(49670, 5074, 13, 'Конфиденциально'),
(49671, 5075, 13, 'Проблема'),
(49672, 5076, 13, 'Проблема DX'),
(49673, 5077, 13, 'Список проблем'),
(49674, 5079, 13, 'Проблемы/жалобы'),
(49675, 5080, 13, 'Мет. груп.'),
(49676, 5081, 13, 'Мет. кат.'),
(49677, 5083, 13, 'Мет. ожид. Rev'),
(49678, 5085, 13, 'Мет. Res'),
(49679, 5086, 13, 'Методика'),
(49680, 5087, 13, 'Участок тела для процедуры'),
(49681, 5088, 13, 'Булевые результаты для методики'),
(49682, 5089, 13, 'Код методики'),
(49683, 5091, 13, 'Сторона применения методики'),
(49684, 5093, 13, 'Предписание процедур'),
(49685, 5095, 13, 'Предписание процедур для'),
(49686, 5102, 13, 'Отчет о методике'),
(49687, 5103, 13, 'Статус отчета по методике'),
(49688, 5104, 13, 'Отклонение результата методики от нормы'),
(49689, 5105, 13, 'Статус результата для методики'),
(49690, 5106, 13, 'Результаты методики'),
(49691, 5107, 13, 'Способ введения для методики'),
(49692, 5108, 13, 'Типы биопроб для методик'),
(49693, 5109, 13, 'Статистический отчет для методики'),
(49694, 5110, 13, 'Тип методики'),
(49695, 5111, 13, 'Типы методик'),
(49696, 5112, 13, 'Единицы измерения для процедуры'),
(49697, 5114, 13, 'Процедуры'),
(49698, 5115, 13, 'Обработать'),
(49699, 5117, 13, 'Файл обработки ERA'),
(49700, 5121, 13, 'Обработано'),
(49701, 5122, 13, 'Обработано через'),
(49702, 5123, 13, 'Обработанная дата'),
(49703, 5125, 13, 'обрабатываемый'),
(49704, 5129, 13, 'Продукт'),
(49705, 5130, 13, 'Способ для контрацептивных изделий'),
(49706, 5132, 13, 'Продукция'),
(49707, 5133, 13, 'Продукция, но не назначенные препараты и не шаблоны'),
(49708, 5134, 13, 'Проф.'),
(49709, 5135, 13, 'Обработка записей'),
(49710, 5136, 13, 'Рак предстательной железы'),
(49711, 5137, 13, 'Скрининг рака предстательной железы'),
(49712, 5138, 13, 'Обследование предстательной железы'),
(49713, 5139, 13, 'Проблемы предстательной железы'),
(49714, 5140, 13, 'Предстательная железа без enlrgmt, лимфоузлов, безболезненная'),
(49715, 5142, 13, 'Предоставьте абсолютный путь'),
(49716, 5143, 13, 'Предоставьте абсолютный путь к файлу'),
(49717, 5145, 13, 'Предоставляет клинические итоги по пациентам для каждого посещения кабинета.'),
(49718, 5146, 13, 'Предоставляет пациентам по запросу электронную копию их медицинской информации (включая результаты диагностических исследований, список проблем, списки лекарств, лекарственную аллергию).'),
(49719, 5147, 13, 'В течение четырех рабочих дней, когда информация доступна для EP, обеспечивает пациентов своевременным электронным доступом к их медицинской информации (включая лабораторные результаты, список проблем, списки лекарств, лекарственную аллергию).'),
(49720, 5148, 13, 'Предоставляет записи у пациента для посещения'),
(49721, 5149, 13, 'Предоставьте допустимый электронный адрес'),
(49722, 5150, 13, 'Предоставить клинические итоги?'),
(49723, 5151, 13, 'Предоставить образовательный ресурс(ы)?'),
(49724, 5152, 13, 'Специалист'),
(49725, 5156, 13, 'Ошибки соответствия специалиста'),
(49726, 5159, 13, 'Номер специалиста'),
(49727, 5162, 13, 'Специалист:'),
(49728, 5163, 13, 'ներ'),
(49729, 5164, 13, 'NPI специалиста'),
(49730, 5165, 13, 'Специалисты видят всю регистрацию'),
(49731, 5166, 13, 'Истинная полицитемия'),
(49732, 5167, 13, 'PSA'),
(49733, 5168, 13, 'Псориаз'),
(49734, 5169, 13, 'Псих. диагноз'),
(49735, 5170, 13, 'Псих. лечение'),
(49736, 5171, 13, 'Психиатрия'),
(49737, 5172, 13, 'Психиатрическое короткое письмо'),
(49738, 5173, 13, 'Психиатрический диагноз'),
(49739, 5174, 13, 'Психиатрическое обследование'),
(49740, 5175, 13, 'Психиатрический анамнез'),
(49741, 5176, 13, 'Прием психотропных'),
(49742, 5177, 13, 'Психиатрическое лечение'),
(49743, 5178, 13, 'Выв. %'),
(49744, 5179, 13, 'Выв. записей'),
(49745, 5180, 13, 'Выв. записей/разр.'),
(49746, 5181, 13, 'Выв. переплаты'),
(49747, 5182, 13, 'Выв. оплаты'),
(49748, 5183, 13, 'Выв. запроса рег.'),
(49749, 5184, 13, 'Выв. возмещения'),
(49750, 5185, 13, 'Выв. релиза'),
(49751, 5186, 13, 'Выв. сообщения'),
(49752, 5187, 13, 'Выв. студент или оставьте пустым'),
(49753, 5188, 13, 'PT_CITY'),
(49754, 5189, 13, 'PT_DOB'),
(49755, 5191, 13, 'PT_FNAME'),
(49756, 5192, 13, 'PT_FNAME'),
(49757, 5193, 13, 'PT_MNAME'),
(49758, 5196, 13, 'PT_POSTAL'),
(49759, 5198, 13, 'PT_POSTAL'),
(49760, 5199, 13, 'PT_STREET'),
(49761, 5201, 13, 'Общедоступное'),
(49762, 5203, 13, 'Министерство здравоохранения (МЗ) или другое федеральное агенство'),
(49763, 5204, 13, 'Пуэрто-риканский'),
(49764, 5205, 13, 'Легочная'),
(49765, 5206, 13, 'Пульс'),
(49766, 5207, 13, 'Панджабский'),
(49767, 5208, 13, 'Приобретение'),
(49768, 5209, 13, 'Приобретение/возврат'),
(49769, 5210, 13, 'Закупки'),
(49770, 5213, 13, 'каждые 3 часа'),
(49771, 5214, 13, 'каждые 4 часа'),
(49772, 5215, 13, 'каждые 5 часов'),
(49773, 5216, 13, 'каждые 6 часов'),
(49774, 5217, 13, 'каждые 8 часов'),
(49775, 5218, 13, 'один раз в день'),
(49776, 5219, 13, 'через день'),
(49777, 5220, 13, 'QOH'),
(49778, 5221, 13, 'QOH меньше ежемесячного использования'),
(49779, 5222, 13, 'Кол.'),
(49780, 5223, 13, 'КОЛ.'),
(49781, 5224, 13, 'Качество'),
(49782, 5225, 13, 'Оценка качества (CQM)'),
(49783, 5226, 13, 'Количество'),
(49784, 5227, 13, 'Количество для NDC'),
(49785, 5228, 13, 'Количество на руках'),
(49786, 5229, 13, 'количество, представленное непригодным'),
(49787, 5231, 13, 'Пометить сомнительным'),
(49788, 5232, 13, 'Очередь для пакетной обработки HCFA'),
(49789, 5233, 13, 'Очередь для пакетной обработки HCFA и печати'),
(49790, 5234, 13, 'Очередь для пакетной обработки UB-92'),
(49791, 5235, 13, 'Очередь для пакетной обработки UB-92 и печати'),
(49792, 5236, 13, 'Состоящее в очереди'),
(49793, 5237, 13, 'Управление событиями в очереди'),
(49794, 5238, 13, 'Состоящее в очереди для'),
(49795, 5240, 13, 'Управление предоставлением в очереди'),
(49796, 5241, 13, 'Выход'),
(49797, 5242, 13, 'Бывший алкоголик'),
(49798, 5243, 13, 'R'),
(49799, 5245, 13, 'Раса'),
(49800, 5246, 13, 'Раса и этническая принадлежность'),
(49801, 5247, 13, 'Раса/этнос'),
(49802, 5248, 13, 'Радио'),
(49803, 5249, 13, 'Кнопки переключения'),
(49804, 5251, 13, 'Диапазон'),
(49805, 5252, 13, 'Сыпь'),
(49806, 5253, 13, 'Величина'),
(49807, 5254, 13, 'Пропорция'),
(49808, 5255, 13, 'Необработанный отчет'),
(49809, 5256, 13, 'Повторная идентификация'),
(49810, 5257, 13, 'Процесс повторной идентификации завершен'),
(49811, 5258, 13, 'Идет процесс повторной идентификации'),
(49812, 5259, 13, 'Файлы повторной идентификации будут сохранены в'),
(49813, 5260, 13, 'Повреждение повторное?'),
(49814, 5261, 13, 'Повторное открытие'),
(49815, 5262, 13, 'Открытый повторно'),
(49816, 5263, 13, 'Реакция'),
(49817, 5264, 13, 'Реакции'),
(49818, 5265, 13, 'Читать'),
(49819, 5268, 13, 'Реальное имя'),
(49820, 5269, 13, 'Действительно удалить'),
(49821, 5270, 13, 'Причина'),
(49822, 5271, 13, 'Умерший по причине'),
(49823, 5272, 13, 'Причина смерти'),
(49824, 5274, 13, 'Цель направления'),
(49825, 5275, 13, 'Причина посещения'),
(49826, 5276, 13, 'Причина/форма'),
(49827, 5277, 13, 'Квитанция'),
(49828, 5278, 13, 'Квитанция по оплате'),
(49829, 5279, 13, 'Созданная квитанция'),
(49830, 5280, 13, 'Квитанции по указанию метода оплаты'),
(49831, 5281, 13, 'Итоговые поступления'),
(49832, 5282, 13, 'Получено'),
(49833, 5283, 13, 'Получено посредством'),
(49834, 5284, 13, 'Получено по факсу'),
(49835, 5285, 13, 'Получен, не проверен'),
(49836, 5287, 13, 'Получатель'),
(49837, 5288, 13, 'ID получателя'),
(49838, 5289, 13, 'ID получателя (ISA08)'),
(49839, 5290, 13, 'Определить ID получателя (ISA07)'),
(49840, 5292, 13, 'Последние три пароля не допускаются.'),
(49841, 5293, 13, 'Адресат'),
(49842, 5294, 13, 'Список адресатов пустой'),
(49843, 5295, 13, 'Фамилия адресата'),
(49844, 5296, 13, 'Получатель информации'),
(49845, 5298, 13, 'Рекомендация'),
(49846, 5300, 13, 'Рекомендации'),
(49847, 5301, 13, 'Рекомендации и лечение'),
(49848, 5302, 13, 'Рекомендации по специалисту'),
(49849, 5303, 13, 'Записать'),
(49850, 5304, 13, 'Запись уже существует'),
(49851, 5310, 13, 'Изменения записи и карты по жизненно важным показателям.'),
(49852, 5311, 13, 'Записывает персональные данные.'),
(49853, 5312, 13, 'Публикация записи'),
(49854, 5313, 13, 'Запись натренированности'),
(49855, 5314, 13, 'Записать оплату'),
(49856, 5315, 13, 'Дата запроса записи'),
(49857, 5316, 13, 'Запись по употреблению табака для пациентов 13 лет и старше.'),
(49858, 5317, 13, 'Записи'),
(49859, 5318, 13, 'записи не найдены'),
(49860, 5319, 13, 'записи не найдены.'),
(49861, 5320, 13, 'Употребление региональных наркотиков'),
(49862, 5321, 13, 'Региональные наркотики'),
(49863, 5322, 13, 'Ректально'),
(49864, 5323, 13, 'Ректальное исследование'),
(49865, 5324, 13, 'ректально'),
(49866, 5325, 13, 'Переназначение'),
(49867, 5326, 13, 'Покраснение'),
(49868, 5327, 13, 'уменьшено:'),
(49869, 5328, 13, 'Ссылаться'),
(49870, 5329, 13, 'Ссылаться через'),
(49871, 5330, 13, 'Дата ссылки'),
(49872, 5331, 13, 'Ссылаться на'),
(49873, 5332, 13, 'Референсная классификация (степень риска)'),
(49874, 5333, 13, 'Стандартный диапазон результатов'),
(49875, 5334, 13, 'Цель направления'),
(49876, 5336, 13, 'Фамилия и подпись направляющего'),
(49877, 5337, 13, 'Направление'),
(49878, 5338, 13, 'Направление через'),
(49879, 5339, 13, 'Талон направления'),
(49880, 5340, 13, 'Дата направления'),
(49881, 5341, 13, 'Форма направления'),
(49882, 5342, 13, 'ФОРМА НАПРАВЛЕНИЯ'),
(49883, 5343, 13, 'ID направления'),
(49884, 5345, 13, 'Источник направления'),
(49885, 5346, 13, 'Источник направления для обращений'),
(49886, 5347, 13, 'Направление к'),
(49887, 5348, 13, 'Направления'),
(49888, 5349, 13, 'Отчет о направлениях'),
(49889, 5350, 13, 'ссылка на'),
(49890, 5351, 13, 'ссылка на'),
(49891, 5352, 13, 'Направлен в'),
(49892, 5353, 13, 'Кто направил'),
(49893, 5355, 13, 'Диагноз при направлении'),
(49894, 5356, 13, 'Диагноз при направлении'),
(49895, 5357, 13, 'Направляющий врач и врачебная практика'),
(49896, 5358, 13, 'Направляющий специалист'),
(49897, 5359, 13, 'Заполните повторно'),
(49898, 5360, 13, 'Добавление'),
(49899, 5361, 13, 'повторное заполнение'),
(49900, 5362, 13, 'Обычные рефлексы'),
(49901, 5363, 13, 'Обновить'),
(49902, 5365, 13, 'Обновить напоминания'),
(49903, 5368, 13, 'Обновить'),
(49904, 5369, 13, 'reg_re'),
(49905, 5370, 13, 'регистрировать'),
(49906, 5372, 13, 'Зарегистрированное'),
(49907, 5373, 13, 'зарегистрирован'),
(49908, 5375, 13, 'Дата регистрации'),
(49909, 5376, 13, 'Регистрационная форма'),
(49910, 5377, 13, 'Восстановление'),
(49911, 5381, 13, 'Связать с'),
(49912, 5382, 13, 'Связан'),
(49913, 5383, 13, 'Связанная проблема'),
(49914, 5385, 13, 'Родственник(и) / дети'),
(49915, 5386, 13, 'Родственники'),
(49916, 5387, 13, 'Родство'),
(49917, 5388, 13, 'Порядок следования этого объекта'),
(49918, 5389, 13, 'Родственники'),
(49919, 5399, 13, 'Права доступа для медицинской смены пропущены в учетной записи этого пользователя.'),
(49920, 5400, 13, 'ID медицинской смены'),
(49921, 5403, 13, 'Религия'),
(49922, 5406, 13, 'Повторно войти в систему'),
(49923, 5407, 13, 'Напом.'),
(49924, 5408, 13, 'Запомнить выбранный компонент'),
(49925, 5409, 13, 'Напоминание'),
(49926, 5410, 13, 'Интервалы для напоминаний'),
(49927, 5411, 13, 'Напоминание еще не отправлено'),
(49928, 5412, 13, 'Напоминание отправлено о'),
(49929, 5413, 13, 'Напоминания'),
(49930, 5414, 13, 'ПЕРЕВЕСТИ В'),
(49931, 5416, 13, 'Удалить'),
(49932, 5419, 13, 'Удалить группу'),
(49933, 5420, 13, 'Удалить форму группы'),
(49934, 5421, 13, 'Снимает поддержку для вакцинации'),
(49935, 5422, 13, 'Отключает поддержку для phpMyAdmin'),
(49936, 5423, 13, 'Отключает поддержку для назначений'),
(49937, 5425, 13, 'Снимает функцию отслеживания карты'),
(49938, 5426, 13, 'Почечно-каменная болезнь'),
(49939, 5427, 13, 'Переименовать'),
(49940, 5428, 13, 'Переименовать группу'),
(49941, 5429, 13, 'Отображение'),
(49942, 5430, 13, 'Назначенный специалист'),
(49943, 5431, 13, 'Номер назначенного специалиста'),
(49944, 5432, 13, 'Переназначить'),
(49945, 5433, 13, 'Переназначить на'),
(49946, 5434, 13, 'Указание по переназначению выполнено'),
(49947, 5435, 13, 'Указание по переназначению, 0 если не применимо'),
(49948, 5436, 13, 'Повт.'),
(49949, 5438, 13, 'Повторное событие'),
(49950, 5439, 13, 'Повторная инф.:'),
(49951, 5440, 13, 'Повторяется'),
(49952, 5444, 13, 'Дата ответа'),
(49953, 5445, 13, 'Ответ от'),
(49954, 5446, 13, 'Отчет'),
(49955, 5447, 13, 'Отчет - клинический'),
(49956, 5449, 13, 'Отчет по'),
(49957, 5457, 13, 'Статус отчета'),
(49958, 5458, 13, 'Всего отчетов'),
(49959, 5460, 13, 'Регистрируемое'),
(49960, 5461, 13, 'Сообщено'),
(49961, 5462, 13, 'Дата отчета'),
(49962, 5463, 13, 'Отчеты'),
(49963, 5467, 13, 'Запрос игнорирован - обработка требования уже выполняется!'),
(49964, 5474, 13, 'Запрошенная услуга'),
(49965, 5475, 13, 'Требует строгих паролей'),
(49966, 5476, 13, 'Требует уникальных паролей'),
(49967, 5477, 13, 'Обязательно'),
(49968, 5479, 13, 'Пропуск обязательного поля: выберите файл EDI-271 для загрузки'),
(49969, 5480, 13, 'Пропущено обязательное поле: введите имя'),
(49970, 5481, 13, 'Пропущено обязательное поле: введите фамилию'),
(49971, 5482, 13, 'Пропущено обязательное поле: введите наименование пользователя'),
(49972, 5483, 13, 'Обязательные поля'),
(49973, 5484, 13, 'Требования'),
(49974, 5485, 13, 'ЗАНЯТ'),
(49975, 5486, 13, 'Занят'),
(49976, 5487, 13, 'Занято для использования в предоставлении запланированного периода отпуска'),
(49977, 5488, 13, 'Занято для ограничения, с какого времени к специалисту не доступна запись на прием.'),
(49978, 5489, 13, 'Занято для определения, когда событие не случается как указано.'),
(49979, 5490, 13, 'Занято для установки, с какого времени к специалисту доступна запись на прием.'),
(49980, 5491, 13, 'Сброс'),
(49981, 5492, 13, 'Сбросить общие параметры доступа к порталу'),
(49982, 5493, 13, 'Сбросить местные параметры доступа к порталу'),
(49983, 5495, 13, 'Resn'),
(49984, 5496, 13, 'Решено'),
(49985, 5497, 13, 'Дыхание'),
(49986, 5498, 13, 'Незначительная одышка'),
(49987, 5499, 13, 'Органы дыхания'),
(49988, 5501, 13, 'Ограничивает незарегистрированных пользователей набором предусмотренных услуг через пользователя admin.'),
(49989, 5502, 13, 'Ограничивает пользователей по услугам'),
(49990, 5503, 13, 'Незаконченное обучение'),
(49991, 5504, 13, 'Результат'),
(49992, 5506, 13, 'Статус результата'),
(49993, 5507, 13, 'Пропущено состояние результата или отклонение от нормы'),
(49994, 5508, 13, 'Результат, используйте % как знак подстановки'),
(49995, 5510, 13, 'Результаты и'),
(49996, 5511, 13, 'В ходе поиска найден результат'),
(49997, 5512, 13, 'Группа результатов'),
(49998, 5515, 13, 'Постраничные результаты'),
(49999, 5516, 13, 'Результаты/сведения'),
(50000, 5517, 13, 'Обследование сетчатки глаза'),
(50001, 5518, 13, 'Право на отказ:'),
(50002, 5519, 13, 'Возврат'),
(50003, 5520, 13, 'Возвратить указанную выше часть с вашей оплатой'),
(50004, 5521, 13, 'Вернуться в календарь'),
(50005, 5527, 13, 'Возвратить значение'),
(50006, 5528, 13, 'Возвратить посещение'),
(50007, 5529, 13, 'Вновь исполнять'),
(50008, 5534, 13, 'Обзор анамнеза перенесенных заболеваний:'),
(50009, 5535, 13, 'Обзор по системам'),
(50010, 5536, 13, 'Обзор выбора систем'),
(50011, 5537, 13, 'Просмотрен'),
(50012, 5538, 13, 'Пересмотр'),
(50013, 5539, 13, 'Ревматоидный артрит'),
(50014, 5540, 13, 'Ревматоидный артрит'),
(50015, 5541, 13, 'Справа'),
(50016, 5542, 13, 'Правое ухо'),
(50017, 5543, 13, 'правое ухо'),
(50018, 5545, 13, 'Справа:'),
(50019, 5546, 13, 'Звон в ушах'),
(50020, 5547, 13, 'Звон в ушах'),
(50021, 5549, 13, 'Факторы риска'),
(50022, 5550, 13, 'Степень риска'),
(50023, 5551, 13, 'Правая нижняя конечность:'),
(50024, 5552, 13, 'ROM'),
(50025, 5553, 13, 'Румынский'),
(50026, 5560, 13, 'Расписание'),
(50027, 5561, 13, 'Способ введения'),
(50028, 5562, 13, 'Путь введения, если применимо'),
(50029, 5563, 13, 'Введенное'),
(50030, 5564, 13, 'Строки'),
(50031, 5565, 13, 'Доказательная медицина без е/м рабочего обзора'),
(50032, 5566, 13, 'Шум трения:'),
(50033, 5567, 13, 'Шумы трения:'),
(50034, 5568, 13, 'Правило'),
(50035, 5569, 13, 'Добавить правило'),
(50036, 5570, 13, 'Сведения о правиле'),
(50037, 5572, 13, 'Изменить правило'),
(50038, 5575, 13, 'Набор правил'),
(50039, 5578, 13, 'Правила'),
(50040, 5580, 13, 'Настройка правил'),
(50041, 5581, 13, 'Выполняемая команда: '),
(50042, 5582, 13, 'Разрыв'),
(50043, 5583, 13, 'Русский'),
(50044, 5584, 13, 'Терапия'),
(50045, 5585, 13, 'Терапия'),
(50046, 5586, 13, 'Нижнее поле (px) Rx'),
(50047, 5587, 13, 'Rx разрешает DEA #'),
(50048, 5588, 13, 'Rx разрешает NPI'),
(50049, 5589, 13, 'Rx разрешает гос. лиц. #'),
(50050, 5590, 13, 'Левое поле (px) Rx'),
(50051, 5591, 13, 'Размер бумаги Rx'),
(50052, 5592, 13, 'Правое поле (px) Rx'),
(50053, 5593, 13, 'Rx показывает DEA #'),
(50054, 5594, 13, 'Rx показывает NPI'),
(50055, 5595, 13, 'Rx показывает гос. лиц. #'),
(50056, 5596, 13, 'Верхнее поле (px) Rx'),
(50057, 5598, 13, 'RxNorm'),
(50058, 5599, 13, 'База данных RxNorm'),
(50059, 5600, 13, 'S'),
(50060, 5601, 13, 'S.S.'),
(50061, 5602, 13, 'S3:'),
(50062, 5603, 13, 'S4:'),
(50063, 5604, 13, 'Гарантия ПО * * Для ознакомления с лицензией прочитайте docs/license.txt или посетите * http://www.gnu.org/copyleft/gpl.html * */ //========================================================================= // '),
(50064, 5605, 13, 'Товарооборот'),
(50065, 5606, 13, 'Товарооборот'),
(50066, 5607, 13, 'Товарооборот по пунктам'),
(50067, 5608, 13, 'Отчет реализации по продукту'),
(50068, 5609, 13, 'Слюна'),
(50069, 5610, 13, 'Тот же день'),
(50070, 5611, 13, 'Полинезийский'),
(50071, 5612, 13, 'Образец'),
(50072, 5613, 13, 'Тип разрешения'),
(50073, 5617, 13, 'Сб'),
(50074, 5618, 13, 'Сб &amp; Вс'),
(50075, 5619, 13, 'Суббота'),
(50076, 5620, 13, 'Сохранить'),
(50077, 5621, 13, 'Сохранить'),
(50078, 5622, 13, 'Сохранить и закрыть'),
(50079, 5624, 13, 'Сохранить и выдать'),
(50080, 5626, 13, 'Сохранить как новое'),
(50081, 5627, 13, 'Сохранить как новую запись'),
(50082, 5628, 13, 'Сохранить параметры настройки сертификата'),
(50083, 5629, 13, 'Сохранить изменения'),
(50084, 5630, 13, 'Сохранить форму'),
(50085, 5631, 13, 'Сохранить вакцинацию'),
(50086, 5632, 13, 'Сохранить новое поле'),
(50087, 5633, 13, 'Сохранить новую группу'),
(50088, 5634, 13, 'Сохранить новый список'),
(50089, 5635, 13, 'Сохранить новый шаблон'),
(50090, 5637, 13, 'Сохранить персональные данные пациента'),
(50091, 5638, 13, 'Сохранение выполнено успешно для ID карты'),
(50092, 5639, 13, 'Сохранить транзакцию'),
(50093, 5641, 13, 'Сканировано'),
(50094, 5642, 13, 'Просмотренная запись по обращению'),
(50095, 5643, 13, 'Просмотренная директория'),
(50096, 5644, 13, 'Просмотренно в'),
(50097, 5645, 13, 'План'),
(50098, 5646, 13, 'Запланированная медпомощь'),
(50099, 5647, 13, 'ШКОЛЬНАЯ ЗАПИСЬ'),
(50100, 5648, 13, 'Сколиоз'),
(50101, 5651, 13, 'SE'),
(50102, 5652, 13, 'Адрес SE'),
(50103, 5653, 13, 'Город SE'),
(50104, 5654, 13, 'Страна SE'),
(50105, 5655, 13, 'Местоположение SE'),
(50106, 5656, 13, 'Почтовый индекс SE'),
(50107, 5657, 13, 'Штат SE'),
(50108, 5658, 13, 'Почтовый индекс SE'),
(50109, 5659, 13, 'Поиск'),
(50110, 5661, 13, 'поиск'),
(50111, 5662, 13, 'повторный поиск'),
(50112, 5664, 13, 'Поиск по:'),
(50113, 5665, 13, 'Поиск для'),
(50114, 5666, 13, 'Поиск для:'),
(50115, 5668, 13, 'Поиск в'),
(50116, 5669, 13, 'Поиск или добавление пациента'),
(50117, 5670, 13, 'Поиск оплаты'),
(50118, 5672, 13, 'Результаты поиска:'),
(50119, 5673, 13, 'Отдельный поиск'),
(50120, 5674, 13, 'Строка поиска не совпадает со списком в базе данных'),
(50121, 5675, 13, 'Строка поиска должна иметь, по крайней, мере три символа'),
(50122, 5676, 13, 'Текстовой поиск'),
(50123, 5677, 13, 'Поиск события'),
(50124, 5678, 13, 'Найти/добавить'),
(50125, 5679, 13, 'Найти/добавить страховщика'),
(50126, 5680, 13, 'Поиск для записей на прием'),
(50127, 5681, 13, 'Идет поиск...'),
(50128, 5682, 13, 'Использование ремня безопасности'),
(50129, 5683, 13, 'Использование ремня безопасности'),
(50130, 5684, 13, 'Второй'),
(50131, 5687, 13, 'Повторный'),
(50132, 5688, 13, 'Повторная страховка'),
(50133, 5689, 13, 'Дата повторной страховки'),
(50134, 5690, 13, 'Поставщик повторной страховки'),
(50135, 5691, 13, 'Тип повторной медпомощи'),
(50136, 5698, 13, 'Безопасность'),
(50137, 5699, 13, 'Показать все'),
(50138, 5700, 13, 'Показать разрешения'),
(50139, 5701, 13, 'Показать карту физического развития'),
(50140, 5702, 13, 'Показать сообщения из последней группы созданных требований'),
(50141, 5704, 13, 'Показать, начиная с'),
(50142, 5707, 13, 'Пароксизм'),
(50143, 5708, 13, 'Выбр.'),
(50144, 5709, 13, 'Выбрать'),
(50145, 5710, 13, 'выбрать'),
(50146, 5712, 13, 'Выбрать контекст'),
(50147, 5714, 13, 'Выберите временной промежуток'),
(50148, 5715, 13, 'Выберите пользователя'),
(50149, 5716, 13, 'Выбрать все'),
(50151, 5720, 13, 'Выбрать категорию'),
(50152, 5722, 13, 'Выберите соответствующий переключатель для удаления'),
(50153, 5723, 13, 'Выберите критерий для удаления'),
(50154, 5725, 13, 'Выберите нужную дату для снятия идентификации'),
(50155, 5726, 13, 'Выберите дату для включения в данные по снятию идентификации'),
(50156, 5727, 13, 'Выберите дату'),
(50157, 5728, 13, 'Выберите необходимую группу'),
(50158, 5729, 13, 'Выберите диагноз'),
(50159, 5730, 13, 'Выберите диагноз для запроса по снятию идентификации'),
(50160, 5731, 13, 'Выберите препарат'),
(50161, 5732, 13, 'Выберите препараты'),
(50162, 5733, 13, 'Выберите препараты для запроса по снятию идентификации'),
(50163, 5734, 13, 'Выберите файл EDI-271'),
(50164, 5736, 13, 'Выберите поле'),
(50165, 5737, 13, 'Выберите поля'),
(50166, 5738, 13, 'Выбор для печати'),
(50167, 5739, 13, 'Выберите вакцинацию'),
(50168, 5740, 13, 'Выберите вакцинацию для запроса по снятию идентификации'),
(50169, 5741, 13, 'Выберите страховку, по типу'),
(50170, 5742, 13, 'Выбрать аспект'),
(50171, 5744, 13, 'Выберите язык'),
(50172, 5746, 13, 'Выберите один или более кодов диагнозов для подтверждения оказания помощи'),
(50173, 5754, 13, 'Выберите элементы конфигурации для экспорта'),
(50174, 5755, 13, 'Выберите проблему, прежде всего, ответственную за любое пропущенное событие в этот день'),
(50175, 5759, 13, 'Выберите пользователя'),
(50176, 5760, 13, 'Выберите пользователей из выпадающего списка'),
(50177, 5761, 13, 'Выберите, какой язык, если доступно, может быть изменен при входе в ситстему. (применимо, только если выше отключено разрешение всех языков)'),
(50178, 5762, 13, 'Выберите Да для подтверждения удаления группы'),
(50179, 5765, 13, 'Выбранный'),
(50180, 5766, 13, 'Выбранное обращение'),
(50181, 5767, 13, 'При этом выборе будет создано сообщение, которое нуждается в обработке по каждому получателю отдельно (это не групповая задача)'),
(50182, 5768, 13, 'Сам'),
(50183, 5769, 13, 'Оплатить самостоятельно'),
(50184, 5771, 13, 'Отправить'),
(50185, 5772, 13, 'Отправить старое напоминание A'),
(50186, 5773, 13, 'Отправить напоминание'),
(50187, 5774, 13, 'Отправить на обработку'),
(50188, 5775, 13, 'Отправить сообщение'),
(50189, 5776, 13, 'Отправить пакет напоминаний'),
(50190, 5777, 13, 'Отправляет напоминания пациентам по профилактике или последующему лечению через выбор пациента.'),
(50191, 5778, 13, 'Отправить сводки по направлениям'),
(50192, 5779, 13, 'Отправить этот файл'),
(50193, 5780, 13, 'Отправить это сообщение'),
(50194, 5781, 13, 'Отправить к'),
(50195, 5784, 13, 'Отправить всем'),
(50196, 5788, 13, 'Отправитель'),
(50197, 5789, 13, 'ID отправителя'),
(50198, 5790, 13, 'ID отправителя (ISA06)'),
(50199, 5791, 13, 'Определитель ID отправителя (ISA05)'),
(50200, 5793, 13, 'Направить в'),
(50201, 5794, 13, 'Конфиденциальность'),
(50202, 5795, 13, 'Конфиденциальность:'),
(50203, 5796, 13, 'Исследование чувствительности в норме'),
(50204, 5799, 13, 'Отправить через, оставить пустым для всех'),
(50205, 5801, 13, 'Отправить дату'),
(50206, 5802, 13, 'Отправить элементы'),
(50207, 5803, 13, 'Отправить медицинские записи?'),
(50208, 5804, 13, 'Отправка проведена успешно'),
(50209, 5807, 13, 'отправлено на печать.'),
(50210, 5808, 13, 'Отправить для, оставить пустым для всех'),
(50211, 5811, 13, 'Отправлен, но не получен'),
(50212, 5812, 13, 'Сен'),
(50213, 5813, 13, 'Отдельный'),
(50214, 5814, 13, 'Сентябрь'),
(50215, 5815, 13, 'Посл.'),
(50216, 5816, 13, 'Последовательность'),
(50217, 5821, 13, 'Услуга'),
(50218, 5822, 13, 'Категория услуги'),
(50219, 5823, 13, 'Код услуги'),
(50220, 5825, 13, 'Коды услуги'),
(50221, 5826, 13, 'Дата услуги'),
(50222, 5827, 13, 'Дата услуги:'),
(50223, 5829, 13, 'Место предоставления услуги'),
(50224, 5831, 13, 'Услуги, предоставляемые специалистом'),
(50225, 5834, 13, 'Услуги'),
(50226, 5835, 13, 'Услуги по категориям'),
(50227, 5836, 13, 'Оказана помощь'),
(50228, 5837, 13, 'Оказана помощь'),
(50229, 5838, 13, 'Услуги/продукция'),
(50230, 5839, 13, 'Тип сессии'),
(50231, 5840, 13, 'Установить'),
(50232, 5841, 13, 'Задает объект cookie для запоминания выбранного объекта между входами в систему.'),
(50233, 5842, 13, 'Установить как выполненное'),
(50234, 5845, 13, 'Задает полный путь. Чтобы создать клиентский сертификат SSL для HTTPS.'),
(50235, 5846, 13, 'Установить в'),
(50236, 5847, 13, 'Установить по умолчанию'),
(50237, 5848, 13, 'Настройка номера версии в базе данных...'),
(50238, 5849, 13, 'Параметры настройки'),
(50239, 5851, 13, 'Сильная мигрень'),
(50240, 5853, 13, 'Степень боли'),
(50241, 5854, 13, 'Степень боли:'),
(50242, 5855, 13, 'Пол'),
(50243, 5856, 13, 'Заболевание, передающееся половым путем'),
(50244, 5858, 13, 'Хэш Sha-1'),
(50245, 5859, 13, 'Совместное использование'),
(50246, 5860, 13, 'Команда shell для печати с сервера.'),
(50247, 5863, 13, 'Короткое описание'),
(50248, 5864, 13, 'Затрудненное дыхание'),
(50249, 5865, 13, 'Затрудненное дыхание'),
(50250, 5866, 13, 'Затрудненное дыхание 2'),
(50251, 5867, 13, 'Короткая запись'),
(50252, 5868, 13, 'Короткая запись как:'),
(50253, 5870, 13, 'должно быть подобно nnnnn-nnnn-nn'),
(50254, 5871, 13, 'Должно быть две буквы'),
(50255, 5872, 13, 'Должно содержать 10 цифр'),
(50256, 5873, 13, 'должно содержать только 10 цифр'),
(50257, 5874, 13, 'Плечо'),
(50258, 5875, 13, 'Плечо + ключица'),
(50259, 5876, 13, 'Проблемы плеча'),
(50260, 5877, 13, 'Показать'),
(50261, 5878, 13, 'Показать активные'),
(50262, 5880, 13, 'Показать всё'),
(50263, 5881, 13, 'Показать все процедуры'),
(50264, 5883, 13, 'Показать все транзакции'),
(50265, 5884, 13, 'Показывать, что занят'),
(50266, 5885, 13, 'Показать только разрешенное'),
(50267, 5886, 13, 'Показать доступные элементы'),
(50268, 5887, 13, 'Показать и US и метрические (основными являются метрические)'),
(50269, 5888, 13, 'Показать и US и метрические (основными являются US)'),
(50270, 5889, 13, 'Показать сведения'),
(50271, 5890, 13, 'Показать только ошибки?'),
(50272, 5891, 13, 'Показать графику'),
(50273, 5892, 13, 'При наведении мышки показывать всплывающий текст по событию?'),
(50274, 5893, 13, 'На страницах admin показывать, сколько событий?'),
(50275, 5894, 13, 'Показать неактивные'),
(50276, 5896, 13, 'Показать меню'),
(50277, 5897, 13, 'Показать только метрические'),
(50278, 5898, 13, 'Показать записи'),
(50279, 5901, 13, 'Показать записи по пациенту'),
(50280, 5904, 13, 'Показать основное завершение'),
(50281, 5905, 13, 'Показать напоминания'),
(50282, 5906, 13, 'Показать отчёт'),
(50283, 5907, 13, 'Показывать в блоке ссылки искать/предоставить?'),
(50284, 5910, 13, 'Показывает индивидуальную форму состояния для виджета о списке добавлений (запросит заголовок и сокращение).'),
(50285, 5913, 13, 'Показать только оплаченные'),
(50286, 5914, 13, 'Показать только US'),
(50287, 5920, 13, 'Родные брат/сестра'),
(50288, 5921, 13, 'серповидная клетка'),
(50289, 5922, 13, 'Sig'),
(50290, 5923, 13, 'Сигмо/колоноскопия'),
(50291, 5925, 13, 'Результаты лабораторных сигнатур (write,addonly необязательно)'),
(50292, 5926, 13, 'Результаты сигнатур'),
(50293, 5927, 13, 'Подпись'),
(50294, 5929, 13, 'Подпись:'),
(50295, 5930, 13, 'Подписано Rx'),
(50296, 5932, 13, 'Значительная опухоль'),
(50297, 5934, 13, 'Простая доплата'),
(50298, 5935, 13, 'Сокращенные персональные данные'),
(50299, 5936, 13, 'Сокращенные назначения'),
(50300, 5937, 13, 'с'),
(50301, 5938, 13, 'С уважением,'),
(50302, 5940, 13, 'Отдельный'),
(50303, 5941, 13, 'Список выбора'),
(50304, 5942, 13, 'Список выбора с возможностью добавления'),
(50305, 5946, 13, 'Проблемы пазух'),
(50306, 5947, 13, 'Хирургия пазух'),
(50307, 5948, 13, 'БОЛЕЗНЕННАЯ ПАЗУХА:'),
(50308, 5949, 13, 'Синуситы'),
(50309, 5951, 13, 'ID сайта'),
(50310, 5953, 13, 'ID сайта для поддержки LibreEHR службой лабораторного обмена LLC.'),
(50311, 5956, 13, 'Размер'),
(50312, 5957, 13, 'Размер должен быть числом между 1 и 999'),
(50313, 5958, 13, 'Размер/список'),
(50314, 5959, 13, 'Дерматология'),
(50315, 5960, 13, 'Рак кожи'),
(50316, 5961, 13, 'Кожное заболевание'),
(50317, 5962, 13, 'Прочие кожные проявления'),
(50318, 5963, 13, 'Пропустить разрешение для записей по пациенту'),
(50319, 5964, 13, 'Пропущенный раздел'),
(50320, 5965, 13, 'Пропущенный дамп регистра SQL - не применяется для сервера Windows'),
(50321, 5967, 13, 'Паттерн сна'),
(50322, 5968, 13, 'Паттерн сна'),
(50323, 5969, 13, 'Сон'),
(50324, 5970, 13, 'Словацкий'),
(50325, 5972, 13, 'Забытый долг без'),
(50326, 5973, 13, 'Кэш Smarty очищен'),
(50327, 5974, 13, 'Курильщик, в настоящее время статус неизвестен'),
(50328, 5976, 13, 'Статус курильщика'),
(50329, 5977, 13, 'Разр. SMS'),
(50330, 5978, 13, 'Шлюз SMS'),
(50331, 5979, 13, 'Ключ API для шлюза SMS'),
(50332, 5980, 13, 'Ключ API для шлюза SMS'),
(50333, 5981, 13, 'Пароль для шлюза SMS'),
(50334, 5982, 13, 'Имя пользователя для шлюза SMS'),
(50335, 5983, 13, 'Уведомление об SMS'),
(50336, 5984, 13, 'Часы уведомления об SMS'),
(50337, 5985, 13, 'Отправлять SMS перед'),
(50338, 5986, 13, 'Отправка SMS'),
(50339, 5987, 13, 'Текст SMS, употребляемый тэг: ***НАИМЕНОВАНИЕ***, ***СПЕЦИАЛИСТ***, ***ДАТА***, ***ВРЕМЯ НАЧАЛА***, ***ВРЕМЯ ОКОНЧАНИЯ***<br> т.е. Уважаемый ***ИМЯ***'),
(50340, 5988, 13, 'Параметры настройки извещения SMS/e-mail'),
(50341, 5989, 13, 'Пароль SMTP для аутентификации'),
(50342, 5992, 13, 'Имя узла сервера SMTP'),
(50343, 5993, 13, 'Номер порта для сервера SMTP'),
(50344, 5994, 13, 'Пользователь SMTP для аутентификации'),
(50345, 5995, 13, 'SNOMED'),
(50346, 6001, 13, 'База данных SNOMED'),
(50347, 6004, 13, 'Храп'),
(50348, 6005, 13, 'SOAP'),
(50349, 6006, 13, 'Трудности общения'),
(50350, 6009, 13, 'Социальный анамнез:'),
(50351, 6010, 13, 'Идентификационный номер налогоплательщика'),
(50352, 6011, 13, 'раствор'),
(50353, 6013, 13, 'Физический смысл'),
(50354, 6014, 13, 'Некоторые разрешения не отображены. Нажмите здесь для просмотра всех.'),
(50355, 6015, 13, 'Некоторые коды не отображаются.'),
(50356, 6016, 13, 'Некоторые обращения не были отображены. Нажмите здесь для просмотра всех.'),
(50357, 6017, 13, 'Во время процесса деидентификации случилась какая-то ошибка'),
(50358, 6018, 13, 'Некоторые записи не отображаются.'),
(50359, 6020, 13, 'некоторые слова');
INSERT INTO `lang_definitions` VALUES
(50360, 6023, 13, 'Что-то не получилось. Попытайтесь снова.'),
(50361, 6024, 13, 'Кратчайший интервал ожидания (клинические напоминания)'),
(50362, 6025, 13, 'Кратчайший интервал ожидания (напоминания о пациенте)'),
(50363, 6026, 13, 'Болезненность в горле'),
(50364, 6028, 13, 'К сожалению, имелась проблема обновления вашего файла'),
(50365, 6029, 13, 'Сортировать по'),
(50366, 6030, 13, 'Сортировать по'),
(50367, 6031, 13, 'Сортировать по контрольной сумме'),
(50368, 6032, 13, 'Сортировать по комментариям'),
(50369, 6033, 13, 'Сортировать по пользователю Crt'),
(50370, 6034, 13, 'Сортировать по дате'),
(50371, 6035, 13, 'Сортировать по дате/времени'),
(50372, 6036, 13, 'Сортировать по событию'),
(50373, 6037, 13, 'Сортировать по группе'),
(50374, 6038, 13, 'Сортировать по новой контролькой сумме'),
(50375, 6039, 13, 'Сортировать по старой контролькой сумме'),
(50376, 6040, 13, 'Сортировать по PatientID'),
(50377, 6041, 13, 'Сортировать по выполнению'),
(50378, 6043, 13, 'Сортировать по пользователю'),
(50379, 6044, 13, 'Сортировать по вакцине'),
(50380, 6045, 13, 'Сортировать в нисходящем порядке'),
(50381, 6046, 13, 'Сортировать результат по'),
(50382, 6047, 13, 'Сортировать в восходящем порядке'),
(50383, 6048, 13, 'Источник'),
(50384, 6049, 13, 'Исходный файл'),
(50385, 6050, 13, 'Путь исходного файла'),
(50386, 6051, 13, 'Для кода пропущен источник '),
(50387, 6052, 13, 'Источник партии'),
(50388, 6057, 13, 'Источник:'),
(50389, 6060, 13, 'Space'),
(50390, 6061, 13, 'SPACE'),
(50391, 6062, 13, 'Испанский'),
(50392, 6063, 13, 'Испанский (Латино-американский)'),
(50393, 6064, 13, 'Испанский (Испанский)'),
(50394, 6068, 13, 'Специалист'),
(50395, 6069, 13, 'Фамилия и подпись специалиста'),
(50396, 6071, 13, 'Специальность'),
(50397, 6072, 13, 'Специальные системы'),
(50398, 6073, 13, 'Специальность:'),
(50399, 6074, 13, 'Определенный'),
(50400, 6075, 13, 'Специальное приложение'),
(50401, 6076, 13, 'Специальная услуга по контрацепции'),
(50402, 6077, 13, 'Особый результат'),
(50403, 6078, 13, 'Указанная услуга'),
(50404, 6079, 13, 'Указанный'),
(50405, 6080, 13, 'Специальное форматирование для кодов. # = digit, * = любой символ. Если не используется, то пусто.'),
(50406, 6081, 13, 'Специальное форматирование для кодов. # = digit, @ = alpha, * = любой символ. Если не используется, то пусто.'),
(50407, 6082, 13, 'Специальное форматирование для ссылочных номеров счетов. # = digit, * = любой символ. Если не используется, то пусто.'),
(50408, 6083, 13, 'Специальное форматирование для ссылочных номеров счетов. # = digit, @ = alpha, * = любой символ, Если не используется, то пусто.'),
(50409, 6084, 13, 'Специальное форматирование для полей средства NDC. # = digit, * = любой символ. Если не используется, то пусто.'),
(50410, 6085, 13, 'Специальное форматирование для полей средства NDC. # = digit, @ = alpha, * = любой символ. Если не используется, то пусто.'),
(50411, 6086, 13, 'Специальное форматирование для внешнего ID пациента. # = digit, * = любой символ. Если не используется, то пусто.'),
(50412, 6087, 13, 'Специальное форматирование для внешнего ID пациента. # = digit, @ = alpha, * = любой символ. Если не используется, то пусто.'),
(50413, 6088, 13, 'Экземпляр'),
(50414, 6089, 13, 'Номер/идентификатор экземпляра'),
(50415, 6090, 13, 'Тип образца'),
(50416, 6092, 13, 'Устная диктовка'),
(50417, 6093, 13, 'Экземпляры'),
(50418, 6094, 13, 'Спленэктомия'),
(50419, 6095, 13, 'Супруг(а)'),
(50420, 6097, 13, 'Мокрота'),
(50421, 6098, 13, 'Мокрота:'),
(50422, 6099, 13, 'Отд.'),
(50423, 6102, 13, 'Отделение'),
(50424, 6103, 13, 'Состав отделения'),
(50425, 6104, 13, 'Отделения'),
(50426, 6105, 13, 'SRH'),
(50427, 6106, 13, 'SRH - планирование семьи'),
(50428, 6107, 13, 'SRH без планирования семьи'),
(50429, 6108, 13, 'Направления для SRH'),
(50430, 6109, 13, 'Форма посещения SRH'),
(50431, 6110, 13, 'Дата усл.'),
(50432, 6111, 13, 'SS'),
(50433, 6112, 13, 'Управление сертификатом SSL'),
(50434, 6113, 13, '№ страх.'),
(50435, 6114, 13, 'Устойчивость'),
(50436, 6116, 13, 'Стандартный'),
(50437, 6117, 13, 'Стандартный код'),
(50438, 6118, 13, 'Стандартные единицы измерения'),
(50439, 6122, 13, 'Стандартное наименование'),
(50440, 6124, 13, 'Начало'),
(50441, 6125, 13, 'Начало (yyyy-mm-dd): '),
(50442, 6128, 13, 'Начальная дата'),
(50443, 6129, 13, 'Дата первоначального обращения в эту клинику'),
(50444, 6130, 13, 'Дата начала не должна быть позже даты окончания'),
(50445, 6131, 13, 'Начальная дата:'),
(50446, 6132, 13, 'Начальная дата:'),
(50447, 6133, 13, 'Начальное время'),
(50448, 6134, 13, 'Начальная дата'),
(50449, 6135, 13, 'стат.'),
(50450, 6136, 13, 'Область (край)'),
(50451, 6137, 13, 'Тип данных для области'),
(50452, 6138, 13, '№ гос. лиц.'),
(50453, 6139, 13, 'Государственный номер лицензии'),
(50454, 6140, 13, 'Список областей (краев)'),
(50455, 6141, 13, 'Список областей/краев (write,addonly необязательно)'),
(50456, 6142, 13, 'Пользовательские поля виджета для списка областей'),
(50457, 6143, 13, 'Область или край'),
(50458, 6144, 13, 'Область/местоположение'),
(50459, 6145, 13, 'Область/район'),
(50460, 6146, 13, 'ИТОГОВАЯ ЗАЯВКА'),
(50461, 6147, 13, 'Заявки и обновленные счета.'),
(50462, 6148, 13, 'Отправка заявок:'),
(50463, 6149, 13, 'заявки; счета не будут обновлены.'),
(50464, 6150, 13, 'Статичный текст'),
(50465, 6151, 13, 'Статистические данные'),
(50466, 6152, 13, 'Стат.'),
(50467, 6153, 13, 'Статус'),
(50468, 6156, 13, 'Status quo'),
(50469, 6158, 13, 'Конс. ЗППП/СПИД'),
(50470, 6159, 13, 'Stength and Conditioning'),
(50471, 6169, 13, 'Тугоподвижность суставов'),
(50472, 6170, 13, 'Тугоподвижность'),
(50473, 6171, 13, 'Стандартные месяцы'),
(50474, 6172, 13, 'Боли в желудке'),
(50475, 6174, 13, 'Сохраненный хэш'),
(50476, 6175, 13, 'Растяжение мышцы'),
(50477, 6176, 13, 'Разбрызгивание'),
(50478, 6177, 13, 'Улица'),
(50479, 6178, 13, 'Уличный адрес'),
(50480, 6179, 13, 'Улица и номер'),
(50481, 6180, 13, 'Сила'),
(50482, 6182, 13, 'Острый фарингит'),
(50483, 6183, 13, 'Стрессовый перелом'),
(50484, 6184, 13, 'Нагрузочная проба'),
(50485, 6185, 13, 'Инсульт'),
(50486, 6186, 13, 'Строгий пароль подразумевает, по крайней мере, 8 символов и, по крайней мере, три условия: число, буква в нижнем регистре, буква в верхнем регистре, специальный символ.'),
(50487, 6188, 13, 'Для добавления нового пациента используется стиль формы'),
(50488, 6189, 13, 'Подкатегория'),
(50489, 6190, 13, 'Промежуточный итог'),
(50490, 6191, 13, 'Подкатегория'),
(50491, 6192, 13, 'подкатегория'),
(50492, 6193, 13, 'подкожно'),
(50493, 6194, 13, 'Субъект'),
(50494, 6195, 13, 'Субъективно'),
(50495, 6196, 13, 'Под язык'),
(50496, 6197, 13, 'под язык'),
(50497, 6198, 13, 'Запросить'),
(50498, 6199, 13, 'запросить'),
(50499, 6200, 13, 'Предоставить все содержание'),
(50500, 6202, 13, 'Подчинить событие'),
(50501, 6203, 13, 'предоставить форму'),
(50502, 6204, 13, 'Предоставить выбранное содержание'),
(50503, 6205, 13, 'предоставленное'),
(50504, 6206, 13, 'Предоставленное по'),
(50505, 6207, 13, 'Предоставить номер доступа EDI (PER06)'),
(50506, 6208, 13, 'Подписант'),
(50507, 6209, 13, 'Адрес подписанта'),
(50508, 6213, 13, 'Место работы подписанта'),
(50509, 6214, 13, 'Работодатель подписанта (SE)'),
(50510, 6215, 13, 'Адрес места работы подписанта'),
(50511, 6216, 13, 'Город работодателя подписанта'),
(50512, 6217, 13, 'Страна работодателя подписанта'),
(50513, 6218, 13, 'Область (край) места работы подписанта'),
(50514, 6221, 13, 'Почтовый индекс работодателя подписанта'),
(50515, 6225, 13, 'Телефон подписанта'),
(50516, 6226, 13, 'Родство подписанта'),
(50517, 6227, 13, 'Родство подписанта другое, но фамилия та же! Это верно?'),
(50518, 6228, 13, 'Родство подписанта другое, но номер SS тот же!'),
(50519, 6229, 13, 'Родство подписанта одно, но фамилия другая! Это верно?'),
(50520, 6230, 13, 'Родство подписанта одно, но номер SS другой! Это верно?'),
(50521, 6231, 13, 'Пол подписанта'),
(50522, 6237, 13, 'Замена'),
(50523, 6238, 13, 'замена разрешена'),
(50524, 6240, 13, 'Успех'),
(50525, 6241, 13, 'успех'),
(50526, 6242, 13, 'Подтверждение успешного получения лабораторного результата'),
(50527, 6243, 13, 'Успешное получение лабораторных результатов'),
(50528, 6244, 13, 'Успешное исправление лабораторных результатов из Lab Exchange Network'),
(50529, 6246, 13, 'Добавление категории успешно'),
(50530, 6247, 13, 'добавление категории успешно,'),
(50531, 6248, 13, 'Удалено успешно'),
(50532, 6250, 13, 'База данных успешно установлена.'),
(50533, 6252, 13, 'Изменено успешно'),
(50534, 6253, 13, 'Сохранено успешно. Хотите внести?'),
(50535, 6254, 13, 'Сохранено успешно. Хотите предоставить?'),
(50536, 6256, 13, 'сохранено успешно.'),
(50537, 6257, 13, 'База данных успешно модернизирована.'),
(50538, 6259, 13, 'удачно.'),
(50539, 6260, 13, 'Суицид'),
(50540, 6261, 13, 'Сводка'),
(50541, 6262, 13, 'Сводка по'),
(50542, 6265, 13, 'Вс'),
(50543, 6267, 13, 'Воскресенье'),
(50544, 6268, 13, 'Superbill'),
(50545, 6269, 13, 'Коды Superbill'),
(50546, 6270, 13, 'Управление кодами Superbill'),
(50547, 6271, 13, 'Отчет Superbill'),
(50548, 6272, 13, 'Лист оплаты/Superbill'),
(50549, 6273, 13, 'Superbills'),
(50550, 6274, 13, 'Superbills, иногда называемые как формы обращений или бланки направлений, являются неотъемлемой частью в большинстве случаев врачебной практики.'),
(50551, 6275, 13, 'Суперпользователь'),
(50552, 6276, 13, 'Руководитель'),
(50553, 6278, 13, 'Ответственный врач DEA'),
(50554, 6279, 13, 'Имя ответственного врача'),
(50555, 6280, 13, 'Фамилия ответственного врача'),
(50556, 6281, 13, 'NPI ответственного врача'),
(50557, 6282, 13, 'UPIN ответственного врача'),
(50558, 6283, 13, 'Наименование поставщика услуги'),
(50559, 6284, 13, 'Поддерживает календарные события, которые использовали многие специалисты'),
(50560, 6285, 13, 'Поддерживает экспорт/импорт конфигурационных данных через страницу резервного копирования.'),
(50561, 6286, 13, 'Поддерживает события многих специалистов'),
(50562, 6288, 13, 'Поддерживает шифрование/дешифрование только TripleDES'),
(50563, 6289, 13, 'Тип поверхности'),
(50564, 6290, 13, 'Операции'),
(50565, 6291, 13, 'Операция'),
(50566, 6293, 13, 'Поддерживаемые'),
(50567, 6294, 13, 'суспензия'),
(50568, 6295, 13, 'Дата Svc'),
(50569, 6296, 13, 'Дата Svc:'),
(50570, 6299, 13, 'Потливость:'),
(50571, 6300, 13, 'Шведский'),
(50572, 6301, 13, 'Отек'),
(50573, 6302, 13, 'Отек справа'),
(50574, 6303, 13, 'Отеки на суставах'),
(50575, 6304, 13, 'Увеличенные лимфоузлы'),
(50576, 6305, 13, 'Символ, используемый для денег в качестве десятичной запятой. Не используйте, если десятичных знаков 0).'),
(50577, 6306, 13, 'Символ, используемый для отделения тысяч для денег.'),
(50578, 6307, 13, 'Внешние признаки'),
(50579, 6308, 13, 'Синхронизировать'),
(50580, 6309, 13, 'Синхронизировать переводы с индивидуальной языковой таблицей.'),
(50581, 6310, 13, 'Новая индивидуальная синхронизированная константа:'),
(50582, 6311, 13, 'Новый пользовательский синхронизированный язык:'),
(50583, 6312, 13, 'Новое индивидуальное синхронизированное определение (язык, константа, определение):'),
(50584, 6313, 13, 'Обморок'),
(50585, 6314, 13, 'Посиндромное исследование'),
(50586, 6315, 13, 'Посиндромное исследование - несообщаемые результаты'),
(50587, 6317, 13, 'Синовиит, тендовагинит, бурсит'),
(50588, 6318, 13, 'Система'),
(50589, 6322, 13, 'T'),
(50590, 6323, 13, 'три раза в день'),
(50591, 6324, 13, 'Трансвеститы'),
(50592, 6325, 13, 'Таблица'),
(50593, 6327, 13, 'Создание таблицы дало сбой'),
(50594, 6328, 13, 'Обновление таблицы дало сбой'),
(50595, 6330, 13, 'Таблетка'),
(50596, 6332, 13, 'Тагальский'),
(50597, 6335, 13, 'Прием'),
(50598, 6336, 13, 'Выберите страховку из ниспадающего списка'),
(50599, 6337, 13, 'Выберите оплату из ниспадающего списка'),
(50600, 6338, 13, 'Возврат'),
(50601, 6339, 13, 'Занимает время'),
(50602, 6340, 13, 'Максимальная область навигации'),
(50603, 6347, 13, 'Намеченная дата'),
(50604, 6351, 13, 'Группы Планируемое/действие'),
(50605, 6354, 13, 'ИНН'),
(50606, 6355, 13, 'Ставка налогообложения'),
(50607, 6356, 13, 'Налоги'),
(50608, 6357, 13, 'Систематизация'),
(50609, 6358, 13, 'АДС'),
(50610, 6359, 13, 'Обзор травматологической бригады'),
(50611, 6360, 13, 'Состав бригады'),
(50612, 6361, 13, 'Просмотр состава бригады'),
(50613, 6362, 13, 'Бригада/отделение'),
(50614, 6363, 13, 'Тел.'),
(50615, 6364, 13, 'Международный код страны'),
(50616, 6366, 13, 'Темп.'),
(50617, 6367, 13, 'Место измерения температуры'),
(50618, 6368, 13, 'Метод измерения температуры'),
(50619, 6369, 13, 'Температура'),
(50620, 6370, 13, 'Шаблон'),
(50621, 6371, 13, 'Имя шаблона'),
(50622, 6372, 13, 'Имена шаблона не должны начинаться с цифр.'),
(50623, 6373, 13, 'Шаблон:'),
(50624, 6374, 13, 'Шаблоны'),
(50625, 6375, 13, 'Височная артерия'),
(50626, 6376, 13, 'Травма сухожилия'),
(50627, 6377, 13, 'Тенденит / остеомиелит / бурсит'),
(50628, 6378, 13, 'Предварительный счет для номера'),
(50629, 6379, 13, 'Третья'),
(50630, 6380, 13, 'Специализированная страховка'),
(50631, 6381, 13, 'Дата специального страхования'),
(50632, 6382, 13, 'Поставщик специального страхования'),
(50633, 6383, 13, 'План обследования'),
(50634, 6384, 13, 'Принципы обследования'),
(50635, 6385, 13, 'Текст'),
(50636, 6386, 13, 'Описательный диагноз'),
(50637, 6387, 13, 'Поле с текстом'),
(50638, 6393, 13, 'Текст-дата'),
(50639, 6394, 13, 'текст-дата'),
(50640, 6395, 13, 'Текстовая область'),
(50641, 6396, 13, 'текстовая область'),
(50642, 6397, 13, 'Текстовое поле'),
(50643, 6398, 13, 'текстовое поле'),
(50644, 6399, 13, 'Список текстовых полей'),
(50645, 6400, 13, 'список текстовых полей'),
(50646, 6401, 13, 'Тайский'),
(50647, 6402, 13, 'Спасибо'),
(50648, 6403, 13, 'Спасибо за Ваш выбор'),
(50649, 6404, 13, 'Кнопка ''Очистить'' удалит все аннотации.'),
(50650, 6405, 13, 'Вышеуказанная заявка дала сбой'),
(50651, 6406, 13, 'Сертификат сервера SSL Apache и общедоступный ключ'),
(50652, 6407, 13, 'Доверенный сертификат Certificate'),
(50653, 6408, 13, 'Требуемый файл: '),
(50654, 6410, 13, 'Соответствующий личный ключ'),
(50655, 6413, 13, 'вот код отказа'),
(50656, 6414, 13, 'вот код группы отказа'),
(50657, 6415, 13, 'Форма места назначения была закрыта'),
(50658, 6416, 13, 'Форма места назначения была закрыта; не удалось активировать ваш выбор.'),
(50659, 6418, 13, 'Обращение в EP, правомочную больницу или CAH, которые получают пациента из других стандартов лечения или от специалистов, соответствует, должно выполнять преемственность лечения.'),
(50660, 6421, 13, 'Полномочные профессионалы, больницы или центры здороья, которые переводят своих пациентов для медицинской помощи с другим управлением или специалистами, или направляют своих пациентов к другому медицинскому специалисту, должны предоставить медицинскую выписку для каждого перевода или направления.'),
(50661, 6422, 13, 'Это событие(я) было принято.'),
(50662, 6423, 13, 'Событие(я) скрыты.'),
(50663, 6424, 13, 'Данные экспорта предоставлены в текстовой области ниже. Можете скопировать и вставить их в email или любое другое необходимое место назначения.'),
(50664, 6426, 13, 'Данные экспорта предоставлены в текстовой области ниже. Можете скопировать и вставить в email или любое другое необходимое место назначения.'),
(50665, 6427, 13, 'Данные экспорта предоставлены в текстовой области ниже. Можете скопировать и вставить их в email или любое другое необходимое место назначения.'),
(50666, 6429, 13, 'Этот файл не удалось переименовать, эта ошибка, обычно связана с проблемами прав доступа в системе хранения.'),
(50667, 6434, 13, 'Были добавлены следующие календарные события:'),
(50668, 6435, 13, 'Следующие календарные события были изменены:'),
(50669, 6436, 13, 'Следующие категории будут удалены из вашего списка категорий'),
(50670, 6437, 13, 'В настоящее время установлена следующая версия базы данных.'),
(50671, 6439, 13, 'Следующий файл EDI был обновлен'),
(50672, 6440, 13, 'Активирован следующий пользователь чрезвычайного входа в систему:'),
(50673, 6441, 13, 'Произошла следующая ошибка'),
(50674, 6444, 13, 'Следующие поля являются обязательными'),
(50675, 6446, 13, 'Для отправки запроса должны быть заполнены следующие поля.'),
(50676, 6449, 13, 'Имя узла на архивном компьютере для аудита ATNA'),
(50677, 6450, 13, 'Начальное окно является страницей поиска счета. Вверху можете ввести источник (например, номер чека), дату оплаты и сумму чека. Причина для источника и даты оплаты одна, так что вам не придется вводить их много раз для каждого требования. ...'),
(50678, 6456, 13, 'Метка, которая появляется для этого пользователя в форме'),
(50679, 6457, 13, 'Длина не должна превышать этого количества символов'),
(50680, 6460, 13, 'Новая категория будет подкатегорией для '),
(50681, 6461, 13, 'Новый пароль не может быть таким же, как текущий.'),
(50682, 6462, 13, 'Поля нового пароля отличаются.'),
(50683, 6465, 13, 'Страница будет перенаправлена в персональные данные. Можно изменить поле страны и снова кликнуть в NewCrop.'),
(50684, 6466, 13, 'Пароль должен быть менее восьми символов и должен...'),
(50685, 6468, 13, 'Запрос на запись для пациента был выполнен.'),
(50686, 6469, 13, 'Напоминания пациенту отправлены'),
(50687, 6470, 13, 'Напоминания пациенту обновлены'),
(50688, 6472, 13, 'Введенные платежи не могут быть позже этой даты. Это означает, что после совершения завершающего отчета никто не введет на более ранние даты.'),
(50689, 6475, 13, 'Сведения, приведенные ниже, применяются, только если вручную публикуете или исправляете.'),
(50690, 6477, 13, 'Запрошенный документ в ожидаемом месте файловой системы отсутствует или нет достаточных прав доступа к нему.'),
(50691, 6480, 13, 'Столбцы источника и даты копируются с первой страницы, так что, обычно, не нужно трогать их. Можете поместить сумму платежа в столбце оплаты, скорректированную сумму в столбце Изменить, или обоих. Можно также нажать «W» справа для авто...'),
(50692, 6484, 13, 'Временная детализация календаря и наименьший интервал в минутах для вставки записи на прием.'),
(50693, 6485, 13, 'Переведенная метка, которая выводится на текущем языке в форме'),
(50694, 6486, 13, 'Переведенный заголовок, который будет выводится на текущем языке'),
(50695, 6487, 13, 'Перевод описания на текущем языке'),
(50696, 6488, 13, 'Таблицы переводов синхронизированы.'),
(50697, 6489, 13, 'Тип этого объекта'),
(50698, 6490, 13, 'Код производителя, идентифицирующий эту методику или результат'),
(50699, 6491, 13, 'Файлы X12 также, как полученные отчеты вывода HTML, архивируются в подкаталоге "era" основной инсталляционной директории LibreEHR. Следует обращаться время от времени к этим архивам. URL-адрес'),
(50700, 6492, 13, 'Файл zip будет содержать следующие пункты'),
(50701, 6493, 13, 'Тема'),
(50702, 6495, 13, 'Терапевтические инъекции'),
(50703, 6496, 13, 'Вот'),
(50704, 6497, 13, 'В настоящее время нет назначений'),
(50705, 6498, 13, 'Имеются ошибки с вашим предоставлением. Они обрисованы ниже.'),
(50706, 6500, 13, 'Выписанных карт нет.'),
(50707, 6501, 13, 'Для этого пациента публикаций не зарегистрировано.'),
(50708, 6502, 13, 'Новых предоставлений нет'),
(50709, 6503, 13, 'Для этого пациента нет записей в файл.'),
(50710, 6504, 13, 'Для этого пациента нет транзакций в файл.'),
(50711, 6505, 13, 'Вот ошибка отправки почты'),
(50712, 6506, 13, 'Категория уже именована'),
(50713, 6507, 13, 'Подкатегория уже именована'),
(50714, 6508, 13, 'Элемент уже именован'),
(50715, 6509, 13, 'Запрос на запись для пациента уже открыт.'),
(50716, 6510, 13, 'Это не ввод COA для аккаунта AR '),
(50717, 6511, 13, 'Это не ввод COA для аккаунта кэша '),
(50718, 6512, 13, 'Это не ввод COA для входящего аккаунта '),
(50719, 6513, 13, 'Нет ни одного текущего пациента'),
(50720, 6515, 13, 'Для id счета нет соответствия'),
(50721, 6516, 13, 'Нет соответствия для счета с id= '),
(50722, 6517, 13, 'Это не ввод части для ID услуг '),
(50723, 6520, 13, 'При обработке вашего запроса была ошибка.'),
(50724, 6523, 13, 'Уплотненное справа'),
(50725, 6524, 13, 'Бедро'),
(50726, 6525, 13, 'Бедро и подколенная ямка'),
(50727, 6527, 13, 'Объекты, которые оперчасть может читать и вводить, но не изменять'),
(50728, 6528, 13, 'Объекты, которые оперчасть может читать и изменять'),
(50729, 6531, 13, 'Объекты, которые клиницисты могут читать и вводить, но не изменять'),
(50730, 6532, 13, 'Объекты, которые клиницисты могут читать и изменять'),
(50731, 6535, 13, 'Объекты, которые регистратура может читать и вводить, но не изменять'),
(50732, 6536, 13, 'Объекты, которые регистратура может читать и изменять'),
(50733, 6539, 13, 'Объекты, которые врачи могут читать и вводить, но не изменять'),
(50734, 6540, 13, 'Объекты, которые врачи могут читать и изменять'),
(50735, 6542, 13, 'Третий'),
(50736, 6544, 13, 'Это действие НЕ МОЖЕТ БЫТЬ отменено.'),
(50737, 6545, 13, 'Это действие не может быть отменено.'),
(50738, 6547, 13, 'Это действие будет зарегистрировано'),
(50739, 6551, 13, 'Этот календарный год'),
(50740, 6554, 13, 'Это требование было отвергнуто. Причина: -'),
(50741, 6555, 13, 'Это требование отправлено на следующий уровень.'),
(50742, 6556, 13, 'Этот тип кода не принимает зависимости.'),
(50743, 6557, 13, 'Вот категории контекстного содержания, которые будут удалены. Все еще нужно продолжить?'),
(50744, 6558, 13, 'Они определяют, как записи на прием отображаются в календаре.'),
(50745, 6559, 13, 'Определяет, какая цветовая схема используется для записи на прием'),
(50746, 6561, 13, 'Это обращение'),
(50747, 6565, 13, 'Этот компонент является экспериментальным и тестирован не полностью. Используйте его на свой собственный риск!'),
(50748, 6566, 13, 'Этот номер счета был изменен на '),
(50749, 6575, 13, 'Этот модуль работает в тестовом режиме. База данных не будет изменена.'),
(50750, 6576, 13, 'Этот модуль поддерживает эффективный ввод данных EOB.'),
(50751, 6577, 13, 'Этот месяц до даты'),
(50752, 6581, 13, 'Эта страница будет включать встроенный вход в систему, чтобы не делать это каждый раз.'),
(50753, 6582, 13, 'Этот пациент не активирован.'),
(50754, 6583, 13, 'Этот ID пациента уже в использовании!'),
(50755, 6584, 13, 'Этот продукт допускает только одну партию на складе'),
(50756, 6591, 13, 'На этом шаге будет создан файл, который нужно сохранить для последующего использования. Этот файл не может быть создан повторно.Необходимо выполнить?'),
(50757, 6592, 13, 'Этот пользователь не является членом ни одной группы'),
(50758, 6595, 13, 'Это посещение начинает использование новой контрацепции'),
(50759, 6596, 13, 'Для этого посещения необходима форма GCAC, предоставление направления или процедуры.'),
(50760, 6597, 13, 'Это была старая только метрическая форма жизненно важных показателей, в настоящее время устарела.'),
(50761, 6598, 13, 'Эта неделя до даты'),
(50762, 6600, 13, 'Активирует сообщения CCR (непрерывность медицинской записи) и CCD (непрерывность медицинского документа).'),
(50763, 6602, 13, 'Разрешает выбор отладочного языка (''подставного'').'),
(50764, 6606, 13, 'Будет создана резервная копия в формате tar и затем отправлена на ваш веб-браузер, так что вы сможете ее сохранить'),
(50765, 6607, 13, 'Функция шифрования и дешифрования документа будет дезактивирована и спрятана в UI.'),
(50766, 6613, 13, 'Это вызовет в итоговом отображении пациента всегда открытый виджет счетов.'),
(50767, 6617, 13, 'Это не предотвратит от перехода в место e-назначения.'),
(50768, 6619, 13, 'Будет использован пользовательский список вакцинации, а не стандартный список вакцинации CVX'),
(50769, 6622, 13, 'Грудной отдел позвоночника'),
(50770, 6623, 13, 'Тыс./куб.мм'),
(50771, 6625, 13, 'Гортань'),
(50772, 6626, 13, 'Рак гортани'),
(50773, 6627, 13, 'Хирургия рака гортани'),
(50774, 6628, 13, 'Тромбоз/инсульт'),
(50775, 6629, 13, 'Чт'),
(50776, 6630, 13, 'Четверг'),
(50777, 6631, 13, 'Четверг'),
(50778, 6632, 13, 'Обычная щитовидная железа'),
(50779, 6633, 13, 'Проблемы щитовидной железы'),
(50780, 6634, 13, 'Преходящее ОНМК'),
(50781, 6636, 13, 'TID'),
(50782, 6638, 13, 'время'),
(50783, 6639, 13, 'Формат отображения времени'),
(50784, 6640, 13, 'Сдвиг времени для добавления (1-60 минут)'),
(50785, 6641, 13, 'Выбор времени'),
(50786, 6647, 13, 'Разовое событие'),
(50787, 6648, 13, 'Набор времени (NA)'),
(50788, 6649, 13, 'Временная метка и текст'),
(50789, 6650, 13, 'TIN'),
(50790, 6651, 13, 'Звон в ушах'),
(50791, 6652, 13, 'Название'),
(50792, 6653, 13, 'Название V'),
(50793, 6654, 13, 'Столбцы данных должно быть числом между 1 и 999'),
(50794, 6655, 13, 'Обращения'),
(50795, 6656, 13, 'TM''S:'),
(50796, 6657, 13, 'Наружный нос, TMs/EAMs/EE'),
(50797, 6658, 13, 'по'),
(50798, 6659, 13, 'ДО'),
(50799, 6660, 13, 'до'),
(50800, 6661, 13, 'в абсолютном пути файла'),
(50801, 6662, 13, 'Кликните для добавления записей '),
(50802, 6663, 13, 'Кликните здесь для добавления записей'),
(50803, 6664, 13, 'На пораженную область'),
(50804, 6665, 13, 'на пораженную область'),
(50805, 6666, 13, 'Для автоматического открытия этой указанной формы. Некоторые спортивные команды здесь используют football_injury_audit.'),
(50806, 6667, 13, 'Для просмотра счета'),
(50807, 6668, 13, 'в категории'),
(50808, 6669, 13, 'Для больничного просмотра'),
(50809, 6670, 13, 'В доплату'),
(50810, 6672, 13, 'В ded''ble'),
(50811, 6673, 13, 'В электронную службу передачи цифровых сообщений'),
(50812, 6674, 13, 'Для отключения сертификатов SSL на стороне клиента закомментируйте вышеуказанные строки в конфигурационном файле Apache и установите'),
(50813, 6675, 13, 'Для отключения HTTPS закомментируйте вышеуказанные строки в конфигурационном файле Apache и перезагрузите сервер Apache.'),
(50814, 6676, 13, 'Для включения сертификатов ssl на стороне клиента'),
(50815, 6677, 13, 'Для включения проверки сертификатов ssl на стороне клиента должен быть включен HTTPS'),
(50816, 6678, 13, 'Для включения только HTTPS, сделайте указанные выше изменения и перезапустите сервер Apache. Если хотите также настроить сертификаты на стороне клиента, сконфигурируйте их в следующем разделе.'),
(50817, 6679, 13, 'Для обращ.'),
(50818, 6680, 13, 'Фильтровать по полу'),
(50819, 6681, 13, 'В анамнез'),
(50820, 6682, 13, 'В проблемы'),
(50821, 6683, 13, 'Для связывания этого обращения или консультации с имеющейся проблемой, нажмите здесь '),
(50822, 6684, 13, 'Для связи этого обращения/консультации с существующей проблемой кликните выше нужную для выделения и нажмите [Сохранить]. Для выбора нескольких проблем удерживайте клавишу [Ctrl].'),
(50823, 6685, 13, 'для повторного входа в систему'),
(50824, 6686, 13, 'Кликните для опубликования записи'),
(50825, 6687, 13, 'для запуска'),
(50826, 6688, 13, 'Для организации доступа https с проверкой сертификата клиента сделайте следующее'),
(50827, 6689, 13, 'Накожно'),
(50828, 6690, 13, 'накожно'),
(50829, 6691, 13, 'в это посещение?'),
(50830, 6693, 13, 'до:'),
(50831, 6694, 13, 'до: '),
(50832, 6695, 13, 'TO_CITY'),
(50833, 6696, 13, 'TO_FAX'),
(50834, 6697, 13, 'TO_FNAME'),
(50835, 6698, 13, 'TO_LNAME'),
(50836, 6699, 13, 'TO_MNAME'),
(50837, 6700, 13, 'TO_ORGANIZATION'),
(50838, 6703, 13, 'TO_POSTAL'),
(50839, 6704, 13, 'TO_STATE'),
(50840, 6705, 13, 'TO_STREET'),
(50841, 6706, 13, 'TO_TITLE'),
(50842, 6707, 13, 'TO_VALEDICTORY'),
(50843, 6708, 13, 'Табак'),
(50844, 6709, 13, 'Вмешательство по прекращению табакокурения'),
(50845, 6710, 13, 'Вмешательство по прекращению табакокурения (CQM)'),
(50846, 6712, 13, 'Использование табака'),
(50847, 6713, 13, 'Оценка использования табака'),
(50848, 6714, 13, 'Оценка использования табака (CQM)'),
(50849, 6715, 13, 'Сегодня'),
(50850, 6716, 13, 'СЕГОДНЯ'),
(50851, 6717, 13, 'сегодня'),
(50852, 6718, 13, 'Сегодняшний баланс'),
(50853, 6719, 13, 'Сегодняшние оплаты'),
(50854, 6720, 13, 'Сегодняшняя дата'),
(50855, 6721, 13, 'Сегодняшние события'),
(50856, 6724, 13, 'ID знака для поддержки LibreEHR лабораторных услуг обмена LLC'),
(50857, 6726, 13, 'Тонзилэктомия'),
(50858, 6728, 13, 'Верх'),
(50859, 6730, 13, 'Раздел'),
(50860, 6731, 13, 'Всего'),
(50861, 6732, 13, 'всего'),
(50862, 6733, 13, 'Всего активных действий'),
(50863, 6734, 13, 'Всего активных напоминаний после обновления'),
(50864, 6735, 13, 'Всего активных напоминаний до обновления'),
(50865, 6737, 13, 'Подлежит всего'),
(50866, 6738, 13, 'Всего подлежит оплатить'),
(50867, 6741, 13, 'Общий платеж'),
(50868, 6742, 13, 'Всего клиентов'),
(50869, 6743, 13, 'Общая стоимость'),
(50870, 6744, 13, 'Итоговое количество для последующей проверки предоставлено не полностью'),
(50871, 6746, 13, 'Через e-mail отправка напоминаний была неудачной'),
(50872, 6747, 13, 'Через телефон отправка напоминаний была неудачной'),
(50873, 6748, 13, 'Всего для'),
(50874, 6749, 13, 'Всего для '),
(50875, 6750, 13, 'Всего для категории'),
(50876, 6751, 13, 'Всего инактивированных напоминаний'),
(50877, 6752, 13, 'Всего новых напоминаний'),
(50878, 6755, 13, 'Общее количество вакцинаций'),
(50879, 6756, 13, 'Общее количество результатов'),
(50880, 6758, 13, 'Общее количество пациентов'),
(50881, 6760, 13, 'Итоговый баланс по пациентам'),
(50882, 6761, 13, 'Всего пациентов'),
(50883, 6764, 13, 'Всего найденных записей'),
(50884, 6765, 13, 'Общее планирование SRH и семьи'),
(50885, 6766, 13, 'Всего успешных напоминаний, отправленных через email,'),
(50886, 6767, 13, 'Всего успешных напоминаний, отправленных через телефон,'),
(50887, 6770, 13, 'Всего неизменных напоминаний'),
(50888, 6771, 13, 'Всего неотправленных напоминаний после запуска процесса'),
(50889, 6772, 13, 'Всего неотправленных напоминаний после обновления'),
(50890, 6773, 13, 'Всего неотправленных напоминаний до запуска процесса'),
(50891, 6774, 13, 'Всего неотправленных напоминаний до обновления'),
(50892, 6775, 13, 'Всего обновленных напоминаний'),
(50893, 6776, 13, 'Итоги'),
(50894, 6777, 13, 'Всего для'),
(50895, 6778, 13, 'Всего для '),
(50896, 6785, 13, 'Тип обучения'),
(50897, 6786, 13, 'Провести'),
(50898, 6787, 13, 'Транзакция'),
(50899, 6788, 13, 'транзакция'),
(50900, 6789, 13, 'Транзакция дала сбой, недостаточное количество в назначаемой партии'),
(50901, 6790, 13, 'Транзакция дала сбой, количество меньше ноля'),
(50902, 6791, 13, 'Тип транзакции'),
(50903, 6792, 13, 'транзакции'),
(50904, 6793, 13, 'Транзакции'),
(50905, 6794, 13, 'Транзакции (write необязательно)'),
(50906, 6795, 13, 'Транзакции/направления'),
(50907, 6797, 13, 'Передать'),
(50908, 6799, 13, 'Передача дала сбой, недостаточное количество в исходной партии'),
(50909, 6804, 13, 'Передачи'),
(50910, 6806, 13, 'Смена/перемещение медицинской помощи?'),
(50911, 6807, 13, 'Группы управления доступом к переводу'),
(50912, 6808, 13, 'Переводить категории приема'),
(50913, 6809, 13, 'Переводить категории документа'),
(50914, 6810, 13, 'Переводить макеты'),
(50915, 6811, 13, 'Переводить списки'),
(50916, 6812, 13, 'Переводить заголовки записей по пациентам'),
(50917, 6813, 13, 'перевести это'),
(50918, 6814, 13, 'Перевод'),
(50919, 6815, 13, 'Переводы'),
(50920, 6819, 13, 'Травма'),
(50921, 6820, 13, 'Лечение'),
(50922, 6822, 13, 'Цель лечения'),
(50923, 6823, 13, 'План лечения'),
(50924, 6826, 13, 'Лечение:'),
(50925, 6827, 13, 'Лечение: '),
(50926, 6828, 13, 'Динамика'),
(50927, 6829, 13, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) ); $month_value'),
(50928, 6830, 13, 'Пусковая точка / синдром сдавления / DOMS / судорога'),
(50929, 6831, 13, 'Трималяр'),
(50930, 6832, 13, 'Торс и живот'),
(50931, 6837, 13, 'ч.л.'),
(50932, 6839, 13, 'Трансдермальная терапевтическая система'),
(50933, 6840, 13, 'Туберкулез'),
(50934, 6841, 13, 'Вт'),
(50935, 6842, 13, 'Вт &amp; Чт'),
(50936, 6843, 13, 'Вторник'),
(50937, 6844, 13, 'Новообразование'),
(50938, 6845, 13, 'Турецкий'),
(50939, 6846, 13, 'Туркменский'),
(50940, 6848, 13, 'дважды в день'),
(50941, 6850, 13, 'Барабанная перепонка'),
(50942, 6851, 13, 'Ввести'),
(50943, 6852, 13, 'Введите id или имя. Минимум 3 символа (включая пробелы).'),
(50944, 6853, 13, 'Тип столбцов, отображаемых для результатов поиска пациента'),
(50945, 6854, 13, 'Тип публикации'),
(50946, 6855, 13, 'Тип событий'),
(50947, 6856, 13, 'Тип макета экрана'),
(50948, 6857, 13, 'Введите или просматривайте идентификатор пациента здесь'),
(50949, 6858, 13, 'Введите здесь свое сообщение'),
(50950, 6859, 13, 'Типы назначений и выполнений'),
(50951, 6864, 13, 'Коды UCSMC предоставлены через Университет Спортивного Медицинского Центра Калгари'),
(50952, 6865, 13, 'Украинский'),
(50953, 6866, 13, 'Изъязвления'),
(50954, 6867, 13, 'Язвенный колит'),
(50955, 6868, 13, 'Язвы'),
(50956, 6869, 13, 'Невозможно открыть директорию'),
(50957, 6870, 13, 'Невозможно открыть URL'),
(50958, 6871, 13, 'Невозможно создать'),
(50959, 6876, 13, 'Неприменимо'),
(50960, 6877, 13, 'Без указания'),
(50961, 6879, 13, 'Несанкционированный доступ к ePrescription'),
(50962, 6880, 13, 'Несанкционированный доступ.'),
(50963, 6882, 13, 'Только не для счетов'),
(50964, 6884, 13, 'под язык'),
(50965, 6885, 13, 'Похудание'),
(50966, 6886, 13, 'Недиагностированный'),
(50967, 6887, 13, 'НЕВЫПЛАЧЕННОЕ'),
(50968, 6888, 13, 'Невыплаченное'),
(50969, 6889, 13, 'Невыплаченным является'),
(50970, 6890, 13, 'Отменить расчет'),
(50971, 6892, 13, 'Уникальные клиенты'),
(50972, 6893, 13, 'Уникальный идентификатор для этого типа, читаемый человеком'),
(50973, 6894, 13, 'Уникальные новые клиенты'),
(50974, 6895, 13, 'Уникальный числовой идентификатор для этого типа'),
(50975, 6896, 13, 'Индивидуальный осмотр пациента'),
(50976, 6897, 13, 'Отчет об индивидуальным осмотре пациента'),
(50977, 6898, 13, 'Индивидуальная периферическая сатурация'),
(50978, 6899, 13, 'Единица измерения'),
(50979, 6900, 13, 'Единицы измерения'),
(50980, 6901, 13, 'ед. изм.'),
(50981, 6903, 13, 'Единицы измерения для форм посещения'),
(50982, 6904, 13, 'Единицы измерения должны быть числом'),
(50983, 6905, 13, 'Единицы измерения не определены'),
(50984, 6906, 13, 'Единица измерения/л'),
(50985, 6907, 13, 'Неизвестный'),
(50986, 6910, 13, 'Неизвестно, даже если курит'),
(50987, 6911, 13, 'Неизвестно или NA'),
(50988, 6913, 13, 'несвязанный пациент'),
(50989, 6914, 13, 'Неназванная страховая компания'),
(50990, 6915, 13, 'Незарегистрированные'),
(50991, 6918, 13, 'Снять все выделения'),
(50992, 6919, 13, 'Не выбранный'),
(50993, 6920, 13, 'Неуказанное'),
(50994, 6921, 13, 'неструктурированное'),
(50995, 6924, 13, 'до'),
(50996, 6925, 13, 'Неподходящая регистрация'),
(50997, 6926, 13, 'Неиспользуемое'),
(50998, 6927, 13, 'Требование экстренного вмешательства'),
(50999, 6928, 13, 'включая до'),
(51000, 6929, 13, 'Ближайшие записи на прием'),
(51001, 6930, 13, 'Предстоящие события'),
(51002, 6931, 13, 'Обновить'),
(51003, 6932, 13, 'обновить'),
(51004, 6933, 13, 'Обновить активность'),
(51005, 6934, 13, 'Обновить файлы');
INSERT INTO `lang_definitions` VALUES
(51006, 6935, 13, 'Обновить инф.'),
(51007, 6936, 13, 'Обновить список'),
(51008, 6937, 13, 'Обновить номер специалиста'),
(51009, 6938, 13, 'Обновить выбранные объекты'),
(51010, 6939, 13, 'Обновляет следующие переменные в файле'),
(51011, 6940, 13, 'Обновляет информацию о пользователе'),
(51012, 6942, 13, 'Обновление персональных данных не разрешено.'),
(51013, 6946, 13, 'Модернизация'),
(51014, 6947, 13, 'Модернизация базы данных'),
(51015, 6948, 13, 'Модернизирует базу данных LibreEHR для включения методик, функций и таблиц, необходимых для процесса исключения дублирования идентификации'),
(51016, 6949, 13, 'Модернизация будет продолжена'),
(51017, 6950, 13, 'Уникальный врачебный идентификационный номер'),
(51018, 6951, 13, 'Загрузить'),
(51019, 6952, 13, 'Загрузить шаблон'),
(51020, 6953, 13, 'Загрузить и установить'),
(51021, 6954, 13, 'Загрузить конфигурационные данные'),
(51022, 6955, 13, 'Загрузить документ'),
(51023, 6956, 13, 'Загрузка не удалась!'),
(51024, 6957, 13, 'Загрузить изображение в'),
(51025, 6958, 13, 'Загрузите файл импорта:'),
(51026, 6961, 13, 'Загрузить отчет'),
(51027, 6963, 13, 'Загрузите этот файл:'),
(51028, 6964, 13, 'При клике на номере счета появляется "окно ручной регистрации". Здесь можно изменить дату оплаты и заметки для счета, выбрать участника, для которого регистрируете и страховку, для которой должны быть получены все предположительные платежи. Особенно важно то, что для каждого биллингового кода, для которого была изменена сумма, можно ввести платеж и информацию по корректировке.'),
(51029, 6965, 13, 'При поиске вы увидите список счетов. Можете кликнуть на один из номеров счета для открытия второго окна, которое является страницей ввода данных для ручной регистрации. Также можете кликнуть по имени пациента, если нужно ввести запись, которую при регистрации пациента увидят сотрудники регистратуры, и вы сможете выбрать появление счетов для заявок по пациенту и их печать.'),
(51030, 6966, 13, 'Верхняя конечность'),
(51031, 6968, 13, 'Императивные позывы'),
(51032, 6970, 13, 'Моча'),
(51033, 6971, 13, 'Подтекание мочи'),
(51034, 6972, 13, 'Учащенное мочеиспускание'),
(51035, 6973, 13, 'Ослабленный напор струи мочи'),
(51036, 6974, 13, 'Микроальбумин мочи'),
(51037, 6975, 13, 'Поток мочи'),
(51038, 6976, 13, 'Безотлагательность позыва на мочеиспускание'),
(51039, 6977, 13, 'URL'),
(51040, 6979, 13, 'URL для поддержки LibreEHR.'),
(51041, 6981, 13, 'URL для телефонного шлюза. Автоматизированная служба VOIP предоставлена через Maviq. Посетите http://signup.maviq.com для получения дополнительной информации.'),
(51042, 6986, 13, 'Индикатор использования (ISA15)'),
(51043, 6987, 13, 'Для сортировки напрямую в этом столбце просто используйте %'),
(51044, 6988, 13, 'Использовать 24-часовой формат времени?'),
(51045, 6990, 13, 'Используйте сертифицированные технологии EHR для выявления образовательных ресурсов конкретному пациенту и, если это необходимо, предоставьте их пациенту.'),
(51046, 6991, 13, 'Использование панели платежа'),
(51047, 6992, 13, 'Используйте CPOE для лечебных назначений, сделанных непосредственно любым дипломированным специалистом, который может делать назначения в медицинской карте согласно государственных, местных и профессиональных руководящих принципов.'),
(51048, 6997, 13, 'Использовать пользовательский список вакцинации'),
(51049, 6999, 13, 'Использовать диапазон дат'),
(51050, 7000, 13, 'Использовать по умолчанию'),
(51051, 7001, 13, 'Используйте опцию Удалить для удаления.'),
(51052, 7002, 13, 'Использовать международный стиль дат?'),
(51053, 7003, 13, 'Используйте имя файла исходника'),
(51054, 7004, 13, 'Используйте поля ниже для получения или передачи.'),
(51055, 7005, 13, 'Используйте эту возможность только для вновь установленных сайтов, '),
(51056, 7006, 13, 'Использовать разделы?'),
(51057, 7007, 13, 'Пользователь'),
(51058, 7009, 13, 'Пользователь / группы'),
(51059, 7010, 13, 'Управление пользователем'),
(51060, 7011, 13, 'Управление пользователем и услугами'),
(51061, 7012, 13, 'Управление пользователем и группой'),
(51062, 7013, 13, 'Пользователь не может быть удален'),
(51063, 7014, 13, 'Проверка сертификата пользователя отключена'),
(51064, 7015, 13, 'Определенный пользователем'),
(51065, 7016, 13, 'Область 11, определенная пользователем'),
(51066, 7017, 13, 'Область 12, определенная пользователем'),
(51067, 7018, 13, 'Поле, определяемое пользователем'),
(51068, 7019, 13, 'Список 1, определенный пользователем'),
(51069, 7020, 13, 'Список 2, определенный пользователем'),
(51070, 7021, 13, 'Список 3, определенный пользователем'),
(51071, 7022, 13, 'Список 4, определенный пользователем'),
(51072, 7023, 13, 'Список 5, определенный пользователем'),
(51073, 7024, 13, 'Список 6, определенный пользователем'),
(51074, 7025, 13, 'Список 7, определенный пользователем'),
(51075, 7026, 13, 'Текст 1, определенный пользователем'),
(51076, 7027, 13, 'Текст 2, определенный пользователем'),
(51077, 7028, 13, 'Текст 3, определенный пользователем'),
(51078, 7029, 13, 'Текст 4, определенный пользователем'),
(51079, 7030, 13, 'Текст 5, определенный пользователем'),
(51080, 7031, 13, 'Текст 6, определенный пользователем'),
(51081, 7032, 13, 'Текст 7, определенный пользователем'),
(51082, 7033, 13, 'Текст 8, определенный пользователем'),
(51083, 7034, 13, 'Имя пользователя'),
(51084, 7039, 13, 'Руководство пользователя'),
(51085, 7040, 13, 'Членство пользователя'),
(51086, 7041, 13, 'Имя пользователя'),
(51087, 7042, 13, 'Имя пользователя или хоста не может быть пустым'),
(51088, 7043, 13, 'Имя пользователя или хоста'),
(51089, 7046, 13, 'Параметры настройки пользователя'),
(51090, 7047, 13, 'Собственная настройка пользователя'),
(51091, 7049, 13, 'Имя пользователя'),
(51092, 7051, 13, 'Имя пользователя для телефонного шлюза. Автоматизированная служба VOIP предоставлена через Maviq. Посетите http://signup.maviq.com для получения дополнительной информации.'),
(51093, 7052, 13, 'Имя пользователя для шлюза SMS'),
(51094, 7053, 13, 'Имя пользователя для шлюза SMS.'),
(51095, 7055, 13, 'Имя пользователя:'),
(51096, 7056, 13, 'Пользователи'),
(51097, 7057, 13, 'Управление пользователями/группами/регистрацией'),
(51098, 7058, 13, 'используйте формат php <a href="http://php.net/strftime">strftime</a>'),
(51099, 7059, 13, 'ИМП'),
(51100, 7062, 13, 'ОТПУСК'),
(51101, 7063, 13, 'Отпуск'),
(51102, 7064, 13, 'Вакцина'),
(51103, 7065, 13, 'Контрацептивное влагалищное кольцо'),
(51104, 7066, 13, 'Напутствие'),
(51105, 7067, 13, 'допустимый'),
(51106, 7068, 13, 'Значение'),
(51107, 7069, 13, 'Значение 1'),
(51108, 7070, 13, 'Значение 2'),
(51109, 7072, 13, 'Значение должно быть цифровым'),
(51110, 7073, 13, 'Перем 1'),
(51111, 7074, 13, 'Перем 2'),
(51112, 7075, 13, 'единственная переменная для запуска скрипта модернизации деидентификации'),
(51113, 7076, 13, 'Ветряная оспа 1'),
(51114, 7077, 13, 'Ветряная оспа 2'),
(51115, 7078, 13, 'Варикозно расширенные вены'),
(51116, 7079, 13, 'Состояние сосудов'),
(51117, 7080, 13, 'Повреждение сосудов'),
(51118, 7081, 13, 'Ангиохирургия'),
(51119, 7083, 13, 'Производитель'),
(51120, 7084, 13, 'Версия'),
(51121, 7085, 13, 'Головокружение'),
(51122, 7086, 13, 'Старая программа'),
(51123, 7087, 13, 'Старая правительственная программа'),
(51124, 7088, 13, 'Детская вакцина'),
(51125, 7089, 13, 'Вьетнамский'),
(51126, 7090, 13, 'вид'),
(51127, 7091, 13, 'Вид'),
(51128, 7092, 13, 'Просмотр аллергии'),
(51129, 7097, 13, 'Просмотр сжатого отчета по пациенту'),
(51130, 7100, 13, 'Просмотр документа'),
(51131, 7101, 13, 'Просмотр обращения'),
(51132, 7103, 13, 'Просмотреть события во всплывающем окне?'),
(51133, 7107, 13, 'Просмотреть журнал'),
(51134, 7108, 13, 'Просмотреть страницу 1'),
(51135, 7109, 13, 'Просмотреть страницу 2'),
(51136, 7110, 13, 'Просмотреть прошлые и будущие напоминания'),
(51137, 7111, 13, 'Обзор по пациенту'),
(51138, 7116, 13, 'Обзор связанных обращений'),
(51139, 7121, 13, 'Обзор/изменение аллергии'),
(51140, 7122, 13, 'Обзор/изменение проблемы'),
(51141, 7123, 13, 'Вид/печать'),
(51142, 7124, 13, 'Просмотреть:'),
(51143, 7125, 13, 'VISA'),
(51144, 7126, 13, 'VISA/MC/AMEX/Dis'),
(51145, 7127, 13, 'Повреждение внутренних органов/травма/оперативное вмешательство'),
(51146, 7133, 13, 'Категория посещения:'),
(51147, 7134, 13, 'Дата посещения'),
(51148, 7135, 13, 'Дата посещения'),
(51149, 7137, 13, 'Форма посещения'),
(51150, 7138, 13, 'Хронология посещений'),
(51151, 7140, 13, 'Посещения'),
(51152, 7141, 13, 'Форма посещения'),
(51153, 7142, 13, 'Обозначение жизненно важных показателей'),
(51154, 7143, 13, 'Жизненно важные показатели'),
(51155, 7144, 13, 'Жизненно важные показатели (метрические)'),
(51156, 7146, 13, 'Голосовое'),
(51157, 7147, 13, 'Телефонограмма'),
(51158, 7149, 13, 'Рвота'),
(51159, 7151, 13, 'W'),
(51160, 7152, 13, 'Окр. талии'),
(51161, 7153, 13, 'Окружность талии'),
(51162, 7154, 13, 'Ожидание'),
(51163, 7155, 13, 'Без предварительной записи'),
(51164, 7157, 13, 'Walt Pennington'),
(51165, 7158, 13, 'Склад'),
(51166, 7159, 13, 'Максимум хранения, 0 если не применимо'),
(51167, 7160, 13, 'Минимум хранения, 0 если не применимо'),
(51168, 7161, 13, 'Склады'),
(51169, 7162, 13, 'Жар'),
(51170, 7163, 13, 'Предупреждение'),
(51171, 7164, 13, 'ПРЕДУПРЕЖДЕНИЕ'),
(51172, 7166, 13, 'Предупреждение, регистрационный номер уже имеется в базе данных'),
(51173, 7168, 13, 'Предупреждение: посещение для этого пациента уже создано!'),
(51174, 7170, 13, 'Предупреждение: ID пациента не уникален!'),
(51175, 7171, 13, 'ПРЕДУПРЕЖДЕНИЕ: конфигурационная информация будет перезаписана с даты этого загруженного файла!'),
(51176, 7173, 13, 'Предупреждения'),
(51177, 7175, 13, 'уже загружен'),
(51178, 7177, 13, 'Мы высоко ценим своевременную выплату задолженностей'),
(51179, 7178, 13, 'мы позаботились об указанном пациенте, проведя амбулаторно обследование и лечение в нашей клинике психиатрии. Благодарим за это направление.'),
(51180, 7179, 13, 'Слабость'),
(51181, 7181, 13, 'Поиск в интернете'),
(51182, 7182, 13, 'Веб-сайт'),
(51183, 7183, 13, 'Ссылка на веб-сайт для местного портала пациентов.'),
(51184, 7184, 13, 'Ср'),
(51185, 7185, 13, 'Среда'),
(51186, 7186, 13, 'Неделя'),
(51187, 7187, 13, 'неделя'),
(51188, 7188, 13, 'Обзор за неделю'),
(51189, 7189, 13, 'Неделя(и)'),
(51190, 7190, 13, 'Еженедельное представление'),
(51191, 7192, 13, 'Недели'),
(51192, 7193, 13, 'Вес'),
(51193, 7194, 13, 'Оценка веса и рекомендации для детей и подростков'),
(51194, 7195, 13, 'Оценка веса и рекомендации для детей и подростков (CQM)'),
(51195, 7196, 13, 'Изменение веса'),
(51196, 7197, 13, 'Потеря веса'),
(51197, 7198, 13, 'Клиника похудения'),
(51198, 7199, 13, 'Добро пожаловать'),
(51199, 7202, 13, 'Что должно быть подсчитано?'),
(51200, 7203, 13, 'Стридорозное дыхание:'),
(51201, 7204, 13, 'Хрипы'),
(51202, 7205, 13, 'Хрипы:'),
(51203, 7208, 13, 'Где можно найти связанные сканированные или бумажные документы?'),
(51204, 7211, 13, 'Хлыстовая травма'),
(51205, 7212, 13, 'Белый'),
(51206, 7213, 13, 'Кто'),
(51207, 7214, 13, 'Кто отвечает?'),
(51208, 7215, 13, 'Овдовевшая(й)'),
(51209, 7217, 13, 'Ширина в пикселях для навигационного меню слева.'),
(51210, 7221, 13, 'С выбранным:'),
(51211, 7222, 13, 'с помощью старого наименования'),
(51212, 7224, 13, 'С кем можно оставить сообщение?'),
(51213, 7225, 13, 'Отложить'),
(51214, 7226, 13, 'на протяжении часов'),
(51215, 7227, 13, 'на протяжении часов:'),
(51216, 7228, 13, 'на протяжении минут'),
(51217, 7229, 13, 'на протяжении минут:'),
(51218, 7232, 13, 'Без обновления'),
(51219, 7233, 13, 'Инспектор'),
(51220, 7234, 13, 'нед.'),
(51221, 7235, 13, 'В пределах нормы'),
(51222, 7237, 13, 'Женщины'),
(51223, 7238, 13, 'Только женщины'),
(51224, 7240, 13, 'Работа'),
(51225, 7241, 13, 'РАБОЧАЯ ЗАПИСЬ'),
(51226, 7242, 13, 'Рабочий телефон'),
(51227, 7243, 13, 'Номер рабочего телефона'),
(51228, 7244, 13, 'Связано с работой?'),
(51229, 7245, 13, 'Работа/образование/хобби'),
(51230, 7246, 13, 'Рабочая/школьная запись'),
(51231, 7247, 13, 'рабочий день'),
(51232, 7248, 13, 'Компенсация для работающего'),
(51233, 7249, 13, 'Программа охраны здоровья рабочих'),
(51234, 7250, 13, 'Работающий пенсионер по возрасту или супруга с планом группового оздоровления предпринимателя'),
(51235, 7252, 13, 'Наихудший'),
(51236, 7253, 13, 'Хотите использовать оставшуюся сумму в общем счете?'),
(51237, 7254, 13, 'Хотите маркировать их как очищенные?'),
(51238, 7255, 13, 'Хотите внести?'),
(51239, 7256, 13, 'Хотите отменить предоставление для этого пациента?'),
(51240, 7257, 13, 'Хотите удалить предоставление оплаты?'),
(51241, 7258, 13, 'Хотите удалить платеж?'),
(51242, 7259, 13, 'Хотите изменить или завершить платеж?'),
(51243, 7260, 13, 'Хотите изменить платеж?'),
(51244, 7261, 13, 'Хотите отправить и завершить платеж?'),
(51245, 7262, 13, 'Хотите отправить платеж?'),
(51246, 7263, 13, 'Хотите сохранить?'),
(51247, 7264, 13, 'Запястье'),
(51248, 7265, 13, 'Запястье и рука'),
(51249, 7266, 13, 'Проблемы запястья'),
(51250, 7267, 13, 'записывать'),
(51251, 7268, 13, 'без записи'),
(51252, 7270, 13, 'wsome'),
(51253, 7271, 13, 'WT'),
(51254, 7273, 13, 'x Отменено'),
(51255, 7274, 13, 'x Отменено'),
(51256, 7275, 13, 'Рентг. исследование'),
(51257, 7276, 13, 'Интерпретация ренг. исследования:'),
(51258, 7277, 13, 'Интерпретация ренг. исследования:'),
(51259, 7278, 13, 'только X12: требование замены '),
(51260, 7279, 13, 'Партнер X12'),
(51261, 7280, 13, 'Партнер X12'),
(51262, 7284, 13, 'г.'),
(51263, 7285, 13, 'Год'),
(51264, 7286, 13, 'год'),
(51265, 7287, 13, 'Обзор за год'),
(51266, 7288, 13, 'Год(ы)'),
(51267, 7289, 13, 'Годы'),
(51268, 7292, 13, 'ДА'),
(51269, 7293, 13, 'Да'),
(51270, 7294, 13, 'да'),
(51271, 7295, 13, 'ДА!'),
(51272, 7296, 13, 'Да, удалить и зарегистрировать'),
(51273, 7298, 13, 'да/нет'),
(51274, 7299, 13, 'Да:'),
(51275, 7300, 13, 'Идиш'),
(51276, 7303, 13, 'Предпринимается попытка навсегда заменить существующий шаблон. Уверены, что нужно продолжить?'),
(51277, 7304, 13, 'Действие пароля для входа в систему сохраняется. Измените пароль до'),
(51278, 7305, 13, 'У вас нет права на удаление этого события'),
(51279, 7306, 13, 'У вас нет права на изменение этого события'),
(51280, 7307, 13, 'Это вам не разрешено.'),
(51281, 7308, 13, 'Доступ к этой группе вам не разрешен.'),
(51282, 7309, 13, 'Вам не разрешено добавление/изменение проблем'),
(51283, 7310, 13, 'Вам не разрешен доступ для планирования записи на прием.'),
(51284, 7311, 13, 'Для просмотра этого обращения вы не авторизированы.'),
(51285, 7313, 13, 'У вас нет прямого доступа к этой функции.'),
(51286, 7314, 13, 'У вас нет прямого доступа к этой странице.'),
(51287, 7315, 13, 'Вы не можете добавить пустое значение для категории!'),
(51288, 7316, 13, 'Вы не можете добавить пустое значение для подкатегории!'),
(51289, 7317, 13, 'Для этого элемента добавление пустого значения невозможно!'),
(51290, 7318, 13, 'Нельзя ввести будущую дату со значением завершения Да.'),
(51291, 7319, 13, 'Вы не выбрали ни одно действие.'),
(51292, 7320, 13, 'Вы не имеете доступа для просмотра/изменения этой записи'),
(51293, 7321, 13, 'Вы пытались изменить блокированное содержание. Если это необходимо сделать, то удалите блокировку. Для разблокирования удалите строку ''/*lock::*/'''),
(51294, 7322, 13, 'Вы благополучно вышли из регистрации.'),
(51295, 7323, 13, 'Вы можете только обнолять файлы .txt'),
(51296, 7325, 13, 'Можете вставить здесь текст, как жалоба по умолчанию для формы обращения пациента.'),
(51297, 7326, 13, 'Вы должны ввести пароль для шифрования этого документа'),
(51298, 7329, 13, 'Сначала нужно выбрать или добавить пациента.'),
(51299, 7331, 13, 'Нужно выбрать категорию посещения'),
(51300, 7332, 13, 'Нужно выбрать категорию посещения.'),
(51301, 7333, 13, 'Для продолжения вы должны выбрать некоторые поля.'),
(51302, 7334, 13, 'Если появилось это требование, то для успешного создания нужно запустить этот тест, но сам требуемый файл не содержит никаких данных или только незавершенные части суммы данных, предполагаемых для включения. Очевидно, с требованиями HCFA, потому что они удобочитаемы для человека, с требованиями X12, которые являются более сложным процессом для определения, подготовлено ли требование надлежащим образом.'),
(51303, 7335, 13, 'Нужно выбрать, по крайней мере, один контекст'),
(51304, 7336, 13, 'Необходимо выбрать хотя бы одного специалиста'),
(51305, 7339, 13, 'Неправильная дата окончания'),
(51306, 7340, 13, 'Ваше событие удалено.'),
(51307, 7341, 13, 'Ваше событие изменено.'),
(51308, 7342, 13, 'Событие было подчинено.'),
(51309, 7343, 13, 'Ваш файл слишком большой'),
(51310, 7345, 13, 'Списочное наименование было изменено для удовлетворения перечисленных требований'),
(51311, 7347, 13, 'Ваше название для этой категории, методики или результата'),
(51312, 7349, 13, 'Действие пароля истекло. Измените свой пароль.'),
(51313, 7350, 13, 'Действие пароля истекло на'),
(51314, 7351, 13, 'Действие пароля истекло сегодня. Измените свой пароль.'),
(51315, 7353, 13, 'Ваши настройки PostCalendar сброшены на использование по умолчанию.'),
(51316, 7354, 13, 'Настройка PostCalendar обновлена.'),
(51317, 7355, 13, 'Частота повторения должна быть целым числом.'),
(51318, 7356, 13, 'Частота повторения должна быть, по крайней мере, 1.'),
(51319, 7357, 13, 'Ваша начальная дата позднее конечной'),
(51320, 7358, 13, 'Ваша начальная дата недопустима'),
(51321, 7359, 13, 'Ваше предоставление дало сбой.'),
(51322, 7360, 13, 'yyyy-mm-dd'),
(51323, 7361, 13, 'YYYY-MM-DD'),
(51324, 7362, 13, 'дата yyyy-mm-dd привязана к этому документу'),
(51325, 7363, 13, 'дата yyyy-mm-dd уничтожена'),
(51326, 7364, 13, 'дата рождения yyyy-mm-dd'),
(51327, 7365, 13, 'Дата рождения yyyy-mm-dd'),
(51328, 7366, 13, 'дата окончания срока действия yyyy-mm-dd'),
(51329, 7367, 13, 'Дата появления или госпитализации yyyy-mm-dd'),
(51330, 7368, 13, 'Дата появления, оперативного вмешательства или начала лечения yyyy-mm-dd'),
(51331, 7369, 13, 'Дата получения или передачи yyyy-mm-dd'),
(51332, 7370, 13, 'Дата выздоровления или окончания лечения yyyy-mm-dd'),
(51333, 7371, 13, 'Дата повторного воспроизведения yyyy-mm-dd'),
(51334, 7372, 13, 'Дата оказания помощи yyyy-mm-dd'),
(51335, 7373, 13, 'дата этого письма yyyy-mm-dd'),
(51336, 7374, 13, 'дата повторного воспроизведения yyyy-mm-dd'),
(51337, 7375, 13, 'дата регистрации yyyy-mm-dd'),
(51338, 7376, 13, 'дата события или включения yyyy-mm-dd'),
(51339, 7381, 13, 'yyyy-mm-dd hh:mm:ss'),
(51340, 7383, 13, 'последняя дата этого события yyyy-mm-dd'),
(51341, 7387, 13, 'Нулевой'),
(51342, 7389, 13, 'Почтовый индекс'),
(51343, 7390, 13, 'Почтовый индекс'),
(51344, 7391, 13, 'Почтовый индекс/страна'),
(51345, 7392, 13, 'Зулусский'),
(51346, 7393, 13, ' но было '),
(51347, 7394, 13, ' получить доступ не удалось.'),
(51348, 7395, 13, 'Действительно нужно удалить'),
(51349, 7396, 13, 'Препарат'),
(51350, 7397, 13, 'электронная почта не отправлена'),
(51351, 7398, 13, 'от'),
(51352, 7399, 13, 'должна быть создана. '),
(51353, 7400, 13, 'должна быть повторно открыта.'),
(51354, 7401, 13, 'Анамнез'),
(51355, 7402, 13, 'это не число'),
(51356, 7403, 13, 'готово для повторного счета.'),
(51357, 7404, 13, 'Левая нижняя конечность:'),
(51358, 7405, 13, 'Партия'),
(51359, 7406, 13, 'Номер официальной медицинской ссылки. '),
(51360, 7407, 13, 'минимум'),
(51361, 7408, 13, 'не найдено!'),
(51362, 7409, 13, 'Особенности многих обозревателей могут предполагать вывод ниже экрана с внезапными рывками и длинные паузы по несколько секунд, когда кажется, что работа завершилась сбоем. Это не так, через некоторое время вы увидите вывод результата строка за строкой. Он может быть последовательностью номеров, появляющихся ниже, это указывает, что даже если ничего отображается, деятельность продолжается. Эти числа будут перемежаться с содержанием биллинга и это нормально.'),
(51363, 7410, 13, 'срок действия назначения истек'),
(51364, 7411, 13, 'до'),
(51365, 7412, 13, 'обновление дало сбой, вне базы данных?'),
(51366, 7413, 13, 'маркирован только как счет.'),
(51367, 7414, 13, 'было включено в очередь.'),
(51368, 7415, 13, '! Ушел без посещения'),
(51369, 7416, 13, '" для кода'),
(51370, 7417, 13, 'В параметрах настройки PostCalendar " означает ОТМЕЧЕНО!'),
(51371, 7418, 13, '# Проблемы с оплатой/страховкой'),
(51372, 7419, 13, '# из таблеток:'),
(51373, 7420, 13, '$'),
(51374, 7421, 13, '$ Индексированное'),
(51375, 7422, 13, '$метка (yyyy-mm-dd) '),
(51376, 7423, 13, '%'),
(51377, 7424, 13, '% Отменено < 24 часа'),
(51378, 7425, 13, '% Отменено < 24 часа '),
(51379, 7426, 13, 'нет '', а должно присутствовать.'),
(51380, 7427, 13, '(% соответствует любой строке, _ соответствует любому символу)'),
(51381, 7428, 13, '([ctrl] + клик для выбора нескольких получателей)'),
(51382, 7429, 13, '(Назад)'),
(51383, 7430, 13, '(Кликните для изменения)'),
(51384, 7431, 13, '(Доставка электронной почты выполняется немедленно, в то время как автоматизированный VOIP отправляется поставщику услуг для дальнейшей обработки.)'),
(51385, 7432, 13, '(подробнее)'),
(51386, 7433, 13, '(Новый пациент)'),
(51387, 7434, 13, '(записи и полномочия)'),
(51388, 7435, 13, '(Записи о пациенте)'),
(51389, 7436, 13, '(Выберите или введите свой)'),
(51390, 7437, 13, 'Для изменения значения кликните с нажатым Shift или выделите мышкой'),
(51391, 7438, 13, '* С напоминанием'),
(51392, 7439, 13, '** Переместите хирургию в проблемы!'),
(51393, 7440, 13, '*Обязательное'),
(51394, 7441, 13, '#ERROR!:parse'),
(51395, 7442, 13, '- Нет'),
(51396, 7445, 13, '.'),
(51397, 7446, 13, '0'),
(51398, 7447, 13, '0-10'),
(51399, 7448, 13, '0-24'),
(51400, 7451, 13, '1'),
(51401, 7452, 13, '1 = Северная Америка. Перечисление кодов других стран см. на http://www.wtng.info/'),
(51402, 7453, 13, '1 день от сегодня'),
(51403, 7454, 13, '1 месяц от сегодня'),
(51404, 7455, 13, '1 неделя от сегодня'),
(51405, 7456, 13, '1 год от сегодня'),
(51406, 7457, 13, '1. Покой 2. Холод в течение двух дней 3. Компрессия, сохраняйте повязку на месте, если не развивается онемение или бледность ноги 4. Поднятое положение ноги и фиксация'),
(51407, 7458, 13, '11-14'),
(51408, 7459, 13, '12 ч'),
(51409, 7460, 13, '15-19'),
(51410, 7462, 13, '2'),
(51411, 7463, 13, '2 дня от сегодня'),
(51412, 7464, 13, '2 месяца от сегодня'),
(51413, 7465, 13, '2 недели от сегодня'),
(51414, 7466, 13, '2 года от сегодня'),
(51415, 7468, 13, '20-24'),
(51416, 7477, 13, '2111-13'),
(51417, 7478, 13, '24 ч'),
(51418, 7479, 13, '25+'),
(51419, 7480, 13, '25-29'),
(51420, 7481, 13, '2-й'),
(51421, 7482, 13, '3 дня от сегодня'),
(51422, 7483, 13, '3 месяца'),
(51423, 7484, 13, '3 месяца от сегодня'),
(51424, 7485, 13, '3 раза ежедневно'),
(51425, 7486, 13, '3 недели от сегодня'),
(51426, 7487, 13, '30-34'),
(51427, 7488, 13, '35-39'),
(51428, 7489, 13, '3-й'),
(51429, 7490, 13, '4 дня от сегодня'),
(51430, 7491, 13, '4 месяца'),
(51431, 7492, 13, '4 месяца от сегодня'),
(51432, 7493, 13, '4 раза в день'),
(51433, 7494, 13, '4 недели от сегодня'),
(51434, 7495, 13, '40-44'),
(51435, 7496, 13, '40-44'),
(51436, 7497, 13, '465.9, URI'),
(51437, 7498, 13, '466.0, бронхит, органонеспецифичный, острый'),
(51438, 7499, 13, '486.0, пневмония, острая'),
(51439, 7500, 13, '491.21, ХОБЛ, обострение'),
(51440, 7501, 13, '491.8, бронхит, хронический'),
(51441, 7502, 13, '493.92, астма, острый Exac.'),
(51442, 7503, 13, '496.0, ХОБЛ'),
(51443, 7504, 13, '4-й'),
(51444, 7505, 13, '5 дней от сегодня'),
(51445, 7506, 13, '5 месяцев от сегодня'),
(51446, 7507, 13, '5 недель от сегодня'),
(51447, 7508, 13, '519.7, бронхоспазм'),
(51448, 7509, 13, '5-й'),
(51449, 7510, 13, '6 дней от сегодня'),
(51450, 7511, 13, '6 месяцев'),
(51451, 7512, 13, '6 месяцев от сегодня'),
(51452, 7513, 13, '6 недель от сегодня'),
(51453, 7514, 13, '6-й'),
(51454, 7515, 13, '7 месяцев от сегодня'),
(51455, 7516, 13, '8 месяцев от сегодня'),
(51456, 7517, 13, '824.0 Перелом медиальной лодыжки, закрытый'),
(51457, 7518, 13, '824.2 Перелом латеральной лодыжки, закрытый'),
(51458, 7519, 13, '824.6 Трёхлодыжечный перелом, закрытый'),
(51459, 7520, 13, '825.32 Перелом ладьевидной кости (лодыжка)'),
(51460, 7521, 13, '825.35 Перелом основания пятой (5-й) метатарзальной кости'),
(51461, 7522, 13, '845.00 Растяжение лодыжки NOS'),
(51462, 7523, 13, '845.01 Растяжение средней (дельтовидной) связки'),
(51463, 7524, 13, '845.02 Растяжение малоберцовой пяточной'),
(51464, 7525, 13, '9 месяцев от сегодня'),
(51465, 7526, 13, '99212 установленный - несложный'),
(51466, 7527, 13, '99213 установленный - низкой сложности'),
(51467, 7528, 13, '< На осмотре'),
(51468, 7529, 13, '> Приём завершён'),
(51469, 7531, 13, '? Неявка'),
(51470, 7532, 13, '@ Прибыл'),
(51471, 7533, 13, '[Изменить вид]'),
(51472, 7534, 13, '[Дата последнего обращения]'),
(51473, 7535, 13, '[Дни от последнего обращения]'),
(51474, 7536, 13, '[EOBs]'),
(51475, 7537, 13, '[Экспорт OFX]'),
(51476, 7538, 13, '[не рекомендовано]'),
(51477, 7539, 13, '[Количество обращений]'),
(51478, 7540, 13, '[Отчеты]'),
(51479, 7541, 13, '[Выбрать все]'),
(51480, 7542, 13, '[Регистр-SQL]'),
(51481, 7543, 13, '[Запуск пакетной обработки]'),
(51482, 7544, 13, '[Просмотреть журнал]'),
(51483, 7545, 13, '[Вид печати для отчета]'),
(51484, 7546, 13, '_PC_DUR_HOURS'),
(51485, 7547, 13, '_PC_DUR_MINUTES'),
(51486, 7548, 13, '_PC_LOCALE'),
(51487, 7549, 13, '~ Опоздал'),
(51488, 2, 14, 'Գրանցման  կամ պահանջագրի համարը՝ վճարումը նույնականացնելու համար'),
(51489, 3, 14, 'Հաճախորդի հավաստագիր՝ որպես ԱԴՄԻՆ օգտվողի համար'),
(51490, 4, 14, 'Կցված է բժշկական/կլինիկական փաստաթուղթ'),
(51491, 5, 14, 'Բժշկական/կլինիկական փաստաթուղթ է կցված'),
(51492, 7, 14, 'Պահանջվում է / անհրաժեշտ է ներկայացուցիչ'),
(51493, 8, 14, 'Այս այցի շրջանակներում պետք է ավելացնել GCAC մուտքի ձև'),
(51494, 9, 14, 'Խմբաքանակի թիվը պարտադիր է'),
(51495, 10, 14, 'Խմբաքանակի թիվը պարտադիր է'),
(51496, 11, 14, 'փոքրատառ'),
(51497, 12, 14, 'համար'),
(51498, 14, 14, 'Սույն ինքնությամբ հիվանդ արդեն գոյություն ունի'),
(51499, 15, 14, 'Սույն  անունով հիվանդ արդեն գոյություն ունի'),
(51500, 16, 14, 'Սույն սոցծառայության համարով հիվանդ արդեն գոյություն ունի'),
(51501, 17, 14, 'Վիդջեթի/սարքի  վրա՝ Հիվանդի Ամփոփ տեղեկագրի էկրանին,  դրական թվով ցույց կտա նախկին նշանակումները  (բացասական թվով ցույց կտա նախկին նշանակումները՝ նվազման կարգով)'),
(51502, 18, 14, 'Վիդջեթի վրա՝ Հիվանդի Ամփոփ տեղեկագրի էկրանին,  դրական թվով ցույց կտա նախկին նշանակումները'),
(51503, 19, 14, 'Յուրաքանչյուր այցի համար տեղեկատվության աղբյուրը կարող է մատնանշվել'),
(51504, 20, 14, 'Պահանջվում է առնչվող/կից IPPF կոդ'),
(51505, 21, 14, 'Հատուկ նշան'),
(51506, 22, 14, 'Այս դաշտի նույնականացման՝ օգտվողի համար  անտեսանելի եզակի նշանակություն/արժեք'),
(51507, 23, 14, 'Այս հիվանդի անվամբ այսօրվա համար արդեն գոյություն  ունի նշանակված այց։ Սեղմեք "Չեղարկել"/Cancel՝ բացելու  համար, կամ "Լավ"/OK շարունակելու և նորն ստեղծելու համար'),
(51508, 25, 14, 'մինչև կեսօր'),
(51509, 27, 14, 'abdominal bloating - որովայնային  ձգում aspiration biopsy  ֊'),
(51510, 28, 14, 'կրճատում'),
(51511, 29, 14, 'թարախակույտ'),
(51512, 30, 14, 'որովայնային'),
(51513, 31, 14, 'կարողանում է կրել ծանրություն 4 /չորս/ քայլ'),
(51514, 34, 14, 'Նորմայից շեղված'),
(51515, 35, 14, 'Ոչ նորմալ արյան հետազոտություն'),
(51516, 36, 14, 'Ոչ նորմալ մազերի աճ'),
(51517, 37, 14, 'Ոչ նորմալ մամոգրաֆիա'),
(51518, 39, 14, 'Աբորտ /հղիության վաղաժամ ընդհատում/'),
(51519, 40, 14, 'Աբորտի հետ կապված խնդիրներ'),
(51520, 41, 14, 'Հղիության ընդհատման մեթոդներ'),
(51521, 42, 14, 'Աբորտին/Հղիության ընդհատմանն առնչվող բաժիններ'),
(51522, 43, 14, 'Աբորտներ /Հղիության ընդհատումներ'),
(51523, 44, 14, 'Օգտվողի օրացույցը'),
(51524, 46, 14, 'Ախտորոշման բացակայություն'),
(51525, 47, 14, '1. Ընդունել նշանակումը/հանձնարարությունը   2. /հանձնարարության ընդունում'),
(51526, 48, 14, 'Ընդունել ․․․֊ն վճարումը'),
(51527, 49, 14, 'Ընդունել ․․․֊ն վճարումը '),
(51528, 50, 14, 'Հանձնարարությունն/ նշանակումն ընդունում է'),
(51529, 51, 14, 'Մուտքի/Հասանելիության վերահսկում'),
(51530, 52, 14, 'Մուտքի վերահսկողության ցանկի ադմինիստրացիա'),
(51531, 53, 14, 'Մուտքի ամսաթիվ'),
(51532, 54, 14, 'Մուտքն արգելված է'),
(51533, 55, 14, 'Մուտքը լիազորված չէ'),
(51534, 56, 14, 'Մուտք գործեք Ձեր հիվանդի պորտալ'),
(51535, 57, 14, 'Պատահար'),
(51536, 59, 14, 'Հաշվի անունը'),
(51537, 62, 14, 'Հաշվառում /Հաշվապահություն'),
(51538, 64, 14, 'Ցավեր'),
(51539, 65, 14, 'Անհրաժեշտ է հաստատում/ճանաչում (ISA14)'),
(51540, 66, 14, 'Հաստատում, Լիցենզավորում և Սերտիֆիկացում'),
(51541, 68, 14, 'ACL կառավարում'),
(51542, 69, 14, 'ACL կառավարումը թույլատրված չէ'),
(51543, 70, 14, 'ACL֊ն հաջողությամբ թարմացվել է'),
(51544, 71, 14, 'Բշտիկ /ակնե'),
(51545, 72, 14, 'Ակտ/գործ'),
(51546, 73, 14, 'Ակտի/գործողության  ամսաթիվ'),
(51547, 74, 14, 'Ակտ/գործողություն'),
(51548, 75, 14, 'Գործողություններ'),
(51549, 77, 14, 'Ակտիվացնել  CCR/CCD հաշվետվությունը'),
(51550, 78, 14, 'Ակտիվ'),
(51551, 79, 14, 'Ակտիվ ծանուցում'),
(51552, 80, 14, 'Ակտիվ ծանուցման կանոններ'),
(51553, 81, 14, 'Ակտիվ ծանուցումներ/հիշեցումներ'),
(51554, 82, 14, 'Ակտիվ բախում'),
(51555, 84, 14, 'Ակտիվ ցանկեր'),
(51556, 85, 14, 'Ակտիվ հիվանդ'),
(51557, 86, 14, 'Ակտիվ պլաններ'),
(51558, 87, 14, 'Ակտիվություն'),
(51559, 88, 14, 'Ակտիվության տեսակը'),
(51560, 90, 14, 'Սուր թունավորում / դուրսբերում'),
(51561, 91, 14, 'Խրոնիկ հիվանդության սուր դրսևորումներ'),
(51562, 92, 14, 'սուր կամ խրոնիկ'),
(51563, 93, 14, 'ավելացնել'),
(51564, 94, 14, 'ավելացնել'),
(51565, 95, 14, 'attention deficit disorder - ուշադրության դեֆիցիտի սինդրոմ/ուշադրության խանգարում'),
(51566, 96, 14, 'Ավելացնել Ընկերություն/Կազմակերպություն'),
(51567, 98, 14, 'Ավելացնել Դեղատուն'),
(51568, 100, 14, 'Ավելացնել իրադարձություն '),
(51569, 101, 14, 'Ավելացնել որպես նոր նշում/գրառում'),
(51570, 102, 14, 'Ավելացնել որպես ՆՈՐ'),
(51571, 104, 14, 'Ավելացնել կոճակ'),
(51572, 105, 14, 'ավելացնել կոճակներ խմբագրման պատուհանի վերին  մասում  տեքստի վրա Click֊ով հատոկ սիմվոլներ, տեքստեր  տեղադրելու համար'),
(51573, 106, 14, 'Ավելացնել կատեգորիա'),
(51574, 107, 14, 'Ավելացնել մշտական'),
(51575, 108, 14, 'Ավելացնել համատեքստ'),
(51576, 109, 14, 'Ավելացնել հավելավճար'),
(51577, 110, 14, 'Ավելացնել չափորոշիչ'),
(51578, 111, 14, 'Ավելացնել գործարկողի կոճակ'),
(51579, 112, 14, 'Ավելացնել ախտորոշում'),
(51580, 113, 14, 'Ավելացնել դեղորայք'),
(51581, 114, 14, 'Ավելացնել /անհետաձգելի, անհապաղ/  հանդիպում'),
(51582, 115, 14, 'Ավելացնել   հանդիպման հետ կապված նշումներ'),
(51583, 116, 14, 'Ավելացնել հնարավաորություն / սարք'),
(51584, 117, 14, 'Ավելացնել  դաշտ'),
(51585, 118, 14, 'Ավելացնել հետևյալ տողերը Apache  կազմաձևով/կազմությամբ  ֆայլին'),
(51586, 119, 14, 'Ավելացնել խումբ'),
(51587, 120, 14, 'Ավելացնել ՀՄԴ /Հիվանդությունների Միջազգային  Դասակարգում/ Կոդ'),
(51588, 121, 14, 'Ավելացնել պատվաստում'),
(51589, 122, 14, 'Հավելում /Ավելացում/  չի թույլատրվում'),
(51590, 123, 14, 'Ավելացնել հարց/խնդիր'),
(51591, 124, 14, 'Շարքին կետ/պարագրաֆ/ ավելացնել'),
(51592, 125, 14, 'Ավելացնել լեզու'),
(51593, 126, 14, 'Ավելացնել Նոր'),
(51594, 127, 14, 'Ավելացնել նորը'),
(51595, 128, 14, 'Ավելացնել նոր կատեգորիա '),
(51596, 129, 14, 'Ավելացնել նոր հավաստագրեր Apache կարգավորման/ ձևաչափի ֆայլին'),
(51597, 130, 14, 'Ավելացնել  նոր բաղադրիչ'),
(51598, 131, 14, 'Ավելացնել  նոր բաղադրիչներ'),
(51599, 132, 14, 'Ավելացնել նոր խումբ'),
(51600, 133, 14, 'Ավելացնել նոր հարց/խնդիր'),
(51601, 134, 14, 'Ավելացներ գերծարքի նոր շարք'),
(51602, 135, 14, 'Ավելացնել Նոր Գրառում'),
(51603, 136, 14, 'Ավելացնել նոր գրառում'),
(51604, 137, 14, 'Ավելացնել նոր գործընկեր'),
(51605, 138, 14, 'Ավելացնել նոր Հիվանդի'),
(51606, 140, 14, 'Ավելացնել գրառում'),
(51607, 141, 14, 'Ավելացնել Հիվանդի Գրանցում'),
(51608, 142, 14, 'Ավելացնել դեղատոմս'),
(51609, 143, 14, 'Ավելացնել ընթացակարգ'),
(51610, 144, 14, 'Ավելացնել Մատակարարի համարը'),
(51611, 145, 14, 'Ավելացնել Վերականգնում /կոճակ/'),
(51612, 146, 14, 'Ավելացնել Կանոն'),
(51613, 147, 14, 'Ավելացնել ․․․֊ին /Ավելացնել հետևյալին'),
(51614, 148, 14, 'Ավելացնել Դեղորայքի Ցանկին'),
(51615, 149, 14, 'Ավելացնել Վերին Մակարդակ'),
(51616, 150, 14, 'ԱՎելացնել Գործարք'),
(51617, 151, 14, 'Ավելացնել Օգտվող'),
(51618, 152, 14, 'Ավելացնել Օգտվողին հետևյալ Խմբում'),
(51619, 153, 14, 'Ավելացնել/Խմբագրել eRx/ ԷԴԽԾ /Էլեկտրոնային  Դեղատոմսի Խթանիչ/Խրախուսման Ծրագիր/'),
(51620, 154, 14, 'Ավելացնել/Խմբագրել  Հիվանդի Գործարք'),
(51621, 155, 14, 'Ավելացված է'),
(51622, 156, 14, 'Անձնական տվյալների ավելացումն արգելվում է'),
(51623, 157, 14, 'Կետի/պարագրաֆի ավելացումը ձախողվեց'),
(51624, 158, 14, 'Էդիսոնի Համախտանիշ'),
(51625, 159, 14, 'Էդիսոնի Համախտանիշ'),
(51626, 160, 14, 'Լրացուցիչ հատկանիշներ / ատրիբուտներ'),
(51627, 161, 14, 'Լրացուցիչ / հավելյալ  ախտորոշում'),
(51628, 162, 14, 'Լրացուցիչ / հավելյալ  Պատմություն'),
(51629, 163, 14, 'Լրացուցիչ / հավելյալ  Պատմության գրառումներ'),
(51630, 164, 14, 'Լրացուցիչ / հավելյալ  Ինֆորմացիա'),
(51631, 165, 14, 'Լրացուցիչ / հավելյալ  Լաբորատոր հետազոտություններ'),
(51632, 166, 14, 'Լրացուցիչ / հավելյալ  նշումներ / գրառումներ'),
(51633, 167, 14, 'Այս արդյունքին ուղղված/արնչվող լրացուցիչ գրառումներ  կամ հանձնարարական'),
(51634, 168, 14, 'Լրացուցիչ / հավելյալ  նշումներ / գրառումներ'),
(51635, 169, 14, 'Լրացուցիչ / հավելյալ  նշումներ / գրառումներ '),
(51636, 170, 14, 'Ռենտգեն հետազոտության լրացուցիչ գրառումներ'),
(51637, 171, 14, 'Բացի այդ,  Միջազգային Snomed Release֊ի /Անգլերեն  տարբերակը/  տեղդրելուց հետո  ԱՄՆ֊ի համապատասխան  Snomed Extension Package կարող է առանձին  ներառվել/տեղադրվել'),
(51638, 172, 14, 'Միայն ավելացնել'),
(51639, 173, 14, 'Հասցեագիրք'),
(51640, 174, 14, 'Հասցեագիրք'),
(51641, 175, 14, 'Հասցե'),
(51642, 178, 14, 'Հասցեագիրք'),
(51643, 179, 14, 'Սույն miջամտությունը կատարող Ընկերության   հասցեագիրք / հասցեների գրանցամատյան'),
(51644, 180, 14, 'Մատակարարների /Դիստրիբյուտորների  հասցեագիրք/ գրանցամատյան'),
(51645, 181, 14, 'Վաճառողի հասցեագիրք / գրանցամատյան'),
(51646, 182, 14, 'Գրանցամատյանների տեսակներ'),
(51647, 183, 14, 'Հասցեապիտակ'),
(51648, 187, 14, 'Հասցե 1'),
(51649, 188, 14, 'Հասցե 2'),
(51650, 189, 14, 'ՀԱՍՑԵ'),
(51651, 190, 14, 'Ճշգրտ․'),
(51652, 191, 14, 'Ճշգրտ․  Քանակ'),
(51653, 192, 14, 'Ճշգրտել'),
(51654, 193, 14, 'Ճշգրտում'),
(51655, 194, 14, 'Ճշգրտումների քնկ․'),
(51656, 195, 14, 'Ճշգրտումների պատճառը'),
(51657, 196, 14, 'Ճշգրտման կոդի արժեքը '),
(51658, 197, 14, 'Ճշգրտումներ'),
(51659, 198, 14, 'Ադմինի ճշգրտումները'),
(51660, 199, 14, 'Ադմին'),
(51661, 200, 14, 'Ադմինի էլ․փոստ'),
(51662, 201, 14, 'Ղեկավարել ․․֊ի միջոցով / որպես'),
(51663, 202, 14, 'Սպասարկվում է / ղեկավարվում է'),
(51664, 203, 14, 'Սպասարկվում է / ղեկավարվում է ․․֊ի կողմից/միջոցով'),
(51665, 204, 14, 'Սպասարկման ամսաթիվ'),
(51666, 205, 14, 'Սպասարկվող կայք'),
(51667, 206, 14, 'Սպասարկում'),
(51668, 207, 14, 'Սպասարկող կայք'),
(51669, 208, 14, 'Ադմինիստրատորներ'),
(51670, 209, 14, 'Ադմինիստրատորներին թույլատրվում է ամեն ինչ'),
(51671, 210, 14, 'Ընդունման Ամսաթիվ'),
(51672, 212, 14, 'Չափահասի քաշի զննում֊հսկողություն'),
(51673, 213, 14, 'Չափահասի քաշի զննում֊հսկողություն  (CQM)'),
(51674, 214, 14, 'Նախնական հրահանգ');
INSERT INTO `lang_definitions` VALUES
(51675, 215, 14, 'Նախնական հրահանգներ'),
(51676, 216, 14, 'Նախնական հրահանգների զգուշացում'),
(51677, 218, 14, 'Ընդլայնված'),
(51678, 219, 14, 'Խորհուրդ'),
(51679, 220, 14, 'Աֆար /ցեղ/  Հեռու/հեռվից'),
(51680, 221, 14, 'Նորմալ ազդեցություն ունենալ'),
(51681, 222, 14, 'Հրվ․ Աֆրիկայի լեզու'),
(51682, 226, 14, 'PDF ֆորմատով պահպանելուց հետո սխալներն ստուգելու  համար սեղմել  [Դիտել Մուտքը]'),
(51683, 227, 14, 'TEXT ֆայլ(եր)ը պահպանելուց հետո սխալներն ստուգելու  համար սեղմել  [Դիտել Մուտքը]'),
(51684, 228, 14, 'Փաթեթը պահպանելուց հետո սեղմել  [Դիտել Մուտքը]'),
(51685, 229, 14, 'Դրանից հետո Համապատասխանության սյունը կցուցադրի  ընտրված Հիվանդի նույնականացման տվյալները կամ  "0" նորն ստեղծելու համար'),
(51686, 230, 14, 'Ինֆորմացիան ճիշտ մուտք անելուց հետո սեղմել  "Պահպանել" կոճակը'),
(51687, 231, 14, 'Վերբերնումից հետո սեղմել "Ներկրել" կոճակը'),
(51688, 232, 14, 'Վերականգնողական աշխատանքների պլանավորում'),
(51689, 233, 14, 'Կրկին'),
(51690, 234, 14, 'Տարիք'),
(51691, 235, 14, 'Տարիքը ըստ'),
(51692, 236, 14, 'Տարիքային կատեգորիա'),
(51693, 237, 14, 'Տարիքային տվյալները միջակայքից դուրս են'),
(51694, 238, 14, 'Տարիքի ցուցադրման ֆորմատ / ձև'),
(51695, 239, 14, 'Ձևաչափը՝ "Տարիքը սկսած․․․"  վավեր չէ'),
(51696, 240, 14, 'Ձևաչափը՝ "Տարիքը մինչև․․․"  վավեր չէ'),
(51697, 241, 14, 'Տարիքը սկսած'),
(51698, 243, 14, 'Մաքսիմալ տարիք'),
(51699, 244, 14, 'Մինիմալ տարիք'),
(51700, 245, 14, 'Տարիքային միջակայք/սանդղակ'),
(51701, 247, 14, 'Տարիքային սյուներ'),
(51702, 248, 14, 'Ական /Հրվ․ Գանայի բնակիչ/'),
(51703, 249, 14, 'Ալբանացի /Ալբաներեն'),
(51704, 250, 14, 'Ալկոհոլ'),
(51705, 252, 14, 'Ալկոհոլի ընդունում'),
(51706, 253, 14, 'Տագնապի հաշիվ'),
(51707, 255, 14, 'Տագնապներ/Ծանուցումներ'),
(51708, 258, 14, 'Ալեուտ /Ալեուտյան Կղզի/'),
(51709, 259, 14, 'Բոլորը'),
(51710, 260, 14, 'ԲՈԼՈՐԸ'),
(51711, 261, 14, 'Բոլորը (Ա Ֆորմատով ընտրված)'),
(51712, 262, 14, 'Բոլորը (Բ Ֆորմատով ընտրված)'),
(51713, 263, 14, 'Բոլորը (Աժողական/ Ընդհանուր)'),
(51714, 265, 14, 'Բոլոր Ավտոմատացված Չափման Հաշվարկները /ԱՉՀ/'),
(51715, 266, 14, 'Բոլոր Կատեգորիաները'),
(51716, 267, 14, 'Կլինիկական Որակի Ցուցանիշներ /ԿՈՑ/'),
(51717, 268, 14, 'Բոլոր Կոդերը'),
(51718, 269, 14, 'Ամբողջ օրը'),
(51719, 270, 14, 'Շուրջօրյա իրադարձություն'),
(51720, 271, 14, 'Անձնական տվյալներով բոլոր դաշտերը՝ որոնման և  կրկնօրինակման ստուգումով'),
(51721, 272, 14, 'Բոլոր ծառայությունները'),
(51722, 273, 14, 'Բոլոր վնասվածքները/խնդիրնեը/ հարցերը'),
(51723, 274, 14, 'Բոլոր լեզուները թույլատրված են'),
(51724, 275, 14, 'Բոլոր Կլինիկական Որակի Ցուցանիշներ /ԿՈՑ/ Ցուցանիշների Խմբեր'),
(51725, 276, 14, 'Անունը կամ մի մասը'),
(51726, 277, 14, 'Ազգանունը կամ մի մասը'),
(51727, 278, 14, 'Ընկերության անունը կամ մի մասը'),
(51728, 279, 14, 'Բոլոր հիվանդները'),
(51729, 280, 14, 'Բոլոր ապրանքները'),
(51730, 281, 14, 'Բոլոր մատակարարները'),
(51731, 282, 14, 'Բոլոր վերանայվածներն ու բացասականները'),
(51732, 283, 14, 'Բոլոր թեմաները'),
(51733, 284, 14, 'Բոլոր օգտվողները'),
(51734, 285, 14, 'Ալերգիկ'),
(51735, 286, 14, 'Ալերգիա'),
(51736, 287, 14, 'Ալերգիա'),
(51737, 288, 14, 'Ալերգիա'),
(51738, 289, 14, 'Ալերգիայի ներկրումն հաջողությամբ կատարված է'),
(51739, 290, 14, 'Ալերգիկ խնդիրների ցանկ /'),
(51740, 291, 14, 'Ալերգիկ ռեակցիա'),
(51741, 294, 14, 'Հատկացնել'),
(51742, 295, 14, 'Թույլատրել'),
(51743, 296, 14, 'Մուտքի մենյուում թույլատրել բոլոր հասանելի լեզուների  ընտրությունը'),
(51744, 297, 14, 'Թույլատրել ախտորոշում, բայց ոչ միջամտություն կամ  վճարում պարունակող պահանջի/բողոքի ստեղծում։  Կլինիկաների մեծ մասը չի ցանկանում դա։'),
(51745, 298, 14, 'Թույլատրել լեզվի կարգաբերումը'),
(51746, 299, 14, 'Թույլատրել էլ․փոստ'),
(51747, 300, 14, 'Թույլատրե՞լ էլ․ նամակներ'),
(51748, 301, 14, 'Թույլատրե՞լ էլ․փոստ'),
(51749, 302, 14, 'Թույլատրել անհապաղ հանդիպման պահանջ'),
(51750, 303, 14, 'Թույլատրել առողջական ինֆորմացիայի փոխանակում'),
(51751, 304, 14, 'Թույլատրել պատվաստման մասին ինֆորմացիայի  տարածում'),
(51752, 305, 14, 'Թույլատրել պատվաստման ռեեստրի օգտագործում'),
(51753, 306, 14, 'Թույլատրել Էլ․փոստով նամակների ուղարկումը'),
(51754, 308, 14, 'Թույլատրել /Հասանելի դարձնել Հիվանդի պորտալը'),
(51755, 309, 14, 'Թույլատրել SMS հաղորդագրություն'),
(51756, 310, 14, 'Թույլատրել SMS /տեքստային/ հաղորդագրություն'),
(51757, 311, 14, 'Թույլատրե՞լ նշանակված միջոցարումների անհապաղ  ակտիվացում'),
(51758, 312, 14, 'Թույլատրե՞լ հեռախոսային հաղորդագրություն'),
(51759, 313, 14, 'Թույլատրել օգտվողներին հրապարակել Ընդհանուր/գլոբալ  իրադարձություններ'),
(51760, 314, 14, 'Թույլատրել օգտվողներին հրապարակել իրենց անձնական  օրացույցները'),
(51761, 315, 14, 'Թույլատրել ձայնային հաղորդակցություններ'),
(51762, 316, 14, 'Թույլատրված է'),
(51763, 317, 14, 'Թույլատրված լեզուներ'),
(51764, 318, 14, 'Թույլատրված է'),
(51765, 319, 14, 'Թույլատրվում է  էլ․ ստորագրություն ողջ հանդիպման վրա'),
(51766, 320, 14, 'Թույլատրվում է  էլ․ ստորագրություն անձնական բլանկների վրա'),
(51767, 321, 14, 'Թույլատրվում է էլ․փոստ'),
(51768, 322, 14, 'Թույլատրվում է ձայնային հաղորդագրություն'),
(51769, 323, 14, 'արդեն գոյություն ունի'),
(51770, 324, 14, 'արդեն գոյություն ունի․'),
(51771, 325, 14, 'Արդեն օգտագործվում է․ ընտրեք այլ նույնացուցիչ'),
(51772, 326, 14, 'Արդեն օգտագործվում է․ ընտրեք այլ վերնագիր'),
(51773, 327, 14, 'Այլընտրանքային հասցե'),
(51774, 328, 14, 'փոխել/այլ'),
(51775, 329, 14, 'Ինչպես նաև կարող եք օգտագործել որոնման էջը՝  վերբեռնելու համար վճարողից կամ հաշվարկային կենտրոնից  ստացված էլեկտրոնային վճարման ֆայլը (X12 835)։  Դա կարող եք անել՝ սեղմելով "Browse" կոճակը և ընտրելով  վերբեռնվող ֆայլը։ Այնուհետև վերբեռնումն իրականացնելու համապատասխան հաշիվ֊ապրանքագիրը ցուցադրելու  համար սեղմել Search․ Այս պարագայում վերը նշված այլ  պարամետրեր չեն ընդունվի և կոչնչացվեն։  Վերբեռնումը պահպանում է ֆայլը'),
(51776, 330, 14, 'մինչև կեսօր'),
(51777, 331, 14, 'առավոտյան ծրագիր'),
(51778, 338, 14, 'Ուղղել/փոփոխել առկա նշումները'),
(51779, 339, 14, 'Փոփոխություն՝ սկսած'),
(51780, 340, 14, 'Փոփոխության կարգավիճակ'),
(51781, 341, 14, 'Փոփոխություններ'),
(51782, 342, 14, 'Փոփոխություններ ֊ի համար'),
(51783, 343, 14, 'Ամերիկյան հնդիկ'),
(51784, 344, 14, 'Ամերիկյան հնդիկ կամ Ալյասկայի բնիկ'),
(51785, 345, 14, 'Ամերիկյան Էքսպրես քարտ'),
(51786, 346, 14, 'Ամհարերեն'),
(51787, 347, 14, 'Գումար'),
(51788, 349, 14, 'Վերջնական գանձումներ'),
(51789, 350, 14, 'Անցած հաշվետվության գումարը'),
(51790, 351, 14, 'Սույն այցի գումարը'),
(51791, 352, 14, 'Վճարված գումար'),
(51792, 353, 14, 'Ընդհանուր գումար։'),
(51793, 354, 14, 'Ընդհանուր վճար։'),
(51794, 355, 14, 'Կրկնակի իրադարձության համար անհրաժեշտ է, որ ավարտման օրը մեկնարկի օրից ավելի ուշ լինի։'),
(51795, 356, 14, 'Ձևաթուղթն ստորագրելու պահին սխալ է տեղի ունեցել'),
(51796, 357, 14, 'LibreEHR֊ի վեբ֊կատալոգը բեռնաթափելիս սխալ է տեղի ունեցել'),
(51797, 358, 14, 'phpGACL֊ի վեբ֊կատալոգը բեռնաթափելիս սխալ է տեղի ունեցել'),
(51798, 359, 14, 'SQL-Ledger֊ի վեբ֊կատալոգը բեռնաթափելիս սխալ է տեղի  ունեցել'),
(51799, 360, 14, 'ստեղծվել ու  հղում է տրվել  անլիարժեք GCAC խնդիր'),
(51800, 362, 14, 'Անսպասելի  սխալ'),
(51801, 363, 14, 'Մեծատառ'),
(51802, 365, 14, 'և'),
(51803, 366, 14, 'ԵՎ'),
(51804, 367, 14, 'և'),
(51805, 368, 14, 'և '),
(51806, 369, 14, 'և բոլո՞ր ստորադաս տվյալները։ Այս գործողությունը  կմուտքագրվի/մուտք կգործի'),
(51807, 370, 14, 'եվ մոդիֆիկատոր'),
(51808, 371, 14, 'եվ մշակված է'),
(51809, 372, 14, 'եվ վերաբեռնեք Apache սերվերը'),
(51810, 373, 14, 'եվ պատճառն է'),
(51811, 374, 14, 'անեմիա'),
(51812, 375, 14, 'կոճ'),
(51813, 376, 14, 'գարշապար + կոճ'),
(51814, 377, 14, 'կոճի գնահատման ձեվ'),
(51815, 378, 14, 'կոճի խնդիրներ'),
(51816, 381, 14, 'անորեքսիա'),
(51817, 383, 14, 'դրույք'),
(51818, 384, 14, 'անալ սֆինքթերի տոնուսը նորմալ է,անցավ, ուռուցքային գոյաթություններ չկան'),
(51819, 385, 14, 'անհանգստություն'),
(51820, 386, 14, 'այլ'),
(51821, 387, 14, 'այլ աստիճան'),
(51822, 388, 14, 'փնտրվող կոդի որեւէ մաս կամ նրա նկարագրությունը'),
(51823, 389, 14, 'փնտրվող մասնագիտության որեւէ մաս'),
(51824, 390, 14, 'դեղամիջոցի նույնականացման սերիայի մի մասը կամ դրա անվանումը'),
(51825, 391, 14, 'պատվաստման նույնականացման սերիայի մի մասը կամ պատվաստման անվանումը'),
(51826, 392, 14, 'Հիվանդի անվան մի մասը, կամ  "ազգանուն, անուն", կամ "Ի-Ա"'),
(51827, 393, 14, 'Այլ համապատասխան ինֆորմցիա'),
(51828, 394, 14, 'API բանալի կոդ կարճ հաղորդագրության մուտքի համար'),
(51829, 395, 14, 'ԱՊՆԵԱ /շնչառության կանգ/'),
(51830, 396, 14, 'Արտաքին տեսք'),
(51831, 397, 14, 'Արտաքին տեսք։'),
(51832, 398, 14, 'Կցել սույն գրառումը'),
(51833, 399, 14, 'Կցել առկա գրառմանը'),
(51834, 400, 14, 'Կցել սույն գրառմանը'),
(51835, 401, 14, 'Կցել Սույն Գրառմանը'),
(51836, 402, 14, 'Ապպենդեկտոմիա /կույր աղիքի հեռացում/'),
(51837, 403, 14, 'ապպենդեկտոմիա /կույր աղիքի հեռացում/'),
(51838, 404, 14, 'Համապատասխան Հիվանդ'),
(51839, 406, 14, 'Հայտի անվանում՝ մուտքի էջի գլխավոր պատուհանի վերնգրի համար'),
(51840, 407, 14, 'Հայտ ընդունողի կոդը (GS03 - եթե դատարկ ISA08 օգտագործվի)'),
(51841, 408, 14, 'Հայտ  Ուղարկողի կոդը (GS02)'),
(51842, 409, 14, 'Հայտի վերնագիրը'),
(51843, 410, 14, 'Վերաբերվում է կենսական օրգանների ցուցանիշներին կամ Աճի գրաֆիկին'),
(51844, 411, 14, 'Վերաբերվում է կենսական օրգանների ցուցանիշներին'),
(51845, 412, 14, 'Ավելացնել փոփոխությունները միայն ընթացիկ իրադարձությանը, այս և առաջիկա բոլոր իրադարձություններին'),
(51846, 413, 14, 'տարածել տուժած հատվածների վրա'),
(51847, 414, 14, 'տարածել մաշկին'),
(51848, 415, 14, 'Կիրառում/Տարածում/Դիմում'),
(51849, 417, 14, 'Այցելություն'),
(51850, 418, 14, 'Այցելության ամսաթիվ'),
(51851, 419, 14, 'Այցելության էկրանավորման ձև'),
(51852, 420, 14, 'Այցելության հիշեցման կարգ'),
(51853, 421, 14, 'Այցելության կարգավիճակ'),
(51854, 422, 14, 'Այցելության կարգավիճակներ'),
(51855, 423, 14, 'Այցելություններ ֊ի ընթացքում/շրջանակներում'),
(51856, 424, 14, 'Այցելության/Իրադարձության Գույն'),
(51857, 425, 14, 'Այցելություններ'),
(51858, 426, 14, 'Այցելություններ (նշել ըստ ցանկության)'),
(51859, 427, 14, 'Այցելություններ (նշել ըստ ցանկության)'),
(51860, 430, 14, 'Այցելություններ և հանդիպումներ'),
(51861, 431, 14, 'Այցելությունների Հաշվետվություն'),
(51862, 432, 14, 'Այցելություններ և հանդիպումների հաշվետվություն'),
(51863, 434, 14, 'Հաստատել'),
(51864, 436, 14, 'Հաստատված է'),
(51865, 437, 14, 'Հաստատված միջոցառումների կառավարում'),
(51866, 438, 14, 'Հաջողությամբ հաստատված է'),
(51867, 440, 14, 'Այց֊հանդ․'),
(51868, 441, 14, 'Այցեր'),
(51869, 442, 14, 'Ապր'),
(51870, 443, 14, 'Ապրիլ'),
(51871, 444, 14, 'Արաբերեն'),
(51872, 445, 14, 'Արագոներեն'),
(51873, 446, 14, 'Արխիվ'),
(51874, 447, 14, 'Թարգմանե՞լ մուտքի վերահսկման խմբերի անունները'),
(51875, 448, 14, 'Թարգմանե՞լ այցելությունների կատեգորիաների անունները'),
(51876, 449, 14, 'Թարգմանե՞լ փաստաթղթերի կատեգորիաների անունները'),
(51877, 450, 14, 'Այս տիպի համար գանձումներ կատարվե՞լ են'),
(51878, 451, 14, 'Թարգմանե՞լ Հիվանդի գրառումների վերնագրերը'),
(51879, 452, 14, 'Այս կոդավորումները պահպանվա՞ծ են sql (0-нет, 1-МКБ-10, 2-SNOMED(RF1), 3-SNOMED(RF2)) արտաքին աղյուսակներում։'),
(51880, 453, 14, 'Պատրա՞ստ եք այս այցին լուծել նոր GCAC խնդիր'),
(51881, 454, 14, 'Վստա՞հ եք, որ/իսկապե՞ս/ ցանկանում եք նշանակել այսօրվա համար'),
(51882, 455, 14, 'Վստա՞հ եք, որ ցանկանում եք հաստատել այս իրադարձությունները'),
(51883, 457, 14, 'Վստա՞հ եք, որ/իսկապե՞ս/  ցանկանում եք ամբողջովին հեռացնել այս ձևը'),
(51884, 458, 14, 'Վստա՞հ եք, որ/իսկապե՞ս/  ցանկանում եք ջնջել'),
(51885, 459, 14, 'Վստա՞հ եք, որ/իսկապե՞ս/  ցանկանում եք ջնջել այս բացահայտումը'),
(51886, 460, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/  ցանկանում եք ջնջել այս իրադարձությունը'),
(51887, 461, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/  ցանկանում եք ջնջել այս կետը տվյալների բազայից'),
(51888, 462, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/  ցանկանում եք ջնջել այս գրառումը'),
(51889, 464, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/  ցանկանում եք խմբագրել այս իրադարձությունները'),
(51890, 465, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/ ցանկանում եք քողարկել/թաքցնել այս իրադարձությունները'),
(51891, 466, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/ ցանկանում եք կրկին փոխանցել այն'),
(51892, 467, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/  ցանկանում եք տեսնել այս իրադարձությունները'),
(51893, 468, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/ ցանկանում եք ջնջել ողջ խումբը'),
(51894, 469, 14, 'Վստա՞հ եք, որ /իսկապե՞ս/ ցանկանում եք ջնջել ողջ ցանկը'),
(51895, 470, 14, 'Վստա՞հ եք, որ  /իսկապե՞ս/ ցանկանում եք ջնջել դաշտը'),
(51896, 471, 14, 'Վստա՞հ եք, որ  /իսկապե՞ս/ ցանկանում եք ջնջել նշված դաշտերը'),
(51897, 472, 14, 'Դուք իսկապե՞ս ցանկանում եք շարունակել այս գործողությունները'),
(51898, 473, 14, 'Տարածքը նշված չէ'),
(51899, 474, 14, 'Բազուկ'),
(51900, 475, 14, 'Հայերեն'),
(51901, 477, 14, 'Առիթմիա'),
(51902, 478, 14, 'Արտրիտ'),
(51903, 479, 14, 'Արտրիտ / հոդերի դեստրուկտիվ հիվանդություն'),
(51904, 480, 14, 'Արտրիտ / հոդերի դեստրուկտիվ հիվանդություն'),
(51905, 481, 14, 'ինչպես'),
(51906, 482, 14, 'ինչպես ֊ի/ց/'),
(51907, 484, 14, 'Ասիական'),
(51908, 485, 14, 'Ասամերեն'),
(51909, 487, 14, 'Գնահատում'),
(51910, 488, 14, 'Նշանակված է'),
(51911, 489, 14, 'Ասիստենտ'),
(51912, 490, 14, 'Ասթմա'),
(51913, 491, 14, '֊ում/կողքը/֊ին'),
(51914, 492, 14, '"Բոլորը" ընտրելու դեպքում անհրաժեշտ է որոնման  առնավազն մեկ պարամետր'),
(51915, 495, 14, 'Սպորտային թիմ'),
(51916, 496, 14, 'Սպորտային Թիմ'),
(51917, 497, 14, 'Սպորտային/վնասվածք'),
(51918, 498, 14, 'ATNA աուդիտի CA վկայական'),
(51919, 499, 14, 'ATNA աուդիտի սերվեր'),
(51920, 500, 14, 'ATNA աուդիտի տեղական/տարածքային վկայական'),
(51921, 501, 14, 'ATNA աուդիտի պորտ'),
(51922, 503, 14, 'Ուշադրություն'),
(51923, 504, 14, 'Ուշադր․'),
(51924, 509, 14, 'Պահեստային կրկնօրինակումների գրանցման աուդիտ'),
(51925, 510, 14, 'Խառը գրանցումների աուդիտ'),
(51926, 511, 14, 'Նշանակման վայրի գրանցումների աուդիտ'),
(51927, 512, 14, 'Հիվանդի գրանցման աուդիտ'),
(51928, 513, 14, 'Պլանավորման գրանցումների աուդիտ'),
(51929, 514, 14, 'Անվտանգության կառավարման գրանցումների աուդիտ'),
(51930, 515, 14, 'SELECT/Ընտրել հարցման գրանցումների աուդիտ'),
(51931, 516, 14, 'Օգս․'),
(51932, 517, 14, 'Օգոստոս'),
(51933, 519, 14, 'թույլ․'),
(51934, 520, 14, 'թույլ․/գրառումներ'),
(51935, 523, 14, 'Լիազորող խումբ'),
(51936, 524, 14, 'Լիազորման/թույլտվության կարգավիճակ'),
(51937, 525, 14, 'Լիազորագրեր'),
(51938, 526, 14, 'Լիազորել/թույլատրել'),
(51939, 527, 14, 'Թույլատրել ցանկացած հանդիպում'),
(51940, 528, 14, 'Թույլատրել իմ հանդիպումները'),
(51941, 530, 14, 'Լիազորված'),
(51942, 531, 14, 'Միայն լիազորված'),
(51943, 532, 14, 'Ավտոմատ  ուղարկում'),
(51944, 535, 14, 'Ավտոմատ կերպով ստեղծել նոր հանդիպում'),
(51945, 536, 14, 'Ավտոմատ ստեղծում'),
(51946, 537, 14, 'Չափման միավորի ավտոմատ հաշվարկում'),
(51947, 538, 14, 'Չափման միավորի ավտոմատ հաշվարկում   - 2011'),
(51948, 539, 14, 'Չափման միավորի ավտոմատ հաշվարկում - 2014'),
(51949, 542, 14, 'Չափման միավորի ավտոմատ հաշվարկման հետևում'),
(51950, 543, 14, 'Ավտոմատ չափման միավոր'),
(51951, 544, 14, 'Ավտոմատ'),
(51952, 546, 14, 'Ավտոմատ ստեղծում է նոր հանդիպում, երբ այցելության կարգավիճակը դրված է "@" (անցկացված է)'),
(51953, 550, 14, 'ավտոմատ պահպանված'),
(51954, 551, 14, 'Հասանելի կատեգորիաներ'),
(51955, 552, 14, 'Հասանելի ժամ'),
(51956, 553, 14, 'Հասանելի ճանապարհ'),
(51957, 554, 14, 'Ավարական'),
(51958, 557, 14, 'Միջին  ամսական'),
(51959, 558, 14, 'Անջատում / կոտրվածքով անջատում'),
(51960, 559, 14, 'Ոտնաթաթի կողային կոճի կոտրվածք'),
(51961, 560, 14, 'Ոտնաթաթի միջնային կոճի կոտրվածք '),
(51962, 561, 14, 'Տեղեկացվածության հիման վրա'),
(51963, 562, 14, 'թևատակի'),
(51964, 565, 14, 'օրը երկու անգամ'),
(51965, 566, 14, 'Հետ'),
(51966, 567, 14, 'հետ'),
(51967, 568, 14, 'Հետ գնալ ութ այցելություն'),
(51968, 569, 14, 'Հետ գնալ տասնմեկ այցելություն'),
(51969, 570, 14, 'Հետ գնալ հինգ այցելություն'),
(51970, 571, 14, 'Հետ գնալ չորս այցելություն'),
(51971, 572, 14, 'Հետ գնալ ինը այցելություն'),
(51972, 573, 14, 'Հետ գնալ մեկ այցելություն'),
(51973, 574, 14, 'Մեջքի ցավ / Ցավ մեջքի շրջանում'),
(51974, 575, 14, 'Ողնաշարային խնդիրներ'),
(51975, 576, 14, 'Հետ գնալ յոթ այցելություն'),
(51976, 577, 14, 'Հետ գնալ վեց այցելություն'),
(51977, 578, 14, 'Ողնաշարի վիրահատություն'),
(51978, 579, 14, 'Հետ գնալ տասը այցելություն'),
(51979, 580, 14, 'Հետ գնալ երեք այցելություն'),
(51980, 581, 14, 'Վերադառնալ Ադմինիստրատորի էջ'),
(51981, 582, 14, 'Վերադառնալ Հանդիպում էջ'),
(51982, 583, 14, 'Վերադառնալ Հիվանդ էջ'),
(51983, 584, 14, 'Վերադառնալ Հիվանդ էջ'),
(51984, 585, 14, 'Վերադառնալ Օգտվողներ էջ'),
(51985, 586, 14, 'Վերադառնալ Դիտարկում էջ'),
(51986, 587, 14, 'Հետ գնալ տասներկու այցելություն'),
(51987, 588, 14, 'Հետ գնալ երկու այցելություն'),
(51988, 590, 14, 'Պահեստային կրկնօրինակ'),
(51989, 591, 14, 'Պահեստային կրկնօրինակի ֆայլը պատրաստ է։ Հիմա կուղարկվի ներբեռնումը։'),
(51990, 592, 14, 'Պահեստային կրկնօրինակների ցանկ'),
(51991, 593, 14, 'Պահեստային կրկնօրինակն ընդունված է'),
(51992, 594, 14, 'Սխալ գրանցում'),
(51993, 595, 14, 'Անհուսալի պարտք'),
(51994, 596, 14, 'Բահասա Ինդոնեզիա'),
(51995, 597, 14, 'Բալ․'),
(51996, 598, 14, 'Մնացորդ'),
(51997, 599, 14, 'մնացորդ'),
(51998, 600, 14, 'Վերջնական մնացորդ'),
(51999, 601, 14, 'Պարտքի մնացորդ'),
(52000, 603, 14, 'Բանկային գործարք'),
(52001, 604, 14, 'Շտրիխ֊կոդի պիտակ'),
(52002, 605, 14, 'Շտրիխ֊կոդի պիտակի ձև'),
(52003, 607, 14, 'Հինգերորդ (5֊րդ) Metarsal֊ի բազա'),
(52004, 608, 14, 'Հինգերորդ (5֊րդ) Metarsal֊ի բազա'),
(52005, 609, 14, 'Բաշկիրերեն'),
(52006, 610, 14, 'Բասկերեն'),
(52007, 612, 14, 'Տվյալների խմբային/փաթեթային փոխանցման միջոց'),
(52008, 613, 14, 'Խմբային վճարման մուտքագրում'),
(52009, 614, 14, 'Խմբային վճարում'),
(52010, 615, 14, 'Փաթեթի մշակումն սկսված է․ այն ի փոքր ժամանակ կխլի'),
(52011, 616, 14, 'Խմբային արդյունքներ'),
(52012, 617, 14, 'Խմբային փոխանցում'),
(52013, 618, 14, 'Ուշադրություն․ որոշ ֆայլերի գործարկումը կարող է մի քանի րոպե տևել'),
(52014, 619, 14, 'որովհետև այս ID֊ն գոյություն չունի'),
(52015, 620, 14, 'Սկիզբ'),
(52016, 621, 14, 'Սկզբնական ամսաթիվ'),
(52017, 623, 14, 'Ծառայության մատուցման սկզբնական ամսաթիվ yyyy-mm-dd'),
(52018, 624, 14, 'Օրացույցային գործողությունների սկզբնական ժամ'),
(52019, 625, 14, 'Բելառուսերեն'),
(52020, 628, 14, 'Բենգալյան'),
(52021, 630, 14, 'միջև'),
(52022, 631, 14, 'Երկկողմանի'),
(52023, 632, 14, 'Բիհարերեն'),
(52024, 633, 14, 'Երկկողմանի'),
(52025, 634, 14, 'Երկկողմանի։'),
(52026, 636, 14, 'Հաշվի/Հաշվարկման ամսաթիվ'),
(52027, 637, 14, 'Հաշիվ / Հավաքագրում'),
(52028, 638, 14, 'Վճարված'),
(52029, 640, 14, 'Հաշիվներ'),
(52030, 641, 14, 'Հաշիվներ  (write պարտադիր չէ)'),
(52031, 642, 14, 'Վճարման նախազգուշացում'),
(52032, 644, 14, 'Պահանջվող ծառայության վճարման կոդ'),
(52033, 645, 14, 'Վճարման կոդեր'),
(52034, 646, 14, 'Վճարման ամսաթիվ'),
(52035, 647, 14, 'Վճարման բաժին'),
(52036, 648, 14, 'Վճարման ծառայություններ'),
(52037, 649, 14, 'Տեղեկություններ հաշիվների մասին /Վճաման ինֆորմացիա'),
(52038, 650, 14, 'Վճարման վայրը'),
(52039, 655, 14, 'Վճարումների կառավարիչ'),
(52040, 656, 14, 'Վճարման ծանուցում'),
(52041, 657, 14, 'Վճարման ծանուցում ֊ի համար '),
(52042, 658, 14, 'Վճարման ծանուցում'),
(52043, 659, 14, 'Վճարումների/հաշիվների հարցման արդյունքներ։'),
(52044, 660, 14, 'Վճարումների/հաշիվների հաշվետվություն'),
(52045, 661, 14, 'Հաշվի  կարգավիճակ'),
(52046, 662, 14, 'Հաշվի  կարգավիճակ՝ վճարված  չէ'),
(52047, 663, 14, 'Հաշիվ '),
(52048, 665, 14, 'Բիոպսիա'),
(52049, 666, 14, 'Ծննդյան ամսաթիվ'),
(52050, 669, 14, 'Սև'),
(52051, 670, 14, 'Սևացած թոք'),
(52052, 671, 14, 'Սևամորթ կամ Աֆրոամերիկացի'),
(52053, 672, 14, 'Միզապարկի քաղցկեղ'),
(52054, 673, 14, 'ՄԻզապարկի բորբոքում'),
(52055, 674, 14, 'Դատարկ ձևեր'),
(52056, 675, 14, 'Արյունահոսության խնդիրներ/գանգատներ'),
(52057, 676, 14, 'Տեսողության անկում'),
(52058, 677, 14, 'Որովայնի փքվածություն'),
(52059, 678, 14, 'Արգելափակված'),
(52060, 679, 14, 'Արյուն'),
(52061, 680, 14, 'Արյան Ճնշում'),
(52062, 681, 14, 'Արյան ճնշում'),
(52063, 682, 14, 'Քթային արյունահոսություն'),
(52064, 683, 14, '"Կապույտ Խեցի" Բժշկական Ապահովագրություն'),
(52065, 684, 14, 'Այս հաշվետվության մեջ կապույտով նշված են  տեղեկատվական տողերը, սև տողերը ցույց են տալիս  նախկինում եղած ինֆորմցիան։ Կանաչով երևում են  հաջողությամբ ավելացված փոփոխությունները։ Կարմիրով  ցուցադրված են սխալները կամ չընդունված  փոփոխությունները․ դրանք պետք է գործարկել ձեռքով։  Ընթացիք մերժված պահանջներն ու վճարման հետկանչը  ավտոմատ չեն գործարկվում, ուստի կցուցադրվեն կարմիրով։'),
(52066, 685, 14, 'Խավար տեսողություն'),
(52067, 686, 14, 'Մարմնի քաշի ինդեքս'),
(52068, 687, 14, 'Քաշի ինդեքսի կարգավիճակ'),
(52069, 689, 14, 'Մարմնի մակերեսը'),
(52070, 690, 14, 'Մարմնի հատվածը'),
(52071, 691, 14, 'Մարմնի կիրառելի մասը'),
(52072, 692, 14, 'Ոսկրային հիվանդություն / Ոսկրային փխրունություն'),
(52073, 693, 14, 'Ոսկրային հիվանդություն․ միջնային կոճ'),
(52074, 694, 14, 'Բուլյան'),
(52075, 696, 14, 'Ներքնամաս'),
(52076, 697, 14, 'Զույգ ականջները'),
(52077, 698, 14, 'Զույգ աչքերը'),
(52078, 699, 14, 'Ներքին /ներքևի'),
(52079, 700, 14, 'Ներքևի լուսանցք  (px)'),
(52080, 701, 14, 'ԴԱՇՏ 10 A։ Արտադրական '),
(52081, 702, 14, 'ԴԱՇՏ 10 B։ Ավտոմոբիլային պատահար '),
(52082, 703, 14, 'ԴԱՇՏ 10 C։ Այլ պատահարներ '),
(52083, 704, 14, 'ԴԱՇՏ 14։ Ամսաթվի դասակարգիչ'),
(52084, 705, 14, 'ԴԱՇՏ 15։ Այլ ամսաթվի դասակարգիչ'),
(52085, 706, 14, 'ԴԱՇՏ 15։  Նույն կամ նմանատիպ հիվանդություն /տտ֊աա֊օօ/'),
(52086, 707, 14, 'ԴԱՇՏ 15։  Նույն կամ նմանատիպ հիվանդություն/Այլ ամսաթիվ  /տտ֊աա֊օօ/'),
(52087, 708, 14, 'ԴԱՇՏ 16։ Չի աշխատում (yyyy-mm-dd)  ամսաթվից'),
(52088, 709, 14, 'ԴԱՇՏ 16։ Չի աշխատում մինչ (yyyy-mm-dd)  ամսաթիվը'),
(52089, 710, 14, 'ԴԱՇՏ 18։ Հոսպիտալացման ամսաթիվը սկսած  (yyyy-mm-dd) '),
(52090, 711, 14, 'ԴԱՇՏ 18։ Հոսպիտալացման ամսաթիվը մինչև  (yyyy-mm-dd) '),
(52091, 712, 14, 'ԴԱՇՏ 20։ Դրսի լաբորատորիան աշխատո՞ւմ  է'),
(52092, 713, 14, 'ԴԱՇՏ 22։ Կրկնակից ուցաբերված բուժօգնության կոդ  (ICD-9) '),
(52093, 714, 14, 'ԴԱՇՏ 23։  Նախնական թույլատրության համար '),
(52094, 715, 14, 'ԱՃ /արյան ճնշում/'),
(52095, 716, 14, 'ԱՃ դիաստոլիկ'),
(52096, 717, 14, 'ԱՃ սիստոլիկ'),
(52097, 719, 14, 'ԱԴՃ'),
(52098, 721, 14, 'ԱՍՃ'),
(52099, 722, 14, 'Բրազիլիական ծագման պորտուգալացի'),
(52100, 723, 14, 'Կրծքագեղձ'),
(52101, 724, 14, 'Կրծքագեղձի բիոպսիա'),
(52102, 725, 14, 'Կռծքագեղձի հեռացում'),
(52103, 726, 14, 'Կրծքագեղձի հիվանդություն'),
(52104, 727, 14, 'Կրծքագեղձի հետազուտություն'),
(52105, 728, 14, 'Կրծքագեղձի նորագոյացություն'),
(52106, 730, 14, 'Շնչառական աղմուկ'),
(52107, 731, 14, 'Բրետոնական /բրետոներեն'),
(52108, 732, 14, 'Ոսկրի վնասվածք'),
(52109, 733, 14, 'Վնասվածքի ձև'),
(52110, 734, 14, 'Բրոնխիտի ձև'),
(52111, 735, 14, 'Փնտրել/Դիտել'),
(52112, 736, 14, 'Փնտրել /Դիտել գրանցման համար'),
(52113, 737, 14, 'Կապտուկ /Հեմատոմա'),
(52114, 738, 14, 'Բուլղարերեն'),
(52115, 739, 14, 'Աջակողմյան ուռածություն'),
(52116, 740, 14, 'Բիրմացի/Բիրմայերեն'),
(52117, 741, 14, 'Այրոց միզարձակման ժամանակ'),
(52118, 742, 14, 'Այրոց միզարձակման ժամանակ'),
(52119, 743, 14, 'Գործնական հեռախոսահամար'),
(52120, 744, 14, 'Զբաղված'),
(52121, 745, 14, 'բայց դեռևս գործարկված չէ'),
(52122, 746, 14, 'Նստատեղ'),
(52123, 747, 14, 'Նստատեղ  + S.I.'),
(52124, 748, 14, 'միջոցով'),
(52125, 749, 14, 'Միջոցով'),
(52126, 750, 14, 'բանավոր'),
(52127, 751, 14, 'Միջոցով/ Աղբյուր'),
(52128, 752, 14, 'Միջոցով։'),
(52129, 753, 14, 'C'),
(52130, 754, 14, 'CA վկայական՝  RFC 5425 TLS syslog սերվերի հաստատման համար'),
(52131, 755, 14, 'Քեշի կենսական տևողությունը  (վայրկյաններով)'),
(52132, 756, 14, 'Քեշի ձևաչափը լրացվա՞ծ է'),
(52133, 757, 14, 'Կոֆեինի կիրառում'),
(52134, 758, 14, 'Օրացույց'),
(52135, 759, 14, 'Օրացույցային ժամի ավարտ'),
(52136, 760, 14, 'Օրացուցային ընդմիջում'),
(52137, 761, 14, 'Օրացույցի ցուցադրում'),
(52138, 762, 14, 'Օրացույցի կարգավորում'),
(52139, 763, 14, 'Օրացույցի մեկնարկային ժամ'),
(52140, 764, 14, 'Օգտվողի օրացույց'),
(52141, 765, 14, 'Օրացույցի դիտում'),
(52142, 766, 14, 'addForm() զանգը կատարվում է այստեղ։ <br>'),
(52143, 767, 14, 'Կալորիաներ'),
(52144, 768, 14, 'Կամբոջայի/կամբոջերեն'),
(52146, 774, 14, 'Չեղարկել'),
(52147, 775, 14, 'Չեղարկել փոփոխությունը'),
(52148, 776, 14, 'Չեղարկված է'),
(52149, 777, 14, 'Քաղցկեղ'),
(52150, 778, 14, 'Քաղցկեղի սկրինինգ/հետազոտություն։ Հաստ աղիքի քաղցկեղի սկրինինգ'),
(52151, 779, 14, 'Քաղցկեղի սկրինինգ/հետազոտություն։ Մամոգրաֆիա'),
(52152, 780, 14, 'Քաղցկեղի սկրինինգ/հետազոտություն։ ՓԱՓ հետազոտություն'),
(52153, 781, 14, 'Քաղցկեղի սկրինինգ/հետազոտություն։ Շագանակագեղձի քաղցկեղի հետազոտություն'),
(52154, 782, 14, 'Հնարավոր չէ ավելացնել սույն գրառումը, քանզի այն արդեն առկա է'),
(52155, 783, 14, 'Հնարավոր չէ ավելացնել/թարմացնել սույն գրառումը, քանզի  առկա է կրկնօրինակը'),
(52156, 784, 14, 'Հնարավոր չէ արխիվացնել․ մարժված է'),
(52157, 785, 14, 'Հնարավոր չէ փոխարկել JPEG ֆորմատի․ համոզվեք, որ տեղադրված է ImageMagick ծրագիրը'),
(52158, 786, 14, 'Հնարավոր չէ ջնջել․ մարժված է'),
(52159, 787, 14, 'Հնարավոր չէ արտածել/ցուցադրել ցանցում, քանի որ բրաուզերը չի ապահովում վերջինիս տեսակը'),
(52160, 788, 14, 'Հնարավոր չէ արտածել/ցուցադրել ցանցում, քանի որ բրաուզերը չի ապահովում վերջինիս տեսակը'),
(52161, 789, 14, 'Հնարավոր չէ արտածել/ցուցադրել ցանցում, քանի որ բրաուզերը չի ապահովում վերջինիս տեսակը'),
(52162, 790, 14, 'Հնարավոր չէ ստեղծաել'),
(52163, 791, 14, 'Հնարավոր չէ ստեղծաել ֆայլ'),
(52164, 792, 14, 'Հնարավոր չէ ջնջել ֆայլ (SFTP սերվերից)'),
(52165, 793, 14, 'Հնարավոր չէ ջնջել ֆայլ'),
(52166, 794, 14, 'Հնարավոր չէ որոշել նշանակված/նախատեսված ֆայլի անունը'),
(52167, 795, 14, 'Հնարավոր չէ գտնել '),
(52168, 796, 14, 'Հնարավոր չէ որոշել գտնել նախատեսված ֆայլի անունը'),
(52169, 799, 14, 'Հնարավոր չէ գտնել Պացիենտին SQL-Ledger֊ի հաճախորդների նույնականացման բաժնում'),
(52170, 800, 14, 'Հնարավոր չէ գտնել postscript/ետգրության փաստաթղթի հղումը ֊ի մեջ '),
(52171, 801, 14, 'Հնարավոր չէ գտնել մասնագետին SQL-Ledger/մատյանի աշխատակից բաժնում '),
(52172, 802, 14, 'Հնարավոր չէ փոփոխել վճարումը․ մնացորդը բացասական է'),
(52173, 803, 14, 'Հնարավոր չէ բացել '),
(52174, 804, 14, 'Հնարավոր չէ կցել Ապահովագրություն բաժնին։ Վճարում կատարողը Պացիենտն է'),
(52175, 805, 14, 'Հնարավոր չէ կցել Պացիենտ բաժնին։ Վճարում կատարողը Ապահովագրությունն է'),
(52176, 806, 14, 'Հնարավոր չէ փոփոխել վճարումը․ մնացորդը բացասական է'),
(52177, 807, 14, 'Հնարավոր չէ կարդալ'),
(52178, 808, 14, 'Հնարավոր չէ կարդալ տեղեկատվություն'),
(52179, 809, 14, 'Հնարավոր չէ թարմացրել, քանի որ չէք խմբագրել գոյություն ունեցող գրառումը'),
(52180, 810, 14, 'Դարձնել մեծատառ'),
(52181, 811, 14, 'Բոլորը դարձնել մեծատառ'),
(52182, 812, 14, 'Դեղապատիճ'),
(52183, 813, 14, 'Քարտ'),
(52184, 814, 14, 'Սրտի խոռոչների կաթետերավորում /Վալվուլոպլաստիկա /'),
(52185, 815, 14, 'Էխոսրտագրություն'),
(52186, 816, 14, 'Սրտանոթային'),
(52187, 821, 14, 'Աճառների/Հոդերի/Դիսկերի վնասվածք'),
(52188, 822, 14, 'Աճառի վնասվածք'),
(52189, 823, 14, 'Քներակի պուլսացիա  nl, ոտնաթաթի զարկերակի պուլսացիա nl'),
(52190, 824, 14, 'կանխիկ'),
(52191, 825, 14, 'Կանխիկ'),
(52192, 826, 14, 'Կանխիկ մուտք'),
(52193, 827, 14, 'Կանխիկ մուտքեր մատակարարից'),
(52194, 829, 14, 'Կատարակտայի վիրաբուժություն'),
(52195, 830, 14, 'Կատարակտա'),
(52196, 831, 14, 'Կատեգորիաներ'),
(52197, 832, 14, 'Կատեգորիաներ ֊ի համար'),
(52198, 833, 14, 'Կատեգորիա'),
(52199, 834, 14, 'կատեգորիա'),
(52200, 835, 14, 'Կատեգորիա '),
(52201, 836, 14, 'Կատեգորիայի մանրամասներ'),
(52202, 837, 14, 'Սահմանափակումեր ըստ կատեգորիայի'),
(52203, 838, 14, 'Կատեգորիայի անվանում'),
(52204, 839, 14, 'Կատեգորիայի անվանումը դատարկ է'),
(52205, 840, 14, 'Կատեգորիա/Վերնագիր'),
(52206, 841, 14, 'Կովկասցի'),
(52207, 842, 14, 'Այցելության/Առաջնային օգնության ցուցաբերողի ինֆորմացիան ցուցադրելու հաստատված պատճառներ՝'),
(52208, 846, 14, 'CCR Հաստատում'),
(52209, 847, 14, 'CCR Պացիենտի զննում'),
(52210, 848, 14, 'CCR Պացիենտի զննում և հաստատում'),
(52211, 850, 14, 'CDR'),
(52212, 851, 14, 'CDR հաշվետվությունների/զեկույցների  գործարկաման/մշակման առաջնայնություն'),
(52213, 852, 14, 'Բջիջ'),
(52214, 853, 14, 'Բջջային հեռախոս'),
(52215, 854, 14, 'Բջջային հեռախոսահամար'),
(52216, 855, 14, 'Բջջային հեռախոսահամար'),
(52217, 856, 14, 'ՀԻմնական/բազային վկայական'),
(52218, 857, 14, 'Կենտրոնական/Հարավային Ամերիկացի'),
(52219, 858, 14, 'Լիազորող մարմնի crt ֆայլի գտնվելու վայրը չի կարող դատարկ լինել'),
(52220, 859, 14, 'Լիազորող մարմնի բանալի ֆայլի գտնվելու վայրը չի կարող դատարկ լինել'),
(52221, 860, 14, 'RFC 5425 TLS syslog սերվերին ուղարկելու վկայական'),
(52222, 861, 14, 'Օգտվողի վկայական'),
(52223, 862, 14, 'Վկայականներ'),
(52224, 866, 14, 'Փոփոխություն'),
(52225, 867, 14, 'Փոփոխություն'),
(52226, 868, 14, 'Փոխել գործողությունը'),
(52227, 870, 14, 'Տեսողության վատթարացում'),
(52228, 871, 14, 'Տեսողության վատթարացում'),
(52229, 872, 14, 'Փոխել գաղտնաբառը'),
(52230, 874, 14, 'Փոփոխված է'),
(52231, 875, 14, 'Փոփոխված աղիք'),
(52232, 876, 14, 'փաստաթղթի համար փոխել Պացիենտի նուհնականացումը'),
(52233, 877, 14, 'առանձնահատկություններ'),
(52234, 878, 14, 'մնացած սիմվոլները'),
(52235, 879, 14, 'վճարում'),
(52236, 880, 14, 'վճարի ճշգրտումներ'),
(52237, 881, 14, 'Վճարի կոդավորում'),
(52238, 882, 14, 'Վճարումներ'),
(52239, 883, 14, 'Աղյուսակ/Քարտ'),
(52240, 884, 14, 'Աղյուսակի /Քարտ ակտիվությունը/տեղաշարժը'),
(52241, 885, 14, 'Գրանցման/Դուրսգրման աղյուսակի/Քարտ ակտիվության զեկույց'),
(52242, 886, 14, 'Նույնականացման Քարտ'),
(52243, 887, 14, 'Նույնականացման Քարտ։'),
(52244, 889, 14, 'Քարտ տեղակայման գործողություն'),
(52245, 890, 14, 'Գրառում Քարտում/աղյուսակում'),
(52246, 891, 14, 'Քարտի/Աղյուսակի համարը'),
(52247, 892, 14, 'Քարտի/Աղյուսակի պահպանման վայրը'),
(52248, 893, 14, 'Քարտի/Աղյուսակի հետևում'),
(52249, 894, 14, 'ՔարտիԱղյուսակի հետև․'),
(52250, 895, 14, 'Փակված Քարտեր'),
(52251, 896, 14, 'Փակված Քարտեր'),
(52252, 898, 14, 'Ստուգել'),
(52253, 899, 14, 'Կտրոն/անդորրագիր'),
(52254, 900, 14, 'Նշել բոլորը'),
(52255, 902, 14, 'Նշել/ Գրանցել Ընդհանուր գումարը'),
(52256, 903, 14, 'Նշել/Գրանցել ամսաթիվ'),
(52257, 904, 14, 'Գրանցել օգտվողի լեզուների աղյուսակի թարգմանության տարբերությունները'),
(52258, 906, 14, 'Նշել/Գրանցել ըստ'),
(52259, 907, 14, 'Նշել մուտքի տվյալները'),
(52260, 909, 14, 'Նշել/Գրանցել լաբորատոր հետազոտությունների արդյունքները'),
(52261, 912, 14, 'Նշել համարը'),
(52262, 915, 14, 'Նշել  վճարումը'),
(52263, 916, 14, 'Նշեք այս վադակը, եթե ֆայլը կոդավորված է'),
(52264, 917, 14, 'Նշեք սա, եթե ցանկանում եք, որ մասնագետները տեսնեն բոլոր նախնական հանդիպումները, այլ ո միայն իրենցը'),
(52265, 919, 14, 'Գրանցման/EOB ամսաթիվ'),
(52266, 920, 14, 'Գրանցման/EOB համար'),
(52267, 921, 14, 'Գրանցման/Տեղեկ․ համար'),
(52268, 922, 14, 'Գրանցման/Տեղեկանքի համար'),
(52269, 923, 14, 'Նշավանդակի ցանկ'),
(52270, 924, 14, 'Նշավանդակի ցանկ'),
(52271, 925, 14, 'նշավանդակ տեքստով'),
(52272, 926, 14, 'նշավանդակ տեքստով'),
(52273, 928, 14, 'նշված'),
(52274, 929, 14, 'նշված վանդակ = ԱՅՈ ,  empty = ՈՉ'),
(52275, 932, 14, 'Վճարում'),
(52276, 933, 14, 'ստուգիչ գումար'),
(52277, 934, 14, 'Կրծքավանդակ'),
(52278, 935, 14, 'Կրծքավանդակի CTAB'),
(52279, 936, 14, 'Ցավ կրծքավանդակի շրջանում'),
(52280, 937, 14, 'Ցավ կրծքավանդակի շրջանում։'),
(52281, 938, 14, 'Ցավ կրծքավանդակի շրջանում'),
(52282, 940, 14, 'Փոխ․'),
(52283, 942, 14, 'Հիմնական/գլխավոր  գանգատ/բողոք'),
(52284, 943, 14, 'Երեխա'),
(52285, 945, 14, 'Մանկական պատվաստումների կարգավիճակ (CQM)'),
(52286, 946, 14, 'Դող'),
(52287, 947, 14, 'Չինարեն'),
(52288, 948, 14, 'Չինարեն (պարզեցված)'),
(52289, 949, 14, 'Չինարեն (ավանդական)'),
(52290, 951, 14, 'Ըստ ցանկության/Ընտրովի'),
(52291, 952, 14, 'Խոլեցիստեկտոմիա /լեղապարկի վիրահատական հեռացում/'),
(52292, 953, 14, 'Խոլեցիստեկտոմիա /լեղապարկի վիրահատական հեռացում/'),
(52293, 954, 14, 'Խոլեցիստեկտոմիա /լեղապարկի վիրահատական հեռացում/'),
(52294, 955, 14, 'Ընտրել'),
(52295, 956, 14, 'Ընտրեք որևէ բաժին և սեղմեք դրանում առկա մի կետի․ մյուս հատվածում այդ կետը տեսանելի ընդգծված կերևա և կկարողանաք այդտեղ սեղմումով ավելացնել կամ ջնջել հարաբերություններ'),
(52296, 957, 14, 'Ընտրել չափորոշիչներ'),
(52297, 958, 14, 'Ընտրել ՆԵՐԲԵՌՆԵԼ կամ Ցուցադրել Ցանցում'),
(52298, 959, 14, 'Ընտրել ֆայլը'),
(52299, 960, 14, 'Ընտրել ցանկից'),
(52300, 961, 14, 'Ընտրել դասավորության ուղղությունը'),
(52301, 962, 14, 'Ընտրել ցանկը'),
(52302, 963, 14, 'Ընտրել թղթի չափը'),
(52303, 965, 14, 'Ընտրել սույն հանդիպման զեկույցի/հաշվետվության տպագրության ֆորմատը'),
(52304, 967, 14, 'Քրոնիկ բրոնխիտ'),
(52305, 968, 14, 'Քրոնիկ հոդացավ'),
(52306, 969, 14, 'Քրոնիկ երիկամային անբավարարություն /ՔԵԱ/'),
(52307, 970, 14, 'Քրոնիկ սինովիտ / զեղում /հոդացավ/ հոդատապ'),
(52308, 971, 14, 'Քրոնիկ/Ընթացիկ'),
(52309, 973, 14, 'Լյարդի ցիրոզ'),
(52310, 974, 14, 'Լյարդի ցիրոզ'),
(52311, 975, 14, 'Քաղաք'),
(52312, 976, 14, 'Քաղաքի անվանումը'),
(52313, 977, 14, 'Քաղաք, Շրջան'),
(52314, 978, 14, 'Քաղաք, շրջանի փոստային ինդեքս'),
(52315, 979, 14, 'Քաղաք/Շրջան'),
(52316, 980, 14, 'Դիմում'),
(52317, 981, 14, 'Դիմում '),
(52318, 983, 14, 'Պահանջված հետազոտությունն կատարված է'),
(52319, 984, 14, 'Ներկայացված պահանջի տեսակը'),
(52320, 985, 14, 'Պահանջը կցվել է ֆայլին'),
(52321, 986, 14, 'Պահանջը կցվել է ֆայլին '),
(52322, 987, 14, 'Պահանջներ'),
(52323, 988, 14, 'Դասակարգում'),
(52324, 989, 14, 'Ջնջել'),
(52325, 990, 14, 'ՋՆՋԵԼ ԱԿՏԻՎ ՊԱՑԻԵՆՏԻՆ'),
(52326, 991, 14, 'Ջնջել ամենը'),
(52327, 992, 14, 'Ջնջել HL7 տվյալները'),
(52328, 993, 14, 'Ամբողջական վերականգնում'),
(52329, 994, 14, 'Մաքրել  Smarty Քեշը'),
(52330, 995, 14, 'EDI 270 փաթեթի ստեղծման համար անհրաժեշտ է ստույգ ինֆորմացիա'),
(52331, 996, 14, 'CLIA համար'),
(52332, 997, 14, 'Սեղմել'),
(52333, 998, 14, 'Սեղմել "արտահանել"՝  Կատեգորիա, Ենթակատեգորիա, Կետ, Բովանդակության ցանկ դեպի տեքստային ֆայլ արտահանելու համար'),
(52334, 999, 14, 'Սեղմեք գրաֆայի վրա որևէ կետի՝ նոր ծանոթագրություն ավելացնելու համար։ կրկնակի սեղմումով հեռցրեք այն'),
(52335, 1000, 14, 'ssl.zip ֆայլում վկայական ավելացնելու համար սեղմել "Ներբեռնել Վկայական"'),
(52336, 1001, 14, 'սեղմել մանրամասների համար'),
(52337, 1002, 14, 'սեղմել մանրամասների համար'),
(52338, 1003, 14, 'պատվերի ամփոփ նկարագրի համար Սեղմել'),
(52339, 1004, 14, 'արդյունքների համար սեղմել'),
(52340, 1005, 14, 'սեղմել այստեղ'),
(52341, 1006, 14, 'Նոր պացիենտ ավելացնելու համար սեղմել այստեղ'),
(52342, 1007, 14, 'Սեղմեք այստեղ՝ վնսավածքի կարգավիճակի փոփոխության թարմացման և առօրյա գործողությունները խմբագրելու համար'),
(52343, 1008, 14, 'Սեղմեք ամսաթիվ ընտրելու համար'),
(52344, 1009, 14, 'Սեղմեք ամսաթիվ  և ժամ ընտրելու համար'),
(52345, 1010, 14, 'Սեղմեք սկզբնական ամսաթիվ ընտրելու համար'),
(52346, 1020, 14, 'որոնման համար սեղմել այստեղ'),
(52347, 1021, 14, 'Կատեգորիայի, առաջնայնության և մականվան պարամետրերի  թարմացման համար սեղմել այստեղ'),
(52348, 1022, 14, 'Ամբողջը դիտելու համար սեղմեք ասյտեղ'),
(52349, 1023, 14, 'Գրաֆիկայի և դիտարկման համար սեղմեք այստեղ'),
(52350, 1025, 14, 'Սեղմեք այստեղ՝ բոլոր կենսական նշանակության օրգանների և դրանց գծապատկերի դիտարկման համար'),
(52351, 1026, 14, 'Սեղմեք այստեղ՝ Պացիենտի մանրամասն տվյալների համար'),
(52352, 1027, 14, 'Այդ ամենի դիտարկման համար սեղմեք այստեղ'),
(52353, 1028, 14, 'Այլ մանրամասների դիտարկման/խմբագրման համար սեղմեք այստեղ'),
(52354, 1029, 14, 'Սեղմել "տեղադրել" կոճակը՝  նշված ամսաթվով տվյալների բազայի տարբերակը տեղադրելու համար'),
(52355, 1030, 14, 'Սեղմեք ժամի ցանկացած գոտու վրա՝ վերջինիս մեծացման համար');
INSERT INTO `lang_definitions` VALUES
(52356, 1031, 14, 'Սեղմել Պացիենտի Անվանը՝  նրա ֆայլը բացելու համար'),
(52357, 1032, 14, 'Սեղմել Թարմացնել կոճակը՝ տեսնելու համար բոլոր արդյունքները, կամ վերևում  տեղադրեք որոնման չափորոշիչ՝ կոնկրետ/առանձին արդյունքի դիտարկման համար'),
(52358, 1033, 14, 'Սեղմել՝ ախտորոշում ավելացնելու համար'),
(52359, 1034, 14, 'Սեղմել՝ նոր բաղադրիչ ավելացնելու համար'),
(52360, 1035, 14, 'Սեղմել՝ նոր բաղադրիչ ավելացնելու համար'),
(52361, 1036, 14, 'Սեղմել՝ հիմնավորված ախտորոշում ընտրելու համար'),
(52362, 1037, 14, 'Սեղմել ներբեռման համար'),
(52363, 1038, 14, 'Սեղմել խմբագրման համար'),
(52364, 1039, 14, 'Սեղմել նկարագրության խմբագրման համար'),
(52365, 1040, 14, 'Սեղմել սույն իրադարձությունը խմբագրելու համար'),
(52366, 1041, 14, 'Սեղմել հաշվետվությունը գեներացնելու համար'),
(52367, 1042, 14, 'Սեղմել Պացիենտի համապատասխանության/համընկնման համար'),
(52368, 1043, 14, 'Սեղմել տպելու համար'),
(52369, 1044, 14, 'Սեղմել նոր շարք ստանալու/ավելացնելու համար'),
(52370, 1045, 14, 'Սեղմել ընտրելու համար'),
(52371, 1046, 14, 'Սեղմել ընտրելու համար'),
(52372, 1047, 14, 'Սեղմել այս մեթոդի արդյունաբերական ստանդարտի կոդի ընտրության համար'),
(52373, 1048, 14, 'Սեղմել այլընտրանքային պրոցեդուրայի կոդի համար'),
(52374, 1049, 14, 'Սեղմել կոդավորման ընտրության կամ փոփոխման համար'),
(52375, 1050, 14, 'Սեղմել  CVX կոդի ընտրության կամ փոփոխման համար'),
(52376, 1051, 14, 'Սեղմել ախտորոշման ընտրության կամ փոփոխման համար'),
(52377, 1052, 14, 'Սեղմել ծառայությունների կոդերի ընտրության կամ փոփոխման համար'),
(52378, 1053, 14, 'Սեղմել Պացիենտի ընտրության համար'),
(52379, 1054, 14, 'Սեղմել համապատասխան կոդի համար'),
(52380, 1055, 14, 'Եթե այս արդյունքը բերում է շեղում նորմայից, ապա սեղմեք  օգնություն ընտրելու համար'),
(52381, 1056, 14, 'Սեղմել անհրաժեշտ պրոցեդուրայի ընտրության համար'),
(52382, 1057, 14, 'Սեղմել տեսակավորման համար'),
(52383, 1058, 14, 'Սեղմել դիտարկման համար'),
(52384, 1059, 14, 'Սեղմել դիտարկման կամ խմբագրման  համար'),
(52385, 1060, 14, 'Սեղմել դիտարկման/խմբագրման  համար'),
(52386, 1061, 14, 'Սեղմել Թարմացնել կոճակը՝ տվյալների բազան  նշված ամսաթվից թարմացնելու համար'),
(52387, 1063, 14, 'Սեղմել։'),
(52388, 1064, 14, 'Հաճախորդի վկայականի վավերականության ժամկետի լրանալու  օրը'),
(52389, 1065, 14, 'Հաճախորդի վկայականի վավերականության ժամկետը'),
(52390, 1066, 14, 'Հաճախորդի  վկայականի վավերականությունը հաստատում է վավեր համարակալում'),
(52391, 1067, 14, 'Հաճախորդի կրկնօրինակ'),
(52392, 1069, 14, 'Քաղվածք Հիվանդի պատմագրից'),
(52393, 1070, 14, 'Հիվանդի Անունը'),
(52394, 1071, 14, 'Հիվանդի հերթական համարը'),
(52395, 1072, 14, 'Հաճախորդի/Հիվանդի  պրոֆիլ ֊ Նոր Հաճախորդ/Հիվանդ'),
(52396, 1073, 14, 'Հաճախորդի/Հիվանդի  պրոֆիլ ֊ Եզակի Հաճախորդ/Հիվանդ'),
(52397, 1074, 14, 'Հաճախորդներ/Հիվանդներ'),
(52398, 1075, 14, 'Կլինիկա'),
(52399, 1076, 14, 'Կլինիկայի կրկնօրինակը'),
(52400, 1077, 14, 'Կլինիկայի ամենօրյա գրանցում'),
(52401, 1078, 14, 'Կլինիկայի նույնականացման տվյալներ'),
(52402, 1079, 14, 'Կլինիկական'),
(52403, 1080, 14, 'Կլինիկական  որոշումների ընդունման/կայացման կանոնների ծանուցման պատասխանատում'),
(52404, 1081, 14, 'Կլինիկական Պատմություն'),
(52405, 1083, 14, 'Կլինիկական ծրագրեր'),
(52406, 1084, 14, 'Կլինիկական Որակի Ցուցանիշներ (CQM)'),
(52407, 1087, 14, 'Կլինիկական հիշեցումներ'),
(52408, 1088, 14, 'Կլինիկական հաշվետվություններ/զեկույցներ'),
(52409, 1089, 14, 'Կլինիկական կանոնների գործունեության/գործողության կատեգորիա'),
(52410, 1090, 14, 'Կլինիկական կանոնների գործունեության/գործողության առարկա'),
(52411, 1091, 14, 'Կլինիկական կանոնների ֆիլտրման մեթոդներ'),
(52412, 1092, 14, 'Կլինիկական կանոնների նպատակայի/թիրախային մեթոդներ'),
(52413, 1093, 14, 'Կլինիկական կանոններ'),
(52414, 1094, 14, 'Տրիքային միջակայքեր կլինիկական կանոնների համար'),
(52415, 1095, 14, 'Կլինիկական Կանոնների համեմատություն'),
(52416, 1096, 14, 'Կլինիկական կանոնների ազդեցության/տարածման տիպերը/տեսակները'),
(52417, 1097, 14, 'Կլինիկական կաննոերի հիշեցման/ծանուցման տեսակները'),
(52418, 1098, 14, 'Կլինիկական կաննոերի հիշեցում/ծանուցում հեռացնելու տեսակները'),
(52419, 1099, 14, 'Կլինիկական կաննոերի հիշեցման/ծանուցման պարբերականություն'),
(52420, 1100, 14, 'Կլինիկական կաննոերի հիշեցման/ծանուցման մեթոդներ'),
(52421, 1101, 14, 'Կլինիկական կաննոերի պլանային պարբերականություն'),
(52422, 1102, 14, 'Կլինիկական խնդիրներ/նպատկ'),
(52423, 1106, 14, 'Բուժաշխատողներ'),
(52424, 1107, 14, 'Կրկնօրինակել'),
(52425, 1108, 14, 'Կրկնօրինակել նախորդ այցը'),
(52426, 1109, 14, 'Փակել'),
(52427, 1110, 14, 'Փակել պատուհանը'),
(52428, 1111, 14, 'Փակել պատուհանը'),
(52429, 1112, 14, 'փակ'),
(52430, 1113, 14, 'սմ'),
(52431, 1114, 14, 'CMS 1500 միջակայք/լուսանցք'),
(52432, 1118, 14, 'CMS ID'),
(52433, 1127, 14, 'անվտանգ CN2-12'),
(52434, 1128, 14, 'հավելավճար'),
(52435, 1129, 14, 'կատարված հավելավճար'),
(52436, 1130, 14, 'ՀԱՎԵԼԱՎՃԱՐ'),
(52437, 1131, 14, 'կոդ'),
(52438, 1132, 14, 'կոդ'),
(52439, 1133, 14, 'կոդի որոնում'),
(52440, 1134, 14, 'Կոդը պետք է լինի երկնիշ և փոքրատառ'),
(52441, 1135, 14, 'Փոխարժեքի կոդ կամ նշան'),
(52442, 1136, 14, 'Տեքստային կոդ'),
(52443, 1137, 14, 'Կոդի տեսակ'),
(52444, 1138, 14, 'Կոդի տեսակ'),
(52445, 1139, 14, 'Կոդի տեսակը ճանաչված/ընդունված չէ'),
(52446, 1140, 14, 'Կոդի տեսակը դեռևս սահմանված չէ'),
(52447, 1141, 14, 'Կոդի տեսակներ'),
(52448, 1142, 14, 'Կոդ(եր)'),
(52449, 1143, 14, 'Կոդավորված է'),
(52450, 1144, 14, 'Կոդեր'),
(52451, 1145, 14, 'Կոդավորում/ինդեքսավորում'),
(52452, 1146, 14, 'Կոդավորում/ինդեքսավորում'),
(52453, 1147, 14, 'Ինդեքսավորում ֊ ցանկացած բուժում (գրել, մի մասն ըստ ցանկության)'),
(52454, 1148, 14, 'Ինդեքսավորում ֊ իմ բուժումները (գրել, մի մասն ըստ ցանկության)'),
(52455, 1149, 14, 'Կոդավորման մուտքն արգելված է'),
(52456, 1150, 14, 'Սուրճ'),
(52457, 1151, 14, 'Սուրճի կիրառում'),
(52458, 1152, 14, 'Համատեղ ապահովագրություն'),
(52459, 1153, 14, 'Անվճար'),
(52460, 1154, 14, 'Շրջել/փլուզել/փակել'),
(52461, 1155, 14, 'թաքցնել'),
(52462, 1156, 14, 'փակել ամենը'),
(52463, 1160, 14, 'Հավաքագրման ամսաթիվ'),
(52464, 1161, 14, 'Հավաքագրումներ/դրամահավաքներ/ժողովներ'),
(52465, 1162, 14, 'Հավաքագրումներ/դրամահավաքներ/ժողովներ֊ի զեկույց'),
(52466, 1163, 14, 'Հաստ աղիքի քաղցկեղ'),
(52467, 1164, 14, 'Հաստ աղիքի քաղցկեղի հետազոտություն'),
(52468, 1165, 14, 'Հաստ աղիքի քաղցկեղի վիրահատություն'),
(52469, 1166, 14, 'Կոլոնոսկոպիա'),
(52470, 1167, 14, 'կոլոնոսկոպիա'),
(52471, 1168, 14, 'Գույն'),
(52472, 1169, 14, 'Գույն։ հպվ․'),
(52473, 1170, 14, 'Սյունակ'),
(52474, 1171, 14, 'Սյունակներ'),
(52475, 1172, 14, 'Համատեղ/միացյալ մասնաբաժիններ'),
(52476, 1173, 14, 'Ստորակետ'),
(52477, 1174, 14, 'Մեկնաբանություն'),
(52478, 1175, 14, 'Մեկնաբանություններ'),
(52479, 1176, 14, 'Սույն արդյունքին կամ խորհրդատվությանն ուղղված մեկնաբանություններ'),
(52480, 1177, 14, 'Առևտրային Ապահովագրական Ընկերություն'),
(52481, 1178, 14, 'Կատարված փոփոխություններ'),
(52482, 1179, 14, 'Կապ'),
(52483, 1180, 14, 'Կապ'),
(52484, 1182, 14, 'Ընկերություն'),
(52485, 1183, 14, 'Ընկերության Անվանում'),
(52486, 1184, 14, 'Ավարտել'),
(52487, 1186, 14, 'Ավարտված'),
(52488, 1188, 14, 'Ավարտվա՞ծ է'),
(52489, 1190, 14, 'Բարդություններ ծառայություն մատուցողի կողմից'),
(52490, 1191, 14, 'Հղիության արհեստական ընդհատման բարդություններ'),
(52491, 1192, 14, 'Բաղադրիչներ'),
(52492, 1193, 14, 'Բժշկական նշանակումների ավտոմատացված համակարգ'),
(52493, 1194, 14, 'Եզրակացություններ'),
(52494, 1199, 14, 'Կարգավորումներ'),
(52495, 1200, 14, 'Կարգավորումների Արտահանում/ներմուծում'),
(52496, 1202, 14, 'Կարգավորել Apache և LibreEHR Հաճախորդի/Հիվանդի կողմից  SSL հավաստագրերի օգտագործման համար'),
(52497, 1203, 14, 'Կարգավորել Apache  Հաճախորդի/Հիվանդի կողմից  SSL հավաստագրերի օգտագործման համար'),
(52498, 1204, 14, 'Կարգավորել Apache   HTTPS օգտագործման համար'),
(52499, 1205, 14, 'Կարգավորել LibreEHR Հաճախորդի/Հիվանդի կողմից  SSL հավաստագրերի օգտագործման համար'),
(52500, 1208, 14, 'Հաստատել նոր պացիենտի գրանցումը'),
(52501, 1209, 14, 'Հաստատել նոր գաղտնաբառը'),
(52502, 1210, 14, 'Հաստատել վճարումը'),
(52503, 1214, 14, 'Բնածին'),
(52504, 1215, 14, 'Կոնյուկտիվ, բիբեր'),
(52505, 1216, 14, 'Կապի խզում'),
(52506, 1217, 14, 'Միակցիչներ/կցորդներ'),
(52507, 1218, 14, 'Հաստատուն'),
(52508, 1219, 14, 'Հաստատուն անվանում'),
(52509, 1220, 14, 'Հաստատուն անվանուը դատարկ է'),
(52510, 1221, 14, 'Հաստատուններ'),
(52511, 1222, 14, 'Փորկապություն'),
(52512, 1223, 14, 'Սահմանադրական/ Կառուցվածքային/Համակարգային/'),
(52513, 1226, 14, 'Խորհրդակցության ամփոփ նկարագիր'),
(52514, 1227, 14, 'Հետադարձ կապ'),
(52515, 1228, 14, 'Էլ․փոստ'),
(52516, 1229, 14, 'Էլ․փոստի հասցե'),
(52517, 1231, 14, 'Կոնտակտային տվյալներ'),
(52518, 1232, 14, 'Կոնտակտային լինզաներ'),
(52519, 1236, 14, 'Անուն'),
(52520, 1237, 14, 'Կոնտակտային անձ'),
(52521, 1238, 14, 'Կոնտակտային հեռախոս'),
(52522, 1239, 14, 'Կոնտակտային հեռախոսահամար'),
(52523, 1240, 14, 'Դիմել  ZMG LLC (zmghealth@gmail.com) eRx ծառայությանը բաժանորդագրվելու համար'),
(52524, 1241, 14, 'Պարունակում է հետևյալ կետերից առնվազն երեքը կամ չորսը'),
(52525, 1243, 14, 'Պարունակություն/Բովանդակություն'),
(52526, 1244, 14, 'պարունակություն/պովանդակություն'),
(52527, 1245, 14, 'Կոնտեքստ/ համատեքստ'),
(52528, 1246, 14, 'Կոնտեքստի անվանումը չպետք է դատարկ լինի'),
(52529, 1247, 14, 'Շարունակել'),
(52530, 1251, 14, 'Հակաբեղմնավորում'),
(52531, 1252, 14, 'Հակաբեղմնավորման ասպեկտները'),
(52532, 1253, 14, 'Հակաբեղմնավորման բարդությունները  (նշել)'),
(52533, 1254, 14, 'Հակաբեղմնավորման մեթոդը'),
(52534, 1255, 14, 'Հակաբեղմնավորիչ ապրանքներ'),
(52535, 1256, 14, 'Հակաբեղմնավորման նախնական ծառայություններ'),
(52536, 1257, 14, 'Հակաբեղմնավորման սկիզբ'),
(52537, 1258, 14, 'ID կարգավորումներ'),
(52538, 1259, 14, 'Կարգավորման համարը'),
(52539, 1261, 14, 'ՀԱՎԵԼԱՎՃԱՐ'),
(52540, 1262, 14, 'Հավելավճար'),
(52541, 1263, 14, 'Հավելավճար'),
(52542, 1264, 14, 'Հավելավճար չի նախատեսվում'),
(52543, 1265, 14, 'Հավելավճարը վճարված է'),
(52544, 1266, 14, 'Հավելավճարներ'),
(52545, 1268, 14, 'Կրկնօրինակել էջերը պացիենտի քարտի մեջ'),
(52546, 1269, 14, 'Կրկնօրինակել արժեքները'),
(52547, 1270, 14, 'Կրկնօրինակել տվյալների բազայի ֆայլը․ այն կխլի որոշակի ժամանակ'),
(52548, 1271, 14, 'Հեղինակային իրավունքների ծանուցում'),
(52549, 1275, 14, 'Ուղղված'),
(52550, 1277, 14, 'CouchDB'),
(52551, 1278, 14, 'CouchDB միացումը ձախողվեց'),
(52552, 1279, 14, 'CouchDB տվյալների բազա'),
(52553, 1280, 14, 'CouchDB տվյալների բազայի անվանում'),
(52554, 1281, 14, 'CouchDB հոսթինգ/սերվեր'),
(52555, 1282, 14, 'CouchDB հոսթի/սերվերի անվանում'),
(52556, 1283, 14, 'Միացնել CouchDB մուտքագրում/գրանցում'),
(52557, 1284, 14, 'CouchDB գաղտնաբառ'),
(52558, 1285, 14, 'CouchDB պորտալ'),
(52559, 1286, 14, 'CouchDB պորտալ'),
(52560, 1287, 14, 'CouchDB պահպանում ձախողվեց'),
(52561, 1288, 14, 'CouchDB օգտվողի անունուն/օգտատեր'),
(52562, 1289, 14, 'Հազ'),
(52563, 1290, 14, 'Հազ։'),
(52564, 1291, 14, 'հնարավոր չէ կապ հաստատել սերվերի հետ'),
(52565, 1293, 14, 'հնարավոր չէ բացել աղյուսակը'),
(52566, 1294, 14, 'հնարավոր չէ կարդալ ֆայլը'),
(52567, 1296, 14, 'Հնարավոր չէ ուղարկել էլ․ նամակ․ առկա է սերվերի խնդիր '),
(52568, 1297, 14, 'Հնարավոր չէ ուղարկել էլ․ նամակ․ առկա է սերվերի խնդիր '),
(52569, 1298, 14, 'Հնարավոր չէ ստեղծել պահեստային կրկնօրինակների ուղեցույց/տեղեկատու'),
(52570, 1299, 14, 'Հնարավոր չէ ջնջել տեղեկատուն'),
(52571, 1300, 14, 'Հնարավոր չէ ջնջել հին պահեստային կրկնօրինակը'),
(52572, 1301, 14, 'Հնարավոր չէ ջնջել հին արտահանվող ֆայլը'),
(52573, 1302, 14, 'Coumadin Կառավարում ֊ միջազգային կարգավորման ցուցանիշի հսկողություն'),
(52574, 1303, 14, 'Մեթոդին համապատասխան խորհրդատվություն'),
(52575, 1304, 14, 'Խորհրդատվություն'),
(52576, 1305, 14, 'Խորհրդատվական աշխատանքներ'),
(52577, 1308, 14, 'Երկիր'),
(52578, 1309, 14, 'Երկրի տվյալների տիպ'),
(52579, 1310, 14, 'Երկրների ցանկ'),
(52580, 1311, 14, 'Երկրների ցանկ  (գրել, ավելացնել ըստ ցանկությանl)'),
(52581, 1312, 14, 'Երկրի անունը ներկայացվում է երկնիշ հապավումով /օր․՝  Միացյալ Նահանգներ ՄՆ/'),
(52582, 1313, 14, 'հանրապետություն'),
(52583, 1315, 14, 'Կուպոն'),
(52584, 1318, 14, 'Հիվանդի կլինիկական հետազոտություն (CPT)'),
(52585, 1319, 14, '(CPT) կոդ'),
(52586, 1320, 14, '(CPT) կոդեր'),
(52587, 1321, 14, 'CPT4  Միջամտություն/Ծառայություն'),
(52588, 1322, 14, 'CPTII էֆֆեկտիվության չափորոշիչ'),
(52589, 1323, 14, 'CQM'),
(52590, 1325, 14, 'քսուք'),
(52591, 1326, 14, 'Ստեղծում էլ հաճախորդի կողմից SSL հավաստագիր յուրաքանչյուր օգտվողի կամ հաճախորդի մեքենայի համար'),
(52592, 1327, 14, 'Ստեղծում էլ հաճախորդի կողմից SSL հավաստագիր օգտվողի կամ հաճախորդի hostname֊ի/սերվերի անվան համար'),
(52593, 1329, 14, 'Ստեղծել իրադարձություն'),
(52594, 1330, 14, 'Ստեղծում և ներբեռնում է ամբողջական կրկնօրինակ'),
(52595, 1332, 14, 'Ստեղծում է պահեստային կրկնօրինակ'),
(52596, 1333, 14, 'Ստեղծել նոր խմբաքանակ'),
(52597, 1334, 14, 'Ստեղծել հաճախորդի վկայագիր/հավաստագիր'),
(52598, 1335, 14, 'Ստեղծել հաճախորդի կողմից SSL վկայագրեր/հավաստագրեր'),
(52599, 1336, 14, 'Ստեղծել կրկնօրինակ'),
(52600, 1338, 14, 'Ստեղծում է պահեստային կրկնօրինակների գրանցամատյան'),
(52601, 1339, 14, 'Ստեղծել նոր խնդիր/հարց'),
(52602, 1340, 14, 'Գրանցել նոր Պացիենտ/ՀԻվանդ'),
(52603, 1342, 14, 'Ստեղծել արտաքին պորտալի նոր լիազորություններ/մանդատներ'),
(52604, 1343, 14, 'Ստեղծել ներքին պորտալի նոր լիազորություններ/մանդատներ'),
(52605, 1344, 14, 'Ստեղծել ՀԻվանդի/Պացիենտի գրառում'),
(52606, 1345, 14, 'Ստեղծում է SSL Լիազորագրեր և Սերվերի հավաստագրեր'),
(52607, 1346, 14, 'Ստեղծել այց'),
(52608, 1347, 14, 'Ստեղծված է'),
(52609, 1348, 14, 'Էքսպորտ/արտահանման  ֆայլի ստեղծում'),
(52610, 1351, 14, 'Ստեղծող'),
(52611, 1352, 14, 'կրեդիտ/վարկ'),
(52612, 1353, 14, 'վարկային քարտ'),
(52613, 1354, 14, 'Վարկեր/վարկավորել'),
(52614, 1356, 14, 'Չափանիշներ'),
(52615, 1357, 14, 'Խորվաթերեն'),
(52616, 1358, 14, 'Քրոնիկ հիվանդություն /աղիների քրոնիկ բորբոքային հիվանդություն/'),
(52617, 1359, 14, 'Քրոնիկ հիվանդություն /աղիների քրոնիկ բորբոքային հիվանդություն/'),
(52618, 1360, 14, 'CSV֊ի արտահանում'),
(52619, 1361, 14, 'CSV ֆայլ'),
(52620, 1363, 14, 'խոր/մմ'),
(52621, 1364, 14, 'Կուբանցի'),
(52622, 1365, 14, 'Գումարը տասնորդական միավորներով'),
(52623, 1366, 14, 'Տասնորդական ստորակետի սիմվոլ'),
(52624, 1367, 14, 'Արժույթի ցուցիչ'),
(52625, 1368, 14, 'Գումարի հազարյակի բաժանիչ'),
(52626, 1369, 14, 'Ներկայիս/ Ընթացիկ /սույն'),
(52627, 1370, 14, 'Ալկոհոլի օգտագործման հակումը ներկայում'),
(52628, 1371, 14, 'Ընթացիկ/սույն խորհրդատվություն'),
(52629, 1372, 14, 'Սույն ափանիշը'),
(52630, 1373, 14, 'Ընթացիկ օրն ընդգծելու գույն'),
(52631, 1374, 14, 'Այս պահի դրությամբ/ներկայումս ծխում է ամեն օր'),
(52632, 1375, 14, 'Ֆայլի ներկայիս անունը փոխարինվել է ֊ով'),
(52633, 1376, 14, 'Սույն վանդականիշը'),
(52634, 1377, 14, 'Ներկայիս գտնվելու վայրը'),
(52635, 1378, 14, 'Ներկայիս/ներկա պահին ընդունվող դեղորայքը'),
(52636, 1379, 14, 'Սույն գաղտնաբառը'),
(52637, 1380, 14, 'Սույն պացիենտը'),
(52638, 1382, 14, 'Ընդունված հանգստացնող դեղամիջոցները'),
(52639, 1383, 14, 'Ներկայումս չի ծխում ամեն օր'),
(52640, 1386, 14, 'Ընթացիկ գործունեությունը/Սույն գործողությունը'),
(52641, 1388, 14, 'Ներկա պահին օգնություն չի ցուցաբերվում'),
(52642, 1389, 14, 'Քուշինգի սինդրում'),
(52643, 1393, 14, 'Օգտվողի  մուտք'),
(52644, 1394, 14, 'Օգտվողի  աղյուսակ'),
(52645, 1396, 14, 'CVX կոդ'),
(52646, 1397, 14, 'CVX կոդի ցուցադրում'),
(52647, 1398, 14, 'CVX պատվաստում'),
(52648, 1399, 14, 'Շրջան / ցիկլ'),
(52649, 1400, 14, 'Ցիտոխրոմ P450'),
(52650, 1401, 14, 'Ցիտոխրոմ P451 գործոն'),
(52651, 1402, 14, 'Ցիտոխրոմ P451 զեկույց'),
(52652, 1403, 14, 'Չեխերեն'),
(52653, 1404, 14, 'D'),
(52654, 1407, 14, 'Ծննդյան  ամսաթիվ'),
(52655, 1408, 14, 'առօրյա / ամեն օր'),
(52656, 1409, 14, 'օրական/ամենօրյա  գրանցում'),
(52657, 1410, 14, 'Դանիական'),
(52658, 1411, 14, 'Նմանատիպ տվյալ արդեն առկա է  տվյալների բազայում․ փոխեք կոդը և/կամ նկարագրությունը'),
(52659, 1412, 14, 'Նմանատիպ տվյալ արդեն առկա է  տվյալների բազայում․ փոխեք հաստատուն անվանումը'),
(52660, 1413, 14, 'Տվյալների սյունակ'),
(52661, 1416, 14, 'Ամսաթվի սխալ'),
(52662, 1420, 14, 'Տվյալների տիպ'),
(52663, 1421, 14, 'Տվյալների բազա'),
(52664, 1422, 14, 'Տվյալների բազան տեղադրված չէ'),
(52665, 1423, 14, 'Տվյալների բազայի սխալ/ ուղղում'),
(52666, 1424, 14, 'Տվյալների բազայի հաղորդագրություն'),
(52667, 1425, 14, 'Տվյալների բազայի թարմացումն ավարտված է'),
(52668, 1426, 14, 'Տվյալների սյուները պետք է համարակալված լինեն 1-999 թվերի միջակայքում'),
(52669, 1427, 14, 'Տվյալ / Ամսաթիվ'),
(52670, 1428, 14, 'ԱՄՍԱԹԻՎ'),
(52671, 1431, 14, 'Ամսաթվի կառավարում'),
(52672, 1432, 14, 'Նմուշի վերցման ամսաթիվ և ժամ'),
(52673, 1433, 14, 'Սույն հետազոտության ամսաթիվն ու ժամը'),
(52674, 1435, 14, 'Բիոնյութի վերցման ամսաթիվն ու ժամը'),
(52675, 1436, 14, 'Ամսաթիվը չի կարող այսօրվանից բարձր լինել'),
(52676, 1437, 14, 'Նախնապես տրամադրված հակաբեղմնավորիչ ծառայության ամսաթիվ'),
(52677, 1438, 14, 'Ստեղծման ամսաթիվ'),
(52678, 1439, 14, 'Մահվան ամսաթիվ'),
(52679, 1440, 14, 'Ոչնչացման / ջնջման ամսաթիվ'),
(52680, 1441, 14, 'Ամսաթվի ցուցադրման ֆորմատ'),
(52681, 1442, 14, '"Այցի ավարտի" ասմաթվի ֆորմատը վավեր չէ'),
(52682, 1443, 14, '"Այցի սկիզբ" ասմաթվի ֆորմատը վավեր չէ'),
(52683, 1444, 14, '"Հաջորդ այցի" ասմաթվի ֆորմատը վավեր չէ'),
(52684, 1445, 14, '"Չի տեսնվել սկսած տտ-աա-օօ֊ից " ասմաթվի ֆորմատը վավեր չէ'),
(52685, 1446, 14, '"տտ-աա-օօ֊ից ի վեր տեսնվել է" ասմաթվի ֆորմատը վավեր չէ'),
(52686, 1447, 14, 'Պատվաստման վերաբերյալ տրամադրված տեղեկանքի ամսաթիվ'),
(52687, 1448, 14, 'Կոդի ամսաթիվը բացակայում է '),
(52688, 1449, 14, 'Ասմաթվի հիմնական չափանիշներ'),
(52689, 1450, 14, 'Բանկային դեպոզիտի/ավանդի ամսաթիվ /տտ-աա-օօ/'),
(52690, 1451, 14, 'Վճարաման ամսաթիվ'),
(52691, 1452, 14, 'Ծննդյան ամսաթիվ'),
(52692, 1453, 14, 'Ծննդյան ամսաթիվ'),
(52693, 1454, 14, 'Ծննդյան ամսաթիվ'),
(52694, 1455, 14, 'Մուտքի ամսաթիվ'),
(52695, 1456, 14, 'Վնասվածքն ստանալու ամսաթիվ'),
(52696, 1458, 14, 'Վճարաման ամսաթիվ /տտ-աա-օօ/'),
(52697, 1459, 14, 'Ուղեգրի տրամադրման ամսաթիվ'),
(52698, 1460, 14, 'Պատասխանի տրամադրման ամսաթիվ'),
(52699, 1462, 14, 'Բուժօգնության տրամադրման ամսաթիվ'),
(52700, 1463, 14, 'Ծառայության տրամադրման ամսաթիվ'),
(52701, 1464, 14, 'Ծառայության տրամադրման ամսաթիվ'),
(52702, 1465, 14, 'Ծառայության տրամադրման ամսաթիվ /տտ-աա-օօ/'),
(52703, 1466, 14, 'Ծառայության տրամադրման ամսաթիվ։'),
(52704, 1467, 14, 'Ստորագրման  մասաթիվ'),
(52705, 1469, 14, 'Սույն նշանակման  ամսաթիվը'),
(52706, 1470, 14, 'Սույն հաշվետվության  ամսաթիվը'),
(52707, 1471, 14, 'Պատվաստումների Տեղեկատվական Հայտարարության/Հաշվետվության  ամսաթիվ'),
(52708, 1472, 14, 'Նշանակման ամսաթիվ'),
(52709, 1475, 14, 'ամսաթվի սելեկտոր/ընտրություն'),
(52710, 1476, 14, 'Ուղարկման ամսաթիվ'),
(52711, 1477, 14, 'Հաղորդագրության ուղարկման ամսաթիվ / ուղարկված հաղորդագրության ամսաթիվ'),
(52712, 1479, 14, 'Ամսաթվի արժեքը չպետք է դատարկ լինի'),
(52713, 1480, 14, 'Ամսաթիվ / այց․'),
(52714, 1481, 14, 'Ամսաթիվ / Գրառում'),
(52715, 1482, 14, 'Վերջին ամսաթիվ / գրառում'),
(52716, 1483, 14, 'Ամսաթիվ / ժամ'),
(52717, 1484, 14, 'Ամսաթիվ։'),
(52718, 1485, 14, 'Հին հաղորդագրությունների մատյան'),
(52719, 1486, 14, 'Օր'),
(52720, 1487, 14, 'օր'),
(52721, 1489, 14, 'Օրվա դիտարկում'),
(52722, 1490, 14, 'Օր(եր)'),
(52723, 1491, 14, 'Օր(եր) Երկ֊Ուրբ'),
(52724, 1492, 14, 'օրեր'),
(52725, 1493, 14, 'Օրեր'),
(52726, 1494, 14, 'օրեր առաջ'),
(52727, 1495, 14, 'Բաց թողնված  օրեր ու ծրագրեր'),
(52728, 1496, 14, 'Նախորդ հանդիպումից անցած օրեր'),
(52729, 1497, 14, 'Բաց թողնված  օրեր'),
(52730, 1498, 14, 'Սյունակումեղած օրերի քանակը։'),
(52731, 1500, 14, 'Օրեր/Սյուն․'),
(52732, 1501, 14, 'ՏԲ֊ն տեղադրված է'),
(52733, 1502, 14, 'ՏՏ/ԱԱ/ՕՕ'),
(52734, 1503, 14, 'Նույնականացման կրկնության կանխում'),
(52735, 1504, 14, 'Ապանույնականացման պրոցեսն ավարտված է'),
(52736, 1505, 14, 'Ապանույնականացման պրոցեսն ընթացքի մեջ է'),
(52737, 1506, 14, 'Ապանույնականացման պրոցեսն սկսված է և շարունակվում է հետին պլանում'),
(52738, 1507, 14, 'Հնարավոր չէ լրացնել ապանույնականացման տվյալները'),
(52739, 1508, 14, 'Ապանույնականացման տվյալները կպահպանվեն ֊ում'),
(52740, 1509, 14, 'Թմրանյութերի Դեմ Պայքարի ԿառավարումՎարչություն'),
(52741, 1511, 14, 'Խուլ'),
(52742, 1512, 14, 'Ճշգրտված ինֆորմացիա'),
(52743, 1515, 14, 'Դեկ․'),
(52744, 1516, 14, 'ՎԱԽՃԱՆՎԱԾ / ՄԱՀԱՑԱԾ'),
(52745, 1517, 14, 'Դեկտեմբեր'),
(52746, 1520, 14, 'Նվազեցում / Նվազելի'),
(52747, 1521, 14, 'Նվազեցման կատարում'),
(52748, 1522, 14, 'Սկզբնական տարբերակ'),
(52749, 1523, 14, 'Սկզբնական տարբերակի օրացույցի տեսք'),
(52750, 1524, 14, 'Այցի սկզբնական տարբերակի ֆորմայի ID'),
(52751, 1526, 14, 'Ծառայության սկզբնական տարբերակ'),
(52752, 1527, 14, 'Սկզբնական լեզու'),
(52753, 1528, 14, 'Հիմնական լեզու․ եթե այլ լեզու թույլատրված կամ ընտրված չէ'),
(52754, 1529, 14, 'Հիմնական ցանկ /գրել, ավելացնել ըստ ցանկության/'),
(52755, 1530, 14, 'Հիմնական մեթոդ'),
(52756, 1531, 14, 'Գաղտնաբառի վավերականության օրը  ըստ նախնականի'),
(52757, 1532, 14, 'Գաղտնաբառի վավերականության ժամկետն օրերով ըստ նախնականի'),
(52758, 1533, 14, 'Պացիենտի երկիրը'),
(52759, 1536, 14, 'Մասնագետ'),
(52760, 1537, 14, 'Միջակայք'),
(52761, 1538, 14, 'Այցի պատճառը'),
(52762, 1540, 14, 'Կարգավորումներ'),
(52763, 1541, 14, 'Պացիենտի ցանկում "Նոր պատուհան"֊ի մակնշման վանդակի կարգավիճակ'),
(52764, 1542, 14, 'Նմուշ'),
(52765, 1546, 14, 'Չափման միավորը'),
(52766, 1547, 14, 'Նշանակությունը'),
(52767, 1548, 14, 'Պահեստ'),
(52768, 1549, 14, 'Գործընկեր X12'),
(52769, 1550, 14, 'Նախնական / Գլոբալ'),
(52770, 1551, 14, 'Ջնջել'),
(52771, 1552, 14, 'ջնջել'),
(52772, 1554, 14, 'Ջնջել'),
(52773, 1555, 14, 'Ջնջել'),
(52774, 1556, 14, 'Ջնջել կատեգորիաները ID-ներով '),
(52775, 1557, 14, 'Ջնջել կատեգորիան'),
(52776, 1560, 14, 'Ջնջել խումբը'),
(52777, 1561, 14, 'Ջնջել ցանկը'),
(52778, 1562, 14, 'Ջնջել էջերը'),
(52779, 1563, 14, 'Ջնջել Պացիենտին, Հանդիպումը, Ձևը, Խնդիրը, Փաստաթուղթը, Վճարումը, հաշիվը կամ գործարքը'),
(52780, 1565, 14, 'Ջնջել տողը'),
(52781, 1566, 14, 'Ջնջել ընտրված կետերը'),
(52782, 1568, 14, 'Ջնջված է'),
(52783, 1569, 14, 'Ջնջել սույն փաստաթուղթը'),
(52784, 1570, 14, 'Ջնջել սույն ձևաչափը'),
(52785, 1571, 14, 'Ջնջել սույն գրառումը'),
(52786, 1572, 14, 'Ջնջված է'),
(52787, 1573, 14, 'Ջնջված է'),
(52788, 1575, 14, 'Հնարավոր չէ չեղարկել այս իրադարձության հեռացումը․ ջնջելուց հետո հնարավոր չէ այն վերականգնել։  Վստա՞հ եք, որ ուզում եք ջնջել սույն իրադարձությունը'),
(52789, 1582, 14, 'Անձնական տվյալներ'),
(52790, 1583, 14, 'Անձնական տվյալներ (նշել, ավելացնել ըստ ցանկության)'),
(52791, 1585, 14, 'Անձնական տվյալների ֆիլտրման չափանիշներ'),
(52792, 1586, 14, 'Անձնական տվյալների հասանելությունն առկա չէ'),
(52793, 1587, 14, 'Անձնական տվյալների հասանելությունն առկա չէ'),
(52794, 1589, 14, 'Մերժված է'),
(52795, 1590, 14, 'Ատամնաբուժություն / ստոմատոլոգիա'),
(52796, 1591, 14, 'Ատամնաբուժական / Ստոմատոլոգիական խնդիրների ցանկ'),
(52797, 1592, 14, 'Ատամնաբուժական / Ստոմատոլոգիական խնդիրներ'),
(52798, 1593, 14, 'Կախվածության մոդուլներ'),
(52799, 1594, 14, 'Կախվածության  խնդիրներ'),
(52800, 1596, 14, 'Դեպոզիտի / ավանդի ամսաթիվ'),
(52801, 1597, 14, 'Դեպոզիտի / ավանդի ամսաթիվը չի կարօղ այսօրվանից բարձր լինել'),
(52802, 1598, 14, 'Դեպոզիտի ամսաթիվ։'),
(52803, 1599, 14, 'Ճնշված / իջեցված'),
(52804, 1600, 14, 'Դեպրեսիա /ընկճվածություն'),
(52805, 1602, 14, 'Նկարագրություն'),
(52806, 1603, 14, 'նկարագրություն'),
(52807, 1605, 14, 'Հրապարակման նկարագրություն'),
(52808, 1606, 14, 'Այս միջամտության նարագիրը կամ արդյունքի կոդը'),
(52809, 1607, 14, 'Նկարագրության թարգմանություն'),
(52810, 1608, 14, 'Ֆայլի նախընտրելի անվանումը'),
(52811, 1609, 14, 'Նշանակման վայր'),
(52812, 1611, 14, 'Ոչնչացնել փաթեթը'),
(52813, 1612, 14, 'Ոչնչացնել'),
(52814, 1613, 14, 'Ոչնչացված է'),
(52815, 1614, 14, 'Ոչնչացված դեղամիջոցներ'),
(52816, 1615, 14, 'Դեղերի ոչնչացման հաշվետվություն'),
(52817, 1616, 14, 'Մանրամասն'),
(52818, 1617, 14, 'Մանրամասներ'),
(52819, 1619, 14, 'Նորմայի շարունակական շեղում / Զարգացող խանգարում'),
(52820, 1620, 14, 'Դիաբետ / Շաքարախտ'),
(52821, 1621, 14, 'Շաքարային դիաբետ'),
(52822, 1622, 14, 'Դաիբետ։ Արյան ճնշման հսկողություն  (CQM)'),
(52823, 1623, 14, 'Դիաբետ։ Աչքերի հետազոտություն'),
(52824, 1624, 14, 'Դիաբետ։ Աչքերի հետազոտություն  (CQM)'),
(52825, 1625, 14, 'Դիաբետ։ Ոտնաթաթի հետազոտություն'),
(52826, 1626, 14, 'Դիաբետ։ Ոտնաթաթի հետազոտություն (CQM)'),
(52827, 1627, 14, 'Դիաբետ: HbA1c Poor Control (CQM)'),
(52828, 1628, 14, 'Դիաբետ: Հեմոգլոբին A1C'),
(52829, 1629, 14, 'Դիաբետ: Ցածր խտության լիպոպրոտեինի հսկողություն  (CQM)'),
(52830, 1630, 14, 'Դիաբետ: Մեզի միկրոալբումին'),
(52831, 1631, 14, 'Ախտ֊ում'),
(52832, 1633, 14, 'Ախտորոշում'),
(52833, 1634, 14, 'Ախտորոշման կոդ'),
(52834, 1635, 14, 'Ախտորոշման կոդեր'),
(52835, 1636, 14, 'Ախտորոշման ամսաթիվ'),
(52836, 1637, 14, 'Ախտորոշումը  պետք է կոդավորվի՝ այցելության  հետ կապելու համար'),
(52837, 1638, 14, 'Ախտորոշման անվանում'),
(52838, 1639, 14, 'Ախտորոշման հաշվետվություն'),
(52839, 1642, 14, 'Ախտորոշման անունը'),
(52840, 1643, 14, 'Ախտորոշում։'),
(52841, 1644, 14, 'Ախտորոշում։ '),
(52842, 1645, 14, 'Ախտորոշիչ հետազոտություններ'),
(52843, 1646, 14, 'Դիալիզ'),
(52844, 1647, 14, 'Պարկուճներ / կափարիչներ'),
(52845, 1648, 14, 'Փորլուծություն'),
(52846, 1650, 14, 'Թելադրանք'),
(52847, 1651, 14, 'Թելադրանք։ '),
(52848, 1652, 14, 'Դուք ստացե՞լ եք HIPAA ծանուցման կրկնօրինակը'),
(52849, 1653, 14, 'Տարածվել'),
(52850, 1654, 14, 'Թվային ստորագրությամբ'),
(52851, 1657, 14, 'Ուղարկել նամակ'),
(52852, 1663, 14, 'Ղեկավարի ազգանունը'),
(52853, 1665, 14, 'Անաշխատունակություն / հաշմանդամություն'),
(52854, 1666, 14, 'Կասեցնել / անջատել'),
(52855, 1667, 14, 'Անջատել օրացույցը'),
(52856, 1668, 14, 'Անջատել/կասեցնել քարտի հետևողականության ֆունկցիան'),
(52857, 1669, 14, 'Անջատել պատվաստումների ֆունկցիան'),
(52858, 1670, 14, 'Անջատել կենսական նշանակության օրգանների հին չափման ձևը'),
(52859, 1672, 14, 'Անջատել phpMyAdmin'),
(52860, 1673, 14, 'Անջատել դեղատոմսերի ֆունկցիան'),
(52861, 1674, 14, 'Անջատել (Օգտվողի) Խմբերը'),
(52862, 1675, 14, 'անջատված/կասեցված է'),
(52863, 1676, 14, 'Անջատված/կասեցված է'),
(52864, 1677, 14, 'Առողջապահական Պլանավորման Մեծ Խմբի մինչև 65 տարեկան հաշմանդամ շահառուներ'),
(52865, 1679, 14, 'Հեռացնել'),
(52866, 1680, 14, 'Հեռացված ՝'),
(52867, 1681, 14, 'Արտահոսք'),
(52868, 1682, 14, 'Արտահոսք միզուկից / Միզուկի արտազատուկ'),
(52869, 1684, 14, 'Դուրս է գրվել առողջացումով'),
(52870, 1685, 14, 'Դուրս է գրվել առողջացումով։'),
(52871, 1688, 14, 'Դուրս է գրվել'),
(52872, 1689, 14, 'Հրապարակված/Բացահայտված տեղեկատվություն'),
(52873, 1690, 14, 'Հրապարակման տեսակը'),
(52874, 1691, 14, 'Հրապարակման տեսակները'),
(52875, 1692, 14, 'Հրապարակումներ'),
(52876, 1694, 14, 'Զեղչ'),
(52877, 1695, 14, 'Զեղչի գումարը'),
(52878, 1696, 14, 'Զեղչի մակարդակը'),
(52879, 1697, 14, 'Զաղչի տոկոսային հարաբերությունը'),
(52880, 1698, 14, 'Զեղչը որպես դրամական առժեք'),
(52881, 1699, 14, 'Զեղչերը դրամարկղային ձևակերպումներում հաշվարկվում են ոչ թե տոկոսային, այլ  գումարային արժեքով'),
(52882, 1700, 14, 'Առանձին արդյունք'),
(52883, 1701, 14, 'Հիվանդություն'),
(52884, 1702, 14, 'Հոդախախտ'),
(52885, 1703, 14, 'Ուղրկ․ #'),
(52886, 1704, 14, 'Առաքում / ուղարկում'),
(52887, 1705, 14, 'Ստացած փաստաթղթի առաքում/ուղարկում'),
(52888, 1706, 14, 'Տրամադրված է/Բաշխված է/ ելքագրված է'),
(52889, 1707, 14, 'Ժողովրդագրական/անձնական տվյալների էջում ցուցադրել լրացման հրահանգներ'),
(52890, 1708, 14, 'Ցուցադրել փաստաթղթերը'),
(52891, 1709, 14, 'Իրադարձության ամսաթիվը ցուցադրե՞լ վանդակում'),
(52892, 1711, 14, 'Քանի՞ իրադարձություն ցուցադրել'),
(52893, 1713, 14, 'Ցուցադրե՞լ  գտնվելու վայրը բլոկում'),
(52894, 1714, 14, 'Ցուցադրել անունը'),
(52895, 1715, 14, 'Ցուցադրե՞լ  օրացույցը'),
(52896, 1718, 14, 'Ցուցադրե՞լ  այսօրվա իրադարձությունները բլոկում'),
(52897, 1719, 14, 'Ցուցադրե՞լ  թեման / բաժինը բլոկում'),
(52898, 1720, 14, 'Ցուցադրե՞լ  գալիք/առաջիկա իրադարձությունները բլոկում'),
(52899, 1721, 14, 'Ցուցադրված սյունակներ'),
(52900, 1722, 14, 'Ցուցադրված է ամենավերջին հետևյալ  հրապարակումները'),
(52901, 1723, 14, 'Ցուցադրված է ամենավերջին հետևյալ  գրառումները'),
(52902, 1724, 14, 'Ցուցադրված է ամենավերջին հետևյալ  գրառումները։'),
(52903, 1725, 14, 'Տրամադրում /Բաշխում'),
(52904, 1726, 14, 'Տրամադրում /Բաշխում'),
(52905, 1727, 14, 'Դիստրիբյուտոր'),
(52906, 1729, 14, 'Դիվերտիկուլիտ'),
(52907, 1730, 14, 'Դիվերտիկուլիտի վիրահատություն'),
(52908, 1731, 14, 'Դիվերտիկուլիտ'),
(52909, 1732, 14, 'Դիվերտիկուլիտի վիրահատություն'),
(52910, 1733, 14, 'Բաժանված/Ամուսնալուծված'),
(52911, 1734, 14, 'Գլխապտույտ։'),
(52912, 1735, 14, 'Չփոխե՛լ'),
(52913, 1737, 14, 'Չցուցադրել NewCrop վերբեռնած  Ալլերգիան'),
(52914, 1739, 14, 'Չցուցադրել NewCrop վերբեռնած  Դեղորայքը'),
(52915, 1742, 14, 'Չցուցադրել օրացույցը'),
(52916, 1744, 14, 'Չգույքագրել և չվաճառել որևէ ապրանք'),
(52917, 1745, 14, 'Պացիենտի գրառումների համար լիազորություն չի պահանջվում'),
(52918, 1746, 14, '"Չվերակենդանացնել" հրաման'),
(52919, 1747, 14, 'չպահպանել'),
(52920, 1748, 14, 'չփոխարինե՛լ'),
(52921, 1749, 14, 'ոչինչ չանել'),
(52922, 1751, 14, 'Իսկապե՞ս ուզում եք ջնջել'),
(52923, 1752, 14, 'Իսկապե՞ս ուզում եք ջնջել ըտրվածը'),
(52924, 1753, 14, 'Իսկապե՞ս ուզում եք ջնջել խումբը'),
(52925, 1754, 14, 'Իսկապե՞ս ուզում եք ջնջել'),
(52926, 1755, 14, 'Շարունակե՞լ'),
(52927, 1756, 14, 'Ջնջե՞լ սա'),
(52928, 1757, 14, 'Ջնջե՞լ'),
(52929, 1758, 14, 'Ջնջե՞լ այս գրառումը'),
(52930, 1759, 14, 'Շարունակե՞լ  նոր պացիենտի ավելացումը'),
(52931, 1760, 14, 'Շարունակե՞լ  նոր անվանումով'),
(52932, 1761, 14, 'Ցանկանո՞ւմ եք ընդմիշտ հեռացնել այս պատվաստման գրառումը'),
(52933, 1762, 14, 'Ծննդյան Օ/Ա/Տ'),
(52934, 1763, 14, 'Ծննդյան ամսաթիվը բացակայում է․ եթե հնարավոր է, նշեք այն'),
(52935, 1764, 14, 'Բժ․'),
(52936, 1765, 14, 'Բժիշկ'),
(52937, 1766, 14, 'Բժիշկ։'),
(52938, 1767, 14, 'Բժշկի ազգանունը և ստորագրությունը'),
(52939, 1768, 14, 'Փաստաթուղթ'),
(52940, 1769, 14, 'փաստաթուղթ'),
(52941, 1770, 14, 'Փաստաթղթի կատեգորիան'),
(52942, 1771, 14, 'Լաբորատոր հետազոտությունների արդյունքների փաստաթղթերի կատեգորիա առկա չէ'),
(52943, 1772, 14, 'Փաստաթղթերի կատեգորիայի անվանում լաբորատոր հետազոտությունների  էլեկտրոնային արդյունքների պահեստի համար'),
(52944, 1775, 14, 'Հնարավոր չէ փաստաթուղթը տեղափոխել Պացիենտի ID  բաժին'),
(52945, 1777, 14, 'Գրանցման ամսաթիվ'),
(52946, 1778, 14, 'Փաստաթղթի ամսաթիվն ու խնդիրները հաջողությամբ թարմացվել են'),
(52947, 1779, 14, 'Փաստաթղթի ID'),
(52948, 1780, 14, 'Փաստաթուղթը տեղափոխվել է նոր կատեգորիա'),
(52949, 1781, 14, 'Փաստաթուղթը տեղափոխվել է Պացիենտի ID  բաժին'),
(52950, 1783, 14, 'Փաստաթուղթն անցել է ամբողջականության/լիարժեքության ստուգում'),
(52951, 1784, 14, 'Փաստաթղթի պահեստավորման մեթոդ'),
(52952, 1785, 14, 'Փաստաթուղթն հաջողությամբ անվանափոխվել է'),
(52953, 1786, 14, 'Փաստաթուղթն հաջողությամբ կցվել է հանդիպմանը'),
(52954, 1788, 14, 'Փաստաթղթի նմուշներ'),
(52955, 1789, 14, 'Փաստաթուղթ(եր)'),
(52956, 1790, 14, 'Փաստաթղթի/նկարի պահուստ'),
(52957, 1791, 14, 'Փաստաթղթեր'),
(52958, 1792, 14, 'Փաստաթղթեր (նշել, ավելացնել ըստ ցանկության)'),
(52959, 1796, 14, 'Չի համապատասխանում PV1 այցի համարին'),
(52960, 1797, 14, 'վավեր չէ'),
(52961, 1798, 14, 'Այստ տիպը/տեսակը թույլատրո՞ւմ է նմանատիպ/իրեն առնչվող կոդեր'),
(52962, 1799, 14, 'Համերկրացի գործընկեր'),
(52963, 1800, 14, 'Չպահպանե՛լ'),
(52964, 1801, 14, 'Չպահպանե՛լ'),
(52965, 1802, 14, 'Չպահպանել փոփոխությունները'),
(52966, 1803, 14, 'Կատարված է'),
(52967, 1804, 14, 'Կատարված է ֊ով'),
(52968, 1805, 14, 'Կատարված է․ հիմա կներբեռնվի'),
(52969, 1806, 14, 'DOS'),
(52970, 1807, 14, 'Դեղաքանակ/դոզավորում'),
(52971, 1809, 14, 'խմբագրման համար կրկնակի սեղմեք'),
(52972, 1810, 14, 'Պատկերի կրկնարտածում /դիպլոպիա/'),
(52973, 1811, 14, 'Ներբեռնել'),
(52974, 1814, 14, 'Ամեն դեպքում/միևնույնն է՝  ներբեռնել'),
(52975, 1815, 14, 'Ներբեռնելով վճարման ֆայլը՝ տեղադրեք այն հաշվապահական հաշվառման մեջ և նշեք որպես վճարված'),
(52976, 1817, 14, 'Ներբեռնել վկայագրերը'),
(52977, 1818, 14, 'Ներբեռնել կոնֆիգուրացիոն/կազմաձևման տվյալները'),
(52978, 1819, 14, 'Ներբեռնել փաստաթուղթ այս Պացիենտի և այցի համար'),
(52979, 1820, 14, 'Ներբեռնել կոդավորված ֆայլ'),
(52980, 1824, 14, 'Ներբեռնել կամ ջնջել Նմուշը'),
(52981, 1825, 14, 'Ներբեռնել կամ PDF ֆորմատով'),
(52982, 1827, 14, 'Ներբեռնել նշված հաշվետվությունները'),
(52983, 1828, 14, 'Գրանցում Բժշկի մոտ'),
(52984, 1829, 14, 'Այցելություն Բժշկին'),
(52985, 1830, 14, 'Բժիշկ'),
(52986, 1831, 14, 'Քաշել՝ տեղափոխելու համար'),
(52987, 1832, 14, 'Միազարձակում'),
(52988, 1833, 14, 'Վարորդական վկայական կամ պետական ID  քարտ'),
(52989, 1834, 14, 'Դեղամիջոց'),
(52990, 1835, 14, 'Դեղորայքի որոնիչ'),
(52991, 1836, 14, 'Դեղամիջոցների ձևերը'),
(52992, 1837, 14, 'Դեղամիջոցի ID֊ն բացակայում է'),
(52993, 1838, 14, 'Դեղամիջոցի ընդունման հաճախականություն'),
(52994, 1839, 14, 'Դեղորայքի հաշվառում'),
(52995, 1840, 14, 'Դեղամիջոցի անվանումը'),
(52996, 1841, 14, 'Դեղամիջոցի կիրառման մեթոդը'),
(52997, 1845, 14, 'Դեղամիջոցի չափման միավորը'),
(52998, 1846, 14, 'Դեղորայք'),
(52999, 1847, 14, 'Դեղորայք և ապրանքներ'),
(53000, 1848, 14, 'Բերանի չորություն'),
(53001, 1849, 14, 'DSMIV ախտորոշում'),
(53002, 1850, 14, 'Դիֆթերիա, փայտացում 1'),
(53003, 1851, 14, 'Դիֆթերիա, փայտացում 2'),
(53004, 1852, 14, 'Դիֆթերիա, փայտացում 3'),
(53005, 1853, 14, 'Դիֆթերիա, փայտացում 4'),
(53006, 1854, 14, 'Դիֆթերիա, փայտացում 5'),
(53007, 1855, 14, 'Դիֆթերիա, փայտացում, կապույտ հազ 1'),
(53008, 1856, 14, 'Դիֆթերիա, փայտացում, կապույտ հազ 2'),
(53009, 1857, 14, 'Դիֆթերիա, փայտացում, կապույտ հազ 3'),
(53010, 1858, 14, 'Դիֆթերիա, փայտացում, կապույտ հազ 4'),
(53011, 1859, 14, 'Դիֆթերիա, փայտացում, կապույտ հազ 5'),
(53012, 1860, 14, 'Պարտքը'),
(53013, 1861, 14, 'Պարտքի վճարման ամսաթիվ'),
(53014, 1862, 14, 'Պարտքի վճարման ամսաթիվ աա/օօ/տտ  կամ տտ/աա/օօ'),
(53015, 1863, 14, 'Պարտքի վճարման ամսաթիվ։'),
(53016, 1868, 14, 'Պարտքի կարգավիճակի թարմացում'),
(53017, 1869, 14, 'LibreEHR տվյալների բազայի դատարկում'),
(53018, 1870, 14, 'LibreEHR  վեբ֊ուղեցույցի կաղապարի դատարկում'),
(53019, 1871, 14, 'phpGACL տվյալների բազայի դատարկում'),
(53020, 1872, 14, 'phpGACL  վեբ֊ուղեցույցի կաղապարի դատարկում'),
(53021, 1873, 14, 'SQL-Ledger տվյալների բազայի դատարկում'),
(53022, 1874, 14, 'SQL-Ledger վեբ֊ուղեցույցի կաղապարի դատարկում'),
(53023, 1875, 14, 'Կրկնօրինակման ստուգում'),
(53024, 1876, 14, 'Նույնականացման/ID առցանց/օնլայն կրկնօրինակում'),
(53025, 1877, 14, 'Կրկնակի անուն տողում'),
(53026, 1878, 14, 'ԿՐԿՆՕՐԻՆԱԿՄԱՆ ՆԱԽԱԶԳՈՒՇԱՑՈՒՄ'),
(53027, 1879, 14, 'Մշտական լիազորագիր'),
(53028, 1880, 14, 'տևողություն'),
(53029, 1881, 14, 'Տևողություն'),
(53030, 1882, 14, 'Հոլանդական/Հոլանդերեն'),
(53031, 1883, 14, 'Dx Rep'),
(53032, 1884, 14, 'Դիսֆագիա /կլման խանգարում, դժվարություն/'),
(53033, 1885, 14, 'Հևոց։'),
(53034, 1886, 14, 'Անմիզություն /դժվարին, ցվոտ միզարձակում/'),
(53035, 1888, 14, 'Էլեկտրոնային դեղատոմս'),
(53036, 1889, 14, 'Էլեկտրոնային հաշվետվություն'),
(53037, 1890, 14, 'Էլեկտրոնային դեղատոմս'),
(53038, 1892, 14, 'Էլ․ դեղատոմսի վերահաստատում'),
(53039, 1893, 14, 'Յուրաքանչյուր ստացող իր հաղորդագրությունը պետք է սահմանի որպես կատարված'),
(53040, 1894, 14, 'Վաղ կրկնություն (< 2 ամս.)'),
(53041, 1895, 14, 'Ականջներ'),
(53042, 1896, 14, 'ԷՍԳ Էլեկտրաստրտագրություն'),
(53043, 1897, 14, 'Էլ․ պահանջներ'),
(53044, 1898, 14, 'Այտուց'),
(53045, 1900, 14, 'ԷՏՓ /Էլ․ տվյալների փոխանակման/ պատմություն'),
(53046, 1902, 14, 'ԷՏՓ-271 ֆայլի բեռնում'),
(53047, 1903, 14, 'ԷՏՓ-271 պատասխան ֆայլի բեռնում'),
(53048, 1904, 14, 'Խմբագրել'),
(53049, 1905, 14, 'խմբագրել'),
(53050, 1906, 14, 'Խմբագրել ալերգիան'),
(53051, 1907, 14, 'Խմբագրել կատեգորիան'),
(53052, 1908, 14, 'Խմբագրել սահմանումները'),
(53053, 1909, 14, 'Խմբագրել սահմանումները'),
(53054, 1910, 14, 'Խմբագրել ֊ի ախտորոշումը');
INSERT INTO `lang_definitions` VALUES
(53055, 1911, 14, 'Խմբագրել հրապարակումը'),
(53056, 1912, 14, 'Խմբագրել ծառայությունները'),
(53057, 1913, 14, 'Խմբագրել ծառայությունը'),
(53058, 1914, 14, 'Խմբագրել ծառայության մասին տեղեկատվությունը'),
(53059, 1915, 14, 'Խմբագրել Հատուկ Օգտվողի ծառայությունների տեղեկատվությունը'),
(53060, 1916, 14, 'Խմբագրել ֊ի ֆայլը'),
(53061, 1917, 14, 'Խմբագրել խարուցվածքը/ձևաչափը'),
(53062, 1918, 14, 'Խմբագրել գլոբալ պարամետրերը'),
(53063, 1919, 14, 'Խմբագրում չի թույլատրվում'),
(53064, 1920, 14, 'Խմբագրել դասավորությունը'),
(53065, 1921, 14, 'Խմբագրել ցանկը'),
(53066, 1922, 14, 'Խմբագրել վճարումը'),
(53067, 1923, 14, 'Խմբագրել կառուցվածքը'),
(53068, 1924, 14, 'Խմբագրել օգտվողի/օգտատիրոջ տվյալները'),
(53069, 1925, 14, 'Խմբագրել օգտվողի/օգտատիրոջ պարամետրերը'),
(53070, 1926, 14, 'Խմբագրեք ձեր մուտքագրած տվյալները'),
(53071, 1927, 14, 'Խմբագրման ձախողում'),
(53072, 1928, 14, 'Կրթություն'),
(53073, 1929, 14, 'Կրթության տարեթիվ'),
(53074, 1930, 14, 'Կրթական նյութեր'),
(53075, 1932, 14, 'Փաստացի /ուժի մեջ մտնելու/ ամսաթիվը'),
(53076, 1934, 14, 'Արդյունավետություն'),
(53077, 1935, 14, 'Գործատուի նույնականացման համարը'),
(53078, 1936, 14, 'Սերմնաժայթքում'),
(53079, 1937, 14, 'Արմունկ'),
(53080, 1938, 14, 'Արմունկի խնդիրներ'),
(53081, 1939, 14, 'Էլեկտրոնային'),
(53082, 1942, 14, 'Էլեկտրոնային փոխանցումներ'),
(53083, 1943, 14, 'Էլեկտրոնային հաշվետվություններ'),
(53084, 1944, 14, 'Իրավասություն / Պիտանիության ժամկետ'),
(53085, 1945, 14, '270'),
(53086, 1946, 14, 'Ընդունելի պատասխան'),
(53087, 1947, 14, 'Երեխեներին մատակարարվող պատվաստանյութի պիտանիության կարգավիճակը'),
(53088, 1948, 14, 'Պիտանի /ընդունելի'),
(53089, 1949, 14, 'Էլ֊փոստ'),
(53090, 1950, 14, 'Էլ֊փոստ'),
(53091, 1951, 14, 'Էլ֊փոստի հասցե'),
(53092, 1952, 14, 'Էլ֊փոստի հասցեն բացակայում է'),
(53093, 1953, 14, 'Պացիենտին հիշեցումներ ուղարկողի էլ․փոստի հասցեն։ Պացիենտի հիշեցումներին կատարված պատասխանները ուղղվում են այդ հասցեին։ Կարևոր է, որ այդ հասցեն լինի Կլինիկայի դոմենից՝ խուսափելու համար այդ հիշեցում֊նամակների՝ պացիենտի էլ֊փոստի "աղբամանում" հայտնվելուց'),
(53094, 1954, 14, 'Առկա որևէ էլ֊հասցե՝ ադմինիստրատիվ ծանուցումներ ստանալու համար'),
(53095, 1955, 14, 'Առկա որևէ էլ֊հասցե՝ օգտվողի արտակարգ մուտքի ակտիվացման հաղորդագրություն ստանալու համար'),
(53096, 1956, 14, 'Էլ֊փոստի թույլատրություն'),
(53097, 1957, 14, 'Փաթեթի մշակման Էլ․նամակ'),
(53098, 1958, 14, 'Էլ․նամակի ծանուցում'),
(53099, 1959, 14, 'Էլ․նամակի ծանուցման ժամեր'),
(53100, 1960, 14, 'Էլ․նամակի ծանուցման հաշվետվություն'),
(53101, 1961, 14, 'Ուղարկել էլ․նամակ մինչև'),
(53102, 1962, 14, 'Էլ․ նամակ ուղարկողը'),
(53103, 1963, 14, 'Էլ․ նամակն ուղարկված է'),
(53104, 1964, 14, 'Էլ․ նամակն ուղարկված է ֊ին'),
(53105, 1965, 14, 'Էլ․ նամակի թեման'),
(53106, 1966, 14, 'Էլ․նամակի տեքստ․ կիրառվող թեգ։ ***ԱՆՎԱՆՈՒՄ***, այսինքն՝ Հարգելի ***ԱՆՈՒՆ***'),
(53107, 1967, 14, 'Էլ․նամակի տեքստ․ կիրառվող թեգ։ ***ԱՆՎԱՆՈՒՄ***, այսինքն՝ Հարգելի ***ԱՆՈՒՆ***{{Չթարգմանել ***NAME*** այս հիմնանվան տարրերը.}}'),
(53108, 1968, 14, 'Էլ․փոստի փոխանցման մեթոդ'),
(53109, 1969, 14, 'Էլ․փոստն ուղարկված է հետևյալ հասցեներին'),
(53110, 1971, 14, 'Լրացուցիչ կապի միջոց'),
(53111, 1972, 14, 'Լրացուցիչ կապի միջոց'),
(53112, 1973, 14, 'Արտակարգ իրավիճակների հեռախոսահամար'),
(53113, 1974, 14, 'Հարկադրված հակաբեղմնավորում'),
(53114, 1975, 14, 'Արտակարգ իրավիճակների Մուտք'),
(53115, 1976, 14, 'Ընտրված է ACL ԱԻ Մուտքը։ Օգտվողի կարգավիճակը դեռ ակտիվ է։ Ապաակտիվացրեք այն, և կրկին ակտիվացրեք դրա անհրաժեշտության դեպքում։ Այցելեք Ադմինիստրացիա->Օգտատերեր ակտիվացնելու և/կամ ապաակտիվացման համար'),
(53116, 1978, 14, 'ԱԻ Մուտքի էլ․փոստի հասցե'),
(53117, 1979, 14, 'ԱԻ Մուտք ունեցող Օգտատերը համակարգում կարող է անել ամեն ինչ'),
(53118, 1980, 14, 'ԱԻ Հեռախոսահամար'),
(53119, 1981, 14, 'Հուզական/Վարքագծային իրավիճակներ և բարդություններ'),
(53120, 1983, 14, 'Աշխատակից'),
(53121, 1984, 14, 'Աշխատանքի վայրը'),
(53122, 1985, 14, 'Աշխատավայրի հասցեն'),
(53123, 1986, 14, 'Աշխատանքի ընդունման ամսաթիվ'),
(53124, 1987, 14, 'Աշխատավայրի անվանումը'),
(53125, 1988, 14, 'ԴԱՏԱՐԿ'),
(53126, 1989, 14, 'դատարկ'),
(53127, 1990, 14, 'Դատարկ գաղտնաբառ չի թույլատրվում'),
(53128, 1991, 14, '"էլ․փոստի ժամ" ֊ի դատարկ արժեք'),
(53129, 1992, 14, '"էլ․փոստ ուղարկող"֊ի դատարկ արժեք'),
(53130, 1993, 14, '"էլ․փոստի թեմա"֊ի դատարկ արժեք'),
(53131, 1994, 14, '"էլ․փոստի տեքստ" ֊ի դատարկ արժեք'),
(53132, 1995, 14, '"Մասնագետի ազգանուն"֊ի դատարկ արժեք'),
(53133, 1996, 14, '"Գաղտնաբառ"֊ի դատարկ արժեք'),
(53134, 1997, 14, '"SMS հաղորդագրության ժամ"֊ի դատարկ արժեք'),
(53135, 1998, 14, '"SMS հաղորդագրության տեքստ"֊ի դատարկ արժեք'),
(53136, 1999, 14, '"Օգտվողի անուն"֊ի դատարկ արժեք'),
(53137, 2006, 14, 'Միացնել AMC զանգը'),
(53138, 2008, 14, 'Միացնել AMC հաշվետվությունը'),
(53139, 2009, 14, 'Միացնել AMC վերահսկողությունը'),
(53140, 2010, 14, 'Միացնել լրացումների հնարավորությունը'),
(53141, 2011, 14, 'Միացնել ATNA աուդիտը'),
(53142, 2012, 14, 'Միացնել աուդիտի մուտքի կոդավորումը'),
(53143, 2015, 14, 'Միացնել Ավտոմատ Չափման Հաշվարկների (AMC/ԱՉՀ) հաշվետվությունը'),
(53144, 2016, 14, 'Թույլատրել հաճախորդի SSL'),
(53145, 2017, 14, 'Թույլատրել հաճախորդի SSL վկայագրի վավերացումը/սկության ստուգումը'),
(53146, 2019, 14, 'Միացնել Կլինիկական Որոշումների Ընդունման Կանոնները (ԿՈԿ)'),
(53147, 2022, 14, 'Միացնել Կլինիկական Որակի Չափման (ԿՈՉ) Հաշվետվություն'),
(53148, 2023, 14, 'Միացնել pop-up/թռուցիկ կլինիկական հիշեցումներ'),
(53149, 2024, 14, 'Միացնել  կլինիկական հիշեցումների վիդջեթ/Widget'),
(53150, 2025, 14, 'Միացնել CMS Portal /Պորտալը'),
(53151, 2026, 14, 'Միացնել CQM հաշվետվության իկոնավորումը'),
(53152, 2027, 14, 'Միացնել CQM հաշվետվությունը'),
(53153, 2028, 14, 'Ձախ մենյուում, միացնել ԷՏՓ /Էլ․ տվյալների փոխանակման/ պատմությունը'),
(53154, 2030, 14, 'Միացնել/ավելացնել "Վճարումներ" Ձախ մենյուում'),
(53155, 2031, 14, 'Միացնել Hylafax աջակցություն'),
(53156, 2033, 14, 'Միացնել NewCrop erx ներմուծման կարգավիճակի մասին հաղորդագրություն'),
(53157, 2037, 14, 'Միացնել/թույլատրել Լաբորատոր փոխանակում'),
(53158, 2040, 14, 'Միացնել/թույլատրել  SQL SELECT հարցումների գրանցում'),
(53159, 2041, 14, 'Միացնել/թույլատրել  պահեստային կրկնօրինակին առնչվող գործողությունների/ գրանցում'),
(53160, 2043, 14, 'Միացնել/թույլատրել  խառը գործողությունների/ակտիվության գրանցում'),
(53161, 2044, 14, 'Միացնել/թույլատրել  պահանջների գործողությունների/ակտիվության գրանցում'),
(53162, 2045, 14, 'Միացնել/թույլատրել  պացիենտի գրանցման փոփոխությունների գրանցում'),
(53163, 2046, 14, 'Միացնել/թույլատրել ծրագրերի/պլանների  գործունեության/ակտիվության գրանցում'),
(53164, 2047, 14, 'Միացնել/թույլատրել անվտանգության և կառավարման գործունեության գրանցում'),
(53165, 2049, 14, 'Միացնել/թույլատրել NewCrop eRx/էլ․ դեղատոմս/ ծառայություն'),
(53166, 2051, 14, 'Միացնել/ստեղծել  օտարերկրյա հիվանդների պորտալ'),
(53167, 2052, 14, 'Միացնել/ստեղծել  օտարերկրյա հիվանդների պորտալ'),
(53168, 2053, 14, 'Միացնել/ստեղծել ներքին/համերկրացի հիվանդների պորտալ'),
(53169, 2055, 14, 'Միացնել/ստեղծել ներքին/համերկրացի հիվանդների պորտալ'),
(53170, 2056, 14, 'Միացնել  պացիենտի հիշեցումների վիդջեթ/Widget'),
(53171, 2058, 14, 'Միացնել Ավտոմատ Չափման Հաշվարկների (ԱՉՀ) պահանջվող տվյալների հիշեցում'),
(53172, 2061, 14, 'Միացնել սկաները'),
(53173, 2065, 14, 'Միացնել LibreEHR օգնության  LLC Լաբորատոր փոխանակման ծառայությունը'),
(53174, 2066, 14, 'Միացնել Օգտվողի Հավաստագրի իսկության ստուգում'),
(53175, 2067, 14, 'Միացնել ZMG, LLC eRx ծառայություն'),
(53176, 2068, 14, 'Միացված/թույլատրված է'),
(53177, 2070, 14, 'Թույլատրում է հին Վճարումների վահանակում մուտքագրել հաշվի/բիլլինգ կոդեր վճարումներ։ Խորհուրդ չի տրվում․ փոխարենն օգտագործեք Վճարման Թերթիկը'),
(53178, 2071, 14, 'Այց․'),
(53179, 2072, 14, 'Այց/հնդ․'),
(53180, 2073, 14, 'Այցելություն/հանդիպում'),
(53181, 2074, 14, 'Այցելություն/հանդիպում'),
(53182, 2075, 14, 'Այցելություն/հանդիպում '),
(53183, 2076, 14, 'Պացիենտի անհետաձգելի տեղափոխում ստացիոնար կամ ԱԻ բաժին'),
(53184, 2081, 14, 'Այցելության ամսաթիվ'),
(53185, 2086, 14, 'Այցելության ձևեր'),
(53186, 2087, 14, 'Այցելություն առողջության ու վարքագծի գնահատման համար'),
(53187, 2088, 14, 'Այցելությունների ժամանակագրություն'),
(53188, 2089, 14, 'Այցելության  ID'),
(53189, 2090, 14, 'Այցելություն գրիպի խնդրով'),
(53190, 2091, 14, 'Այցելությունների քանակ'),
(53191, 2093, 14, 'Այցելություն բուժքրոջ մոտ՝ դուրսգրման համար'),
(53192, 2094, 14, 'Այցելություն բուժույրական ծառայության համար'),
(53193, 2095, 14, 'Այցելություն էրոթերապիայի համար'),
(53194, 2096, 14, 'Գրասենյակային այցելություն'),
(53195, 2097, 14, 'Ամբուլատոր այց'),
(53196, 2098, 14, 'w/PCP & obgyn ամբուլատոր այց'),
(53197, 2099, 14, 'Այցելության էջի չափեր'),
(53198, 2100, 14, 'Այցելության վճար'),
(53199, 2101, 14, 'Հղիության խորհրդատվության այց'),
(53200, 2102, 14, 'Անհատական պրոֆիլակտիկ բուժզննման այց'),
(53201, 2103, 14, '40 և բարձր տարիքային պրոֆիլակտիկ բուժզննման այց'),
(53202, 2104, 14, 'Խմբային պրոֆիլակտիկ բուժզննման այց'),
(53203, 2105, 14, 'Այլ ծառայությունների պրոֆիլակտիկ բուժզննման այց'),
(53204, 2106, 14, '18 և բարձր տարիքային պրոֆիլակտիկ բուժզննման այց'),
(53205, 2107, 14, 'Հոգեբանի և հոգեբույժի այցելություն'),
(53206, 2108, 14, 'Այցելությունների վիճակագրություն'),
(53207, 2109, 14, 'Այցելության ամփոփում'),
(53208, 2110, 14, 'Այցը կոդավորված է'),
(53209, 2111, 14, 'Այց/Այցելություն'),
(53210, 2112, 14, 'Այցելություն։ Հիվանդի պլանավորված այց ստացիոնար, ամբուլատոր կամ ակնաբուժական բաժանմունք'),
(53211, 2113, 14, 'Այցեր/Այցելություններ'),
(53212, 2114, 14, 'Այցելություններ և դրանց կարգը'),
(53213, 2115, 14, 'Այցելություններ &amp։ կարգեր/ձևեր'),
(53214, 2116, 14, 'Այցերի/Այցելությունների  հասանելիություն թույլատրված չէ'),
(53215, 2117, 14, 'Այցերի/Այցելությունների հաշվետվություն'),
(53216, 2118, 14, 'Այցերի/Այցելությունների բաժին'),
(53217, 2120, 14, 'Կոդավորում'),
(53218, 2121, 14, 'Վերջ/Ավարտ'),
(53219, 2122, 14, 'Վերջ/Ավարտ  (yyyy-mm-dd)/ (տտ-աա-օօ)։ '),
(53220, 2123, 14, 'Ավարտ (ամսաթիվ)'),
(53221, 2124, 14, 'Ավարտ (ամսաթիվ)'),
(53222, 2126, 14, 'Ավարտման ամսաթիվը պետք է  ուշ լինի Սկզբի ամսաթվից'),
(53223, 2127, 14, 'Ավարտ (ամսաթիվ)'),
(53224, 2130, 14, 'Հաշվետվության ավարտ'),
(53225, 2131, 14, 'Ավարտման ժամ'),
(53226, 2133, 14, 'Ծառայության ավարտի ամսաթիվ yyyy-mm-dd'),
(53227, 2135, 14, 'Օրացույցային իրադարձությունների ավարտման ժամ'),
(53228, 2136, 14, 'Արյան՝ նորմայից խիստ շեղում'),
(53229, 2137, 14, 'Էնդոկրին'),
(53230, 2138, 14, 'Էնդոսկոպ'),
(53231, 2141, 14, 'Անգլերեն'),
(53232, 2142, 14, 'Անգլերեն '),
(53233, 2143, 14, 'Անգլերեն (հնդկական)'),
(53234, 2144, 14, 'Անգլերեն (սատնդարտ)'),
(53235, 2145, 14, 'Կոդավորել Hylafax֊ով օգտագործված/կիրառված հրամանը'),
(53236, 2146, 14, 'Համոզվեք, որ LibreEHR֊ը տեղեկատուի մուտքի արտոնություն ունի'),
(53237, 2147, 14, 'Քիթ֊Կոկորդ֊Ականջ/ՔԿԱ դուրսգրում'),
(53238, 2148, 14, 'ՔԿԱ/Քիթ֊Կոկորդ֊Ականջ/ ցավեր'),
(53239, 2149, 14, 'Մուտքագրեք ախտորոշման կոդը՝ բացառելու համար այդ կոդը չպարունակող մնացած հաշիվ֊ապրանքագրերը'),
(53240, 2150, 14, 'Մուտքագրեք/ կատարեք փոփոխություններ և լրացումներ'),
(53241, 2151, 14, 'Նամակի բովանդակությունը/տեքստը մուտքագրեք այստեղ'),
(53242, 2152, 14, 'Մուտքագրեք տվյալների բազայի արմատական/root գաղտնաբառը'),
(53243, 2153, 14, 'Մուտքագրեք տվյալների բազայի արմատական/root օգտանունը/օգտվողի անունը'),
(53244, 2154, 14, 'Մուտքագրեք ախտորոշումը'),
(53245, 2155, 14, 'Մուտքագրեք դեղամիջոցները/դեղորայքը'),
(53246, 2156, 14, 'Մուտքագրեք այցելությունը'),
(53247, 2157, 14, 'Մուտքագրեք այցելության համարը'),
(53248, 2158, 14, 'Մուտքագրեք պատվաստումը'),
(53249, 2159, 14, 'Մուտքագրեք բանալի բառը/կոդը'),
(53250, 2160, 14, 'Մուտքագրեք նոր տվյալ'),
(53251, 2161, 14, 'Մուտքագրեք նոր բաժին'),
(53252, 2162, 14, 'Մուտքագրեք ստացողի հասցեն'),
(53253, 2163, 14, 'Այս միջամտության համար մուտքագրեք LOINC կոդ'),
(53254, 2164, 14, 'Մուտքագրեք վերանույնականացման  կոդը'),
(53255, 2165, 14, 'Որոնման չափանիշները նշեք վերևում'),
(53256, 2166, 14, 'Սխալ մուտքագրում'),
(53257, 2167, 14, 'Մուտքեր'),
(53258, 2168, 14, 'Բնապահպանական'),
(53259, 2169, 14, 'EOB  (գործատուի, պետության կամ ապահովագրական ընկերության  կատարվող վճարի ծանուցում/բացատրագիր) տվյալների մուտք'),
(53260, 2170, 14, 'EOB մուտքագրում ֊ էլէկտրոնային փոխանցումներ'),
(53261, 2171, 14, 'EOB մուտքագրում ֊ հրահանգ'),
(53262, 2172, 14, 'EOB մուտքագրում ֊ հաշիվ ապրանքագիր'),
(53263, 2173, 14, 'EOB մուտքագրում ֊ Պացիենտի գրառում'),
(53264, 2174, 14, 'EOB մուտքագրում ֊ Որոնում'),
(53265, 2176, 14, 'Էպիլեպսիա'),
(53266, 2178, 14, 'Երիկամային հիվանդություններով զբաղվող մասնագետների Եվրոպական Ասոցացիա /ԵՀԶՄԵԱ/'),
(53267, 2179, 14, 'ԵՀԶՄԵԱ ֆայլեր'),
(53268, 2180, 14, 'ԵՀԶՄԵԱ հայտարարությունների տեղադրում'),
(53269, 2181, 14, 'Վերացնել/ջնջել'),
(53270, 2182, 14, 'էրեկցիա'),
(53271, 2183, 14, 'Սխալ'),
(53272, 2184, 14, 'ՍԽԱԼ'),
(53273, 2185, 14, 'Լաբորատոր հետազոտության արդյունքների անդորրագրի հաստատման սխալ'),
(53274, 2187, 14, 'Lab Exchange Network ֊ից լաբորատոր հետազոտության արդյունքների ստացման սխալ'),
(53275, 2188, 14, '"Սեռ" ընտրության սխալ'),
(53276, 2189, 14, '"HIPAA" ընտրության սխալ'),
(53277, 2190, 14, '"Գործընթաց" ընտրության սխալ'),
(53278, 2191, 14, '"SMS շլյուզի" ընտրության սխալ'),
(53279, 2192, 14, '"Դասավորել ըստ" ընտրության սխալ'),
(53280, 2193, 14, 'Ֆայլի gzip սեղմման սխալ: '),
(53281, 2194, 14, 'ԱՅՈ կամ ՈՉ տարբերակի սխալ'),
(53282, 2195, 14, 'Բեռնված ֆայլի բացման ընթացքում գրանցված սխալ'),
(53283, 2196, 14, 'Ֆայլի գործարկման սխալ'),
(53284, 2197, 14, 'Ֆայլի բեռնման սխալ'),
(53285, 2198, 14, 'Հաղորդագրության հեռացման սխալ'),
(53286, 2199, 14, 'Lab Exchange Network ֊ից  արդյունքների վերստացման/վերականգնման սխալ'),
(53287, 2200, 14, 'Նշանակության/արժեքի վերստացման/վերականգնման սխալ'),
(53288, 2201, 14, 'Փաստաթղթի պահպանման սխալ'),
(53289, 2202, 14, 'LibreEHR Օգտվողին ֆայլի հասանելիության տրամադրման սխալ'),
(53290, 2205, 14, 'Ձևաչափի գրանցման սխալ'),
(53291, 2206, 14, 'Ֆայլի պահպանման սխալ'),
(53292, 2209, 14, 'նոր արդյունքնրից ստացված սխալ'),
(53293, 2210, 14, 'ՍԽԱԼ։ ֆայլը գոյություն չունի'),
(53294, 2211, 14, 'ՍԽԱԼ։ հնարավոր չէ սերվերից տվյալներ հավաքել'),
(53295, 2212, 14, 'Սխալ։ հնարավոր չէ ստեղծել հաճախորդի վկայական/հավաստագիր'),
(53296, 2213, 14, 'Սխալ։ հնարավոր չէ ստեղծել admin.p12 վկայական/հավաստագիր'),
(53297, 2214, 14, 'Սխալ։ հնարավոր չէ ստեղծել Հավաստագրող Մարմնի վկայական'),
(53298, 2215, 14, 'Սխալ։ հնարավոր չէ ստեղծել Սերվերի վկայական'),
(53299, 2216, 14, 'Սխալ։ հնարավոր չէ բացել ֆայլը'),
(53300, 2217, 14, 'Սխալ։  LibreEHR֊ում Սերտիֆիկացման Լիազորություն միացված/ակտիվացված չէ'),
(53301, 2218, 14, 'Սխալ։ անհրաժեշտ է տեղադրել Archive/Tar.php php մոդուլ'),
(53302, 2219, 14, 'ՍԽԱԼ։ հնարավո՞ր չէ բացել table.sql վնասված ձևը'),
(53303, 2220, 14, 'Սխալ։ տողում առկա է ID կրկնօրինակ'),
(53304, 2221, 14, 'Սխալ։ տողում առկա է անվան կրկնօրինակ'),
(53305, 2222, 14, 'ՍԽԱԼ։ Դաշտ'),
(53306, 2223, 14, 'ՍԽԱԼ։ Բացակայող ZipArchive PHP մոդուլ'),
(53307, 2225, 14, 'Սխալ։ Գաղտնաբառերը չեն համապատասխանում։ Ստուգեք կատարած մուտքագրումը'),
(53308, 2226, 14, 'Սխալ։ Գաղտնաբառերը չեն համապատասխանում։ Ստուգեք կատարած մուտքագրումը'),
(53309, 2227, 14, 'Սխալ։ Ֆայլ գոյություն չունի'),
(53310, 2229, 14, 'ՍԽԱԼ։ հնարավոր չէ կրկնօրինակել ֆայլը'),
(53311, 2230, 14, 'Սխալ։ հնարավոր չէ ստեղծել արխիվի ներբեռնման տարբերակ'),
(53312, 2231, 14, 'ՍԽԱԼ։ հնարավոր չէ ստեղծել Zip արխիվ'),
(53313, 2232, 14, 'ՍԽԱԼ։ հնարավոր չէ ապաարխիվացնել'),
(53314, 2233, 14, 'ՍԽԱԼ։ հնարավոր չէ ֆայլը բեռնել տվյալների բազա'),
(53315, 2234, 14, 'ՍԽԱԼ։ հնարավոր չէ սահմանել տարբերակի համարը'),
(53316, 2235, 14, 'Սխալներ'),
(53317, 2236, 14, 'eRx հաշվի/օգտվողի կարգավիճակ'),
(53318, 2237, 14, 'eRx օգտվողներ/մուտքեր'),
(53319, 2238, 14, 'ERX Անուն'),
(53320, 2239, 14, 'ERX Գաղտնաբառ'),
(53321, 2240, 14, 'ERX Դեր/Նշանակություն'),
(53322, 2241, 14, 'ERX Օգտվող/օգտատեր'),
(53323, 2243, 14, 'Էլ․ ստորագրություն'),
(53324, 2244, 14, 'Էլ․ ստորագրության մուտք'),
(53325, 2245, 14, 'Էսկիմոս'),
(53326, 2247, 14, 'Գրանցված պացիենտ'),
(53327, 2248, 14, 'Էստոնացի /էստոներեն'),
(53328, 2249, 14, 'Էթնիկ պատկանելիություն/Ծագում/Ազգություն'),
(53329, 2250, 14, 'Էթնիկ պատկանելիություն/Ազգություն կամ ռասսա'),
(53330, 2251, 14, 'Ծագում֊Ռասսայի ցանկ (նշել, ավելացնել ըստ ցանկության)'),
(53331, 2252, 14, 'ETIN'),
(53332, 2253, 14, 'Իրադարձություն'),
(53333, 2254, 14, 'Իրադարձության սկիզբ'),
(53334, 2255, 14, 'Իրադարձության կատեգորիա'),
(53335, 2256, 14, 'Իրադարձության ամսաթիվ'),
(53336, 2257, 14, 'Իրադարձության նկարագիրություն'),
(53337, 2258, 14, 'Իրադարձության մանրամասներ'),
(53338, 2259, 14, 'Իրադարձությունը չի կրկնվում'),
(53339, 2260, 14, 'Իրադարձության տևողություն'),
(53340, 2261, 14, 'Իրադարձության տևողությունը րոպեներով'),
(53341, 2262, 14, 'Իրադարձության վճար'),
(53342, 2263, 14, 'Իրադարձության վայր'),
(53343, 2264, 14, 'Իրադարձությունը կրկնվում է յուրաքանչյուր․․․'),
(53344, 2265, 14, 'Իրադարձությունը կրկնվում է ․․․ին'),
(53345, 2266, 14, 'Իրադարձության մեկնարկի ժամ'),
(53346, 2267, 14, 'Իրադարձության վերնագիր'),
(53347, 2268, 14, 'Իրադարձության վերնագիր'),
(53348, 2269, 14, 'Իրադարձության վեբ֊կայք'),
(53349, 2270, 14, 'Իրադարձություններ'),
(53350, 2271, 14, 'Իրադարձություններ ․․․ի համար'),
(53351, 2272, 14, 'Իրադարձությունները բացվում են նոր պատուհանում'),
(53352, 2273, 14, 'յուրաքանչյուր'),
(53353, 2274, 14, 'Յուրաքանչյուր'),
(53354, 2275, 14, 'ամեն 3֊րդ ժամին'),
(53355, 2276, 14, 'ամեն 4֊րդ ժամին'),
(53356, 2277, 14, 'ամեն 5֊րդ ժամին'),
(53357, 2278, 14, 'ամեն 6֊րդ ժամին'),
(53358, 2279, 14, 'ամեն 8֊րդ ժամին'),
(53359, 2280, 14, 'Ամեն չորրորդ'),
(53360, 2281, 14, 'Ամեն երկրորդ'),
(53361, 2282, 14, 'Ամեն երրորդ'),
(53362, 2283, 14, 'Յուրաքանչյուր․ ամեն երկրորդ, ամեն երրորդ ը այլն․'),
(53363, 2285, 14, 'Հետազոտության և լաբորատոր փորձաքննության արդյունքներ'),
(53364, 2286, 14, 'Հետազոտության  արդյունքներ'),
(53365, 2289, 14, 'Հետազոտություն'),
(53366, 2290, 14, 'Հետազոտության ամսաթիվ'),
(53367, 2291, 14, 'Օրինակ'),
(53368, 2292, 14, 'Օրինակներ'),
(53369, 2293, 14, 'Հետազոտություններ'),
(53370, 2294, 14, 'Բացի/բացառությամն'),
(53371, 2295, 14, 'Աառատ/չափից շատ  արցունքաբերություն'),
(53372, 2296, 14, 'Չընդգրկված հիվանդներ'),
(53373, 2297, 14, 'Բացառությամն'),
(53374, 2298, 14, 'Բացառիկ մատակարար/պրովայդեր կազմակերպություն (EPO)'),
(53375, 2299, 14, 'Թղթի գործնալկան չափեր'),
(53376, 2300, 14, 'Վարժություն'),
(53377, 2301, 14, 'Վարժության օրինակներ'),
(53378, 2302, 14, 'Վարժության օրինակներ'),
(53379, 2303, 14, 'Գոյություն ունեցող/առկա'),
(53380, 2304, 14, 'Elq aդմինիստրատեր բաժնից'),
(53381, 2305, 14, 'Ընդարձ․'),
(53382, 2306, 14, 'Ընդարձակել'),
(53383, 2307, 14, 'Ընդարձակել'),
(53384, 2308, 14, 'Ընդարձակել ամբողջը'),
(53385, 2311, 14, 'Ընդլայնված դիտում'),
(53386, 2312, 14, 'Ընդունված ձև―encounter.pid to be '),
(53387, 2313, 14, 'Պիտանիության ժամկետ'),
(53388, 2314, 14, 'Պիտանիության ժամկետի ամսաթիվ'),
(53389, 2315, 14, 'Ժամկետը լրանում է'),
(53390, 2316, 14, 'Ժամկետը լրանում է ֊ ֊ ֊ին'),
(53391, 2317, 14, 'Արտահանում'),
(53392, 2318, 14, 'Արտահանել որպես CSV'),
(53393, 2319, 14, 'Կոնֆիգուրացիայի արտահանում'),
(53394, 2322, 14, 'Պացիենտի Անձնական/ազգագրական տվյալների արտահանում'),
(53395, 2323, 14, 'CSV֊ի արտահանում'),
(53396, 2327, 14, 'Արտահանել դեպի CSV'),
(53397, 2328, 14, 'Արտահանում դեպի արտաքին բիլլինգային համակարգ'),
(53398, 2329, 14, 'Ծանոթացումը օտար երկրներին'),
(53399, 2330, 14, 'Ծանոթացումը օտար երկրներին'),
(53400, 2334, 14, 'Արտաքին'),
(53401, 2336, 14, 'Արտաքին ID'),
(53402, 2337, 14, 'Արտաքին id'),
(53403, 2338, 14, 'Արտաքին նույնացուցիչ'),
(53404, 2339, 14, 'Միայն արտաքին'),
(53405, 2342, 14, 'Արտաքին ուղղորդիչ'),
(53406, 2343, 14, 'Արտաքին ուղղորդման հսկողություն'),
(53407, 2344, 14, 'Ուղղությունը դեպի դո՞ւրս'),
(53408, 2345, 14, 'Արտաքին ուղղություններ'),
(53409, 2346, 14, 'zip ֆայլի բացում'),
(53410, 2347, 14, 'Այս ֆայլը բացվում է․ այն մի քանի րոպե կտևի'),
(53411, 2349, 14, 'Աչքի գրգռվածություն'),
(53412, 2350, 14, 'Աչքի ցավ'),
(53413, 2351, 14, 'Աչքի կարմրություն'),
(53414, 2352, 14, 'Տեսողություն'),
(53415, 2353, 14, 'F'),
(53416, 2354, 14, 'F/H  Արյան հետ կապված/Հեմատոլոգիկ խնդիրներ'),
(53417, 2356, 14, 'Ծառայություններ/Հաստատություններ'),
(53418, 2357, 14, 'Ծառայություն//Հաստատություն'),
(53419, 2358, 14, 'ծառայություն/հաստատություն'),
(53420, 2359, 14, 'Ծառայությունների/Հաստատությունների կառավարում'),
(53421, 2360, 14, 'Ծառայությունների մատուցման քաղաք'),
(53422, 2361, 14, 'Ծառայության/Հաստատության կոդ'),
(53423, 2362, 14, 'Ծառայություն մատուցող//Հաստատության երկրի կոդը'),
(53424, 2363, 14, '/Հաստատության ՖԱՔՍ'),
(53425, 2364, 14, 'Ծառայության//Հաստատության անվանում'),
(53426, 2365, 14, 'Ծառայություն մատուցող բժշկական գործակալի նույնականացման  պետական կոդը/համարը'),
(53427, 2366, 14, 'Ծառայությունների մատուցման/Հաստատության հեռախոսահամար'),
(53428, 2368, 14, 'Հաստատության շրջանը/մարզը'),
(53429, 2369, 14, 'Հաստատության փողոցը'),
(53430, 2370, 14, 'Հաստատության փոստային ինդեքս'),
(53431, 2372, 14, 'Հաստատություն։'),
(53432, 2373, 14, 'ՁԱԽՈՂՈՒՄ'),
(53433, 2374, 14, 'ձախողված է'),
(53434, 2375, 14, 'ձախողված է'),
(53435, 2376, 14, 'Գրանցումը ձախողված պացիենտներ'),
(53436, 2377, 14, 'Հիվանդի ավելացումը պորտալին ձախողված է'),
(53437, 2378, 14, 'Բացառիկ անվան հաշվարկը ձախողված է'),
(53438, 2379, 14, 'Չի հաջողվել ստաեղծել'),
(53439, 2380, 14, 'Ժամանակավոր թղթապանակի ստեղծումը ձախողված է։ CouchDB չի աշխատի'),
(53440, 2382, 14, 'Ձախողված է'),
(53441, 2383, 14, 'ձախողում'),
(53442, 2384, 14, 'Ձախողում'),
(53443, 2390, 14, 'Ընտանեկան անամնեզ'),
(53444, 2391, 14, 'Գլաուկոմայի մասին ընտանեկան անամնեզ'),
(53445, 2392, 14, 'Ընտանեկան անամնեզ։'),
(53446, 2394, 14, 'Ընտանեկան վճարում'),
(53447, 2395, 14, 'Ընտանիքի կազմը'),
(53448, 2396, 14, 'Պատկերացում/ենթադրություն'),
(53449, 2398, 14, 'Պարսիկ/պարսկերեն'),
(53450, 2400, 14, 'Հայր'),
(53451, 2402, 14, 'Հոգնածություն'),
(53452, 2403, 14, 'Հոգնած'),
(53453, 2404, 14, 'Ֆաքս'),
(53454, 2405, 14, 'Ֆաքսերի քանակ'),
(53455, 2406, 14, 'Ֆաքսի համար'),
(53456, 2408, 14, 'Ֆաքս/Սկան'),
(53457, 2409, 14, 'ընդունել ֆաքսով'),
(53458, 2410, 14, 'ուղարկել ֆաքսով'),
(53459, 2411, 14, 'Հնարավորություններ'),
(53460, 2412, 14, 'Փետրվ․'),
(53461, 2413, 14, 'Փետրվար'),
(53462, 2414, 14, 'FECA'),
(53463, 2415, 14, 'Դեղամիջոցի պետական ID'),
(53464, 2416, 14, 'Պետական EIN'),
(53465, 2417, 14, 'Հարկ վճարողի հաշվառման պետական համար'),
(53466, 2418, 14, 'Վճար'),
(53467, 2419, 14, 'վճար'),
(53468, 2420, 14, 'Վճարում թույլատրված չէ'),
(53469, 2421, 14, 'Վճարման թերթիկ'),
(53470, 2422, 14, 'Վճարման թերթիկի տարբերակներ'),
(53471, 2423, 14, 'Վճարներ'),
(53472, 2424, 14, 'Իգական'),
(53473, 2425, 14, 'Կանացի 1. զարկերակային ճնշում 2. անգինա'),
(53474, 2426, 14, 'Կանացի պահպանակ'),
(53475, 2427, 14, 'Կանացի G'),
(53476, 2428, 14, 'Կանացի LC'),
(53477, 2429, 14, 'Կանացի P'),
(53478, 2430, 14, 'Կանացի ախտանիշներ'),
(53479, 2431, 14, 'Կանացի VSC'),
(53480, 2432, 14, 'Բերել'),
(53481, 2433, 14, 'Պորտալից բերում է հետևյալ ֆայլը'),
(53482, 2434, 14, 'Տենդ'),
(53483, 2435, 14, 'Տենդ։'),
(53484, 2436, 14, 'FH արյան խնդիրներ'),
(53485, 2437, 14, 'Ֆիբրոիդներ /բարորակ ուռուցք/'),
(53486, 2438, 14, 'Դաշտ'),
(53487, 2439, 14, 'Դաշտի "անվանումը" չպետք է դատարկ լինի'),
(53488, 2443, 14, 'Բաց թողնված դաշտ(եր)'),
(53489, 2447, 14, 'Ֆայլ'),
(53490, 2449, 14, 'ֆայլի տեղակայում'),
(53491, 2450, 14, 'Ֆայլի կառավարում'),
(53492, 2453, 14, 'Ֆայլի հանդեպ LibreEHR օգտվողի իրավունք/արտոնություն'),
(53493, 2455, 14, 'Գրանցման բաժին'),
(53494, 2456, 14, 'բեռնվող ֆայլ'),
(53495, 2457, 14, 'Բեռնվող ֆայլ'),
(53496, 2458, 14, 'Այս տիրույթում նման անունով ֆայլ արդեն գոյություն ունի'),
(53497, 2459, 14, 'Ֆայլի անվանում'),
(53498, 2460, 14, 'Ֆայլի անունը պետք է վերջանա ".pdf"֊ով'),
(53499, 2461, 14, 'Ֆայլեր'),
(53500, 2462, 14, 'Ֆիլիպինյան'),
(53501, 2463, 14, 'Լրացրեք ներքևի ցանկացած տողը'),
(53502, 2465, 14, 'Բացատրությունը գրեք ներքևում'),
(53503, 2467, 14, 'Լրացրեք տողը'),
(53504, 2468, 14, 'Ֆիլտր'),
(53505, 2469, 14, 'Կոնստանտի ֆիլտր'),
(53506, 2470, 14, 'Սահմանումների ֆիլտր'),
(53507, 2472, 14, 'ֆիլտրեր'),
(53508, 2473, 14, 'ֆիլտրեր'),
(53509, 2474, 14, 'Վերջնական'),
(53510, 2475, 14, 'Վերջնական ախտորոշում'),
(53511, 2476, 14, 'Մասնագետի վերջնական ախտորոշում'),
(53512, 2478, 14, 'Ֆինանսական'),
(53513, 2480, 14, 'Ֆինանսական հաշվետվություն ֊ ցանկացած'),
(53514, 2481, 14, 'Ֆինանսական հաշվետվություն ֊ իմ այցելությունները'),
(53515, 2482, 14, 'Ֆինանսական ամփոփման ամսաթիվ'),
(53516, 2483, 14, 'Ֆինանսական ամփոփ տեղեկագիր ծառայության կոդով'),
(53517, 2484, 14, 'Գտնել'),
(53518, 2485, 14, 'Գտնել հասանելիները'),
(53519, 2486, 14, 'Գտնել այցերի հասանելի  գրանցումներ'),
(53520, 2487, 14, 'Գտնել Պացիենտին'),
(53521, 2488, 14, 'Գտնել պացիենտի տեղեկատվական նյութեր'),
(53522, 2489, 14, 'Արդյունքներ'),
(53523, 2490, 14, 'Արդյունքներ ըստ մասնագետի'),
(53524, 2491, 14, 'Տուգանք'),
(53525, 2492, 14, 'Վերջնական վճարումներ'),
(53526, 2493, 14, 'ավարտված է'),
(53527, 2494, 14, 'Ֆիննական/ֆիններեն'),
(53528, 2495, 14, 'Առաջին'),
(53529, 2497, 14, 'Շաբաթվա առաջին օրը'),
(53530, 2498, 14, 'Անուն'),
(53531, 2499, 14, 'Անուն'),
(53532, 2500, 14, 'Անուն։'),
(53533, 2501, 14, 'Առաջին այց կամ խորհրդատվություն'),
(53534, 2502, 14, 'Անուն  Ազգանուն'),
(53535, 2503, 14, 'Ֆիզիկական պատրաստվածություն'),
(53536, 2504, 14, 'Ֆիզիկական պատրաստվածության մակարդակը'),
(53537, 2505, 14, 'Սույն խաղացողի այսօրվա ֆիզիկական պատրաստվածության մակարդակը'),
(53538, 2506, 14, 'Ֆիզիկական պատրաստվածության քննություն'),
(53539, 2507, 14, 'Ֆիզիկական նախապատրաստում խաղին'),
(53540, 2508, 14, 'Գրանցել այցելությունների ամսաթվերը ֊ ցանկացած այցելություններ'),
(53541, 2509, 14, 'Գրանցել սա'),
(53542, 2510, 14, 'Ազդրերի երկարությունը'),
(53543, 2511, 14, 'Մետեորիզմ'),
(53544, 2512, 14, 'Դաշտանային ցիկլ'),
(53545, 2514, 14, 'Գրիպի համաճարակային շրջան/փուլ'),
(53546, 2515, 14, 'Գրիպի համաճարակային շրջան/փուլ'),
(53547, 2516, 14, 'Գրիպի դեմ պատվաստում'),
(53548, 2517, 14, 'Հիդրոէլեկտրալույծի բալանսի խնդիր'),
(53549, 2519, 14, 'Թղթի գրքային չափը'),
(53550, 2520, 14, 'Լրացնել ձեռքով'),
(53551, 2521, 14, 'Հետևյալ տվյալների բազան տեղադրելու կամ թարմացնելու համար հետևեք այս հրահանգներին'),
(53552, 2522, 14, 'Հետևող'),
(53553, 2524, 14, 'Առաջացող պատճառներ'),
(53554, 2525, 14, 'Հաջորդիվ'),
(53555, 2526, 14, 'Ահա նոր հիմնական լեզուն'),
(53556, 2529, 14, 'Հետագա ծառայություններ'),
(53557, 2530, 14, 'Հետագա նշվածները'),
(53558, 2531, 14, 'Սննդային անհամատեղելիություն / սննդի հանդեպ հակակրանք'),
(53559, 2532, 14, 'Ոտք'),
(53560, 2533, 14, 'Ոտքերի խնդիր'),
(53561, 2534, 14, 'Ոտք։'),
(53562, 2535, 14, 'Ֆուտբոլային վնասվածքներ'),
(53563, 2536, 14, 'Ֆուտբոլային վնասվածք'),
(53564, 2537, 14, 'Տեղեկություն ֆուտբոլային վնասվածքի մասին'),
(53565, 2538, 14, 'Կոշիկի տեսակ'),
(53566, 2539, 14, 'համար'),
(53567, 2540, 14, 'Համար'),
(53568, 2541, 14, 'Կոդի համար'),
(53569, 2543, 14, 'Այցելության պահանջների համար'),
(53570, 2544, 14, 'Օրինակ։'),
(53571, 2547, 14, 'հաշվի համար'),
(53572, 2548, 14, 'Միայն անվճար բուժօգնության համար/դեպքում խորհրդատուին վկայակոչում են որպես բժիշկ'),
(53573, 2550, 14, 'Պացիենտի համար'),
(53574, 2552, 14, 'Ուղղորդող հաստատությունների / Պրակտիկանտների համար'),
(53575, 2553, 14, 'Նախկինների համար'),
(53576, 2554, 14, 'Փոփոխականների համար'),
(53577, 2555, 14, 'համար։'),
(53578, 2556, 14, 'Պահանջում է բիլլինգային վիդջեթի բացում'),
(53579, 2557, 14, 'Պահանջում է նոր պացիենտի ստեղծում'),
(53580, 2559, 14, 'Նախաբազուկ'),
(53581, 2560, 14, 'Ձև'),
(53582, 2561, 14, 'ձև'),
(53583, 2564, 14, 'Ձևաչափ'),
(53584, 2565, 14, 'Ձևաչափ'),
(53585, 2566, 14, 'Տարիքի ցուցադրման ձևաչափ'),
(53586, 2567, 14, 'NDC֊ի սխալ ձևաչափ'),
(53587, 2568, 14, 'Ամսաթվերի մեծ քանակ  ցուցադրելու ֆորմատ'),
(53588, 2569, 14, 'Մեծ ժամացուցակ ցուցադրելու ֆորմատ'),
(53589, 2570, 14, 'Ֆորմատավորման/կազմավորման զեկույց'),
(53590, 2571, 14, 'Նախկին ծխող'),
(53591, 2572, 14, 'Ձևեր/բլանկներ'),
(53592, 2573, 14, 'Բլանկների կառավարում'),
(53593, 2575, 14, 'Փոխանցել / առաջ /'),
(53594, 2576, 14, 'Փոխանցել էջերը ֆաքսով'),
(53595, 2577, 14, 'Փոխանցված'),
(53596, 2579, 14, 'Չորրորդ'),
(53597, 2581, 14, 'Կոտրվածք'),
(53598, 2582, 14, '֊ի կոտրվածք'),
(53599, 2583, 14, 'կողային  կոճի կոտրվածք'),
(53600, 2584, 14, 'մեջտեղի  կոճի կոտրվածք'),
(53601, 2587, 14, 'Ֆրանսերեն'),
(53602, 2588, 14, 'Ֆրանսերեն (կանադական)'),
(53603, 2589, 14, 'Ֆրանսերեն (ստանդարտ)'),
(53604, 2590, 14, 'Հաճախություն'),
(53605, 2591, 14, 'Հաճախ կրկնվող հարբուխներ'),
(53606, 2592, 14, 'Հաճախ կրկնվող հիվանդություններ'),
(53607, 2593, 14, 'Ուրբ․'),
(53608, 2594, 14, 'Ուրբաթ'),
(53609, 2595, 14, '֊ից'),
(53610, 2596, 14, '֊ից'),
(53611, 2597, 14, '֊ից'),
(53612, 2598, 14, '"֊ից" ասմաթիվը չի կարող մոծ լինել "մինչ" ամսաթվից'),
(53613, 2599, 14, '֊ից։'),
(53614, 2600, 14, '֊ից։ '),
(53615, 2603, 14, 'FROM_FNAME'),
(53616, 2604, 14, 'FROM_LNAME'),
(53617, 2605, 14, 'FROM_MNAME'),
(53618, 2606, 14, 'FROM_PHONE'),
(53619, 2607, 14, 'FROM_PHONECELL'),
(53620, 2608, 14, 'FROM_POSTAL'),
(53621, 2609, 14, 'FROM_STATE'),
(53622, 2610, 14, 'FROM_STREET'),
(53623, 2611, 14, 'FROM_TITLE'),
(53624, 2612, 14, 'FROM_VALEDICTORY'),
(53625, 2613, 14, 'Գրասենյակ /Ռեգիստր/'),
(53626, 2614, 14, 'Գրասենյակի /Ռեգիստրի մուտքեր'),
(53627, 2615, 14, 'Գրասենյակի /Ռեգիստրի մուտքերի զեկույց'),
(53628, 2616, 14, 'Գրանցում'),
(53629, 2617, 14, 'Առաջին աջ'),
(53630, 2619, 14, 'Անուն, ազգանուն'),
(53631, 2624, 14, 'Ամբողջական վերարտադրում/գործարկում'),
(53632, 2625, 14, 'Ամբողջական ուսուցում'),
(53633, 2626, 14, 'Ամբողջությամբ վճարված'),
(53634, 2631, 14, 'Ապագա'),
(53635, 2633, 14, 'G'),
(53636, 2636, 14, 'Լեղապարկի վիճակ'),
(53637, 2637, 14, 'Լեղապարկի քարեր'),
(53638, 2638, 14, 'Խաղի տևողություն'),
(53639, 2639, 14, 'Խաղեր'),
(53640, 2640, 14, 'Խաղը բացակայում է'),
(53641, 2641, 14, 'Խաղեր/միջոցառումներ'),
(53642, 2642, 14, 'Խաղերը/միջոցառումները բացակայում են'),
(53643, 2644, 14, 'Գաստրիտ'),
(53644, 2645, 14, 'Գաստրիտային ցավեր'),
(53645, 2646, 14, 'Աղեստամոքսային/մարսողական օրգաններ'),
(53646, 2647, 14, 'GCAC վիճակագրական հաշվետվություն'),
(53647, 2648, 14, 'GCAC վիճակագրություն'),
(53648, 2649, 14, 'GCAC այցի բլանկը դատարկ է'),
(53649, 2650, 14, 'Սեռ'),
(53650, 2651, 14, 'Սեռ '),
(53651, 2652, 14, 'Ընդհանուր/գլխավոր'),
(53652, 2653, 14, 'Ընդհանուր/գլխավոր հարցերի ցանկ'),
(53653, 2655, 14, 'Հիմնական ծառայությունների կատեգորիա'),
(53654, 2656, 14, 'Ստեղծել'),
(53655, 2657, 14, 'Ստեղծել և ներբեռնել CMS 1500 թղթային պահանջները'),
(53656, 2658, 14, 'Ստեղծել և ներբեռնել HCFA 15 թղթային պահանջները'),
(53657, 2659, 14, 'Ստեղծել և ներբեռնել X12 փաթեթը'),
(53658, 2660, 14, 'Ստեղծել և ներբեռնել այցելության  X12 պահանջված փաթեթը'),
(53659, 2663, 14, 'Թույլատրելի դեղատոմսի ստեղծում և էլեկտրոնային փոխանցում'),
(53660, 2664, 14, 'Ստեղծել CMS 1500'),
(53661, 2665, 14, 'Ստեղծել 1500 PDF'),
(53662, 2666, 14, 'Ստեղծել 1500 TEXT'),
(53663, 2667, 14, 'Ստեղծել HCFA'),
(53664, 2668, 14, 'Ստեղծել հաշիվ ապրանքագիր'),
(53665, 2669, 14, 'Ստեղծել նամակ'),
(53666, 2670, 14, 'Ստեղծել նամակ ֊ի վերաբերյալ '),
(53667, 2671, 14, 'Ստեղծել PQRI հաշվետվություն (Մեթոդ Ա)'),
(53668, 2672, 14, 'Ստեղծել PQRI հաշվետվություն (Մեթոդ Ա) ֊ 2011'),
(53669, 2673, 14, 'Ստեղծել PQRI հաշվետվություն (Մեթոդ Ե)'),
(53670, 2674, 14, 'Ստեղծել PQRI հաշվետվություն (Մեթոդ Ե) - 2011'),
(53671, 2677, 14, 'Ստեղծել հաշվետվություն'),
(53672, 2678, 14, 'Ստեղծել Օգտվողի անուն և գաղտնաբառ ֊ի համար'),
(53673, 2679, 14, 'Ստեղծել X12'),
(53674, 2680, 14, 'Ստեղծել X12 այց'),
(53675, 2682, 14, 'Ստեղծված ֊ին'),
(53676, 2683, 14, 'Ստեղծում է'),
(53677, 2684, 14, 'Միազասեռական'),
(53678, 2686, 14, 'վրացերեն'),
(53679, 2687, 14, 'Գերմաներեն'),
(53680, 2691, 14, 'Ստանալ HL7'),
(53681, 2692, 14, 'Գլաուկոմա'),
(53682, 2693, 14, 'Գլաուկոմայի ընտանեկան անամնեզ'),
(53683, 2694, 14, 'Գլոբալ/համընդհանուր'),
(53684, 2696, 14, 'Գլոբալ ID'),
(53685, 2697, 14, 'Գլոբալ կարգավորումներ/պարամետրեր'),
(53686, 2698, 14, 'Գլոբալ փոփոխություններ'),
(53687, 2699, 14, 'GM/DL'),
(53688, 2700, 14, 'Առաջ'),
(53689, 2701, 14, 'Առաջ'),
(53690, 2704, 14, 'Գնալ/վերադառնալ դեպի'),
(53691, 2705, 14, 'Գնալ/վերադառնալ ֊ի շաբաթ'),
(53692, 2706, 14, 'Գնալ/վերադառնալ'),
(53693, 2707, 14, 'Նպատակ Ա'),
(53694, 2708, 14, 'Նպատակ և Մեթոդներ'),
(53695, 2709, 14, 'Նպատակ Բ'),
(53696, 2710, 14, 'Նպատակ Գ'),
(53697, 2711, 14, 'Վնասվածքի ծանրության աստիճանը'),
(53698, 2712, 14, 'Աստիճան։'),
(53699, 2713, 14, 'գրամ'),
(53700, 2714, 14, 'Ընդհանուր քանակ'),
(53701, 2715, 14, 'Ընդհանուր քանակ'),
(53702, 2718, 14, 'Գրաֆիկորեն արտածվող'),
(53703, 2720, 14, 'Ավելի մեծ, քան'),
(53704, 2721, 14, 'Ավելի քան կամ հավասար'),
(53705, 2722, 14, 'Հունարեն'),
(53706, 2723, 14, 'Հունարեն․ Ժամանակակից'),
(53707, 2724, 14, 'Խումբ'),
(53708, 2725, 14, 'Խմբի անվանում'),
(53709, 2726, 14, 'Խմբի անվանումը չի կարող դատարկ լինել'),
(53710, 2727, 14, 'Խմբի անվանումը չի կարող սկսվել թվերով կամ բացատով'),
(53711, 2728, 14, 'Խմբի անվանումը չի կարող սկսվել թվերով'),
(53712, 2729, 14, 'Խմբի համարը'),
(53713, 2730, 14, 'Խմբային վճարում'),
(53714, 2731, 14, 'Խումբ։'),
(53715, 2732, 14, 'Խմբի անվանում'),
(53716, 2733, 14, 'Խմբեր և հասանելիության հսկողություն'),
(53717, 2734, 14, 'Աճի սանդղակ'),
(53718, 2735, 14, 'Աճի աղյուսակ'),
(53719, 2736, 14, 'gtts (կաթիլներ)'),
(53720, 2737, 14, 'Գուամերերն'),
(53721, 2739, 14, 'Խնամակալի ազգանունը'),
(53722, 2741, 14, 'Գինեկոլոգիական հետազոտություն'),
(53723, 2742, 14, 'ժ'),
(53724, 2743, 14, 'քնի ժամ'),
(53725, 2744, 14, 'Հեպատիտներ H/O'),
(53726, 2745, 14, 'Հաջողությամբ ջնջված է։ Հնարավոր առկա ենթակատեգորիաներն տեղափոխվել են ներքև'),
(53727, 2746, 14, 'Հեմատոմա / կապտուկ'),
(53728, 2750, 14, 'Ձեռքեր + մատներ'),
(53729, 2751, 14, 'Ձեռքերի խնդիր'),
(53730, 2752, 14, 'Կոշտ սկավառակ'),
(53731, 2753, 14, 'Առանց դժվարությունների'),
(53732, 2754, 14, 'կապված է այցի հետ'),
(53733, 2755, 14, 'ժամկետանց'),
(53734, 2757, 14, 'Այս ֆայլի համար ֊ գոյություն չունի։ Նոր ֊ է ստեղծվել'),
(53735, 2758, 14, '֊ը չի համապատասխանում։ Տվյալների ամբողջականությունը խախտված է'),
(53736, 2760, 14, 'Հավայան'),
(53737, 2761, 14, 'Վտանգավոր գործունեություն/գործողություն'),
(53738, 2762, 14, 'Վտանգավոր գործունեություն/գործողություն'),
(53739, 2763, 14, 'HCFA-ի ձախ հատվածը/միջակայք կետերով'),
(53740, 2764, 14, 'HCFA-ի միջակայք'),
(53741, 2765, 14, 'HCFA-ի վերին հատվածը/միջակայք կետերով'),
(53742, 2766, 14, 'HCPCS միջամտություն / ծառայություն'),
(53743, 2767, 14, 'he PostCalendar '),
(53744, 2768, 14, 'Գլուխ'),
(53745, 2769, 14, 'Գլխի շրջագիծ'),
(53746, 2770, 14, 'Գլխի շրջագիծ'),
(53747, 2771, 14, 'Գլխացավ'),
(53748, 2772, 14, 'Գլխացավեր'),
(53749, 2773, 14, 'Բժշկական վիրահատություններ'),
(53750, 2774, 14, 'Առողջապահական միջոցառումներ'),
(53751, 2775, 14, 'Բժշկական կենտրոն/կլինիկա'),
(53752, 2776, 14, 'Առողջապահական  կազմակերպություն/հաստատություն'),
(53753, 2777, 14, 'Առողջապահական  կազմակերպության/հաստատության (ԱԿ / ԱՀ) Ապահովագրական ռիսկ'),
(53754, 2778, 14, 'Լսողության կորուստ'),
(53755, 2779, 14, 'Սրտամկանի ինֆարկտ'),
(53756, 2780, 14, 'Սրտային հիվանդություն'),
(53757, 2781, 14, 'Սրտի անբավարարություն'),
(53758, 2782, 14, 'Սրտանոթային խնդիր'),
(53759, 2783, 14, 'Սրտանոթային խնդիրներ'),
(53760, 2784, 14, 'Սրտային վիրաբուժություն'),
(53761, 2785, 14, 'Սրտի փոխպատվաստում'),
(53762, 2786, 14, 'ՍԻՐՏ։'),
(53763, 2787, 14, 'Այրոց'),
(53764, 2788, 14, 'Տենդ կամ Սարսուռ'),
(53765, 2789, 14, 'Տենդ կամ Սարսուռ'),
(53766, 2790, 14, 'Ծխախոտամոլ'),
(53767, 2791, 14, 'Եբրայերեն'),
(53768, 2793, 14, 'Քիթ֊Կոկորդ֊Ականջ'),
(53769, 2794, 14, 'Հասակ'),
(53770, 2795, 14, 'Բարձրություն/երկարություն'),
(53771, 2796, 14, 'Օգնություն'),
(53772, 2797, 14, 'օգնություն'),
(53773, 2798, 14, 'արյան փսխում'),
(53774, 2800, 14, 'Արյունաբանություն'),
(53775, 2801, 14, 'Հեմատուրիա /մեզի մեջ արյան առկայություն/'),
(53776, 2802, 14, 'Հեմոգլոբին'),
(53777, 2803, 14, 'Հեմոգլոբին A1C'),
(53778, 2804, 14, '/արյունազատում հազի ժամանակ/'),
(53779, 2805, 14, 'Հեպատիտ'),
(53780, 2806, 14, 'Հեպատիտ A 1'),
(53781, 2807, 14, 'Հեպատիտ A 2'),
(53782, 2808, 14, 'Հեպատիտ B 1');
INSERT INTO `lang_definitions` VALUES
(53783, 2809, 14, 'Հեպատիտ B 2'),
(53784, 2810, 14, 'Հեպատիտ B 3'),
(53785, 2811, 14, 'այստեղ'),
(53786, 2813, 14, 'Ճողվածքի բուժում'),
(53787, 2814, 14, 'Դիսկի ճողվածք'),
(53788, 2815, 14, 'Հերպես'),
(53789, 2816, 14, 'Միզարձակության դժվարություն'),
(53790, 2817, 14, 'Ահա․ դուք այստեղ էիք ֊ի համար '),
(53791, 2818, 14, 'Hib 1 պատվաստանյութ'),
(53792, 2819, 14, 'Hib 2 պատվաստանյութ'),
(53793, 2820, 14, 'Hib 3 պատվաստանյութ'),
(53794, 2821, 14, 'Hib 4 պատվաստանյութ'),
(53795, 2822, 14, 'Թաքնված /գաղտնի'),
(53796, 2823, 14, 'Գաղտնի միջոցառումների կառավարում'),
(53797, 2824, 14, 'Թաքցնել'),
(53798, 2825, 14, 'Թաքցնել մանրամասները'),
(53799, 2827, 14, 'Փաստաթղթային կառավարման մեջ թաքցնել կոդավորում/ապակոդավորում տարբերակները'),
(53800, 2828, 14, 'Թաքցնել մենյուն'),
(53801, 2830, 14, 'Թաքցնել հիշեցումները'),
(53802, 2831, 14, 'Թաքցնել/ցուցադրել սյուները'),
(53803, 2833, 14, 'Բարձր'),
(53804, 2834, 14, 'Արյան բարձր նշում'),
(53805, 2835, 14, 'Հինդի / հնդկերեն'),
(53806, 2836, 14, 'Ազդր + աճուկ'),
(53807, 2837, 14, 'Ազդր և աճուկ'),
(53808, 2838, 14, 'Ազդրի խնդիրներ'),
(53809, 2839, 14, 'Կոնքազդրային հոդի փոխարինում'),
(53810, 2840, 14, 'Առողջության ապահովագրության հաշվետվության ծանուցումն ստացված է'),
(53811, 2843, 14, 'Լատինամերիկացի'),
(53812, 2844, 14, 'Լատինամերիկացի - այլկերպ (ծնված ԱՄՆ֊ում)'),
(53813, 2845, 14, 'Լատինամերիկացի - այլկերպ (ծնված ոչ ԱՄՆ֊ում)'),
(53814, 2846, 14, 'Լատինամերիկյան կամ լատինական'),
(53815, 2847, 14, 'Տարեգրություն/ժամանակագրություն'),
(53816, 2848, 14, 'Անամնեզի հավաքագրման ամսաթիվ'),
(53817, 2849, 14, 'Անամնեզի ամսաթիվ'),
(53818, 2851, 14, 'Աղմուկի նշում/առկայություն անամնեզում'),
(53819, 2852, 14, 'Տարեգրություն/ժամանակագրություն ռույլատրված չէ'),
(53820, 2853, 14, 'Սրտի աղմուկի անամնեզ'),
(53821, 2855, 14, 'ՄԻԱՎ'),
(53822, 2858, 14, 'HL7 բրաուզեր'),
(53823, 2860, 14, 'մմոլ/լ'),
(53824, 2861, 14, 'Հմոնգերեն'),
(53825, 2862, 14, 'Սեղմեք  Ctrl կոճակը՝ մի քանի տարրեր ընտրելու և/կամ չեղարկելու համար'),
(53826, 2863, 14, 'Սեղմեք  Ctrl կոճակը՝ մի քանի խումբ ընտրելու համար'),
(53827, 2864, 14, 'Սեղմեք  Ctrl կոճակը՝ մի քանի բաժանմունք ընտրելու համար'),
(53828, 2865, 14, 'Տուն'),
(53829, 2866, 14, 'Տան/քաղաքային հեռախոս'),
(53830, 2867, 14, 'Տան/քաղաքային հեռախոսահամար'),
(53831, 2868, 14, 'Անօթևան կամ նման կարգավիճա՞կ է'),
(53832, 2869, 14, 'Անօթևան և այլն'),
(53833, 2870, 14, 'Անօթևան և այլն'),
(53834, 2871, 14, 'Խոյակներ/կեռիկներ'),
(53835, 2872, 14, 'Հոսթի անվանումը'),
(53836, 2873, 14, 'Հոսթի անվանումը չի կարող դատարկ լինել'),
(53837, 2875, 14, 'Ժամ'),
(53838, 2876, 14, 'Ժամեր'),
(53839, 2878, 14, 'Ինչպե՞ս է ստացվել տրավման'),
(53840, 2879, 14, 'Ինչպե՞ս է ստացվել տրավման'),
(53841, 2880, 14, 'Ինչպե՞ս են իմացել մեր մասին'),
(53842, 2882, 14, 'Ուղեկցվող հիվանդությունների անամնեզ'),
(53843, 2883, 14, 'Սրտի փոխպատվաստում'),
(53844, 2884, 14, 'HTML'),
(53845, 2886, 14, 'LibreEHR Support LLC֊ի Լաբորատոր փոխանակման ծառայության Https լինք'),
(53846, 2887, 14, 'Հունգարերեն'),
(53847, 2888, 14, 'Hylafax ուղեցույց'),
(53848, 2889, 14, 'Hylafax կոդավորման հրաման'),
(53849, 2890, 14, 'Hylafax սերվեր'),
(53850, 2891, 14, 'Hylafax սերվերի հոսթանավանումը'),
(53851, 2892, 14, 'Հիպերակտիվ/գերակտիվ'),
(53852, 2893, 14, 'Հիպերտոնիա /գերճնշում/'),
(53853, 2894, 14, 'Հիպերտոնիա /գերճնշում/։ արյան ճնշման չափում'),
(53854, 2895, 14, 'Հիպերտոնիա /գերճնշում/։ արյան ճնշման չափում (CQM)'),
(53855, 2896, 14, 'Հիպերթիրեոզ'),
(53856, 2897, 14, 'Հիպոթիրեոզ'),
(53857, 2898, 14, 'իստերէկտոմիա'),
(53858, 2899, 14, 'Ես'),
(53859, 2900, 14, 'Ես զբաղված եմ այս ժամանակահատվածում'),
(53860, 2901, 14, 'Ընթերցման թույլտվություն չունեմ '),
(53861, 2902, 14, '1. Հիվանդությունների միջազգային դասակարգում /ՀՄԴ/ 2. Միզաքարային հիվանդություն  /ՄՔՀ/'),
(53862, 2903, 14, 'ՄՔՀ 10 ախտորոշում'),
(53863, 2904, 14, 'ՄՔՀ 10 միջամտություն/ծառայություն'),
(53864, 2905, 14, 'ՄՔՀ 9'),
(53865, 2906, 14, 'ՄՔՀ 9 ախտորոշում'),
(53866, 2907, 14, 'ՄՔՀ 9 միջամտություն/ծառայություն'),
(53867, 2908, 14, 'Իսլանդերեն'),
(53868, 2909, 14, 'ID'),
(53869, 2910, 14, 'id'),
(53870, 2911, 14, 'ID չի կարող դատարկ լինել'),
(53871, 2912, 14, 'ID քարտ'),
(53872, 2913, 14, 'IDays'),
(53873, 2914, 14, 'նույնականացնել որպես'),
(53874, 2915, 14, 'նույնացուցիչ (մեկ բառ)'),
(53875, 2916, 14, 'Նույնականացաման կոդ'),
(53876, 2919, 14, 'Եթե այս ձևի համար բոլոր սյունակների բոլոր տվյալները լրացված են'),
(53877, 2920, 14, 'Բիլլինգային վերականգնման համար մուտքագրեք ախտորոշման կոդի անվանումը'),
(53878, 2921, 14, 'եթե մուտքագրել եք, ընտրեք միայն նրանք, որոնք ունեեն են այդ ծառայությունը'),
(53879, 2922, 14, 'եթե անվանումով, ապա ազգանվան մի մասը կամ ազգանունը, անունը'),
(53880, 2923, 14, 'եթե վճարված է ֊ով'),
(53881, 2924, 14, 'եթե անձը վախճանվել է, ապա մուտքագրեք մահվան ամսաթիվը'),
(53882, 2925, 14, 'SMTP կիրառման դեպքում սերվերի հոսթանունը կամ IP հասցեն'),
(53883, 2926, 14, 'SMTP կիրառման դեպքում սերվերի TCPպորտի համարը (սովորաբար 25)'),
(53884, 2927, 14, 'եթե չի աշխատում, ապա նշեք ՈՒՍԱՆՈՂ'),
(53885, 2928, 14, 'Եթե տարիքի ցուցադրման համար ընտրված է YMD, ապա անցնել միայն տարեթվերին, երբ պացիենտի տարիքը  մեծ է սույն արժեքից'),
(53886, 2929, 14, 'e-RX֊ը դերը  ePrescription /էլ․ դեղատոմս/֊ի  փոխարինելու դեպքում կարող է ազդել էլ դեղատոմսի աշխատանքի արդյունքի վրա։ Խնդիրների դեպքում կապվեք էլ; դեղատոմս տրամադրողի/մատակարարողի հետ։'),
(53887, 2930, 14, 'եթե չեք նշում "համընկնում", "պացիենտ" կստեղծվի/կհաստատվի'),
(53888, 2933, 14, 'եթե ցանկանում եք փոխել տվյալների տեսակը, կամ ավելացնել տողեր և/կամ սյուներ'),
(53889, 2934, 14, 'եթե ցանկանում եք թարմացնել վյալների բազան, տեղադրեք տվյալների բազայի zip ֆայլը հետևյալ քարտացուցակի մեջ'),
(53890, 2936, 14, 'մերժել'),
(53891, 2937, 14, 'հիվանդություն'),
(53892, 2938, 14, 'թերապեվտ'),
(53893, 2941, 14, 'ցուցադրման միջոց'),
(53894, 2942, 14, 'Պատվաստում'),
(53895, 2943, 14, 'Պատվաստման կոդ'),
(53896, 2945, 14, 'Պատվաստման ամսաթիվ'),
(53897, 2946, 14, 'Պատվաստանյութի պիտանիության ժամկետը'),
(53898, 2947, 14, 'Պատվաստանյութի խմբաքանակի համարը'),
(53899, 2948, 14, 'Պատվաստանյութն արտադրողը'),
(53900, 2949, 14, 'Պատվաստանյութի գրանցումը'),
(53901, 2950, 14, 'Պատվաստման հաշվետվություն'),
(53902, 2951, 14, 'Պատվաստման ծառայություն'),
(53903, 2952, 14, 'Պատվաստման անվանում'),
(53904, 2953, 14, 'Պատվաստումներ'),
(53905, 2954, 14, 'Պատվաստել'),
(53906, 2955, 14, 'Իմունոլոգիական'),
(53907, 2956, 14, 'Իմպլանտներ'),
(53908, 2957, 14, 'Ներմուծել/ներմուծում'),
(53909, 2961, 14, 'Վկայականը ներմուծել բրաուզեր'),
(53910, 2962, 14, 'Ներմուծման կարգավորումներ'),
(53911, 2964, 14, 'Ներմուծել պացիենտի տվյալները / Պացիենտի տվյալների ներմուծում'),
(53912, 2965, 14, 'Պացիենտի անձնական տվյալների ներմուծում'),
(53913, 2966, 14, 'Կարևոր կոդեր։'),
(53914, 2969, 14, 'Ներմուծված է հաշվապահությունից'),
(53915, 2972, 14, 'Բարելավվել է'),
(53916, 2973, 14, '֊ում'),
(53917, 2974, 14, '֊ում'),
(53918, 2975, 14, 'Յուրաանչչյուր աչքում'),
(53919, 2976, 14, 'ձախ աչքում'),
(53920, 2977, 14, 'քթանցքում'),
(53921, 2978, 14, 'Աշխատասենյակում'),
(53922, 2979, 14, 'Աջ աչքում'),
(53923, 2980, 14, 'տանը / տնային'),
(53924, 2981, 14, 'պասիվ / անգործ'),
(53925, 2982, 14, 'հանգստյան/ոչ աշխատանքային օրեր'),
(53926, 2983, 14, 'Մուտքային փոստարկղ'),
(53927, 2986, 14, 'Միացնել checksum'),
(53928, 2988, 14, 'Միացնել ոչ ակտիվ օգտվողներին'),
(53929, 2989, 14, 'Միացնել/ներառել չդասակարգվածները'),
(53930, 2990, 14, 'Միացնել/ներառել չհամակարգված տվյալները'),
(53931, 2991, 14, 'Միացնել/ներառել կենսական նշանակության օրգանները'),
(53932, 2992, 14, 'Միացնե՞լ/ներառե՞լ կենսական նշանակության օրգանների տվյալները'),
(53933, 2993, 14, 'Միացում/ներառում'),
(53934, 2994, 14, 'Եկամուտ'),
(53935, 2995, 14, 'Ուշադրություն պահանջող մուտքային տվյալներ'),
(53936, 2996, 14, 'թերի/անավարտ'),
(53937, 2997, 14, 'Հղիության արհեստական ընդհատման անավարտ բուժում'),
(53938, 2998, 14, 'անզսպություն'),
(53939, 2999, 14, 'Լաբորատոր հետազոտությունների արդյունքների ներառում հավաստագրված EHR տեխնոլոգիա՝ որպես համակարգված տվյալ'),
(53940, 3000, 14, 'Սխալ գաղտնաբառ'),
(53941, 3001, 14, 'աճած/ավելացած։'),
(53942, 3002, 14, 'Ապահովագրական փոխհատուցում'),
(53943, 3003, 14, 'Անորոշ'),
(53944, 3004, 14, 'Հնդկերեն'),
(53945, 3005, 14, 'Ցույց է տալիս շեղում/խանգարում'),
(53946, 3006, 14, 'Ցույց է տալիս ներկայում խնդրի առկայությունը'),
(53947, 3008, 14, 'Մասնագիտական օգտագործման ցուցանիշ'),
(53948, 3009, 14, 'Կարիքավոր/անապահով հիվանդ'),
(53949, 3010, 14, 'Կարիքավոր/անապահով հիվանդների հաշվետվություն'),
(53950, 3011, 14, 'Աղքատ/չքավոր'),
(53951, 3013, 14, 'Ինդոնեզիական'),
(53952, 3014, 14, 'Հղիության արհեստական ընդհատում'),
(53953, 3016, 14, 'Անհամապատասխան'),
(53954, 3017, 14, 'Վարակ / թարախակույտ'),
(53955, 3018, 14, 'Վարակ'),
(53956, 3019, 14, 'Անպտղության խորհրդատվություն'),
(53957, 3020, 14, 'Անպտղություն'),
(53958, 3021, 14, 'Գրիպ 1'),
(53959, 3022, 14, 'Գրիպ 2'),
(53960, 3023, 14, 'Հակագրիպային պատվաստում >= 50 տարեկան Պացիենտների համար'),
(53961, 3024, 14, 'Հակագրիպային պատվաստում >= 50 տարեկան Պացիենտների համար (CQM)'),
(53962, 3025, 14, 'Հակագրիպային պատվաստում'),
(53963, 3026, 14, 'Ինֆորմ․'),
(53964, 3027, 14, 'Ինֆորմ․ թեստ 1'),
(53965, 3028, 14, 'Ինֆորմ․ թեստ 2'),
(53966, 3029, 14, 'Ինֆորմ․ թեստ 3'),
(53967, 3030, 14, 'Ինֆորմ․ թեստ 4'),
(53968, 3031, 14, 'Ինֆորմ․ թեստ 5'),
(53969, 3032, 14, 'Ինֆորմ․ թեստ 6'),
(53970, 3034, 14, 'Ինհալացիաներ'),
(53971, 3036, 14, 'Նախնական բուժում'),
(53972, 3037, 14, 'Նախնական/սկզբնական օգտվող'),
(53973, 3038, 14, 'Վնասվ․/ Վերականգն․'),
(53974, 3039, 14, 'Ներարկելի'),
(53975, 3040, 14, 'Ներարկում'),
(53976, 3041, 14, 'Մարմնի վնասված մաս/հատվածը'),
(53977, 3042, 14, 'Վնասվածքի հետևանք'),
(53978, 3043, 14, 'Վնասվածք'),
(53979, 3044, 14, 'Վնասվածքի մեխանիզմ'),
(53980, 3045, 14, 'Վնասվածքի ընդհանուր/ամբողջական զեկույց'),
(53981, 3046, 14, 'Վնասվածքաբանական հետազոտություն'),
(53982, 3047, 14, 'Վնասվածքի տեսակը'),
(53983, 3048, 14, 'Վնասվածքի/հիվանդության հետ կապված'),
(53984, 3049, 14, 'հերթում'),
(53985, 3050, 14, 'Մուտքագրումը չի սկսվում MSH սեգմենտից'),
(53986, 3051, 14, 'Մուտքագրման դաշտ'),
(53987, 3052, 14, 'Միջազգային կարգավորման ինդեքս /ՄԿԻ/'),
(53988, 3053, 14, 'Տեղ․ 1'),
(53989, 3054, 14, 'Տեղ․ 2 կամ Տեղ․ 3'),
(53990, 3055, 14, 'Տեղ․ հասցեն'),
(53991, 3056, 14, 'Տեղ․ շտկումներ'),
(53992, 3057, 14, 'Տեղ․ վիրակապ'),
(53993, 3058, 14, 'Տեղ․ կոդ'),
(53994, 3059, 14, 'Տեղ․ խումբ'),
(53995, 3060, 14, 'Տեղ․ Անունը'),
(53996, 3061, 14, 'Տեղ․ գերավճարը'),
(53997, 3062, 14, 'Տեղ․ ապահովագրական վկայականը'),
(53998, 3063, 14, 'Տեղ․ հատուցումը'),
(53999, 3064, 14, 'Տեղ․ ամփոփագիրը'),
(54000, 3065, 14, 'Տեղ․ 1'),
(54001, 3066, 14, 'Տեղ․ 2'),
(54002, 3067, 14, 'Տեղ․ 3'),
(54003, 3068, 14, 'Տեղադրել'),
(54004, 3069, 14, 'Տեղադրումը ձախողվեց '),
(54005, 3070, 14, 'Տեղադրել հին/նախկին իրադարձությունները աղյուսակում'),
(54006, 3072, 14, 'Անքնություն'),
(54007, 3073, 14, 'Ստուգել/զննել մուտքը'),
(54008, 3074, 14, 'Քննություն/ստուգում/զննում'),
(54009, 3075, 14, 'Անկայունություն / մասնակի հոդախախտում'),
(54010, 3076, 14, 'ՏԵՂԱԴՐԵԼ'),
(54011, 3077, 14, 'Տեղադրել'),
(54012, 3078, 14, 'Տեղադրել կոդը'),
(54013, 3079, 14, 'Տեղադրել տվյալների բազան'),
(54014, 3080, 14, 'Տեղադրված տարբերակ'),
(54015, 3081, 14, 'Հրահանգավորված'),
(54016, 3082, 14, 'Հրահանգ/ցուցում'),
(54017, 3084, 14, 'Հրահանգներ/ցուցումներ'),
(54018, 3085, 14, 'Արտադրանքի նույնականացման անբավարար գույքագրում'),
(54019, 3086, 14, 'Ինսուլինից կախյալ շաքարախտ/շաքարային դիաբետ'),
(54020, 3087, 14, 'Ապահովագրություն'),
(54021, 3088, 14, 'Ապահովագրություն'),
(54022, 3091, 14, 'Ապահովագրական հաշվեկշիռ/մնացորդ'),
(54023, 3092, 14, 'Ապահովագրական հաշվեկշիռ/մնացորդ՝  առ'),
(54024, 3093, 14, 'Ապահովագրական ընկերություն'),
(54025, 3094, 14, 'Ապահովագրական ընկերություններ'),
(54026, 3095, 14, 'Ապահովագրական ընկերություն'),
(54027, 3096, 14, 'Ապահովագրական ընկերության Որոնում/Ավելացում'),
(54028, 3098, 14, 'Ապահովագրության ամսաթիվ'),
(54029, 3099, 14, 'Ապահովագրական տեղեկատվություն ֆայլում'),
(54030, 3100, 14, 'Ապահովագրության համարը'),
(54031, 3101, 14, 'Ապահովագրական վճարում'),
(54032, 3103, 14, 'Ապահովագրող'),
(54033, 3104, 14, 'Ապահովագրության տեսակներ'),
(54034, 3105, 14, 'Ապահովագրություններ'),
(54035, 3106, 14, 'Ապահովագրված'),
(54036, 3107, 14, 'Ընդունման/օգտագործման եզրակացություն'),
(54037, 3108, 14, 'Ընդունման ամսաթիվ'),
(54038, 3109, 14, 'Մտավոր անկում'),
(54039, 3110, 14, 'Ինտերլինգվա (ավտոմատ թարգմանության միջանկյալ/արհեստական լեզու)'),
(54040, 3113, 14, 'Ներքին սխալ ֊ չկա ընտրված էջ'),
(54041, 3114, 14, 'Ներքին սխալ ֊ պացիենտի ID ներկայացված չէ'),
(54042, 3115, 14, 'Բեռնված ֆայլի հասանելիության ներքին սխալ'),
(54043, 3116, 14, 'Ներքին սխալ'),
(54044, 3117, 14, 'Ներքին սխալ․ դեղամիջոցի ID նշված չէ'),
(54045, 3118, 14, 'Ներքին սխալ․ հնարավոր չէ գտնել MSH-10'),
(54046, 3119, 14, 'Ներքին սխալ․ պահանջ '),
(54047, 3120, 14, 'Ներքին սխալ․ այց '''),
(54048, 3121, 14, 'Ներքին սխալ․ pid/ կանացի սեռ․ օրգանների բորբոքային հիվ․/ կամ այցելության բացակայություն'),
(54049, 3122, 14, 'Ներքին սխալ․ այցի շրջանակներից դուրս ենք'),
(54050, 3123, 14, 'Ներքին նույնացուցիչ (pid)'),
(54051, 3126, 14, 'Ներքին ուղղորդումներ'),
(54052, 3127, 14, 'Ներքին  ժամանակի հավաքագրում/ծախս'),
(54053, 3128, 14, 'Միջազգային պարտավորություն/պարտականություն'),
(54054, 3129, 14, 'Թարգմանիչ'),
(54055, 3130, 14, 'Թարգմանչի կարիք կա՞'),
(54056, 3131, 14, 'Ինտերստիցիալ թոքային բորբոքում'),
(54057, 3132, 14, 'Դադար/ընդմիջում'),
(54058, 3133, 14, 'Դադար/ընդմիջում (րոպե)'),
(54059, 3134, 14, 'Հաղորդագրությունների ստուգման ինտերվալը (զրոյացնել միայն մեխ․/ձեռքով ստուգման դեպքում)'),
(54060, 3135, 14, 'Միջամտություն'),
(54061, 3136, 14, 'Ցուցաբերված/կատարված միաջմտություն'),
(54062, 3137, 14, 'Անհանդուրժողականություն'),
(54063, 3139, 14, 'միջմկանային'),
(54064, 3140, 14, 'ներերակային'),
(54065, 3141, 14, 'Ներածություն/ծանուցում'),
(54066, 3144, 14, 'Սխալ/անվավեր  սիմվոլ ֊ում'),
(54067, 3147, 14, 'Սխալ երկարություն ֊ի համար'),
(54068, 3148, 14, 'Ոչ թվային սխալ  սիմվոլ'),
(54069, 3149, 14, 'Ըստ կոդի սկզբնաղբյուրի սխալ կամ գոյություն չունեցող վճարող '),
(54070, 3150, 14, 'Սխալ հասցեատեր․ կրկին փորձեք'),
(54071, 3151, 14, 'Ծառայության սխալ կոդեր'),
(54072, 3152, 14, 'Սկզբնաղբյուրի սխալ անվանում/նշանակություն'),
(54073, 3153, 14, 'Սխալ օգտատեր կամ գաղտնաբառ'),
(54074, 3154, 14, 'Նյութական ակտիվների արժեք'),
(54075, 3155, 14, 'Նյութական ակտիվներ'),
(54076, 3157, 14, 'Դեղամիջոցների և ոչ դեղորայքային ակտիվների գույքագրում և վաճառք'),
(54077, 3158, 14, 'Գույքագրել և վաճառել միայն դեղորայք'),
(54078, 3159, 14, 'Այս պատվերի համար գույքագրում հասնաելի չէ'),
(54079, 3160, 14, 'Նյութական ակտիվների ցանկ'),
(54080, 3161, 14, 'Գույքագրման / Նյութական ակտիվների գործարքներ'),
(54081, 3162, 14, 'Հաշիվ֊ապրանքագիր'),
(54082, 3163, 14, 'հաշիվ֊ապրանքագիր'),
(54083, 3164, 14, 'Հաշիվ֊ապրանքագրի մնացորդ'),
(54084, 3165, 14, 'Հնարավոր չէ հրապարակել/տեղադրել հաշիվ֊ապրանքագրի մնացորդ․ ստեղծված այց չկա'),
(54085, 3166, 14, 'Հաշիվ֊ապրանքագրի ամսաթիվ'),
(54086, 3167, 14, 'Հաշիվ֊ապրանքագրում ամսաթիվ չկա'),
(54087, 3168, 14, 'Հաշիվ֊ապրանքագրի համարը'),
(54088, 3173, 14, 'Հաշիվ֊ապրանքագիր։'),
(54089, 3174, 14, '1. Թոքերի իդիոպաթիկ ֆիբրոս  2. Ընտանիքի պլանավորման միջազգային Ֆեդերացիա /ԸՊՄՖ/'),
(54090, 3175, 14, 'ԸՊՄՖ Հղիության արհեստական ընդհատում'),
(54091, 3176, 14, 'ԸՊՄՖ Հակաբեղմնավորիչ միջոցներ'),
(54092, 3177, 14, 'ԸՊՄՖ Սեռական և վերարտադրողական առողջության տվյլաներ'),
(54093, 3178, 14, 'ԸՊՄՖ Վիճակագրական զեկույց/հաշվետվություն'),
(54094, 3179, 14, 'ԸՊՄՖ Վիճակագրություն'),
(54095, 3180, 14, 'Պոլիոմելիտի կանխարգելման պատվաստում 1'),
(54096, 3181, 14, 'Պոլիոմելիտի կանխարգելման պատվաստում 2'),
(54097, 3182, 14, 'Պոլիոմելիտի կանխարգելման պատվաստում 3'),
(54098, 3183, 14, 'Պոլիոմելիտի կանխարգելման պատվաստում 4'),
(54099, 3184, 14, 'Իռլանդերեն'),
(54100, 3185, 14, 'Առիթմիա'),
(54101, 3186, 14, 'Գրգռվածություն / դյուրագրգռություն'),
(54102, 3187, 14, 'Գրգիռ'),
(54103, 3188, 14, 'սույն/այս տվյալների բազայի այլալեզու տարբերակն է'),
(54104, 3189, 14, 'սույն/այս տվյալների բազայի այլ տարբերակն է'),
(54105, 3190, 14, 'սույն/այս տվյալների բազայի ամենավերջին տարբերակն է'),
(54106, 3191, 14, 'պահանջված դաշտ է'),
(54107, 3192, 14, 'արմատական/հիմնական հանգույց է և չի կարող հեռացվել/ջնջվել'),
(54108, 3193, 14, 'սույն տվյալների բազայի շարունակությունն է'),
(54109, 3194, 14, 'ճի՞շտ/ընդունելի՞ է արդյոք  CVX կոդերի արտապատկերումը գոյություն ունեցող պատվաստումների վրա'),
(54110, 3195, 14, 'սխալ է տեղակայված կամ գոյություն չունի'),
(54111, 3197, 14, 'վավեր չէ/անվավեր է (տասնորդական կոտորակները ընդունելի են)'),
(54112, 3198, 14, 'PHP-ն կիրառո՞ւմ է անվտանգության ռեժիմ'),
(54113, 3201, 14, 'Արդյո՞ք ցուցակների տեքստը պետք է թարգմանել'),
(54114, 3202, 14, 'Այս ֆայլը կոդավորվա՞ծ է'),
(54115, 3203, 14, 'Սա կլինիկական կոդի տեսա՞կ է'),
(54116, 3204, 14, 'Սա ախտորոշմա՞ն տեսակ է'),
(54117, 3205, 14, 'Արդյո՞ք սա բժշկական խնդրի կոդի տեսակ է'),
(54118, 3206, 14, 'Արդյո՞ք սա դեղորայքի տեսակ է'),
(54119, 3207, 14, 'Արդյո՞ք սա միջամտության / ծառայության տեսակ է'),
(54120, 3208, 14, 'Ակտի՞վ է'),
(54121, 3209, 14, 'Կոդի այս տեսակն ակտի՞վ է'),
(54122, 3210, 14, 'Այս կոդն օգտագործվո՞ւմ է գանգատների մեջ'),
(54123, 3211, 14, 'Արդյո՞ք ամեն ինչ նորմալ է'),
(54124, 3212, 14, 'Արդյո՞ք այս տեսակը թաքցված է վճարման թերթիկից/էջից'),
(54125, 3214, 14, 'չափազանց երկար է'),
(54126, 3215, 14, 'ISO 639-2 Կոդ'),
(54127, 3216, 14, 'Խնդիր'),
(54128, 3217, 14, 'խնդիր'),
(54129, 3218, 14, 'Խնդրի առաջացման/ծագման ամսաթիվ'),
(54130, 3219, 14, 'խնդրի ID'),
(54131, 3220, 14, 'Խնդրի անվանում'),
(54132, 3221, 14, 'Խնդրի տեսակ'),
(54133, 3222, 14, 'Խնդրի տեսակներ'),
(54134, 3223, 14, 'Խնդիրներ'),
(54135, 3224, 14, 'Խնդրի ասպեկտներ (տրավմաներ / թերապիա / ալերգիա)'),
(54136, 3225, 14, 'Խնդրի ասպեկտներ (տրավմաներ / թերապիա / ալերգիա)։'),
(54137, 3226, 14, 'Խնդրի ասպեկտներ և այցեր'),
(54138, 3227, 14, 'Խնդրի ասպեկտներ և այցեր ֊ի համար'),
(54139, 3228, 14, 'Խնդիրների հասանելիություն չկա'),
(54140, 3229, 14, 'Խնդիրների բաժիններ'),
(54141, 3230, 14, 'Իտալերեն'),
(54142, 3231, 14, 'Կետ'),
(54143, 3232, 14, 'Կետ'),
(54144, 3233, 14, 'Կետեր/պարագրաֆներ'),
(54145, 3234, 14, 'Կետերի/նյութերի բեռնումը ձախողվեց'),
(54146, 3238, 14, 'Հնվ․'),
(54147, 3239, 14, 'Հունվար'),
(54148, 3240, 14, 'Ճապոներեն'),
(54149, 3241, 14, 'Դեղնախտ'),
(54150, 3243, 14, 'Աշխատանքի նկարագիր'),
(54151, 3244, 14, 'Աշխատանքի ID'),
(54152, 3245, 14, 'Հոդախախտություն / հոդերի անկայունություն'),
(54153, 3246, 14, 'Հոդացավ'),
(54154, 3247, 14, 'Հոդերի գերձգում/'),
(54155, 3248, 14, 'Հուլ․'),
(54156, 3249, 14, 'Հուլիս'),
(54157, 3250, 14, 'Հուն․'),
(54158, 3251, 14, 'Հունիս'),
(54159, 3252, 14, 'Քիչ ներքև՝ կապույտ հատվածում է ստուգիչ ինֆորմացիան, որտեղ լրացնում եք որոնման պարամետրերը։ Կարող եք որոնել պացիենտի անունով, քարտի համարով, այցի համարով, ծառայության մատուցման ամսաթվով կամ սրանց որևէ համակցումով։ Կարող եք նաև ընտրել, թե որտեղ ցուցադրվեն բոլոր հաշիվ֊ապրանքագրերը, բացված հ֊աերը, կամ միայն պարտքի մնացորդ ունեցողները․ Սեղմեք ՈՐՈՆԵԼ կոճակին՝ որոնումն իրականացնելու համար։'),
(54160, 3253, 14, 'Միայն իմը / ինձ պատկանողները'),
(54161, 3254, 14, 'Հիմնավորման գրառումներ'),
(54162, 3255, 14, 'Հաստատել'),
(54163, 3256, 14, 'Հաստատել/պահպանել'),
(54164, 3258, 14, 'k, ահա մնացածը'),
(54165, 3264, 14, 'Բանալի'),
(54166, 3265, 14, 'Բանալի բառ'),
(54167, 3266, 14, 'կգ'),
(54168, 3267, 14, 'կգ/մ^2'),
(54169, 3269, 14, 'Երիկամային քաղցկեղ'),
(54170, 3270, 14, 'Երիկամային անբավարարություն'),
(54171, 3271, 14, 'Երիկամային վարակ/ինֆեկցիա'),
(54172, 3272, 14, 'Երիկամային քարեր'),
(54173, 3273, 14, 'Երիկամների փոխպատվաստում'),
(54174, 3277, 14, 'Ծունկ'),
(54175, 3278, 14, 'Ծնկների խնդիր'),
(54176, 3279, 14, 'Ծնկահոդի փոխարինում'),
(54177, 3282, 14, 'Կորեերեն'),
(54178, 3283, 14, 'Քրդերեն'),
(54179, 3286, 14, 'Լաբորատորիա'),
(54180, 3287, 14, 'Լաբորատոր փաստաթղթեր'),
(54181, 3288, 14, 'Լաբորատոր փոխանակման կայքի հասցեն'),
(54182, 3289, 14, 'Լաբորատոր փոխանակման կայքի Id'),
(54183, 3290, 14, 'Լաբորատոր փոխանակման սիմվոլիկ Id'),
(54184, 3291, 14, 'Լաբ․ հետազոտության հրաման'),
(54185, 3292, 14, 'Լաբ․ հետազոտության ամփոփ նկարագիր'),
(54186, 3293, 14, 'Լաբ․ հետազոտության ամփոփ նկարագիր'),
(54187, 3294, 14, 'Լաբ․ հարցման կարգավիճակ'),
(54188, 3295, 14, 'Լաբ․ հետազոտությունների զեկույց'),
(54189, 3296, 14, 'Լաբ․ հետազոտության արդյունքներ'),
(54190, 3297, 14, 'Լաբ․ հետազոտության արդյունքներ'),
(54191, 3298, 14, 'Լաբ․ հետազոտության արդյունքների կատեգորիայի անվանումը'),
(54192, 3299, 14, 'Լաբ․ հետազոտության արդյունքների զեկույց/հաշվետվություն'),
(54193, 3300, 14, 'Լաբորատոր ծառայություններ'),
(54194, 3301, 14, 'Լաբորատոր հետազոտության արդյունքներ'),
(54195, 3302, 14, 'Լաբորատոր/ֆայլ'),
(54196, 3303, 14, 'Պիտակ / նշաթուղթ'),
(54197, 3304, 14, 'Պիտակը / նշաթուղթը չի կարող դատարկ լինել'),
(54198, 3305, 14, 'Պիտակ / նշաթուղթ֊ի սյուներ'),
(54199, 3306, 14, 'Այս տիպի/ձևի/տեսակի նշաթուղթ/պիտակ'),
(54200, 3307, 14, 'Piտակի սյուները պետք է լինեն 1֊999 թվերի միջակայքում'),
(54201, 3308, 14, 'Պիտակներ / նշաթղթեր'),
(54202, 3311, 14, 'Լաբորատորիաներ'),
(54203, 3312, 14, 'Պատռվածք / մաշկի վիճակ'),
(54204, 3313, 14, 'Պատռվածք / քայքայում/ճանկռվածք'),
(54205, 3315, 14, 'Հորիզոնական'),
(54206, 3316, 14, 'Լեզու'),
(54207, 3317, 14, 'Լեզվի կոդ'),
(54208, 3318, 14, 'Լեզվի սահմանաումն ավելացված է'),
(54209, 3319, 14, 'Լեզվի ինտերֆեյս գործիք'),
(54210, 3320, 14, 'Լեզուների ցանկ (գրել, միայն ավելացնել ըստ ցանկության)'),
(54211, 3321, 14, 'Լեզվի անվանում'),
(54212, 3322, 14, 'Լեզու։'),
(54213, 3324, 14, 'Լաոսերեն'),
(54214, 3325, 14, 'Վերջին'),
(54215, 3326, 14, 'Վերջին ակտիվության ամսաթիվ'),
(54216, 3327, 14, 'Վերջին ապենդեկտոմիայի /կույր աղիքի հեռացման/ ամսաթիվ'),
(54217, 3328, 14, 'Վերջին հաշվի ամսաթիվ'),
(54218, 3329, 14, 'Շնչառական վերջին հետազոտություն'),
(54219, 3330, 14, 'Անցած օրացուցային'),
(54220, 3331, 14, 'Կատարակտայի վերջին վիրահատությունը'),
(54221, 3332, 14, 'Վերջին խոլեցիստէկտոմիա /լեղապարկի հեռացում/'),
(54222, 3333, 14, 'Վերջին այց'),
(54223, 3334, 14, 'Գինեկոլոգիական վերջին հետազոտությունը'),
(54224, 3335, 14, 'Սրտի վերջին վիրահատությունը'),
(54225, 3336, 14, 'Ճողվածքի վերջին բուժում / շտկում'),
(54226, 3337, 14, 'Կոնքազդրային հոդի փոխարինում'),
(54227, 3338, 14, 'Վերջին հիստերէկտոմիա /արգանդի մասնակի կամ ամբողջական հեռացում/'),
(54228, 3339, 14, 'Ծնկի վերջին փոխարինում'),
(54229, 3341, 14, 'Վերջին մամոգրաֆիան'),
(54230, 3342, 14, 'Վերջին դաշտանի ցիկլը'),
(54231, 3343, 14, 'Անցած ամիս'),
(54232, 3344, 14, 'Ազգանուն'),
(54233, 3345, 14, 'ազգանուն'),
(54234, 3346, 14, 'Ազգանուն։'),
(54235, 3347, 14, 'Վերջին ֆիզզննում'),
(54236, 3348, 14, 'Շագանակագեղձի վերջին զննում'),
(54237, 3349, 14, 'Ուղիղ աղու/Rectal վերջին հետազոտում'),
(54238, 3350, 14, 'Վերջին անգամ վերանայվել է'),
(54239, 3351, 14, 'Վերջին մեկնարկը տրվել է ֊ին'),
(54240, 3352, 14, 'Վերջին անգամ պահպանվել է'),
(54241, 3353, 14, 'Վերջին սիգմայաձև (S֊աձև; կիսալուսնաձև)/ կոլոնոսկոպիա'),
(54242, 3355, 14, 'Վերջին տոնսիլեկտոմիան /նշագեղձերի հեռացում/'),
(54243, 3356, 14, 'Վերջին թարմացումը ֊ի միջոցով'),
(54244, 3357, 14, 'Վերջին ստուգումը/հաստատումը ֊ին'),
(54245, 3358, 14, 'Վերջին այցը'),
(54246, 3359, 14, 'Վերջին ռենտգենը'),
(54247, 3360, 14, 'Ուշ/ուշացած/ կրկնություն (2-12 ամ.)'),
(54248, 3361, 14, 'Լատերալ/կողային Կոճ։'),
(54249, 3362, 14, 'Լատերալ/կողային կոճ։'),
(54250, 3363, 14, 'Աջլիկություն / Ձախլիկություն'),
(54251, 3367, 14, 'Ամենավերջին այցը կամ խորհրդատվությունը'),
(54252, 3368, 14, 'Լատիներեն'),
(54253, 3369, 14, 'Լատվիերեն'),
(54254, 3372, 14, 'Դասավորություն /մակետ'),
(54255, 3373, 14, 'Դասավորությունինց/նախագծից ելնելով'),
(54256, 3374, 14, 'Դասավորության/մակետի խմբագիր'),
(54257, 3375, 14, 'Մակետների խմբեր'),
(54258, 3376, 14, 'Մակետի ձև'),
(54259, 3378, 14, 'Դասավորությամբ պայմանավորվ այցերի ձևեր'),
(54260, 3379, 14, 'Մակետներ'),
(54261, 3380, 14, 'ֆունտ'),
(54262, 3381, 14, 'ֆունտեր'),
(54263, 3382, 14, 'Լիպոպրոտեինների ցածր խտություն'),
(54264, 3383, 14, 'Եթե դեռ ակտիվ է, թողնել դատարկ'),
(54265, 3384, 14, 'Ֆայլի նախնական անվանումը պահպանելու համար դաշտը թողնել դատարկ'),
(54266, 3385, 14, 'Նախկին գաղտնաբարը պահպանելու համար դաշտը թողնել դատարկ'),
(54267, 3386, 14, 'Թողնել հաղորդագրություն ֊ով'),
(54268, 3387, 14, 'Դուրս եկեք այս ձևից'),
(54269, 3388, 14, 'Գաղտնաբառի դաշտը դատարկ թողնելով փաստաթուղթը չի կոդավորվի'),
(54270, 3390, 14, 'Ձախ / ձախ կողմում'),
(54271, 3391, 14, 'Ձախ ականջ'),
(54272, 3392, 14, 'Ձախ ականջ'),
(54273, 3393, 14, 'Ձախ լուսանցք (մմ)'),
(54274, 3394, 14, 'Ձախ / ձախ կողմում։'),
(54275, 3395, 14, 'Ձախ / ձախ կողմում։ '),
(54276, 3396, 14, 'Ոտքի ցավ / կծկումներ'),
(54277, 3397, 14, 'Օրինական / իրավական'),
(54278, 3399, 14, 'Էջի հաստատված/օրինական չափ'),
(54279, 3400, 14, 'Լեգենդ։'),
(54280, 3401, 14, 'Երկարություն'),
(54281, 3402, 14, 'Ձևափոխիչի երկարությունը․ եթե դրված չէ, ապա 0'),
(54282, 3403, 14, 'Քիչ, քան'),
(54283, 3404, 14, 'Քիչ կամ հավասար'),
(54284, 3405, 14, 'Քիչ/ո խիստ անձնական տեղեկություններ (գրել, միայն ավելացնել ըստ ցանկության)'),
(54285, 3406, 14, 'Նամակ / տառ'),
(54286, 3407, 14, 'Նամակի գեներատոր'),
(54287, 3408, 14, 'Թղթի՝ նամակային չափ'),
(54288, 3409, 14, 'Բժշկի նշումներով/ստորագրությամբ բլանկ'),
(54289, 3410, 14, 'Պացիենտի ստորագրությամբ բլանկ'),
(54290, 3411, 14, 'Հրատապության/կարևորության  աստիճան'),
(54291, 3412, 14, 'Պատասխանատվություն'),
(54292, 3413, 14, 'Բժշկական պատասխանատվություն'),
(54293, 3414, 14, 'Լիցենզիա / ID'),
(54294, 3419, 14, 'Լիցենզավորված նշանակողի/պատասխանատուի ազգանունը'),
(54295, 3420, 14, 'Լիցենզավորված նշանակողի/պատասխանատուի NPI'),
(54296, 3421, 14, 'Լիցենզավորված նշանակողի/պատասխանատուի UPIN'),
(54297, 3423, 14, 'Կենսակերպ / ապրելակերպ'),
(54298, 3424, 14, 'Կենսակերպի վիճակը/մակարդակը'),
(54299, 3425, 14, 'Ջլերի գերձգում կամ պատռվածք'),
(54300, 3426, 14, 'Թեթև/քիչ ծխող'),
(54301, 3428, 14, 'Միջոցարումների/իրադարձությունների սահմանափակում'),
(54302, 3429, 14, 'Սահմանափակումներ'),
(54303, 3431, 14, 'Հղում'),
(54304, 3432, 14, 'Հղում պացիենտին'),
(54305, 3433, 14, 'Կապված'),
(54306, 3434, 14, 'Կապված/միացված փաստաթուղթ'),
(54307, 3435, 14, 'Փոխկապակցված միջամտության պահանջ/հրաման'),
(54308, 3436, 14, 'Փաստաթղթի հետ կապված'),
(54309, 3437, 14, 'Միջամտության պահանջի հետ կապված'),
(54310, 3438, 14, 'Ցանկ/ցուցակ'),
(54311, 3439, 14, 'Ցանկավանդակ'),
(54312, 3440, 14, 'Ցանկավանդակ'),
(54313, 3441, 14, 'Ցանկավանդակ գրել/ավելացնել'),
(54314, 3442, 14, 'Ցանկավանդակ գրել/ավելացնել'),
(54315, 3443, 14, 'Ցանկի խմբագրիչ'),
(54316, 3444, 14, 'Ցուցակագրել/ցուցադրել այցերը'),
(54317, 3445, 14, 'Ցուցակագրել/ցուցադրել խմբերը'),
(54318, 3446, 14, 'Ցուցակագրել/ցուցադրել ապահովագրական Ընկերությունները'),
(54319, 3448, 14, 'Ցուցակի /ցանկի տարրերը չեն կարող սկսվել թվերով'),
(54320, 3449, 14, 'Ցուցակի /ցանկի տարրերը պարունակում են չթույլատրված սիմվոլ(ner)'),
(54321, 3451, 14, 'Տպել ցուցակները'),
(54322, 3452, 14, 'Ցանկի անվանում'),
(54323, 3453, 14, 'Ցանկի անվանումները չեն կարող սկսվել թվերով'),
(54324, 3454, 14, 'Ցուցակագրել/ցուցադրել նշանակումները'),
(54325, 3455, 14, 'Ցանկը կիրառվում է վերոնշյալ երկրի տվյալների տարբերակով'),
(54326, 3456, 14, 'Ցանկը կիրառվում է վերոնշյալ նահանգի/մարզի տվյալների տարբերակով'),
(54327, 3457, 14, 'RFC 5425 TLS syslog սերվերի լսողական պորտ'),
(54328, 3458, 14, 'Ցանկեր/ցուցակներ'),
(54329, 3459, 14, 'Լիտվերեն'),
(54330, 3460, 14, 'Կտակ'),
(54331, 3461, 14, 'Ստորին ձախ վերջույթ'),
(54332, 3462, 14, 'Վերջին դաշտան'),
(54333, 3463, 14, 'Բեռնել ամփոփագիրը'),
(54334, 3464, 14, 'Բեռնել բացատրությունները/սահմանումները'),
(54335, 3465, 14, 'Բեռնել լաբորատոր կարգավորումները'),
(54336, 3469, 14, 'ՀԱՋՈՂՈՒԹՅԱՄԲ ԲԵՌՆՎԱԾ Է։ Կոդերը ներմուծված են'),
(54337, 3470, 14, 'ԲԵՌՆՎՈւՄ Է'),
(54338, 3471, 14, 'Ֆայլերը բեռնվում են տվյալների բազա։ ՄԻ քանի րոպե կտևի'),
(54339, 3472, 14, 'Ընկալման կրճատում'),
(54340, 3473, 14, 'Տեղային'),
(54341, 3476, 14, 'Տեղային'),
(54342, 3477, 14, 'Բնակավայր / տեղ'),
(54343, 3478, 14, 'Տեղակայում / տեղադրում/ տեղավորություն'),
(54344, 3479, 14, 'libreehr  մեքենայի տեղակայումը կարող է պարունակել գաղտնի տվյալներ․ ուստի խորհուրդ է տրվում օգտվելուց հետո ձեռքով ջնջել դրանք'),
(54345, 3480, 14, 'Այս /սույն  խմբաքանակի տեղակայումը'),
(54346, 3481, 14, 'Չմասնավորեցված / անորոշ տեղակայում'),
(54347, 3482, 14, 'Վայր, ուր Hylafax֊ը պահեստավորում է  ֆաքսերը'),
(54348, 3483, 14, 'Սկանավորված ֆայլերի պահեստավորման վայր'),
(54349, 3484, 14, 'Վայր/տեղ/ տաղակայում։'),
(54350, 3485, 14, 'Արգելափակել'),
(54351, 3486, 14, 'Արգելափակել էլ․ ստորագրության  ձևն անհատապես'),
(54352, 3487, 14, 'Արգելափակել էլ․ ստորագրությամբ այցերն ու դրանց ձևերը'),
(54353, 3488, 14, 'Արգելափակե՞լ'),
(54354, 3489, 14, 'Արգելափակված է'),
(54355, 3492, 14, 'Մուտք / Մուտք գործել'),
(54356, 3493, 14, 'Մուտք / Մուտք գործել'),
(54357, 3494, 14, 'Ելք / Դուրս գալ'),
(54358, 3495, 14, 'Մուտք է գործել'),
(54359, 3496, 14, 'Մուտք է գործել որպես։'),
(54360, 3497, 14, 'Մուտք է գործել որպես '),
(54361, 3498, 14, 'Դուրս է եկել'),
(54362, 3499, 14, 'Գրանցում'),
(54363, 3500, 14, 'Մուտք / Մուտք գործել'),
(54364, 3501, 14, 'Մուտք / Մուտքaնուն'),
(54365, 3502, 14, 'WordPress օգտատիրոջ՝ պորտալ մուտքի մուտքանուն'),
(54366, 3505, 14, 'Ելք / Դուրս գալ'),
(54367, 3506, 14, 'ելք / դուրս գալ'),
(54368, 3507, 14, 'Տեղեկամատյաններ /գրանցամատյաններ'),
(54369, 3510, 14, 'Փնտրել'),
(54370, 3511, 14, 'Խմբաքանակ'),
(54371, 3512, 14, 'Խմբաքանակի  ID֊ն բացթողնված է'),
(54372, 3513, 14, 'Խմբաքանակի համար'),
(54373, 3514, 14, 'Ցածր / թույլ/ ստորին'),
(54374, 3515, 14, 'Ցածր առաջնայնություն'),
(54375, 3516, 14, 'Կարճեցված ոտք'),
(54376, 3517, 14, 'Նվազագույն/ամենացածր առաջնայնություն'),
(54377, 3519, 14, 'Ողնաշարի գոտկային հատված'),
(54378, 3520, 14, 'ԼԱՆՉ /Կեսօրյա նախաճաշ/'),
(54379, 3521, 14, 'լանչ /Կեսօրյա նախաճաշ/'),
(54380, 3522, 14, 'Թոքերի քաղցկեղ'),
(54381, 3523, 14, 'Թոքերի քաղցկեղի վիրահատություն'),
(54382, 3524, 14, 'ԹՈՔԵՐ։'),
(54383, 3525, 14, 'Թոքեր։'),
(54384, 3526, 14, 'Գայլախտ'),
(54385, 3528, 14, 'M'),
(54386, 3529, 14, 'MA Կատեգորիա'),
(54387, 3530, 14, 'MA Բաժանորդի/հաճախորդի ընդունման մերժում'),
(54388, 3531, 14, 'MA վիճակագրություն'),
(54389, 3532, 14, 'Մակեդոներեն'),
(54390, 3533, 14, 'Փոստն ուղարկված է'),
(54391, 3534, 14, 'Հիմնական/գլխավոր'),
(54392, 3535, 14, 'Հիմնական հասցե'),
(54393, 3536, 14, 'Էկրանի հիմնական/գլխավոր շրջանակը/մակերեսը'),
(54394, 3537, 14, 'Պահպանել ակտիվ դեղորայքային ալերգիայի ցանկը'),
(54395, 3538, 14, 'Պահպանել ակտիվ դեղորայքային ցանկը'),
(54396, 3539, 14, 'Պահպանել ընթացիք և ակտիվ ախտորոշումների թարմացված խնդրացանկը'),
(54397, 3540, 14, 'Կատարել փոփոխություններ ընթացիկ կատեգորիաներում'),
(54398, 3541, 14, 'Ստեղծել նոր այց ֊ի համար'),
(54399, 3542, 14, 'Համոզվեք, որ  "'),
(54400, 3545, 14, 'Դիսկոմֆորտ։'),
(54401, 3548, 14, 'Արական'),
(54402, 3549, 14, 'Արական սեռի պահպանակներ'),
(54403, 3550, 14, 'Արական VSC'),
(54404, 3552, 14, 'Մամոգրաֆիա'),
(54405, 3553, 14, 'Կառավարում'),
(54406, 3555, 14, 'Մոդուլների կառավարում'),
(54407, 3556, 14, 'Թարգմանությունների կառավարում'),
(54408, 3557, 14, 'Կառավարում'),
(54409, 3558, 14, 'Պարտադիր և սահմանված դաշտեր'),
(54410, 3559, 14, 'Միայն պարտադիր կամ սահմանված դաշտերը․ կրկնակի ստուգում, ոչ մի որոնում'),
(54411, 3560, 14, 'Միայն պարտադիր կամ սահմանված դաշտերը․ որոնում և կրկնակի ստուգում,'),
(54412, 3561, 14, 'Ձեռնարկ / տեղեկագիրք'),
(54413, 3562, 14, 'Մեխանիկական ուղերձ'),
(54414, 3563, 14, 'Արտադրող'),
(54415, 3568, 14, 'Մարտ'),
(54416, 3569, 14, 'Ընտանեկան դրություն'),
(54417, 3570, 14, 'Նշել որպես հաշվեգրված/հաշվարկված/վճարված'),
(54418, 3571, 14, 'Նշել որպես վճարված, սակայն բաց թողնել ներկայացված հաշիվը'),
(54419, 3572, 14, 'Նշել որպես մաքրված'),
(54420, 3573, 14, 'Նշել որպես չվճարված'),
(54421, 3574, 14, 'Նշել սույն հաշվետվությունները որպես վերանայված'),
(54422, 3575, 14, 'Նշված է որպես մաքուր/մաքրված'),
(54423, 3576, 14, 'Ամուսնացած'),
(54424, 3578, 14, 'Դիմակ / քողարկում'),
(54425, 3579, 14, 'Հաշիվներ համարների քողարկում'),
(54426, 3580, 14, 'Պացիենտի ID֊ի/ անձնական տվյալների քողարկում'),
(54427, 3581, 14, 'Ապրանքի ID֊ի/ անձնական տվյալների քողարկում'),
(54428, 3582, 14, 'Համապատասխանություն'),
(54429, 3583, 14, 'Փաստերի/դեպքերի համընկնում/համապատասխանություն'),
(54430, 3584, 14, 'Գտնվել է համապատասխանություն/համընկնում'),
(54431, 3590, 14, 'Մատրիցա'),
(54432, 3591, 14, 'Մաքսիմում'),
(54433, 3592, 14, 'Հասել է ֆայլերի առավելագույն քանակին/հաշվին ֊ անունները բեռնել ներքև'),
(54434, 3595, 14, 'Առավելագույն տարիք'),
(54435, 3596, 14, 'Առավելագույ սիմվոլներ/ սիմվոլների առավելագույն քանակ'),
(54436, 3597, 14, 'Ելքից առաջ առավելագույն պարապ ժամանակը վայրկյաններով․ նախնականը 7200վրկ  (2 ժամ).'),
(54437, 3600, 14, 'Առավելագույն խելամիտ պահուստը․ եթե չի օգտագործվում, ապա - 0'),
(54438, 3601, 14, 'Առավելագույն չափը'),
(54439, 3602, 14, 'Առավելագույն չափը  0֊ի մուտքագրումը կթույլատրի ցանկացած չափ)'),
(54440, 3603, 14, 'Մայիս'),
(54441, 3605, 14, 'մկգ'),
(54442, 3607, 14, 'Նշանակում է, որ վերջին երեք գաղտնաբառերից և ոչ մեկը թույլատրված չէ գաղտնաբառի փոփոխման համար'),
(54443, 3609, 14, 'Չափման միավորների խմբի կոդը'),
(54444, 3611, 14, 'Չափում'),
(54445, 3612, 14, 'Ներքին կոճ'),
(54446, 3613, 14, 'Անվճար բուժօգնություն /անապահովների բժշկական ապահովագրության համակարգ/'),
(54447, 3614, 14, 'Բժշկական'),
(54448, 3615, 14, 'Բժշկական աբորտ'),
(54449, 3616, 14, 'Բժշկական վարչակազմ'),
(54450, 3617, 14, 'Անամնեզ /Հիվանդության պատմություն/'),
(54451, 3618, 14, 'Բժշկական հարց'),
(54452, 3619, 14, 'Բժշկական հարց'),
(54453, 3620, 14, 'Բժշկական խնդիր'),
(54454, 3621, 14, 'Բժշկական խնդիր'),
(54455, 3622, 14, 'Բժշկական խնդիրների հարցաշար'),
(54456, 3623, 14, 'Բժշկական խնդիրներ'),
(54457, 3624, 14, 'Բժշկական գրանցում / Բժշկական քարտ'),
(54458, 3625, 14, 'Բժշկական գրանցում/ Հիվանդության պատմություն #'),
(54459, 3626, 14, 'Բժշկական գրանցումներ/ Հիվանդության պատմություններ'),
(54460, 3627, 14, 'Բժշկական գրանցումներն ուղարկված են'),
(54461, 3629, 14, 'Բժշկական ամփոփագիրը տրված է'),
(54462, 3630, 14, 'Բժշկական համակարգ'),
(54463, 3631, 14, 'Բուժման մեթոդը / տեսակը'),
(54464, 3632, 14, 'Հիվանդության պատմություն  (գրել, միայն ավելացնել ըստ ցանկության)'),
(54465, 3633, 14, 'Անվճար բուժօգնություն Մաս Բ'),
(54466, 3634, 14, 'Անվճար բուժօգնության հանձնարարողը/ուղղորդողը հանեց բուժօգնություն ցուցաբերողն է'),
(54467, 3635, 14, 'Դեղամիջոց'),
(54468, 3636, 14, 'Դեղորայքային ալերգիայի ցանկ'),
(54469, 3637, 14, 'Դեղորայքային հարցերի ցանկ'),
(54470, 3638, 14, 'Դեղամիջոցներ/դեղորայքի ցանկ'),
(54471, 3639, 14, 'Դեղորայքի համաձայնեցումն իրականացվա՞ծ է /'),
(54472, 3640, 14, 'Դեղամիջոցներ'),
(54473, 3641, 14, 'Դեղամիջոցներ։'),
(54474, 3642, 14, 'Դեղամիջոցի բացթողման միավորը'),
(54475, 3643, 14, 'Միջին'),
(54476, 3645, 14, 'Ասոցիացիայի անդամներ վիճակագրական զեկույց/հաշվետվություն'),
(54477, 3646, 14, 'Հիշողության խնդիր'),
(54478, 3647, 14, 'Տղամարդիկ'),
(54479, 3648, 14, 'Տղամարդիկ և կանայք'),
(54480, 3649, 14, 'Միայն տղամարդիկ'),
(54481, 3650, 14, 'Դաշտանի առաջին երևույթը'),
(54482, 3651, 14, 'Դաշտանադադար'),
(54483, 3652, 14, 'Դաշտանային արյունահոսություն / Առատ դաշտան'),
(54484, 3653, 14, 'Դաշտանային ցիկլ'),
(54485, 3654, 14, 'Հոգեկան հիվանդություն'),
(54486, 3655, 14, 'Մենյուի տեքստ'),
(54487, 3656, 14, 'Մենյուներ'),
(54488, 3657, 14, 'Միացնել/զետեղել'),
(54489, 3658, 14, 'Միացումն/ զետեղումն կատարված է'),
(54490, 3659, 14, 'Միացնել/զետեղել պացիենտներին'),
(54491, 3661, 14, 'Հաղորդագրություն / Նամակ'),
(54492, 3662, 14, 'Հաղորդագրությունների և հիշեցումների կենտրոն'),
(54493, 3663, 14, 'Հաղորդագրության/Նամակի  բովանդակությունը/պարունակությունը տեքստային չէ, ուստի այն պահպանվել է որպես փաստաթուղթ'),
(54494, 3664, 14, 'Հաղորդագրություն / Նամակ պացիենտից');
INSERT INTO `lang_definitions` VALUES
(54495, 3665, 14, 'Հաղորդագրությունն ուղարկված է'),
(54496, 3666, 14, 'Հաղորդագրության կարգավիճակը'),
(54497, 3667, 14, 'Հաղորդագրության /նամակի Վերնագիր'),
(54498, 3668, 14, 'Պացիենտին ուղղված հաղորդագրություն /նամակ'),
(54499, 3669, 14, 'Հաղորդագրության / Նամակի  տեսակը'),
(54500, 3670, 14, 'ՀԱՂՈՐԴԱԳՐՈւԹՅՈւՆ։'),
(54501, 3671, 14, 'Հաղորդագրություն'),
(54502, 3672, 14, 'Այսօրվա ուղարկած հաղորդագրությունը'),
(54503, 3673, 14, 'Մեթոդ'),
(54504, 3674, 14, 'Մեթոդ և առանձնահատուկ արդյունք'),
(54505, 3675, 14, 'Էլ․փոստի ուղարկման մեթոդ'),
(54506, 3676, 14, 'Ոչնչացման մեթոդ'),
(54507, 3677, 14, 'Մեկսիկացի/մեկսիկական ծագման ամերիկացի/ չիկանո'),
(54508, 3679, 14, 'մգ'),
(54509, 3680, 14, 'մգ/1խոր․սմ'),
(54510, 3681, 14, 'մգ/2խոր․սմ'),
(54511, 3682, 14, 'մգ/3խոր․սմ'),
(54512, 3683, 14, 'մգ/4խոր․սմ'),
(54513, 3684, 14, 'մգ/5խոր․սմ'),
(54514, 3685, 14, 'մգ/դլ'),
(54515, 3686, 14, 'Միջին'),
(54516, 3687, 14, 'Հայրանուն'),
(54517, 3688, 14, 'Հայրանուն'),
(54518, 3690, 14, 'Միջին մակարդակի  DEA մասնագետ/պատասխանատու'),
(54519, 3691, 14, 'Միջին մակարդակի  պատասխանատուի  անունը'),
(54520, 3692, 14, 'Միջին մակարդակի  պատասխանատուի  ազգնունը'),
(54521, 3693, 14, 'Միջին մակարդակի  պատասխանատուի  բնորոշիչ'),
(54522, 3694, 14, 'Միջին մակարդակի  պատասխանատուի  UPIN'),
(54523, 3695, 14, 'Դեմքի արտահայտություն'),
(54524, 3696, 14, 'Վերբնակի՞չ  է, թե՞ սեզոնային աշխատող'),
(54525, 3697, 14, 'Վերբնակիչ/ սեզոնային աշխատող'),
(54526, 3698, 14, 'մլն/խոր․մմ'),
(54527, 3703, 14, 'նվազագույն'),
(54528, 3704, 14, 'նվազագույն'),
(54529, 3705, 14, 'Նվազագույն տարիք'),
(54530, 3708, 14, 'րոպե'),
(54531, 3709, 14, 'րոպեներ'),
(54532, 3710, 14, 'Րոպեներ'),
(54533, 3712, 14, 'Այլ/խառը'),
(54534, 3713, 14, 'Այլ/խառը հաշիվների տարբերակներ'),
(54535, 3714, 14, 'HCFA-1500 այլ/խառը հաշիվների տարբերակներ'),
(54536, 3715, 14, 'HCFA այլ/խառը հաշիվների տարբերակներ'),
(54537, 3716, 14, 'Տրբեր'),
(54538, 3717, 14, 'Բաց թողնված'),
(54539, 3718, 14, 'բաց թողնված'),
(54540, 3719, 14, 'Պարտադիր դաշտ է բաց թողնված'),
(54541, 3720, 14, 'Վճարումը բացթողնված է'),
(54542, 3721, 14, 'Բացակայում է միայն ձևափոխիչը'),
(54543, 3722, 14, 'Բաց թողնված կամ անվավեր է'),
(54544, 3723, 14, 'PID բացակայում է'),
(54545, 3724, 14, 'Հաշվետվության ամսաթիվը բաց թողնված է'),
(54546, 3725, 14, 'Կոդի մեջ վճարողից հետո բացակայում է սլեշը '),
(54547, 3726, 14, 'Խառնված'),
(54548, 3727, 14, 'մլ'),
(54549, 3728, 14, 'MM/DD/YYYY ԱԱ/ՕՕ/ՏՏ'),
(54550, 3731, 14, 'Մայրական մահացության մակարդակ 1'),
(54551, 3732, 14, 'Մայրական մահացության մակարդակ 2'),
(54552, 3733, 14, 'Շարժական'),
(54553, 3734, 14, 'Բջջային հեռախոս'),
(54554, 3735, 14, 'Մոդիֆիկատոր'),
(54555, 3738, 14, 'Միջին/ չափավոր առաջնահերթություն'),
(54556, 3740, 14, 'Միջին/ Ցածր առաջնահերթություն'),
(54557, 3741, 14, 'Մոդիֆիկատոր/ձևաթոխիչ'),
(54558, 3742, 14, 'Մոդիֆիկատորներ/ձևաթոխիչներ'),
(54559, 3743, 14, 'Փոփոխել'),
(54560, 3745, 14, 'Փոփոխել վճարումները'),
(54561, 3746, 14, 'Մոդ․ երկ․'),
(54562, 3747, 14, 'Մոդուլ'),
(54563, 3748, 14, 'Մոդուլի ուղեցույց չի գտնվել'),
(54564, 3749, 14, 'Մոդուլի տեղադրիչ'),
(54565, 3750, 14, 'Մոդուլի անվանում'),
(54566, 3751, 14, 'Մոդուլի անվանում արդեն գոյություն ունի'),
(54567, 3752, 14, 'Մոդուլներ'),
(54568, 3753, 14, 'Երկ․'),
(54569, 3754, 14, 'Երկ ֊ Ուրբ'),
(54570, 3755, 14, 'Երկ․ Չրք․ &amp; Ուրբ․'),
(54571, 3756, 14, 'Երկուշաբթի'),
(54572, 3757, 14, 'Մոնղոլերեն'),
(54573, 3758, 14, 'Ամիս'),
(54574, 3759, 14, 'ամիս'),
(54575, 3760, 14, 'Ամսվա դիտում'),
(54576, 3761, 14, 'Ամիս(ներ)'),
(54577, 3762, 14, 'Ամսական եկամուտ'),
(54578, 3763, 14, 'Ամիսներ'),
(54579, 3765, 14, 'Գտնվել է ավելի, քան 100 գրանցում։ Խնդրում ենք սահմանափակել/սեղմել որոնման չափորոշիչները'),
(54580, 3766, 14, 'Ավելի, քան 50 արդյունք։ Խնդրում ենք  որոնումն ավելի կոնկրետացնել'),
(54581, 3767, 14, 'Սյուների անվանումների/վերնագրերի մեծ մասի դասավորությունը հնարավոր է կտտոցով/սեղմելով փոփոխել'),
(54582, 3768, 14, '֊ից ամենավերջինը'),
(54583, 3769, 14, 'Ամենավերջին լաբորատոր տվյալը'),
(54584, 3770, 14, 'Ամենավերջին կենսական տվյալները ֊ից'),
(54585, 3771, 14, 'Մայրը'),
(54586, 3772, 14, 'Մայրիկի անունիը'),
(54587, 3773, 14, 'Մայրիկի անամնեզը/պատմությունը'),
(54588, 3774, 14, 'Բերան'),
(54589, 3775, 14, 'Շարժել/ տեղափոխել'),
(54590, 3776, 14, 'Փաստաթուղթը տեղափոխել ֊֊ կատեգորիա'),
(54591, 3777, 14, 'Տեղափոխել ներքև'),
(54592, 3778, 14, 'Տեղափուխումը ձախողվեց'),
(54593, 3779, 14, 'Տեղափոխել Պացիենտ բաժին'),
(54594, 3780, 14, 'Տեղափոխել ․․․'),
(54595, 3781, 14, 'Տեղափոխել վերև'),
(54596, 3782, 14, 'Տեղափոխում'),
(54597, 3783, 14, 'Պրն․'),
(54598, 3784, 14, 'Գրանցման համար /պացիենտի նույնացուցիչ/'),
(54599, 3785, 14, 'Տիկին'),
(54600, 3786, 14, 'Տիկին'),
(54601, 3787, 14, 'MSH-11'),
(54602, 3788, 14, 'MSH-3.1'),
(54603, 3789, 14, 'MSH-4.1'),
(54604, 3790, 14, 'MSH-5.1'),
(54605, 3791, 14, 'MSH-6.1'),
(54606, 3793, 14, 'MSH.8 հաղորդագրության տեսակը վավեր չէ'),
(54607, 3794, 14, 'MSP կոդ'),
(54608, 3795, 14, 'MSP առաքման կոդեր'),
(54609, 3796, 14, 'Բազմալեզու/թարգմանչական գործիք'),
(54610, 3797, 14, 'Մի քանի/բազմաթիվ տարածքներ'),
(54611, 3798, 14, 'Միանգամից  կարող եք ընտրել և  բեռնել մի քանի ֆայլ՝ օգտագործելովսեղմելով CTRL+Click կամ SHIFT+Click'),
(54612, 3799, 14, 'Մի քանի խմբաքանակ'),
(54613, 3800, 14, 'Մի քանի բաղադրիչներ կարող են առանձնացվել/բաժանվել կրկնակետով կամ բացատով․ առավելագույնը 4 բաղադրիչ (M1:M2:M3:M4)'),
(54614, 3801, 14, 'Բազմակի ընտրության ցանկ'),
(54615, 3802, 14, 'Բազմազգ'),
(54616, 3803, 14, 'Աղմուկ։'),
(54617, 3804, 14, 'Մկանային ցավ'),
(54618, 3805, 14, 'Մկանային ցավեր'),
(54619, 3806, 14, 'Մկանային կարմրություն'),
(54620, 3807, 14, 'Մկանային կոշտություն'),
(54621, 3808, 14, 'Մկանային/Մկանների այտուց'),
(54622, 3809, 14, 'Մկանների գերտաքացում'),
(54623, 3810, 14, 'Մկան'),
(54624, 3811, 14, 'Մկանի վնասվածք'),
(54625, 3812, 14, 'Հենաշարժիչ համակարգ'),
(54626, 3813, 14, 'Եթե SMTP վավերացում/նույնականացում չի կիրառվում, ապա պետք է դատարկ լինի'),
(54627, 3814, 14, 'Երկուստեք սահմանված'),
(54628, 3815, 14, 'Ճանապարհատրանսպորտային պատահար/ավտովթար'),
(54629, 3818, 14, 'Ինքնուրույն'),
(54630, 3821, 14, 'N/A / ոչ կիրառելի'),
(54631, 3822, 14, 'n/a'),
(54632, 3823, 14, 'անուն'),
(54633, 3825, 14, 'Անուն (սեղմել ավելին տեսնելու համար)'),
(54634, 3826, 14, 'Անուն 1'),
(54635, 3827, 14, 'Անուն 2'),
(54636, 3828, 14, 'Պատվաստաման ղեկավարի անունն ու պաշտոնը'),
(54637, 3829, 14, 'Անունն EMR֊ում'),
(54638, 3830, 14, 'Անունը պետք է լինի  codetype_code_language.pdf, օրինակ՝ icd9_274.11_en.pdf'),
(54639, 3831, 14, 'Իրադարձության անվանումը'),
(54640, 3832, 14, 'Ապահովագրող Ընկերության անունը'),
(54641, 3833, 14, 'Մասնագետի անունը/ազգանունը'),
(54642, 3834, 14, 'Պացիենտին հիշեցումներ ուղարկողի անունը'),
(54643, 3835, 14, 'Անվան թարգմանություն'),
(54644, 3836, 14, 'Անուն/Նշանակություն'),
(54645, 3837, 14, 'Անուն։'),
(54646, 3838, 14, 'ՌՈՒՆԳԵՐ։ /ՔԹԱՆՑՔԵՐ։'),
(54647, 3839, 14, 'ՌՈՒՆԳԵՐ։ /ՔԹԱՆՑՔԵՐ։ Նորմալ աջ'),
(54648, 3841, 14, 'Գրառումներ ազգության մասին'),
(54649, 3844, 14, 'Ազգություն'),
(54650, 3845, 14, 'Գրառ․ ազգ․ մասին'),
(54651, 3846, 14, 'Ազգաբանական տվյալը բեռմվում է'),
(54652, 3847, 14, 'Բնիկ հավայական կամ  խաղաղ օվկիանոսյան այլ կղզու բնակիչ'),
(54653, 3852, 14, 'սրտխառնոց'),
(54654, 3854, 14, 'Նավիգացիա / ճանապարհային ուղեցույց'),
(54655, 3855, 14, 'Նավիգացիոն տարածքը ներառում է այցելության բլանկ'),
(54656, 3856, 14, 'Նավիգացիոն տարածքը օգտագործում է պատուհանի ողջ բարձրությունը'),
(54657, 3857, 14, 'Նավիգացիոն տարածքի այցելության բլանկներ/ձևեր'),
(54658, 3858, 14, 'Նավիգացիոն տարածքի լայնություն'),
(54659, 3859, 14, 'Նավիգացիոն մենյուն բաղկացած է զույգ անջատիչներից'),
(54660, 3860, 14, 'Ծառի տեսքով /treeview նավիգացիոն մենյու'),
(54661, 3861, 14, 'Նավիգացիան կիրառում է/ունի սահող մենյու'),
(54662, 3862, 14, 'NDC  Դեղամիջոցի ազգային կոդ'),
(54663, 3863, 14, 'NDC /Դեղամիջոցի ազգային կոդ/'),
(54664, 3864, 14, 'NDC /Դեղամիջոցի ազգային կոդ/ տվյալ'),
(54665, 3865, 14, 'NDC /Դեղամիջոցի ազգային կոդ/ համար'),
(54666, 3866, 14, 'Վիզ/պարանոց'),
(54667, 3867, 14, 'Պարանոցի խնդիրներ'),
(54668, 3868, 14, 'Պարանոցի ձգում'),
(54669, 3869, 14, 'Անհրաժեշտ է մուտքագրել նկարագրություն'),
(54670, 3870, 14, 'Անհրաժեշտ է մուտքագրել հետադարձ նկարագրություն'),
(54671, 3871, 14, 'Անհրաժեշտ է մուտքագրել նույնացուցիչ'),
(54672, 3872, 14, 'Անհրաժեշտ է մուտքագրել անուն/անվանում'),
(54673, 3873, 14, 'Պահանջվում/անհրաժեշտ է թույլտվություն'),
(54674, 3874, 14, 'Պահանջվում/անհրաժեշտ է թհաստատում'),
(54675, 3875, 14, 'Պահանջվում/անհրաժեշտ է կրկնակի բիլլինգ/հաշվեգրում'),
(54676, 3876, 14, 'Բացասական'),
(54677, 3877, 14, 'Ժխտում/բացասում'),
(54678, 3880, 14, 'Նյարդերի վնասվածք'),
(54679, 3881, 14, 'Նյարդային/նյարդաբանական վիճակ / նյարդի/ներվի վնասվածք'),
(54680, 3882, 14, 'Նյարդերի թմրություն'),
(54681, 3883, 14, 'Նյարդային թուլություն'),
(54682, 3884, 14, 'Նյարդաբանական'),
(54683, 3885, 14, 'Երբեք'),
(54684, 3886, 14, 'Երբևէ չի օգտագործել ալկոհոլ'),
(54685, 3887, 14, 'Երբևէ չի ծխել'),
(54686, 3888, 14, 'Նոր'),
(54687, 3889, 14, 'Նոր =>'),
(54688, 3890, 14, 'Նոր ընդունողներ/ստացողներ'),
(54689, 3892, 14, 'Նոր ալերգիա'),
(54690, 3893, 14, 'Նոր փոփոխության պահանջ'),
(54691, 3894, 14, 'Նոր այցելություն'),
(54692, 3895, 14, 'Նոր կատեգորիաներ'),
(54693, 3896, 14, 'Նոր կատեգորիա'),
(54694, 3897, 14, 'Նոր հաճախորդներ'),
(54695, 3898, 14, 'Նոր խորհրդատվություն'),
(54696, 3900, 14, 'Ավելացվել է սահմանումների նոր շարք'),
(54697, 3901, 14, 'Նոր փաստաթուղթ'),
(54698, 3902, 14, 'Նոր փաստաթղթեր'),
(54699, 3904, 14, 'Նոր այց'),
(54700, 3905, 14, 'Նոր այց՝ ստեղծված ֊֊֊ id֊ով'),
(54701, 3906, 14, 'Նոր այցելության ձև/բլանկ'),
(54702, 3907, 14, 'Նոր այցերին հասանելություն թույլատրված չէ'),
(54703, 3908, 14, 'Նոր այց'),
(54704, 3909, 14, 'Տեղեկություն նոր ծառայության մասին'),
(54705, 3910, 14, 'Նոր ֆայլ'),
(54706, 3911, 14, 'Նոր ֆայլեր'),
(54707, 3912, 14, 'Նոր խումբ'),
(54708, 3913, 14, 'Տեղեկություն նոր խմբի մասին'),
(54709, 3914, 14, 'Նոր մուտք/կարգավիճակ'),
(54710, 3916, 14, 'Իրադարձությունների նոր սահմանաչափ'),
(54711, 3917, 14, 'Նոր ցուցակ/ցանկ'),
(54712, 3918, 14, 'Նոր նշանակումներ/հրահանգներ'),
(54713, 3919, 14, 'Նոր պարագրաֆ'),
(54714, 3920, 14, 'Նոր գաղտնաբառ'),
(54715, 3921, 14, 'Նոր պացիենտ'),
(54716, 3922, 14, 'ՆՈՐ ՊԱՑԻԵՆՏ'),
(54717, 3923, 14, 'Նոր պացիենտի այց'),
(54718, 3924, 14, 'Նոր պացիենտի բլանկ'),
(54719, 3925, 14, 'Նոր պացիենտի ID'),
(54720, 3926, 14, 'Նոր վճարում'),
(54721, 3927, 14, 'Մուտք նոր պորտալ'),
(54722, 3928, 14, 'Նոր կետ'),
(54723, 3929, 14, 'Լաբորատոր փոխանակման նոր արդյունքներ'),
(54724, 3930, 14, 'Նոր որոնում'),
(54725, 3931, 14, 'Նոր սահմանումներ/պնդումներ'),
(54726, 3932, 14, 'Նոր օգտատեր'),
(54727, 3933, 14, 'Նոր սահմանում/արժեք'),
(54728, 3934, 14, 'Նոր այց'),
(54729, 3935, 14, 'Նոր/Որոնում'),
(54730, 3936, 14, 'NewCrop հաշվի կարգավիճակ'),
(54731, 3937, 14, 'NewCrop ադմին'),
(54732, 3938, 14, 'NewCrop կանչը ձախողվեց'),
(54733, 3939, 14, 'NewCrop բժիշկ'),
(54734, 3940, 14, 'NewCrop eRx հաշվի Id'),
(54735, 3944, 14, 'NewCrop eRx անվանում'),
(54736, 3945, 14, 'NewCrop eRx գործընկերոջ անվանում'),
(54737, 3946, 14, 'NewCrop eRx գաղտնաբառ'),
(54738, 3947, 14, 'NewCrop eRx դերը/մակարդակը'),
(54739, 3948, 14, 'NewCrop eRx դերը/մակարդակը'),
(54740, 3949, 14, 'NewCrop eRx կայքի հասցե'),
(54741, 3954, 14, 'NewCrop eRx վեբսպասարկման հասցե'),
(54742, 3955, 14, 'NewCrop eRx մենեջեր/ղեկավար'),
(54743, 3956, 14, 'NewCrop բժշ․ գրանցում'),
(54744, 3957, 14, 'NewCrop միջին մակարդակի Բժիշկ՝ դեղատոմս դուրսգրելու իրավասությամբ'),
(54745, 3958, 14, 'NewCrop բուժքույր'),
(54746, 3959, 14, 'NewCrop Ղեկավար բժիշկ'),
(54747, 3960, 14, 'Ավելի նոր'),
(54748, 3961, 14, 'Թերթ /օրաթերթ'),
(54749, 3962, 14, 'Հաջորդ'),
(54750, 3964, 14, 'Հաջորդ օրը'),
(54751, 3965, 14, 'Հաջորդ ամիս'),
(54752, 3966, 14, 'Հաջորդ ամիս  (մենյուն ֆիքսելու համար)'),
(54753, 3967, 14, 'Պլանավորված հաջորդ մեկնարկը'),
(54754, 3968, 14, 'Հաջորդ շաբաթ'),
(54755, 3969, 14, 'Հաջորդ տարի  (մենյուն ֆիքսելու համար)'),
(54756, 3970, 14, 'Մականուն'),
(54757, 3971, 14, 'Մականուն'),
(54758, 3973, 14, 'Գիշերային քրտնարտադրություն'),
(54759, 3975, 14, 'Ոչ'),
(54760, 3976, 14, 'ՈՉ'),
(54761, 3977, 14, 'Հասանելի չէ'),
(54762, 3978, 14, 'Հիվանդի ակտիվ հիշեցումներ չկան'),
(54763, 3979, 14, 'Ադենոպատիա չկա (անհրաժեշտ/պահանջվում է 2 ոլորտ/տարածք)'),
(54764, 3980, 14, 'Ճշգրտման պատճառ չի գտնվել'),
(54765, 3982, 14, '1. Փոփոխության հարցումները հասանելի չեն 2. Չկան փոփոխության հասանելի հարցումներ'),
(54766, 3983, 14, 'Նշանակված այցեր չկան'),
(54767, 3985, 14, 'Այս պահին չկա ակտիվ բիլլինգային համակարգ Այս պահին բիլլինգային համակարգն ակտիվ չէ'),
(54768, 3986, 14, 'OFX Export֊ի ներմուծման հաշիվ չի գտնվել'),
(54769, 3987, 14, 'OFX Export<br>֊ի ներմուծման հաշիվ չի գտնվել'),
(54770, 3989, 14, 'Կոդ նշված չէ'),
(54771, 3990, 14, 'Այս մոդուլի համար կարգավորման սահմանում չկա'),
(54772, 3992, 14, 'Ախտորոշում չկա'),
(54773, 3993, 14, '(Ոչ մի) Փաստաթուղթ չի գտնվել'),
(54774, 3994, 14, 'Հնրավաոր չէ ստեղծել նոր այց'),
(54775, 3995, 14, 'ավարտման ամսաթիվ չկա'),
(54776, 3996, 14, '(Ոչ մի) գրառում չկա․ օգտվեք ստորև ներկայացված ձևը՝ գրառում կատարելու համար'),
(54777, 3997, 14, 'Սխալներ չեն հայտնաբերվել/չկան'),
(54778, 3998, 14, 'Իրադարձություններ չկան'),
(54779, 4000, 14, 'Տեղադրման ենթակա ներկայացված ֆայլեր չկան'),
(54780, 4001, 14, 'Խումբ ընտրված չէ'),
(54781, 4002, 14, 'Ճողվածք չկա'),
(54782, 4005, 14, 'Առանց տրավմաների/վնասվածքների/հիվանդության'),
(54783, 4006, 14, 'Ապահովագրող կազմակերպություն չի գտնվել'),
(54784, 4007, 14, 'Խնդիրներ չկան'),
(54785, 4008, 14, 'Այս այցի տակ չկան գրանցված խնդիրներ'),
(54786, 4009, 14, 'Ընտրված կատեգորիայում կետեր/պարագրաֆներ չկան'),
(54787, 4010, 14, 'Չկա ընտրված կետ/պարագրաֆ'),
(54788, 4024, 14, 'Լաբորատոր տվյալ տեղադրված չէ'),
(54789, 4025, 14, 'Նշված օրով  մուտքի ֆայլ գոյություն չունի'),
(54790, 4028, 14, 'Տրված կրկնակի նույնականացման կոդով համապատասխան Պացիենտի գրառում չի  գտնվել'),
(54791, 4029, 14, 'Համապատասխան արդյունք չի գտնվել․ կրկին կատարեք որոնում'),
(54792, 4030, 14, 'Համապատասխան արդյունք չի գտնվել'),
(54793, 4031, 14, 'Համապատասխան արդյունք չի գտնվել․ Ստեղծե՞լ/գրանցե՞լ  նոր Պացիենտ'),
(54794, 4032, 14, 'Չի գտնվել համապատասխան գրառում'),
(54795, 4033, 14, 'Նոր արդյունք չեն գտնվել'),
(54796, 4034, 14, 'Գրառումներ չկան'),
(54797, 4035, 14, 'Որովայնային խոռոչի ներքին օրգանների մեծացում չկա'),
(54798, 4036, 14, 'Այս ժամանակահտվածում նոր գրանցումներ չեն գտնվել'),
(54799, 4037, 14, 'Այլ հեռախոսահամարներ չկան'),
(54800, 4038, 14, 'Պարամետրեր ընտրված չեն'),
(54801, 4039, 14, 'Գործընկերներ չկան'),
(54802, 4040, 14, 'Ընտրված չափորոշիչներով գրանցված Պացիենտ չի գտնվել'),
(54803, 4041, 14, 'Տրված կրկնակի նույնականացման կոդով գրանցված Պացիենտ չի  գտնվել'),
(54804, 4042, 14, 'Վերջույթային այտուցներ չկան'),
(54805, 4043, 14, 'Դեղատուն չի գտնվել'),
(54806, 4044, 14, 'Դեղատոմս/նշանակում չի գտնվել'),
(54807, 4045, 14, 'Հիվանդություն/տրավմա ներկայացված չէ'),
(54808, 4046, 14, 'Անցած գրառումներ չկան'),
(54809, 4048, 14, 'Նախնական հանդիպում/այց չկա'),
(54810, 4049, 14, 'Այս հանդիպման/այցի տակ չկան գրանցված միաջմտություններ'),
(54811, 4051, 14, 'Մատակարար/մասնագետ չի գտնվել'),
(54812, 4052, 14, 'Ոչ մի ցան կամ ախտահարված մաս'),
(54813, 4053, 14, 'Գրառումներ չեն գտնվել'),
(54814, 4055, 14, 'Գրառումներ չեն գտնվել․ խնդրում ենք ընդլայնել որոնման չափորոշիչները'),
(54815, 4056, 14, 'Հիշեցումներ չկան'),
(54816, 4057, 14, 'Վերոնշյալ որոնման արդյունքներ չկան'),
(54817, 4058, 14, 'Արդյունքներ չկան'),
(54818, 4059, 14, 'Արդյունքներ չեն հայտնաբերվել'),
(54819, 4060, 14, 'Որոնման արդյունքներ չկան'),
(54820, 4061, 14, 'Արդյունքներ չեն հայտնաբերվել․ նորից/կրկին փորձեք'),
(54821, 4062, 14, 'Արդյունքներ չկան․ նորից/կրկին փորձեք'),
(54822, 4063, 14, 'Արդյունքներ չկան․ նորից/կրկին փորձեք'),
(54823, 4064, 14, 'Այս մոդուլում հասանելի պարամետրեր/կարգավորումներ չկան'),
(54824, 4065, 14, 'Չցուցադրել / չի ցուցադրում'),
(54825, 4066, 14, 'Ֆայլի վրա ստորագրություն առկա չէ'),
(54826, 4072, 14, '1. Առանց հուզմունքի կամ շնչարգելության  2.  հուզմունք կամ շնչարգելություն չկա'),
(54827, 4075, 14, 'Այցեր չկան'),
(54828, 4076, 14, 'Կենսական նշաններ գրանցված չեն'),
(54829, 4077, 14, 'Ոչ, չեղարկել'),
(54830, 4079, 14, 'Ոչ։'),
(54831, 4080, 14, 'Nocturia /չափից շատ գիշերամիզություն/'),
(54832, 4081, 14, 'Չվճարված'),
(54833, 4082, 14, 'Չներկայացված հաշվետվություն'),
(54834, 4083, 14, 'ոչ սպեցիֆիկ վնասվածք'),
(54835, 4084, 14, 'Ոչ էլեկտրոնային'),
(54836, 4085, 14, 'Ինսուլինանկախ շաքարային դիաբեթ'),
(54837, 4086, 14, 'Չապահովագրված'),
(54838, 4089, 14, 'Ոչ մեկը'),
(54839, 4090, 14, 'ոչ մեկը'),
(54840, 4091, 14, '1. Չսահմանված 2. Ոչ մեկը սահմանված չէ'),
(54841, 4092, 14, 'Ոչ մեկը գրանցված չէ'),
(54842, 4093, 14, 'Վերոնշյալից և ոչ մեկը'),
(54843, 4094, 14, 'Վերին բաշխիչ տողերից ոչ մեկը չի կարող/չպետք է դատարկ լինի'),
(54844, 4095, 14, 'Ինսուլինանկախ շաքարային դիաբեթ'),
(54845, 4096, 14, 'ոչ էլ'),
(54846, 4097, 14, 'Սովորական/նորմալ'),
(54847, 4098, 14, 'Նորմալ/սովորական / BL արյուն'),
(54848, 4099, 14, 'Սրտանոթային նորմալ/սովորական /  հետազոտություն'),
(54849, 4100, 14, 'Սրտանոթային նորմալ/սովորական /  հետազոտություն '),
(54850, 4101, 14, 'Թոքերի սովորական  հետազոտություն'),
(54851, 4102, 14, 'Թոքերի սովորական  հետազոտություն '),
(54852, 4103, 14, 'Սովորական գրասենյակային/խորհրդատվական այց'),
(54853, 4105, 14, 'Սովորական աջ'),
(54854, 4106, 14, 'Սովորական աջ։'),
(54855, 4107, 14, 'Սովորական տեսքը'),
(54856, 4108, 14, 'սովորկան։'),
(54857, 4109, 14, 'Սովորաբար սա պետք է ստուգվի։ Կապված չէ մուտքի վերահսկողության հետ'),
(54858, 4112, 14, 'Նորվեգացի Նորվեգերեն'),
(54859, 4115, 14, 'Քիթ'),
(54860, 4116, 14, 'Քթային արյունահոսություն'),
(54861, 4117, 14, 'ոչ տառ կամ թիվ'),
(54862, 4119, 14, 'Ոչ բոլոր դաշտերն են պարտադիր բոլոր կոդերի կամ դրանց տեակների համար'),
(54863, 4120, 14, 'Թույլատրված չէ'),
(54864, 4121, 14, 'Չի թույլատրվում ջնջել Ադմինիստրատորների խումբը'),
(54865, 4122, 14, 'Խմբագրում թույլատրված չէ  Չի թույլատրվում խմբագրել'),
(54866, 4123, 14, 'Չի թույլատրվում ապաակտիվացնել անվտանգության բոլոր օբյեկտները'),
(54867, 4124, 14, 'Administrators ACL֊ից ոչինչ չի թուլատրվում ապաակտիվացնել'),
(54868, 4125, 14, 'Չի թույլատրվում հեռացնել  admin օգտատիրօջը Ադմինիստրատորներ խմբից'),
(54869, 4126, 14, 'Չի թույլատրվում հեռացնել  այս օգտատիրօջը Ադմինիստրատորներ խմբից'),
(54870, 4127, 14, 'Կիրառելի չէ'),
(54871, 4128, 14, 'PostCalendar մոդուլին հասանելություն թույլատրված չէ'),
(54872, 4129, 14, 'Թույլատրված չէ  հասանելիություն/լիազորություն չկա'),
(54873, 4130, 14, 'Թույլատրված չէ  հասանելիություն/լիազորություն չկա'),
(54874, 4131, 14, 'Այս խմբի համար թույտվություն/հասանելիություն/լիազորություն չկա'),
(54875, 4132, 14, 'Այս խմբի համար թույտվություն/հասանելիություն/լիազորություն չկա'),
(54876, 4133, 14, 'Օգտատերերի կառավարման հասանելիություն/լիազորություն չկա'),
(54877, 4134, 14, 'Արդյունքների ստորագրման/գրանցման հասանելիություն/լիազորություն չկա'),
(54878, 4135, 14, 'Հասանելի չէ'),
(54879, 4137, 14, 'Հաշիվ ներկայացված չէ /հաշվեգրված չէ'),
(54880, 4138, 14, 'Գրանցված չէ'),
(54881, 4139, 14, 'Ստուգված չէ Դուրսգրված չէ'),
(54882, 4140, 14, 'Կոդավորված չէ'),
(54883, 4141, 14, 'Չպայմանավորված'),
(54884, 4143, 14, 'Չհետազոտված'),
(54885, 4144, 14, 'Չհետազոտված։'),
(54886, 4145, 14, 'Չհետազոտված։ '),
(54887, 4146, 14, 'չի գտնվել'),
(54888, 4148, 14, 'չի գտնվել'),
(54889, 4149, 14, 'Ոչ իսպանական կամ լատինամերիկյան'),
(54890, 4150, 14, 'Տեղադրված չէ/ չի տեղադրվել'),
(54891, 4151, 14, 'Տեղադրված չէ/ չի տեղադրվել'),
(54892, 4152, 14, 'Առայժմ չի բացվել/նայվել'),
(54893, 4153, 14, 'Չի ուղարկվել / ուղարկված չէ'),
(54894, 4154, 14, 'Դեռևս չի ուղարկվել / ուղարկված չէ'),
(54895, 4155, 14, 'Նշված չէ'),
(54896, 4156, 14, 'Նշված չէ'),
(54897, 4157, 14, 'Նշում Գրառում'),
(54898, 4158, 14, 'Նշումների/գրառումների կոդեր/կոդավորում'),
(54899, 4159, 14, 'Ի նկատի ունեցեք, որ ՏԵՂԱԴՐԵԼ կոճակը սեղմելուց հետո 5-10րոպե կտևի ողջ պրոցեսն ավարտին հասցնելու համար'),
(54900, 4160, 14, 'Ի նկատի ունեցեք, որ Թարմացնել կոճակը սեղմելուց հետո 5-10րոպե կտևի ողջ պրոցեսն ավարտին հասցնելու համար'),
(54901, 4161, 14, 'Ի նկատի ունեցեք, որ  վերևում Audit Logging֊ը պետք է միացված լինի'),
(54902, 4162, 14, 'Գրառման տեսակը'),
(54903, 4163, 14, 'Հիշեցում։ 12։00 PM է, այլ ոչ AM'),
(54904, 4172, 14, 'Գրառումներ / Նշումներ'),
(54905, 4173, 14, 'Գրառումներ / Նշումներ - ցանկացած այց/բուժում (գրել, միայն ավելացնել ըստ ցանկության)'),
(54906, 4174, 14, 'Գրառումներ / Նշումներ - իմ այցերը/բուժումները (գրել, միայն ավելացնել ըստ ցանկության)'),
(54907, 4175, 14, 'Գրառումներ / Նշումներ֊ի մուտքը հասանելի չէ'),
(54908, 4176, 14, 'Հաստատման սպասող ոչինչ չկա'),
(54909, 4177, 14, 'Ոչինչ չի գրանցվել'),
(54910, 4179, 14, 'Ալերգիայի համար/մասին ոչինչ բեռնված չէ'),
(54911, 4180, 14, 'Նշանակումների համար/մասին ոչինչ բեռնված չէ'),
(54912, 4181, 14, 'Ցուցադրելու ոչինչ չկա'),
(54913, 4182, 14, 'Ոչինչ ընտրված չէ'),
(54914, 4183, 14, 'Ստացվել է ծանուցում'),
(54915, 4184, 14, 'ԾԱՆՈՒՑՈՒՄ :: Post Calendar֊ի ներկայացում / ձեևափոխում'),
(54916, 4185, 14, 'Ծանուցում'),
(54917, 4186, 14, 'Ծանուցման էլ․ հասցե'),
(54918, 4188, 14, 'Ծանուցումներ'),
(54919, 4189, 14, 'Ադմինին տեղեկացնե՞լ իրադարձությունների ներկայցման/փոփոխման մասին'),
(54920, 4190, 14, 'Նոյ․'),
(54921, 4191, 14, 'Նոյեմբեր'),
(54922, 4192, 14, 'Այժմ  հրապարակվում/տեղադրվում է'),
(54923, 4193, 14, 'Տպվում է'),
(54924, 4194, 14, 'Տպվում է $stmt_count այցերի/բուժումների թարմացումն ու հայտարարությունները'),
(54925, 4195, 14, 'Տպվում է $stmt_count հաշիվների թարմացումն ու հայտարարությունները'),
(54926, 4196, 14, 'Տպվում է $stmt_count հայտարարությունները։ այցերը/բուժումները չեն թարմացվի'),
(54927, 4197, 14, 'Տպվում է $stmt_count հայտարարությունները։ հաշիվները չեն թարմացվի'),
(54928, 4198, 14, 'NPI'),
(54929, 4199, 14, 'NQF'),
(54930, 4200, 14, 'Թիվ / համար'),
(54931, 4201, 14, 'Լաբոր․ համարը'),
(54932, 4204, 14, 'Սյուների քանակը տարվա կտրվածքով'),
(54933, 4211, 14, 'Հիվանդի հավաստագրի վավերության օրերի քանակը'),
(54934, 4213, 14, 'Արժույթը ներկայացնելիս ստորակետից հետո թվերի քանակը'),
(54935, 4214, 14, 'Էջում ցուցադրվող այցերի քանակը'),
(54936, 4215, 14, 'Բաց թողնված իրադարձությունների կամ game֊երի քանակը՝ եթե այդպիսիք կան'),
(54937, 4216, 14, 'Էլ․ փոստով ծանուցումներ ուղարկելու նախնական ժամանակը /ժամերի քանակը/'),
(54938, 4217, 14, 'Հեռախոսային ծանուցումներ ուղարկելու նախնական ժամանակը /ժամերի քանակը/'),
(54939, 4218, 14, 'SMS հաղորդագրությամբ ծանուցումներ ուղարկելու նախնական ժամանակը /ժամերի քանակը/'),
(54940, 4221, 14, 'Նախկին անամնեզի/հիվ․ պատմության սյուների քանակը'),
(54941, 4222, 14, 'Հիվանդների ցանկից մեկ էջում ցուցադրվով հիվանդների քանակը'),
(54942, 4223, 14, 'Թմրություն/անզգայացում'),
(54943, 4224, 14, 'Համարացույց'),
(54944, 4225, 14, 'Թվային ցուցադրության կարգը'),
(54945, 4227, 14, 'Սնուցում / կերակրում'),
(54946, 4228, 14, 'Սննդային'),
(54947, 4229, 14, 'O.A.F.V.'),
(54948, 4230, 14, 'O2 Sat'),
(54949, 4231, 14, '1֊ին աստիճանի Գիրություն/ճարպակալում'),
(54950, 4232, 14, '2֊րդ աստիճանի Գիրություն/ճարպակալում'),
(54951, 4233, 14, '3֊րդ աստիճանի Գիրություն/ճարպակալում'),
(54952, 4234, 14, 'Նպատակ/խնդիր օբյեկտիվորեն/անաչառ'),
(54953, 4237, 14, 'զբաղեցրած պաշտոնը'),
(54954, 4239, 14, 'առաջացում; դեպք; երևույթ,'),
(54955, 4240, 14, 'Հոկտ․'),
(54956, 4241, 14, 'Հոկտեմբեր'),
(54957, 4242, 14, 'OD'),
(54958, 4243, 14, '֊ի; ֊ից'),
(54959, 4244, 14, 'քանակի'),
(54960, 4245, 14, 'հաբ'),
(54961, 4246, 14, 'յուրաքանչյուր ամիս'),
(54962, 4247, 14, 'Գործն․/ծառ․ գրառումներ'),
(54963, 4248, 14, 'Դուրս'),
(54964, 4249, 14, 'Գործն․/ծառ․ գրառումներ'),
(54965, 4250, 14, 'Կբինետային այց'),
(54966, 4251, 14, 'Կլինիկական որակի չափման համեմատության խումբ'),
(54967, 4252, 14, 'Պացիենտի պորտալի արտաքին Https կապ/լինք'),
(54968, 4253, 14, 'Պացիենտի պորտալի արտաքին Https կապ/լինք (Պացիենտի հղում)'),
(54969, 4256, 14, 'Offsite Patient Portal Provider ID'),
(54970, 4257, 14, 'Offsite Patient Portal Provider ID (եթե գրանցված  չէ, թողնել դատարկ).'),
(54971, 4258, 14, 'Offsite Պացիենտի պորտալ կայքի հասցեն'),
(54972, 4259, 14, 'Offsite Պացիենտի պորտալ կայքի հասցեն (Պացիենտի հղում)'),
(54973, 4260, 14, 'Offsite Պացիենտի պորտալ օգտանունը'),
(54974, 4261, 14, 'Offsite Պացիենտի պորտալ օգտանունը (եթե գրանցված  չէ, թողնել դատարկ).'),
(54975, 4263, 14, 'Ժառանգ'),
(54976, 4264, 14, 'Ժառանգական պատմություն'),
(54977, 4265, 14, 'քսուք'),
(54978, 4267, 14, 'OK'),
(54979, 4268, 14, 'Փակե՞լ այս թառթող պատուհանը'),
(54980, 4272, 14, 'Նախկին հաճախորդներ/հիվանդներ'),
(54981, 4273, 14, 'Հին կոտրվածք անլիարժեք վերականգնում / ոչ ճիշտ կպում'),
(54982, 4274, 14, 'Նախկին տեղակայման ձևը/տեսքը առանց ձախակողմյան մենյուի'),
(54983, 4275, 14, 'Նախկին ստատիկ ձևը առան որոնման կամ կրկնօրինակի ստուգման'),
(54984, 4276, 14, 'հին, նախկին, ավելի հին'),
(54985, 4277, 14, 'բաց թողնել; չնկատել'),
(54986, 4278, 14, 'բաց թողնել/անտեսել շրջանակը'),
(54987, 4279, 14, 'Բաց թողնել գործատուի տվյալները Պացիենտի անձնական տվյաներում'),
(54988, 4280, 14, 'Բաց թողնել աշխատավայրը'),
(54989, 4281, 14, 'Բաց թողնված ձև․ դեղերի ընդունումը ևընդմիջումները, որոնք հետո դառնում են չափաբաժնի մի մասը'),
(54990, 4282, 14, 'Անձնական տվյալներում բաց թողնել ապահովագրությունը և այլ տվյալներ'),
(54991, 4283, 14, 'Բացառե՞լ ներքին օգտատերերին'),
(54992, 4284, 14, 'Գերավճարի վահանակից հանել վճարման մեթոդը'),
(54993, 4285, 14, 'բաց թողնել/բացառել ավտոմատ նշանակումը'),
(54994, 4286, 14, '֊ին'),
(54995, 4287, 14, '֊ին'),
(54996, 4288, 14, 'առձեռն'),
(54997, 4289, 14, 'Նշանակմամբ'),
(54998, 4290, 14, 'Տեղում'),
(54999, 4291, 14, 'Գործունեության հիմնական տեսակը գրանցելուց հետ այն չպետք է փոխվի։ Դրա փոփոխումը կազդի NewCrop ePrescription֊ի աշխատանքի վրա'),
(55000, 4292, 14, 'Գաղտնաբառը փոխելուց հետո պետք նորից մուտք գործել'),
(55001, 4297, 14, 'Առցանց օգնություն'),
(55002, 4298, 14, 'Առցանց օգնության հղում'),
(55003, 4299, 14, 'Միայն ակտիվները'),
(55004, 4300, 14, 'Կիրառելի/ընդունելի է միայն երբ վերոնշյալ մասնագետը/ծառայություն մատուցողը կամ ցանկն ընտրված է'),
(55005, 4302, 14, 'միայն հաշիվների տեղակայման համար'),
(55006, 4303, 14, 'միայն ապաակտիվ/ապաակտիվացնել'),
(55007, 4304, 14, 'Միայն իմը'),
(55008, 4305, 14, 'Ցուցադրել միայն ախտորոշման հաշվետվության կոդերը'),
(55009, 4306, 14, 'Ցուցադրել միայն ծառայությունների ֆինանսական հաշվետվության կոդերը'),
(55010, 4307, 14, 'Բեռնել միայն ակտիվ դեղատոմսերը/նշանակումները'),
(55011, 4309, 14, 'Սույն ախտանիշների կամ հիվանդության սկիզբը/հայտվնելը/բռնկումը'),
(55012, 4310, 14, 'Հիվանդության ի հայտ գալը'),
(55013, 4311, 14, 'Հիվանդության ի հայտ գալը '),
(55014, 4312, 14, 'Ուռուցքի/նորագոյացության  ի հայտ գալը'),
(55015, 4313, 14, 'Ստացիոնար դիմելու ամսաթիվ'),
(55016, 4315, 14, 'Oops!'),
(55017, 4316, 14, 'բացել'),
(55018, 4318, 14, 'Բացել նոր պատուհանում'),
(55019, 4319, 14, 'Բացել Պացիենտի էջը'),
(55020, 4321, 14, 'Բացել այսօրվա այցը'),
(55021, 4322, 14, 'LibreEHR֊ն արդեն ունի/կազմել է հավաստագիր'),
(55022, 4323, 14, 'LibreEHR  դիմումների կատեգորիա'),
(55023, 4324, 14, 'LibreEHR տվյալների բազայի թարմացում'),
(55024, 4327, 14, 'Մինչև հաճախորդների հավաստագիր ստեղծելը LibreEHR֊ին պետք են հավաստագրերի կիրառման կարգավորումներ'),
(55025, 4328, 14, 'օգտվողի իսկությունը ստուգելու համար LibreEHR-ը պահանջում է Javascript'),
(55026, 4329, 14, 'LibreEHR օգտատերեր'),
(55027, 4330, 14, 'Մուտքեր'),
(55028, 4332, 14, 'Աչքի / ակնաբուժական'),
(55029, 4333, 14, 'Տարբերակ'),
(55030, 4334, 14, 'Փաստաթղթի պահեստավորման մեթոդի պահպանության տարբերակ'),
(55031, 4335, 14, 'Նյութական ակտիվների գույքագրման և վաճառքի տարբերակ'),
(55032, 4336, 14, 'Ըստ ցանկության'),
(55033, 4337, 14, 'ID Card֊ի նկարի կատեգորիայի   ընտրովի անուն, որը երևալու է Պացիենտի ամփոփ էջում'),
(55034, 4338, 14, 'Լուսանկարի կատեգորիայի   ընտրովի անուն, որը երևալու է Պացիենտի ամփոփ էջում'),
(55035, 4339, 14, 'Փաստաթղթի կատեգորիայի   ընտրովի անուն՝ Պացիենտի ամփոփ էջի հղման համար։ Հնարավորություն է տալիս սեղմել Պացիենտ անվան վրա՝ նրա ID քարտը տեսնելու համար'),
(55036, 4343, 14, 'Դեղամիջոցի անունն ըստ ցանկության․ օգտագործել %՝ որպես խմբանիշ'),
(55037, 4344, 14, 'Պատվաստման անուն կամ կոդն ըստ ցանկության․ օգտագործել %՝ որպես խմբանիշ'),
(55038, 4345, 14, 'Իրադարձության մասին ինֆորմացիա ըստ ցանկության'),
(55039, 4346, 14, 'Խմբաքանակի անուն  ըստ ցանկության․ օգտագործել %՝ որպես խմբանիշ'),
(55040, 4350, 14, 'Տարբերակներ'),
(55041, 4351, 14, 'կամ'),
(55042, 4352, 14, 'ԿԱՄ'),
(55043, 4353, 14, 'կամ ընտրել'),
(55044, 4354, 14, 'կամ սեղմել և քաշել արագ ընտրության համար'),
(55045, 4356, 14, 'կամ դուրս՝ դեպի'),
(55046, 4357, 14, 'կամ ընտրել պահոցից'),
(55047, 4358, 14, 'կամ սեղմել  Shift-click փոքրացնելու/նվազեցնելու համար'),
(55048, 4359, 14, 'կամ բեռնել ERA ֆայլը։'),
(55049, 4360, 14, 'Բերանային /բերանի խոռաչ'),
(55050, 4361, 14, 'Բերանի լորձաթաղանթը վարդագույն է, կոկորդը՝ մաքուր'),
(55051, 4362, 14, '1. Կարգ 2. Ցուցում/նշանակում'),
(55052, 4363, 14, 'Ցուցումների/նշանակումների և արդյունքների տեսակներ'),
(55053, 4364, 14, 'Ցուցումների/նշանակումների ցանկ'),
(55054, 4365, 14, 'Նշանակումների ամսաթիվ'),
(55055, 4366, 14, 'Նշանակման նկարագրություն'),
(55056, 4367, 14, 'Նշանակում ֊ից'),
(55057, 4368, 14, 'Նշանակման ID'),
(55058, 4369, 14, 'Նշանակաումը պետք է լինի 1-999 թվերով'),
(55059, 4370, 14, 'Նշանակման անվանում'),
(55060, 4371, 14, 'Նշանակման առաջնահերթություն'),
(55061, 4373, 14, 'Նշանակման արդյունքները'),
(55062, 4374, 14, 'Նշանակման կարգավիճակը'),
(55063, 4375, 14, 'Նշանակման կարգավիճակներ'),
(55064, 4376, 14, 'Նշանակման ամփոփագիր'),
(55065, 4378, 14, 'Նշանակման տեսակը'),
(55066, 4380, 14, 'Նշանակման/Արդյունքի տեսակը'),
(55067, 4381, 14, 'Նշանակված է'),
(55068, 4382, 14, 'Նշանակված է ֊ի կողմից'),
(55069, 4383, 14, 'Նշանակված միջամտություն'),
(55070, 4384, 14, 'Նշանակող մասնագետ'),
(55071, 4385, 14, 'Նշանակումների պատմություն'),
(55072, 4386, 14, 'Օրգանի վնասվածք'),
(55073, 4387, 14, 'Կազմակերպություն'),
(55074, 4388, 14, 'Կազմակերպության անունը'),
(55075, 4389, 14, 'Կազմակերպության բաժնի անունը'),
(55076, 4390, 14, 'Կազմակերպություններ'),
(55077, 4391, 14, 'Ուղված x 3'),
(55078, 4392, 14, 'Օրիգինալ  բնօրինակ'),
(55079, 4396, 14, 'ԲԵՐԱՆԸՄՊԱՆ։ '),
(55080, 4398, 14, 'OS'),
(55081, 4399, 14, 'Օստեոարտրիտ'),
(55082, 4401, 14, 'Օստեոպատիա'),
(55083, 4402, 14, 'Այլ'),
(55084, 4403, 14, 'այլ'),
(55085, 4404, 14, 'Այլ (նշել)'),
(55086, 4405, 14, 'Այլ ֊ նշված'),
(55087, 4406, 14, 'Այլ պետական ծրագիր'),
(55088, 4407, 14, 'Այլ Առողջապահության ֆինանսական վարչակազմ'),
(55089, 4408, 14, 'Այլ՝ չնշված վնասվածքներ'),
(55090, 4409, 14, 'Հիմնական պատասխանատու է այլ ապահովագրող ընկերություն'),
(55091, 4410, 14, 'այլ ամիս'),
(55092, 4411, 14, 'Այլ՝ ոչ պետական ծրագրեր'),
(55093, 4412, 14, 'Այլ նշումներ/գրառումներ'),
(55094, 4413, 14, 'Այլ համապատասխան ախտանիշներ'),
(55095, 4414, 14, 'Այլ համապատասխան ախտանիշներ։'),
(55096, 4416, 14, 'Այլ լարում;սթերս; ճնշում / Չափից մեծ վնասվածք'),
(55097, 4417, 14, 'Այլ վիրաբուժական միջամտություն'),
(55098, 4418, 14, 'Այլ/ընդհանուր աբորտով;ընդհատումով պայմանավորված'),
(55099, 4420, 14, 'Այլ'),
(55100, 4421, 14, 'այլապես/հակառակ դեպքում կոչնչացնեք  առկա տվյալներին կապող կամ դրանից եկող հղումը'),
(55101, 4422, 14, 'Ottawa Ankle կանոններ'),
(55102, 4424, 14, 'Տեղում չէ Չի աշխատում'),
(55103, 4425, 14, 'Աշխատավայռում չէ'),
(55104, 4426, 14, 'Ուղղությունը դեպի արտերկիր'),
(55105, 4427, 14, 'Արդյունք'),
(55106, 4428, 14, 'Մտահորիզոն / հայացք'),
(55107, 4430, 14, 'Ընդհանուր վիճակը դուրսգրվելիս'),
(55108, 4431, 14, 'ԱՄԿԵՏԱՆՑ/ՈՒՇԱՑԱԾ'),
(55109, 4432, 14, 'Չարաշահում'),
(55110, 4433, 14, 'Ամփոփում'),
(55111, 4434, 14, 'Հավելյալ քաշ'),
(55112, 4435, 14, 'Վերագրանցել HIPAA (Բժշկական ապահովագրության  պահպանման և հաշվետվության մասին օրենք) ընտրությունը'),
(55113, 4437, 14, 'Թթվածնային հագեցվածություն'),
(55114, 4439, 14, 'P'),
(55115, 4440, 14, 'տոկոս'),
(55116, 4441, 14, 'կեսօրից հետո'),
(55117, 4442, 14, 'անհրաժեշտության դեպքում'),
(55118, 4443, 14, 'Խաղաղ օվկիանոսի կղզիաբնակ'),
(55119, 4444, 14, 'Մանկական'),
(55120, 4445, 14, 'Էջ'),
(55121, 4446, 14, 'էջեր'),
(55122, 4447, 14, 'Վճարված'),
(55123, 4448, 14, 'Հատկացման ենթակա վճարված գումարը'),
(55124, 4449, 14, 'Վճարված գումար'),
(55125, 4450, 14, 'Վճարվել է ֊ով'),
(55126, 4451, 14, 'Ցավ'),
(55127, 4453, 14, 'Ստրխփոց/ Սրտի բաբախ'),
(55128, 4456, 14, 'Թուղթ'),
(55129, 4457, 14, 'Թղթի չափ'),
(55130, 4458, 14, 'Կաթված'),
(55131, 4459, 14, 'Ծնող'),
(55132, 4461, 14, 'Խմբագրել HL7'),
(55133, 4463, 14, 'Մասնակից/գործընկեր/ընկեր/ամուսին'),
(55134, 4464, 14, 'Գործընկերոջ անվանում'),
(55135, 4467, 14, 'Գաղտնաբառ'),
(55136, 4468, 14, 'փաստաթուղթի ապակոդավորման գաղտնաբառ'),
(55137, 4469, 14, 'Փոխադրված հիվանդներ'),
(55138, 4470, 14, 'Պասիվ ծանուցում'),
(55139, 4471, 14, 'Պասիվ ծանուցման կանոններ'),
(55140, 4472, 14, 'Գաղտնաբառ'),
(55141, 4473, 14, 'Գաղտնաբառի փոփոխում'),
(55142, 4474, 14, 'Գաղտնաբառը հաջողությամբ փոփոխվեց'),
(55143, 4475, 14, 'Գաղտնաբառը հաջողությամբ փոփոխվեց։'),
(55144, 4476, 14, 'Գաղտնաբառը չի համապատասխանում նվազագույն  պահանջներին․ այն պետք է պարունակի հետևյալ 3-4 տարրերը․ թիվ, փոքրատառ, մեծատառ և նշան (ոչ թիվ կամ տառ)'),
(55145, 4477, 14, 'Գաղտնաբառի վավերականության ժամկետը'),
(55146, 4482, 14, 'Վերոնշյալ օգտվողի գաղտնաբառ'),
(55147, 4483, 14, 'Գաղտնաբառի անվտանգություն/հուսալիությունը թարմացվել է վերջերս'),
(55148, 4484, 14, 'CouchDB֊ի միացման գաղտնաբառ'),
(55149, 4485, 14, 'Գաղտնաբառը չափազանց կարճ է․ պահանջվում է նվազագույնը 8 նիշ'),
(55150, 4486, 14, 'Գաղտնաբառ։'),
(55151, 4487, 14, 'Գաղտնաբառերը չեն համապատասխանում'),
(55152, 4488, 14, 'Նախկին այցեր'),
(55153, 4489, 14, 'Նախկին այցերի ցուցադրման վիդջեթ'),
(55154, 4490, 14, 'Ժամկետանց'),
(55155, 4491, 14, 'Ժամկետանց'),
(55156, 4492, 14, 'Ուշացած ընդմիջում (կլինիկական հիշեցում)'),
(55157, 4493, 14, 'Ուշացած ընդմիջում (պացիենտի հիշեցում)'),
(55158, 4494, 14, 'Նախկին այցերի/բուժումների ցանկ'),
(55159, 4495, 14, 'Նախկին այցեր/բուժումներ'),
(55160, 4496, 14, 'Նախկին այցեր/բուժումներ և փաստաթղթեր'),
(55161, 4497, 14, '֊ի նախկին այցեր'),
(55162, 4498, 14, 'Տեղադրել HL7 տվյալներ'),
(55163, 4499, 14, 'Տեղադրեք ինֆորմացիան՝ ներքոհիշյալ տեքստային տարածք ներմուծելու համար'),
(55164, 4502, 14, 'Վիրակապ 2. ուղղում'),
(55165, 4508, 14, 'Իրադարձությունների/միջոցառումների գրանցամատյանի պահեստային կրկնօրինակի ուղին'),
(55166, 4509, 14, 'CA վկայականի ֆայլի ուղին'),
(55167, 4510, 14, 'CA բանալի ֆայլի ուղին'),
(55168, 4513, 14, 'Ժամանակավոր ֆայլերի ուղի'),
(55169, 4514, 14, 'Պացիենտ'),
(55170, 4515, 14, 'պացիենտ'),
(55171, 4516, 14, 'ՊԱՑԻԵՆՏ'),
(55172, 4517, 14, 'Պացիենտի հասցե'),
(55173, 4518, 14, 'Պացիենտի հասցեն դատարկ է'),
(55174, 4521, 14, 'Պացիենտի մոտ առկա ալերգիա'),
(55175, 4522, 14, 'Պացիենտի մոտ առկա ալերգիա'),
(55176, 4523, 14, 'Պացիենտի այցի նշանակում'),
(55177, 4524, 14, 'Պացիենտի պարտքի մնացորդ'),
(55178, 4525, 14, 'Պացիենտի պարտքի մնացորդն առ'),
(55179, 4528, 14, 'Պացիենտի  ID քարտ'),
(55180, 4529, 14, 'Պացիենտի վճարում'),
(55181, 4530, 14, 'Պացիենտի վճարում ֊ի համար '),
(55182, 4531, 14, 'Պացիենտի քաղաքը'),
(55183, 4532, 14, 'Պացիենտի քաղաքը բաց թողնված է'),
(55184, 4533, 14, 'Պացիենտի հետ կապը հաստատված է'),
(55185, 4534, 14, 'Պացիենտի հետ կապը հաստատված է'),
(55186, 4535, 14, 'Պացիենտի երկիրը'),
(55187, 4536, 14, 'Պացիենտի երկիրը բացակայում է։ Նաև գլոբալ կարգավորումների բաժնում տեղադրված չէ Պացիենտի երկիրն ըստ նախնականի'),
(55188, 4537, 14, 'Պացիենտի լուսաբանում'),
(55189, 4539, 14, 'Պացիենտի տվյալներ'),
(55190, 4541, 14, 'Պացիենտի ծննդյան ամսաթիվը բացակայում է/բաց թողնված է'),
(55191, 4542, 14, 'Տեղեկություններ Պացիենտի մասին'),
(55192, 4543, 14, 'Պացիենտի ծննդյան ամսաթիվը'),
(55193, 4544, 14, 'Պացիենտի փաստաթուղթը'),
(55194, 4545, 14, 'Պացիենտի կրթությունը'),
(55195, 4546, 14, 'Տեղեկություններ Պացիենտի կրթության մասին'),
(55196, 4547, 14, 'Պացիենտի այցը/բուժումը'),
(55197, 4548, 14, 'Պացիենտի այցի/բուժման թերթիկը'),
(55198, 4549, 14, 'Պացիենտի այցերը/բուժումները'),
(55199, 4550, 14, 'Պացիենտի որոնման ինդեքս');
INSERT INTO `lang_definitions` VALUES
(55200, 4551, 14, 'Պացիենտի անունը'),
(55201, 4553, 14, 'Պացիենտի անունը բացակայում է/բաց թողնված է'),
(55202, 4558, 14, 'Պացիենտի սեռը'),
(55203, 4559, 14, 'Պացիենտի սեռը բացակայում է/բաց թողնված է'),
(55204, 4560, 14, 'Պացիենտի չունի պորտալի հասանելիություն'),
(55205, 4561, 14, 'Պացիենտի անամնեզ/հիվ․ պատմություն'),
(55206, 4562, 14, 'Պացիենտի անամնեզ / Ապրելակերպը'),
(55207, 4563, 14, 'Պացիենտի քաղաքային հեռախոսահամար'),
(55208, 4564, 14, 'Պացիենտի ID'),
(55209, 4565, 14, 'Պացիենտի ID'),
(55210, 4566, 14, 'Պացիենտի ID քարտը'),
(55211, 4567, 14, 'Պացիենտի ID կատեգորիայի անվանումը'),
(55212, 4568, 14, 'Պացիենտի պատվաստում'),
(55213, 4569, 14, 'Տեղեկություն Պացիենտի մասին'),
(55214, 4570, 14, 'Պացիենտի ցուցումներ'),
(55215, 4571, 14, 'Պացիենտի ապահովագրության իրականացում'),
(55216, 4572, 14, 'Պացիենտին տրամադրված ապահովագրության հաշվետվություն'),
(55217, 4573, 14, 'Պացիենտի խնդիրները'),
(55218, 4575, 14, 'Պացիենտի ազգանունը'),
(55219, 4577, 14, 'Պացիենտի ազգանունը բացակայում է/բաց թողնված է'),
(55220, 4581, 14, 'Պացիենտների ցանկ'),
(55221, 4582, 14, 'Պացիենտների ցանկի սյուները'),
(55222, 4584, 14, 'Պացիենտների ցանկի նոր պատուհան'),
(55223, 4585, 14, 'Պացիենտների ցանկի էջի չափը'),
(55224, 4586, 14, 'Պացիենտի որոնման սխալ'),
(55225, 4587, 14, 'Պացիենտի բժշկական խնդիրները'),
(55226, 4588, 14, 'Պացիենտին նշանակված դեղորայք'),
(55227, 4589, 14, 'Պացիենտի անուն'),
(55228, 4590, 14, 'Պացիենտի անուն և հասցե'),
(55229, 4593, 14, 'Պացիենտի անունը պարտադիր է'),
(55230, 4595, 14, 'Գրառում Պացիենտի մասին'),
(55231, 4596, 14, 'Պացիենտի գրառման տիպեր'),
(55232, 4597, 14, 'Գրառումներ  Պացիենտի մասին'),
(55233, 4598, 14, 'Գրառումներ  Պացիենտի մասին (գրել, միայն ավելացնել՝ ըստ ցանկության)'),
(55234, 4599, 14, 'Պացիենտի հերթական համարը'),
(55235, 4600, 14, 'Պացիենտի կատարած վճարումը'),
(55236, 4602, 14, 'Պացիենտի լուսանկրաի կատեգորիայի անվանումը'),
(55237, 4603, 14, 'Պացիենտի պորտալ'),
(55238, 4604, 14, 'Պացիենտի պորտալի կապի խնդիր'),
(55239, 4605, 14, 'Պացիենտի պորտալն անջատված է'),
(55240, 4606, 14, 'Մուտք Պացիենտի պորտալ'),
(55241, 4607, 14, 'Պացիենտի պորտալի կայքի հասցեն'),
(55242, 4608, 14, 'Պացիենտի տպագիր հաշվետվություն/զեկույց'),
(55243, 4609, 14, 'Պացիենտների գրանցման հաշվետվություն'),
(55244, 4610, 14, 'Պացիենտների գրանցման հարցում'),
(55245, 4611, 14, 'Պացիենտների գրանցումների հարցումներ'),
(55246, 4613, 14, 'Պացիենտի հիշեցում  Հիշեցում Պացիենտին'),
(55247, 4614, 14, 'Պացիենտի հիշեցման խմբային կիրառում'),
(55248, 4615, 14, 'Պացիենտին ուղղված հիշեցումների ստեղծման առաջնահերթությունը'),
(55249, 4616, 14, 'Պացիենտին ուղղված հիշեցումների կանոններ'),
(55250, 4617, 14, 'Պացիենտին հիշեցում ուղարկողի էլ․ հասցեն'),
(55251, 4618, 14, 'Պացիենտին հիշեցում ուղարկողի ազգանունը'),
(55252, 4619, 14, 'Պացիենտի հիշեցումներ'),
(55253, 4620, 14, 'Հաշվետվություն/զեկույց Պացիենտի մասին'),
(55254, 4621, 14, 'Պացիենտի հարցում'),
(55255, 4622, 14, 'Պահանջվող Հիվանդության պատմություն'),
(55256, 4623, 14, 'Արդյունքներ Պացիենտի մասին'),
(55257, 4624, 14, 'Պացիենտի որոնման արդյունքներ'),
(55258, 4625, 14, 'Պացիենտի որոնման/ավելացման պատուհան'),
(55259, 4626, 14, 'Պացիենտի գրանցման կարգավորումներ'),
(55260, 4627, 14, 'Պացիենտի վիճակը'),
(55261, 4629, 14, 'Պացիենտի ամփոփ նկարագիր'),
(55262, 4630, 14, 'Պացիենտների տեղափոխում'),
(55263, 4631, 14, 'Պացիենտի փոստային ինդեքս'),
(55264, 4632, 14, 'Տվյալների բազայում մուտքագրված անձնական/ազգագրական տվյալներով Պացիենտ(ներ)ի համապատասխանություն/համընկնում'),
(55265, 4633, 14, 'Պացիենտ/Հաախորդ'),
(55266, 4634, 14, 'Պացիենտ։'),
(55267, 4635, 14, 'Պաց․ ID'),
(55268, 4636, 14, 'Պացիենտներ'),
(55269, 4637, 14, 'Պացիենտների տվյալների մշակում'),
(55270, 4638, 14, 'Վճարել'),
(55271, 4639, 14, 'Ուշադրություն դարձրեք "Պատրաստ է" ցուցավանդակին․ Ապահովագրական տվյալների  լրացումից հետո խնդրում ենք Պացիենտին վճարել մնացորդը․ եթե չնշեք ապահովագրության ամբողջական կատարում, ապա  հնարավոր չի լինի գանձել գումարի մնացորդը։ Եթե կա պացիենտի կողմից վճարվելիք մնացորդ, ապա տեղադրել վճարման համապատասխան ամսաթիվ/ժամկետ, քանի որ այն կազդի ․․․․'),
(55272, 4640, 14, 'Վճարման ամսաթիվ։'),
(55273, 4641, 14, 'Վճարման կարգավիճակ'),
(55274, 4642, 14, 'Վճարը ստացողի անունը'),
(55275, 4643, 14, 'Վճարող'),
(55276, 4644, 14, 'Վճարման տեսակը'),
(55277, 4645, 14, 'Վճարում'),
(55278, 4646, 14, 'Վճարող/ Վճարում կատարող'),
(55279, 4647, 14, 'Վճար/Վճարում'),
(55280, 4648, 14, 'Վճար/Վճարում'),
(55281, 4649, 14, 'Վճարման ճշգրտման կոդ'),
(55282, 4651, 14, 'Վճարման գումար'),
(55283, 4652, 14, 'Վճարման գումարը թվերով'),
(55284, 4653, 14, 'Վճարման կատեգորիա'),
(55285, 4654, 14, 'Վճարման ամսաթիվ'),
(55286, 4655, 14, 'Վճարում՝ մուտքագրված ֊ին'),
(55287, 4656, 14, 'Վճարում ֊ից'),
(55288, 4659, 14, 'Վճարման ցուցակ'),
(55289, 4660, 14, 'Վճարման մեթոդ'),
(55290, 4661, 14, 'Դասավորել վճարումներն ըստ'),
(55291, 4662, 14, 'Վճարման կարգավիճակ'),
(55292, 4663, 14, 'Վճարման ձև'),
(55293, 4664, 14, 'Վճարման կոդ '),
(55294, 4665, 14, 'Վճարումներ'),
(55295, 4667, 14, 'PCP'),
(55296, 4668, 14, 'Տողերի տակաոսը (%)'),
(55297, 4669, 14, 'PDF'),
(55298, 4670, 14, 'PDF ֆորմատով բեռնված ընտրված հաշվետվություններ'),
(55299, 4671, 14, 'PDF լեզու'),
(55300, 4672, 14, 'կոնքի և հետույքի շրջան'),
(55301, 4673, 14, 'բշտիկ'),
(55302, 4674, 14, 'ընթացում/ընթացքի մեջ գտնվող'),
(55303, 4675, 14, 'Հաստատման մեջ / հաստատման սպասող'),
(55304, 4676, 14, 'Հաջորդիվ սպասվող'),
(55305, 4677, 14, 'Հաջորդիվ սպասվող'),
(55306, 4678, 14, 'Արդյունքից սպասվողշարունակությունը'),
(55307, 4679, 14, 'Ընթացում/ընթացքի մեջ գտնվող նշանակումներ/ցուցումներ'),
(55308, 4681, 14, 'Սպասվող գնահատականը'),
(55309, 4685, 14, 'մարսողական համակարգի խոցային հիվանդություն'),
(55310, 4686, 14, 'Յուրաքանչյուր այց/հանդիպում'),
(55311, 4687, 14, 'յուր․ րոպե'),
(55312, 4688, 14, 'Յուր․ քթանցքին'),
(55313, 4689, 14, 'Յուր․ քթանցքին'),
(55314, 4692, 14, 'Ուղիղ աղու միջով'),
(55315, 4693, 14, 'Ուղիղ աղու միջով'),
(55316, 4694, 14, 'Տոկոս'),
(55317, 4697, 14, 'Տոկոսային'),
(55318, 4699, 14, 'Կատարել որոնում'),
(55319, 4700, 14, 'Կատարել սույն գործողությունը'),
(55320, 4701, 14, 'Իրագործման տոկոսը'),
(55321, 4703, 14, 'Իրականացնել լաբորատոր ծառայություններ'),
(55322, 4705, 14, 'Շրջան/ժամանակաշրջան'),
(55323, 4708, 14, 'Ծայրամասային/պերիֆերիկ'),
(55324, 4710, 14, 'Պարսկերեն'),
(55325, 4711, 14, 'Պարսկերեն'),
(55326, 4712, 14, 'Անձ'),
(55327, 4713, 14, 'Անհատականացաում/անհատականացնել'),
(55328, 4714, 14, 'PG'),
(55329, 4715, 14, 'Դեղատուն'),
(55330, 4716, 14, 'Ընդհ․ դեղ․ հաշիվ'),
(55331, 4717, 14, 'Դեղատներ'),
(55332, 4718, 14, 'Դեղատուն'),
(55333, 4719, 14, 'Դեղատնային/դեղագործական բաժանմունք'),
(55334, 4720, 14, 'Պնեվմոտորաքս'),
(55335, 4721, 14, 'phiMail Allow CCD ուղարկում'),
(55336, 4722, 14, 'phiMail Allow CCR ուղարկում'),
(55337, 4723, 14, 'phiMail հաղորդագրության ուղարկում'),
(55338, 4724, 14, 'phiMail ծանուցումների օգտատեր'),
(55339, 4725, 14, 'phiMail գաղտնաբառ'),
(55340, 4726, 14, 'phiMail սերվերի հասցե'),
(55341, 4727, 14, 'phiMail օգտվողի անուն'),
(55342, 4729, 14, 'Հեռախոս'),
(55343, 4730, 14, 'Հեռախոսազանգերի ցանկ'),
(55344, 4731, 14, 'Հեռախոսազանգերի հաշվետվություն'),
(55345, 4732, 14, 'Հեռախոսահամարի վանդակ'),
(55346, 4733, 14, 'Հեռախոսի կապուղու/gateway գաղտնաբառ'),
(55347, 4734, 14, 'Հեռախոսի կապուղու/gateway URL/հասցե'),
(55348, 4735, 14, 'Հեռախոսի կապուղու/gateway օգտվողի անուն'),
(55349, 4736, 14, 'Քաղաքային հեռախոսահամար'),
(55350, 4737, 14, 'Հեռախոսային ծանուցման ժամ'),
(55351, 4738, 14, 'Հեռախոսահամար'),
(55352, 4739, 14, 'հեռախոսահամար'),
(55353, 4740, 14, 'Ֆոտոֆոբիա /աչքի չափազանց զգայունությունը լույսի հանդեպ/'),
(55354, 4741, 14, 'Ֆոտոներ/նկարներ'),
(55355, 4742, 14, 'սեղմված PHP'),
(55356, 4743, 14, 'PHP CURL մոդուլը պետք է միացված լինի ձեր սերվերին'),
(55357, 4744, 14, 'PHP-ն բացված է'),
(55358, 4745, 14, 'php-GACL հասանելիությունն անջատված է'),
(55359, 4746, 14, 'PHP-gacl տեղադրված չէ'),
(55360, 4747, 14, 'Բժշկական զննություն'),
(55361, 4749, 14, 'Բժշկական հարցում'),
(55362, 4750, 14, 'Բժշկի ստորագրություն'),
(55363, 4752, 14, 'Թերապեվտ'),
(55364, 4753, 14, 'ընտրել'),
(55365, 4754, 14, 'Ընտրել'),
(55366, 4755, 14, 'Ընտրել CSS թեման'),
(55367, 4756, 14, 'ՓԿԲՀ'),
(55368, 4757, 14, 'ՓԿԲՀ (Փոքր կոնքի բորբոքային հիվանդություն)'),
(55369, 4758, 14, 'Դեղահաբի չափը'),
(55370, 4759, 14, 'Դեղահաբեր'),
(55371, 4760, 14, 'Այս տարբերակի տեղադրման համար տվյալների բազայի  zip ֆայլն հետևյալ տեղեկատուի մեջ'),
(55372, 4761, 14, 'Տեղադրեք ներբեռնված  ICD 10 տվյալների բազայի  zip ֆայլերը հետևյալ տեղեկատուի մեջ'),
(55373, 4762, 14, 'Տեղադրեք ներբեռնված  ICD 9 տվյալների բազայի  zip ֆայլը հետևյալ տեղեկատուի մեջ'),
(55374, 4763, 14, 'Տեղադրեք ներբեռնված RxNorm տվյալների բազայի  zip ֆայլը հետևյալ տեղեկատուի մեջ'),
(55375, 4764, 14, 'Տեղադրեք ներբեռնված Snomed տվյալների բազայի  zip ֆայլը հետևյալ տեղեկատուի մեջ'),
(55376, 4765, 14, 'Տեղապահ կոճակ'),
(55377, 4766, 14, 'Տեղապահ կոճակ  (աջակցում է դատարկ ACLs)'),
(55378, 4767, 14, 'Հասարակ տեքստ'),
(55379, 4768, 14, 'Պլան/Ծրագիր'),
(55380, 4771, 14, 'Ծրագրի անուն'),
(55381, 4775, 14, 'Ծրագրի տեղադրում'),
(55382, 4779, 14, 'Պլան/Ծրագիր։'),
(55383, 4782, 14, 'Պլաններ։ / Ծրագրեր։'),
(55384, 4784, 14, 'Մասնակից'),
(55385, 4785, 14, 'Մասնակցի պաշտոնը'),
(55386, 4786, 14, 'Եթե վերոնշյալ ինֆորմացիան սխալ է, խնդրում ենք արձագանքել'),
(55387, 4787, 14, 'Փոխեք Ձեր գաղտնաբառը'),
(55388, 4788, 14, 'Ընտրեք ֆայլը'),
(55389, 4789, 14, 'Ընտրեք Պացիենտին'),
(55390, 4790, 14, 'Նշեք ճիշտ ընտրվածը'),
(55391, 4791, 14, 'Նշեք ճիշտը'),
(55392, 4792, 14, 'Ընտրեք արժեք'),
(55393, 4793, 14, 'Վերևում ընտրեք ամսաթվերի տիրույթի կրիտերիաները և սեղմեք Թարմացնել կոճակը՝ արդյունքը տեսնելու համար'),
(55394, 4794, 14, 'Ընտրեք համապատասխամ ֆորմատով EDI-271 ֆայլը'),
(55395, 4797, 14, 'Փակեք պատուհանը'),
(55396, 4798, 14, 'Համեմատեք նոր անվանումը'),
(55397, 4800, 14, 'Ուղղեք արժեքները մինչ գործարկումը'),
(55398, 4801, 14, 'Մինչ գործարկումն ստեղծել հետևյալ տեղեկատուն'),
(55399, 4809, 14, 'Մուտքագրել վերջին վերանայման ամսաթիվը'),
(55400, 4810, 14, 'Մուտքագրել  ամսաթիվ'),
(55401, 4811, 14, 'Մուտքագրել ճիշտ ամսաթիվ'),
(55402, 4812, 14, 'Մուտքագրել հաղորդագրություն'),
(55403, 4813, 14, 'Մուտքագրել գումար՝ օգտագործելով միայն թվեր ու տասնորդական կետեր'),
(55404, 4814, 14, 'Մուտքագրել նոր գաղտնաբառ'),
(55405, 4815, 14, 'Մուտքագրել վերնագիր'),
(55406, 4817, 14, 'Մուտքագրել առնվազն տարրի անվանումը'),
(55407, 4818, 14, 'Մուտքագրել առնվազն ուղու անվանումը'),
(55408, 4819, 14, 'Մուտքագրել կրկնակի նույնականացման ճշգրիտ կոդ'),
(55409, 4820, 14, 'Ավարտի ամսաթվին ավելի մեծ պետք է լինի, քան սկսզբի ամսաթիվը'),
(55410, 4821, 14, 'Ավելացրեք որոնման նոր տող'),
(55411, 4822, 14, 'Մուտքագրել կրկնակի նույնականացման ճշգրիտ կոդը'),
(55412, 4823, 14, 'Մուտքագրել  գաղտնաբառը'),
(55413, 4824, 14, 'Լրացրեք գրանցման համարը'),
(55414, 4825, 14, 'Լրացրեք գրանցման/Ref համարը'),
(55415, 4826, 14, 'Լրացրեք ամսաթիվը'),
(55416, 4827, 14, 'Լրացրեք վճարման գումարը'),
(55417, 4828, 14, 'Լրացրեք վճարման կատեգորիան'),
(55418, 4829, 14, 'Լրացրեք "Ում կողմից է վճարվել"'),
(55419, 4830, 14, 'Լրացրեք գրառումն այսօրվա ամսաթվով'),
(55420, 4831, 14, 'Նախքան շարունակելը լրացրեք դրանք/այդ'),
(55421, 4832, 14, 'Խնդրում ենք նշել այցի պատճառը'),
(55422, 4833, 14, 'Վերևում նշանակեք որոնման չափորոշիչներ և գործարկման համար սեղմեք Հաստատել'),
(55423, 4834, 14, 'Վերևում նշանակեք որոնման չափորոշիչներ և արդյունքը տեսնելու համար սեղմեք Հաստատել'),
(55424, 4835, 14, 'Վերևում նշանակեք որոնման չափորոշիչներ և արդյունքը տեսնելու համար սեղմեք Հաստատել (Արդյունքը կցուցադրվի թարթող պատուհանով)'),
(55425, 4836, 14, 'Խնդրում ենք՝ կրկին մուտք գործեք'),
(55426, 4837, 14, 'Ի նկատի ունեցեք, որ դա կարող է երկար տևել, ընդհուպ մի քանի րոպե․ այս ընթացքում բրոուզերն ակտիվ չի լինի․ հաշվի գեներացումը բարդ պրոցես է, և բրոուզերն ուղղակի սպասում է ինֆորմացիայի առավել մեծ պաշարի'),
(55427, 4838, 14, 'Ուշադրություն․'),
(55428, 4839, 14, 'Օգտագործեք միայն այբենական նիշեր/սիմվոլներ'),
(55429, 4840, 14, 'Օգտագործեք միայն այբենական նիշեր/սիմվոլներ՝ առանց բացատների'),
(55430, 4841, 14, 'Խնդրում ենք վճարել սույն գումարը'),
(55431, 4842, 14, 'Տեղադրեք թողարկվող ֆայլերն այս տեղեկատու մեջ'),
(55432, 4843, 14, 'Խնդրում ենք դիմել  -ին'),
(55433, 4844, 14, 'Վերագրանցեք գաղտնաբառը'),
(55434, 4845, 14, 'Խնդրում ենք վերագործարկել Apache սերվերը մինչև'),
(55435, 4846, 14, 'Խնդրում ենք նայեք կից PDF ֆայլը'),
(55436, 4847, 14, 'Խնդրում ենք ընտրել'),
(55437, 4849, 14, 'Խնդրում ենք ընտրել լեզուն'),
(55438, 4850, 14, 'Խնդրում ենք ընտրել Պացիենտ'),
(55439, 4854, 14, 'Ընտրեք ստացողին'),
(55440, 4855, 14, 'Ընտրեք սկզբի և ավարտի ամսաթվերը'),
(55441, 4856, 14, 'Ընտրեք վավեր ստացողի'),
(55442, 4857, 14, 'Ընտրեք ակտիվ խումբ'),
(55443, 4858, 14, 'Ընտրեք կոդի ճշգրտման պատճառը '),
(55444, 4859, 14, 'Ընտրեք իրադարձություն'),
(55445, 4860, 14, 'Ընտրեք որոնման տարբերակ'),
(55446, 4863, 14, 'Ընտրեք առնվազն մեկ դեղատոմս'),
(55447, 4864, 14, 'Ընտրեք այցելություն'),
(55448, 4865, 14, 'Ընտրեք կրկնօրինակման կամ փոխանցման համար նախընտրելի էջերը'),
(55449, 4866, 14, 'Ընտրեք վճարման տարբերակը'),
(55450, 4867, 14, 'Ընտրեք վճարման տեսակը'),
(55451, 4868, 14, 'Ընտրեք այցելության կատեգորիան'),
(55452, 4869, 14, 'Ընտրեք 270 խմբաքանակի ստեղծման համար պահանջվող X12 գործընկերոջը'),
(55453, 4870, 14, 'Տեղադրեք'),
(55454, 4873, 14, 'Սկսեք նոր դեիդենտիֆիկացիոն գործընթացը'),
(55455, 4874, 14, 'Թարմացրեք LibreEHR տվյալների բազան՝ դեիդենտիֆիկացիոն միջամտությունների, ֆունկցիայի և աղյուսակների  ներառման համար'),
(55456, 4875, 14, 'Մանրամասն տեղեկությունների համար նայեք դեիդենտիֆիկացիոն սխալների աղյուսակը'),
(55457, 4876, 14, 'Որոշ ժամանակ անց այցելեք դեիդենտիֆիկացիայի էկրան'),
(55458, 4877, 14, 'Որոշ ժամանակ անց այցելեք վերանույնականացման էկրան'),
(55459, 4878, 14, 'Որոշ ժամանակ անց այցելեք  էկրան'),
(55460, 4881, 14, 'Հոգնակի/բազմակի'),
(55461, 4882, 14, '1․ Կեսօրից հետո 2, Անձնական նամակ'),
(55462, 4883, 14, 'երեկոյան ծրագիր'),
(55463, 4884, 14, 'Pmt մեթոդ'),
(55464, 4885, 14, '1․ Պարոքսիզմալ գիշերային շնչահեղձություն/հևոց 2, Գիշերային շնչահեղձության համախտանիշ'),
(55465, 4890, 14, 'Թոքատապային պատվաստանյութ'),
(55466, 4891, 14, 'Թոքատապային պատվաստում'),
(55467, 4892, 14, 'Թոքաբորբի պատվաստանյութի կարգավիճակը տարեցների/մեծահասակների համար'),
(55468, 4893, 14, 'Թոքաբորբի պատվաստանյութի կարգավիճակը տարեցների/մեծահասակների համար (CQM)'),
(55469, 4896, 14, 'Ծառայության մատուցման վայրը'),
(55470, 4897, 14, 'Ապահովագրություն/Ապահովագրաթերթիկ'),
(55471, 4898, 14, 'Ապահովագրություն/Ապահովագրաթերթիկ  №'),
(55472, 4899, 14, 'Ապահովագրության/Ապահովագրաթերթիկի համարը'),
(55473, 4900, 14, 'Լեհերեն'),
(55474, 4901, 14, 'Պոլիդիպսիա'),
(55475, 4902, 14, 'Պոլիպ'),
(55476, 4903, 14, 'Պոլիուրիա'),
(55477, 4904, 14, 'Վատ ախորժակ'),
(55478, 4905, 14, 'Վատ շրջանառություն'),
(55479, 4906, 14, 'Վատ լսողություն'),
(55480, 4907, 14, 'Այս հաշվետվությունները ցուցադրելու համար անհրաժեշտ է ակտիվացնել Pop ups'),
(55481, 4908, 14, 'Տեղակայե՞լ իրադարձությունները տարեցույցի հետ'),
(55482, 4909, 14, 'Թարթող պատուհան'),
(55483, 4910, 14, 'Պորտալ'),
(55484, 4911, 14, 'Պորտալի ակտիվությունը'),
(55485, 4912, 14, 'Պորտալի ID'),
(55486, 4913, 14, 'Պորտալի ID-ն չի համապատասխանում'),
(55487, 4914, 14, 'Պորտալի գաղտնաբառը բացակայում է'),
(55488, 4915, 14, 'Պորտալի պահանջները'),
(55489, 4916, 14, 'Գրքային'),
(55490, 4917, 14, 'Պորտուգալերեն'),
(55491, 4918, 14, 'Պորտուգալերեն (բրազիլական)'),
(55492, 4919, 14, 'Պորտուգալերեն (եվրոպական)'),
(55493, 4920, 14, 'POS /Ծառայության Մատուցման Վայր/ կոդ'),
(55494, 4921, 14, 'Դիրք Պաշտոն'),
(55495, 4922, 14, 'Դրական'),
(55496, 4923, 14, 'Դրական արդյունքներ'),
(55497, 4925, 14, 'Ուղարկել դեպի/համար'),
(55498, 4926, 14, 'Քթային կաթիլներ'),
(55499, 4927, 14, 'Հետվճարներ'),
(55500, 4928, 14, 'Հետվիրահատական'),
(55501, 4929, 14, 'Ուղարկել հաշվառման և գրանցել որպես վճարված'),
(55502, 4930, 14, 'Վճարված է առ այսօր'),
(55503, 4931, 14, 'Վճարված է "առ այսօր" չի կարող այսօրվանից ավելի մեծ լինել'),
(55504, 4932, 14, 'Վճարել  "առ այսօր" պետք է ավելի մեծ լինի ֆինանսական ձևակերպման փակման օրվանից'),
(55505, 4933, 14, 'Հետաբորտային խնամք'),
(55506, 4934, 14, 'Հետաբորտային հակաբեղմնավորիչ'),
(55507, 4935, 14, 'Հետաբորտային խորհրդատվություն'),
(55508, 4936, 14, 'Հետաբորտային այցեր'),
(55509, 4937, 14, 'Փոստային'),
(55510, 4938, 14, 'Փոստային ինդեքս'),
(55511, 4939, 14, 'Փոստային ինդեքս'),
(55512, 4941, 14, 'PostCalendar'),
(55513, 4942, 14, 'PostCalendar-ի համակարգում'),
(55514, 4943, 14, 'PostCalendar-ի կատեգորիաների կարգավորում'),
(55515, 4944, 14, 'PostCalendar-ի գլոբալ կարգավորում'),
(55516, 4945, 14, 'Հրապարակված է'),
(55517, 4946, 14, 'Ուղարկման ամսաթիվ'),
(55518, 4947, 14, 'Pos{{Պաշտոնի հապավումը}}'),
(55519, 4948, 14, 'Աշխատում է -ի միջոցով'),
(55520, 4949, 14, 'PPE + Prev Med/Surg Hx'),
(55521, 4950, 14, 'PQRI'),
(55522, 4951, 14, 'PQRI գրանցման ID'),
(55523, 4952, 14, 'PQRI գրանցման Անուն'),
(55524, 4953, 14, 'Պրակտիկա'),
(55525, 4954, 14, 'Բժշկական պրակտիկայի Default/կանխադրված կարգավորումներ'),
(55526, 4955, 14, 'Բժշկական պրակտիկայի կարգավորումներ'),
(55527, 4956, 14, 'Մասնակից/Կատարող'),
(55528, 4957, 14, 'Մասնակցության նախընտրական գնահատում'),
(55529, 4958, 14, 'Նախօրոք վճարել'),
(55530, 4959, 14, 'Կանխավճար'),
(55531, 4960, 14, 'Նախաաբորտային կոնսուլտացիա'),
(55532, 4961, 14, 'Նախաաբորտային խորհրդատվություն'),
(55533, 4962, 14, 'Նախընտրելի կատեգորիան'),
(55534, 4963, 14, 'Նախապատվություն/Գերադասություն'),
(55535, 4964, 14, 'Նախապատվություններ'),
(55536, 4965, 14, 'Միջոցառման/իրադարձության նախընտրելի կատեգորիան'),
(55537, 4966, 14, 'Նախընտրելի լեզուն'),
(55538, 4967, 14, 'Նախընտրելի դեղատունը'),
(55539, 4968, 14, 'Նախընտրելի բժշկական հաստատությունը'),
(55540, 4969, 14, 'Հղիության թեստ'),
(55541, 4970, 14, 'Նախնական/սկզբնական'),
(55542, 4971, 14, 'Զեկույցի մեկնարկի նախապատրաստում'),
(55543, 4972, 14, 'Կանխավճար'),
(55544, 4973, 14, 'Նշանակում'),
(55545, 4974, 14, 'Նշանակումը հասել է իր սահմանին'),
(55546, 4975, 14, 'Նշանակումների թերթիկ/պատմություն'),
(55547, 4976, 14, 'Նշանակումների թերթիկի/պատմության ներբեռնումն հաջողվեց'),
(55548, 4977, 14, 'Նշանակումների պիտակ'),
(55549, 4978, 14, 'Նշանակումների հաշվետվություն'),
(55550, 4979, 14, 'Նշանակումներ/դեղատոմսեր'),
(55551, 4980, 14, 'Նշանակում և բաշխում'),
(55552, 4981, 14, 'Նշանակումներ և այլ ուղեգրեր'),
(55553, 4982, 14, 'Մասնագետի կողմից արված նշանակումներ և/կամ ուղեգրեր'),
(55554, 4983, 14, 'Նշանակումների հաշվետվություն'),
(55555, 4984, 14, 'Նշանակումներ/Ուղեգրեր'),
(55556, 4985, 14, 'Առկա է'),
(55557, 4986, 14, 'Առկա գանգատներ'),
(55558, 4987, 14, 'Առկա խնդիր(ներ)'),
(55559, 4988, 14, 'Գործարկման համար սեղմել "Շարունակել"'),
(55560, 4989, 14, 'Ենթադրյալ ախտորոշում'),
(55561, 4990, 14, 'Մասնագետի ենթադրյալ ախտորոշում'),
(55562, 4991, 14, 'Նխրդ․'),
(55563, 4992, 14, 'Նխրդ Բժշ/Վրբժ․ Hx'),
(55564, 4993, 14, 'Նախորդ ամիս (ցանկում պահպանված)'),
(55565, 4994, 14, 'Նախորդ տարի (ցանկում պահպանված)'),
(55566, 4995, 14, 'Կանխարգելիչ բուժում'),
(55567, 4996, 14, 'Կանխարգելիչ վերականգնում'),
(55568, 4998, 14, 'Միջոցառման/իրադարձության նախադիտում'),
(55569, 5000, 14, '-ի նախադիտում'),
(55570, 5001, 14, 'Նախորդ/անցած/նախկին'),
(55571, 5002, 14, 'Նախկին կոնսուլտացիաներ'),
(55572, 5003, 14, 'Նախորդ օրը'),
(55573, 5004, 14, 'Անցածի պատմություն/Էկրանավորում/ցուցադրում'),
(55574, 5005, 14, 'Նախորդ ամիս'),
(55575, 5006, 14, 'Նախորդ շաբաթ'),
(55576, 5007, 14, 'Գին'),
(55577, 5008, 14, 'Զեղչ'),
(55578, 5009, 14, 'Գնային սանդղակ'),
(55579, 5010, 14, 'Գնային սանդղակ։'),
(55580, 5011, 14, 'Գներ'),
(55581, 5012, 14, 'Հիմնական'),
(55582, 5013, 14, 'Գործունեության հիմնական տեսակը'),
(55583, 5014, 14, 'Իրավաբանական անձի հարկային կոդը NewCrop ePrescription-ում օգտագործվում է որպես  id։ Հաստատությունը փոփոխելը կարող է ազդել NewCropի աշխատանքին'),
(55584, 5022, 14, 'Հիմնական/տարրական ապահովագրություն'),
(55585, 5023, 14, 'Հիմնական/տարրական ապահովագրություն'),
(55586, 5024, 14, 'Հիմնական/տարրական ապահովագրության ամսաթիվ'),
(55587, 5025, 14, 'Հիմնական ապահովագրող'),
(55588, 5027, 14, 'Տպել'),
(55589, 5028, 14, 'Տպել (HTML)'),
(55590, 5029, 14, 'Տպել  (PDF)'),
(55591, 5030, 14, 'Տպագրական ուղղումներ'),
(55592, 5031, 14, 'Տպել ցանկացած այց'),
(55593, 5032, 14, 'Տպել ուղեգրի նմուշ/դատարկ ձև'),
(55594, 5033, 14, 'Տպագրության հրաման'),
(55595, 5034, 14, 'Տպագրության ամսաթիվ'),
(55596, 5038, 14, 'Տպել ամբողջ ցանկը'),
(55597, 5039, 14, 'Տպագրության ֆորմատ'),
(55598, 5042, 14, 'Տպել հաղորդագրությունը'),
(55599, 5043, 14, 'Բազմակի տպագրություն'),
(55600, 5045, 14, 'Տպել անունը, ստորագրությունն ու ամսաթիվը'),
(55601, 5046, 14, 'Տպել նշումները'),
(55602, 5047, 14, 'Տպել էջ 1'),
(55603, 5048, 14, 'Տպել էջ 2'),
(55604, 5049, 14, 'Տպել պացիենտի հասցեի տողը'),
(55605, 5051, 14, 'Տպել դեղատոմսերն ըստ նշանակողի'),
(55606, 5053, 14, 'Տպել ընտրված հաշվետվությունները'),
(55607, 5056, 14, 'Տպել սույն այցը'),
(55608, 5057, 14, 'Տպել սույն նշումը'),
(55609, 5058, 14, 'Տպել Սույն Նշումը'),
(55610, 5060, 14, 'ՖԱՔՍի արտածում'),
(55611, 5061, 14, 'Տպագրության նախնական տեսքը'),
(55612, 5062, 14, 'տպագրության ենթակա'),
(55613, 5063, 14, 'Տպագրության տարբերակ'),
(55614, 5064, 14, 'Տպագիր/տպագրված'),
(55615, 5066, 14, 'Տպագրության արդյունքներ։'),
(55616, 5067, 14, 'Տպագրությունը բաց թողնված է․ տես թեստային եզրակացությունը'),
(55617, 5068, 14, 'Տպագրությունը բաց թողնված է․ տես թեստային եզրակացությունը '),
(55618, 5069, 14, 'Նախն․ լիազորություն/թույլատրություն'),
(55619, 5070, 14, 'Նախնական լիազորության ձև'),
(55620, 5071, 14, 'Նախնական այց'),
(55621, 5072, 14, 'Առաջնայնություն/կարևորություն'),
(55622, 5073, 14, 'Առաջնայնություն/կարևորություն '),
(55623, 5074, 14, 'Գաղտնի'),
(55624, 5075, 14, 'Խնդիր'),
(55625, 5076, 14, 'DX խնդիր'),
(55626, 5077, 14, 'Խնդրացուցակ'),
(55627, 5078, 14, 'Խնդիրներ'),
(55628, 5079, 14, 'Խնդիրներ/գանգատներ'),
(55629, 5087, 14, 'Մարմնի հատվածային/մասնակի միջամտություն'),
(55630, 5088, 14, 'Միջամտության Բուլյան արդյունքներ'),
(55631, 5089, 14, 'Միջամտության կոդ'),
(55632, 5090, 14, 'Միջամտության կոդեր'),
(55633, 5091, 14, 'Աջլիկության/Ձախլիկության միջամտություն'),
(55634, 5092, 14, 'Միջամտության անվանում'),
(55635, 5093, 14, 'Միջամտության պատվեր/պահանջ'),
(55636, 5094, 14, 'Միջամտության պատվեր/պահանջ'),
(55637, 5095, 14, '-ի միջամտության պահանջ'),
(55638, 5096, 14, 'Միջամտության պատվեր/պահանջ չի գտնվել'),
(55639, 5097, 14, 'Միջամտության պահանջներ և  հաշվետվություններ'),
(55640, 5098, 14, 'Միջամտության նշիչ/ընտրիչ'),
(55641, 5099, 14, 'Միջամտություն իրականացնող'),
(55642, 5100, 14, 'Միջամտություն Իրականացնող'),
(55643, 5101, 14, 'Միջամտություն Իրականացնողներ'),
(55644, 5102, 14, 'Միջամտության  հաշվետվություն/զեկույց'),
(55645, 5103, 14, 'Միջամտության  հաշվետվության/զեկույցի կարգավիճակ'),
(55646, 5104, 14, 'Միջամտության արդյունքը նորմայից շեղված է'),
(55647, 5105, 14, 'Միջամտության արդյունքների կարգավիճակ'),
(55648, 5106, 14, 'Միջամտության արդյունքներ'),
(55649, 5107, 14, 'Միջամտության ընթացքը'),
(55650, 5108, 14, 'Միջամտության բիոփորձարկման տեսակներ'),
(55651, 5109, 14, 'Միջամտության վիակագրական զեկույց'),
(55652, 5110, 14, 'Միջամտության տեսակ'),
(55653, 5111, 14, 'Միջամտության տեսակներ'),
(55654, 5112, 14, 'Միջամտությունների չափման միավորներ'),
(55655, 5113, 14, 'Միջամտություն/Ծառայություն'),
(55656, 5114, 14, 'Միջամտություններ'),
(55657, 5115, 14, 'Մշակել/Գործարկել'),
(55658, 5116, 14, 'Մշակել և Ուղարկել Հիշեցումներ'),
(55659, 5117, 14, 'Մշակել ERA ֆայլը'),
(55660, 5118, 14, 'CSV գրանցումների համար մշակեք նոր ֆայլեր'),
(55661, 5119, 14, 'Գործընթացի հիշեցումներ'),
(55662, 5120, 14, 'Գործընթացը որոշ ժամանակ կտևի'),
(55663, 5121, 14, 'Գործարկված/մշակված է'),
(55664, 5122, 14, 'Գործարկված/մշակված է -ի միջոցով'),
(55665, 5123, 14, 'Գործարկման ամսաթիվ'),
(55666, 5124, 14, 'հաջողությամբ Գործարկված/մշակված է'),
(55667, 5125, 14, 'մշակվող մշակվում է'),
(55668, 5126, 14, 'Պացիենտի հիշեցումների մշակում և ուղարկում'),
(55669, 5127, 14, 'Պացիենտի հիշեցումների մշակում'),
(55670, 5128, 14, 'Մշակման ժամանակ'),
(55671, 5129, 14, 'Ապրանք/արտադրանք'),
(55672, 5131, 14, 'Արտադրություն'),
(55673, 5132, 14, 'Արտադրանք'),
(55674, 5133, 14, 'Ապրանքներ, բայց ոչ նշանակված դեղորայք կամ շաբլոններ'),
(55675, 5134, 14, 'Պրոֆ․'),
(55676, 5135, 14, 'Նշումներ առաջընթացի վերաբերյալ'),
(55677, 5136, 14, 'Շագանակագեղձի քաղցկեղ'),
(55678, 5137, 14, 'Շագանակագեղձի քաղցկեղի սկրինինգ/կանխարգելում'),
(55679, 5138, 14, 'Շագանակագեղձի քաղցկեղի հետազոտություն'),
(55680, 5139, 14, 'Շագանակագեղձի խնդիրներ'),
(55681, 5140, 14, 'Շագանակագեղձի մեծացման, հանգուցավորման, անզգայունության բացակայություն'),
(55682, 5141, 14, 'Արձանագրություն'),
(55683, 5142, 14, 'Ապահովել/տրամադրել բացարձակ ուղի'),
(55684, 5143, 14, 'Ապահովել/տրամադրել բացարձակ ուղի դեպի ֆայլը'),
(55685, 5145, 14, 'Յուրաքանչյուր կաբինետային այցի համար տրամադրել պացիենտի լինիկական ամփոփագիր'),
(55686, 5146, 14, 'Ըստ պահանջի պացիենտին տրմադրել իր առողջության մասին տեղեկագրի էլէկտրոնային կրկնօրինակը (ներառյալ ախտորոշիչ հետազոտություների արդյունքները, խնդրացանկը, դեղորայքի ցանկը, դեղերի հանդեպ գրանցված ալերգիաները)։'),
(55687, 5147, 14, 'EP-ում ինֆորմացիային հասանաելի լինելուց 4 աշխատանքային օրվա ընթացքում պացիենտին ժամանակին տրամադրել իր առողջական տեղեկատվության (ներառյալ լաբորատոր հետազոտության արդյունքները, խնդրացանկը, դեղորայքի ցանկը, դեղերի հանդեպ գրանցված ալերգիաները ) էլեկտրոնային հասանելիություն։'),
(55688, 5148, 14, 'Տրամադրել հիվանդի այցի վերաբերյալ  գրառումներ'),
(55689, 5149, 14, 'Տրամադրեք վավեր էլ․փոստի հասցե'),
(55690, 5150, 14, 'Տրամադրե՞լ բժշկական ամփոփագիր'),
(55691, 5151, 14, 'Տրամադրե՞լ կրթական ռեսուրսներ'),
(55692, 5152, 14, 'Մասնագետ'),
(55693, 5153, 14, 'Մասնագետի id'),
(55694, 5154, 14, 'Մասնագետի ID'),
(55695, 5155, 14, 'Նշված Հաստատությունում Մասնագետի ID'),
(55696, 5156, 14, 'Մասնագետի համապատասխանության սխալ'),
(55697, 5159, 14, 'Մասնագետի հերթական համարը'),
(55698, 5162, 14, 'Մասնագետ։'),
(55699, 5163, 14, 'Մասնագետներ։'),
(55700, 5164, 14, 'Մասնագետի  NPI'),
(55701, 5165, 14, 'Մասնագետները տեսնում են ողջ օրացույցը'),
(55702, 5167, 14, 'PSA'),
(55703, 5168, 14, 'Փսորիազ'),
(55704, 5169, 14, 'Հոգեկան ախտորոշում'),
(55705, 5170, 14, 'հոգեմետ դեղորայք'),
(55706, 5171, 14, 'Հոգեբուժական'),
(55707, 5172, 14, 'Հոգեբուժական հակիրճ նամակ'),
(55708, 5173, 14, 'Հոգեկան/հոգեբուժական ախտորոշում'),
(55709, 5174, 14, 'Հոգեկան/հոգեբուժական հետազոտություն'),
(55710, 5175, 14, 'Հոգեբուժական անամնեզ'),
(55711, 5176, 14, 'հոգեմետ դեղորայքի ընդունում'),
(55712, 5177, 14, 'Հոգեմետ Դեղորայք'),
(55713, 5178, 14, 'Պացիենտ /Pt %'),
(55714, 5179, 14, 'Պացիենտի գրառումներ'),
(55715, 5180, 14, 'Պացիենտի գրառումներ/Լիազոր․'),
(55716, 5181, 14, 'Պացիենտի գերավճար'),
(55717, 5182, 14, 'Պացիենտի վճարում Պացիենտը վճարել է'),
(55718, 5183, 14, 'Պացիենտի գրանցման պահանջ'),
(55719, 5184, 14, 'Պացիենտի փոխհատուցում'),
(55720, 5185, 14, 'Պացիենտի դուրսգրում'),
(55721, 5186, 14, 'Պացիենտի զեկույց'),
(55722, 5187, 14, 'Պացիենտն ուսանող է կամ թողնել դատարկ'),
(55723, 5188, 14, 'Պցտ—ՔԱՂԱՔ'),
(55724, 5189, 14, 'PT_DOB'),
(55725, 5190, 14, 'ՊԱՑ․—ԷԼ ՓՈՍՏ'),
(55726, 5191, 14, 'ՊԱՑ․—ԱԶԳԱՆՈՒՆ'),
(55727, 5192, 14, 'ՊԱՑ․—ՀԱՅՐԱՆՈՒՆ'),
(55728, 5193, 14, 'ՊԱՑ․—ՄԱՅՐԱՆՈՒՆ'),
(55729, 5194, 14, 'ՊԱՑ․—ՀԵՌԱԽՈՍ—ԲՋՋԱՅԻՆ'),
(55730, 5195, 14, 'ՊԱՑ․—ՀԵՌԱԽՈՍ—ՔԱՂԱՔԱՅԻՆ'),
(55731, 5196, 14, 'ՊԱՑ․— ՓՈՍՏԱՅԻՆ ԿՈԴ'),
(55732, 5198, 14, 'ՊԱՑ․— ՓՈՍՏԱՅԻՆ ԿՈԴ'),
(55733, 5199, 14, 'ՊԱՑ․— ՓՈՂՈՑ'),
(55734, 5201, 14, 'Հանրային/հրապաակային'),
(55735, 5203, 14, 'Առողջապահության նախարարություն (ԱՆ) կամ այլ պետական կառույց/կազմակերպություն'),
(55736, 5204, 14, 'Պուերտոռիկացի'),
(55737, 5205, 14, 'Թոքային'),
(55738, 5206, 14, 'Զարկերակ'),
(55739, 5207, 14, 'Փենջաբերեն'),
(55740, 5208, 14, 'Գնել/գնում'),
(55741, 5209, 14, 'Գնում/վերադարձ'),
(55742, 5210, 14, 'Գնումներ'),
(55743, 5211, 14, 'P{{Նշել վերնագիրը}}'),
(55744, 5212, 14, 'Pāli'),
(55745, 5213, 14, 'յուր․ 3 ժամը մեկ'),
(55746, 5214, 14, 'յուր․ 4 ժամը մեկ'),
(55747, 5215, 14, 'յուր․ 5 ժամը մեկ'),
(55748, 5216, 14, 'յուր․ 6 ժամը մեկ'),
(55749, 5217, 14, 'յուր․ 8 ժամը մեկ'),
(55750, 5218, 14, 'օրը մեկ անգամ'),
(55751, 5219, 14, 'օրումեջ'),
(55752, 5220, 14, 'QOH'),
(55753, 5221, 14, 'QOH-ն ամսական օգտագործումից քիչ է'),
(55754, 5222, 14, 'Քանակ'),
(55755, 5223, 14, 'ՔՆԿ․'),
(55756, 5224, 14, 'Որակ'),
(55757, 5225, 14, 'Որակի չափանիշ (CQM)'),
(55758, 5226, 14, 'Քանակ'),
(55759, 5227, 14, 'NDC Քանակ'),
(55760, 5228, 14, 'Առկա քանակ'),
(55761, 5229, 14, 'ոչ պիտանի համարվողների քանակը'),
(55762, 5231, 14, 'հարցական նշան'),
(55763, 5232, 14, 'HCFA խմբաքանակի մշակման հերթագրում'),
(55764, 5233, 14, 'HCFA խմբաքանակի մշակման և տպագրման հերթագրում'),
(55765, 5234, 14, 'UB-92 խմբաքանակի մշակման հերթագրում'),
(55766, 5235, 14, 'UB-92 խմբաքանակի մշակման և տպագրման հերթագրում'),
(55767, 5236, 14, 'հերթագրված է'),
(55768, 5237, 14, 'Հերթագրված միջոցառումների կառավարում'),
(55769, 5238, 14, 'Հերթագրված է -ի համար'),
(55770, 5240, 14, 'Հերթագրված պնդումների/ներկայացումների կառավարում'),
(55771, 5241, 14, 'Ելք'),
(55772, 5242, 14, 'Թողնել ալկոհոլը Նախկին ալկոհոլամոլ'),
(55773, 5243, 14, 'R'),
(55774, 5245, 14, 'Ռասսա'),
(55775, 5246, 14, 'Ռասսան կամ էթնիկ պատկանելիությունը'),
(55776, 5247, 14, 'Ռասսա/Էթնոս'),
(55777, 5248, 14, 'Ռադիո'),
(55778, 5249, 14, 'Ռադիոկոճակներ'),
(55779, 5251, 14, 'Միջակայք'),
(55780, 5252, 14, 'Ցան'),
(55781, 5253, 14, 'Արժեք'),
(55782, 5254, 14, 'Չափաբաժին'),
(55783, 5255, 14, 'Անավարտ հաշվետվություն'),
(55784, 5256, 14, 'Կրկնակի իդենտիֆիկացիա/նույնականացում'),
(55785, 5257, 14, 'Կրկնակի իդենտիֆիկացիայի/նույնականացման մշակումն ավարտված է'),
(55786, 5258, 14, 'Կրկնակի իդենտիֆիկացիայի/նույնականացման մշակումն իրականացվում  է'),
(55787, 5259, 14, 'Կրկնակի իդենտիֆիկացիայի/նույնականացման ֆայլերը կպահպանվեն'),
(55788, 5260, 14, 'Կրկնակի վնասվա՞ծք է'),
(55789, 5261, 14, 'Վերաբացել'),
(55790, 5262, 14, 'Վերաբացված'),
(55791, 5263, 14, 'Ռեակցիա/փոխազդեցություն/հակազդեցություն'),
(55792, 5264, 14, 'Ռեակցիաներ/փոխազդեցություններ/հակազդեցություններ'),
(55793, 5265, 14, 'Կարդալ'),
(55794, 5267, 14, 'Միայն կարդալ Հիվ․ Պատմությունից'),
(55795, 5268, 14, 'Իրական անվանումը'),
(55796, 5269, 14, 'Իսկապես ջնջել'),
(55797, 5270, 14, 'Պատճառ'),
(55798, 5271, 14, 'Մահվան պատճառը'),
(55799, 5272, 14, 'Մահվան պատճառը'),
(55800, 5274, 14, 'Ուղեգրի պատճառը'),
(55801, 5275, 14, 'Այցի պատճառը'),
(55802, 5276, 14, 'Պատճառ/Ձև'),
(55803, 5277, 14, 'Կտրոն'),
(55804, 5278, 14, 'Վճարման կտրոն/անդորրագիր'),
(55805, 5279, 14, 'Կտրոնը/անդորրագիրը պատրաստ է'),
(55806, 5280, 14, 'Կտրոններ/անդորրագրեր ըստ վճարման տեսակի զեկույցի'),
(55807, 5281, 14, 'Մուտքերի ամփոփագիր'),
(55808, 5282, 14, 'Ստացված է'),
(55809, 5283, 14, 'Ստացված է -ով'),
(55810, 5284, 14, 'Ստացված է ՖԱՔՍ-ով'),
(55811, 5285, 14, 'Ստացված է, վերանայված չէ'),
(55812, 5286, 14, 'Ստացված, չվերանայված'),
(55813, 5287, 14, 'Ստացող'),
(55814, 5288, 14, 'Ստացողի ID'),
(55815, 5289, 14, 'Ստացողի ID (ISA08)'),
(55816, 5290, 14, 'Ստացողի ID որոշիչ (ISA07)'),
(55817, 5291, 14, 'Ստացողի ID-ներ'),
(55818, 5292, 14, 'Վերջին երեք գաղտնաբառերը թույլատրելի չեն'),
(55819, 5293, 14, 'Ստացող'),
(55820, 5294, 14, 'Ստացողների ցանկը դատարկ է'),
(55821, 5295, 14, 'Ստացողի անունը'),
(55822, 5296, 14, 'Տեղեկատվություն ստացողը'),
(55823, 5297, 14, 'Մինչև կարգավիակը ավարտուն լինելը պահանջվում է ստացողի տվյալներ'),
(55824, 5298, 14, 'Երաշխավորություն/Խորհրդատվություն'),
(55825, 5299, 14, 'Խորհրդատվություն հետագա այցերի մասին'),
(55826, 5300, 14, 'Խորհրդատվություն և բուժում'),
(55827, 5301, 14, 'Խորհրդներ և բուժում'),
(55828, 5302, 14, 'Մասնագետի կողմից տրված խորհուրդներ'),
(55829, 5303, 14, 'Գրանցել'),
(55830, 5304, 14, 'Գրանցում արդեն գոյություն ունի'),
(55831, 5310, 14, 'Կատարել գրանցումներ կամ փոփոխություններ կենսական նշանակություն ունեցող ցուցանիշներում'),
(55832, 5311, 14, 'Անձնական/ազգագրական տվյալների գրանցում'),
(55833, 5312, 14, 'Տեղեկության բացահայտում/հրապարակում'),
(55834, 5313, 14, 'Համապատասխանության/պիտանիության մասին գրանցում'),
(55835, 5314, 14, 'Վճարման գրանցում'),
(55836, 5315, 14, 'Գրանցման պահանջի ամսաթիվ'),
(55837, 5316, 14, 'Գրանցել 13 և բարձր տարիքի պացիենտների՝ ծխողի կարգավիակը'),
(55838, 5317, 14, 'Գրանցումներ'),
(55839, 5318, 14, 'գտնվել են գրանցումներ'),
(55840, 5319, 14, 'գտնվել են գրանցումներ'),
(55841, 5320, 14, 'Հանգստացնող դեղորայքի/հակադեպրեսանտների կիրառում'),
(55842, 5321, 14, 'Հանգստացնող դեղորայքի/հակադեպրեսանտներ'),
(55843, 5322, 14, 'Հետանցքային/ուղիղ աղու'),
(55844, 5323, 14, 'Հետանցքային/ուղիղ աղու հետազոտում'),
(55845, 5324, 14, 'Հետանցքային/ուղիղ աղու'),
(55846, 5325, 14, 'Վերաուղղորդում'),
(55847, 5326, 14, 'Կարմրություն'),
(55848, 5327, 14, 'կրճատված է'),
(55849, 5328, 14, 'Հղել'),
(55850, 5329, 14, 'Հղել -ով'),
(55851, 5330, 14, 'Հղման ամսաթիվ'),
(55852, 5331, 14, 'Հղել -ին'),
(55853, 5332, 14, 'Քաղվածքի/տեղեկանքի դասակարգում (ռիսկային մակարդակը)'),
(55854, 5334, 14, 'Տեղեկանքի նպատակը'),
(55855, 5335, 14, 'Տեղեկանք տրամադրող'),
(55856, 5336, 14, 'Տեղեկանք տրամադրողի ազգանուն և ստորագություն'),
(55857, 5337, 14, 'Ուղեգիր'),
(55858, 5338, 14, 'Ուղեգիր -ով'),
(55859, 5339, 14, 'Ուղեգրի կտրոն'),
(55860, 5340, 14, 'Ուղեգրի ամսաթիվ'),
(55861, 5341, 14, 'Ուղեգրի ձև'),
(55862, 5342, 14, 'ՈՒՂԵԳՐԻ  ՁԵՎ'),
(55863, 5343, 14, 'Ուղեգրի ID'),
(55864, 5345, 14, 'Ուղեգրի հիմքը/աղբյուրը'),
(55865, 5346, 14, 'Ուղեգրի հիմքը/աղբյուրը այցի համար'),
(55866, 5347, 14, 'Ուղեգիր -ին'),
(55867, 5348, 14, 'Ուղեգրեր'),
(55868, 5349, 14, 'Ուղեգրերի վերաբերյալ հաշվետվություն'),
(55869, 5350, 14, 'Ուղեգրված է -ի կողմից'),
(55870, 5351, 14, 'Ուղեգրված է -ի կողմից'),
(55871, 5352, 14, 'Ուղեգրված է -ին'),
(55872, 5353, 14, 'Ուղեգրող կողմ'),
(55873, 5354, 14, 'Ուղեգրող կողմի հասցե'),
(55874, 5355, 14, 'Ուղեգրողի ախտորոշումը Ախտորոշումն ուղեգրելիս'),
(55875, 5356, 14, 'Ուղեգրողի ախտորոշումը Ախտորոշումն ուղեգրելիս'),
(55876, 5357, 14, 'Ուղեգրող բժիշկն ու ոլորտը'),
(55877, 5358, 14, 'Ուղեգրող բժիշկ'),
(55878, 5359, 14, 'Վերալրացնել Կրկին լրացրեք'),
(55879, 5360, 14, 'Լրացվում է'),
(55880, 5361, 14, 'Լրացվում է'),
(55881, 5362, 14, 'Նորմալ/բնական ռեֆլեքս'),
(55882, 5363, 14, 'Թարմացնել'),
(55883, 5365, 14, 'Թարմացնել հիշեցումները'),
(55884, 5368, 14, 'Հրապարակման մերժում'),
(55885, 5369, 14, 'reg_re'),
(55886, 5370, 14, 'գրանցել'),
(55887, 5371, 14, 'գրանցել'),
(55888, 5372, 14, 'Գրանցված'),
(55889, 5373, 14, 'Գրանցված'),
(55890, 5374, 14, 'Գրանցված մոդուլներ'),
(55891, 5375, 14, 'Գրանցման ամսաթիվ'),
(55892, 5376, 14, 'Գրանցման ձև'),
(55893, 5377, 14, 'Վերականգնում'),
(55894, 5379, 14, 'Մերժված'),
(55895, 5380, 14, 'ռեցիդիվ ներուժը'),
(55896, 5381, 14, 'կապված -ի հետ -ով պայմանավորված'),
(55897, 5382, 14, 'կապված/պայմանավորված/առնչվող'),
(55898, 5383, 14, 'Առնչվող հարց'),
(55899, 5384, 14, 'Առնչվող Պացիենտի գրառումներ'),
(55900, 5385, 14, 'Հարազատ(ներ) / երեխաներ'),
(55901, 5386, 14, 'Հարազատներ'),
(55902, 5387, 14, 'Բարեկամական կապ'),
(55903, 5388, 14, 'Սույն հաստատության կազմակերպական կառուցվածքը'),
(55904, 5389, 14, 'Հարազատներ'),
(55905, 5391, 14, 'Ուղեկցվող/գենետիկ քաղցկեղային հիվանդություն'),
(55906, 5392, 14, 'Ուղեկցվող/գենետիկ շաքարային դիաբետ'),
(55907, 5393, 14, 'Ուղեկցվող/գենետիկ էպիլեպսիա'),
(55908, 5394, 14, 'Ուղեկցվող/գենետիկ սրտային հիվանդություն'),
(55909, 5395, 14, 'Ուղեկցվող/գենետիկ մտավոր խնդիրներ'),
(55910, 5396, 14, 'Ուղեկցվող/գենետիկ կաթված/ինսուլտ'),
(55911, 5397, 14, 'ինքնասպանություն'),
(55912, 5398, 14, 'Ուղեկցվող/գենետիկ պալարախտ/տուբերկուլյոզ'),
(55913, 5399, 14, 'Relay Health լիազորությունը/հասանելիությունը բացակայում է սույն օգտվողի հաշվից'),
(55914, 5400, 14, 'Relay Health ID'),
(55915, 5402, 14, 'Թողարկման ամսաթիվ'),
(55916, 5403, 14, 'Կրոն'),
(55917, 5406, 14, 'Կրկին մուտք գոծեք'),
(55918, 5407, 14, 'Հիշեցում');
INSERT INTO `lang_definitions` VALUES
(55919, 5408, 14, 'Հիշել ընտրված հաստատությունը/բաղադրիչը'),
(55920, 5409, 14, 'Հիշեցում'),
(55921, 5410, 14, 'Հիշեցումների միջակայք'),
(55922, 5411, 14, 'Հիշեցումը դեռևս ուղարկված չէ'),
(55923, 5412, 14, 'Հիշեցումն  ուղարկված է'),
(55924, 5413, 14, 'Հիշեցումներ'),
(55925, 5414, 14, 'Տեղափոխել դեպի'),
(55926, 5416, 14, 'Ջնջել'),
(55927, 5419, 14, 'Ջնջել խումբը'),
(55928, 5420, 14, 'Ջնջել խմբի ձևը'),
(55929, 5421, 14, 'Հեռացնում է պատվաստումների աջակցությունը'),
(55930, 5422, 14, 'Հեռացնում է  phpMyAdmin աջակցությունը'),
(55931, 5423, 14, 'Հեռացնում է դեղատոմսերի աջակցությունը'),
(55932, 5426, 14, 'Երիկամային հիվանդություն'),
(55933, 5427, 14, 'Վերանվանել'),
(55934, 5428, 14, 'Վերանվանել խումբը'),
(55935, 5429, 14, 'Արտածում/մեկնաբանում'),
(55936, 5430, 14, 'Մեկնաբանող բժիշկ'),
(55937, 5431, 14, 'Մեկնաբանող բժշկի հերթական համարը'),
(55938, 5432, 14, 'Վերանշանակել/վերադասավորել'),
(55939, 5433, 14, 'Վերանշանակել -ում'),
(55940, 5436, 14, 'Կրկ․'),
(55941, 5437, 14, 'Կրկնել նոր գաղտնաբառը'),
(55942, 5438, 14, 'Կրկնվող իրադարձություն'),
(55943, 5439, 14, 'Կրկնվող ինֆորմ։'),
(55944, 5440, 14, 'Կրկնվում է'),
(55945, 5441, 14, 'ՓՈԽԱՐԻՆԵԼ'),
(55946, 5442, 14, 'Փոխարինել ողջ կոդերը'),
(55947, 5443, 14, 'Փոխարինված է'),
(55948, 5444, 14, 'Պատասխանի ամսաթիվ'),
(55949, 5445, 14, '-ից պատասխան'),
(55950, 5446, 14, 'Հաշվետվություն/զեկույց'),
(55951, 5447, 14, 'Զեկույց - կլինիկական'),
(55952, 5449, 14, '-ի զեկույց'),
(55953, 5451, 14, 'Զեկույցի ավարտը   (Բուժումից հրաժարման ամսաթիվ)'),
(55954, 5452, 14, 'Զեկույցն ուղարկվել է պացիենտին'),
(55955, 5453, 14, 'Զեկուցել անամնեզը/արդյունքները'),
(55956, 5454, 14, 'Զեկուցել  արդյունքները'),
(55957, 5455, 14, 'Զեկուցել  արդյունքները/անամնեզը'),
(55958, 5456, 14, 'Զեկույցի սկիզբ/մեկնարկ (բուժման ենթադրյալ  ամսաթիվ)'),
(55959, 5457, 14, 'Զեկույցի կարգավիճակը'),
(55960, 5458, 14, 'Ընդամենը զեկույցներ'),
(55961, 5459, 14, 'Զեկույց/ձև'),
(55962, 5461, 14, 'Զեկուցված'),
(55963, 5462, 14, 'Զեկուցման ամսաթիվ'),
(55964, 5463, 14, 'Զեկույցներ'),
(55965, 5465, 14, 'Պահանջի նկարագրություն'),
(55966, 5466, 14, 'Պահանջի ID բացակայում է'),
(55967, 5467, 14, 'Հարցումը մերժվել է․ պահանջի մշակումն ընթացքի մեջ է'),
(55968, 5469, 14, 'Պահանջի/հարցման կարգավիճակը'),
(55969, 5470, 14, 'Պահանջի/հարցման տեսակը'),
(55970, 5471, 14, 'Պահանջի/հարցման տեսակը չի իրականացվել'),
(55971, 5472, 14, 'Պահնջված է-ի կողմից'),
(55972, 5473, 14, 'Պահնաջի /հարցման ամսաթիվ'),
(55973, 5474, 14, 'Պահանջված ծառայություն'),
(55974, 5475, 14, 'Պահանջվում է ուժեղ/ապահով գաղտնաբառ'),
(55975, 5476, 14, 'Պահանջվում է եզակի գաղտնաբառ'),
(55976, 5477, 14, 'Պարտադիր է'),
(55977, 5478, 14, 'Պարտադիր հավելավճար'),
(55978, 5479, 14, 'Պարտադիր դաշտ է դատարկ․ բեռնման համար ընտրել EDI-271'),
(55979, 5480, 14, 'Պարտադիր դաշտ է դատարկ․ մուտքագրել անունը'),
(55980, 5481, 14, 'Պարտադիր դաշտ է դատարկ․ մուտքագրել ազգանունը'),
(55981, 5482, 14, 'Պարտադիր դաշտ է դատարկ․ մուտքագրել օգտվողի անունը'),
(55982, 5483, 14, 'Պարտադիր դաշտեր'),
(55983, 5484, 14, 'Պահանջներ'),
(55984, 5485, 14, 'ԶԲԱՂՎԱԾ Է'),
(55985, 5486, 14, 'Զբաղված է'),
(55986, 5487, 14, 'Զբաղեցրած է  օգտագործման նպատակով՝  նախատեսվող արձակուրդ սահմանելու համար'),
(55987, 5488, 14, 'Զբաղեցրած է՝  մասնագետի մոտ այցերի գրանցումների անհասանելություն սահմանելու/որոշելու  համար'),
(55988, 5489, 14, 'Զբաղված է՝ որոշելու, թե երբ  միջոցառումը չի կատարվում ըստ նախատեսվածի'),
(55989, 5490, 14, 'Զբաղեցրած է՝  այդուհետ մասնագետի մոտ այցերի գրանցումների հասանելություն սահմանելու/որոշելու  համար'),
(55990, 5491, 14, 'Վերակայել/հետադարձել'),
(55991, 5492, 14, 'Զրոյացնել/Վերակայել/հետադարձել Offsite պորտալի հասանելիության պարամետրերը'),
(55992, 5493, 14, 'Զրոյացնել/Վերակայել/հետադարձել Onsite պորտալի հասանելիության պարամետրերը'),
(55993, 5495, 14, 'Resn'),
(55994, 5496, 14, 'Լուծված է'),
(55995, 5497, 14, 'Շնչառություն'),
(55996, 5499, 14, 'Շնչական/շնչառական համակարգ'),
(55997, 5504, 14, 'Արդյունք'),
(55998, 5505, 14, 'Արդյունքի անվանում'),
(55999, 5506, 14, 'Արդյունքի կարգավիճակ'),
(56000, 5507, 14, 'Արդյունքի կարգավիճակը կամ նորմայից շեղումը բացակայում է'),
(56001, 5509, 14, 'Արդյունքներ'),
(56002, 5510, 14, 'Արդյունքներ և'),
(56003, 5511, 14, 'Գտնվել են հետևյալ արդյունքները'),
(56004, 5512, 14, 'Արդյունքների խումբ'),
(56005, 5513, 14, 'Միայն արդյունքները'),
(56006, 5515, 14, 'Արդյունքների էջադրում'),
(56007, 5516, 14, 'Արդյունքներ/մանրամասներ'),
(56008, 5517, 14, 'Աչքի ցանցաթաղանթի զննություն'),
(56009, 5518, 14, 'Իրավունքի չեղարկում'),
(56010, 5519, 14, 'Հետ վերադարձ'),
(56011, 5520, 14, 'Ձեր կատարած վճարման վերոնշյալ մասի վերադարձ'),
(56012, 5521, 14, 'Վերադառնալ օրացույցին'),
(56013, 5522, 14, 'Վերադառնալ զեկույցի արդյունքներին'),
(56014, 5527, 14, 'Վերադարձնել արժեք/նշանակություն'),
(56015, 5528, 14, 'Վերադարձնել այցը'),
(56016, 5529, 14, 'Նորից գործարկել/կատարել'),
(56017, 5530, 14, 'Նախկին երեք գաղտնաբառերի կիրառումն արգելվում է'),
(56018, 5531, 14, 'Ստուգում/Վերանայում'),
(56019, 5532, 14, 'Ստուգել/Վերանայել և հաստատել'),
(56020, 5534, 14, 'PMH ստուգում/վերանայում։'),
(56021, 5535, 14, 'Համակարգերի ստուգում/վերանայում։'),
(56022, 5536, 14, 'Համակարգերի ստուգման վերանայում'),
(56023, 5537, 14, 'Ստուգված/Վերնայված է'),
(56024, 5538, 14, 'Վերանայում'),
(56025, 5539, 14, 'Ռևմատոիդ արթրիտ'),
(56026, 5540, 14, 'Ռևմատոիդ արթրիտ'),
(56027, 5541, 14, 'Աջ'),
(56028, 5542, 14, 'Աջ ականջ'),
(56029, 5543, 14, 'Աջ ականջ'),
(56030, 5544, 14, 'Աջ լուսանցք (մմ)'),
(56031, 5545, 14, 'Աջ։'),
(56032, 5546, 14, 'Աղմուկ ականջներում'),
(56033, 5547, 14, 'Աղմուկ ականջներում'),
(56034, 5549, 14, 'Ռիսկի գործոն'),
(56035, 5550, 14, 'Ռիսկային մակարդակ'),
(56036, 5551, 14, 'Աջ ստորին վերջույթ։'),
(56037, 5552, 14, 'ROM'),
(56038, 5553, 14, 'Ռումիներեն'),
(56039, 5554, 14, 'Ռումինացի'),
(56040, 5560, 14, 'Հերթապահության ցուցակ'),
(56041, 5561, 14, 'Ուղեգիծ ընթացք'),
(56042, 5562, 14, 'Ադմինիստրացիայի ուղեգիծը, եթե այդպիսին կա'),
(56043, 5563, 14, 'Ներկայացված է'),
(56044, 5564, 14, 'Տողեր'),
(56045, 5568, 14, 'Կանոն'),
(56046, 5569, 14, 'Ավելացնել կանոն'),
(56047, 5570, 14, 'Կանոնի մանրամասներ'),
(56048, 5572, 14, 'Խմբագրել կանոնը'),
(56049, 5575, 14, 'Սահմանված կանոններ'),
(56050, 5578, 14, 'Կանոններ'),
(56051, 5580, 14, 'Կանոնների կոնֆիգուրացիա'),
(56052, 5581, 14, 'Կատարվող/իրականացվող հրաման '),
(56053, 5582, 14, 'Պատռվածք'),
(56054, 5583, 14, 'Ռուսերեն'),
(56055, 5586, 14, 'Rx ստորին լուսանցք (px)'),
(56056, 5587, 14, 'Rx թույլատրում է DEA #'),
(56057, 5588, 14, 'Rx թույլատրում է NPI'),
(56058, 5589, 14, 'Rx թույլատրում է պետ․ լից. #'),
(56059, 5590, 14, 'Rx ձախ լուսանցք (px)'),
(56060, 5591, 14, 'Rx թղթի չափ'),
(56061, 5592, 14, 'Rx աջ լուսանցք (px)'),
(56062, 5593, 14, 'Rx ցուցադրում է DEA #'),
(56063, 5594, 14, 'Rx ցուցադրում է NPI'),
(56064, 5595, 14, 'Rx ցուցադրում է պետ․ լից. #'),
(56065, 5596, 14, 'Rx վերին լուսանցք (px)'),
(56066, 5597, 14, 'RXCUI Դեղորայք'),
(56067, 5598, 14, 'RxNorm'),
(56068, 5599, 14, 'RxNorm տվյալների բազա'),
(56069, 5600, 14, 'S'),
(56070, 5601, 14, 'S.S.'),
(56071, 5602, 14, 'S3:'),
(56072, 5603, 14, 'S4:'),
(56073, 5604, 14, 'SA  *  * Լիցենզիան կարդալու համար կարդալ փաստաթղթերը/license.txt կամ այցելել  * http://www.gnu.org/copyleft/gpl.html  *  */  //========================================================================= // '),
(56074, 5605, 14, 'ապրանքաշրջանառություն'),
(56075, 5606, 14, 'ապրանքաշրջանառություն'),
(56076, 5607, 14, 'ապրանքաշրջանառություն ըստ կետերի'),
(56077, 5608, 14, 'Վաառք/ապրանքաշրջանառություն ըստ ապրանքների հաշվետվության'),
(56078, 5609, 14, 'Թուք'),
(56079, 5610, 14, 'Նույն օրը'),
(56080, 5611, 14, 'Սամոերեն'),
(56081, 5612, 14, 'Օրինակ'),
(56082, 5613, 14, 'Տույժի տեսակը'),
(56083, 5614, 14, 'Սանգո'),
(56084, 5615, 14, 'Սանսկրիտ (Saṁskṛta)'),
(56085, 5617, 14, 'Շբթ․'),
(56086, 5618, 14, 'Շբթ &amp; Կիր'),
(56087, 5619, 14, 'Շաբաթ'),
(56088, 5620, 14, 'Պահպանել'),
(56089, 5621, 14, 'ՊԱՀՊԱՆԵԼ'),
(56090, 5622, 14, 'Պահպանել և փակել'),
(56091, 5623, 14, 'Պահպանել և հեռացնել պահանջը/հարցումը'),
(56092, 5624, 14, 'Պահպանել և բաշխել'),
(56093, 5625, 14, 'Պահպանել եւ փոխանցել'),
(56094, 5626, 14, 'Պահպանել որպես նոր'),
(56095, 5627, 14, 'Պահպանել որպես նոր գրանցում'),
(56096, 5628, 14, 'Պահպանել վկայականի կարգավորումները'),
(56097, 5629, 14, 'Պահպանել փոփոխությունները'),
(56098, 5630, 14, 'Պահպանել ձևը'),
(56099, 5631, 14, 'Պահպանել պատվաստումը'),
(56100, 5632, 14, 'Պահպանել նոր դաշտը'),
(56101, 5633, 14, 'Պահպանել խումբը'),
(56102, 5634, 14, 'Պահպանել ցանկը'),
(56103, 5635, 14, 'Պահպանել նոր բլանկը'),
(56104, 5637, 14, 'Պահպանել պացիենտի անձնական/ազգագրական տվյալները'),
(56105, 5638, 14, 'ID քարտը  հաջողությամբ պհպանվեց'),
(56106, 5639, 14, 'Պահպանել գործարքը'),
(56107, 5640, 14, 'Հաջողությամբ պահպանվեց'),
(56108, 5641, 14, 'Սքանավորված է'),
(56109, 5642, 14, 'Այցելության գրառումների սքան'),
(56110, 5643, 14, 'Սքաների ուղեցույց'),
(56111, 5644, 14, 'Սքաներ'),
(56112, 5645, 14, 'Գրաֆիկ'),
(56113, 5646, 14, 'Պլանավորված բուժծառայություններ'),
(56114, 5647, 14, 'ԳՐԱՌՈՒՄ ԴՊՐՈՑԻ ՄԱՍԻՆ'),
(56115, 5648, 14, 'Սկոլիոզ'),
(56116, 5649, 14, 'Շոտլանդական-Կելտական-կելտերեն'),
(56117, 5650, 14, 'Էկրանավորում / թեստավորում'),
(56118, 5651, 14, 'SE'),
(56119, 5652, 14, 'SE Հասցե'),
(56120, 5653, 14, 'SE Քաղաք'),
(56121, 5654, 14, 'SE Երկիր'),
(56122, 5655, 14, 'SE Բնակավայր'),
(56123, 5656, 14, 'SE Փոստային ինդեքս'),
(56124, 5657, 14, 'SE Նահանգ/մարզ'),
(56125, 5658, 14, 'SE Zip Code'),
(56126, 5659, 14, 'Որոնում/որոնել'),
(56127, 5661, 14, 'որոնել'),
(56128, 5662, 14, 'կրկին որոնել'),
(56129, 5663, 14, 'Փնտրել բոլոր սյուները'),
(56130, 5664, 14, 'Որոնում ըստ։'),
(56131, 5665, 14, '-ի որոնում'),
(56132, 5666, 14, '-ի որոնում։'),
(56133, 5667, 14, 'Փնտրել -ում'),
(56134, 5668, 14, 'Փնտրել -ում'),
(56135, 5669, 14, 'Պացիենտի որոնում կամ ավելացում'),
(56136, 5670, 14, 'Վչարման որոնում Փնտրել վճարումը'),
(56137, 5671, 14, 'Որոնման արդյունքներ'),
(56138, 5672, 14, 'Որոնման արդյունքներ։'),
(56139, 5673, 14, 'Որոնել ընտրվածները որոնումն ընտրված է'),
(56140, 5674, 14, 'Որոնման տողը չի համապատասխանում տվյալների բազայի ցանկին'),
(56141, 5675, 14, 'Որոնման տողը պետք է ունենա առնվազն 3 նիշ'),
(56142, 5676, 14, 'Տեքստային որոնում'),
(56143, 5677, 14, 'Իադարջության որոնում'),
(56144, 5678, 14, 'Փնտրել/ավելացնել'),
(56145, 5679, 14, 'Փնտրել/ավելացնել ապահովագրող'),
(56146, 5680, 14, 'Այցերի որոնում'),
(56147, 5681, 14, 'Փնտրվում է․․․'),
(56148, 5682, 14, 'Ամարագոտու/անվտանգության գոտու կիրառում'),
(56149, 5683, 14, 'Ամարագոտու/անվտանգության գոտու կիրառում'),
(56150, 5684, 14, 'Երկրորդ'),
(56151, 5687, 14, 'Կրկնակի/երկրորդային'),
(56152, 5688, 14, 'Կրկնակի/երկրորդային ապահովագրություն'),
(56153, 5689, 14, 'Կրկնակի/երկրորդային ապահովագրության ամսաթիվ'),
(56154, 5690, 14, 'Կրկնակի/երկրորդային ապահովագրող'),
(56155, 5691, 14, 'Կրկնակի/երկրորդային բուժօգնության տեսակը'),
(56156, 5693, 14, 'Բաժնի  ID'),
(56157, 5694, 14, 'Բաժնի  ID-ն և անվանումը չեն կարող դատարկ լինել'),
(56158, 5695, 14, 'Բաժնի անվանում'),
(56159, 5696, 14, 'Բաժինը հաջողությամբ պահպանվել է'),
(56160, 5698, 14, 'Անվատնգություն'),
(56161, 5699, 14, 'Տեսնել ամբողջը'),
(56162, 5700, 14, 'Տեսնել լիազորագրերը'),
(56163, 5701, 14, 'Տեսնել աճի սանդղակը'),
(56164, 5702, 14, 'Տեսնել վերջին պահանջներից ստացված հաղորդագրությունները'),
(56165, 5704, 14, 'Տեսնել սկսած'),
(56166, 5705, 14, 'Սեգմենտի անվանում'),
(56167, 5707, 14, 'Հանկարծակի նոպա'),
(56168, 5708, 14, 'Ընտր․'),
(56169, 5709, 14, 'Ընտրել'),
(56170, 5710, 14, 'Ընտրել'),
(56171, 5711, 14, 'Ընտրել բաղադրիչ/կոմպոնենտ'),
(56172, 5712, 14, 'Ընտրել համատքեստը'),
(56173, 5713, 14, 'Ընտրել տողերի տոկոսը կամ ամսաթիվը'),
(56174, 5714, 14, 'Ընտրել ժամանակահատված'),
(56175, 5715, 14, 'Ընտրել օգտվողին'),
(56176, 5716, 14, 'Ընտրել ամբողջը'),
(56177, 5717, 14, 'Ընտրել փոփոխությունների ամսաթիվը'),
(56178, 5718, 14, 'Ընտրել տպագրության ենթակա փոփոխությունները'),
(56180, 5720, 14, 'Ընտրել կատեգորիան'),
(56181, 5721, 14, 'Ընտրել հաղորդակցության նախընտրելի տարբերակները'),
(56182, 5722, 14, 'Ջնջելու համար ընտրեք համապատասխան նշավանդակները'),
(56183, 5723, 14, 'Ընտրել ջնջելու/հեռացնելու չափորոիչները'),
(56184, 5724, 14, 'Ընտրել CSV աղյուսակը'),
(56185, 5725, 14, 'Ընտրել դեինդենտիֆիկացիայի համար պահանջվող ամսաթիվը'),
(56186, 5726, 14, 'Ընտրել դեինդենտիֆիկացիայի բազայում ներառվող ամսաթիվը'),
(56187, 5727, 14, 'Ընտրել ամսաթիվը'),
(56188, 5728, 14, 'Ընտրել անհրաժեշտ խումբը'),
(56189, 5729, 14, 'Ընտրել ախտորոշումը'),
(56190, 5730, 14, 'Ընտրել ախտորոշումն ըստ դեինդենտիֆիկացիայի պահանջի'),
(56191, 5731, 14, 'Ընտրել դեղամիջոցը'),
(56192, 5732, 14, 'Ընտրել դեղորայքը'),
(56193, 5733, 14, 'Ընտրել դեղորայքն ըստ դեինդենտիֆիկացիայի պահանջի'),
(56194, 5734, 14, 'Ընտրել  EDI-271 ֆայլը'),
(56195, 5735, 14, 'Ընտրել այցը'),
(56196, 5736, 14, 'Ընտրել դաշտը'),
(56197, 5737, 14, 'Ընտրել դաշտերը'),
(56198, 5738, 14, 'Ընտրել տպագրության համար'),
(56199, 5739, 14, 'Ընտրել պատվաստումները'),
(56200, 5740, 14, 'Ընտրել պատվաստումներն ըստ դեինդենտիֆիկացիայի պահանջի'),
(56201, 5741, 14, 'Ընտրել ապահովագրությունն ըստ տպագրության/տեսակավորման'),
(56202, 5742, 14, 'Ընտրել խնդիրը'),
(56203, 5743, 14, 'Ընտրել կետերը'),
(56204, 5744, 14, 'Ընտրել լեզուն'),
(56205, 5745, 14, 'Ընտրել մեկը'),
(56206, 5746, 14, 'Ընտրել մեկ և ավել ախտորոշման կոդեր՝ բուժծառայությունը հաստատելու համար'),
(56207, 5747, 14, 'Ընտրել մեկ և ավել դաշտեր բեռնման համար'),
(56208, 5748, 14, 'Ընտրել արտադրանքը/ելքերը'),
(56209, 5750, 14, 'Ընտրել ըստ պահանջի'),
(56210, 5752, 14, 'Ընտրել սկզբնաղբյուրը'),
(56211, 5753, 14, 'Ընտրել նմուշը'),
(56212, 5754, 14, 'Ընտրել արտածման համար անհրաժեշտ կոնֆիգուրացիոն տարրերը'),
(56213, 5755, 14, 'Ընտրեք խնդիրը, որը հիմնականում պատասխանատու է այս օրվա ցանկացած բաց թողնված իրադարձության համար'),
(56214, 5757, 14, 'Ընտրել ուղին'),
(56215, 5759, 14, 'Ընտրել օգտվողին'),
(56216, 5760, 14, 'Բացվող ցանկից ընտրել օգտվողներին'),
(56217, 5761, 14, 'Ընտրել լեզուն, եթե մուտքի համար թույլատրվում է այլ լեզու (սա վերաբերում է միայն այն դեպքին, երբ ԲՈԼՈՐ ԼԵԶՈւՆԵՐԸ ԹՈւՅԼԱՏՐՎԱԾ ԵՆ ֆունկցիան/կաճակն անջատված է)'),
(56218, 5762, 14, 'Սեղմել ԱՅՈ խումբը ջնջելու/հեռացնելու համար'),
(56219, 5765, 14, 'Ընտրված/Ընտրված է'),
(56220, 5766, 14, 'Ընտրված այց'),
(56221, 5767, 14, 'Սա ընտրելու դեպքում կստեղծվիհաղորդագրություն, որը յուրաքանչյուր պացիենտի համար կպահանջի անհատական մշակում (սա աշխատանքային խումբ չէ)'),
(56222, 5768, 14, 'Ինքնուրույն'),
(56223, 5769, 14, 'Ինքնուրույն վճարել'),
(56224, 5771, 14, 'Ուղարկել'),
(56225, 5772, 14, 'Ուղարկել օրացուցային հիշեցում'),
(56226, 5773, 14, 'Ուղարկել հիշեցում'),
(56227, 5774, 14, 'Ուղարկվում է'),
(56228, 5775, 14, 'Ուղարկել հաղորդագրություն'),
(56229, 5776, 14, 'Ուղարկել հիշեցումների խմբաքանակ'),
(56230, 5777, 14, 'Ըստ յուրաքանչյուր պացիենտի նախապատվության ուղարկել  կանխարգելիչ/հետագա խնամքի հիշեցումները'),
(56231, 5778, 14, 'Ուղարկել ամփոփագրերն ուղեգրերի հետ'),
(56232, 5779, 14, 'Ուղարկել այս ֆայլը'),
(56233, 5780, 14, 'Ուղարկել սույն հաղորդագրությունը'),
(56234, 5781, 14, 'Ուղարկել -ին'),
(56235, 5784, 14, 'Ուղարկել բոլորին'),
(56236, 5786, 14, 'Ուղարկել պորտալ'),
(56237, 5787, 14, 'Ուղարկել պորտալ'),
(56238, 5788, 14, 'Ուղարկող'),
(56239, 5789, 14, 'Ուղարկողի ID'),
(56240, 5790, 14, 'Ուղարկողի ID (ISA06)'),
(56241, 5791, 14, 'Ուղարկողի ID որոշիչ (ISA05)'),
(56242, 5792, 14, 'Ուղարկողի ID-ներ'),
(56243, 5793, 14, 'Ուղարկել -ին'),
(56244, 5794, 14, 'Զագայունություն'),
(56245, 5795, 14, 'Զագայունություն'),
(56246, 5796, 14, 'Զգայունության թեստը նորմալ է'),
(56247, 5797, 14, 'Ուղարկված է'),
(56248, 5798, 14, 'Ուղարկված - Հաստատված'),
(56249, 5799, 14, 'Ուղարկված է  -ով/կողմից, Բոլորի համար դատարկ թողնել'),
(56250, 5800, 14, 'Ուղարկված է  -ով/կողմից։'),
(56251, 5801, 14, 'Ուղարկման ամսաթիվ'),
(56252, 5802, 14, 'Ուղարկվածներ'),
(56253, 5803, 14, 'Ուղարկե՞լ բժշկական գրանցումները'),
(56254, 5804, 14, 'Հաջողությամբ ուղարկվել է'),
(56255, 5807, 14, 'Ուղարկված է տպագրության'),
(56256, 5808, 14, 'Ուղարկված է  -ին, Բոլորի համար դատարկ թողնել'),
(56257, 5809, 14, 'Ուղարկված է  -ին'),
(56258, 5810, 14, 'Ուղարկվել է, սակայն ստացումը դեռ չի հաստատվել'),
(56259, 5811, 14, 'Ուղարկված, բայց ստացված չէ'),
(56260, 5812, 14, 'Սեպտ․ Առնձ․'),
(56261, 5813, 14, 'Առանձին'),
(56262, 5814, 14, 'Սեպտեմբեր'),
(56263, 5815, 14, 'Հերթ․'),
(56264, 5816, 14, 'Հերթականություն'),
(56265, 5817, 14, 'Սերբերեն'),
(56266, 5819, 14, 'Հնարավոր է սերվերն անջատված է'),
(56267, 5820, 14, 'Սերվերի հաղորդագրություն'),
(56268, 5821, 14, 'Ծառայություն'),
(56269, 5822, 14, 'Ծառայության կատեգորիա'),
(56270, 5823, 14, 'Ծառայության կոդ'),
(56271, 5825, 14, 'Ծառայությունների կոդեր'),
(56272, 5826, 14, 'Ծառայության ամսաթիվ'),
(56273, 5827, 14, 'Ծառայության ամսաթիվ։'),
(56274, 5829, 14, 'Ծառայության մատուցման վայրը'),
(56275, 5830, 14, 'Ծառայության անվանումը'),
(56276, 5831, 14, 'Մասնագետի կողմից մատուցված ծառայությունը'),
(56277, 5832, 14, 'Ծառայությունների զեկույց'),
(56278, 5834, 14, 'Ծառայություններ'),
(56279, 5835, 14, 'Ծառայություններ ըստ կատեգորիաների'),
(56280, 5836, 14, 'Մատուցված ծառայություններ'),
(56281, 5837, 14, 'Մատուցված ծառայություններ'),
(56282, 5838, 14, 'Ծառայություններ / Ապրանքներ'),
(56283, 5839, 14, 'Սեսսիայի տեսակը'),
(56284, 5840, 14, 'Սահմանել/Տեղադրել'),
(56285, 5842, 14, 'Սահմանել որպես ավարտված'),
(56286, 5844, 14, 'Սահմանել Պացիենտի հիշեցումների մշակման առաջնայնություն  (լիարժեք կլինիկական ռեժիմով)'),
(56287, 5846, 14, 'Սահմանել -ում'),
(56288, 5847, 14, 'Սահմանել որպես կանխադրված'),
(56289, 5848, 14, 'Տվյալների բազայում տեղադրել տարբերակի հերթական համարը'),
(56290, 5849, 14, 'Կարգավորումներ'),
(56291, 5851, 14, 'Ծանր միգրեն'),
(56292, 5853, 14, 'Ցավի ուժգնության աստիճան'),
(56293, 5854, 14, 'Ցավի ուժգնության աստիճան։'),
(56294, 5855, 14, 'Սեռ'),
(56295, 5856, 14, 'Սեռական ճանապարհով փոխանցվող հիվանդություն'),
(56296, 5857, 14, 'SFTP'),
(56297, 5858, 14, 'Sha-1 Հեշ'),
(56298, 5859, 14, 'Համատեղ կիրառում Բաժնեկցել'),
(56299, 5860, 14, 'Shell հրաման՝ սերվերից տպելու համար'),
(56300, 5863, 14, 'Հակիրճ նկարագրություն'),
(56301, 5864, 14, 'Հևոց Շնչարգելություն'),
(56302, 5865, 14, 'Հևոց Շնչարգելություն'),
(56303, 5866, 14, 'Հևոց 2 Շնչարգելություն 2'),
(56304, 5867, 14, 'Կրճատ գրանցում'),
(56305, 5868, 14, 'Կրճատ գրանցում որպես'),
(56306, 5869, 14, 'Պետք է ակտիվացնել'),
(56307, 5870, 14, 'Պետք է նման լինի nnnnn-nnnn-nn'),
(56308, 5871, 14, 'Պետք է լինի 2 տառ'),
(56309, 5872, 14, 'Պետք է պարունակի 10 թիվ'),
(56310, 5873, 14, 'Պետք է պարունակի միայն 10 թիվ'),
(56311, 5874, 14, 'Ուս'),
(56312, 5875, 14, 'Ուս+անրակ'),
(56313, 5876, 14, 'Ուսերի խնդիր'),
(56314, 5877, 14, 'Ցույց տալ'),
(56315, 5878, 14, 'Ցույց տալ /Ցուցադրել ակտիվներին'),
(56316, 5880, 14, 'Ցույց տալ/Ցուցադրել ամբողջը'),
(56317, 5881, 14, 'Ցույց տալ /Ցուցադրել բոլոր միջամտությունները'),
(56318, 5883, 14, 'Ցույց տալ/ Ցուցադրել բոլոր գործարքները'),
(56319, 5884, 14, 'Ցույց տալ զբաղված լինելը'),
(56320, 5885, 14, 'Ցույց տալ միայն թույլատրվածները'),
(56321, 5886, 14, 'Ցույց տալ հասանելի տարրերը'),
(56322, 5889, 14, 'Ցույց տալ մանրամասները'),
(56323, 5890, 14, 'Ցույց տալ միայն սխալնե՞րը'),
(56324, 5891, 14, 'Ցույց տալ  գրաֆիկը'),
(56325, 5893, 14, 'Քանի՞ իրադարձություն ցուցադրել ադմինի էջում'),
(56326, 5894, 14, 'Ցույց տալ ոչ ակտիվները/պասսիվները'),
(56327, 5896, 14, 'Ցույց տալ ցանկը'),
(56328, 5897, 14, 'Ցույց տալ միայն չափումայինները'),
(56329, 5898, 14, 'Ցույց տալ գրառումները'),
(56330, 5900, 14, 'Ցույց տալ միայն չբացակայող միջամտությունները'),
(56331, 5901, 14, 'Ցույց տալ պացիենտի մասին գրառումները'),
(56332, 5905, 14, 'Ցույց տալ հիշեցումները'),
(56333, 5906, 14, 'Ցույց տալ զեկույցը/հաշվետվությունը'),
(56334, 5907, 14, 'Ցուցադրե՞լ որոնման/հաստատման հղումները վանդակում'),
(56335, 5913, 14, 'Ցույց տալ միայն չվճարվածները'),
(56336, 5914, 14, 'Ցույց տալ միայն US'),
(56337, 5915, 14, 'Ցույց է տալիս / Ցուցադրում է'),
(56338, 5916, 14, 'Ցույց է տալիս / Ցուցադրում է արդյունքները'),
(56339, 5918, 14, 'Հարազատների պատմություն'),
(56340, 5920, 14, 'Հարազատներ քույր/եղբայր'),
(56341, 5921, 14, 'Մանգաղանման բջիջներ'),
(56342, 5922, 14, 'Sig'),
(56343, 5923, 14, 'Սիգմոիդ/Սիգմայաձև / Կոլոնոսկոպիա'),
(56344, 5924, 14, 'Ստորագրել/հաստատել'),
(56345, 5925, 14, 'Գրանցել/Ստորագրել/հաստատել  լաբորատոր հետազոտությունների արդյունքները (գրել, միայն ավելացնել ըստ ցանկության)'),
(56346, 5926, 14, 'Գրանցել/Ստորագրել/հաստատել  արդյունքները'),
(56347, 5927, 14, 'Ստորագրություն'),
(56348, 5928, 14, 'Ստորագրություն ֆայլի վրա'),
(56349, 5929, 14, 'Ստորագրություն։'),
(56350, 5930, 14, 'Ստորագրված Rx'),
(56351, 5932, 14, 'Զգալի չափերի ուռուցք'),
(56352, 5933, 14, 'Պարզեցված'),
(56353, 5934, 14, 'Պարզեցված հավելավճար'),
(56354, 5935, 14, 'Պարզեցված/կրճատ անձնական տվյալներ'),
(56355, 5936, 14, 'Պարզեցված/կրճատ դեղատոմսեր'),
(56356, 5937, 14, 'ի վեր/ սկսած'),
(56357, 5938, 14, 'Հարգանքներով'),
(56358, 5940, 14, 'Ամուրի/չամուսնացած Մեկ'),
(56359, 5941, 14, 'Մեկական  ընտրության ցանկ'),
(56360, 5942, 14, 'Մեկական  ընտրության ցանկ՝ ավելացման հնարավորությամբ'),
(56361, 5943, 14, 'Եզակի'),
(56362, 5950, 14, 'Կայք'),
(56363, 5951, 14, 'Կայքի ID'),
(56364, 5952, 14, 'LLC Lab Exchange Service-ում բժշկական ինֆորմացիայի տեղադրման համար պահանջվող կայքի ID'),
(56365, 5953, 14, 'LLC Lab Exchange Service-ում LibreEHR գործարկելու համար պահանջվող կայքի ID'),
(56366, 5956, 14, 'Չափ'),
(56367, 5957, 14, 'Չափը պետք է լինի 1-999 միջակայքի թիվ'),
(56368, 5958, 14, 'Չափ / Ցանկ'),
(56369, 5959, 14, 'Մաշկ'),
(56370, 5960, 14, 'Մաշկային քաղցկեղ'),
(56371, 5961, 14, 'Մաշկային հիվանդություն'),
(56372, 5962, 14, 'Այլ մաշկային հիվանդություն'),
(56373, 5963, 14, 'Բաց թողնել Պացիենտի գրառումների թույլտվությունը'),
(56374, 5964, 14, 'Բաց թողնված բաժին'),
(56375, 5967, 14, 'Քնի մոդել/նկարագիր'),
(56376, 5968, 14, 'Քնի մոդել/նկարագիր'),
(56377, 5969, 14, 'Քուն'),
(56378, 5970, 14, 'սլովակերեն'),
(56379, 5971, 14, 'սլովենացի'),
(56380, 5973, 14, 'Smarty Cache մաքրվել է'),
(56381, 5974, 14, 'Ծխող․ ներկա պահին կարգավիճակն անորոշ է'),
(56382, 5976, 14, 'Ծխողի կարգավիճակը'),
(56383, 5983, 14, 'SMS/Կարճ խաղորդակգրության ծանուցում'),
(56384, 5984, 14, 'SMS/Կարճ խաղորդակգրության ծանուցման ժամեր'),
(56385, 5985, 14, 'Ուղարկել SMS/Կարճ խաղորդակգրություն մինչև/առաջ'),
(56386, 5986, 14, 'SMS/Կարճ խաղորդակգրությունն ուղարկվել է'),
(56387, 5987, 14, 'SMS տեքստ, Usable Tag: ***ԱՆՈւՆ***, ***ՄԱՏԱԿԱՐԱՐ***, ***ԱՄՍԱԹԻՎ***, ***ՍԿԻԶԲ***, ***ԱՎԱՐՏ***<br> i.e. Հարգելի ***ԱՆՈւՆ***'),
(56388, 5988, 14, 'SMS/Կարճ խաղորդակգրության /Էլ․ փոստի ծանուցման կարգավորումներ'),
(56389, 5989, 14, 'SMTP նույնականացման գաղտնաբառ'),
(56390, 5992, 14, 'SMTP սերվերի հոսթանունը'),
(56391, 5993, 14, 'SMTP սերվերի պորտ համարը'),
(56392, 5994, 14, 'SMTP   նույնականացման  օգտվող'),
(56393, 5995, 14, 'SNOMED'),
(56394, 6001, 14, 'SNOMED տվյալների բազա'),
(56395, 6002, 14, 'SNOMED ախտորոշում'),
(56396, 6003, 14, 'SNOMED միջամտություն'),
(56397, 6004, 14, 'Խռմփոց/խռմփացնել'),
(56398, 6005, 14, 'SOAP'),
(56399, 6006, 14, 'Սոցիալական խնդիրներ'),
(56400, 6009, 14, 'Սոցիալական կարգավիակի պատմություն'),
(56401, 6010, 14, 'Սոցիալական ապահովության համարը/Սոցիալական քարտի համարը'),
(56402, 6011, 14, 'լուծույթ լուծում'),
(56403, 6013, 14, 'Սոմատիկ/ֆիզիկական ենթատքեստ/իմաստ'),
(56404, 6014, 14, 'Որոշ տույտվություններ/լիազորություններ չեն ցուցադրվել․ սեղմեք այստեղ՝ ամբողջը տեսնելու համար'),
(56405, 6015, 14, 'Որոշ կոդեր չեն ցուցադրվել'),
(56406, 6016, 14, 'Որոշ այցեր չեն ցուցադրվել․ սեղմեք այստեղ՝ ամբողջը տեսնելու համար'),
(56407, 6017, 14, 'Դեիդենտիֆիկացիայի մշակման ժամանակ որոշ սխալներ են հայտնվել'),
(56408, 6018, 14, 'Որոշ  գրառումներ  չեն ցուցադրվել'),
(56409, 6019, 14, 'Որոշ գրասենյակային գրառումներ  չեն ցուցադրվել․ սեղմեք այստեղ՝ ամբողջը տեսնելու համար'),
(56410, 6020, 14, 'որոշ բառեր'),
(56411, 6021, 14, 'Ինչ-որ մեկը փոփոխել է այս այցը․ չեղարկեք այս էջը և կրկին փորձեք'),
(56412, 6023, 14, 'Ինչոր բան սխալ է․ Կրկին փորձեք'),
(56413, 6026, 14, 'Կոկորդի ցավ'),
(56414, 6027, 14, 'Ցավոք ոչ մի այց չի ֆիքսվել/հաստատվել'),
(56415, 6028, 14, 'Ցավոք ֆայլի բեռնման ընթացքում խնդիր է ծագել'),
(56416, 6029, 14, 'Դասավորել ըստ'),
(56417, 6030, 14, 'Դասավորել ըստ'),
(56418, 6032, 14, 'Դասավորել ըստ մեկնաբանությունների'),
(56419, 6033, 14, 'Դասավորել ըստ Crt օգտվողի'),
(56420, 6034, 14, 'Դասավորել ըստ ամսաթվերի'),
(56421, 6035, 14, 'Դասավորել ըստ ամսաթվերի/ժամերի'),
(56422, 6036, 14, 'Դասավորել ըստ միջոցառումների'),
(56423, 6037, 14, 'Դասավորել ըստ խմբերի'),
(56424, 6040, 14, 'Դասավորել ըստ պացիենտի ID-ների'),
(56425, 6041, 14, 'Դասավորել ըստ կատարվածի/արդյունքների հաջողության'),
(56426, 6043, 14, 'Դասավորել ըստ օգտվողների'),
(56427, 6044, 14, 'Դասավորել ըստ պատվաստանյութի'),
(56428, 6045, 14, 'Դասավորել նվազման կարգով'),
(56429, 6046, 14, 'Դասավորել արդյունքն ըստ'),
(56430, 6047, 14, 'Դասավորել աճման կարգով'),
(56431, 6048, 14, 'Հիմք/սկզբնաղբյուր'),
(56432, 6049, 14, 'Հիմնային/բազային ֆայլ'),
(56433, 6050, 14, 'Հիմնային/բազային ֆայլի  ուղին'),
(56434, 6051, 14, 'Կոդի համար բացակայամու է հիմքը/աղբյուրը '),
(56435, 6052, 14, 'Էջի աղբյուրի/բազայի խմբաքանակ'),
(56436, 6057, 14, 'Աղբյուր/Էջի աղբյուր'),
(56437, 6060, 14, 'Տարածություն/հեռավորություն'),
(56438, 6061, 14, 'Տարածություն/հեռավորություն'),
(56439, 6062, 14, 'Իսպաներեն'),
(56440, 6063, 14, 'Իսպաներեն  (լատինամերիկյան)'),
(56441, 6064, 14, 'Իսպաներեն  (իսպանական)'),
(56442, 6066, 14, 'Հատուկ նշաններ չեն թույլատրվում'),
(56443, 6067, 14, 'Կենսական ննակության օրգանների հատուկ բուժում'),
(56444, 6068, 14, 'Մասնագետ'),
(56445, 6069, 14, 'Մասնագետի ազգանունը և ստորագրությունը'),
(56446, 6071, 14, 'Մասնագիտություն'),
(56447, 6072, 14, 'Հատուկ համակարգեր'),
(56448, 6073, 14, 'Մասնագիտություն։'),
(56449, 6074, 14, 'Հատուկ'),
(56450, 6075, 14, 'Հատուկ հայտ/դիմում/կիրառում'),
(56451, 6076, 14, 'Հակաբեղմնավորիչ հատուկ ծառայություն'),
(56452, 6077, 14, 'Հատուկ արդյունք'),
(56453, 6078, 14, 'Հատուկ ծառայություն'),
(56454, 6079, 14, 'Նշված'),
(56455, 6080, 14, 'Կոդերի հատուկ ֆորմատավորում. # = digit, * = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56456, 6081, 14, 'Կոդերի հատուկ ֆորմատավորում. # = digit, @ = alpha, * = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56457, 6082, 14, 'Հաշիվների ստուգիչ համարների հատուկ ֆորմատավորում. # = digit, * = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56458, 6083, 14, 'Հաշիվների ստուգիչ համարների հատուկ ֆորմատավորում. # = digit,@ = alpha, * = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56459, 6084, 14, 'Հաշիվների NDC ապրանքների դաշտերի հատուկ ֆորմատավորում. # = digit, * = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56460, 6085, 14, 'Հաշիվների NDC ապրանքների դաշտերի հատուկ ֆորմատավորում. # = digit, @ = alpha,* = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56461, 6086, 14, 'Օտարերկրյա պացիենտի ID-ի հատուկ ֆորմատավորում. # = digit, * = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56462, 6087, 14, 'Օտարերկրյա պացիենտի ID-ի հատուկ ֆորմատավորում. # = digit, @ = alpha,* = ցանկ․ սիմվոլ. Եթե չի կիրառվում, ապա դատարկ է'),
(56463, 6088, 14, 'Նմուշ/օրինակ'),
(56464, 6089, 14, 'Նմուշի/օրինակի համար/նույնացուցիչ'),
(56465, 6090, 14, 'Նմուշի/օրինակի տեսակը'),
(56466, 6092, 14, 'Բանավոր թելադրանք'),
(56467, 6093, 14, 'Նմուշներ/օրինակներ'),
(56468, 6094, 14, 'Սպլենէկտոմիա /Փայծախի վիրահատական հեռացում/'),
(56469, 6095, 14, 'Կին/ամուսին'),
(56470, 6096, 14, 'Կնոջ/ամուսնու անամնեզը'),
(56471, 6097, 14, 'Խորխ'),
(56472, 6098, 14, 'Խորխ։'),
(56473, 6099, 14, 'ԲԺ'),
(56474, 6100, 14, 'sql'),
(56475, 6102, 14, 'Բաժանմունք'),
(56476, 6103, 14, 'Բաժանմունքի անձնակազմ'),
(56477, 6104, 14, 'Բաժանմունքներ'),
(56478, 6105, 14, 'SRH'),
(56479, 6106, 14, 'SRH - ընտանիքի պլանավորում'),
(56480, 6107, 14, 'SRH - ոչ ընտանեկան պլանավորում'),
(56481, 6108, 14, 'SRH ուղեգիր'),
(56482, 6109, 14, 'SRH այցի ձև'),
(56483, 6110, 14, 'Ծառայության ամսաթիվ'),
(56484, 6111, 14, 'SS'),
(56485, 6112, 14, 'SSL հավաստագրի կառավարում/կարգավորում'),
(56486, 6113, 14, 'SSN'),
(56487, 6114, 14, 'Կայունություն'),
(56488, 6115, 14, 'Պլանային դուրսգրում'),
(56489, 6116, 14, 'Ստանդարտ'),
(56490, 6117, 14, 'Ստանդարտ կոդ'),
(56491, 6118, 14, 'Ստանդարտ միջոցներ/միջոցառումներ'),
(56492, 6119, 14, 'Ստանդարտ միջոցներ/միջոցառումներ (Ակտիվ ազդանշաններ)'),
(56493, 6120, 14, 'Ստանդարտ միջոցներ/միջոցառումներ (Պասիվ ազդանշաններ)'),
(56494, 6121, 14, 'Ստանդարտ միջոցներ/միջոցառումներ (Պացիենտի հիշեցումներ)'),
(56495, 6122, 14, 'Ստանդարտ անվանում'),
(56496, 6123, 14, 'Ստանդարտ։ Պարզեցված։ միայն վերնագիր, մեկնարկի ամսաթիվ, մեկնաբանություններ և ակտիվ նշավանդակ; ոչ մի ախտորոշում, բացահայտում/կրկնություն, ավարտման ամսաթիվ,, անդրադարձ, սպորտային դաշտ; ֆուտբոլային վնասվածք'),
(56497, 6124, 14, 'Սկիզբ/մեկնարկ'),
(56498, 6125, 14, 'Սկիզբ/մեկնարկ (տտ-աա-օօ): '),
(56499, 6126, 14, 'Սկսել մեկ ուրիշ հաշվետվություն'),
(56500, 6128, 14, 'Մեկնարկի ամսաթիվ'),
(56501, 6129, 14, 'Սույն կլինիկայում սկսված ամսաթիվը'),
(56502, 6130, 14, 'Սկզբի ամսաթիվը չի կարող մեծ լինել ավարտի ամսաթվից'),
(56503, 6131, 14, 'Մեկնարկի ամսաթիվ։'),
(56504, 6132, 14, 'Մեկնարկի ամսաթիվ։'),
(56505, 6134, 14, 'Սկիզբ (ժամ)'),
(56506, 6135, 14, 'Սկզբնական ամսաթիվ'),
(56507, 6136, 14, 'Շրջան'),
(56508, 6137, 14, 'Պետական տվյալների ձև'),
(56509, 6138, 14, 'Պետական լիցենզիա #'),
(56510, 6139, 14, 'Պետական լիցենզիայի համար'),
(56511, 6140, 14, 'Պետական ցանկ'),
(56512, 6141, 14, 'Պետական ցանկ (գրել,  միայն ավելացնել ըստ ցանկության)'),
(56513, 6143, 14, 'Նահանգ կամ շրջան'),
(56514, 6144, 14, 'Նահանգ/շրջան/տեղամաս/բնակության վայր'),
(56515, 6145, 14, 'Նահանգ/շրջան'),
(56516, 6146, 14, 'ԵԶՐԱՓԱԿՈՒՄ/ ԵԶՐԱՓԱԿԻՉ ՀԱՅՏԱՐԱՐՈՒԹՅՈՒՆ'),
(56517, 6147, 14, 'Հայտարարություններ և թարմացվող հաշիվներ'),
(56518, 6148, 14, 'Հայտարարություններն ուղարկվել են'),
(56519, 6149, 14, 'հայտարարություններ։ հաշիվները չեն թարմացվի'),
(56520, 6150, 14, 'Ստատիկ տեքստ'),
(56521, 6151, 14, 'Վիճակագրական տվյալներ'),
(56522, 6152, 14, 'Վիճ․'),
(56523, 6153, 14, 'Կարգավիճակ'),
(56524, 6154, 14, 'Վիճակն ընդունվելիս'),
(56525, 6155, 14, 'Գանգատի կարգավիճակը'),
(56526, 6156, 14, 'Ստատուս քվո'),
(56527, 6159, 14, 'Ուժ և ազդեցություն'),
(56528, 6163, 14, 'CCR XML բեռնման քայլեր'),
(56529, 6164, 14, 'DSM IV տվյալների բազայի տեղադրման քայլեր'),
(56530, 6165, 14, 'ICD 10 տվյալների բազայի տեղադրման քայլեր'),
(56531, 6166, 14, 'ICD 9 տվյալների բազայի տեղադրման քայլեր'),
(56532, 6167, 14, 'RxNorm տվյալների բազայի տեղադրման քայլեր'),
(56533, 6168, 14, 'Snomed տվյալների բազայի տեղադրման քայլեր'),
(56534, 6169, 14, 'Կոշտ/ոչ ճկուն հոդեր'),
(56535, 6170, 14, 'Կոշտություն'),
(56536, 6171, 14, 'Ֆոնդային ամիսներ'),
(56537, 6172, 14, 'Ստամոքսի ցավեր'),
(56538, 6173, 14, 'Դադար/դադարեցնել'),
(56539, 6175, 14, 'Մկանների լարում'),
(56540, 6176, 14, 'Հոսք/տարածում'),
(56541, 6177, 14, 'Փողոց'),
(56542, 6178, 14, 'Փողոցի հասցեն'),
(56543, 6179, 14, 'Փողոց և համար'),
(56544, 6180, 14, 'Ուժ'),
(56545, 6181, 14, 'Ուժ և ազդեցություն'),
(56546, 6182, 14, 'Կոկորդի սուր հիվանդություն'),
(56547, 6183, 14, 'Ճնշմամբ պայմանավորված կոտրվածք'),
(56548, 6184, 14, 'Ծանրաբեռնվածության թեստ'),
(56549, 6185, 14, 'Կաթված'),
(56550, 6186, 14, 'Ապահով գաղտնաբառը պարունակում է 8 նիշ, որից ամենաքիչը 3 թիվ, մեծատառ, փոքրատառ, սիմվոլ'),
(56551, 6187, 14, 'Տեսք'),
(56552, 6188, 14, 'Նոր պացիենտ ավելացնելու ձևաթղթի տեսքը'),
(56553, 6189, 14, 'Ենթաբաժին'),
(56554, 6190, 14, 'Միջանկյալ հանրագումար'),
(56555, 6191, 14, 'Ենթաբաժին'),
(56556, 6192, 14, 'ենթաբաժին'),
(56557, 6193, 14, 'ենթամաշկային'),
(56558, 6194, 14, 'Թեմա/առարկա'),
(56559, 6195, 14, 'Սուբյեկտիվ'),
(56560, 6196, 14, 'Ենթալեզվային'),
(56561, 6197, 14, 'ենթալեզվային'),
(56562, 6198, 14, 'Ներկայացնել/հաստատել'),
(56563, 6199, 14, 'Ներկայացնել/հաստատել'),
(56564, 6200, 14, 'Ներկայացնել/հաստատել ողջ բովանդակությունը'),
(56565, 6201, 14, 'Հաստատել և ջնջել պահանջը'),
(56566, 6202, 14, 'Հաստատել իրադարձությունը'),
(56567, 6203, 14, 'հաստատել ձևը'),
(56568, 6204, 14, 'Հաստատել ընտրված ենթատեքստը'),
(56569, 6205, 14, 'հաստատված է'),
(56570, 6206, 14, 'հաստատված է -ի կողմից'),
(56571, 6208, 14, 'Բաժանորդ'),
(56572, 6209, 14, 'Բաժանորդի հասցեն'),
(56573, 6210, 14, 'Բաժանորդի քաղաք'),
(56574, 6211, 14, 'Բաժանորդի երկիր'),
(56575, 6212, 14, 'Բաժանորդի ծննդյան տարեթիվ'),
(56576, 6213, 14, 'Բաժանորդի աշխատավայր'),
(56577, 6214, 14, 'Բաժանորդի աշխատավայր  (SE)'),
(56578, 6215, 14, 'Բաժանորդի աշխատավայրի/գործատուիհասցե'),
(56579, 6216, 14, 'Բաժանորդի աշխատավայրի/գործատուիքաղաք'),
(56580, 6217, 14, 'Բաժանորդի աշխատավայրի/գործատուիերկիր'),
(56581, 6218, 14, 'Բաժանորդի աշխատավայրի/գործատուիմարզ'),
(56582, 6219, 14, 'Բաժանորդի աշխատավայրի/գործատուի փողոց'),
(56583, 6220, 14, 'Բաժանորդի աշխատավայրի/գործատուի փոստայի ինդեքս'),
(56584, 6221, 14, 'Բաժանորդի աշխատավայրի/գործատուի փոստայի ինդեքս'),
(56585, 6222, 14, 'Բաժանորդի անուն'),
(56586, 6223, 14, 'Բաժանորդի ազգանուն'),
(56587, 6224, 14, 'Բաժանորդի հայրանուն'),
(56588, 6225, 14, 'Բաժանորդի հեռախոս'),
(56589, 6226, 14, 'Բաժանորդի կապը/առնչությունը/հարաբերությունը'),
(56590, 6227, 14, 'Ազգագրական տվյալներն այլ են, սակայն ազգանունը նույնն է․ Արդյո՞ք սա ճիշտ է'),
(56591, 6228, 14, 'Ազգագրական տվյալներն այլ են, սակայն SS համարը  նույնն է․'),
(56592, 6229, 14, 'Ազգագրական տվյալներն նույնն են, սակայն անունը այլ է․ Արդյո՞ք սա ճիշտ է'),
(56593, 6230, 14, 'Ազգագրական տվյալներն  նույնն  են, սակայն SS համարը այլ է․'),
(56594, 6231, 14, 'Բաժանորդի սեռը'),
(56595, 6232, 14, 'Բաժանորդի SS'),
(56596, 6233, 14, 'Բաժանորդի Մարզը/շրջանը'),
(56597, 6234, 14, 'Բաժանորդի փոստային կոդը'),
(56598, 6235, 14, 'Բաժանորդի հեռախոս'),
(56599, 6237, 14, 'Փոխարինում /'),
(56600, 6238, 14, 'Փոխարինում թույլատրված է'),
(56601, 6240, 14, 'Հաջողություն'),
(56602, 6241, 14, 'հաջողություն'),
(56603, 6242, 14, 'Լաբորատոր հետազոտությունների դրական/հաջող պատասխան'),
(56604, 6243, 14, 'Լաբորատոր հետազոտությունների պատասխանը հաջողությամբ ստացվեց'),
(56605, 6244, 14, 'Lab Exchange Network-ից արդյունքների հաջող արտածում'),
(56606, 6246, 14, 'Կատեգորիան հաջողությամբ ավելացվեց'),
(56607, 6247, 14, 'Հաջողությամբ ավելացվեց կատեգորիային'),
(56608, 6248, 14, 'Հաջողությամբ ջնջվեց'),
(56609, 6249, 14, 'Մանրամասները հաջողությամբ ներբեռնվեցին։ Խնդրում ենք հաստատել հաստատմանն սպասող Պացիենտին'),
(56610, 6250, 14, 'Տվյալների բազան հաջողությամբ տեղադրվել է'),
(56611, 6251, 14, 'Սույն տվյալների բազան հաջողությամբ տեղադրվել է'),
(56612, 6252, 14, 'Հաջողությամբ փոփոխվեց'),
(56613, 6253, 14, 'Հաջողությամբ պահպանվեց․ Սահամանե՞լ այն'),
(56614, 6254, 14, 'Հաջողությամբ պահպանվեց․ Սահամանե՞լ այն'),
(56615, 6256, 14, 'Հաջողությամբ պահպանվեց/պահեստավորվեց'),
(56616, 6257, 14, 'Տվյալների բազան հաջողությամբ թարմացվեց'),
(56617, 6258, 14, 'Սույն տվյալների բազան հաջողությամբ թարմացվեց'),
(56618, 6259, 14, 'հաջողությամբ'),
(56619, 6260, 14, 'Ինքնասպանություն'),
(56620, 6261, 14, 'Ամփոփում'),
(56621, 6262, 14, '-ի ամփոփում'),
(56622, 6265, 14, 'Կիր․'),
(56623, 6266, 14, 'Սունդաաներեն/սունդանացի'),
(56624, 6267, 14, 'Կիրակի'),
(56625, 6268, 14, 'Superbill'),
(56626, 6269, 14, 'Superbill կոդեր'),
(56627, 6270, 14, 'Superbill կոդերի կառավարում'),
(56628, 6271, 14, 'Superbill հաշվետվություն'),
(56629, 6272, 14, 'Superbill/Վճարման թերթիկ'),
(56630, 6273, 14, 'Superbills'),
(56631, 6275, 14, 'Գերօգտվող'),
(56632, 6276, 14, 'Վերահսկող/Ղեկավարող/Կառավարող'),
(56633, 6278, 14, 'DEA ղեկավարող բժիշկ'),
(56634, 6279, 14, 'Ղեկավարող Բժշկի անունը'),
(56635, 6280, 14, 'Ղեկավարող Բժշկի ազգանունը'),
(56636, 6281, 14, 'Ղեկավարող Բժշկի NPI'),
(56637, 6282, 14, 'Ղեկավարող Բժշկի UPIN'),
(56638, 6283, 14, 'Արտադրող մատակարարի իրավապանական անվանումը'),
(56639, 6284, 14, 'Աջակցում/գործարկում է մի շարք մասնագետների կողմից օգտագործվող օրացուցային իրադարձությունները'),
(56640, 6286, 14, 'Աջակցում/գործարկում է մի շարք մասնագետների մասնակցությամբ իրադարձությունները'),
(56641, 6289, 14, 'Մակերեսի/մակերևույթի տեսակը'),
(56642, 6290, 14, 'Վիրահատություններ'),
(56643, 6291, 14, 'Վիրահատություն'),
(56644, 6292, 14, 'Վիրահատությունների ցանկ'),
(56645, 6293, 14, 'Հետաձգված'),
(56646, 6294, 14, 'Ընդհատում, դադարեցում'),
(56647, 6295, 14, 'Svc Ամսաթիվ'),
(56648, 6296, 14, 'Svc Ամսաթիվ։');
INSERT INTO `lang_definitions` VALUES
(56649, 6299, 14, 'Քրտնարտադրություն։'),
(56650, 6300, 14, 'Շվեդական'),
(56651, 6301, 14, 'Այտուց/ուռուցք'),
(56652, 6302, 14, 'Աջակողմյա ուռուցք/այտուց'),
(56653, 6303, 14, 'Այտուցված հոդեր'),
(56654, 6304, 14, 'Այտուցված ավշային հանգույցներ'),
(56655, 6305, 14, 'Սիմվոլն օգտագործվում է արժույթի տասնորդական կետի համար․ չի կիրառվում, եթե տասնորդական նիշը 0 է'),
(56656, 6306, 14, 'Սիմվոլն օգտագործվում է արժույթի հազարական կետերի բաժանման  համար'),
(56657, 6307, 14, 'Սիմպտոմ/ախտանիշ'),
(56658, 6308, 14, 'Համաժամանակեցնել'),
(56659, 6309, 14, 'Համաժամանակեցնել թարգմանությունը անհատական լեզվախմբի հետ'),
(56660, 6310, 14, 'Նոր  անհատական կոնստանտի համաժամանակեցում'),
(56661, 6311, 14, 'Նոր  անհատական լեզվի համաժամանակեցում'),
(56662, 6312, 14, 'Նոր  բացատրության/նշանակության համաժամանակեցում (Լեզու, Կոնստանտ, Նշանակություն)'),
(56663, 6313, 14, 'Սինկոպա/հնչակորուստ'),
(56664, 6314, 14, 'Համախտանիշի վերահսկողություն'),
(56665, 6315, 14, 'Համախտանիշի վերահսկողություն -Չհրապարակված հարցեր/արդյունքներ'),
(56666, 6316, 14, 'Համախտանիշի վերահսկողության հաշվետվություն/զեկույց'),
(56667, 6318, 14, 'Համակարգ'),
(56668, 6322, 14, 'T'),
(56669, 6323, 14, 'Օրը երեք անգամ'),
(56670, 6325, 14, 'Աղյուսակ'),
(56671, 6327, 14, 'Աղյուսակի ստեղծումը ձախողեց'),
(56672, 6328, 14, 'Աղյուսակի թարմացումը ձախողեց'),
(56673, 6329, 14, 'Աղյուսակներ'),
(56674, 6330, 14, 'Հաբ/կոճակ'),
(56675, 6335, 14, 'Ընդունել/վերցնել'),
(56676, 6336, 14, 'Ընտրել Ապահովագրին դեպի ցած բացվող ցանկից'),
(56677, 6337, 14, 'Ընտրել Վճարման ձևը ցած բացվող ցանկից'),
(56678, 6338, 14, 'Հետ վերցնել'),
(56679, 6339, 14, 'Երկար ժամանակ կպահանջի/կտևի'),
(56680, 6340, 14, 'Բարձրադիր նավիգացիոն տարածք'),
(56681, 6342, 14, 'Կեղծ ամսաթիվ'),
(56682, 6343, 14, 'Կեղծ գումար'),
(56683, 6347, 14, 'Թիրախային ամսաթիվ'),
(56684, 6348, 14, 'Թիրախային պացիենտ'),
(56685, 6349, 14, 'Թիրախային պացիենտը ծննդյան ամսաթիվ չունի'),
(56686, 6350, 14, 'Թիրախային պացիենտ չի գտնվել'),
(56687, 6351, 14, 'Թիրախ/գործողությունների խմբեր'),
(56688, 6352, 14, 'Թաթար'),
(56689, 6354, 14, 'ՀՎՀՀ'),
(56690, 6355, 14, 'Հարկային դրույք'),
(56691, 6356, 14, 'Հարկեր'),
(56692, 6359, 14, 'Վնասվածքի թիմային ախտորոշում'),
(56693, 6360, 14, 'Թիմի անվանացանկ'),
(56694, 6361, 14, 'Թիմի անվանացանկի դիտում'),
(56695, 6362, 14, 'Թիմ/բաժանմունք'),
(56696, 6363, 14, 'Հեռ․'),
(56697, 6364, 14, 'Երկրի միջազգային հեռախոսային կոդը'),
(56698, 6366, 14, 'Ջերմ․'),
(56699, 6367, 14, 'Ջերմաչափման վայրը'),
(56700, 6368, 14, 'Ջերմաչափման մեթոդը'),
(56701, 6369, 14, 'Ջերմություն'),
(56702, 6370, 14, 'Ձև/Նմուշ'),
(56703, 6371, 14, 'Նմուշի անվանում'),
(56704, 6372, 14, 'Նմուշի անվանումը չի կարող սկսվել թվով'),
(56705, 6373, 14, 'Ձև/Նմուշ։'),
(56706, 6374, 14, 'Ձևեր/Նմուշներ։'),
(56707, 6376, 14, 'Ջլի վնասվածք'),
(56708, 6378, 14, 'Փորձնական հաշիվ-ապրանքագրի համար'),
(56709, 6379, 14, 'Երրորդային/ երրորդ կարգի'),
(56710, 6380, 14, 'Երրորդային/ երրորդ կարգի ապահովագրություն'),
(56711, 6381, 14, 'Երրորդային/ երրորդ կարգի ապահովագրության ամսաթիվ'),
(56712, 6382, 14, 'Երրորդային/ երրորդ կարգի ապահովագրող'),
(56713, 6383, 14, 'Թեստավորման/հետազոտման պլանավորում'),
(56714, 6384, 14, 'Թեստային համակարգ'),
(56715, 6385, 14, 'Տեքստ'),
(56716, 6386, 14, 'Ախտորոշման նկարագիր'),
(56717, 6387, 14, 'Տեքստային դաշտ'),
(56718, 6393, 14, 'Տեքստի ամսաթիվ'),
(56719, 6394, 14, 'տեքստի ամսաթիվ'),
(56720, 6395, 14, 'Տեքստային տարածք'),
(56721, 6396, 14, 'տեքստային տարածք'),
(56722, 6397, 14, 'Տեքստային դաշտ'),
(56723, 6398, 14, 'տեքստային դաշտ'),
(56724, 6399, 14, 'Տեքստային դաշտի ցանկ'),
(56725, 6400, 14, 'տեքստային դաշտի ցանկ'),
(56726, 6401, 14, 'թայերեն'),
(56727, 6402, 14, 'Շնորհակալություն'),
(56728, 6403, 14, 'Շնորհակալություն ընտրության համար'),
(56729, 6404, 14, '"Մաքրել" կոճակը կջնջի/կհեռացնի բոլոր ծանոթագրությունների'),
(56730, 6405, 14, 'Վերոնշյալ հայտը ձախողվեց'),
(56731, 6406, 14, 'SSL Apache սերվերի հավաստագիր և ընդհանուր բանալի'),
(56732, 6407, 14, 'Լիազորման Սերիտիֆիկատի հավաստագիր'),
(56733, 6408, 14, 'Պահանջի ֆայլ։ '),
(56734, 6410, 14, 'Համապատասխան անձնական բանալի'),
(56735, 6411, 14, 'Այս ձևի տվյալների ամբողջականության փորձարկումը ձախողվեց'),
(56736, 6413, 14, 'Մերժման կոդը հետևյալն է։'),
(56737, 6414, 14, 'Խմբի մերժման կոդը հետևյալն է։'),
(56738, 6415, 14, 'Նշանակման ձևը փակ է'),
(56739, 6416, 14, 'Նշանակման ձևը փակ է․ այն չի կարող ազդել ընտրության վրա'),
(56740, 6422, 14, 'Իրադարձություն(ներ)ը հաստատված է(են)'),
(56741, 6423, 14, 'Իրադարձություն(ներ)ը թաքցված է(են)'),
(56742, 6424, 14, 'Ներմուծված տվյալը հայտնվում է ներքոհիշյալ տեքստային տարածքում։ Կարող եք կրկնօրինակել այն տեղադրել էլ․փոստում կամ այլ նշանակված վայրում։'),
(56743, 6426, 14, 'Ներմուծված տվյալը հայտնվում է ներքոհիշյալ տեքստային տարածքում։ Կարող եք կրկնօրինակել այն տեղադրել էլ․փոստում կամ այլ նշանակված վայրում։'),
(56744, 6427, 14, 'Ներմուծված տվյալը հայտնվում է ներքոհիշյալ տեքստային տարածքում։ Կարող եք կրկնօրինակել այն տեղադրել էլ․փոստում կամ այլ նշանակված վայրում։ {{ՀԱՋՈՐԴ ԹԱՐԳՄԱՆՈՒԹՅԱՆ ԻՐԱԳՈՐԾՄԱՆ ԺԱՄԱՆԱԿ ՆՇԵՔ ԱՅՆ ՋՆՋՄԱՆ ՆՊԱՏԱԿՈՎ}}'),
(56745, 6428, 14, 'Ֆայլը չի պահպանվել CouchDB-ում'),
(56746, 6429, 14, 'Ֆայլի անվանափոխումը չհաջողվեց։ Նման խնդիրները սովորաբար կապված են պահեստային համակարգի թույլտվության հետ։'),
(56747, 6430, 14, 'Ֆայլի պահեստավորումը չհաջողվեց։ Նման խնդիրները սովորաբար կապված են պահեստային համակարգի թույլտվության հետ։'),
(56748, 6431, 14, 'Առաջին ("թիրախ") աղյուսակը միաիկն է, որ համարվում է առավել ամբողջականն ու շգրիտը։ Ազգագրական, հիվանդության պատմության  և ապահովագրական տվյալները կպահպանվեն այստեղ'),
(56749, 6433, 14, 'Առաջին քայլը  Միասնական Բժշկական Լեզվի համակարգի /Unified Medical Language System/ վեբ կայքում օգտվողի հաշիվ բացելն է'),
(56750, 6434, 14, 'Ավելացվել է հետևյալ օրացույցային իրադարձությունը'),
(56751, 6435, 14, 'Փոփոխվել է հետևյալ օրացույցային իրադարձությունը'),
(56752, 6436, 14, 'Կատեգորիաների ցանկից կջնջվեն հետևյալները։'),
(56753, 6437, 14, 'Տեղադրվել էտվյալների բազայի  հետևյալ տարբերակը'),
(56754, 6438, 14, 'Անձնական նամակին կցվել են հետևյալ փաստաթղթերը'),
(56755, 6439, 14, 'Թարմացվել է հետևյալ  EDI ֆայլը'),
(56756, 6440, 14, 'Ակտիվացվել է հետևյալ արտակարգ մուտքի օգտվողը'),
(56757, 6441, 14, 'Տեղի են ունեցել հետևյալ սխալները'),
(56758, 6442, 14, 'Այս դաշտը պարունակում է անվավեր արժեք'),
(56759, 6444, 14, 'Հետևյալ դաշտերը պարտադիր են'),
(56760, 6446, 14, 'Պահանջն ուղարկելու համար անհրաժեշտ է լրացնել հետևյալ դաշտերը'),
(56761, 6448, 14, 'Հետևյալ խնդիրներն ունեն միևնույն ախտորոշման կոդերը։ Այցի ընթացքում գրանցված խնդիրները չեն թարմացվի։ Խնդրում ենք օգտագործել  այցելության ինտերֆեյսը միայն'),
(56762, 6450, 14, 'Սկզբնական պատուհանը համարվում է հաշիվ-ապրանքագրի որոնման էջ։ Վերևում կարող եք մուտքագրել սկզբնաղբյուրը (օր․՝ հերթական համարը), վճարման ամսաթիվը և գումարը։ Աղբյուրի և վճարման ամսաթվի անհրաժեշտությունը նրանում է, որ այսուհետ կարիք չի լինի յուրաքանչյուր անգամ մուտքագրել դրանք։ Յուրաքանչյուր մասնակի վճարման դեպքում գումարը կնվազի և վերջում կզրոյանա։'),
(56763, 6454, 14, 'Տեղադրված տարբերակն ու ֆայլերը նույնն են'),
(56764, 6455, 14, 'Տեղադրված տարբերակն ավելի թարմ է, քան  ֆայլերը'),
(56765, 6456, 14, 'Ձևանմուշի վրա օգտվողի մոտ հայտնվող պիտակը'),
(56766, 6457, 14, 'Երկարությունը չպետք է գերզանցի նիշերի հետևյալ քանակը'),
(56767, 6459, 14, 'Այս պահին հնարավոր չէ հաղորդագրություն ուղարկել'),
(56768, 6460, 14, 'Նոր կատեգորիան կլինի -ի ենթակատեգորիան '),
(56769, 6461, 14, 'Նոր և ընթացիկ գաղտնաբառը չեն կարող նույնը լինել'),
(56770, 6462, 14, 'Նոր գաղտնաբառի դաշտերը տարբեր են'),
(56771, 6463, 14, 'Տեղադրված ֆայլերի համարը սխալ է․ Տեղադրեք միայն այն ֆայլը, որն ուզում եք հաստատել/թարմացնել'),
(56772, 6464, 14, 'Տեղադրված ֆայլերի համարը սխալ է․ Տեղադրեք միայն այն ֆայլը, որն ուզում եք հաստատել/թարմացնել'),
(56773, 6465, 14, 'Էջը վերահղում կանի դեպի ազգագրական տվյալներ․ Դուք կկարողանաք խմբագրել երկիր դաշտը, ապա քլիքի օգնությամբ կրկին վերադառնալ NewCrop'),
(56774, 6466, 14, 'Գաղտնաբառը պետք է լինի առնվազն ութ նիշ և պիտի․․․'),
(56775, 6467, 14, 'Մուտքագրված գաղտնաբառը սխալ է'),
(56776, 6468, 14, 'Պացիենտի գրանցման հայտն ընդունված է'),
(56777, 6469, 14, 'Պացիենտի հիշեցումներն ուղարկված են'),
(56778, 6470, 14, 'Պացիենտի հիշեցումները թարմացված են'),
(56779, 6471, 14, 'Այս ձևը հաստատելիս պացիենտը մուտք չի գործել համակարգ'),
(56780, 6472, 14, 'Հրապարակված վճարումները չեն կարող լինել այս ամսաթվից ներքև․ սա նշանակում է, որ վերջնական հաշվետվություն ստանալուց հետո ոչ ոք չի հրապարակում նախկին ամսաթվերը'),
(56781, 6473, 14, 'Այս պացիենտի և ձևի համար պորտալում առկա են տվյալներ։  Բեռնե՞լ դրանք'),
(56782, 6475, 14, 'Մնացած ներքոհիշյալ ինֆորմացիան  ավելացվում է միայն երբ ձեռքով կատարում եք  գրառում կամ շտկումներ։'),
(56783, 6476, 14, 'Պահանջվող փաստաթուղթն առկա չէ ֆայլերի համակարգի տվյալ տարածքում, կամ չկա դրանց հասանելիության  համապատասխան թույլտվություն։'),
(56784, 6477, 14, 'Պահանջվող փաստաթուղթն առկա չէ ֆայլերի համակարգի տվյալ տարածքում, կամ չկա դրանց հասանելիության  համապատասխան թույլտվություն։'),
(56785, 6480, 14, 'Աղբյուրի և ամսաթվի սյուները կրկնօրինակվում են առաջին էջից, ուստի կարիք չկա դրանց ձեռք տալ։ Վճարման գումարը տեղադրում եք վճարում սյան մեջ, ճշգրտման ենթական ումարը՝ Ճշգրտում սյան մեջ, կամ երկուսում էլ։ Կարող եք աջ կողմում սեղմել  "W" to automatically compute an adjustment value that writes off the remainder of the charge for that line item.'),
(56786, 6484, 14, 'Օրացույցի ժամանակային և այցերի միջակայքի րոպեական  ճշգրտում'),
(56787, 6485, 14, 'Թարգմանված պիտակ, որն արտածվում է տվյալ լեզվով նմուշի/ձևի վրա'),
(56788, 6486, 14, 'Թարգմանված Վերնագիր, որ հայտնվում է ընթացիկ լեզվով'),
(56789, 6487, 14, 'Ընթացիկ լեզվով նկարագրության թարգմանություն'),
(56790, 6488, 14, 'Թարգմանված աղյուսակները համաժամանակեցված են'),
(56791, 6489, 14, 'Իրավաբանական անձի տեսակը'),
(56792, 6490, 14, 'Միջամտությունը կամ արդյունքը նույնականացնող հատուկ կոդ'),
(56793, 6492, 14, 'zip/սեղմված ֆայլը կարող է պարունակել հետևյալ կետերը'),
(56794, 6493, 14, 'Թեմա'),
(56795, 6495, 14, 'Թերապեվտիկ ներարկումներ'),
(56796, 6496, 14, 'Կան'),
(56797, 6497, 14, 'Ներկա պահին դեղատոմսեր/նշանակումներ չկան'),
(56798, 6498, 14, 'Հայտի ներկայացման սխալ կա։ Դրանք ներկայացված են ստորև'),
(56799, 6499, 14, 'Պաորտալ լոգինով առկա են տարբեր պացիենտներ'),
(56800, 6500, 14, 'Դուրսգրված քարտեր չկան'),
(56801, 6501, 14, 'Այս հիվանդի համար գրանցված բացահայտումներ չկան'),
(56802, 6502, 14, 'Նոր պնդումներ/հաստատումներ չկան'),
(56803, 6503, 14, 'Ֆայլում առկա չեն սույն պացիենտի մասին գրառումներ'),
(56804, 6504, 14, 'Ֆայլում առկա չեն սույն պացիենտի վերաբերյալ փոխանցումներ'),
(56805, 6505, 14, 'Տեղի է ունեցել փստի ուղարկման սխալ'),
(56806, 6506, 14, 'Կատեգորիան արդեն անվանակոչվել է'),
(56807, 6507, 14, 'Ենթակատեգորիան արդեն անվանակոչվել է'),
(56808, 6508, 14, 'Առկա է անվանակոչված կետ'),
(56809, 6509, 14, 'Հիվանդի գրառման հարցումն արդեն բացված է'),
(56810, 6510, 14, 'AR հաշվի համար չկա COA մուտք '),
(56811, 6511, 14, 'Կանխիկ/Դրամական հաշվի համար չկա COA մուտք '),
(56812, 6512, 14, 'Եկամտային հաշվի համար չկա COA մուտք '),
(56813, 6513, 14, 'Չկա ընթացիկ պացիենտ'),
(56814, 6514, 14, 'Այս թեմայի շուրջ չկա  local content'),
(56815, 6515, 14, 'Հաշիվ-ապրանքագրի նույնականացման համապատասխանություն չկա'),
(56816, 6516, 14, 'Հաշիվ-ապրանքագրի նույնականացման համապատասխանություն չկա '),
(56817, 6518, 14, 'Պորտալ լոգինով պացիենտ չկա'),
(56818, 6519, 14, 'Տեղի է ունեցել նամակի ուղարկման սխալ'),
(56819, 6520, 14, 'Հարցումն իրականացնելիս սխալ է տեղի ունեցել'),
(56820, 6522, 14, 'Ահա 2012 հղումները'),
(56821, 6523, 14, 'Աջակողմյա հաստացում'),
(56822, 6524, 14, 'Ազդր'),
(56823, 6525, 14, 'Ազդր + ծնկատակի ջիլ'),
(56824, 6526, 14, 'Տվյալներ, որ back office-ում  կարող են միայն կարդալ'),
(56825, 6527, 14, 'Տվյալներ, որ back office-ում կարող են  կարդալ, մուտքագրել, բայց չփոփոխել'),
(56826, 6528, 14, 'Տվյալներ, որ back office-ում կարող են  կարդալ և փոփոխել'),
(56827, 6529, 14, 'Տվյալներ, որ back office-ում կարող են  կարդալ և փոփոխել մասնակի'),
(56828, 6530, 14, 'Տվյալներ, որ բժիշկները/բուժաշխատողները  կարող են միայն կարդալ'),
(56829, 6531, 14, 'Տվյալներ, որ բժիշկները/բուժաշխատողները կարող են  կարդալ, մուտքագրել, բայց չփոփոխել'),
(56830, 6532, 14, 'Տվյալներ, որ բժիշկները/բուժաշխատողները կարող են  կարդալ և փոփոխել'),
(56831, 6533, 14, 'Տվյալներ, որ բժիշկները/բուժաշխատողները կարող են  կարդալ և փոփոխել մասնակի'),
(56832, 6534, 14, 'Տվյալներ, որ գլխավոր գրասենյակում  կարող են միայն կարդալ'),
(56833, 6535, 14, 'Տվյալներ, որ գլխավոր գրասենյակում կարող են  կարդալ, մուտքագրել, բայց չփոփոխել'),
(56834, 6536, 14, 'Տվյալներ, որ գլխավոր գրասենյակում կարող են  կարդալ և փոփոխել'),
(56835, 6537, 14, 'Տվյալներ, որ գլխավոր գրասենյակում կարող են  կարդալ և փոփոխել մասնակի'),
(56836, 6538, 14, 'Տվյալներ, որ բժիշկները  կարող են միայն կարդալ'),
(56837, 6539, 14, 'Տվյալներ, որ բժիշկները կարող են  կարդալ, մուտքագրել, բայց չփոփոխել'),
(56838, 6540, 14, 'Տվյալներ, որ բժիշկները կարող են  կարդալ և փոփոխել'),
(56839, 6541, 14, 'Տվյալներ, որ բժիշկները կարող են  կարդալ և փոփոխել մասնակի'),
(56840, 6542, 14, 'Երրորդ'),
(56841, 6544, 14, 'Տվյալ գործողությունը ՀՆԱՐԱՎՈՐ ՉԷ չեղարկել/հետադարձել'),
(56842, 6545, 14, 'Տվյալ գործողությունը հնարավոր չէ չեղարկել/հետադարձել'),
(56843, 6547, 14, 'Տվյալ գործողությունը կգրանցվի համակարգում'),
(56844, 6549, 14, 'Այցելությունների ավտոմատացումը կիրառված է։ Կրկի՞ն կիրառել'),
(56845, 6550, 14, 'Այցելությունների ավտոմատացումն անհասանելի է․ փորձեք մեկ ուրիշը'),
(56846, 6551, 14, 'Այս օրացույցային տարին'),
(56847, 6552, 14, 'Այս պահանջը հանված/չեղարկված է'),
(56848, 6553, 14, 'Այս պահանջը փակված է'),
(56849, 6554, 14, 'Պահանջը մերժված է․ պատճառը։ -'),
(56850, 6555, 14, 'Պահանջն ուղարկված է հաջորդ մակարդակ'),
(56851, 6557, 14, 'Այս կոնտեքստում առկա են կատեգորիաներ, որոնք կարող են ջնջվել։ Ցանկանո՞ւմ եք շարունակել'),
(56852, 6558, 14, 'Սրանով վորոշվում է այցերի էկրանավորման ձևը'),
(56853, 6559, 14, 'Սրանով վորոշվում է այցերի գունային սխեմայի կիրառումը'),
(56854, 6561, 14, 'Սույն այցը'),
(56855, 6562, 14, 'Այս այցը հաշվեգրված է․ եթե ցանկանում եք փոփոխել, ապա պետք է նորից բացեք այն'),
(56856, 6563, 14, 'Այս այցը արգելափակված է։ Ոչ մի նոր ձև հնարավոր չէ ավելացնել'),
(56857, 6564, 14, 'Այս առանձնահատկությունը/բաղադրիչը դեռևս հասանելի չէ'),
(56858, 6565, 14, 'Այս առանձնահատկությունը/բաղադրիչը փորձարարական է և չի ամբողջությամբ չի փորձարկվել։ Կիրառեք այն ռիսկի համաձայն'),
(56859, 6566, 14, 'Այս հաշիվ-ապրանքագրի համարը փոխարինվել է -ով '),
(56860, 6573, 14, 'Այս տեքստային հաղորդագրությունն ավտոմատ չի պահպանվել։ Կրկնօրինակեք այն և պահպանեք որպես կոնտեքստի/ենթատեքստի/համատեքստի համապատասխան մաս'),
(56861, 6574, 14, 'Այս մոդուլն այժմ կիրառվում է -ի կողմից '),
(56862, 6575, 14, 'Այս մոդուլն այժմ փորձարկվում է։ Տվյալների բազան չի կարող փոփոխվել'),
(56863, 6576, 14, 'Այս մոդուլը նպաստում է EOB տվյալների արդյունավետ մուտքագրմանը'),
(56864, 6577, 14, 'Այս ամիս մինչ օրս'),
(56865, 6578, 14, 'Հրամանն արդեն ուղարկվել/փոխանցվել/հաղորդվել է դեպի'),
(56866, 6579, 14, 'Այս էջը հնարավորություն է ընձեռում վերանայել աջակցվող   յուրաքանչյուր արտաքին տվյալի բեռնումը, որը հնարավոր է տեղադրել կամ թարմացնել։ Each section below can be expanded by clicking on the section header to review the status of the particular database of interest.'),
(56867, 6580, 14, 'Անվտանգության նկատառումներից ելնելով էջն ապաակտիվացվել է'),
(56868, 6581, 14, 'Այս էջը կներառի նաև մինջակյալ մուտքի էջ, որպեսզի ամեն անգամ չսեղմեք "կրկին մուտք գործել"'),
(56869, 6582, 14, 'Այս պացիենտի էջում գործողություններ չկան'),
(56870, 6583, 14, 'Պացիենտի ID-ն արդեն գործածվում է/գործածության մեջ է'),
(56871, 6584, 14, 'Այս ապրանքը յուրաքանչյուր պահեստում թույլատրում է միայն մեկ խմբաքանակ'),
(56872, 6585, 14, 'Այս արձանագրությունը չի իրականացվել/կյանքի չի կոչվել'),
(56873, 6586, 14, 'Այս զեկույցը/հաշվետվությունն աշխատում է միայն ICD9  կոդերի համար'),
(56874, 6589, 14, 'Սրանով սահմանվում/ճշտում է, թե արդյոք պետք է ամսաթիվ ներառվի 31 վանդակում'),
(56875, 6591, 14, 'Այս քայլով կստեղծվի նոր ֆայլ, որն անհրաժեշտ է պահպանել հետագա կիրառման համար։ Այն հետագայում չի վերստեղծվելու։ Գործարկե՞լ այն։'),
(56876, 6592, 14, 'Այս օգտատերը չի հանդիսանում ոչ մի խմբի անդամ'),
(56877, 6593, 14, 'Այս օգտատերը անձնական նամակների վերաբերյալ ծանուցումներ կստանա'),
(56878, 6594, 14, 'Սա փորձնական սպասարկող ծրագիր է․ Կրկնօրինակեք ձեր տվյալներն ու փաստաթղթերը նախքան վերջինիս կիրառումը։'),
(56879, 6595, 14, 'Այս այցով սկսվում է նոր հակաբեղմնավորիչների կիրառմամբ'),
(56880, 6596, 14, 'Այս այցի համար անհրաժեշտ է GCAC ձև, ուղեգիր կամ միջամտություն'),
(56881, 6597, 14, 'Դա ընդամենը հին մետրիկ կենսաչափական որոշիչների ձև էր, որն այժմ համարվում է անընդունելի'),
(56882, 6598, 14, 'Այս շաբաթ մինչ օրս'),
(56883, 6600, 14, 'Այն կակտիվացնի ԽՇԳ (Խնամքի Շարունակական Գրառման) և ՇԽՓ (Շարունակական  Խնամքի Փաստաթղթերի) զեկուցումը'),
(56884, 6602, 14, 'Թույլ կտա կատարել կարգաբերող ( ''կեղծ '') լեզվի  ընտրություն'),
(56885, 6606, 14, 'Սա կստեղծի tar ֆորմատի կրկնօրինակ և կուղարկի ձեր բրոուզեր, որպեսզի կարողանա պահպանել այն։'),
(56886, 6607, 14, 'Փաստաթղթի կոդավորման և ապակոդավորման հնարավորությունները կարգելափակվեն և կթաքցվեն օգտվողի ինտերֆեյսում'),
(56887, 6608, 14, 'Սա կանջատի բոլոր այն ձևերի "Խմբագրել" կոճակը, որոնցում առաջին/գլխավոր այցելության վրա առկա է էլ․ ստորագրություն'),
(56888, 6609, 14, 'Սա կանջատի  էլ․ ստորագրությամբ ստորագրված ցանկացած  ձևի "Խմբագրել" կոճակը'),
(56889, 6611, 14, 'Ի տարբերություն անհատական/առանձին ձևերի՝ սա թույլ կտա ստորագրել ողջ այցելությունը'),
(56890, 6612, 14, 'Սա թույլ կտա առանձին ստորագրել  անհատական/տարբեր ձևերը'),
(56891, 6614, 14, 'Սա օգտվողին կտրամադրի արգելափակման տարբերակներ (առանձին արգելափակում  և ստորագրում)'),
(56892, 6615, 14, 'Սա հիվանդի զեկույցում կթաքցնի դատարկ էլ․ ստորագրության մուտքերը'),
(56893, 6616, 14, 'Իրար է միացնում  երկու պացիենտի քարտերը։ Սա օգտակար է հատկապես երբ սխալմամբ կրկնօրինակվել է պացիենտի տվյալները։ Եթե դա հաճախ է պատահում, ապա կարգավորեք գրասենյակային միջամտությունները՝ այդ ֆունկցիան հաճախ կիրառելու փոխարեն'),
(56894, 6617, 14, 'Սա չի խոնգարում էլ-դեղատոմսերի կայք անցնելուն'),
(56895, 6619, 14, 'Սա կկիրառի  ոչ թե ստանդարտ CVX, այլ   օգտվողի կողմից խմբագրվող պատվաստումների ցանկը,'),
(56896, 6622, 14, 'Ողնաշարի կրծքային հատված'),
(56897, 6623, 14, 'Հազ/Խոր․մմ'),
(56898, 6625, 14, 'Կոկորդ'),
(56899, 6626, 14, 'Կոկորդի քաղցկեղ'),
(56900, 6627, 14, 'Կոկորդի քաղցկեղի վիրահատություն'),
(56901, 6628, 14, 'Թրոմբոզ / ինսուլտ'),
(56902, 6629, 14, 'Չրք․'),
(56903, 6630, 14, 'Չորեքշաբթի'),
(56904, 6631, 14, 'Չորեքշաբթի'),
(56905, 6632, 14, 'Նորմալ վահանաձև գեղձ'),
(56906, 6633, 14, 'Վահանագեղձի խնդիրներ'),
(56907, 6634, 14, 'TIA'),
(56908, 6635, 14, 'Tibetan Standard, Tibetan, Central'),
(56909, 6636, 14, 'TID'),
(56910, 6637, 14, 'Tigrinya'),
(56911, 6638, 14, 'Ժամանակ'),
(56912, 6639, 14, 'Ժամի էկրանավորման ֆորմատ'),
(56913, 6640, 14, 'Ժամանակի  ավելացում (1-60 րոպե)'),
(56914, 6641, 14, 'Ժամանակի ընտրություն'),
(56915, 6647, 14, 'Ժամանակավորված միջոցառում'),
(56916, 6651, 14, 'Ականջներում զնգոց'),
(56917, 6652, 14, 'Անվանում'),
(56918, 6653, 14, 'Անվանում V'),
(56919, 6654, 14, 'Անվանման սյուները պետք է լինեն 1-999 թվերի միջակայքում'),
(56920, 6655, 14, 'Վերնագրեր/Անվանումներ'),
(56921, 6656, 14, 'TM''S:'),
(56922, 6657, 14, 'Արտաքին քիթ TMs/EAMs/EE'),
(56923, 6658, 14, 'մինչ/դեպի'),
(56924, 6659, 14, 'ՄԻՆՉ/ԴԵՊԻ'),
(56925, 6660, 14, 'մինչ/դեպի'),
(56926, 6661, 14, 'ֆայլի բացարձակ ուղի'),
(56927, 6662, 14, 'սեղմել նշումներ ավելացնելու համար '),
(56928, 6663, 14, 'նշումներ ավելացնելու համար սեղմել այստեղ'),
(56929, 6664, 14, 'վնասված/ախտահարված մասում'),
(56930, 6665, 14, 'վնասված/ախտահարված մասում'),
(56931, 6668, 14, 'կատեգորիային կատեգորիայում'),
(56932, 6669, 14, 'Կլինիկական հետազոտման'),
(56933, 6670, 14, 'Հավելավճարին'),
(56934, 6671, 14, 'ավարտի ամսաթիվը պետք է ավելի մեծ լինի, քա մեկնարկի ամսաթիվը'),
(56935, 6672, 14, 'В ded''ble'),
(56936, 6679, 14, 'Այցին'),
(56937, 6680, 14, 'ֆիլտրել ըստ սեռի'),
(56938, 6681, 14, 'Անամնեզին'),
(56939, 6682, 14, 'Խնդիրներին'),
(56940, 6683, 14, 'Այս այցը/խորհրդատվությունը առկա խնդրին կապելու/հղելու համար սեղմել '),
(56941, 6684, 14, 'Այս այցը/խորհրդատվությունը առկա խնդրին կապելու/հղելու համար սեղմել վերոնշյալ ցանկացած խնդրի վրա, որպեսզի այն ընդգծվի, ապա սեղմել [պահպանել]: Տարբեր խնդիրներ ընտրելու համար սեղմած պահել [Ctrl] կոճակը'),
(56942, 6685, 14, 'կրկին/նորից մուտք գործել'),
(56943, 6686, 14, 'Նոր բացահայտումների գրանցման համար սեղմել'),
(56944, 6687, 14, 'գործարկել/գործարկման համար'),
(56945, 6689, 14, 'Մաշկին'),
(56946, 6690, 14, 'մաշկին'),
(56947, 6691, 14, 'ա՞յս այցին'),
(56948, 6692, 14, 'Առկա պացիենտին CCR փաստաթուղթ կցելու համար կիրառեք Պացիենտի Ամփոփ Տեղեկագիրը'),
(56949, 6693, 14, 'մինչ։'),
(56950, 6694, 14, 'մինչ։ '),
(56951, 6695, 14, 'ՔԱՂԱՔ'),
(56952, 6696, 14, 'ՖԱՔՍ'),
(56953, 6697, 14, 'ԱՆՈՒՆ'),
(56954, 6698, 14, 'ԱԶԳԱՆՈՒՆ'),
(56955, 6699, 14, 'ՀԱՅՐԱՆՈՒՆ'),
(56956, 6700, 14, 'ԿԱԶՄԱԿԵՐՊՈՒԹՅՈՒՆ'),
(56957, 6701, 14, 'ՀԵՌԱԽՈՍ'),
(56958, 6702, 14, 'ԲՋՋԱՅԻՆ ՀԵՌԱԽՈՍ'),
(56959, 6703, 14, 'ՓՈՍՏԱՅԻՆ ԻՆԴԵՔՍ'),
(56960, 6704, 14, 'ՆԱՀԱՆԳ/ՄԱՐԶ'),
(56961, 6705, 14, 'ՓՈՂՈՑ'),
(56962, 6706, 14, 'ԱՆՎԱՆՈՒՄ'),
(56963, 6707, 14, 'ՎԵՐՋՆԱԳԻՐ/ՓԱԿՄԱՆ ԽՈՍՔ'),
(56964, 6708, 14, 'Ծխախոտ'),
(56965, 6709, 14, 'Ծխելու դադարեցման միջամտություն'),
(56966, 6710, 14, 'Ծխելու դադարեցման միջամտություն (CQM)'),
(56967, 6711, 14, 'Ծխախոտի կիրառում'),
(56968, 6712, 14, 'Ծխախոտի կիրառում'),
(56969, 6713, 14, 'Ծխախոտի կիրառման գնահատական'),
(56970, 6714, 14, 'Ծխախոտի կիրառման գնահատական  (CQM)'),
(56971, 6715, 14, 'Այսօր'),
(56972, 6716, 14, 'ԱՅՍՕՐ'),
(56973, 6717, 14, 'այսօր'),
(56974, 6718, 14, 'Այսօրվա մնացորդը'),
(56975, 6719, 14, 'Այսօրվա վճարումները'),
(56976, 6720, 14, 'Այսօրվա ամսաթիվը'),
(56977, 6721, 14, 'Այսօրվա իրադարձությունները'),
(56978, 6726, 14, 'Տոնզիլեկտոմիա /նշագեղձերի վիրահատական հեռացում'),
(56979, 6727, 14, 'տոնզիլեկտոմիա /նշագեղձերի վիրահատական հեռացում'),
(56980, 6728, 14, 'Վերև'),
(56981, 6729, 14, 'Վերին լուսանցք'),
(56982, 6730, 14, 'Թեմա'),
(56983, 6731, 14, 'Ընդհանուր/Ընդամենը'),
(56984, 6732, 14, 'ընդհանուր/ընդամենը'),
(56985, 6733, 14, 'Ընդամենը ակտիվ գործողություններ'),
(56986, 6734, 14, 'Ընդհանուր ակտիվ հիշեցումներ թԹարմացումից հետո'),
(56987, 6735, 14, 'Ընդհանուր ակտիվ հիշեցումներ թարմացումից առաջ'),
(56988, 6737, 14, 'Վճարման ենթակա ընդհանուր գումարը'),
(56989, 6738, 14, 'Ընդամենը վճարված է'),
(56990, 6739, 14, 'Ընդհանուր մնացորդը'),
(56991, 6740, 14, 'Ընդհանուր գանձում'),
(56992, 6741, 14, 'Ընդհանուր վճարներ'),
(56993, 6742, 14, 'Հաճախորդների ընդհանուր քանակ'),
(56994, 6743, 14, 'Ընդհանուր արժեքը'),
(56995, 6744, 14, 'Հերթական համարի ընդհանուր բաշխումը լիարժեք չէ'),
(56996, 6745, 14, 'Ընդհանուր մուտքեր'),
(56997, 6746, 14, 'էլ․փոստով ուղարկվող ձախողված հիշեցումների ընդհանուր քանակը'),
(56998, 6747, 14, 'Հեռախոսով ուղարկվող ձախողված հիշեցումների ընդհանուր քանակը'),
(56999, 6748, 14, 'Ընդամենը -ի համար'),
(57000, 6749, 14, 'Ընդամենը -ի համար '),
(57001, 6750, 14, 'Ընդամենը կատեգորիայի համար'),
(57002, 6751, 14, 'Ընդամենը ապակտիվացարած հիշեցումներ'),
(57003, 6752, 14, 'Ընդամենը նոր հիշեցումներ'),
(57004, 6753, 14, 'Հանդիպումների/նշանակված այցերի ընդհանուր քանակը'),
(57005, 6755, 14, 'Պատվաստումների ընդհանուր քանակը'),
(57006, 6756, 14, 'Արդյունքների ընդհանուր քանակը'),
(57007, 6758, 14, 'Պացիենտների ընդհանուր քանակը'),
(57008, 6760, 14, 'Պացիենտների ընդհանուր հաշվեկշիռը'),
(57009, 6761, 14, 'Ընդամենը պացիենտ'),
(57010, 6764, 14, 'Գտնված գրանցումների ընդհանուր քանակը'),
(57011, 6766, 14, 'Էլ․փոստով հաջողությամբ ուղակված հիշեցումների ընդհանուր քանակը'),
(57012, 6767, 14, 'Հեռախոսով  հաջողությամբ ուղակված հիշեցումների ընդհանուր քանակը'),
(57013, 6770, 14, 'Չփոփոխված  հիշեցումների ընդհանուր քանակը'),
(57014, 6771, 14, 'Ուղարկում հրամանից հետո չուղարկված  հիշեցումների ընդհանուր քանակը'),
(57015, 6772, 14, 'Թարմացումից հետո չուղարկված  հիշեցումների ընդհանուր քանակը'),
(57016, 6773, 14, 'Ուղարկում հրամանից առաջ չուղարկված  հիշեցումների ընդհանուր քանակը'),
(57017, 6774, 14, 'Թարմացումից առաջ չուղարկված  հիշեցումների ընդհանուր քանակը'),
(57018, 6775, 14, 'Թարմացված  հիշեցումների ընդհանուր քանակը'),
(57019, 6776, 14, 'Ընդհանուր քանակներ'),
(57020, 6777, 14, '-ի ընդհանուր քանակներ'),
(57021, 6778, 14, '-ի ընդհանուր քանակներ '),
(57022, 6785, 14, 'Ուսուցման ձևը'),
(57023, 1, 16, 'A'),
(57024, 2, 16, 'Nomor cek atau nomor klaim untuk identifikasi pembayaran'),
(57025, 3, 16, 'Surat keterangan pelanggan untuk pengguna admin'),
(57026, 4, 16, 'Dokumen klinik sudah dilampirkan'),
(57027, 5, 16, 'Dokumen klinik sudah dilampirkan'),
(57028, 7, 16, 'Penyalur dibutuhkan'),
(57029, 8, 16, 'Formulir kunjungan CGAC harus ditambahkan pada kunjungan ini'),
(57030, 9, 16, 'Angka perlu lebih banyak lagi'),
(57031, 10, 16, 'Angka perlu lebih banyak lagi!'),
(57032, 11, 16, 'Huruf kecil'),
(57033, 12, 16, 'Angka'),
(57034, 14, 16, 'Pasien dengan ID tersebut telah terdaftar'),
(57035, 15, 16, 'Pasien dengan Nama tersebut telah terdaftar'),
(57036, 16, 16, 'Pasien dengan SS tersebut telah terdaftar'),
(57037, 19, 16, 'Sumber rujukan harus ditentukan pada tiap kunjungan'),
(57038, 20, 16, 'Diperlukan kode yang berhubungan dengan IPPF!'),
(57039, 21, 16, 'Karakter khusus'),
(57040, 22, 16, 'Nilai yang unik untuk mengidentifikasi bagian ini, tidak terlihat ke pengguna'),
(57041, 23, 16, 'Jadwal kunjungan sudah tersedia untuk pasien ini hari ini. Klik Cancel untuk membuka jadwal tersebut, atau OK untuk memproses pembuatan jadwal baru'),
(57042, 24, 16, 'Sebelum makan'),
(57043, 25, 16, 'Pagi Hari'),
(57044, 26, 16, 'A/F Level Kanan'),
(57045, 27, 16, 'AB'),
(57046, 28, 16, 'Kependekan'),
(57047, 29, 16, 'Abses'),
(57048, 30, 16, 'Perut'),
(57049, 31, 16, 'Mampu Berjalan empat (4) langkah:'),
(57050, 32, 16, 'Abn'),
(57051, 33, 16, 'ABN1'),
(57052, 34, 16, 'Abnormal'),
(57053, 35, 16, 'Tes Darah Abnormal'),
(57054, 36, 16, 'Pertumbuhan Rambut Abnormal'),
(57055, 37, 16, 'Mammogram Abnormal'),
(57056, 39, 16, 'Aborsi'),
(57057, 40, 16, 'Isu Aborsi'),
(57058, 41, 16, 'Metode Aborsi'),
(57059, 42, 16, 'Kategori-Berhubungan dengan Aborsi'),
(57060, 43, 16, 'Aborsi'),
(57061, 44, 16, 'Mengenai kalendar'),
(57062, 46, 16, 'Absen oleh Diagnosis'),
(57063, 47, 16, 'Terima Penugasan'),
(57064, 48, 16, 'Terima Pembayaran untuk'),
(57065, 49, 16, 'Terima Pembayaran untuk '),
(57066, 50, 16, 'Terima Penugasan'),
(57067, 51, 16, 'Kontrol Akses'),
(57068, 52, 16, 'Daftar Administrasi Kontrol Akses'),
(57069, 53, 16, 'Tanggal mengakses'),
(57070, 54, 16, 'Akses tidak diperkenankan'),
(57071, 55, 16, 'Akses tidak sah'),
(57072, 56, 16, 'Silahkan akses portal pasien anda'),
(57073, 57, 16, 'Kecelakaan'),
(57074, 59, 16, 'Nama Akun'),
(57075, 62, 16, 'Akuntansi'),
(57076, 64, 16, 'Sakit'),
(57077, 65, 16, 'Permintaan Pernyataan (ISA14)'),
(57078, 66, 16, 'Pernyataan, Lisensi dan Sertifikasi'),
(57079, 67, 16, 'ACL'),
(57080, 68, 16, 'Administrasi ACL'),
(57081, 69, 16, 'Administrasi ACL Tidak Diizinkan'),
(57082, 70, 16, 'ACL sudah sukses di update'),
(57083, 71, 16, 'Jerawat'),
(57084, 72, 16, 'Tindakan'),
(57085, 73, 16, 'Tanggal tindakan'),
(57086, 74, 16, 'Tindakan'),
(57087, 75, 16, 'Tindakan'),
(57088, 77, 16, 'Aktifkan Pelaporan CCR/CCD'),
(57089, 78, 16, 'Aktif'),
(57090, 79, 16, 'Pemberitahuan Aktif'),
(57091, 80, 16, 'Peraturan Pemberitahuan Aktif'),
(57092, 81, 16, 'Pemberitahuan/Pengingat Aktif'),
(57093, 82, 16, 'Konsultasi Hari Ini'),
(57094, 84, 16, 'Daftar Aktif'),
(57095, 85, 16, 'Pasien Aktif'),
(57096, 86, 16, 'Rencana Aktif'),
(57097, 87, 16, 'Kegiatan'),
(57098, 88, 16, 'Tipe Kegiatan'),
(57099, 92, 16, 'Akut Kronis'),
(57100, 93, 16, 'tambah'),
(57101, 94, 16, 'Tambah'),
(57102, 95, 16, 'TAMBAH'),
(57103, 96, 16, 'Tambah Perusahaan'),
(57104, 98, 16, 'Tambah Apotek'),
(57105, 100, 16, 'tambah kegiatan untuk '),
(57106, 101, 16, 'Tambah sebagai catatan baru'),
(57107, 102, 16, 'Tambah Baru'),
(57108, 104, 16, 'Tambah Tombol'),
(57109, 105, 16, 'Tambah Tombol untuk Karakter Spesial, Teks untuk ditampilkan pada bagian editor paling atas untuk pencantuman pada teks gunakan Klik'),
(57110, 106, 16, 'Tambah Kategori'),
(57111, 107, 16, 'Tambah Konstanta'),
(57112, 108, 16, 'Tambah Konteks'),
(57113, 109, 16, 'Tambah Asuransi'),
(57114, 110, 16, 'Tambah kriteria'),
(57115, 111, 16, 'Tambah Tombol Custom'),
(57116, 112, 16, 'Tambah Diagnosa'),
(57117, 113, 16, 'Tambah Obat'),
(57118, 114, 16, 'Tambah Konsultasi'),
(57119, 115, 16, 'Tambah konsultasi/catatan'),
(57120, 116, 16, 'Tambah Fasilitas'),
(57121, 117, 16, 'Tambah Kotak'),
(57122, 118, 16, 'Tambahkan baris berikut ini pada file konfigurasi Apache'),
(57123, 119, 16, 'Tambah Grup'),
(57124, 120, 16, 'Tambah Kode ICD'),
(57125, 121, 16, 'Tambah Imunisasi'),
(57126, 122, 16, 'Penambahan tidak diizinkan!'),
(57127, 123, 16, 'Tambah Isu'),
(57128, 124, 16, 'Tambahkan item ke jalur'),
(57129, 125, 16, 'Tambah Bahasa'),
(57130, 126, 16, 'Tambah Baru'),
(57131, 127, 16, 'Tambah baru'),
(57132, 128, 16, 'Tambah kategori baru : '),
(57133, 129, 16, 'Tambah sertifikat baru pada file konfigurasi Apache'),
(57134, 130, 16, 'Tambah komponen baru'),
(57135, 131, 16, 'Tambah beberapa komponen baru'),
(57136, 132, 16, 'Tambah Grup Baru'),
(57137, 133, 16, 'Tambah hal baru'),
(57138, 134, 16, 'Tambah kumpulan baru dan transaksi'),
(57139, 135, 16, 'Tambah Catatan Baru'),
(57140, 136, 16, 'Tambah catatan baru'),
(57141, 137, 16, 'Tambah Mitra Baru'),
(57142, 138, 16, 'Tambah Pasien Baru'),
(57143, 140, 16, 'Tambah Catatan'),
(57144, 141, 16, 'Tambah Catatan Medis Pasien'),
(57145, 142, 16, 'Tambah Resep'),
(57146, 143, 16, 'Tambah Prosedur'),
(57147, 144, 16, 'Tambah Nomor Penyedia'),
(57148, 145, 16, 'Tambah Rehabilitasi'),
(57149, 146, 16, 'Tambah Aturan'),
(57150, 147, 16, 'Tambahkan ke'),
(57151, 148, 16, 'Tambahkan ke Daftar Obat'),
(57152, 149, 16, 'Tambah Level Teratas'),
(57153, 150, 16, 'Tambah Transaksi'),
(57154, 151, 16, 'Tambah Pengguna'),
(57155, 152, 16, 'Tambah Pengguna Pada Grup'),
(57156, 153, 16, 'Tambah/Edit eRx'),
(57157, 154, 16, 'Tambah/Edit Transaksi Pasien'),
(57158, 155, 16, 'menambahkan'),
(57159, 156, 16, 'Penambahan demografis tidak diizinkan.'),
(57160, 158, 16, 'Sindroma Addison'),
(57161, 159, 16, 'Sindroma Addison'),
(57162, 160, 16, 'Atribut Tambahan'),
(57163, 161, 16, 'Diagnosis Tambahan:'),
(57164, 162, 16, 'Riwayat Sakit Tambahan'),
(57165, 163, 16, 'Catatan riwayat sakit tambahan'),
(57166, 164, 16, 'Info Tambahan'),
(57167, 165, 16, 'Laboratorium Tambahan'),
(57168, 166, 16, 'Catatan Tambahan'),
(57169, 168, 16, 'Catatan Tambahan:'),
(57170, 169, 16, 'Catatan Tambahan: '),
(57171, 170, 16, 'Tambahan Catatan X-RAY:'),
(57172, 172, 16, 'hanya menambahkan'),
(57173, 173, 16, 'Buku Alamat'),
(57174, 174, 16, 'Buku Alamat'),
(57175, 175, 16, 'Alamat'),
(57176, 178, 16, 'Buku Alamat'),
(57177, 179, 16, 'Entri buku alamat untuk perusahaan yang melaksanakan prosedur ini'),
(57178, 180, 16, 'Entri buku alamat untuk distributor'),
(57179, 181, 16, 'Entri buku alamat untuk vendor'),
(57180, 182, 16, 'Tipe Buku Alamat'),
(57181, 183, 16, 'Label Alamat'),
(57182, 187, 16, 'Alamat 1'),
(57183, 188, 16, 'Alamat 2'),
(57184, 189, 16, 'ALAMAT'),
(57185, 190, 16, 'Menyesuaikan'),
(57186, 191, 16, 'Jumlah Penyesuaian'),
(57187, 192, 16, 'Menyesuaikan'),
(57188, 193, 16, 'Penyesuaian'),
(57189, 194, 16, 'Penyesuaian Nilai'),
(57190, 195, 16, 'Alasan Penyesuaian'),
(57191, 196, 16, 'Nilai Penyesuaian untuk kode '),
(57192, 197, 16, 'Penyesuaian'),
(57193, 198, 16, 'Adm menyesuaikan'),
(57194, 199, 16, 'Admin'),
(57195, 200, 16, 'Alamat Email Admin'),
(57196, 201, 16, 'Administrasi Melalui'),
(57197, 202, 16, 'Diberikan'),
(57198, 203, 16, 'Dimasukan Oleh'),
(57199, 206, 16, 'Administrasi'),
(57200, 208, 16, 'Administrator'),
(57201, 209, 16, 'Administrator dapat melakukan apa saja'),
(57202, 212, 16, 'Penyaringan Berat Sampai Umur dan Tindak Lanjut'),
(57203, 213, 16, 'Penyaringan Berat Sampai Umur dan Tindak Lanjut (CQM)'),
(57204, 214, 16, 'Petunjuk Lanjutan'),
(57205, 215, 16, 'Petunjuk-petunjuk lanjutan'),
(57206, 216, 16, 'Tanda Pemberitahuan Petunjuk Lanjutan'),
(57207, 218, 16, 'Lebih Lanjut'),
(57208, 219, 16, 'Saran'),
(57209, 221, 16, 'Mempengaruhi normal'),
(57210, 223, 16, 'Panggilan Diluar jam kerja'),
(57211, 225, 16, 'Setelah melakukan pengaturan diatas, impor sertifikat/surat keterangan klien admin ke browser kemudian restart server Apache (password kosong)'),
(57212, 226, 16, 'Setelah menyimpan file PDF, klik [Lihat Log] untuk memeriksa kesalahan.'),
(57213, 227, 16, 'Setelah menyimpan file TEXT, klik [Lihat Log] untuk memeriksa kesalahan.'),
(57214, 228, 16, 'Setelah menyimpan batch, klik [Lihat Log] untuk memeriksa kesalahan.'),
(57215, 230, 16, 'Setelah memasukkan informasi dengan benar, tekan tombol Simpan.'),
(57216, 233, 16, 'Lagi'),
(57217, 234, 16, 'Usia'),
(57218, 235, 16, 'Usia Berdasarkan'),
(57219, 236, 16, 'Kategori usia'),
(57220, 237, 16, 'Data di luar jangkauan.'),
(57221, 239, 16, 'Format Umur Untuk "dari umur" tidak berlaku'),
(57222, 240, 16, 'Format umur untuk "sampai umur" tidak berlaku'),
(57223, 241, 16, 'Dari Umur'),
(57224, 243, 16, 'Umur maksimal'),
(57225, 244, 16, 'Umur minimal'),
(57226, 245, 16, 'Rentang Umur'),
(57227, 247, 16, 'Kolom Usia:'),
(57228, 249, 16, 'Albania'),
(57229, 250, 16, 'Alkohol'),
(57230, 251, 16, 'Konsumsi alkohol'),
(57231, 253, 16, 'Jumlah Tanda Pemberitahuan'),
(57232, 255, 16, 'Tanda Pemberitahuan'),
(57233, 258, 16, 'ALEUT'),
(57234, 259, 16, 'Semua'),
(57235, 260, 16, 'SEMUA'),
(57236, 261, 16, 'Semua (Disusun Format A)'),
(57237, 262, 16, 'Semua (Disusun Format B)'),
(57238, 263, 16, 'Semua (Kumulatif)'),
(57239, 266, 16, 'Semua Kategori'),
(57240, 268, 16, 'Semua Kode'),
(57241, 269, 16, 'Semua Hari'),
(57242, 270, 16, 'Semua acara hari'),
(57243, 271, 16, 'Semua bidang demografis, dengan pencarian dan duplikasi pemeriksaaan'),
(57244, 272, 16, 'Semua Fasilitas'),
(57245, 273, 16, 'Semua Luka/Masalah'),
(57246, 274, 16, 'Semua Bahasa Diijinkan'),
(57247, 276, 16, 'Semua atau bagian dari nama depan'),
(57248, 277, 16, 'Semua atau bagian dari nama belakang'),
(57249, 278, 16, 'Semua atau bagian dari organisasi'),
(57250, 280, 16, 'Semua Produk'),
(57251, 281, 16, 'Semua Penyedia'),
(57252, 282, 16, 'Semua Diulas dan Negatif:'),
(57253, 283, 16, 'Semua Topik'),
(57254, 284, 16, 'Semua Pengguna'),
(57255, 285, 16, 'Alergi'),
(57256, 286, 16, 'Alergi'),
(57257, 287, 16, 'Alergi:'),
(57258, 288, 16, 'Alergi'),
(57259, 289, 16, 'Impor Alergi selesai dengan sukses'),
(57260, 291, 16, 'Reaksi akibat Alergi'),
(57261, 294, 16, 'Mengalokasikan'),
(57262, 295, 16, 'Mengizinkan'),
(57263, 296, 16, 'Semua bahasa yang tersedia bisa digunakan sebagai pilihan pada menu di bagian Login'),
(57264, 297, 16, 'Mengizinkan pembuatan klaim yang berisi diagnosa namun bukan prosedur atau biaya. Sebagian besar klinik tidak menginginkannya.'),
(57265, 298, 16, 'Izinkan Debugging Bahasa'),
(57266, 299, 16, 'Izinkan Email'),
(57267, 300, 16, 'Izinkan pesan melalui email?'),
(57268, 301, 16, 'Izinkan Email?'),
(57269, 302, 16, 'Izinkan Klaim Konsultasi'),
(57270, 303, 16, 'Izinkan Pertukaran Informasi Kesehatan'),
(57271, 304, 16, 'Izinkan Pertukaran Informasi Imunisasi'),
(57272, 305, 16, 'Izinkan Penggunaan Informasi Imunisasi'),
(57273, 306, 16, 'Izinkan Pesan Email'),
(57274, 308, 16, 'Izinkan Portal Pasien'),
(57275, 309, 16, 'Izinkan SMS'),
(57276, 310, 16, 'Izinkan Pesan Singkat (SMS)?'),
(57277, 311, 16, 'Izinkan pembuatan peristiwa yang akan dibuat aktif segera?'),
(57278, 312, 16, 'Izinkan pesan di telepon?'),
(57279, 313, 16, 'Izinkan pengguna untuk mempublikasikan Kegiatan Global'),
(57280, 314, 16, 'Izinkan pengguna untuk mempublikasikan Kalender Pribadi'),
(57281, 315, 16, 'Izinkan Pesan suara'),
(57282, 316, 16, 'Diizinkan'),
(57283, 317, 16, 'Bahasa yang diizinkan'),
(57284, 318, 16, 'Diizinkan(c)'),
(57285, 323, 16, 'sudah ada.'),
(57286, 324, 16, 'sudah ada.'),
(57287, 325, 16, 'Telah digunakan, pilih identitas lain'),
(57288, 326, 16, 'Telah digunakan, pilih gelar lain'),
(57289, 327, 16, 'Alamat Lain'),
(57290, 328, 16, 'sisipkan'),
(57291, 329, 16, 'Sebagai alternatif, Anda dapat menggunakan halaman pencarian untuk mengupload sebuah uang elektronik (X12 835) file yang telah diperoleh dari pembayar atau clearinghouse. Anda dapat melakukannya dengan mengklik tombol Browse dan memilih file untuk di-upload, kemudian klik Cari untuk melakukan upload dan menampilkan tagihan yang sesuai. Dalam hal ini parameter yang lain yang disebutkan di atas tidak berlaku dan akan diabaikan. Mengupload menyimpan file tetapi belum memproses isinya - yang dilakukan secara terpisah seperti yang dijelaskan di bawah ini.'),
(57292, 330, 16, 'AM'),
(57293, 331, 16, 'Program AM'),
(57294, 332, 16, 'AMC'),
(57295, 333, 16, 'Pelacakan AMC'),
(57296, 338, 16, 'Mengubah Catatan yang Ada'),
(57297, 343, 16, 'Indian Amerika'),
(57298, 344, 16, 'Indian Amerika atau Alaska Asli'),
(57299, 345, 16, 'AMEX'),
(57300, 346, 16, 'Amharik'),
(57301, 347, 16, 'Jumlah'),
(57302, 349, 16, 'Jumlah Biaya'),
(57303, 350, 16, 'Jumlah Saldo Akhir'),
(57304, 351, 16, 'Jumlah Kunjungan Ini'),
(57305, 352, 16, 'Jumlah Dibayar'),
(57306, 353, 16, 'Jumlah:'),
(57307, 354, 16, 'Jml Tagihan'),
(57308, 355, 16, 'Batas waktu akhir diperlukan untuk kegiatan berulang!'),
(57309, 357, 16, 'Terjadi masalah saat membuka susunan direktori web LibreEHR'),
(57310, 358, 16, 'Terjadi masalah saat membuka susunan direktori phpGACL'),
(57311, 359, 16, 'Terjadi masalah saat membuka susunan direktori SQL-Ledger'),
(57312, 360, 16, 'Isu GCAC yang tidak lengkap telah dibuat dan terhubung. Perlu seseorang untuk menyempurnakannya kemudian.'),
(57313, 362, 16, 'Masalah tak terduga telah terjadi'),
(57314, 363, 16, 'Huruf besar'),
(57315, 365, 16, 'Dan'),
(57316, 366, 16, 'DAN'),
(57317, 367, 16, 'dan'),
(57318, 368, 16, 'dan '),
(57319, 369, 16, 'Dan semua data subordinat? Tindakan ini akan dicatat'),
(57320, 370, 16, 'dan pengubah'),
(57321, 371, 16, 'dan diproses.'),
(57322, 372, 16, 'dan restart Apache Server'),
(57323, 373, 16, 'dan Alasannya adalah'),
(57324, 374, 16, 'Anemia'),
(57325, 375, 16, 'Pergelangan Kaki'),
(57326, 376, 16, 'Pergelangan Kaki + Tumit'),
(57327, 377, 16, 'Formulir Evaluasi Pergelangan Kaki'),
(57328, 378, 16, 'Masalah Pergelangan Kaki'),
(57329, 379, 16, 'Ankylosing Sondlilitis'),
(57330, 380, 16, 'Ankylosing Spondlilitis'),
(57331, 381, 16, 'Anoreksia'),
(57332, 382, 16, 'Satu hal yang dapat Anda lakukan di jendela posting adalah permintaan tagihan kedua. Jika Anda memilih kotak centang sebelum menyimpannya, maka klaim asli akan dibuka kembali dan antri di halaman Penagihan, dan akan diproses selama menjalankan penagihan berikutnya.'),
(57333, 383, 16, 'Sebelum');
INSERT INTO `lang_definitions` VALUES
(57334, 384, 16, 'Anus nl, tidak ada nyeri dubur / massa'),
(57335, 385, 16, 'Kegelisahan/Keluhan'),
(57336, 386, 16, 'Apapun'),
(57337, 387, 16, 'Semua Kategori'),
(57338, 388, 16, 'Bagian dari kode yang dikehendaki atau deskripsinya'),
(57339, 389, 16, 'Bagian dari yang dikehendaki khusus'),
(57340, 390, 16, 'Bagian dari ID atau nama obat-obatan'),
(57341, 391, 16, 'Bagian dari ID atau nama imunisasi'),
(57342, 392, 16, 'Bagian dari nama pasien, atau "belakang,depan", atau "X-Y"'),
(57343, 394, 16, 'API key untuk SMS Gateway'),
(57344, 395, 16, 'Apnea'),
(57345, 396, 16, 'Tampilan'),
(57346, 397, 16, 'Penampilan:'),
(57347, 398, 16, 'Menambahkan catatan ini'),
(57348, 399, 16, 'Menambahkan ke catatan yang sudah ada'),
(57349, 400, 16, 'Menambahkan ke catatan ini'),
(57350, 401, 16, 'Menambahkan ke Catatan Ini'),
(57351, 402, 16, 'Appendectomy (Pembedahan Usus Buntu)'),
(57352, 404, 16, 'Pasien Berlaku'),
(57353, 406, 16, 'Nama Aplikasi untuk halaman login dan judul halaman utama.'),
(57354, 407, 16, 'Kode Aplikasi Penerima (GS03 - jika kosong ISA08 akan digunakan)'),
(57355, 408, 16, 'Kode Aplikasi Pengirim (GS02)'),
(57356, 409, 16, 'Judul Aplikasi'),
(57357, 410, 16, 'Berlaku untuk formulir Vital dan Grafik Pertumbuhan'),
(57358, 412, 16, 'Terapkan perubahan pada peristiwa yang masih berlaku saja, pada hal ini dan semua kejadian di masa yang akan datang, atau pada semua kejadian?'),
(57359, 413, 16, 'diterapkan pada daerah yang sakit'),
(57360, 414, 16, 'diterapkan pada kulit'),
(57361, 415, 16, 'Diterapkan'),
(57362, 416, 16, 'Terapkan Patch pada situs'),
(57363, 417, 16, 'Janji'),
(57364, 418, 16, 'Tanggal Janji Temu'),
(57365, 419, 16, 'Ragam Tampilan Janji Temu'),
(57366, 420, 16, 'Aturan Pengingat Tanggal Janji Temu'),
(57367, 421, 16, 'Status janji temu'),
(57368, 422, 16, 'Status Janji Temu'),
(57369, 423, 16, 'Janji temu dalam'),
(57370, 424, 16, 'Warna Janji Temu/Peristiwa'),
(57371, 425, 16, 'Janji Temu'),
(57372, 426, 16, 'Janji Temu (tulis opsional)'),
(57373, 427, 16, 'Janji Temu (tulis,wsome opsional)'),
(57374, 430, 16, 'Janji Temu dan Konsultasi'),
(57375, 431, 16, 'Laporan Janji Temu'),
(57376, 432, 16, 'Laporan Janji Temu-Konsultasi'),
(57377, 434, 16, 'Menyetujui'),
(57378, 436, 16, 'Disetujui'),
(57379, 437, 16, 'Administrasi Kegiatan Disetujui'),
(57380, 440, 16, 'Appt-Enc (Janji Temu-Konsultasi)'),
(57381, 441, 16, 'Janji Temu'),
(57382, 442, 16, 'Apr'),
(57383, 443, 16, 'April'),
(57384, 444, 16, 'Bahasa Arab'),
(57385, 447, 16, 'Apakah nama grup kontrol akses akan diterjemahkan?'),
(57386, 448, 16, 'Apakah nama kategori janji temu akan diterjemahkan?'),
(57387, 449, 16, 'Apakah nama kategori dokumen akan diterjemahkan?'),
(57388, 450, 16, 'Apakah biaya akan dibebankan pada tipe ini?'),
(57389, 451, 16, 'Apakah judul catatan pasien akan diterjemahkan?'),
(57390, 452, 16, 'Apakah kode disimpan pada tabel eksternal sql (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2))?'),
(57391, 453, 16, 'Anda siap untuk menyelesaikan isu baru GCAC untuk kunjungan ini?'),
(57392, 454, 16, 'Anda yakin menerbitkannya hari ini?'),
(57393, 455, 16, 'Anda yakin menyetujui kegiatan ini?'),
(57394, 457, 16, 'Anda yakin menyingkirkan formulir ini?'),
(57395, 459, 16, 'Anda yakin menghapus penyingkapan ini?'),
(57396, 460, 16, 'Anda yakin menghapus kegiatan ini?'),
(57397, 461, 16, 'Anda yakin menghapus item ini dari database?'),
(57398, 462, 16, 'Anda yakin menghapus catatan ini?'),
(57399, 464, 16, 'Anda yakin mengedit kegiatan ini?'),
(57400, 465, 16, 'Anda yakin menyembunyikan kegiatan ini?'),
(57401, 467, 16, 'Anda yakin ingin melihat kegiatan ini?'),
(57402, 468, 16, 'Apakah anda yakin menghapus seluruh grup dengan nama'),
(57403, 469, 16, 'Apakah anda yakin ingin menghapus seluruh daftar'),
(57404, 470, 16, 'Apakah anda yakin ingin menghapus bidang'),
(57405, 471, 16, 'Anda yakin menghapus kolom yang dipilih?'),
(57406, 472, 16, 'Anda yakin melanjutkan dengan tindakan ini?'),
(57407, 473, 16, 'Wilayah tidak dispesifikasikan'),
(57408, 474, 16, 'Lengan'),
(57409, 475, 16, 'Armenia'),
(57410, 477, 16, 'Arrythmia'),
(57411, 478, 16, 'Radang Sendi'),
(57412, 479, 16, 'Radang Sendi / penyakit sendi degen'),
(57413, 480, 16, 'Radang Sendi / penyakit sendi degen'),
(57414, 481, 16, 'sebagai'),
(57415, 482, 16, 'Pada'),
(57416, 484, 16, 'Asia'),
(57417, 487, 16, 'Penilaian'),
(57418, 488, 16, 'Ditugaskan Kepada'),
(57419, 489, 16, 'Asisten'),
(57420, 490, 16, 'Asma'),
(57421, 491, 16, 'pada'),
(57422, 492, 16, 'Diperlukan paling tidak satu parameter pencarian jika memilih Semua'),
(57423, 493, 16, 'Pada Navicular'),
(57424, 494, 16, 'Pada Navicular:'),
(57425, 495, 16, 'Regu Atletis/Keolahragaan'),
(57426, 497, 16, 'Atletis/Cedera'),
(57427, 498, 16, 'Sertifikat CA audit ATNA'),
(57428, 499, 16, 'Host audit ATNA'),
(57429, 500, 16, 'Sertifikat lokal audit ATNA'),
(57430, 501, 16, 'Port audit ATNA'),
(57431, 503, 16, 'Perhatian'),
(57432, 504, 16, 'Perhatian'),
(57433, 509, 16, 'Cadangan Audit Logging'),
(57434, 510, 16, 'Ragam Audit Logging'),
(57435, 511, 16, 'Urutan Audit Logging'),
(57436, 512, 16, 'Catatan Pasien Audit Logging'),
(57437, 513, 16, 'Penjadwalan Audit Logging'),
(57438, 514, 16, 'Keamanan Administrasi Audit Logging'),
(57439, 515, 16, 'Pemilihan Pertanyaan Audit Logging'),
(57440, 516, 16, 'Ags'),
(57441, 517, 16, 'Agustus'),
(57442, 519, 16, 'Auth'),
(57443, 520, 16, 'Auth / catatan'),
(57444, 523, 16, 'Grup yang berwenang'),
(57445, 524, 16, 'Status Kewenangan'),
(57446, 525, 16, 'Kewenangan'),
(57447, 526, 16, 'Mengizinkan'),
(57448, 527, 16, 'Izinkan - setiap pertemuan'),
(57449, 528, 16, 'Izinkan - pertemuan saya'),
(57450, 530, 16, 'Berwenang'),
(57451, 531, 16, 'Berwenang Saja'),
(57452, 532, 16, 'Kirim Otomatis'),
(57453, 535, 16, 'Pembuatan Otomatis Pertemuan Baru'),
(57454, 536, 16, 'Dihasilkan Otomatis'),
(57455, 537, 16, 'Perhitungan Ukuran Otomatis (AMC)'),
(57456, 542, 16, 'Pelacakan Perhitungan Ukuran Otomatis (AMC)'),
(57457, 543, 16, 'Pengukuran Otomatis (AMC)'),
(57458, 544, 16, 'Automatis'),
(57459, 546, 16, 'Secara otomatis membuat pertemuan baru ketika status janji-temu diatur menjadi "@" (tiba).'),
(57460, 549, 16, 'Kendaraan Medis'),
(57461, 550, 16, 'Menyimpan Otomatis'),
(57462, 551, 16, 'Kategori yang Tersedia'),
(57463, 552, 16, 'Waktu yang Tersedia'),
(57464, 557, 16, 'Rata-rata Bulanan'),
(57465, 558, 16, 'Avulsi/patah avulsi'),
(57466, 559, 16, 'Maleolus rusuk/sisi Avulsi'),
(57467, 560, 16, 'Maleolus ditengah-tengah Avulsi '),
(57468, 561, 16, 'Kesadaran Berbasis'),
(57469, 562, 16, 'Aksila'),
(57470, 565, 16, 'b.i.d.'),
(57471, 566, 16, 'Kembali'),
(57472, 567, 16, 'kembali'),
(57473, 568, 16, 'Kembali delapan kunjungan'),
(57474, 569, 16, 'Kembali sebelas kunjungan'),
(57475, 570, 16, 'Kembali lima kunjungan'),
(57476, 571, 16, 'Kembali empat kunjungan'),
(57477, 572, 16, 'Kembali sembilan kunjungan'),
(57478, 573, 16, 'Kembali satu kunjungan'),
(57479, 574, 16, 'Sakit Punggung'),
(57480, 575, 16, 'Masalah Punggung'),
(57481, 576, 16, 'Kembali tujuh kunjungan'),
(57482, 577, 16, 'Kembali enam kunjungan'),
(57483, 578, 16, 'Bedah Punggung'),
(57484, 579, 16, 'Kembali sepuluh kunjungan'),
(57485, 580, 16, 'Kembali tiga kunjungan'),
(57486, 584, 16, 'Kembali Ke Pasien'),
(57487, 586, 16, 'Kembali Ke Tampilan'),
(57488, 587, 16, 'Kembali dua belas kunjungan'),
(57489, 588, 16, 'Kembali dua kunjungan'),
(57490, 590, 16, 'Cadangan'),
(57491, 591, 16, 'File backup elah dibuat. Sekarang akan dikirimkan untuk didownload.'),
(57492, 593, 16, 'Backup/Cadangan telah berhasi diambil'),
(57493, 594, 16, 'Pemeriksaan buruk'),
(57494, 595, 16, 'Hutang buruk'),
(57495, 596, 16, 'Bahasa Indonesia'),
(57496, 597, 16, 'Saldo'),
(57497, 598, 16, 'Saldo'),
(57498, 599, 16, 'saldo'),
(57499, 601, 16, 'Utang Saldo'),
(57500, 603, 16, 'Draf Bank'),
(57501, 607, 16, 'Dasar kelima (5.) Metarsal'),
(57502, 608, 16, 'Dasar kelima (5.) Metarsal:'),
(57503, 612, 16, 'Alat Komunikasi Batch'),
(57504, 613, 16, 'Entry Pembayaran Batch'),
(57505, 614, 16, 'Batch Pembayaran'),
(57506, 615, 16, 'Proses Batch dimulai; hal ini dapat memakan waktu cukup lama.'),
(57507, 616, 16, 'Hasil Batch'),
(57508, 617, 16, 'BatchCom'),
(57509, 619, 16, 'karena id yang dimaksud belum ada.'),
(57510, 620, 16, 'Mulai'),
(57511, 621, 16, 'Tanggal Mulai'),
(57512, 623, 16, 'Mulai tanggal layanan yyyy-mm-dd'),
(57513, 624, 16, 'Waktu mulai pada hari dalam event kalender.'),
(57514, 626, 16, 'Bersendawa'),
(57515, 628, 16, 'Bengali'),
(57516, 630, 16, 'antara'),
(57517, 633, 16, 'Bilateral'),
(57518, 634, 16, 'Bilateral:'),
(57519, 636, 16, 'Tanggal tagihan:'),
(57520, 637, 16, 'Tagihan'),
(57521, 638, 16, 'Ditagih'),
(57522, 640, 16, 'Penagihan'),
(57523, 641, 16, 'Penagihan (tulis opsional)'),
(57524, 642, 16, 'Atensi Penagihan'),
(57525, 644, 16, 'Kode penagihan untuk Layanan yang Diminta'),
(57526, 645, 16, 'Kode Penagihan'),
(57527, 646, 16, 'Data Tagihan'),
(57528, 647, 16, 'Departemen/Bagian Penagihan'),
(57529, 648, 16, 'Fasilitas Tagihan'),
(57530, 649, 16, 'Informasi Tagihan'),
(57531, 650, 16, 'Lokasi Penagihan'),
(57532, 655, 16, 'Pengelola Tagihan'),
(57533, 656, 16, 'Catatan Tagihan'),
(57534, 657, 16, 'Catatan Tagihan untuk '),
(57535, 658, 16, 'Catatan Tagihan:'),
(57536, 659, 16, 'Hasil antrian Tagihan:'),
(57537, 660, 16, 'Laporan Tagihan'),
(57538, 662, 16, 'Status Tagihan = Belum ditagih'),
(57539, 663, 16, 'penagihan ke '),
(57540, 665, 16, 'Biopsi'),
(57541, 666, 16, 'Tanggal Lahir'),
(57542, 669, 16, 'Hitam'),
(57543, 670, 16, 'Paru-paru hitam'),
(57544, 671, 16, 'Kulit Hitam atau Afrika Amerika'),
(57545, 672, 16, 'Kanker kandung kemih'),
(57546, 673, 16, 'Infeksi kandung kemih'),
(57547, 674, 16, 'Formulir Kosong'),
(57548, 675, 16, 'Masalah Pendarahan'),
(57549, 676, 16, 'Titik Buta'),
(57550, 677, 16, 'Kembung'),
(57551, 678, 16, 'Diblokir'),
(57552, 679, 16, 'Darah'),
(57553, 680, 16, 'Tekanan Darah'),
(57554, 681, 16, 'Tekanan darah'),
(57555, 682, 16, 'Hidung Berdarah'),
(57556, 683, 16, 'Blue Cross Blue Shield (Garis dan Perisai Biru)'),
(57557, 684, 16, 'Garis biru dalam laporan ini adalah informasi. Garis hitam menunjukkan informasi yang sebelumnya ada. Garis hijau menunjukkan perubahan yang telah berhasil. Garis merah menunjukkan kesalahan atau perubahan yang tidak diterapkan, ini harus diproses secara manual. Pembantahan klaim sekarang dan pengembalian pembayaran tidak ditangani secara otomatis dan akan muncul dalam warna merah.'),
(57558, 685, 16, 'Penglihatan Kabur'),
(57559, 686, 16, 'BMI'),
(57560, 687, 16, 'Status BMI'),
(57561, 689, 16, 'Wilayah Badan/Lembaga'),
(57562, 690, 16, 'Situs Badan/Lembaga'),
(57563, 691, 16, 'Situs Badan/Lembaga, jika berlaku'),
(57564, 692, 16, 'Kesakitan tulang:'),
(57565, 693, 16, 'Kesakitan tulang: Malleolus di tengah-tengah'),
(57566, 694, 16, 'Boolean'),
(57567, 696, 16, 'Dasar'),
(57568, 697, 16, 'Kedua Telinga'),
(57569, 698, 16, 'kedua telinga'),
(57570, 699, 16, 'Dasar'),
(57571, 701, 16, 'BOX 10 A. Pekerjaan yang berhubungan '),
(57572, 702, 16, 'BOX 10 B. Kecelakaan secara otomatis '),
(57573, 703, 16, 'BOX 10 C. Kecelakaan Lainnya '),
(57574, 706, 16, 'BOX 15. Tanggal dari penyakit yang sama atau mirip (yyyy-mm-dd):'),
(57575, 708, 16, 'BOX 16. Tanggal tidak dapat bekerja dari (yyyy-mm-dd):'),
(57576, 709, 16, 'BOX 16. Tanggal tidak dapat bekerja untuk (yyyy-mm-dd):'),
(57577, 710, 16, 'BOX 18. Rawat inap dari tanggal (yyyy-mm-dd): '),
(57578, 711, 16, 'BOX 18. Rawat inap ke tanggal (yyyy-mm-dd): '),
(57579, 712, 16, 'BOX 20. Apakah lab luar digunakan?'),
(57580, 713, 16, 'BOX 22. Medicaid Resubmission Kode (ICD-9) '),
(57581, 714, 16, 'BOX 23. Nomor Otorisasi Sebelumnya '),
(57582, 715, 16, 'BP'),
(57583, 716, 16, 'Diastolik BP'),
(57584, 717, 16, 'Systolik BP'),
(57585, 719, 16, 'Bpd'),
(57586, 721, 16, 'Bps'),
(57587, 722, 16, 'Portugis Brasil'),
(57588, 723, 16, 'Dada'),
(57589, 724, 16, 'Biopsi Payudara'),
(57590, 725, 16, 'Pelepasan Payudara'),
(57591, 726, 16, 'Penyakit payudara'),
(57592, 727, 16, 'Pemeriksaan Payudara'),
(57593, 728, 16, 'Gumpalan Payudara'),
(57594, 730, 16, 'Suara Nafas:'),
(57595, 732, 16, 'Patah Tulang'),
(57596, 734, 16, 'Bentuk Bronkitis'),
(57597, 735, 16, 'Telusuri'),
(57598, 736, 16, 'Telusuri Catatan'),
(57599, 737, 16, 'Memar/lebam'),
(57600, 739, 16, 'Menonjol Kanan:'),
(57601, 741, 16, 'Rasa Panas saat Buang Air Kecil'),
(57602, 742, 16, 'Rasa Panas Saat Buang Air Kecil'),
(57603, 744, 16, 'Sibuk'),
(57604, 745, 16, 'namun belum diproses.'),
(57605, 746, 16, 'Pantat'),
(57606, 747, 16, 'Pantat + S.I.'),
(57607, 748, 16, 'oleh'),
(57608, 749, 16, 'Oleh'),
(57609, 750, 16, 'oleh mulut'),
(57610, 751, 16, 'Oleh/Sumber'),
(57611, 752, 16, 'Oleh:'),
(57612, 753, 16, 'C'),
(57613, 754, 16, 'Sertifikat CA untuk memverifikasi RFC 5425 syslog server TLS.'),
(57614, 755, 16, 'Lifetime Cache (dalam detik)'),
(57615, 756, 16, 'Template output cache?'),
(57616, 757, 16, 'Konsumsi kafein'),
(57617, 758, 16, 'Kalender'),
(57618, 759, 16, 'Waktu Akhir Kalender'),
(57619, 760, 16, 'Selang/Interval Kalender'),
(57620, 761, 16, 'Layar/Monitor Kalender'),
(57621, 762, 16, 'Pengaturan Kalender'),
(57622, 763, 16, 'Waktu Mulai Kalender'),
(57623, 764, 16, 'UI (Interface Pengguna) Kalender'),
(57624, 765, 16, 'Lihat kalender'),
(57625, 766, 16, 'Panggilan ke addForm () di sini. <br>'),
(57626, 767, 16, 'Kalori'),
(57627, 768, 16, 'Kamboja'),
(57629, 774, 16, 'Membatalkan'),
(57630, 775, 16, 'Batalkan Perubahan'),
(57631, 776, 16, 'Dibatalkan'),
(57632, 777, 16, 'Kanker'),
(57633, 778, 16, 'Penyaringan Kanker: Penyaringan Kanker Usus Besar'),
(57634, 779, 16, 'Penyaringan Kanker: Mammogram'),
(57635, 780, 16, 'Penyaringan Kanker: Pap Smear'),
(57636, 781, 16, 'Penyaringan Kanker: Penyaringan Kanker Prostat'),
(57637, 782, 16, 'Tidak dapat menambahkan karena data ini sudah ada!'),
(57638, 783, 16, 'Tidak dapat menambahkan atau memperbarui karena duplikat data sudah ada!'),
(57639, 785, 16, 'tidak dapat dikonversi ke JPEG. ImageMagick mungkin tidak diinstal?'),
(57640, 787, 16, 'tidak dapat ditampilkan inline karena jenis ini tidak didukung oleh browser.'),
(57641, 788, 16, 'tidak dapat ditampilkan inline karena jenis ini tidak didukung oleh browser'),
(57642, 789, 16, 'tidak dapat ditampilkan inline karena jenis ini tidak didukung oleh browser.'),
(57643, 790, 16, 'Tidak dapat membuat'),
(57644, 795, 16, 'Tidak dapat menemukan '),
(57645, 796, 16, 'Tidak dapat menemukan tempat tujuan dari nama file'),
(57646, 799, 16, 'Tidak bisa menemukan pasien dari SQL-Ledger id pelanggan'),
(57647, 800, 16, 'Tidak dapat menemukan kata-kata dalam dokumen acuan '),
(57648, 801, 16, 'Tidak dapat menemukan selular dari SQL-Ledger karyawan = '),
(57649, 802, 16, 'Tidak dapat Mengubah Pembayaran. Undistributed ditolak.'),
(57650, 803, 16, 'Tidak bisa membuka '),
(57651, 804, 16, 'Tidak bisa Mencatat untuk Asuransi. Entitas Pembayaran yang dipilih adalah Pasien.'),
(57652, 805, 16, 'Tidak bisa Mencatat untuk Pasien. Entitas Pembayaran yang dipilih adalah Asuransi.'),
(57653, 806, 16, 'Tidak bisa Mencatat Pembayaran. Undistributed ditolak.'),
(57654, 807, 16, 'Tidak bisa membaca'),
(57655, 808, 16, 'Tidak bisa membaca direktori'),
(57656, 809, 16, 'Tidak dapat diperbarui karena Anda tidak mengedit catatan yang ada!'),
(57657, 810, 16, 'Huruf Besar'),
(57658, 812, 16, 'kapsul'),
(57659, 813, 16, 'Kartu'),
(57660, 814, 16, 'Kateterisasi Jantung'),
(57661, 815, 16, 'Jantung Nemo'),
(57662, 816, 16, 'Kardiovaskular'),
(57663, 821, 16, 'Tulang rawan / chondral / kerusakan sendi'),
(57664, 822, 16, 'Cedera tulang rawan'),
(57665, 823, 16, 'Denyut Carotid(Pembuluh nadi kepala), denyut nadi'),
(57666, 824, 16, 'uang tunai'),
(57667, 825, 16, 'Uang Tunai'),
(57668, 826, 16, 'Rec Tunai'),
(57669, 827, 16, 'Penerimaan uang oleh Provider'),
(57670, 829, 16, 'Bedah katarak'),
(57671, 830, 16, 'Katarak'),
(57672, 831, 16, 'Kategori'),
(57673, 832, 16, 'Kategori untuk'),
(57674, 833, 16, 'Kategori'),
(57675, 834, 16, 'kategori'),
(57676, 835, 16, 'Kategori '),
(57677, 836, 16, 'Detail Kategori'),
(57678, 837, 16, 'Batas Kategori'),
(57679, 838, 16, 'Nama Kategori'),
(57680, 839, 16, 'Nama kategori kosong'),
(57681, 840, 16, 'Kategori/Judul'),
(57682, 841, 16, 'Kaukasia/Kaukasus'),
(57683, 842, 16, 'Alasan Penerimaan untuk Cetak Encounter/Info Provider Utama'),
(57684, 852, 16, 'Seluler'),
(57685, 853, 16, 'Telepon Seluler'),
(57686, 855, 16, 'Nomor Telepon seluler'),
(57687, 856, 16, 'Balai Sertifikasi'),
(57688, 857, 16, 'Amerika Selatan/Tengah'),
(57689, 858, 16, 'Lokasi file crt Pengijinan Sertifikat tidak boleh kosong'),
(57690, 859, 16, 'Lokasi file kunci Pengijinan Sertifikat tidak boleh kosong'),
(57691, 860, 16, 'Sertifikat untuk dikirimkan ke RFC 5425 TLS Syslog Server'),
(57692, 861, 16, 'Sertifikat Pengguna'),
(57693, 862, 16, 'Sertifikat'),
(57694, 864, 16, 'ChampUS'),
(57695, 865, 16, 'ChampUSVA'),
(57696, 866, 16, 'mengubah'),
(57697, 867, 16, 'Ubah'),
(57698, 868, 16, 'Ubah Kegiatan'),
(57699, 870, 16, 'Perubahan Penglihatan'),
(57700, 871, 16, 'Perubahan Penglihatan'),
(57701, 874, 16, 'Berubah'),
(57702, 875, 16, 'Perubahan Usus'),
(57703, 877, 16, 'Karakteristik'),
(57704, 878, 16, 'Karakter yang Tersisa'),
(57705, 879, 16, 'Biaya'),
(57706, 880, 16, 'Pengaturan Biaya'),
(57707, 882, 16, 'Biaya'),
(57708, 883, 16, 'Bagan/Grafik'),
(57709, 884, 16, 'Grafik Kegiatan'),
(57710, 885, 16, 'Grafik Laporan Kegiatan Check-in/out'),
(57711, 886, 16, 'ID Bagan:'),
(57712, 887, 16, 'ID Bagan:'),
(57713, 889, 16, 'Bagan Lokasi Kegiatan'),
(57714, 890, 16, 'Catatan Bagan'),
(57715, 891, 16, 'Nomor Bagan'),
(57716, 892, 16, 'Lokasi Penyimpanan Bagan'),
(57717, 893, 16, 'Bagan Tracker'),
(57718, 894, 16, 'Bagan Trk'),
(57719, 895, 16, 'Grafik Checked Out'),
(57720, 896, 16, 'Grafik Keluar'),
(57721, 898, 16, 'Periksa'),
(57722, 899, 16, 'periksa'),
(57723, 900, 16, 'Periksa Semua'),
(57724, 902, 16, 'Periksa Jumlah'),
(57725, 903, 16, 'Periksa Tanggal'),
(57726, 904, 16, 'Periksa perbedaan terjemahan dengan tabel bahasa custom'),
(57727, 906, 16, 'Check in ke'),
(57728, 907, 16, 'Periksa Input Data'),
(57729, 909, 16, 'Periksa Hasil Lab'),
(57730, 912, 16, 'Periksa Nomor'),
(57731, 915, 16, 'Periksa Pembayaran'),
(57732, 916, 16, 'Centang jika ini adalah file yang terenkripsi'),
(57733, 917, 16, 'Centang jika anda ingin provider/penyedia layanan untuk melihat semua janji-temu secara default.'),
(57734, 919, 16, 'Centang/Tanggal EOB:'),
(57735, 920, 16, 'Centang/No EOB:'),
(57736, 921, 16, 'Centang/Nomor Ref'),
(57737, 922, 16, 'Centang/Nomor Referensi'),
(57738, 923, 16, 'Daftar checkbox'),
(57739, 924, 16, 'daftar chcekbox'),
(57740, 925, 16, 'checkbox w/(tulis) teks'),
(57741, 926, 16, 'Checkbox w/(tulis) teks'),
(57742, 928, 16, 'Dicentang'),
(57743, 929, 16, 'Kotak dicentang = yes, kosong = tidak'),
(57744, 932, 16, 'Pemeriksaan'),
(57745, 933, 16, 'Checksum'),
(57746, 934, 16, 'Dada'),
(57747, 935, 16, 'Dada CTAB'),
(57748, 936, 16, 'Sakit pada Dada'),
(57749, 937, 16, 'Sakit pada Dada:'),
(57750, 938, 16, 'Sakit pada Dada'),
(57751, 940, 16, 'Chg'),
(57752, 942, 16, 'Keluhan pada Kepala'),
(57753, 943, 16, 'Anak'),
(57754, 945, 16, 'Status Imunisasi Anak (CQM)'),
(57755, 946, 16, 'Panas Dingin'),
(57756, 947, 16, 'Cina'),
(57757, 948, 16, 'Cina (Sederhana)'),
(57758, 949, 16, 'Cina (Tradisional)'),
(57759, 951, 16, 'Pilihan'),
(57760, 952, 16, 'Kolesistektomi'),
(57761, 954, 16, 'Kolesistektomi'),
(57762, 955, 16, 'Pilih'),
(57763, 956, 16, 'Pilih bagian dan klik item yang ada, kemudian di bagian lain, Anda akan melihat item terkait disorot, dan Anda dapat klik di bagian tersebut untuk menambahkan dan menghapus hubungan.'),
(57764, 957, 16, 'Pilih Kriteria'),
(57765, 962, 16, 'Pilih daftar'),
(57766, 965, 16, 'Pilih format print untu laporan ini.'),
(57767, 967, 16, 'Bronkitis Kronis'),
(57768, 968, 16, 'Nyeri Sendi Kronis'),
(57769, 969, 16, 'Penyakit Ginjal Kronis (CKD)'),
(57770, 970, 16, 'Sinovitis kronis/efusi/nyeri sendi/encok'),
(57771, 971, 16, 'Kronis/Berulang'),
(57772, 973, 16, 'Sirosis Hati'),
(57773, 974, 16, 'Sirosis Hati'),
(57774, 975, 16, 'Kota'),
(57775, 976, 16, 'Nama Kota'),
(57776, 977, 16, 'Kota, Negara'),
(57777, 978, 16, 'City, Zip Negara'),
(57778, 979, 16, 'Kota/Negara'),
(57779, 980, 16, 'Klaim'),
(57780, 981, 16, 'Klaim '),
(57781, 983, 16, 'Klaim tes telah berjalan'),
(57782, 984, 16, 'Tipe Klaim'),
(57783, 985, 16, 'Klaim telah dibuatkan pada berkas'),
(57784, 986, 16, 'Klaim telah dibuatkan pada berkas '),
(57785, 987, 16, 'Klaim'),
(57786, 988, 16, 'Klasifikasi'),
(57787, 989, 16, 'Bersih'),
(57788, 991, 16, 'Hapus Semua'),
(57789, 992, 16, 'Hapus Data HL7'),
(57790, 993, 16, 'Hapus Pembenaran'),
(57791, 994, 16, 'Hapus Smarty Cache'),
(57792, 995, 16, 'Pembersihan info Kantor penerimaan cek antara bank yang diperlukan untuk pembuatan batch EDI 270.'),
(57793, 996, 16, 'Nomor CLIA'),
(57794, 997, 16, 'Klik'),
(57795, 998, 16, 'Klik ''ekspor'' untuk mengekspor Kategori anda, Subkategori, data Konten ke file teks. Setiap kemiripan file ini terhadap file XML adalah murni tidak disengaja. Tag pembuka dan penutup harus berada pada baris yang sama, harus huruf kecil dan tanpa spasi. Untuk mengimpor, telusuri file dan klik ''impor''. Jika datanya berbeda, akan bergabung denga data yang ada. Jika ada nama item yang sama, yang lama akan tetap ada dan yang baru akan disimpan dengan nomor yang ditambahkan terakhir.'),
(57796, 999, 16, 'Klik sebuah tempat pada grafis untuk menambahkan penjelasan baru, klik lagi untuk menghapusnya'),
(57797, 1000, 16, 'Klik Download Sertifikat untuk mendownload sertifikat dalam berkas ssl.zip'),
(57798, 1001, 16, 'klik untuk lebih'),
(57799, 1005, 16, 'Klik disini'),
(57800, 1006, 16, 'Klik disini untuk menambahkan pasien baru'),
(57801, 1007, 16, 'Klik disini untuk menambahkan perubahan status cedera dan mengedit kegiatan harian'),
(57802, 1008, 16, 'Klik disini untuk memilih tanggal'),
(57803, 1009, 16, 'Klik disini untuk memilih tanggal dan waktu'),
(57804, 1010, 16, 'Klik disini untuk memilih tanggal mulai'),
(57805, 1020, 16, 'klik disini untuk mencari'),
(57806, 1021, 16, 'klik disini untuk memperbarui prioritas, kategori dan pengaturan panggilan'),
(57807, 1022, 16, 'Klik disini untuk melihat semua.'),
(57808, 1023, 16, 'Klik disini untuk melihat dan grafik'),
(57809, 1025, 16, 'Klik disini untuk melihat grafik tanda-tanda vital.'),
(57810, 1026, 16, 'Klik disini untuk melihat rincian pasien'),
(57811, 1027, 16, 'Klik disini untuk melihat semuanya.'),
(57812, 1029, 16, 'Klik tombol Instal untuk menginstal rilis database dari tanggal berikut'),
(57813, 1030, 16, 'Klik pada salah satu bagian waktu untuk meningkatkannya'),
(57814, 1031, 16, 'Klik Nama Pasien untuk Membuka File/Berkas Pasien'),
(57815, 1032, 16, 'Klik Refresh untuk melihat semua hasil, atau masukkan kriteria pencarian diatas untuk melihat hasil yang spesifik/tertentu.'),
(57816, 1034, 16, 'Klik untuk menambahkan komponen baru'),
(57817, 1035, 16, 'Klik untuk menambahkan konsultasi baru'),
(57818, 1037, 16, 'Klik untuk mendownload'),
(57819, 1038, 16, 'Klik untuk mengedit'),
(57820, 1040, 16, 'Klik untuk mengedit kegiatan ini'),
(57821, 1041, 16, 'Klik untuk menghasilkan laporan'),
(57822, 1043, 16, 'Klik untuk mencetak'),
(57823, 1044, 16, 'Klik untuk mendapatkan (tambah) banyak lot'),
(57824, 1045, 16, 'Klik untuk memilih'),
(57825, 1046, 16, 'Klik Untuk Memilih'),
(57826, 1047, 16, 'Klik untuk memilih kode standar industri untuk prosedur ini'),
(57827, 1048, 16, 'Klik untuk memilih kode prosedur opsional'),
(57828, 1050, 16, 'Klik untuk memilih atau mengubah kode CVX'),
(57829, 1051, 16, 'Klik untuk memilih atau mengubah diagnosa'),
(57830, 1052, 16, 'Klik untuk memilih atau mengubah kode layanan'),
(57831, 1053, 16, 'Klik untuk memilih pasien'),
(57832, 1054, 16, 'Klik untuk memilih kode yang terkait'),
(57833, 1055, 16, 'Klik untuk memilih layanan untuk melakukan jika hasil ini tidak normal'),
(57834, 1056, 16, 'Klik untuk memilih prosedur yang diinginkan'),
(57835, 1058, 16, 'Klik untuk melihat'),
(57836, 1059, 16, 'Klik untuk melihat atau mengedit'),
(57837, 1060, 16, 'Klik untuk melihat/mengedit'),
(57838, 1061, 16, 'Klik tombol Upgrade untuk mengupgrade rilis database dari tangal berikut'),
(57839, 1063, 16, 'Klik:'),
(57840, 1064, 16, 'Hari Masa Berlaku Sertifikat Klien'),
(57841, 1065, 16, 'Periode validasi sertifikat klien'),
(57842, 1066, 16, 'Keabsahan sertifikat klien harus angka yang valid/benar.'),
(57843, 1067, 16, 'Salinan Klien'),
(57844, 1069, 16, 'Ringkasan riwayat medis klien'),
(57845, 1072, 16, 'Profil Klien - Klien Baru'),
(57846, 1073, 16, 'Profil klien - Klien Unik'),
(57847, 1074, 16, 'Klien'),
(57848, 1075, 16, 'Klinik'),
(57849, 1076, 16, 'Salinan Klinik'),
(57850, 1077, 16, 'Catatan Harian Klinik'),
(57851, 1078, 16, 'ID Klinik'),
(57852, 1079, 16, 'Klinik'),
(57853, 1080, 16, 'Pengelola Pemberitahuan Aturan Keputusan Klinis'),
(57854, 1083, 16, 'Rencana Klinis'),
(57855, 1084, 16, 'Ukuran Kualitas Klinis (CQM)'),
(57856, 1087, 16, 'Pengingat Klinis'),
(57857, 1088, 16, 'Laporan Klinis'),
(57858, 1089, 16, 'Aturan Klinis Kategori Aksi'),
(57859, 1090, 16, 'Aturan Klinis Item Aksi'),
(57860, 1091, 16, 'Aturan Klinis Metode Filter'),
(57861, 1092, 16, 'Aturan Klinis Metode Sasaran'),
(57862, 1093, 16, 'Aturan Klinis'),
(57863, 1094, 16, 'Aturan Klinis Interval Usia'),
(57864, 1095, 16, 'Aturan Klinis Perbandingan'),
(57865, 1096, 16, 'Aturan Klinis Jenis Encounter'),
(57866, 1097, 16, 'Aturan Klinis Pengingat karena Pilihan'),
(57867, 1098, 16, 'Aturan Klinis Pengingat Inaktivasi Pilihan'),
(57868, 1099, 16, 'Aturan Klinis Interval Pengingat'),
(57869, 1100, 16, 'Aturan Klinis Metode Pengingat'),
(57870, 1101, 16, 'Aturan Klinis Interval Sasaran'),
(57871, 1102, 16, 'Sasaran klinis'),
(57872, 1106, 16, 'Dokter'),
(57873, 1107, 16, 'Duplikasi'),
(57874, 1108, 16, 'Duplikasi Kunjungan Sebelumnya'),
(57875, 1109, 16, 'Tutup'),
(57876, 1111, 16, 'tutup jendela'),
(57877, 1112, 16, 'Ditutup'),
(57878, 1113, 16, 'cm'),
(57879, 1114, 16, 'CMS 1500 Margin'),
(57880, 1118, 16, 'CMS ID'),
(57881, 1127, 16, 'CN2-12 intact'),
(57882, 1128, 16, 'Co Pay'),
(57883, 1129, 16, 'Co Pay dibayar'),
(57884, 1130, 16, 'CO-PAY'),
(57885, 1131, 16, 'Kode'),
(57886, 1132, 16, 'kode'),
(57887, 1133, 16, 'Kode Penemu'),
(57888, 1134, 16, 'Kode harus dua huruf kecil'),
(57889, 1135, 16, 'Kode atau simbol untuk mengindikasikan mata uang'),
(57890, 1136, 16, 'Teks Kode'),
(57891, 1138, 16, 'jenis kode'),
(57892, 1141, 16, 'Jenis Kode'),
(57893, 1143, 16, 'Dikode'),
(57894, 1144, 16, 'Kode'),
(57895, 1145, 16, 'Pengkodean'),
(57896, 1147, 16, 'Pengkodean - semua pertemuan (tulis,wsome opsional)'),
(57897, 1148, 16, 'Pengkodean - semua pertemuan (tulis,wsome opsional)'),
(57898, 1149, 16, 'Pengkodean tidak diizinkan'),
(57899, 1150, 16, 'Kopi'),
(57900, 1152, 16, 'Coinsurance'),
(57901, 1153, 16, 'Coll w/o'),
(57902, 1154, 16, 'Kempiskan'),
(57903, 1155, 16, 'kempiskan'),
(57904, 1156, 16, 'Kempiskan Semua'),
(57905, 1157, 16, 'Kempiskan semua'),
(57906, 1158, 16, 'kempiskan semua'),
(57907, 1161, 16, 'Koleksi'),
(57908, 1162, 16, 'Laporan Koleksi'),
(57909, 1163, 16, 'Kanker Usus Besar'),
(57910, 1164, 16, 'Penyaringan Kanker Usus Besar'),
(57911, 1165, 16, 'Pembedahan Kanker Usus Besar'),
(57912, 1166, 16, 'Colonoscopy'),
(57913, 1167, 16, 'colonoscopy'),
(57914, 1168, 16, 'Warna'),
(57915, 1169, 16, 'Warna:Abbr'),
(57916, 1170, 16, 'Kolom'),
(57917, 1171, 16, 'Kolom'),
(57918, 1172, 16, 'Menggabungkan Lot'),
(57919, 1173, 16, 'Koma'),
(57920, 1174, 16, 'Komentar'),
(57921, 1175, 16, 'Komentar'),
(57922, 1176, 16, 'Komentar untuk hasil dari rekomendasi ini'),
(57923, 1177, 16, 'Perusahaan Asuransi Komersial'),
(57924, 1178, 16, 'Lakukan Perubahan'),
(57925, 1180, 16, 'Komunikasi'),
(57926, 1182, 16, 'Perusahaan'),
(57927, 1183, 16, 'Nama Perusahaan'),
(57928, 1184, 16, 'Selesai'),
(57929, 1186, 16, 'Selesai'),
(57930, 1188, 16, 'Selesai?'),
(57931, 1190, 16, 'Komplikasi oleh Service Provider'),
(57932, 1191, 16, 'Komplikasi Aborsi'),
(57933, 1192, 16, 'Komponen'),
(57934, 1193, 16, 'Sistem Pengurutan Medis Dibantu Komputer'),
(57935, 1194, 16, 'Kesimpulan'),
(57936, 1199, 16, 'Konfigurasi'),
(57937, 1200, 16, 'Konfigurasi Ekspor/Impor'),
(57938, 1202, 16, 'Konfigurasi Apache dan LibreEHR untuk menggunakan sertifikat SSL dari sisi Klien.'),
(57939, 1203, 16, 'Konfigurasi Apache untuk menggunakan sertifikat SSL dari sisi Klien'),
(57940, 1204, 16, 'Konfigurasi Apache untuk menggunakan HTTPS.'),
(57941, 1205, 16, 'Konfigurasi LIBREEHR untuk menggunakan sertifikat SSL dari sisi klien'),
(57942, 1208, 16, 'Konfirmasi Buat Pasien Baru'),
(57943, 1209, 16, 'Konfirmasi Sandi Baru'),
(57944, 1210, 16, 'Konfirmasi Pembayaran'),
(57945, 1214, 16, 'Bawaan'),
(57946, 1215, 16, 'Konjungtiva, pupil'),
(57947, 1217, 16, 'Penghubung'),
(57948, 1218, 16, 'Konstan'),
(57949, 1219, 16, 'nama tetap'),
(57950, 1220, 16, 'Nama tetap kosong'),
(57951, 1221, 16, 'konstan'),
(57952, 1222, 16, 'Konstipasi/Sembelit'),
(57953, 1223, 16, 'Kontstitusional'),
(57954, 1226, 16, 'Penjelasan Singkat Konsultasi'),
(57955, 1227, 16, 'Kontak'),
(57956, 1228, 16, 'Kontak Email'),
(57957, 1229, 16, 'Kontak Alamat Email'),
(57958, 1231, 16, 'info kontak'),
(57959, 1232, 16, 'Lensa Kontak'),
(57960, 1236, 16, 'Nama kontak'),
(57961, 1237, 16, 'Contact Person'),
(57962, 1239, 16, 'Kontak/Hubungi Nomor Telepon'),
(57963, 1240, 16, 'Contact ZMG, LLC (zmghealth@gmail.com) untuk berlangganan layanan eRx'),
(57964, 1241, 16, 'mengandung setidaknya tiga dari empat item berikut:'),
(57965, 1243, 16, 'Isi'),
(57966, 1244, 16, 'isi'),
(57967, 1245, 16, 'Konteks'),
(57968, 1246, 16, 'Nama konteks tidak boleh kosong'),
(57969, 1247, 16, 'Lanjut'),
(57970, 1248, 16, 'Kontinuitas Perawatan Dokumen (CCD)'),
(57971, 1249, 16, 'Kontinuitas Perawatan Catatan (CCR)'),
(57972, 1250, 16, 'Kontra Klien'),
(57973, 1251, 16, 'Kontrasepsi'),
(57974, 1252, 16, 'Masalah kontrasepsi'),
(57975, 1253, 16, 'Komplikasi Kontrasepsi (sebutkan)'),
(57976, 1254, 16, 'Metode kontrasepsi'),
(57977, 1255, 16, 'Produk Kontrasepsi'),
(57978, 1256, 16, 'Layanan kontrasepsi sebelumnya dimulai'),
(57979, 1257, 16, 'Mulai kontrasepsi'),
(57980, 1258, 16, 'ID Kontrol'),
(57981, 1259, 16, 'Nomor Kontrol'),
(57982, 1262, 16, 'Copay'),
(57983, 1263, 16, 'CoPay'),
(57984, 1264, 16, 'Copay tidak positif'),
(57985, 1266, 16, 'Copays'),
(57986, 1267, 16, 'COPD'),
(57987, 1268, 16, 'Salin ke Halaman Bagan/Grafik Pasien'),
(57988, 1269, 16, 'Salin Nilai'),
(57989, 1270, 16, 'Mengkopi file databse. Ini akan sedikit memakan waktu...'),
(57990, 1271, 16, 'Hak Cipta'),
(57991, 1273, 16, 'Arteri koroner Bypass'),
(57992, 1274, 16, 'Transplatasi Arteri Koroner (CABG)'),
(57993, 1275, 16, 'Dikoreksi'),
(57994, 1277, 16, 'CouchDB'),
(57995, 1278, 16, 'Koneksi CouchDB Gagal.'),
(57996, 1279, 16, 'Database CouchDB'),
(57997, 1280, 16, 'Nama database CouchDB'),
(57998, 1281, 16, 'Host CouchDB'),
(57999, 1282, 16, 'HostName CouchDB'),
(58000, 1283, 16, 'Log CouchDB Aktif'),
(58001, 1284, 16, 'Sandi CouchDB'),
(58002, 1285, 16, 'Port CouchDB'),
(58003, 1286, 16, 'port CouchDB'),
(58004, 1288, 16, 'Username CouchDB'),
(58005, 1289, 16, 'Batuk'),
(58006, 1290, 16, 'Batuk:'),
(58007, 1294, 16, 'Tidak dapat membaca file'),
(58008, 1296, 16, 'Tidak dapat mengirim email karena masalah server, '),
(58009, 1298, 16, 'Tidak dapat membuat direktori backup'),
(58010, 1299, 16, 'Tidak dapat menghapus direktori:'),
(58011, 1300, 16, 'Tidak dapat menghapus file backup yang lama:'),
(58012, 1301, 16, 'Tidak dapat menghapus file ekspor yang lama:'),
(58013, 1302, 16, 'Pengelolaan Coumadin - Pemantauan USD'),
(58014, 1303, 16, 'Konseling dengan Metode'),
(58015, 1304, 16, 'Konseling'),
(58016, 1305, 16, 'Kegiatan konseling'),
(58017, 1306, 16, 'FORMULIR RUJUKAN KONTER/KASIR'),
(58018, 1307, 16, 'Rujukan Konter/Kasir'),
(58019, 1308, 16, 'Negara'),
(58020, 1309, 16, 'Jenis Data Negara'),
(58021, 1310, 16, 'Daftar Negara'),
(58022, 1311, 16, 'Daftar Negara (tulis, hanya tambah opsional)'),
(58023, 1312, 16, 'Nama Negara harus dinyatakan dalam dua kata. (Contoh: United States adalah US)'),
(58024, 1313, 16, 'negara'),
(58025, 1315, 16, 'Kupon'),
(58026, 1318, 16, 'CPT'),
(58027, 1319, 16, 'Kode CPT'),
(58028, 1320, 16, 'Kode CPT'),
(58029, 1323, 16, 'CQM'),
(58030, 1324, 16, 'Crackles:'),
(58031, 1325, 16, 'krim'),
(58032, 1326, 16, 'Buat sertifikat SSL sisi klien untuk setiap mesin klien atau pengguna.'),
(58033, 1327, 16, 'Buat sertifikat SSL sisi klien baik untuk nama host klien atau pengguna.'),
(58034, 1329, 16, 'Buat Event'),
(58035, 1330, 16, 'Buat atau download backup/salinan lengkap'),
(58036, 1332, 16, 'Buat Backup'),
(58037, 1333, 16, 'Buat batch'),
(58038, 1334, 16, 'Buat Sertifikat Klien'),
(58039, 1335, 16, 'Buat sertifikat SSL dari sisi Klien'),
(58040, 1336, 16, 'Buat Duplikat'),
(58041, 1338, 16, 'Buat Backup Log Event'),
(58042, 1339, 16, 'Buat Isu/Masalah Baru'),
(58043, 1340, 16, 'Buat Pasien Baru'),
(58044, 1342, 16, 'Buat Surat Pengenal Portal Offsite'),
(58045, 1343, 16, 'Buat Surat Pengenal Portal Onsite'),
(58046, 1344, 16, 'Buat Catatan Pasien'),
(58047, 1345, 16, 'Buat Pengijinan Sertifikat SSL dan sertifikat Server'),
(58048, 1346, 16, 'Buat Kunjungan'),
(58049, 1347, 16, 'Dibuat'),
(58050, 1348, 16, 'Membuat file ekspor'),
(58051, 1351, 16, 'Pembuat/Pencipta'),
(58052, 1352, 16, 'kredit'),
(58053, 1353, 16, 'Kartu Kredit'),
(58054, 1354, 16, 'Kredit'),
(58055, 1356, 16, 'Kriteria'),
(58056, 1358, 16, 'Crohn Penyakit'),
(58057, 1359, 16, 'Crohn Penyakit'),
(58058, 1360, 16, 'Ekspor CSV'),
(58059, 1361, 16, 'File CSV'),
(58060, 1363, 16, 'CU.MM'),
(58061, 1364, 16, 'Kuba'),
(58062, 1365, 16, 'Bagian Desimal Mata Uang'),
(58063, 1366, 16, 'Simbol Angka Mata Uang'),
(58064, 1367, 16, 'Penanda Mata Uang'),
(58065, 1368, 16, 'Pemisah Ribuan Mata Uang'),
(58066, 1369, 16, 'Saat ini'),
(58067, 1370, 16, 'Alkohol Saat Ini'),
(58068, 1371, 16, 'Konsultasi Saat Ini'),
(58069, 1372, 16, 'Kriteria Saat Ini'),
(58070, 1373, 16, 'Warna sorot hari saat ini'),
(58071, 1374, 16, 'Perokok tiap hari saat ini'),
(58072, 1375, 16, 'Nama file saat ini diubah menjadi'),
(58073, 1376, 16, 'Kekalutan/Keluhan Saat Ini'),
(58074, 1377, 16, 'Lokasi Saat Ini'),
(58075, 1378, 16, 'Obat Saat Ini'),
(58076, 1379, 16, 'Pasword Saat Ini'),
(58077, 1380, 16, 'Pasien Saat Ini'),
(58078, 1382, 16, 'Obat Rekreasi Saat Ini'),
(58079, 1383, 16, 'Perokok beberapa hari saat ini'),
(58080, 1386, 16, 'Sedang aktif'),
(58081, 1388, 16, 'Saat ini tidak ada fasilitas.'),
(58082, 1389, 16, 'Sindrom Cushing'),
(58083, 1390, 16, 'Sindrom Cushing'),
(58084, 1392, 16, 'Custom/Kebiasaan'),
(58085, 1393, 16, 'Masukan custom?'),
(58086, 1394, 16, 'Tabel Custom'),
(58087, 1396, 16, 'Kode CVX'),
(58088, 1397, 16, 'Kode Pemetaan CVX'),
(58089, 1399, 16, 'Siklus'),
(58090, 1400, 16, 'CYP'),
(58091, 1401, 16, 'Faktor CYP'),
(58092, 1402, 16, 'Laporan CYP'),
(58093, 1403, 16, 'Ceko'),
(58094, 1404, 16, 'D'),
(58095, 1405, 16, 'D&C'),
(58096, 1406, 16, 'D&E'),
(58097, 1407, 16, 'D.O.B.'),
(58098, 1408, 16, 'harian'),
(58099, 1409, 16, 'Catatan Harian'),
(58100, 1410, 16, 'Denmark'),
(58101, 1411, 16, 'Data serupa telah ada dalam database, silahkan ganti kode dan/atau deskripsi'),
(58102, 1412, 16, 'Data serupa telah ada dalam database, silahkan ganti nama tetap'),
(58103, 1413, 16, 'Kolom Data'),
(58104, 1416, 16, 'Kesalahan Data'),
(58105, 1420, 16, 'Jenis data'),
(58106, 1421, 16, 'Database'),
(58107, 1422, 16, 'Database tidak terinstal.'),
(58108, 1424, 16, 'Pelaporan Database'),
(58109, 1425, 16, 'Upgrade database selesai.'),
(58110, 1426, 16, 'Kolom Data harus berupa nomor antara 1 dan 999'),
(58111, 1427, 16, 'Tanggal'),
(58112, 1428, 16, 'TANGGAL'),
(58113, 1431, 16, 'Tanggal Diperintah'),
(58114, 1432, 16, 'Tanggal dan waktu pengumpulan sampel'),
(58115, 1433, 16, 'Tanggal dan waktu pengamatan ini'),
(58116, 1435, 16, 'Tanggal dan waktu sampel diambil'),
(58117, 1436, 16, 'Tanggal tidak boleh lebih dari hari ini'),
(58118, 1437, 16, 'Tanggal layanan kontrasepsi yang diberikan pada awalnya'),
(58119, 1438, 16, 'Tanggal Dibuat'),
(58120, 1439, 16, 'Tanggal Meninggal'),
(58121, 1440, 16, 'Tanggal Hancur'),
(58122, 1441, 16, 'Format Tampilan Tanggal'),
(58123, 1442, 16, 'Format tanggal untuk "akhir janji-temu" tidak valid'),
(58124, 1443, 16, 'Format tanggal untuk "mulai janji-temu" tidak valid'),
(58125, 1444, 16, 'Format tanggal untuk "Janji-Temu Berikutnya" tidak valid'),
(58126, 1445, 16, 'Format tanggal untuk "tidak terlihat sejak" tidak valid'),
(58127, 1446, 16, 'Format tanggal untuk "terlihat sejak" tidak valid'),
(58128, 1447, 16, 'Statemen Informasi Tanggal Imunisasi yang Diberikan'),
(58129, 1448, 16, 'Tanggal tersebut tidak ada untuk kode '),
(58130, 1449, 16, 'Kriteria Tanggal'),
(58131, 1450, 16, 'Tanggal deposito bank yyyy-mm-dd'),
(58132, 1452, 16, 'Tanggal Lahir'),
(58133, 1453, 16, 'Tanggal lahir'),
(58134, 1454, 16, 'Tanggal Lahir'),
(58135, 1456, 16, 'Tanggal Cedera'),
(58136, 1458, 16, 'Tanggal pembayaran yyyy-mm-dd'),
(58137, 1459, 16, 'Tanggal rujukan'),
(58138, 1460, 16, 'Tanggal balasan'),
(58139, 1463, 16, 'Tanggal Pelayanan'),
(58140, 1464, 16, 'Tanggal Pelayanan = Hari Ini'),
(58141, 1465, 16, 'Tanggal layanan mm / dd / yyyy'),
(58142, 1466, 16, 'Tanggal Pelayanan:'),
(58143, 1467, 16, 'Tanggal Penandatanganan'),
(58144, 1469, 16, 'Tanggal pemesanan ini'),
(58145, 1470, 16, 'Tanggal laporan ini'),
(58146, 1471, 16, 'Tanggal Pernyataan VIS'),
(58147, 1472, 16, 'Tanggal Diperintah'),
(58148, 1475, 16, 'Pemilih tanggal'),
(58149, 1476, 16, 'Tanggal Terkirim'),
(58150, 1477, 16, 'Tanggal Terkirimnya Pesan'),
(58151, 1479, 16, 'Nilai tanggal Tidak boleh Kosong'),
(58152, 1480, 16, 'Tanggal/Janji-Temu'),
(58153, 1481, 16, 'Tanggal/Catatan'),
(58154, 1482, 16, 'Tanggal / Catatan dari Terakhir'),
(58155, 1483, 16, 'Tanggal/Waktu'),
(58156, 1484, 16, 'Tanggal:'),
(58157, 1485, 16, 'Tanggal Log Pesan'),
(58158, 1486, 16, 'Hari'),
(58159, 1487, 16, 'hari'),
(58160, 1489, 16, 'Lihat Hari'),
(58161, 1490, 16, 'Hari'),
(58162, 1491, 16, 'Hari S-J'),
(58163, 1492, 16, 'bulan'),
(58164, 1493, 16, 'Bulan'),
(58165, 1494, 16, 'beberapa hari yang lalu'),
(58166, 1495, 16, 'Bulan dan Permainan yang Terlewat'),
(58167, 1496, 16, 'Hari Dari Encounter Terakhir'),
(58168, 1497, 16, 'Hari yang Terlewat'),
(58169, 1498, 16, 'Hari per Kolom:'),
(58170, 1500, 16, 'Hari/Kolom:'),
(58171, 1501, 16, 'DB diinstal'),
(58172, 1502, 16, 'DD/MM/YYYY'),
(58173, 1503, 16, 'Identifikasi'),
(58174, 1504, 16, 'Proses Identifikasi selesai'),
(58175, 1505, 16, 'Proses Identifikasi sedang berlangsung'),
(58176, 1506, 16, 'Proses Identifikasi dimulai dan berjalan pada latar belakang'),
(58177, 1507, 16, 'Data yang diidentifikasi mungkin tidak lengkap'),
(58178, 1508, 16, 'File Identifikasi akan disimpan dalam'),
(58179, 1509, 16, 'DEA'),
(58180, 1511, 16, 'Tuli/Tuna Rungu'),
(58181, 1512, 16, 'Informasi Debug'),
(58182, 1515, 16, 'Desember'),
(58183, 1516, 16, 'MENINGGAL'),
(58184, 1517, 16, 'Desember'),
(58185, 1520, 16, 'Dapat Dikurangi'),
(58186, 1521, 16, 'Met yang Dapat Dikurangi'),
(58187, 1522, 16, 'Default/Standar'),
(58188, 1523, 16, 'Tampilan Standar Kalender'),
(58189, 1524, 16, 'Encounter Format ID Standar'),
(58190, 1526, 16, 'Fasilitas Standar'),
(58191, 1527, 16, 'Bahasa Standar'),
(58192, 1528, 16, 'Bahasa standar jika tidak ada bahasa lain yang diizinkan atau dipilih.'),
(58193, 1529, 16, 'Daftar Standar (tulis, hanya tambah opsional)'),
(58194, 1530, 16, 'Metode default'),
(58195, 1531, 16, 'Standar Hari Kadaluarsa Pasword'),
(58196, 1532, 16, 'Standar Periode Kadaluarsa Pasword dalam hari. 0 berarti fitur ini tidak difungsikan.'),
(58197, 1533, 16, 'Negara Pasien Standar'),
(58198, 1536, 16, 'Provider/Penyedia Layanan Standar'),
(58199, 1537, 16, 'Rentang Standar'),
(58200, 1538, 16, 'Rentang Standar untuk Kunjungan'),
(58201, 1540, 16, 'Pengaturan Standar'),
(58202, 1542, 16, 'Template Standar'),
(58203, 1546, 16, 'Unit/Satuan Standar'),
(58204, 1547, 16, 'Nilai Standar'),
(58205, 1548, 16, 'Warehouse/Gudang Standar'),
(58206, 1549, 16, 'Mitra X12 Standar'),
(58207, 1550, 16, 'Standar/Global'),
(58208, 1551, 16, 'Hapus'),
(58209, 1552, 16, 'hapus'),
(58210, 1553, 16, 'Kambuh Tertunda (> 12 Bulan)'),
(58211, 1554, 16, 'Menghapus'),
(58212, 1555, 16, 'menghapus'),
(58213, 1556, 16, 'Hapus Kategori dengan ID: '),
(58214, 1557, 16, 'Hapus Kategori'),
(58215, 1560, 16, 'Hapus Grup'),
(58216, 1561, 16, 'Hapus Daftar'),
(58217, 1562, 16, 'Hapus Halaman'),
(58218, 1563, 16, 'Hapus Pasien, Encounter, Formulir, Isu/Masalah, Dokumen, Pembayaran, Tagihan atau Transaksi'),
(58219, 1565, 16, 'Hapus Baris'),
(58220, 1566, 16, 'Hapus Item yang Dipilih'),
(58221, 1568, 16, 'Penghapusan berhasil.'),
(58222, 1569, 16, 'Hapus dokumen ini'),
(58223, 1570, 16, 'Hapus formulir ini'),
(58224, 1571, 16, 'Hapus catatan ini'),
(58225, 1573, 16, 'Berhasil Dihapus.'),
(58226, 1581, 16, 'Demensia'),
(58227, 1582, 16, 'Demografi'),
(58228, 1583, 16, 'Demografi (tulis, hanya tambah opsional)'),
(58229, 1585, 16, 'Kriteria penyaringan demografi'),
(58230, 1586, 16, 'Demografi tidak diizinkan'),
(58231, 1587, 16, 'Demografi tidak diizinkan.'),
(58232, 1589, 16, 'Penyebut'),
(58233, 1590, 16, 'Dental'),
(58234, 1592, 16, 'Masalah Dental'),
(58235, 1595, 16, 'Tergantung pada jenis tagihan yang anda uji anda akan melihat HCFA seperti output pada halaman kosong untuk tagihan HCFA, anda akan melihat banyak baris teks yang rusak dan informasi jika anda menguji klaim X12. Teks yang rusak tersebut merupakan format X12 EDI 4010A. Kadang anda akan melihat karakter aneh yang terlihat seperti domino atau squigiles, ini merupakan karakter kontrol seperti pada ''page feeds'' dan bersifat normal.'),
(58236, 1596, 16, 'Tanggal Deposito'),
(58237, 1597, 16, 'Tanggal Deposito Tidak boleh lebih dari Hari Ini'),
(58238, 1598, 16, 'Tanggal deposito:'),
(58239, 1599, 16, 'Sedih'),
(58240, 1600, 16, 'Depresi'),
(58241, 1602, 16, 'Deskripsi/Keterangan'),
(58242, 1603, 16, 'deskripsi'),
(58243, 1605, 16, 'Deskripsi dari Pengungkapan'),
(58244, 1606, 16, 'Deskripsi dari pengungkapan ini atau kode hasil'),
(58245, 1607, 16, 'Deskripsi Terjemahan'),
(58246, 1609, 16, 'Tujuan'),
(58247, 1610, 16, 'Tujuan Nama file'),
(58248, 1611, 16, 'Hancurkan Lot'),
(58249, 1612, 16, 'Hancurkan...'),
(58250, 1613, 16, 'Hancur'),
(58251, 1614, 16, 'Obat Hancur'),
(58252, 1615, 16, 'Laporan Obat Hancur'),
(58253, 1616, 16, 'Rincian'),
(58254, 1617, 16, 'Rincian'),
(58255, 1619, 16, 'Kelainan Pengembangan'),
(58256, 1620, 16, 'Diabetes'),
(58257, 1621, 16, 'Diabetes Mellitus'),
(58258, 1622, 16, 'Diabetes: Pengelolaan Tekanan Darah (CQM)'),
(58259, 1623, 16, 'Diabetes: Pengujian Mata'),
(58260, 1624, 16, 'Diabetes: Pengujian Mata (CQM)'),
(58261, 1625, 16, 'Diabetes: Pengujian Kaki'),
(58262, 1626, 16, 'Diabetes: Pengujian Kaki (CQM)'),
(58263, 1627, 16, 'Diabetes: Kontrol Lemahnya HbA1c (CQM)'),
(58264, 1628, 16, 'Diabetes: Hemoglobin A1C'),
(58265, 1629, 16, 'Diabetes: Pengelolaan LDL & Kontrol (CQM)'),
(58266, 1630, 16, 'Diabetes: Microalbumin Air Seni'),
(58267, 1631, 16, 'Diagnosa'),
(58268, 1633, 16, 'Diagnosa'),
(58269, 1634, 16, 'Kode Diagnosa'),
(58270, 1636, 16, 'Tanggal Diagnosa'),
(58271, 1637, 16, 'Diagnosa harus dikodekan menjadi encounter yang terhubung'),
(58272, 1638, 16, 'Nama Diagnosa'),
(58273, 1639, 16, 'Laporan Diagnosa'),
(58274, 1642, 16, 'Judul Diagnosa'),
(58275, 1643, 16, 'Diagnosa:'),
(58276, 1644, 16, 'Diagnosa: '),
(58277, 1645, 16, 'Pengujian diagnostik:'),
(58278, 1646, 16, 'Setel'),
(58279, 1647, 16, 'Diafragma/Caps'),
(58280, 1648, 16, 'Diare'),
(58281, 1650, 16, 'Perintah'),
(58282, 1651, 16, 'Perintah: '),
(58283, 1652, 16, 'Apakah anda menerima salinan Pemberitahuan HIPAA?'),
(58284, 1653, 16, 'Diffuse/Tersebar:'),
(58285, 1654, 16, 'Ditandatangani secara Digital'),
(58286, 1657, 16, 'Surat langsung'),
(58287, 1663, 16, 'Nama Direktu/Pemimpin'),
(58288, 1665, 16, 'Cacat'),
(58289, 1667, 16, 'Nonaktifkan Kalender'),
(58290, 1668, 16, 'Nonaktifkan Pelacak Bagan/Grafik'),
(58291, 1669, 16, 'Nonaktifkan Imunisasi'),
(58292, 1670, 16, 'Nonaktifkan Formulir Tanda Vital Metrik Lama'),
(58293, 1672, 16, 'Nonaktifkan phpMyAdmin'),
(58294, 1673, 16, 'Nonaktifkan Resep'),
(58295, 1674, 16, 'Nonaktifkan Grup Pengguna'),
(58296, 1675, 16, 'dinonaktifkan'),
(58297, 1676, 16, 'Dinonaktifkan'),
(58298, 1677, 16, 'Dinonaktifkan Penerima Dibawah Umur 65 Tahun dengan Large Group Health Plan (LGHP)'),
(58299, 1678, 16, 'DISC'),
(58300, 1681, 16, 'Pengeluaran'),
(58301, 1682, 16, 'Pengeluaran dari Uretra/Saluran Kencing'),
(58302, 1684, 16, 'Pengeluaran Sehat'),
(58303, 1685, 16, 'Pengeluaran Sehat:'),
(58304, 1689, 16, 'Pengungkapan Informasi'),
(58305, 1690, 16, 'Jenis Pengungkapan'),
(58306, 1691, 16, 'Jenis Pengungkapan'),
(58307, 1692, 16, 'Pengungkapan Informasi'),
(58308, 1694, 16, 'Diskon'),
(58309, 1695, 16, 'Jumah Diskon'),
(58310, 1696, 16, 'Level/Tingkat Diskon'),
(58311, 1697, 16, 'Persentase Diskon'),
(58312, 1698, 16, 'Diskon sebagai Jumlah Moneter'),
(58313, 1699, 16, 'Diskon pada waktu checkout/pemeriksaan dimasukkan sebagai jumlah uang, berlawanan dengan persentase.'),
(58314, 1700, 16, 'Hasil Diskrit'),
(58315, 1701, 16, 'Penyakit'),
(58316, 1702, 16, 'Dislokasi'),
(58317, 1703, 16, 'Disp #'),
(58318, 1704, 16, 'Pengiriman'),
(58319, 1705, 16, 'Pengiriman Dokumen yang Diterima'),
(58320, 1706, 16, 'Ditiadakan'),
(58321, 1707, 16, 'Tampilkan petunjuk terlebih dahulu pada halaman demografik.'),
(58322, 1709, 16, 'Tampilkan tanggal event pada blok/berkas?'),
(58323, 1711, 16, 'Tampilkan berapa banyak event/peristiwa?'),
(58324, 1713, 16, 'Tampilkan lokasi pada blok/berkas?'),
(58325, 1714, 16, 'Nama yang Ditampilkan'),
(58326, 1715, 16, 'Tampilkan kalender?'),
(58327, 1718, 16, 'Tampilkan event hari ini pada blok/berkas?'),
(58328, 1719, 16, 'Tampilkan topik di blok/berkas?'),
(58329, 1720, 16, 'Tampilkan acara mendatang di blok/berkas?'),
(58330, 1721, 16, 'Kolom yang Ditampilkan'),
(58331, 1722, 16, 'Menampilkan nomor berikut dari pengungkapan yang terbaru:'),
(58332, 1723, 16, 'Menampilkan nomor berikut dari catatan yang terbaru'),
(58333, 1724, 16, 'Menampilka nomor berikut dari catatan yang terbaru:'),
(58334, 1725, 16, 'Distribusi/Penyaluran'),
(58335, 1726, 16, 'Distribusi'),
(58336, 1727, 16, 'Distributor/Penyalur'),
(58337, 1729, 16, 'Diverticulitis'),
(58338, 1730, 16, 'Bedah Diverticulitis'),
(58339, 1731, 16, 'Divirticulitis'),
(58340, 1732, 16, 'Bedah Divirticulitis'),
(58341, 1733, 16, 'Bercerai'),
(58342, 1734, 16, 'Pusing:'),
(58343, 1735, 16, 'Jangan ubah'),
(58344, 1737, 16, 'Jangan tampilkan Alergi yang diupload ke NewCrop'),
(58345, 1739, 16, 'Jangan tampilkan Obat yang diupload ke NewCrop'),
(58346, 1742, 16, 'jangan tampilkan kalender.'),
(58347, 1744, 16, 'Jangan menginventarisasi dan menjual produk apapun'),
(58348, 1745, 16, 'Tidak memerlukan catatan pasien untuk diotorisasi/diizinkan'),
(58349, 1746, 16, 'Jangan Resusitasi Pesanan/Perintah'),
(58350, 1747, 16, 'tidak menyimpan'),
(58351, 1748, 16, 'tidak menggantikan'),
(58352, 1749, 16, 'tidak melakukan apa-apa'),
(58353, 1751, 16, 'Apakah anda benar-benar ingin menghapus'),
(58354, 1752, 16, 'Apakah anda benar-benar ingin menghapus pilihan ini?'),
(58355, 1753, 16, 'Apakah Anda benar-benar ingin menghapus grup ini'),
(58356, 1755, 16, 'Apakah anda ingin melanjut?'),
(58357, 1756, 16, 'Apakah anda ingin menghapus ini?'),
(58358, 1757, 16, 'Apakah anda ingin menghapus?'),
(58359, 1758, 16, 'Apakah anda ingin menyingkirkan record/catatan ini?'),
(58360, 1759, 16, 'Apakah anda ingin lanjut menambahkan pasien baru ini?'),
(58361, 1760, 16, 'Apakah anda ingin lanjut dengan nama baru tersebut?'),
(58362, 1761, 16, 'Apakah anda ingin menghapus record/catatan imunisasi ini SECARA PERMANEN?'),
(58363, 1762, 16, 'DOB'),
(58364, 1763, 16, 'DOB tidak ada, silahkan masukkan jika bisa'),
(58365, 1764, 16, 'Docs/Dokumen'),
(58366, 1765, 16, 'Dokter'),
(58367, 1766, 16, 'Dokter:'),
(58368, 1767, 16, 'Nama Dokter dan tanda tangan'),
(58369, 1768, 16, 'Dokumen'),
(58370, 1769, 16, 'dokumen'),
(58371, 1770, 16, 'Kategori Dokumen'),
(58372, 1775, 16, 'Dokumen tidak dapat dipindahkan ke id pasien'),
(58373, 1777, 16, 'Tanggal Dokumen'),
(58374, 1778, 16, 'Tanggal dan Isu/Pokok(Persoalan) dokumen berhasil diupdate'),
(58375, 1779, 16, 'ID Dokumen'),
(58376, 1780, 16, 'Dokumen dipindahkan ke kategori yang baru'),
(58377, 1781, 16, 'Dokumen dipindahkan ke id pasien'),
(58378, 1783, 16, 'Dokumen lulus cek/uji integritas.'),
(58379, 1785, 16, 'Dokumen berhasil berganti nama.'),
(58380, 1790, 16, 'Persediaan Dokumen/Pencitraan(Image)'),
(58381, 1791, 16, 'Dokumen'),
(58382, 1792, 16, 'Dokumen (tulis, hanya tambah opsional)'),
(58383, 1794, 16, 'DOE'),
(58384, 1798, 16, 'Apakah jenis ini mengizinkan kode yang terkait?'),
(58385, 1799, 16, 'Mitra Domestik'),
(58386, 1800, 16, 'Jangan Simpan'),
(58387, 1801, 16, 'Jangan Simpan'),
(58388, 1802, 16, 'Jangan Simpan Perubahan'),
(58389, 1803, 16, 'Selesai'),
(58390, 1804, 16, 'Dilakukan/Selesai dengan:'),
(58391, 1805, 16, 'Selesai. Sekarang akan mengirim download.'),
(58392, 1806, 16, 'DOS'),
(58393, 1807, 16, 'Dosis'),
(58394, 1809, 16, 'klik dua kali untuk mengedit'),
(58395, 1810, 16, 'Penglihatan Ganda'),
(58396, 1811, 16, 'Download/Unduh'),
(58397, 1814, 16, 'Tetap Mendownload'),
(58398, 1815, 16, 'Download file tagihan, posting ke akuntansi dan tandai sebagai ditagih'),
(58399, 1817, 16, 'Download Sertifikat'),
(58400, 1818, 16, 'Download pengaturan data'),
(58401, 1820, 16, 'Download file yang terenkripsi'),
(58402, 1827, 16, 'Download Statemen yang Dipilj'),
(58403, 1828, 16, 'Dr Periksa'),
(58404, 1829, 16, 'Dr Kunjungi'),
(58405, 1830, 16, 'Dr.'),
(58406, 1831, 16, 'Drag/Tarik untuk memindahkan'),
(58407, 1832, 16, 'Menggiring'),
(58408, 1833, 16, 'Lisensi Pengemudi atau ID Negara'),
(58409, 1834, 16, 'Obat'),
(58410, 1835, 16, 'Pencari Obat'),
(58411, 1836, 16, 'Formulir Obat'),
(58412, 1837, 16, 'ID Obat hilang!'),
(58413, 1838, 16, 'Interval Obat'),
(58414, 1839, 16, 'Persediaan obat'),
(58415, 1840, 16, 'Nama obat'),
(58416, 1841, 16, 'Rute Obat'),
(58417, 1845, 16, 'Unit/Satuan Obat'),
(58418, 1846, 16, 'Obat'),
(58419, 1847, 16, 'Obat dan Produk'),
(58420, 1848, 16, 'Mulut Kering'),
(58421, 1850, 16, 'DT 1'),
(58422, 1851, 16, 'DT 2'),
(58423, 1852, 16, 'DT 3'),
(58424, 1853, 16, 'DT 4'),
(58425, 1854, 16, 'DT 5'),
(58426, 1855, 16, 'DTaP 1'),
(58427, 1856, 16, 'DTaP 2'),
(58428, 1857, 16, 'DTaP 3'),
(58429, 1858, 16, 'DTaP 4'),
(58430, 1859, 16, 'DTaP 5'),
(58431, 1860, 16, 'Jatuh Tempo'),
(58432, 1861, 16, 'Tanggal Jatuh Tempo'),
(58433, 1862, 16, 'Tanggal jatuh tempomm / dd / yyyy atau yyyy-mm-dd'),
(58434, 1863, 16, 'Tanggal Jatuh Tempo:'),
(58435, 1864, 16, 'Ins Jatuh Tempo(batas)'),
(58436, 1865, 16, 'Pt Jatuh Tempi(batas)'),
(58437, 1866, 16, 'Segera Jatuh Tempo'),
(58438, 1867, 16, 'Status Jatuh Tempo'),
(58439, 1868, 16, 'Update Status Jatuh Tempo'),
(58440, 1869, 16, 'Dumping database LibreEHR'),
(58441, 1870, 16, 'Dumping pohon direktori web LibreEHR'),
(58442, 1871, 16, 'Dumping database phpGACL'),
(58443, 1872, 16, 'Dumping pohon direktori web phpGACL'),
(58444, 1873, 16, 'Dumping database SQL-Ledger'),
(58445, 1874, 16, 'Dumping pohon direktori web SQL-Ledger'),
(58446, 1875, 16, 'Pemeriksaan Duplikasi'),
(58447, 1876, 16, 'ID rangkap pada baris'),
(58448, 1877, 16, 'Nama rangkap pada baris'),
(58449, 1878, 16, 'PERINGATAN DUPLIKASI'),
(58450, 1879, 16, 'Ketahanan Surat Kuasa'),
(58451, 1880, 16, 'durasi'),
(58452, 1881, 16, 'Durasi'),
(58453, 1882, 16, 'Belanda'),
(58454, 1884, 16, 'Disfagia'),
(58455, 1885, 16, 'Dispnea/Nafas yg sulit:'),
(58456, 1886, 16, 'Disuria'),
(58457, 1888, 16, 'Resep Elektronik?'),
(58458, 1890, 16, 'e-Rx'),
(58459, 1892, 16, 'Pembaruan e-Rx'),
(58460, 1893, 16, 'Setiap penerima harus mengatur pesan mereka sendiri sebagai lengkap.'),
(58461, 1894, 16, 'Awal Kambuh (<2 Bulan)'),
(58462, 1895, 16, 'Kuping'),
(58463, 1896, 16, 'ECG'),
(58464, 1898, 16, 'Busung'),
(58465, 1902, 16, 'EDI-271 Upload File'),
(58466, 1903, 16, 'EDI-271 Respon Upload File'),
(58467, 1904, 16, 'Edit');
INSERT INTO `lang_definitions` VALUES
(58468, 1905, 16, 'edit'),
(58469, 1906, 16, 'Edit Alergi'),
(58470, 1907, 16, 'Edit Kategori'),
(58471, 1908, 16, 'Edit Definisi'),
(58472, 1909, 16, 'Edit definisi'),
(58473, 1910, 16, 'Edit Diagnosa untuk'),
(58474, 1911, 16, 'Edit Pengungkapan'),
(58475, 1912, 16, 'Edit Fasilitas'),
(58476, 1913, 16, 'Edit Fasilitas'),
(58477, 1914, 16, 'Edit Informasi Fasilitas'),
(58478, 1916, 16, 'Edit File pada'),
(58479, 1917, 16, 'Edit formulir'),
(58480, 1918, 16, 'Edit Pengaturan Global'),
(58481, 1919, 16, 'Pengeditan tidak diizinkan!'),
(58482, 1920, 16, 'Edit Layout/Tata Letak'),
(58483, 1921, 16, 'Edit daftar'),
(58484, 1922, 16, 'Edit Pembayaran'),
(58485, 1923, 16, 'Edit Struktur'),
(58486, 1924, 16, 'Edit Pengguna'),
(58487, 1925, 16, 'Edit Pengaturan Pengguna'),
(58488, 1928, 16, 'Pendidikan'),
(58489, 1929, 16, 'Tanggal Pendidikan'),
(58490, 1931, 16, 'ee * the GNU General Public License untuk rincian lebih lanjut. * * Anda harus menerima salinan GNU General Public License * bersama-sama dengan program ini, jika tidak, tulis ke Free '),
(58491, 1932, 16, 'Tanggal efektif'),
(58492, 1934, 16, 'Efektivitas'),
(58493, 1935, 16, 'EIN'),
(58494, 1936, 16, 'Ejakulasi'),
(58495, 1937, 16, 'Siku'),
(58496, 1938, 16, 'Masalah Siku'),
(58497, 1939, 16, 'Elektronik'),
(58498, 1942, 16, 'Pengiriman Elektronik'),
(58499, 1944, 16, 'Persyaratan'),
(58500, 1945, 16, 'Kelayakan Pemeriksaan Batch 270'),
(58501, 1946, 16, 'Tanggapan Persyaratan'),
(58502, 1947, 16, 'Status Kelayakan untuk vaksin yang disediakan untuk Anak-anak'),
(58503, 1948, 16, 'Memenuhi Syarat'),
(58504, 1949, 16, 'Email'),
(58505, 1951, 16, 'Alamat Email'),
(58506, 1953, 16, 'Alamat email dari pengirim untuk pengingat pasien. Balasan kepada pengingat pasien akan diarahkan ke alamat ini. Penting untuk menggunakan alamat dari domain klinik anda untuk menghindari membantu mencegah pengingat pasien menuju ke folder junk/sampah pada mail.'),
(58507, 1954, 16, 'Alamat email, jika ada, untuk menerima pemberitahuan administratif.'),
(58508, 1955, 16, 'Alamat email, jika ada, untuk menerima pesan aktivasi login pengguna darurat.'),
(58509, 1956, 16, 'Auth Email'),
(58510, 1957, 16, 'Email dari Batchcom'),
(58511, 1958, 16, 'Notifikasi/Pemberitahuan Email'),
(58512, 1959, 16, 'Waktu Notifikasi Email'),
(58513, 1961, 16, 'Email dikirim sebelum'),
(58514, 1962, 16, 'Email Pengirim'),
(58515, 1963, 16, 'Email Terkirim'),
(58516, 1965, 16, 'Subjek email'),
(58517, 1966, 16, 'Teks email, Tag yang dapat digunakan: ***NAMA***, contoh Kepada*** NAMA***'),
(58518, 1968, 16, 'Metode Pengiriman Email'),
(58519, 1969, 16, 'Email dikirimkan ke alamat berikut'),
(58520, 1971, 16, 'Kontak Darurat'),
(58521, 1972, 16, 'Kontak Pribadi Darurat'),
(58522, 1974, 16, 'Darurat Contraception'),
(58523, 1975, 16, 'Login Darurat'),
(58524, 1976, 16, 'Login Darurat ACL telah dipilih. Pengguna masih dalam keadaan aktif, silahkan nonaktifkan pengguna dan aktifkan kembali ketika diperlukan selama situasi darurat. Kunjungi Administrasi->Pengguna untuk aktivasi dan nonaktivasi.'),
(58525, 1977, 16, 'Email aktivasi Login darurat akan beredar hanya jika pengaturan berikut dalam file interface/globals.php dikonfigurasi.'),
(58526, 1978, 16, 'Alamat Email Login Darurat'),
(58527, 1979, 16, 'Pengguna Login Darurat dapat melakukan apapun'),
(58528, 1980, 16, 'Telepon Darurat'),
(58529, 1982, 16, 'Empisema'),
(58530, 1983, 16, 'Karyawan'),
(58531, 1984, 16, 'Perusahaan Pemberi Kerja'),
(58532, 1985, 16, 'Alamat Perusahaan Pemberi Kerja'),
(58533, 1986, 16, 'Data Perusahaan Pemberi Kerja'),
(58534, 1987, 16, 'Nama Perusahaan Pemberi Kerja'),
(58535, 1988, 16, 'KOSONG'),
(58536, 1989, 16, 'Kosong'),
(58537, 1990, 16, 'Tidak Diijinkan Menggunakan Password Kosong'),
(58538, 1991, 16, 'Nilai kosong pada "Waktu Email"'),
(58539, 1992, 16, 'Nilai kosong pada "Pengirim Email"'),
(58540, 1993, 16, 'Nilai kosong pada "Subjek Email"'),
(58541, 1994, 16, 'Nilai kosong pada "Teks Email"'),
(58542, 1995, 16, 'Nilai kosong pada "Nama Provider"'),
(58543, 1996, 16, 'Nilai kosong pada "Pasword"'),
(58544, 1997, 16, 'Nilai kosong pada "Waktu SMS"'),
(58545, 1998, 16, 'Nilai kosong pada "Teks SMS"'),
(58546, 1999, 16, 'Nilai kosong pada "Nama pengguna"'),
(58547, 2001, 16, 'Aktifkan'),
(58548, 2006, 16, 'Aktifkan Percepatan AMC'),
(58549, 2008, 16, 'Aktifkan Laporan AMC'),
(58550, 2009, 16, 'Aktifkan Pelacakan AMC'),
(58551, 2011, 16, 'Aktifkan Audit ATNA'),
(58552, 2013, 16, 'Aktifkan Logging Audit'),
(58553, 2014, 16, 'Aktifkan Trail Audit dan Otentikasi Node (ATNA)'),
(58554, 2015, 16, 'Aktifkan Laporan Penghitungan Ukuran Otomatis (AMC)'),
(58555, 2016, 16, 'Aktifkan SSL Klien'),
(58556, 2017, 16, 'Aktifkan otentikasi sertifikat klien SSL'),
(58557, 2019, 16, 'Aktifkan Aturan Keputusan Klinis (CDR)'),
(58558, 2022, 16, 'Aktifkan Laporan Ukuran Kualitas Klinis (CQM)'),
(58559, 2023, 16, 'Aktifkan Popup Pengingat Klinis'),
(58560, 2024, 16, 'Aktifkan Widget Pengingat Klinis'),
(58561, 2027, 16, 'Aktifkan Laporan CQM'),
(58562, 2031, 16, 'Aktifkan Dukungan Hylafax'),
(58563, 2033, 16, 'Aktifkan pesan status impor untuk NewCrop erx'),
(58564, 2037, 16, 'Aktifkan Pertukaran Lab'),
(58565, 2040, 16, 'Aktifkan logging dari semua query SQL SELECT.'),
(58566, 2041, 16, 'Aktifkan logging dari backup kegiatan yang terkait.'),
(58567, 2043, 16, 'Aktifkan logging dari kegiatan lain-lain.'),
(58568, 2044, 16, 'Aktifkan logging dari susunan kegiatan.'),
(58569, 2045, 16, 'Aktifkan logging dari modifikasi record/catatan pasien.'),
(58570, 2046, 16, 'Aktifkan logging dari penjadwalan kegiatan.'),
(58571, 2047, 16, 'Aktifkan logging dari keamanan dan kegiatan administrasi.'),
(58572, 2049, 16, 'Aktifkan Layanan NewCrop eRx'),
(58573, 2051, 16, 'Aktifkan Portal Offsite Pasien'),
(58574, 2052, 16, 'Aktifkan Portal Offsite Pasien.'),
(58575, 2053, 16, 'Aktifkan Portal Onsite Pasien'),
(58576, 2055, 16, 'Aktifkan Portal Onsite Pasien.'),
(58577, 2056, 16, 'Aktifkan Widget Pengingat Pasien'),
(58578, 2058, 16, 'Aktifkan Percepatan Untuk Penghitungan Ukuran Otomatis (AMC) Data yang Dibutuhkan'),
(58579, 2060, 16, 'Aktifkan Laporan dari Pelacakan Tanggal Dari Penghitungan Ukuran Otomatis (AMC)'),
(58580, 2061, 16, 'Aktifkan Dukungan Scanner'),
(58581, 2065, 16, 'Aktifkan Dukungan LibreEHR LLC Layanan Pertukaran Lab.'),
(58582, 2066, 16, 'Aktifkan Otentikasi Sertifikat Pengguna'),
(58583, 2067, 16, 'Aktifkan layanan ZMG, LLC, eRx'),
(58584, 2068, 16, 'diaktifkan'),
(58585, 2070, 16, 'Memungkinkan panel Buaya yang lama untuk memasukkan kode tagihan dan pembayaran. Tidak direkomendasikan, sebaga gantinya gunakan Lembar Biaya.'),
(58586, 2071, 16, 'Enc(Encounter)'),
(58587, 2072, 16, 'Encounter'),
(58588, 2073, 16, 'Encounter'),
(58589, 2074, 16, 'encounter'),
(58590, 2075, 16, 'Encounter '),
(58591, 2076, 16, 'mengalami rawat inap akut atau ED'),
(58592, 2081, 16, 'Tanggal Encounter'),
(58593, 2086, 16, 'Formulir Encounter'),
(58594, 2087, 16, 'mengalami penilaian kesehatan dan perilaku'),
(58595, 2088, 16, 'Riwayat Encounter'),
(58596, 2089, 16, 'ID Encounter'),
(58597, 2090, 16, 'mengalamai influenza'),
(58598, 2091, 16, 'Nomor encounter'),
(58599, 2093, 16, 'menghadapi pemberhentian keperawatan'),
(58600, 2094, 16, 'menjumpai fasilitas keperawatan'),
(58601, 2095, 16, 'menghadapi terapi kerja'),
(58602, 2096, 16, 'menghadapi kunjungan kerja'),
(58603, 2097, 16, 'mengalami rawat jalan'),
(58604, 2098, 16, 'mengalami rawat jalan PCP dan obgyn'),
(58605, 2099, 16, 'Ukuran Halaman Encounter'),
(58606, 2101, 16, 'mengalami kehamilan'),
(58607, 2102, 16, 'mengalami obat pencegahan - konseling individu'),
(58608, 2103, 16, 'mengalami obat pencegahan 40 dan lebih tua'),
(58609, 2104, 16, 'mengalami konseling kelompok obat pencegahan'),
(58610, 2105, 16, 'mengalami layanan pengobatan pencegahan lainnya'),
(58611, 2106, 16, 'mengalami layanan pengobatan pencegahan 18 dan lebih tua'),
(58612, 2107, 16, 'mengalami layan psikiatri dan psikologi'),
(58613, 2108, 16, 'Statistik encounter'),
(58614, 2109, 16, 'Ringkasan Encounter'),
(58615, 2110, 16, 'Encounter dikodekan'),
(58616, 2111, 16, 'Encounter:'),
(58617, 2112, 16, 'Encounter: mengalami rawat inap non-akut, rawat jalan, dan oftamologi'),
(58618, 2113, 16, 'Encounter'),
(58619, 2114, 16, 'Encounter & Formulir'),
(58620, 2115, 16, 'Encounter & Formulir'),
(58621, 2116, 16, 'Encounter tidak diizinkan'),
(58622, 2117, 16, 'Laporan Encounter'),
(58623, 2118, 16, 'Bagian Encounter'),
(58624, 2120, 16, 'Enkripsi'),
(58625, 2121, 16, 'Akhir'),
(58626, 2122, 16, 'Akhir (yyyy-mm-dd): '),
(58627, 2123, 16, 'Tanggal Akhir'),
(58628, 2124, 16, 'Tanggal akhir'),
(58629, 2126, 16, 'Tanggal akhir harus lebih dari Tanggal mulai'),
(58630, 2127, 16, 'Tanggal Berakhir:'),
(58631, 2131, 16, 'Waktu Akhir'),
(58632, 2132, 16, 'Tahap Akhir Penerima Penyakit Ginjal pada MCP dengan Employer''s Group Plan (Rencana)'),
(58633, 2133, 16, 'Tanggal berakhirnya layanan yyyy-mm-dd'),
(58634, 2134, 16, 'Berakhirnya DOS mm/dd/yyyy jika anda ingin memasukkan range'),
(58635, 2135, 16, 'Berakhirnya waktu pada hari untuk event kalender'),
(58636, 2136, 16, 'Endo Darah Abnormal'),
(58637, 2137, 16, 'Kelenjar endokrin'),
(58638, 2138, 16, 'Endoskopi'),
(58639, 2141, 16, 'Inggris'),
(58640, 2142, 16, 'Inggris '),
(58641, 2143, 16, 'Inggris (Indian)'),
(58642, 2144, 16, 'Inggris (Standar)'),
(58643, 2145, 16, 'Perintah Enscript digunakan oleh Hylafax'),
(58644, 2146, 16, 'Patikan LibreEHR telah menulis hak akses ke direktori'),
(58645, 2147, 16, 'Pelepasan THT'),
(58646, 2149, 16, 'Masukkan kode diagnosa untuk mengecualikan semua faktur/tagihan yang tidak mengandung hal tersebut'),
(58647, 2151, 16, 'Masukkan badan surat disini'),
(58648, 2152, 16, 'Masukkan Pasword root Database'),
(58649, 2153, 16, 'Masukkan Nama pengguna root Database'),
(58650, 2154, 16, 'Masukkan Diagnosa'),
(58651, 2155, 16, 'Masukkan Obat'),
(58652, 2158, 16, 'Masukkan Imunisasi'),
(58653, 2159, 16, 'Masukan Kunci'),
(58654, 2161, 16, 'Masukkan Negara baru'),
(58655, 2164, 16, 'Masukkan kode Identifikasi'),
(58656, 2165, 16, 'Masukkan kriteria pencarian anda diatas'),
(58657, 2168, 16, 'Lingkungan'),
(58658, 2169, 16, 'Entry Data EOB'),
(58659, 2170, 16, 'Posting EOB - Layanan Pengiriman Uang'),
(58660, 2171, 16, 'Posting EOB - Instruksi'),
(58661, 2172, 16, 'Posting EOB - Faktur'),
(58662, 2173, 16, 'Posting EOB - Catatan Pasien'),
(58663, 2174, 16, 'Posting EOB - Cari'),
(58664, 2176, 16, 'Epilepsi'),
(58665, 2178, 16, 'ERA'),
(58666, 2180, 16, 'Posting ERA'),
(58667, 2181, 16, 'Menghapus'),
(58668, 2182, 16, 'Ereksi'),
(58669, 2183, 16, 'Kesalahan'),
(58670, 2185, 16, 'Kesalahan mengkonfirmasikan hasil lab'),
(58671, 2187, 16, 'Kesalahan mendapatkan hasil lab dari Lab Exchange Network (Jaringan Pertukaran Lab)'),
(58672, 2188, 16, 'Kesalahan dalam pemilihan "Jenis Kelamin"'),
(58673, 2189, 16, 'Kesalahan dalam pemilihan "HIPAA"'),
(58674, 2190, 16, 'Kesalahan dalam pemilihan "Proses"'),
(58675, 2191, 16, 'Kesalahan dalam pemilihan "SMS Gateway"'),
(58676, 2192, 16, 'Kesalahan dalam pemilihan "Urut Berdasarkan"'),
(58677, 2193, 16, 'Kesalahan dalam pengkompresian file gzip: '),
(58678, 2194, 16, 'Kesalahan dalam pilihan YA atau TIDAK'),
(58679, 2195, 16, 'Kesalahan pembukaan file yang telah diupload untuk dibaca'),
(58680, 2198, 16, 'Kesalahan Menghapus Pesan'),
(58681, 2199, 16, 'Kesalahan mengambil hasil dari Lab Exchange Network (Jaringan Pertukaran Lab)'),
(58682, 2202, 16, 'Kesalahan saat memberikan hak akses file kepada pengguna LibreEHR.'),
(58683, 2205, 16, 'kesalahan saat mendaftarkan formulir'),
(58684, 2206, 16, 'Kesalahan saat menyimpan kedalam file'),
(58685, 2208, 16, 'Kesalahan saat menulis kedalam file'),
(58686, 2210, 16, 'Kesalahan, file tersebut tidak ada'),
(58687, 2211, 16, 'KESALAHAN, tidak dapat mengambil data dari server'),
(58688, 2212, 16, 'Kesalahan, tidak dapat membuat sertifikat klien.'),
(58689, 2213, 16, 'Kesalahan, tidak dapat membuat sertifikat admin.p12.'),
(58690, 2214, 16, 'Kesalahan, tidak dapat membuat sertifikat Pengizinan Sertifikat.'),
(58691, 2215, 16, 'Kesalaham, tidak dapat membuat sertifikat Server.'),
(58692, 2216, 16, 'Kesalahan, tidak dapat membuka file'),
(58693, 2217, 16, 'Kesalahan, Otentikasi Sertifikat Pengguna tidak diaktifkan pada LibreEHR'),
(58694, 2218, 16, 'Kesalahan. Anda harus menginstal modul php Archive/Tar.php.'),
(58695, 2219, 16, 'KESALAHAN: tidak dapat membuka table.sql, formulir rusak?'),
(58696, 2220, 16, 'Kesalahan: ID rangkap pada baris'),
(58697, 2221, 16, 'Kesalahan: nama rangkap pada baris'),
(58698, 2222, 16, 'KESALAHAN: Field/Bagian'),
(58699, 2223, 16, 'KESALAHAN: Module PHP ZipArchive tidak ditemukan'),
(58700, 2225, 16, 'Kesalahan: pasword tidak cocok. Silahkan periksa pengetikan anda.'),
(58701, 2226, 16, 'Kesalahan: pasword tidak cocok. Silahkan periksa pengetikan anda.'),
(58702, 2227, 16, 'Kesalahan: file tersebut tidak ada'),
(58703, 2228, 16, 'KESALAHAN: Variabel tersebut berisi karakter yang tidak valid'),
(58704, 2229, 16, 'KESALAHAN: Tidak dapat menyalin file.'),
(58705, 2230, 16, 'Keslahan: Tidak dapat membuat arsip yang dapat didownload'),
(58706, 2231, 16, 'KESALAHAN: Tidak dapat Membuat Arsip Zip.'),
(58707, 2232, 16, 'KESALAHAN: Tidak dapat mengekstrak file.'),
(58708, 2233, 16, 'KESALAHAN: Tidak dapat memuat file kedalama database.'),
(58709, 2234, 16, 'KESALAHAN: Tidak dapat mengatur nomor versi.'),
(58710, 2235, 16, 'Kesalahan'),
(58711, 2236, 16, 'Status Akun/Rekening eRx'),
(58712, 2237, 16, 'Log eRx'),
(58713, 2238, 16, 'Nama ERX'),
(58714, 2239, 16, 'Pasword ERX'),
(58715, 2240, 16, 'Tugas ERX'),
(58716, 2241, 16, 'Pengguna ERX'),
(58717, 2242, 16, 'Eritema:'),
(58718, 2245, 16, 'Eskimo'),
(58719, 2247, 16, 'Pasien yang Ditetapkan'),
(58720, 2249, 16, 'Etnis'),
(58721, 2250, 16, 'Etnis atau Ras'),
(58722, 2251, 16, 'Etnis-Daftar Ras (tulis, hanya tambah opsional)'),
(58723, 2252, 16, 'ETIN'),
(58724, 2253, 16, 'Event'),
(58725, 2254, 16, 'Event Dimulai'),
(58726, 2255, 16, 'Kategori Event'),
(58727, 2256, 16, 'Tanggal Event'),
(58728, 2257, 16, 'Deskripsi Event'),
(58729, 2258, 16, 'Rincian Event'),
(58730, 2259, 16, 'Event tidak diulangi'),
(58731, 2260, 16, 'Durasi Event'),
(58732, 2261, 16, 'Durasi event dalam menit'),
(58733, 2262, 16, 'Biaya Event'),
(58734, 2263, 16, 'Lokasi Event'),
(58735, 2264, 16, 'Event diulang setiap'),
(58736, 2265, 16, 'Event diulang pada'),
(58737, 2266, 16, 'Waktu mulai Event'),
(58738, 2267, 16, 'Judul Event'),
(58739, 2268, 16, 'Judul Event'),
(58740, 2269, 16, 'Situs Web Event'),
(58741, 2270, 16, 'Event'),
(58742, 2271, 16, 'Event untuk'),
(58743, 2272, 16, 'Event dibuka pada jendela baru'),
(58744, 2273, 16, 'setiap'),
(58745, 2274, 16, 'Setiap'),
(58746, 2275, 16, 'setiap 3 jam'),
(58747, 2276, 16, 'setiap 4 jam'),
(58748, 2277, 16, 'setiap 5 jam'),
(58749, 2278, 16, 'setiap 6 jam'),
(58750, 2279, 16, 'setiap 8 jam'),
(58751, 2280, 16, 'Setiap yang Keempat'),
(58752, 2281, 16, 'Setiap Lainya'),
(58753, 2282, 16, 'Setiap yang Ketiga'),
(58754, 2283, 16, 'Setiap, setiap lainnya, setiap ketiga, dll.'),
(58755, 2285, 16, 'Pemeriksaan dan hasil pengujian'),
(58756, 2286, 16, 'Hasil pemeriksaan'),
(58757, 2289, 16, 'Pemeriksaan'),
(58758, 2290, 16, 'Tanggal Pemeriksaan'),
(58759, 2291, 16, 'Contoh'),
(58760, 2292, 16, 'Contoh'),
(58761, 2293, 16, 'Pemeriksaan/Pengujian'),
(58762, 2294, 16, 'Kecuali'),
(58763, 2295, 16, 'Tearing Berlebihan'),
(58764, 2296, 16, 'Pasien yang Dikecualikan'),
(58765, 2297, 16, 'Pengecualian'),
(58766, 2298, 16, 'Organisasi eksklusif Provider (EPO)'),
(58767, 2299, 16, 'Ukuran Kertas Eksekutif'),
(58768, 2300, 16, 'Latihan'),
(58769, 2301, 16, 'Pola Latihan'),
(58770, 2302, 16, 'Pola latihan'),
(58771, 2303, 16, 'Ada'),
(58772, 2304, 16, 'Keluar dari Administrasi'),
(58773, 2305, 16, 'Exp'),
(58774, 2306, 16, 'Memperluas'),
(58775, 2307, 16, 'memperluas'),
(58776, 2308, 16, 'Perluas Semua'),
(58777, 2311, 16, 'Penglihatan Diperluas'),
(58778, 2312, 16, 'Form_encounter.pid diharapkan akan menjadi '),
(58779, 2313, 16, 'Kadaluarsa'),
(58780, 2314, 16, 'Tanggal Kadaluarsa'),
(58781, 2315, 16, 'Berakhir'),
(58782, 2316, 16, 'berakhir pada'),
(58783, 2317, 16, 'Ekspor'),
(58784, 2318, 16, 'Ekspor sebagai CSV'),
(58785, 2319, 16, 'Ekspor Konfigurasi'),
(58786, 2322, 16, 'Ekspor Demografic Pasien'),
(58787, 2323, 16, 'Ekspor Laporan PQRI'),
(58788, 2325, 16, 'Ekspor yang Dipilih sebagai CSV'),
(58789, 2326, 16, 'Ekspor yang Dipilih ke Koleksi'),
(58790, 2327, 16, 'Ekspor ke CSV'),
(58791, 2328, 16, 'Ekspor ke sistem tagihan eksternal'),
(58792, 2329, 16, 'Eksposur ke Negara Asing'),
(58793, 2330, 16, 'Eksposur Ke Negara Asing'),
(58794, 2331, 16, 'Waktu Ext(Eksternal) Terkumpul'),
(58795, 2332, 16, 'Eksternal'),
(58796, 2336, 16, 'ID Eksternal'),
(58797, 2337, 16, 'Id Eksternal'),
(58798, 2338, 16, 'Identifier eksternal'),
(58799, 2339, 16, 'Hanya Eksternal'),
(58800, 2342, 16, 'Rujukan Eksternal'),
(58801, 2343, 16, 'Tindak Lanjut Rujukan Eksternal'),
(58802, 2344, 16, 'Rujukan eksternal?'),
(58803, 2345, 16, 'Rujukan Eksternal'),
(58804, 2346, 16, 'Ekstrak file zip'),
(58805, 2347, 16, 'Sedang mengekstrak file. Ini akan sedikit memakan waktu...'),
(58806, 2348, 16, 'Eksudat:'),
(58807, 2349, 16, 'Iritasi Mata'),
(58808, 2350, 16, 'Sakit Mata'),
(58809, 2351, 16, 'Mata Kemerahan'),
(58810, 2352, 16, 'Mata'),
(58811, 2353, 16, 'F'),
(58812, 2354, 16, 'F/H Masalah Darah'),
(58813, 2355, 16, 'F/H Hirsutisme Wanita/Striae'),
(58814, 2356, 16, 'Fasilitas'),
(58815, 2357, 16, 'Fasilitas'),
(58816, 2358, 16, 'fasilitas'),
(58817, 2359, 16, 'Fasilitas Administrasi'),
(58818, 2360, 16, 'Fasilitas Kota'),
(58819, 2361, 16, 'Fasilitas Kode'),
(58820, 2362, 16, 'Fasilitas kode Negara'),
(58821, 2363, 16, 'Fasilitas Fax'),
(58822, 2364, 16, 'Nama Fasilitas'),
(58823, 2365, 16, 'Fasilitas NPI'),
(58824, 2366, 16, 'Fasilitas Telepon'),
(58825, 2368, 16, 'Fasilitas Negara'),
(58826, 2369, 16, 'Fasilitas Jalan'),
(58827, 2370, 16, 'Fasilitas Zip'),
(58828, 2372, 16, 'Fasilitas:'),
(58829, 2373, 16, 'GAGAL'),
(58830, 2374, 16, 'gagal'),
(58831, 2375, 16, 'Gagal'),
(58832, 2383, 16, 'kegagaln'),
(58833, 2390, 16, 'Riwayat Keluarga'),
(58834, 2391, 16, 'Riwayat Keluarga dari Glaukoma'),
(58835, 2392, 16, 'Riwayat Keluarga:'),
(58836, 2394, 16, 'Pembayaran Keluarga'),
(58837, 2395, 16, 'Ukuran Keluarga'),
(58838, 2396, 16, 'Indah'),
(58839, 2398, 16, 'Persia'),
(58840, 2400, 16, 'Ayah'),
(58841, 2402, 16, 'Kelelahan'),
(58842, 2403, 16, 'Kelelahan'),
(58843, 2404, 16, 'Fax'),
(58844, 2405, 16, 'Jumlah Fax'),
(58845, 2406, 16, 'Nomor fax'),
(58846, 2408, 16, 'Fax/Scan'),
(58847, 2409, 16, 'Faks Masuk'),
(58848, 2410, 16, 'Faks Keluar'),
(58849, 2411, 16, 'Fitur'),
(58850, 2412, 16, 'Februari'),
(58851, 2413, 16, 'Februari'),
(58852, 2414, 16, 'FECA'),
(58853, 2415, 16, 'ID Obat Federal'),
(58854, 2416, 16, 'EIN Federal'),
(58855, 2417, 16, 'ID Pajak Federal'),
(58856, 2418, 16, 'Biaya'),
(58857, 2419, 16, 'biaya'),
(58858, 2420, 16, 'Biaya tidak diizinkan'),
(58859, 2421, 16, 'Lembar Biaya'),
(58860, 2422, 16, 'Opsi Lembar Biaya'),
(58861, 2423, 16, 'Biaya'),
(58862, 2424, 16, 'Wanita'),
(58863, 2425, 16, 'AP Wanita'),
(58864, 2426, 16, 'Kondom Wanita'),
(58865, 2427, 16, 'Wanita G'),
(58866, 2428, 16, 'Wanita LC'),
(58867, 2429, 16, 'Wanita P'),
(58868, 2430, 16, 'Gejala Kewanitaan'),
(58869, 2431, 16, 'Perempuan VSC'),
(58870, 2434, 16, 'Demam'),
(58871, 2435, 16, 'Demam:'),
(58872, 2436, 16, 'FH Masalah Darah'),
(58873, 2437, 16, 'Fibroids'),
(58874, 2441, 16, 'Jenis bagian yang akan digunakan untuk negara majikan atau pelanggan dalam demografi.'),
(58875, 2442, 16, 'Jenis bagian yang akan digunakan untuk negara majikan atau pelanggan dalam demografi.'),
(58876, 2443, 16, 'Field(Bagian) tidak ada!'),
(58877, 2447, 16, 'File'),
(58878, 2448, 16, 'file dalam direktori dokumentasi untuk mempelajari bagaimana cara untuk mengotomatisasi proses menciptakan backup log'),
(58879, 2449, 16, 'lokasi file'),
(58880, 2450, 16, 'Pengelolaan file'),
(58881, 2453, 16, 'Hak akses file diberikan kepada pengguna LibreEHR'),
(58882, 2455, 16, 'File Kamar'),
(58883, 2456, 16, 'File untuk diupload'),
(58884, 2458, 16, 'FIle dengan nama yang sama telah ada pada lokasi:'),
(58885, 2459, 16, 'Nama file'),
(58886, 2461, 16, 'File'),
(58887, 2462, 16, 'Filipina'),
(58888, 2463, 16, 'Isi salah satu dibawah baris.'),
(58889, 2464, 16, 'Isi di sini hanya jika mengirim email pemberitahuan kepada pasien'),
(58890, 2465, 16, 'Isikan nilai-nilai dibawah'),
(58891, 2467, 16, 'Isi Baris.'),
(58892, 2468, 16, 'Filter(Penyaringan)'),
(58893, 2469, 16, 'Penyaringan untuk Konstan'),
(58894, 2470, 16, 'Penyaringan untuk Definisi'),
(58895, 2472, 16, 'penyaringan'),
(58896, 2473, 16, 'Penyaring'),
(58897, 2474, 16, 'Akhir'),
(58898, 2475, 16, 'Diagnosa Akhir'),
(58899, 2476, 16, 'Diagnosa akhir oleh pakar'),
(58900, 2478, 16, 'Finansial/Keuangan'),
(58901, 2479, 16, 'Tanggal Penutupan Keuangan (yyyy-mm-dd)'),
(58902, 2480, 16, 'Laporan Keuangan - apapun'),
(58903, 2481, 16, 'Laporan Keuangan - encounter saya'),
(58904, 2482, 16, 'Tanggal Tinjauan Keuangan'),
(58905, 2484, 16, 'Temukan'),
(58906, 2485, 16, 'Temukan yang Tersedia'),
(58907, 2486, 16, 'Temukan Janji Temu yang Tersedia'),
(58908, 2487, 16, 'Cari Pasien'),
(58909, 2488, 16, 'Cari Bahan Edukasi Pasien'),
(58910, 2489, 16, 'Temuan'),
(58911, 2490, 16, 'Temuan oleh pakar'),
(58912, 2491, 16, 'Baik'),
(58913, 2492, 16, 'Selesai Pembayaran'),
(58914, 2495, 16, 'Pertama'),
(58915, 2497, 16, 'Hari pertama dalam minggu'),
(58916, 2498, 16, 'Nama Depan'),
(58917, 2499, 16, 'Nama depan'),
(58918, 2500, 16, 'Nama Depan:'),
(58919, 2503, 16, 'Kebugaran'),
(58920, 2504, 16, 'Tingkat Kebugaran'),
(58921, 2505, 16, 'Tingkat Kebugaran untuk pemain ini pada hari ini'),
(58922, 2507, 16, 'Kebugaran untuk Bermain'),
(58923, 2508, 16, 'Tanggal Encounter yang Ditetapkan - encounter apapun'),
(58924, 2509, 16, 'Perbaiki ini'),
(58925, 2510, 16, 'FL'),
(58926, 2511, 16, 'Perut Kembung'),
(58927, 2512, 16, 'Aliran'),
(58928, 2514, 16, 'Musim flu'),
(58929, 2515, 16, 'Musim Flu'),
(58930, 2516, 16, 'Vaksinasi flu'),
(58931, 2517, 16, 'Masalah elektrolit dan cairan'),
(58932, 2518, 16, 'FMS'),
(58933, 2519, 16, 'Ukuran Kertas Folio'),
(58934, 2520, 16, 'Mengikuti secara manual'),
(58935, 2522, 16, 'Menindaklanjuti'),
(58936, 2524, 16, 'Alasan Menindaklanjuti'),
(58937, 2525, 16, 'Berikut adalah konstanta custom baru:'),
(58938, 2526, 16, 'Berikut adalah bahasa custom baru:'),
(58939, 2527, 16, 'Berikut adalah definisi baru (Bahasa, Konstanta, Definisi)'),
(58940, 2529, 16, 'Layanan Penindaklanjut'),
(58941, 2530, 16, 'Tindak Lanjut Dinyatakan'),
(58942, 2531, 16, 'Makanan yang Tidak dapat Ditoleransi'),
(58943, 2532, 16, 'Kaki'),
(58944, 2533, 16, 'Masalah kaki'),
(58945, 2534, 16, 'Kaki:'),
(58946, 2535, 16, 'Cedera Sepakbola'),
(58947, 2537, 16, 'Laporan Cedera Sepakbola'),
(58948, 2538, 16, 'Jenis Alas Kaki/Sepatu'),
(58949, 2539, 16, 'untuk'),
(58950, 2540, 16, 'Untuk'),
(58951, 2541, 16, 'Untuk kode'),
(58952, 2543, 16, 'Untuk Klaim Pertemuan'),
(58953, 2544, 16, 'Sebagai contoh:'),
(58954, 2547, 16, 'untuk Faktur/Tagihan'),
(58955, 2548, 16, 'Hanya untuk Medicare, memaksa provider yang mengacu/dimaksud sama dengan provider render.'),
(58956, 2552, 16, 'Untuk Praktisi/Organisasi yang Dimaksud'),
(58957, 2553, 16, 'Untuk masa lalu'),
(58958, 2554, 16, 'untuk variabel'),
(58959, 2555, 16, 'untuk:'),
(58960, 2556, 16, 'Memaksa Tagihan Widget Terbuka'),
(58961, 2557, 16, 'Memaksa Membuat Pasien Baru'),
(58962, 2559, 16, 'Lengan Bawah/Tangan'),
(58963, 2560, 16, 'Formulir'),
(58964, 2561, 16, 'formulir'),
(58965, 2564, 16, 'Format'),
(58966, 2565, 16, 'format'),
(58967, 2567, 16, 'Format salah untuk NDC'),
(58968, 2568, 16, 'Format digunakan untuk menampilkan tanggal terbanyak.'),
(58969, 2569, 16, 'Format digunakan untuk menampilkan waktu terbanyak.'),
(58970, 2570, 16, 'Laporat Terformat'),
(58971, 2571, 16, 'Bekas Perokok'),
(58972, 2572, 16, 'Formulir'),
(58973, 2573, 16, 'Formulir Administrasi'),
(58974, 2575, 16, 'Teruskan'),
(58975, 2576, 16, 'Teruskan Halaman melalui Fax'),
(58976, 2577, 16, 'Diteruskan'),
(58977, 2579, 16, 'Keempat'),
(58978, 2581, 16, 'Patah'),
(58979, 2582, 16, 'Patah di Navicula'),
(58980, 2583, 16, 'Patah tulang rusuk malleolus'),
(58981, 2584, 16, 'Patah di tengah-tengah malleolus'),
(58982, 2585, 16, 'Pematahan, Berdasarkan dari Metatarsal kelima (5)'),
(58983, 2587, 16, 'Perancis'),
(58984, 2588, 16, 'Peracis (Kanada)'),
(58985, 2589, 16, 'Perancis (Standar)'),
(58986, 2590, 16, 'Frekuensi'),
(58987, 2591, 16, 'Sering Pilek'),
(58988, 2592, 16, 'Sering Sakit'),
(58989, 2593, 16, 'Jumat'),
(58990, 2594, 16, 'Jumat'),
(58991, 2595, 16, 'Dari'),
(58992, 2596, 16, 'DARI'),
(58993, 2597, 16, 'dari'),
(58994, 2598, 16, 'Tanggal Dari Tidak Boleh Lebih Dari Tanggal Sampai'),
(58995, 2599, 16, 'Dari:'),
(58996, 2600, 16, 'Dari: '),
(58997, 2601, 16, 'DARI_KOTA'),
(58998, 2603, 16, 'DARI_NAMADEPAN'),
(58999, 2604, 16, 'DARI_NAMAAKHIR'),
(59000, 2605, 16, 'DARI_NAMATENGAH'),
(59001, 2607, 16, 'DARI_TELEPONSELULER'),
(59002, 2608, 16, 'DARI_POS'),
(59003, 2609, 16, 'DARI_NEGARA'),
(59004, 2610, 16, 'DARI_JALAN'),
(59005, 2611, 16, 'DARI_JUDUL'),
(59006, 2612, 16, 'DARI_PIDATOPERPISAHAN'),
(59007, 2613, 16, 'Kantor Depan'),
(59008, 2614, 16, 'Penerimaan Kantor Depan'),
(59009, 2615, 16, 'Laporan Penerimaan Kantor Depan'),
(59010, 2616, 16, 'Record/Catatan Depan'),
(59011, 2617, 16, 'Frontal Kanan:'),
(59012, 2619, 16, 'Nama Lengkap'),
(59013, 2620, 16, 'Path kendali ke direktori yang berisi executable MySQL.'),
(59014, 2621, 16, 'Path kendali ke direktori yang berisi executable Perl.'),
(59015, 2622, 16, 'Path kendali ke direktori untuk backup log event.'),
(59016, 2623, 16, 'Path kendarli ke direktori yang digunakan untuk file sementara.'),
(59017, 2624, 16, 'Putar Penuh'),
(59018, 2625, 16, 'Pelatihan Penuh'),
(59019, 2626, 16, 'Dibayar Penuh'),
(59020, 2633, 16, 'G'),
(59021, 2634, 16, 'G/DL'),
(59022, 2636, 16, 'Kondisi Kandung Empedu'),
(59023, 2637, 16, 'Batu Empedu'),
(59024, 2638, 16, 'Periode permainan'),
(59025, 2639, 16, 'Permainan'),
(59026, 2640, 16, 'Permainan Terlewat'),
(59027, 2641, 16, 'permainan/event'),
(59028, 2642, 16, 'Permainan/Event Terlewat'),
(59029, 2644, 16, 'Radang Perut'),
(59030, 2645, 16, 'Nyeri Lambung'),
(59031, 2646, 16, 'Gastrointestinal'),
(59032, 2647, 16, 'Laporan Statistik GCAC'),
(59033, 2648, 16, 'Status GCAC'),
(59034, 2649, 16, 'Formulir kunjungan GCAC tidak ada'),
(59035, 2650, 16, 'Jenis Kelamin'),
(59036, 2651, 16, 'Jenis Kelamin '),
(59037, 2652, 16, 'Umum'),
(59038, 2655, 16, 'Kategori Layanan Umum'),
(59039, 2657, 16, 'Hasilkan dan download klaim kertas CMS 1500'),
(59040, 2658, 16, 'Hasilkan dan download klaim kertas HCFA 1500'),
(59041, 2659, 16, 'Hasilkan dan download batch X12'),
(59042, 2660, 16, 'Hasilkan dan download batch klaim encounter X12'),
(59043, 2663, 16, 'Hasilkan dan kirim resep yang diperbolehkan secara elektronik.'),
(59044, 2664, 16, 'Hasilkan CMS 1500'),
(59045, 2665, 16, 'Hasilkan PDF CMS 1500'),
(59046, 2666, 16, 'Hasilkan TEKS CMS 1500'),
(59047, 2667, 16, 'Hasilkan HCFA'),
(59048, 2669, 16, 'Hasilkan Surat'),
(59049, 2670, 16, 'Hasilkan Surat tentang '),
(59050, 2671, 16, 'Hasilkan laporan PQRI (Metode A)'),
(59051, 2673, 16, 'Hasilkan laporan PQRI (Metode B)'),
(59052, 2677, 16, 'Hasilkan Laporan'),
(59053, 2678, 16, 'Hasilkan Nama User Dan Pasword Untuk'),
(59054, 2679, 16, 'Hasilkan X12'),
(59055, 2680, 16, 'Hasilkan Encounter X12'),
(59056, 2682, 16, 'Hasilkan pada'),
(59057, 2683, 16, 'Menghasilkan'),
(59058, 2684, 16, 'Kemih'),
(59059, 2687, 16, 'Jerman'),
(59060, 2691, 16, 'Dapatkan HL7'),
(59061, 2692, 16, 'Glaukoma'),
(59062, 2693, 16, 'Riwayat Keluarga Glaukoma'),
(59063, 2694, 16, 'Global'),
(59064, 2696, 16, 'ID Global'),
(59065, 2697, 16, 'Pengaturan Global'),
(59066, 2698, 16, 'Global'),
(59067, 2699, 16, 'GM/DL'),
(59068, 2700, 16, 'pergi'),
(59069, 2701, 16, 'Pergi'),
(59070, 2704, 16, 'Pergi ke'),
(59071, 2705, 16, 'Pergi ke minggu dari'),
(59072, 2706, 16, 'Pergi ke Hari Ini'),
(59073, 2711, 16, 'Tinkgat Cedera'),
(59074, 2712, 16, 'Tingkat:'),
(59075, 2713, 16, 'gram'),
(59076, 2714, 16, 'Jumlah Seluruhnya'),
(59077, 2715, 16, 'Jumlah Seluruhnya'),
(59078, 2718, 16, 'Graphable'),
(59079, 2720, 16, 'Lebih Dari'),
(59080, 2721, 16, 'Lebih Dari atau Sama Dengan'),
(59081, 2722, 16, 'Yunani'),
(59082, 2724, 16, 'Grup'),
(59083, 2725, 16, 'Nama Grup'),
(59084, 2726, 16, 'Nama grup tidak boleh kosong'),
(59085, 2727, 16, 'Nama grup tidak boleh dimulai dengan angka atau spasi.'),
(59086, 2728, 16, 'Nama grup tidak boleh dimulai dengan angka.'),
(59087, 2729, 16, 'Nomor Grup'),
(59088, 2730, 16, 'Payment Grup'),
(59089, 2731, 16, 'Grup:'),
(59090, 2732, 16, 'Nama grup'),
(59091, 2733, 16, 'Kontrol Akses dan Grup'),
(59092, 2734, 16, 'Grafik Pertumbuhan'),
(59093, 2735, 16, 'Grafik Perumbuhan'),
(59094, 2736, 16, 'gtts(tetes)'),
(59095, 2737, 16, 'Guamanian'),
(59096, 2739, 16, 'Nama Wali'),
(59097, 2741, 16, 'Pemeriksaan Ginekologi'),
(59098, 2742, 16, 'h'),
(59099, 2743, 16, 'h.s.'),
(59100, 2744, 16, 'H/O Hepatitis'),
(59101, 2745, 16, 'telah berhasi dihapus. Setiap sub kategori jika ada dipindahkan dibawah ini'),
(59102, 2746, 16, 'Haematoma / memar'),
(59103, 2747, 16, 'Status HAI'),
(59104, 2750, 16, 'Tangan + jari'),
(59105, 2751, 16, 'Masalah Tangan'),
(59106, 2753, 16, 'Kesulitan w / o'),
(59107, 2754, 16, 'telah dikaitkan dengan kunjungan'),
(59108, 2755, 16, 'telah berakhir'),
(59109, 2756, 16, 'Hash'),
(59110, 2757, 16, 'Hash tidak ada pada file ini. Hash yang baru telah dihasilkan.'),
(59111, 2758, 16, 'Hash tidak cocok. Integritas data telah diganggu.'),
(59112, 2760, 16, 'Hawaii'),
(59113, 2761, 16, 'Kegiatan Berbahaya'),
(59114, 2762, 16, 'Kegiatan berbahaya'),
(59115, 2763, 16, 'Batas kiri HCFA dalam angka'),
(59116, 2764, 16, 'Batas HCFA'),
(59117, 2765, 16, 'Batas atas HCFA dalam angka'),
(59118, 2767, 16, 'he PostCalendar '),
(59119, 2768, 16, 'Kepala'),
(59120, 2769, 16, 'Lingkar Kepala'),
(59121, 2770, 16, 'Lingkar Kepala'),
(59122, 2771, 16, 'Sakit Kepala'),
(59123, 2772, 16, 'Sakit Kepala'),
(59124, 2773, 16, 'Operasi perawatan kesehatan'),
(59125, 2774, 16, 'Operasi Perawatan Kesehatan'),
(59126, 2775, 16, 'Pusat/klinik kesehatan'),
(59127, 2776, 16, 'Organisasi Pemeliharaan Kesehatan'),
(59128, 2777, 16, 'Organisasi Pemeliharaan Kesehatan (HMO) Resiko Medicare'),
(59129, 2778, 16, 'Gangguan Pendengaran'),
(59130, 2779, 16, 'Serangan Jantung'),
(59131, 2780, 16, 'Penyakit Jantung'),
(59132, 2781, 16, 'Gagal jantung'),
(59133, 2782, 16, 'Masalah Jantung'),
(59134, 2783, 16, 'Masalah Jantung'),
(59135, 2784, 16, 'Bedah jantung'),
(59136, 2785, 16, 'Transplantasi jantung'),
(59137, 2786, 16, 'JANTUNG:'),
(59138, 2787, 16, 'Mulas'),
(59139, 2788, 16, 'Panas atau Dingin'),
(59140, 2789, 16, 'Panas Atau Dingin'),
(59141, 2791, 16, 'Ibrani'),
(59142, 2793, 16, 'HEENT'),
(59143, 2794, 16, 'Tinggi'),
(59144, 2796, 16, 'Membantu'),
(59145, 2797, 16, 'membantu'),
(59146, 2798, 16, 'Hematemesis'),
(59147, 2799, 16, 'Hematochezia'),
(59148, 2800, 16, 'Hematologi'),
(59149, 2801, 16, 'Hematuria'),
(59150, 2802, 16, 'Hemoglobin'),
(59151, 2803, 16, 'Hemoglobin A1C'),
(59152, 2804, 16, 'Hemoptisis'),
(59153, 2805, 16, 'Hepatitis'),
(59154, 2806, 16, 'Hepatitis A 1'),
(59155, 2807, 16, 'Hepatitis A 2'),
(59156, 2808, 16, 'Hepatitis B 1'),
(59157, 2809, 16, 'Hepatitis B 2'),
(59158, 2810, 16, 'Hepatitis B 3'),
(59159, 2811, 16, 'disini'),
(59160, 2813, 16, 'Perbaikan Hernia'),
(59161, 2814, 16, 'Piringan Hernia'),
(59162, 2815, 16, 'Herpes'),
(59163, 2816, 16, 'Keraguan'),
(59164, 2817, 16, 'heyyo. anda telah di sini untuk '),
(59165, 2818, 16, 'Hib 1'),
(59166, 2819, 16, 'Hib 2'),
(59167, 2820, 16, 'Hib 3'),
(59168, 2821, 16, 'Hib 4'),
(59169, 2822, 16, 'Tersembunyi'),
(59170, 2823, 16, 'Kegiatan Administrasi yang Tersembunyi'),
(59171, 2824, 16, 'Sembunyikan'),
(59172, 2825, 16, 'Sembunyikan Detail'),
(59173, 2827, 16, 'Sembunyikan Pilihan Enkripsi/Dekripsi Dalam Pengelolaan Dokumen'),
(59174, 2828, 16, 'Sembunyikan Menu'),
(59175, 2830, 16, 'Sembunyikan Pengingat'),
(59176, 2831, 16, 'Sembunyi/Tampilkan Kolom'),
(59177, 2833, 16, 'Tinggi'),
(59178, 2834, 16, 'Tekanan Darah Tinggi'),
(59179, 2835, 16, 'Hindi'),
(59180, 2836, 16, 'Panggul + selangkangan'),
(59181, 2837, 16, 'Panggul dan selangkangan'),
(59182, 2838, 16, 'Masalah Panggul'),
(59183, 2839, 16, 'Penggantian Panggul'),
(59184, 2840, 16, 'Pemberitahuan HIPAA Diterima'),
(59185, 2842, 16, 'Hirsutisme/Striae'),
(59186, 2843, 16, 'Hispanic'),
(59187, 2844, 16, 'Hispanic - Lainnya (Lahir di US)'),
(59188, 2845, 16, 'Hispanic - Lainnya (Lahir diluar US)'),
(59189, 2846, 16, 'Hispanic atau Latino'),
(59190, 2847, 16, 'Riwayat'),
(59191, 2848, 16, 'Riwayat Data'),
(59192, 2849, 16, 'Riwayat Tanggal'),
(59193, 2851, 16, 'Bunyi Riwayat'),
(59194, 2852, 16, 'Riwayat tidak diizinkan'),
(59195, 2853, 16, 'Riwayat dari Desiran yang Abnormal'),
(59196, 2854, 16, 'Pukulan'),
(59197, 2855, 16, 'HIV'),
(59198, 2858, 16, 'Pelihat HL7'),
(59199, 2860, 16, 'HMOL/L'),
(59200, 2861, 16, 'Hmong'),
(59201, 2862, 16, 'Tahan [Ctrl] untuk beberapa pilihan atau untuk tidak memilih'),
(59202, 2863, 16, 'Tahan Ctrl untuk memilih beberapa item'),
(59203, 2864, 16, 'Tahan Ctrl untuk memilih beberapa regu'),
(59204, 2865, 16, 'Home'),
(59205, 2866, 16, 'Telepon Rumah'),
(59206, 2867, 16, 'Nomor Telepon Rumah'),
(59207, 2868, 16, 'Tunawisma atau serupa?'),
(59208, 2869, 16, 'Tunawisma, dll'),
(59209, 2870, 16, 'Tunawisma, dll'),
(59210, 2872, 16, 'Nama Host'),
(59211, 2873, 16, 'Nama Host tidak boleh kosong'),
(59212, 2875, 16, 'Jam/Waktu'),
(59213, 2876, 16, 'Jam/Waktu'),
(59214, 2878, 16, 'Bagaimana Cedera Terjadi?'),
(59215, 2879, 16, 'Bagaimana Cedera terjadi?:'),
(59216, 2880, 16, 'Bagaimana mereka mendengar tentang kami'),
(59217, 2881, 16, 'Berapa bulan kedepan untuk query untuk event mendatang?'),
(59218, 2882, 16, 'HPI:'),
(59219, 2883, 16, 'HT'),
(59220, 2884, 16, 'HTML'),
(59221, 2886, 16, 'Link Https untuk dukungan LibreEHR LLC Lab Exchange Service (Layanan Pertukaran Lab)'),
(59222, 2887, 16, 'Hongaria'),
(59223, 2888, 16, 'Direktori Hylafax'),
(59224, 2889, 16, 'Perintah Enscript Hylafax'),
(59225, 2890, 16, 'Server Hylafax'),
(59226, 2891, 16, 'Nama host server Hylafax.'),
(59227, 2892, 16, 'Hiperaktif'),
(59228, 2893, 16, 'Hipertensi'),
(59229, 2894, 16, 'Hipertensi: Pengukuran Tekandan Darah'),
(59230, 2895, 16, 'Hipertensi: Pengukuran Tekandan Darah (CQM)'),
(59231, 2896, 16, 'Hipertiroid'),
(59232, 2897, 16, 'Hypothyroidism'),
(59233, 2898, 16, 'Histerektomi'),
(59234, 2899, 16, 'Saya'),
(59235, 2900, 16, 'Saya sibuk selama waktu ini.'),
(59236, 2901, 16, 'Saya tidak memiliki izin untuk membaca '),
(59237, 2902, 16, 'ICD'),
(59238, 2905, 16, 'ICD9'),
(59239, 2909, 16, 'ID'),
(59240, 2910, 16, 'Id'),
(59241, 2911, 16, 'ID tidak boleh kosong'),
(59242, 2912, 16, 'Kartu ID'),
(59243, 2913, 16, 'Hari'),
(59244, 2914, 16, 'diidentifikasi sebagai'),
(59245, 2915, 16, 'Identifier(satu kata)'),
(59246, 2917, 16, 'Detik Waktu Sesi Siaga'),
(59247, 2919, 16, 'Jika semua data untuk semua kolom ini adalah untuk melengkapi formulir'),
(59248, 2920, 16, 'Jika pembenaran tagihan digunakan masukkan nama dari tipe kode diagnosa.'),
(59249, 2921, 16, 'jika dimasukkan, pilih hanya mereka yang memiliki layanan ini'),
(59250, 2922, 16, 'Jika nama, salah satu bagian dari nama belakang atau nama belakang, nama depan'),
(59251, 2923, 16, 'Jika membayar dengan'),
(59252, 2924, 16, 'Jika seseorang telah meninggal, maka masukkan tangal wafat.'),
(59253, 2925, 16, 'Jika SMTP digunakan, nama host server atau alamat IP.'),
(59254, 2926, 16, 'Jika SMTP digunakan, nomor port TCP Server (biasanya 25)'),
(59255, 2927, 16, 'jika menganggur masukkan Mahasiswa'),
(59256, 2929, 16, 'Jika anda mengubah tugas e-RX untuk ePrescription(Resep Elektronik), mungkin akan mempengaruhi alur kerja ePrescription. Jika anda menghadapi kesulitan, hubungi vendor ePrescription anda.'),
(59257, 2931, 16, 'Jika Anda telah memilih untuk mengupload pengiriman uang elektronik, maka jendela pencarian menampilkan kembali dengan sendirinya dengan faktu/tagihan yang sesuai dari X12 file. Anda bisa mengklik pada salah satu nomor faktur (seperti yang dijelaskan di bawah) jika anda ingin melakukan koreksi sebelum informasi pengiriman uang diterapkan. Untuk menerapkan perubahan, klik tombol Proses ERA File di bagian bawah halaman. Ini akan menghasilkan sebuah jendela baru dengan laporan rinci.'),
(59258, 2932, 16, 'Jika Anda telah memasuki Tanggal Bayar di halaman pencarian, ini akan menimpa postingan tanggal pembayaran dan penyesuaian yang sebaliknya diambil dari file X12. Ini mungkin berguna untuk keperluan laporan, jika Anda ingin laporan penerimaan anda menggunakan tanggal posting Anda daripada tanggal pengolahan asuransi perusahaan. Catatan bahwa ini juga akan mempengaruhi tanggal pembayaran sebelumnya dan penyesuaian yang dimasukkan ke dalam klaim sekunder.'),
(59259, 2933, 16, 'Jika Anda ingin mengubah jenis data, atau tambahkan baris atau kolom'),
(59260, 2934, 16, 'Jika anda ingin mengupgrade database, maka tempatkan file zip database pada direktori berikut'),
(59261, 2936, 16, 'Abaikan'),
(59262, 2937, 16, 'Penyakit'),
(59263, 2938, 16, 'IM'),
(59264, 2941, 16, 'Layanan Pencitraan(Image)'),
(59265, 2942, 16, 'Imunisasi'),
(59266, 2943, 16, 'Kode Imunisasi'),
(59267, 2945, 16, 'Tanggal Imunisasi'),
(59268, 2947, 16, 'Nomor Lot Imunisasi'),
(59269, 2948, 16, 'Produsen imunisasi'),
(59270, 2949, 16, 'Registri/Pendaftaran Imunisasi'),
(59271, 2951, 16, 'Layanan Imunisasi'),
(59272, 2952, 16, 'Judul Imunisasi'),
(59273, 2953, 16, 'Imunisasi'),
(59274, 2954, 16, 'Mengebalkan'),
(59275, 2955, 16, 'Imunologi'),
(59276, 2956, 16, 'Penanaman/Memasukkan'),
(59277, 2957, 16, 'Impor'),
(59278, 2961, 16, 'Impor sertifikat ke browser'),
(59279, 2962, 16, 'Impor Konfigurasi'),
(59280, 2964, 16, 'Impor Pasien'),
(59281, 2965, 16, 'Impor Demografi Pasien'),
(59282, 2969, 16, 'Diimpor dari Akuntansi'),
(59283, 2972, 16, 'Peningkatan'),
(59284, 2973, 16, 'di'),
(59285, 2974, 16, 'DI'),
(59286, 2975, 16, 'di setiap mata'),
(59287, 2976, 16, 'di mata kiri'),
(59288, 2977, 16, 'dalam lubang hidung'),
(59289, 2978, 16, 'Di Kantor'),
(59290, 2979, 16, 'di mata kanan'),
(59291, 2980, 16, 'dalam rumah'),
(59292, 2981, 16, 'Tidak Aktif'),
(59293, 2982, 16, 'Hari Tidak Aktif'),
(59294, 2983, 16, 'Kotak Masuk'),
(59295, 2986, 16, 'Sertakan Checksum'),
(59296, 2987, 16, 'Memasukkan Selesai'),
(59297, 2988, 16, 'Sertakan pengguna tidak aktif'),
(59298, 2989, 16, 'Sertakan Yang tidak dikategorikan'),
(59299, 2990, 16, 'Sertakan Data tidak terstruktur'),
(59300, 2991, 16, 'Setakan Vital(Bagian Vital)'),
(59301, 2992, 16, 'Sertakan data vital(bagian vital)?'),
(59302, 2993, 16, 'Pencantuman/Penyertaan'),
(59303, 2994, 16, 'Pendapatan'),
(59304, 2996, 16, 'Tidak Selesai'),
(59305, 2997, 16, 'Pengobatan/Perawatan Aborsi Tidak Selesai'),
(59306, 2998, 16, 'Inkontinensia'),
(59307, 2999, 16, 'Memasukkan hasil tes lab klinis kedalam teknologi EHR bersertifikat sebagai data terstruktur.'),
(59308, 3001, 16, 'meningkat:'),
(59309, 3002, 16, 'Ganti Rugi Asuransi'),
(59310, 3003, 16, 'Tidak Tetap'),
(59311, 3004, 16, 'India'),
(59312, 3005, 16, 'Menunujukkan abnormalitas'),
(59313, 3006, 16, 'Menunjukkan jika masalah ini masih aktif saat ini'),
(59314, 3008, 16, 'Indikator untuk penggunaan khusus'),
(59315, 3009, 16, 'Pasien Miskin'),
(59316, 3010, 16, 'Laporan Pasien Miskin'),
(59317, 3011, 16, 'Miskin'),
(59318, 3014, 16, 'Terimbas Aborsi'),
(59319, 3016, 16, 'Tidak memenuhi syarat'),
(59320, 3017, 16, 'Infeksi/Abses'),
(59321, 3018, 16, 'Infeksi'),
(59322, 3019, 16, 'Infert Couns'),
(59323, 3020, 16, 'Kemandulan'),
(59324, 3021, 16, 'Influensa 1'),
(59325, 3022, 16, 'Influensa 2'),
(59326, 3023, 16, 'Imunisasi Influensa untuk Pasien >= 50 Tahun'),
(59327, 3024, 16, 'Imunisasi Influensa untuk Pasien >= 50 Tahun (CQM)'),
(59328, 3025, 16, 'Vaksin Influensa'),
(59329, 3026, 16, 'Info'),
(59330, 3027, 16, 'Info tes 1'),
(59331, 3028, 16, 'Info tes 2'),
(59332, 3029, 16, 'Info tes 3'),
(59333, 3030, 16, 'Info tes 4'),
(59334, 3031, 16, 'Info tes 5'),
(59335, 3032, 16, 'Info tes 6'),
(59336, 3034, 16, 'penarikan'),
(59337, 3035, 16, 'inhilations'),
(59338, 3037, 16, 'Pengguna Awal'),
(59339, 3038, 16, 'Inj/Rehab'),
(59340, 3039, 16, 'Suntikan'),
(59341, 3040, 16, 'Injeksi'),
(59342, 3041, 16, 'Bagian Tubuh yang Cedera'),
(59343, 3042, 16, 'Cedera/Luka Keluar'),
(59344, 3043, 16, 'Cedera/Luka'),
(59345, 3044, 16, 'Mekanisme Cedera/Luka'),
(59346, 3045, 16, 'Laporan Gambaran Cedera/Luka'),
(59347, 3046, 16, 'Pengawasan Cedera/Luka'),
(59348, 3047, 16, 'Jenis Cedera/Luka'),
(59349, 3048, 16, 'Cedera/Penyakit terkait'),
(59350, 3051, 16, 'Masukkan Field(Bagian)'),
(59351, 3052, 16, 'USD'),
(59352, 3056, 16, 'Ins menyesuaikan'),
(59353, 3057, 16, 'Ins bundling'),
(59354, 3058, 16, 'Ins Kode'),
(59355, 3061, 16, 'Ins kelebihan pembayaran'),
(59356, 3063, 16, 'Ins pengembalian uang'),
(59357, 3064, 16, 'Ins Ringkasan'),
(59358, 3065, 16, 'Ins1'),
(59359, 3066, 16, 'Ins2'),
(59360, 3067, 16, 'Ins3'),
(59361, 3069, 16, 'Masukkan gagal: '),
(59362, 3070, 16, 'Masukkan kegiatan lama kedalam tabel'),
(59363, 3072, 16, 'Insomnia'),
(59364, 3074, 16, 'Inspeksi'),
(59365, 3075, 16, 'Ketidakstabilan / subluksasi'),
(59366, 3077, 16, 'Instal'),
(59367, 3079, 16, 'instal DB'),
(59368, 3081, 16, 'Menginstruksikan'),
(59369, 3082, 16, 'Instruksi/Perintah'),
(59370, 3084, 16, 'Instruksi:'),
(59371, 3086, 16, 'Insulin Dependent Diabetes'),
(59372, 3087, 16, 'Asuransi'),
(59373, 3088, 16, 'asuransi'),
(59374, 3093, 16, 'Perusahaan Asuransi'),
(59375, 3094, 16, 'Perusahaan Asuransi'),
(59376, 3095, 16, 'Perusahaan Asuransi'),
(59377, 3096, 16, 'Perusahaan Asuransi Cari/Tambah'),
(59378, 3098, 16, 'Data Asuransi'),
(59379, 3099, 16, 'Informasi asuransi pada file'),
(59380, 3100, 16, 'Nomor Asuransi'),
(59381, 3101, 16, 'Pembayaran Asuransi'),
(59382, 3103, 16, 'Provider Asuransi'),
(59383, 3107, 16, 'Pengambilan Kesimpulan'),
(59384, 3108, 16, 'Pengambilan Tanggal'),
(59385, 3109, 16, 'Penurunan Intelektual'),
(59386, 3113, 16, 'Kesalahan internal - tidak ada halaman yang terpilih!'),
(59387, 3114, 16, 'Kesalahan internal - ID pasien tidak disediakan!'),
(59388, 3115, 16, 'Kesalahan internal mengakses file yang diupload!'),
(59389, 3116, 16, 'Kesalahan internal!'),
(59390, 3117, 16, 'Kesalahan internal, tidak ada ID obat yang ditentukan!'),
(59391, 3119, 16, 'Kesalahan internal: klaim '),
(59392, 3120, 16, 'Kesalahan internal: encounter(pertemuan) '''),
(59393, 3121, 16, 'Kesalahan internal: encounter(pertemuan) tidak ada.'),
(59394, 3122, 16, 'Kesalahan internal: kami tidak terlihat berada pada encounter(pertemuan)!'),
(59395, 3123, 16, 'Identifier Internal(pid)'),
(59396, 3126, 16, 'Rujukan Internal'),
(59397, 3127, 16, 'Waktu Internal Diambil'),
(59398, 3128, 16, 'Tugas internasional'),
(59399, 3129, 16, 'Penerjemah'),
(59400, 3130, 16, 'Penerjemah dibutuhkan?'),
(59401, 3131, 16, 'Penyakit Paru Interstitial'),
(59402, 3132, 16, 'Interval/Selang'),
(59403, 3135, 16, 'Intervensi'),
(59404, 3137, 16, 'Ketidaktoleranan'),
(59405, 3139, 16, 'intramuskuler'),
(59406, 3140, 16, 'urat nadi'),
(59407, 3141, 16, 'Pengenalan'),
(59408, 3144, 16, 'Karakter tidak valid pada'),
(59409, 3147, 16, 'Panjang tidak valid untuk'),
(59410, 3148, 16, 'Karakter non numerik tidak valid pada'),
(59411, 3149, 16, 'Pembayar tidak valid atau tidak ada dalam sumber untuk kode '),
(59412, 3151, 16, 'Kode Layanan Tidak Valid'),
(59413, 3152, 16, 'Penunjukkan sumber tidak valid "'),
(59414, 3154, 16, 'InvAmt'),
(59415, 3155, 16, 'Inventaris'),
(59416, 3156, 16, 'Kegiatan Inventaris'),
(59417, 3157, 16, 'Inventaris dan jual produk obat dan non obat'),
(59418, 3158, 16, 'Inventaris dan jual obat saja'),
(59419, 3159, 16, 'Inventaris tidak tersedia untuk pesanan/perintah ini'),
(59420, 3160, 16, 'Daftar Inventaris'),
(59421, 3161, 16, 'Transaksi Inventaris'),
(59422, 3162, 16, 'Faktur/Tagihan'),
(59423, 3163, 16, 'faktur'),
(59424, 3166, 16, 'Tanggal Faktur'),
(59425, 3167, 16, 'Faktur tidak memiliki tanggal!'),
(59426, 3168, 16, 'Nomor Faktur'),
(59427, 3169, 16, 'Nomor Referensi Faktur'),
(59428, 3170, 16, 'Kelompok nomor referensi faktur, jika digunakan'),
(59429, 3171, 16, 'Kelompok Nomor Referensi Faktur'),
(59430, 3172, 16, 'Kelompok Nomor Referensi Faktur'),
(59431, 3173, 16, 'Faktur:'),
(59432, 3174, 16, 'IPPF'),
(59433, 3177, 16, 'Data IPPF SRH untuk'),
(59434, 3178, 16, 'Laporan Statistik IPPF'),
(59435, 3179, 16, 'Status IPPF'),
(59436, 3180, 16, 'IPV 1'),
(59437, 3181, 16, 'IPV 2'),
(59438, 3182, 16, 'IPV 3'),
(59439, 3183, 16, 'IPV 4'),
(59440, 3185, 16, 'Denyut Jantung Tidak Teratur'),
(59441, 3186, 16, 'Sifat Lekas Marah'),
(59442, 3187, 16, 'Iritasi'),
(59443, 3191, 16, 'adalah field/bagian yang dibutuhkan.'),
(59444, 3192, 16, 'adalah root node (simpul akar) dan tidak bisa dihapus'),
(59445, 3197, 16, 'tidak valid (pecahan desimal OK).'),
(59446, 3198, 16, 'Apakah PHP menggunakan Safe Mode?'),
(59447, 3200, 16, 'Apakah teks dari formulir layout akan diterjemahkan?'),
(59448, 3201, 16, 'Apakah teks dari daftar akan diterjemahkan?'),
(59449, 3202, 16, 'Apakah File Terenkripsi?'),
(59450, 3204, 16, 'Apakah ini jenis diagnosa?'),
(59451, 3209, 16, 'Apakah jenis/tipe kode ini aktif?'),
(59452, 3212, 16, 'Apakah jenis ini tersembunyi dalam lembar biaya?'),
(59453, 3214, 16, 'terlalu panjang'),
(59454, 3216, 16, 'Isu(Masalah/Persoalan)'),
(59455, 3217, 16, 'isu/masalah'),
(59456, 3218, 16, 'Tanggal Isu'),
(59457, 3219, 16, 'ID Isu'),
(59458, 3220, 16, 'Judul Isu'),
(59459, 3223, 16, 'Isu(Masalah/Persoalan)'),
(59460, 3224, 16, 'Masalah (Cedera(Luka)/Medis/Alergi)'),
(59461, 3225, 16, 'Masalah (Cedera(Luka)/Medis/Alergi):'),
(59462, 3226, 16, 'Isu(Masalah) dan Encounter(Pertemuan)'),
(59463, 3227, 16, 'Isu(Masalah) dan Encounter(Pertemuan)untuk'),
(59464, 3228, 16, 'Isu(Masalah) tidak diizinkan'),
(59465, 3229, 16, 'Bagian Isu(Masalah)'),
(59466, 3230, 16, 'Italia'),
(59467, 3231, 16, 'Item'),
(59468, 3232, 16, 'item'),
(59469, 3234, 16, 'Item gagal dimuat'),
(59470, 3235, 16, 'IU/L'),
(59471, 3236, 16, 'IUD'),
(59472, 3237, 16, 'IV'),
(59473, 3238, 16, 'Januari'),
(59474, 3239, 16, 'Januari'),
(59475, 3240, 16, 'Jepang'),
(59476, 3241, 16, 'Penyakit Kuning'),
(59477, 3243, 16, 'Deskripsi Pekerjaan'),
(59478, 3244, 16, 'ID Pekerjaan'),
(59479, 3245, 16, 'Dislokasi Persendian'),
(59480, 3246, 16, 'Sakit Persendian'),
(59481, 3247, 16, 'Persendian keseleo'),
(59482, 3248, 16, 'Juli'),
(59483, 3249, 16, 'Juli'),
(59484, 3250, 16, 'Juni'),
(59485, 3251, 16, 'Juni'),
(59486, 3252, 16, 'Tepat di bawah cek informasi adalah daerah biru di mana Anda memasukkan parameter pencarian anda. Anda dapat mencari berdasarkan nama pasien, nomor tabel/grafik, nomor encounter(pertemuan) atau tanggal pelayanan, atau kombinasi dari semuanya. Anda juga dapat memilih apakah Anda ingin melihat semua faktur/tagihan, buka faktur, atau faktur yang jatuh tempo (oleh pasien). Klik tombol Cari untuk melakukan pencarian.'),
(59487, 3253, 16, 'Milik Saya'),
(59488, 3255, 16, 'Membenarkan'),
(59489, 3256, 16, 'Membenarkan/Simpan'),
(59490, 3258, 16, 'inilah sisanya'),
(59491, 3264, 16, 'Kunci'),
(59492, 3265, 16, 'Kata kunci'),
(59493, 3266, 16, 'kg'),
(59494, 3267, 16, 'kg/m^2'),
(59495, 3269, 16, 'Kanker ginjal'),
(59496, 3270, 16, 'Gagal ginjal'),
(59497, 3271, 16, 'Infeksi ginjal'),
(59498, 3272, 16, 'Batu ginjal'),
(59499, 3273, 16, 'Transplantasi ginjal'),
(59500, 3277, 16, 'Lutut'),
(59501, 3278, 16, 'Masalah Lutut'),
(59502, 3279, 16, 'Penggantian Lutut'),
(59503, 3282, 16, 'Korea'),
(59504, 3286, 16, 'Lab'),
(59505, 3288, 16, 'Alamat Situs Lab Exchange (Pertukaran Lab)'),
(59506, 3289, 16, 'ID Situs Lab Exchange (Pertukaran Lab)'),
(59507, 3290, 16, 'ID Token Lab Exchange (Pertukaran Lab)'),
(59508, 3294, 16, 'Status Query Lab'),
(59509, 3295, 16, 'Laporan Lab'),
(59510, 3296, 16, 'Hasil Lab'),
(59511, 3297, 16, 'Hasil Lab'),
(59512, 3299, 16, 'Laporan Hasil Lab'),
(59513, 3300, 16, 'Layanan Lab'),
(59514, 3301, 16, 'Hasil Pemeriksaan/Pengujian Lab'),
(59515, 3303, 16, 'Label'),
(59516, 3304, 16, 'Label tidak boleh kosong'),
(59517, 3305, 16, 'Kolom Label'),
(59518, 3306, 16, 'Label untuk tipe/jenis ini'),
(59519, 3307, 16, 'Kolom Label harus berupa angka antara 1 dan 999'),
(59520, 3308, 16, 'Label'),
(59521, 3311, 16, 'Lab'),
(59522, 3312, 16, 'Pengoyakan(goresan)/kondisi kulit'),
(59523, 3313, 16, 'Pengoyakan(goresan)/abrasi'),
(59524, 3316, 16, 'Bahasa'),
(59525, 3317, 16, 'Kode Bahasa'),
(59526, 3318, 16, 'Definisi bahasa ditambahkan'),
(59527, 3319, 16, 'Perangkat Antarmuka Bahasa'),
(59528, 3320, 16, 'Daftar Bahasa (tulis, hanya tambah opsional)'),
(59529, 3321, 16, 'Nama Bahasa'),
(59530, 3322, 16, 'Bahasa:'),
(59531, 3324, 16, 'Laos'),
(59532, 3325, 16, 'Terakhir'),
(59533, 3326, 16, 'Tanggal Kegiatan Terakhir'),
(59534, 3328, 16, 'Tanggal Tagihan Terakhir'),
(59535, 3330, 16, 'Kalender Tahun Terakhir'),
(59536, 3333, 16, 'Encounter(Pertemuan) Terakhir'),
(59537, 3343, 16, 'Bulan Lalu'),
(59538, 3344, 16, 'Nama Belakang'),
(59539, 3345, 16, 'Nama belakang'),
(59540, 3346, 16, 'Nama Belakang:'),
(59541, 3350, 16, 'Terakhir Diulas'),
(59542, 3352, 16, 'Terakhir Disimpan'),
(59543, 3356, 16, 'Terakhir diupdate oleh'),
(59544, 3357, 16, 'Terakhir Diverifikasi pada'),
(59545, 3358, 16, 'Kunjungan Terakhir'),
(59546, 3360, 16, 'Akhir Kambuh (2-12 Bulan)'),
(59547, 3361, 16, 'Rusuk Malleolus'),
(59548, 3362, 16, 'Rusuk malleolus:'),
(59549, 3363, 16, 'Lateralitas'),
(59550, 3364, 16, 'Lateralitas dari prosedur ini, jika dapat berlaku'),
(59551, 3365, 16, 'lateral mengungsi PMI:'),
(59552, 3373, 16, 'Tata Letak Dasar'),
(59553, 3374, 16, 'Tata Letak Editor'),
(59554, 3375, 16, 'Tata Letak grup'),
(59555, 3376, 16, 'Gaya Tata Letak'),
(59556, 3378, 16, 'Tata Letak Dasar Formulir Kunjungan'),
(59557, 3379, 16, 'Layout(Tata Letak)'),
(59558, 3380, 16, 'lb'),
(59559, 3381, 16, 'lbs'),
(59560, 3382, 16, 'LDL'),
(59561, 3383, 16, 'biarkan kosong jika masih aktif'),
(59562, 3384, 16, 'Biarkan Kosong Untuk Memelihara Keaslian Nama File'),
(59563, 3385, 16, 'Biarkan kosong untuk password tetap tidak berubah.'),
(59564, 3386, 16, 'Tinggalkan Pesan Dengan'),
(59565, 3387, 16, 'Tinggalkan Formulir'),
(59566, 3388, 16, 'Membiarkan frasa pasword kosong tidak akan mengenkripsi dokumen'),
(59567, 3390, 16, 'Kiri'),
(59568, 3391, 16, 'Telinga Kiri'),
(59569, 3392, 16, 'telinga kiri'),
(59570, 3394, 16, 'Kiri:'),
(59571, 3395, 16, 'Kiri: '),
(59572, 3396, 16, 'Nyeri Kaki/Kram'),
(59573, 3397, 16, 'Legal'),
(59574, 3399, 16, 'Ukuran Kertas Legal'),
(59575, 3400, 16, 'Legenda:'),
(59576, 3401, 16, 'Panjang'),
(59577, 3402, 16, 'Panjang modifier, 0 jika tidak ada'),
(59578, 3403, 16, 'Kurang Dari'),
(59579, 3404, 16, 'Kurang Dari atau Sama Dengan'),
(59580, 3405, 16, 'Informasi pribadi(sedikit) (tulis, hanya tambah opsional)'),
(59581, 3406, 16, 'Surat'),
(59582, 3407, 16, 'Generator Surat'),
(59583, 3408, 16, 'Ukuran Kertas Surat'),
(59584, 3409, 16, 'Kepala surat yang ditandatangani dokter'),
(59585, 3410, 16, 'Kepala surat yang ditandatangani pasien'),
(59586, 3411, 16, 'Tingkat urgensi'),
(59587, 3412, 16, 'Kewajiban'),
(59588, 3413, 16, 'Kewajiban Medis'),
(59589, 3414, 16, 'Lisensi/ID'),
(59590, 3419, 16, 'Nama belakang Resep yang Diizinkan'),
(59591, 3420, 16, 'NPI Resep yang Diizinkan'),
(59592, 3421, 16, 'UPIN Resep yang Diizinkan'),
(59593, 3423, 16, 'Gaya Hidup'),
(59594, 3424, 16, 'Status Gaya Hidup'),
(59595, 3425, 16, 'Sobekan Ligamen atau keseleo'),
(59596, 3428, 16, 'Batas Event'),
(59597, 3429, 16, 'Batas'),
(59598, 3431, 16, 'Link/Tautan'),
(59599, 3432, 16, 'Link ke Pasien'),
(59600, 3433, 16, 'Dilink/Terkait'),
(59601, 3436, 16, 'Dilink ke dokumen'),
(59602, 3438, 16, 'Daftar'),
(59603, 3439, 16, 'Kotak daftar'),
(59604, 3440, 16, 'kotak daftar'),
(59605, 3441, 16, 'kotak daftar tulis/tambah'),
(59606, 3442, 16, 'Kotak daftar tulis/tambah'),
(59607, 3443, 16, 'Daftar Editor'),
(59608, 3444, 16, 'Daftar encounter(pertemuan)'),
(59609, 3445, 16, 'Daftar grup');
INSERT INTO `lang_definitions` VALUES
(59610, 3446, 16, 'Daftar Perusahaan Asuransi'),
(59611, 3448, 16, 'Daftar item tidak boleh dimulai dengan angka.'),
(59612, 3449, 16, 'Daftar item mengandung karakter yang tidak diizinkan.'),
(59613, 3451, 16, 'Daftar daftar'),
(59614, 3452, 16, 'Daftar Nama'),
(59615, 3453, 16, 'Daftar nama tidak boleh dimulai dengan angka.'),
(59616, 3454, 16, 'Daftar Resep'),
(59617, 3455, 16, 'Daftar diatas digunakan oleh pilihan Tipe/Jenis Data Negara.'),
(59618, 3456, 16, 'Daftar diatas digunakan oleh pilihan Tipe/Jenis Data Negara.'),
(59619, 3457, 16, 'Mendengarkan port dari server syslog RFC 5425 TLS.'),
(59620, 3458, 16, 'Daftar'),
(59621, 3460, 16, 'Keinginan Hidup'),
(59622, 3461, 16, 'LLL/BMPK:'),
(59623, 3462, 16, 'LMP'),
(59624, 3464, 16, 'Memuat Definisi'),
(59625, 3470, 16, 'SEDANG MEMUAT'),
(59626, 3471, 16, 'Sedang memuat file kedalam database. Ini akan sedikit memakan waktu...'),
(59627, 3472, 16, 'LOC'),
(59628, 3473, 16, 'Lokal'),
(59629, 3476, 16, 'Lokal'),
(59630, 3477, 16, 'Lokalitas'),
(59631, 3478, 16, 'Lokasi'),
(59632, 3479, 16, 'lokasi dari mesin libreehr dan mungkin berisi data sensitif, sehingga dianjurkan untuk secara manual menghapus file setelah penggunaannya'),
(59633, 3480, 16, 'Lokasi dari lot ini'),
(59634, 3481, 16, 'Lokasi tidakk ditentukan'),
(59635, 3482, 16, 'Lokasi dimana Hylafax menyimpan faks.'),
(59636, 3483, 16, 'Lokasi dimana scan disimpan.'),
(59637, 3484, 16, 'Lokasi:'),
(59638, 3485, 16, 'Mengunci'),
(59639, 3492, 16, 'Login(Masuk)'),
(59640, 3494, 16, 'Logout(Keluar)'),
(59641, 3495, 16, 'Login'),
(59642, 3496, 16, 'Login sebagai'),
(59643, 3497, 16, 'Login sebagai: '),
(59644, 3498, 16, 'Keluar.'),
(59645, 3500, 16, 'Login(Masuk)'),
(59646, 3501, 16, 'login(masuk)'),
(59647, 3505, 16, 'Logout(Keluar)'),
(59648, 3506, 16, 'logout(keluar)'),
(59649, 3507, 16, 'Log'),
(59650, 3508, 16, 'Pelihat Log'),
(59651, 3510, 16, 'Mengunjungi'),
(59652, 3511, 16, 'Lot'),
(59653, 3512, 16, 'ID Lot tidak ada!'),
(59654, 3513, 16, 'Nomor Lot'),
(59655, 3514, 16, 'Rendah'),
(59656, 3516, 16, 'Kaki bagian bawah'),
(59657, 3519, 16, 'Tulang belakang pinggang'),
(59658, 3520, 16, 'MAKAN SIANG'),
(59659, 3521, 16, 'Makan Siang'),
(59660, 3522, 16, 'Kanker Paru-Paru'),
(59661, 3523, 16, 'Bedah Kanker Paru'),
(59662, 3524, 16, 'PARU-PARU:'),
(59663, 3525, 16, 'Paru-paru:'),
(59664, 3526, 16, 'Lupus'),
(59665, 3528, 16, 'M'),
(59666, 3529, 16, 'Kategori MA'),
(59667, 3530, 16, 'Klien MA yang Menerima Aborsi'),
(59668, 3531, 16, 'Status MA'),
(59669, 3533, 16, 'Surat Terkirim'),
(59670, 3534, 16, 'Utama'),
(59671, 3535, 16, 'Alamat Utama'),
(59672, 3536, 16, 'Panel Layar Utama bagian Atas'),
(59673, 3537, 16, 'Memelihara daftar obat alergi aktif.'),
(59674, 3538, 16, 'Memelihara daftar obat aktif.'),
(59675, 3539, 16, 'Memelihara daftar masalah terbaru dari diagnosa aktif dan berlaku.'),
(59676, 3540, 16, 'Buat modifikasi pada kategori yang berlaku.'),
(59677, 3541, 16, 'Buat janji temu baru untuk'),
(59678, 3542, 16, 'Pastikan "'),
(59679, 3543, 16, 'Membuat file teks batch untuk mengupload ke Kantor Penerimaan Cek Antara Bank dan akan ditandai sebagai ditagih'),
(59680, 3545, 16, 'Rasa Tidak Enak:'),
(59681, 3548, 16, 'Laki-laki'),
(59682, 3549, 16, 'Kondom Laki-Laki'),
(59683, 3550, 16, 'VSC Laki-Laki'),
(59684, 3552, 16, 'Mammogram'),
(59685, 3553, 16, 'Mengelola'),
(59686, 3556, 16, 'Mengelola Terjemahan'),
(59687, 3557, 16, 'Pengelolaan'),
(59688, 3558, 16, 'Field(Bagian) tertentu dan wajib'),
(59689, 3559, 16, 'Field(Bagian) tertentu dan wajib saja, cek dup(gkg), tidak ada pencarian'),
(59690, 3560, 16, 'Field(Bagian) tertentu dan wajib saja, cari dan cek dup(gkg)'),
(59691, 3561, 16, 'Manual'),
(59692, 3562, 16, 'Posting Manual'),
(59693, 3563, 16, 'Pabrikan'),
(59694, 3565, 16, 'Maret'),
(59695, 3568, 16, 'Maret'),
(59696, 3569, 16, 'Status Pernikahan'),
(59697, 3571, 16, 'Tandai sebagai ditagih namun lewati penagihan'),
(59698, 3572, 16, 'Tandai sebagai Diselesaikan'),
(59699, 3573, 16, 'Tandai sebagai belum ditagih'),
(59700, 3575, 16, 'Tandai sebagai diselesaikan'),
(59701, 3576, 16, 'Menikah'),
(59702, 3578, 16, 'Masker/Penutup'),
(59703, 3579, 16, 'Penutup untuk Nomor Faktur/Tagihan'),
(59704, 3580, 16, 'Penutup untuk ID Pasien'),
(59705, 3581, 16, 'Penutup untuk ID Pasien'),
(59706, 3582, 16, 'Cocok'),
(59707, 3591, 16, 'Max'),
(59708, 3594, 16, 'Rahang Atas Kanan:'),
(59709, 3595, 16, 'Usia Maksimum'),
(59710, 3596, 16, 'Karakter maksimum'),
(59711, 3597, 16, 'Waktu diam maksimum sebelum logout. Default(standar) adalah 7200 (2 jam)'),
(59712, 3600, 16, 'Persediaan wajar maksimum, 0 jika tidak berlaku'),
(59713, 3603, 16, 'Mei'),
(59714, 3604, 16, 'MC'),
(59715, 3605, 16, 'mcg'),
(59716, 3607, 16, 'Berarti tidak ada tiga pasword terakhir yang diizinkan ketika mengubah pasword'),
(59717, 3609, 16, 'Kode Ukuran Grup'),
(59718, 3611, 16, 'Pengukuran'),
(59719, 3612, 16, 'Di tengah-tengah malleolus:'),
(59720, 3613, 16, 'Medicaid'),
(59721, 3614, 16, 'Medis(Pengobatan)'),
(59722, 3615, 16, 'Aborsi Medis'),
(59723, 3616, 16, 'Administrasi Medis'),
(59724, 3617, 16, 'Riwayat Medis'),
(59725, 3618, 16, 'Isu(Masalah) Medis'),
(59726, 3619, 16, 'Isu(Masalah) medis'),
(59727, 3620, 16, 'Masalah medis'),
(59728, 3623, 16, 'Masalah Medis'),
(59729, 3624, 16, 'Catatan Medis'),
(59730, 3625, 16, 'Catatan Medis #'),
(59731, 3626, 16, 'Catatan Medis'),
(59732, 3627, 16, 'Catatan Medis Terkirim'),
(59733, 3629, 16, 'Ringkasan Medis Diberikan'),
(59734, 3630, 16, 'Sistem Medis'),
(59735, 3631, 16, 'Tipe/Jenis Medis(Pengobatan)'),
(59736, 3632, 16, 'Medis/Riwayat (tulis, hanya tambah opsional)'),
(59737, 3633, 16, 'Medicare Bagian B'),
(59738, 3634, 16, 'Pengarah Medicare adalah Pemberi'),
(59739, 3635, 16, 'Obat/Pengobatan'),
(59740, 3636, 16, 'Daftar Pengobatan Alergi'),
(59741, 3638, 16, 'Daftar Pengobatan'),
(59742, 3639, 16, 'Rekonsiliasi Pengobatan Dilakukan?'),
(59743, 3640, 16, 'Obat/Pengobatan'),
(59744, 3641, 16, 'Obat/Pengobatan:'),
(59745, 3642, 16, 'Unit(satuan) Obat'),
(59746, 3643, 16, 'Medium'),
(59747, 3645, 16, 'Laporan Statistik Anggota Asosiasi'),
(59748, 3646, 16, 'Masalah Ingatan'),
(59749, 3647, 16, 'Laki-laki'),
(59750, 3648, 16, 'Laki-laki dan Wanita'),
(59751, 3649, 16, 'Hanya Laki-laki'),
(59752, 3650, 16, 'Menarche'),
(59753, 3651, 16, 'Menopause (Mati Haid)'),
(59754, 3652, 16, 'Arus Menstruasi'),
(59755, 3653, 16, 'Frekuensi Menstruasi'),
(59756, 3654, 16, 'Penyakit Mental'),
(59757, 3661, 16, 'Pesan'),
(59758, 3662, 16, 'Pusat Pengingat dan Pesan'),
(59759, 3665, 16, 'Pesan Tekirim'),
(59760, 3666, 16, 'Status Pesan'),
(59761, 3670, 16, 'PESAN:'),
(59762, 3671, 16, 'Pesan'),
(59763, 3672, 16, 'Pesan yang telah Anda kirim Hari Ini'),
(59764, 3673, 16, 'Metode'),
(59765, 3674, 16, 'Metode dan Produk Spesifik'),
(59766, 3675, 16, 'Metode untuk mengirimkan email keluar.'),
(59767, 3676, 16, 'Metode Perusakan'),
(59768, 3677, 16, 'Meksiko/MexAmer/Chicano'),
(59769, 3679, 16, 'mg'),
(59770, 3680, 16, 'mg/1cc'),
(59771, 3681, 16, 'mg/2cc'),
(59772, 3682, 16, 'mg/3cc'),
(59773, 3683, 16, 'mg/4cc'),
(59774, 3684, 16, 'mg/5cc'),
(59775, 3685, 16, 'MG/DL'),
(59776, 3686, 16, 'Tengah'),
(59777, 3687, 16, 'Nama Tengah'),
(59778, 3688, 16, 'Nama tengah'),
(59779, 3690, 16, 'Midlevel(Tingkat Pertengahan) DEA Resep'),
(59780, 3691, 16, 'Midlevel(Tingkat Pertengahan) Nama awal Resep'),
(59781, 3692, 16, 'Midlevel(Tingkat Pertengahan) Nama akhir Resep'),
(59782, 3693, 16, 'Midlevel(Tingkat Pertengahan) Awalan Resep'),
(59783, 3694, 16, 'Midlevel(Tingkat Pertengahan) UPIN Resep'),
(59784, 3695, 16, 'Wajah'),
(59785, 3696, 16, 'Migran atau pekerja musiman?'),
(59786, 3697, 16, 'Migran/Musiman'),
(59787, 3698, 16, 'Mil/CU.MM'),
(59788, 3702, 16, 'Tipe/Jenis Mime(Pantomim/Meniru-niru)'),
(59789, 3703, 16, 'Min'),
(59790, 3704, 16, 'min'),
(59791, 3705, 16, 'Usia Minimum'),
(59792, 3706, 16, 'Ketengan persendian minor +/- sinovitis'),
(59793, 3708, 16, 'Menit'),
(59794, 3709, 16, 'menit'),
(59795, 3710, 16, 'Menit'),
(59796, 3712, 16, 'Macam-macam'),
(59797, 3713, 16, 'Macam-macam Pilihan Tagihan'),
(59798, 3714, 16, 'Macam-macam Pilihan Tagihan untuk HCFA-1500'),
(59799, 3715, 16, 'Macam-macam Pilihan Tagihan HCFA'),
(59800, 3716, 16, 'Macam-macam'),
(59801, 3717, 16, 'Terlewat/Terjawab'),
(59802, 3718, 16, 'hilang/tidak ada'),
(59803, 3719, 16, 'Kurang field(bagian) yang dibutuhkan'),
(59804, 3720, 16, 'Biaya Hilang'),
(59805, 3721, 16, 'Hanya Mods yang Hilang'),
(59806, 3722, 16, 'Hilang atau Tidak Valid'),
(59807, 3723, 16, 'PID yang Hilang'),
(59808, 3724, 16, 'Tanggal laporan yang hilang'),
(59809, 3725, 16, 'Garis miring hilang setelah pembayar dalam sumber untuk kode '),
(59810, 3726, 16, 'Campur'),
(59811, 3727, 16, 'ml'),
(59812, 3728, 16, 'MM/DD/YYYY'),
(59813, 3729, 16, 'mm/hg'),
(59814, 3730, 16, 'mmHg'),
(59815, 3731, 16, 'MMR 1'),
(59816, 3732, 16, 'MMR 2'),
(59817, 3733, 16, 'Handphone'),
(59818, 3734, 16, 'Ponsel'),
(59819, 3735, 16, 'Mod'),
(59820, 3741, 16, 'Modifier'),
(59821, 3742, 16, 'Modifier'),
(59822, 3745, 16, 'Modifikasi Pembayaran'),
(59823, 3746, 16, 'Modifikasi Panjang'),
(59824, 3753, 16, 'Senin'),
(59825, 3754, 16, 'Senin sampai Jumat'),
(59826, 3755, 16, 'Senin, Rabu & Jumat'),
(59827, 3756, 16, 'Senin'),
(59828, 3758, 16, 'Bulan'),
(59829, 3759, 16, 'bulan'),
(59830, 3760, 16, 'Lihat Bulan'),
(59831, 3761, 16, 'Bulan'),
(59832, 3762, 16, 'Pendapatan Bulanan'),
(59833, 3763, 16, 'Bulan'),
(59834, 3765, 16, 'Lebih dari 100 record(catatan) ditemukan. Silahkan persempit kriteria pencarian anda.'),
(59835, 3766, 16, 'Lebih dari 50 hasil, silahkan buat pencarian anda lebih spesifik.'),
(59836, 3767, 16, 'Kebanyakan kolom header dapat diklik untuk mengubah tata urutan'),
(59837, 3768, 16, 'Terbaru dari'),
(59838, 3770, 16, 'Vital terbaru dari:'),
(59839, 3771, 16, 'Ibu'),
(59840, 3772, 16, 'Nama Ibu'),
(59841, 3774, 16, 'Mulut'),
(59842, 3775, 16, 'Pindah'),
(59843, 3776, 16, 'Pindahkan Dokumen ke Kategori:'),
(59844, 3777, 16, 'Pindah ke Bawah'),
(59845, 3779, 16, 'Pindah ke Pasien'),
(59846, 3780, 16, 'Pindah ke...'),
(59847, 3781, 16, 'Pindah ke Atas'),
(59848, 3783, 16, 'Mr.(Bapak)'),
(59849, 3785, 16, 'Mrs.(Ibu)'),
(59850, 3786, 16, 'Ms.(Nona)'),
(59851, 3794, 16, 'Kode MSP'),
(59852, 3796, 16, 'Perangkat Multi Bahasa'),
(59853, 3797, 16, 'Beberapa daerah'),
(59854, 3799, 16, 'Beberapa lot'),
(59855, 3800, 16, 'Beberapa modifier dapat dipisahkan oleh titik dua atau spasi, maksimum 4 (M1:M2:M3:M4)'),
(59856, 3802, 16, 'Bersuku Banyak'),
(59857, 3803, 16, 'Dengut:'),
(59858, 3805, 16, 'Nyeri Otot'),
(59859, 3806, 16, 'Otot Kemerahan'),
(59860, 3807, 16, 'Kekejuran Otot'),
(59861, 3808, 16, 'Pembengkakan Otot'),
(59862, 3809, 16, 'Pemanasan Otot'),
(59863, 3810, 16, 'Otot'),
(59864, 3811, 16, 'Cedera otot'),
(59865, 3812, 16, 'Musculoskeletal'),
(59866, 3813, 16, 'Harus kosong jika otentifikasi SMPT tidak digunakan.'),
(59867, 3814, 16, 'Saling Ditetapkan'),
(59868, 3815, 16, 'MVA'),
(59869, 3818, 16, 'Diri Sendiri'),
(59870, 3821, 16, 'N/A'),
(59871, 3822, 16, 'n/a'),
(59872, 3823, 16, 'Nama'),
(59873, 3825, 16, 'Nama (klik untuk lebih lanjut)'),
(59874, 3826, 16, 'Nama 1'),
(59875, 3827, 16, 'Nama 2'),
(59876, 3828, 16, 'Nama dan Judul imunisasi dari Administrator'),
(59877, 3831, 16, 'Nama dari Event'),
(59878, 3832, 16, 'Nama dari perusahaaan asuransi'),
(59879, 3833, 16, 'Nama Provider'),
(59880, 3834, 16, 'Nama dari pengirim untuk pengingat pasien'),
(59881, 3835, 16, 'Nama Terjemahan'),
(59882, 3836, 16, 'Nama/Nilai'),
(59883, 3837, 16, 'Nama:'),
(59884, 3838, 16, 'NARES:'),
(59885, 3839, 16, 'NARES: Normal Kanan'),
(59886, 3840, 16, 'Nasal mucosa pink(Sengau mukosa merah muda), septum midline(garis tengah sekat)'),
(59887, 3841, 16, 'Catatan Negara'),
(59888, 3842, 16, 'Konfigurasi Catatan Negara'),
(59889, 3844, 16, 'Kebangsaan'),
(59890, 3845, 16, 'Catatan Negara'),
(59891, 3847, 16, 'Hawai Asli atau Kepulauan Pasifik Lainnya'),
(59892, 3852, 16, 'Mual'),
(59893, 3854, 16, 'Navigasi'),
(59894, 3855, 16, 'Area navigasi meliputi formulir encounter(pertemuan)'),
(59895, 3856, 16, 'Area navigasi menggunakan tinggi yang penuh dari frameset'),
(59896, 3857, 16, 'Area Navigasi Formulir Kunjungan'),
(59897, 3858, 16, 'Lebar Area Navigasi'),
(59898, 3859, 16, 'Menu navigasi terdiri dari sepasang tombol radio (radio buttons)'),
(59899, 3860, 16, 'Menu navigasi berupa tampilan pohon (tree view)'),
(59900, 3861, 16, 'Navigasi menggunakan menu geser (sliding menu)'),
(59901, 3862, 16, 'NDC'),
(59902, 3864, 16, 'Nomor NDC'),
(59903, 3866, 16, 'Leher'),
(59904, 3867, 16, 'Masalah leher'),
(59905, 3868, 16, 'Lemas leher'),
(59906, 3869, 16, 'Harus memasukkan keterangan'),
(59907, 3870, 16, 'Harus memasukkan Nilai Kembali'),
(59908, 3871, 16, 'Harus memasukkan identifier'),
(59909, 3872, 16, 'Harus memasukkan judul'),
(59910, 3873, 16, 'Membutuhkan Otentifikasi'),
(59911, 3874, 16, 'Membuthkan Pembenaran'),
(59912, 3875, 16, 'Membutuhkan tagihan sekunder'),
(59913, 3876, 16, 'Negatif'),
(59914, 3877, 16, 'Negatif'),
(59915, 3880, 16, 'Cedera saraf'),
(59916, 3881, 16, 'Kondisi saraf / kerusakan saraf'),
(59917, 3882, 16, 'Saraf Mati Rasa'),
(59918, 3883, 16, 'Lemah Saraf'),
(59919, 3884, 16, 'Neurologis'),
(59920, 3885, 16, 'Tidak Pernah'),
(59921, 3886, 16, 'Tidak Pernah Alkohol'),
(59922, 3887, 16, 'Tidak Pernah perokok'),
(59923, 3888, 16, 'Baru'),
(59924, 3889, 16, 'Baru =>'),
(59925, 3890, 16, 'Akseptor Baru'),
(59926, 3892, 16, 'Alergi Baru'),
(59927, 3894, 16, 'Janji Temu Baru'),
(59928, 3895, 16, 'Kategori Baru'),
(59929, 3896, 16, 'Kategori Baru'),
(59930, 3897, 16, 'Klien Baru'),
(59931, 3898, 16, 'Konsultasi baru'),
(59932, 3899, 16, 'Hasil Baru'),
(59933, 3900, 16, 'Set definisi baru ditambahkan'),
(59934, 3901, 16, 'Dokumen Baru'),
(59935, 3904, 16, 'Encounter(Pertemuan) Baru'),
(59936, 3905, 16, 'Encounter(pertemuan) baru diciptakan dengan id'),
(59937, 3906, 16, 'Formulir Encounter(Pertemuan) Baru'),
(59938, 3907, 16, 'Encounter(pertemuan) tidak diizinkan'),
(59939, 3908, 16, 'Encounter(Pertemuan) Baru'),
(59940, 3909, 16, 'Fasilitas Informasi Baru'),
(59941, 3912, 16, 'Grup Baru'),
(59942, 3913, 16, 'Grup Informasi Baru'),
(59943, 3914, 16, 'Status/Cedera Baru'),
(59944, 3916, 16, 'Batas Baru dari Event'),
(59945, 3917, 16, 'Daftar Baru'),
(59946, 3918, 16, 'Order(Perintah/Pesanan) Baru'),
(59947, 3919, 16, 'Paragraf Baru'),
(59948, 3920, 16, 'Pasword Baru'),
(59949, 3921, 16, 'Pasien Baru'),
(59950, 3922, 16, 'PASIEN BARU'),
(59951, 3923, 16, 'Encounter(Pertemuan) Pasien Baru'),
(59952, 3924, 16, 'Formulir Pasien Baru'),
(59953, 3925, 16, 'ID Pasien Baru'),
(59954, 3926, 16, 'Pembayaran Baru'),
(59955, 3928, 16, 'Pt Baru'),
(59956, 3929, 16, 'Hasil baru dari Lab Exchange(Pertukaran Lab)'),
(59957, 3930, 16, 'Pencarian Baru'),
(59958, 3931, 16, 'Pengiriman Baru'),
(59959, 3932, 16, 'Pengguna Baru'),
(59960, 3934, 16, 'Kunjungan Baru'),
(59961, 3935, 16, 'Baru/Cari'),
(59962, 3936, 16, 'Status Akun NewCrop'),
(59963, 3937, 16, 'Admin NewCrop'),
(59964, 3938, 16, 'Pemanggilan NewCrop gagal'),
(59965, 3939, 16, 'Dokter NewCrop'),
(59966, 3944, 16, 'Nama eRx NewCrop'),
(59967, 3945, 16, 'Nama Rekan eRx NewCrop'),
(59968, 3946, 16, 'Pasword eRx NewCrop'),
(59969, 3947, 16, 'Tugas eRX NewCrop'),
(59970, 3948, 16, 'Tugas eRx NewCrop'),
(59971, 3949, 16, 'Alamat Situs eRx NewCrop'),
(59972, 3954, 16, 'Alamat Layanan Web eRx NewCrop'),
(59973, 3955, 16, 'Pengelola NewCrop'),
(59974, 3956, 16, 'MedEntry NewCrop'),
(59975, 3957, 16, 'Resep Midlevel(tingkat menengah) NewCrop'),
(59976, 3958, 16, 'Perawat NewCrop'),
(59977, 3959, 16, 'Dokter Pengawasan NewCrop'),
(59978, 3961, 16, 'Koran'),
(59979, 3962, 16, 'Berikutnya'),
(59980, 3964, 16, 'Hari Berikutnya'),
(59981, 3965, 16, 'Bulan Berikutnya'),
(59982, 3966, 16, 'Bulan berikutnya (tahan untuk menu)'),
(59983, 3968, 16, 'Minggu Berikutnya'),
(59984, 3969, 16, 'Minggu Berikutnya (tahan untuk menu)'),
(59985, 3971, 16, 'Nama Panggilan'),
(59986, 3973, 16, 'Kegelisahan saat Malam Hari'),
(59987, 3974, 16, 'Nl ext kemaluan, vag mucosa, tengkuk(leher rahim'),
(59988, 3975, 16, 'Tidak'),
(59989, 3976, 16, 'TIDAK'),
(59990, 3977, 16, 'Tidak ada akses'),
(59991, 3978, 16, 'Tidak ada pengingat pasien yang aktif'),
(59992, 3979, 16, 'Tidak ada adenopathy (2 daerah diperlukan)'),
(59993, 3980, 16, 'Tidak ada jenis alasan pengaturan yang ditemukan'),
(59994, 3981, 16, 'Tidak ada kesakitan adnexal/massa'),
(59995, 3983, 16, 'Tidak ada Janji Temu'),
(59996, 3985, 16, 'Tidak ada sistem penagihan yang sedang aktif'),
(59997, 3987, 16, 'Tidak ada Tagihan yang Ditemukan Termasuk di dalam Ekspor OFX<br>'),
(59998, 3989, 16, 'Tidak ada kode yang ditentukan!'),
(59999, 3992, 16, 'Tidak ada Diagnosa'),
(60000, 3993, 16, 'Tidak ada Dokumen yang Ditemukan'),
(60001, 3995, 16, 'Tidak ada tanggal akhir'),
(60002, 3996, 16, 'Tidak ada masukan ditemukan, gunakan formulir di bawah ini untuk memberikan masukan.'),
(60003, 3997, 16, 'Tidak ada kesalahan yang ditemukan'),
(60004, 3998, 16, 'Tidak ada Event'),
(60005, 4001, 16, 'Tidak ada grup yang dipilih'),
(60006, 4002, 16, 'Tidak hernia(burut)'),
(60007, 4005, 16, 'Tidak ada cedera/penyakit'),
(60008, 4006, 16, 'Perusahaan Asuransi Tidak Ditemukan'),
(60009, 4007, 16, 'Tidak ada Isu(Masalah)'),
(60010, 4009, 16, 'Tidak ada item dibawah kategori yang dipilih'),
(60011, 4010, 16, 'Tidak ada item yang dipilih!'),
(60012, 4025, 16, 'Tidak ada log file untuk tanggal yang dipilih'),
(60013, 4027, 16, 'Tidak ada massa, kelembutan'),
(60014, 4028, 16, 'Tidak ada catatan Pasien yang cocok yang ditemukan untuk kode Identifikasi'),
(60015, 4030, 16, 'Tidak ada yang ditemukan.'),
(60016, 4031, 16, 'Tidak ada yang ditemukan. Buat pasien baru sekarang?'),
(60017, 4033, 16, 'Tidak ada hasil baru yang ditemukan'),
(60018, 4034, 16, 'Tidak ada catatan'),
(60019, 4035, 16, 'Tidak ogrganomegoly'),
(60020, 4036, 16, 'Tidak ada bukaan ditemukan untuk periode ini.'),
(60021, 4037, 16, 'Tidak ada nomor telepon lain yang tercantum'),
(60022, 4039, 16, 'Tidak Ditemukan Mitra/Rekan'),
(60023, 4040, 16, 'Tidak ada catatan Pasien yang ditemukan untuk kriteria Pemilihan yang diberikan'),
(60024, 4041, 16, 'Tidak ada catatan Pasien yang ditemukan untuk kode Identifikasi yang diberikan'),
(60025, 4042, 16, 'Tidak ada perifer(sekeliling) busung'),
(60026, 4043, 16, 'Apotek tidak Ditemukan'),
(60027, 4044, 16, 'Tidak ada resep Ditemukan'),
(60028, 4045, 16, 'Tidak ada presentasi penyakit/cedera'),
(60029, 4046, 16, 'Tidak ada entri/masukan sebelumnya.'),
(60030, 4047, 16, 'Tidak ada Entitas Bisnis Utam yang dipilih dalam daftar fasilitas'),
(60031, 4051, 16, 'Tidak Ditemukan Provider'),
(60032, 4052, 16, 'Tidak ada luka ruam atau abnormal'),
(60033, 4053, 16, 'Tidak ada record(catatan) yang ditemukan'),
(60034, 4055, 16, 'Tidak ada record(catatan) yang ditemukan. Silahkan perluas kriteria pencarian anda.'),
(60035, 4056, 16, 'Tidak ada Pengingat'),
(60036, 4057, 16, 'Hasil Tidak Ditemukan, untuk kriteria pencarian diatas'),
(60037, 4058, 16, 'Hasil Tidak Ada'),
(60038, 4060, 16, 'Tidak Ditemukan Hasil Pencarian Untuk'),
(60039, 4062, 16, 'Tidak ada hasil, silahkan baki lagi.'),
(60040, 4063, 16, 'Tidak ada hasil, silahkan cari lagi.'),
(60041, 4065, 16, 'Tampilan Tidak Ada'),
(60042, 4067, 16, 'Tidak ada Kesakitan Sinus:'),
(60043, 4068, 16, 'Tidak ada dimpling atau bengkak kulit payudara'),
(60044, 4069, 16, 'KONTEKS NAMA TERSEBUT TIDAK ADA'),
(60045, 4071, 16, 'Tidak ada kesakitan testis, massa'),
(60046, 4072, 16, 'Tidak ada kecemasan atau nafas'),
(60047, 4075, 16, 'Tidak ada kunjungan'),
(60048, 4076, 16, 'Tidak ada vital yang didokumentasikan'),
(60049, 4077, 16, 'Tidak, Batalkan'),
(60050, 4078, 16, 'Tidak ada kesalahan Asuransi termasuk Otomatis adalah Primer'),
(60051, 4079, 16, 'Tidak:'),
(60052, 4080, 16, 'Nokturia'),
(60053, 4081, 16, 'Tidak Dibayar'),
(60054, 4082, 16, 'Laporan yang Tidak Dilaporkan'),
(60055, 4083, 16, 'Cedera yang tidak spesifik'),
(60056, 4084, 16, 'Non-elektronik'),
(60057, 4085, 16, 'Diabetes yang tidak Tergantung Insulin'),
(60058, 4087, 16, 'Kedokteran/Pengobatan Non-SRH'),
(60059, 4088, 16, 'Non-Medis Non-SRH'),
(60060, 4089, 16, 'Tak satupun'),
(60061, 4090, 16, 'tak satupun'),
(60062, 4091, 16, 'Tidak didefinisikan'),
(60063, 4092, 16, 'Tidak ada yang telah didokumentasikan'),
(60064, 4093, 16, 'Tidak ada diatas'),
(60065, 4094, 16, 'Tidak ada satupun dari Baris Distribusi Bagian Atas bisa Benar-benar Kosong.'),
(60066, 4095, 16, 'Diabetes tidak Tergantung Insulin'),
(60067, 4096, 16, 'Maupun'),
(60068, 4097, 16, 'Normal'),
(60069, 4098, 16, 'BL Normal'),
(60070, 4099, 16, 'Pemeriksaan Jantung Normal:'),
(60071, 4100, 16, 'Pemeriksaan Jantung Normal: '),
(60072, 4101, 16, 'Pemeriksaan Paru-paru Normal:'),
(60073, 4102, 16, 'Pemeriksaan Paru-paru Normal: '),
(60074, 4103, 16, 'Pemeriksaan Kunjungan Kantor/Kerja'),
(60075, 4104, 16, 'Orofaring Normal:'),
(60076, 4105, 16, 'Normal Kanan'),
(60077, 4106, 16, 'Normal Kanan:'),
(60078, 4107, 16, 'Tampilan Normal'),
(60079, 4108, 16, 'normal:'),
(60080, 4109, 16, 'Biasanya ini harus diperiksa. Tidak terkait dengan akses kontrol.'),
(60081, 4112, 16, 'Norwegia'),
(60082, 4115, 16, 'Hidung'),
(60083, 4116, 16, 'Mimisan'),
(60084, 4117, 16, 'bukan huruf atau angka'),
(60085, 4119, 16, 'Tidak semua field(bidang) diperlukan untuk semua jenis kode atau kode.'),
(60086, 4120, 16, 'Tidak Diizinkan'),
(60087, 4121, 16, 'Tidak diperbolehkan untuk menghapus grup Administrator'),
(60088, 4122, 16, 'Tidak diperbolehkan untuk Mengedit'),
(60089, 4123, 16, 'Tidak diperbolehkan untuk menonaktifkan semua objek keamanan'),
(60090, 4124, 16, 'Tidak diperbolehkan untuk menonaktifkan apapun dari Administrator ACL'),
(60091, 4125, 16, 'Tidak diperbolehkan untuk menghapus pengguna admin dari grup Administrator'),
(60092, 4126, 16, 'Tidak diperbolehkan untuk menghapus pengguna ini dari grup Administrator'),
(60093, 4128, 16, 'Tidak diizinkan untuk mengakses modul PostCalendar'),
(60094, 4129, 16, 'Tidak diizinkan'),
(60095, 4130, 16, 'Tidak Diizinkan'),
(60096, 4131, 16, 'Tidak diizinkan untuk regu ini!'),
(60097, 4132, 16, 'Tidak diizinkan untuk regu ini.'),
(60098, 4135, 16, 'Tidak Tersedia'),
(60099, 4137, 16, 'Tidak ditagih'),
(60100, 4138, 16, 'Tidak Diperiksa'),
(60101, 4139, 16, 'Tidak Diperiksa'),
(60102, 4141, 16, 'Tidak Sesuai'),
(60103, 4143, 16, 'Tidak Diperiksa'),
(60104, 4144, 16, 'Tidak Diperiksa:'),
(60105, 4145, 16, 'Tidak Diperiksa: '),
(60106, 4146, 16, 'tidak ditemukan'),
(60107, 4148, 16, 'tidak ditemukan!'),
(60108, 4149, 16, 'Tidak Hispanic atau Latino'),
(60109, 4152, 16, 'Tidak terlihat sejak'),
(60110, 4154, 16, 'Belum Terkirim'),
(60111, 4156, 16, 'Tidak Ditentukan.'),
(60112, 4157, 16, 'Catatan'),
(60113, 4158, 16, 'Kode Catatan'),
(60114, 4159, 16, 'Sebagai catatan, ini akan menghabiskan waktu 5-10 menit untuk sepenuhnya memproses setelah anda klik Instal'),
(60115, 4160, 16, 'Sebagai catatan, ini akan menghabiskan waktu 5-10 menit untuk sepenuhnya memproses setelah anda klik Upgrade'),
(60116, 4161, 16, 'Sebagai catatan, Logging Audit perlu diaktifkan diatas'),
(60117, 4162, 16, 'Jenis Catatan'),
(60118, 4168, 16, 'Catatan: Kode ini tidak dimasukkan oleh pengguna yang berwenang. Hanya kode yang diizinkan yang mungkin diupload ke Open Medical Billing Network (Jaringan Penagihan Medis Terbuka) untuk diproses. Jika Anda ingin mengupload kode ini, silahkan pilih salah satu pengguna berwenang di sini.'),
(60119, 4170, 16, 'CATATAN: Mengupload file dengan nama sama akan menyebabkan file yang diganti nama secara otomatis. (misalnya, file.jpg akan menjadi file.jpg.1). Nama file dianggap unik per pasien, bukan per kategori.'),
(60120, 4171, 16, 'CATATAN: Mengupload file dengan nama sama akan menyebabkan file yang akan diganti nama secara otomatis. Misalnya ''<i>file.jpg</ i>'' akan menjadi ''<i>file.jpg.1</ i>''. Nama file dianggap unik per pasien, bukan per kategori.'),
(60121, 4172, 16, 'Catatan'),
(60122, 4173, 16, 'Catatan - encounter(pertemuan) apapun (tulis, hanya tambah opsional)'),
(60123, 4174, 16, 'Catatan - encounter(pertemuan) saya (tulis, hanya tambah opsional)'),
(60124, 4175, 16, 'Catatan tidak diizinkan'),
(60125, 4177, 16, 'Tidak ada yang Disimpan'),
(60126, 4179, 16, 'Tidak ada yang diimpor untuk Alergi'),
(60127, 4180, 16, 'Tidak ada yang diimpor untuk Resep'),
(60128, 4182, 16, 'Tidak ada yang dipilih'),
(60129, 4184, 16, 'PEMBERITAHUAN:: Pengiriman/Modifikasi PostCalendar'),
(60130, 4185, 16, 'Pemberitahuan'),
(60131, 4186, 16, 'Pemberitahuan Alamat Email'),
(60132, 4188, 16, 'Pemberitahuan'),
(60133, 4189, 16, 'Beritahu Admin Tentang Pengiriman/Modifikasi Event?'),
(60134, 4190, 16, 'Novembar'),
(60135, 4191, 16, 'November'),
(60136, 4192, 16, 'Sekarang posting untuk:'),
(60137, 4193, 16, 'Sedang mencetak'),
(60138, 4194, 16, 'Sedang mencetak pernyataan $stmt_count dan mengupdate encounter(pertemuan).'),
(60139, 4195, 16, 'Sedang mencetak pernyataan $stmt_count dan mengupdate faktur/tagihan.'),
(60140, 4196, 16, 'Sedang mencetak pernyataan $stmt_count; encounter(pertemuan) tidak akan diupdate.'),
(60141, 4197, 16, 'Sedang mencetak pernyataan $stmt_count; faktur/tagihan tidak akan diupdate.'),
(60142, 4198, 16, 'NPI'),
(60143, 4199, 16, 'NQF'),
(60144, 4200, 16, 'Nomor'),
(60145, 4201, 16, 'Nomor lab'),
(60146, 4204, 16, 'Jumlah kolom pada tampilan tahun.'),
(60147, 4211, 16, 'Jumlah hari bahwa sertifikat klien valid'),
(60148, 4213, 16, 'Jumlah digit setelah titik desimal untuk mata uang, biasanya 0 atau 2.'),
(60149, 4214, 16, 'Jumlah encounter(pertemuan) untuk ditampilkan per halaman.'),
(60150, 4215, 16, 'Jumlah permainan atau event terlewat/terjawab, jika ada'),
(60151, 4216, 16, 'Jumlah jam/waktu sebelumnya untuk mengirim notifikasi email.'),
(60152, 4217, 16, 'Jumlah jam/waktu sebelumnya untuk mengirim notifikasi Telepon.'),
(60153, 4218, 16, 'Jumlah jam/waktu sebelumnya untuk mengirim notifikasi SMS.'),
(60154, 4221, 16, 'Jumlah kolom riwayat yang lalu'),
(60155, 4223, 16, 'Mati Rasa'),
(60156, 4224, 16, 'Pembilang/Penghitung'),
(60157, 4225, 16, 'Tampilan order numerik'),
(60158, 4227, 16, 'Nutrisi'),
(60159, 4229, 16, 'O.A.F.V.'),
(60160, 4230, 16, 'O2 Sat'),
(60161, 4231, 16, 'Obesitas I'),
(60162, 4232, 16, 'Obesitas II'),
(60163, 4233, 16, 'Obesitas III'),
(60164, 4234, 16, 'Tujuan'),
(60165, 4237, 16, 'Pekerjaan'),
(60166, 4239, 16, 'Kejadian'),
(60167, 4240, 16, 'Oktober'),
(60168, 4241, 16, 'Oktober'),
(60169, 4242, 16, 'OD'),
(60170, 4243, 16, 'dari'),
(60171, 4244, 16, 'dari kuantitas'),
(60172, 4245, 16, 'dari tablet'),
(60173, 4246, 16, 'dari bulan setiap'),
(60174, 4247, 16, 'Catatan Ofc'),
(60175, 4248, 16, 'Mati'),
(60176, 4249, 16, 'Catatan Kantor'),
(60177, 4250, 16, 'Kunjungan Kantor/Kerja'),
(60178, 4251, 16, 'Ukuran Kualitas Klinis (CQM) Resmi'),
(60179, 4252, 16, 'Link Https Offsite untuk Portal Pasien.'),
(60180, 4253, 16, 'Link Https Offsite untuk Portal Pasien. (Link/Tautan Pasien)'),
(60181, 4254, 16, 'Pasword Portal Pasien Offsite'),
(60182, 4255, 16, 'Pasword Portal Pasien Offsite (Kosongkan Jika tidak Terdaftar).'),
(60183, 4258, 16, 'Alamat Situs Portal Pasien Offsite'),
(60184, 4259, 16, 'Alamat Situs Portal Pasien Offsite (Link/Tautan Pasien)'),
(60185, 4260, 16, 'Nama Pengguna Portal Pasien Offsite'),
(60186, 4261, 16, 'Nama Pengguna Portal Pasien Offsite (Kosongkan Jika tidak Terdaftar).'),
(60187, 4263, 16, 'Keturunan'),
(60188, 4265, 16, 'Obat Salep'),
(60189, 4267, 16, 'OK'),
(60190, 4269, 16, 'OK untuk menghubungkan tangal isu(masalah) GCAC'),
(60191, 4270, 16, 'Tua'),
(60192, 4272, 16, 'Klien Lama'),
(60193, 4273, 16, 'Tidak patah / malunion lama'),
(60194, 4274, 16, 'Tata letak lama tanpa menu kiri'),
(60195, 4275, 16, 'Formulir gaya lama statis tanpa pencarian atau cek duplikasi'),
(60196, 4279, 16, 'Hilangkan informasi majikan dalam demografi pasien'),
(60197, 4280, 16, 'Hilangkan Majikan'),
(60198, 4281, 16, 'Hilangkan formulir, rute dan interval yang kemudian menjadi bagian dari dosis'),
(60199, 4282, 16, 'Hilangkan asuransi dan beberapa hal lain dari formulir demografi'),
(60200, 4283, 16, 'HIlangkan pengguna internal?'),
(60201, 4284, 16, 'Hilangkan metode pembayaran dari panel co-pay'),
(60202, 4285, 16, 'hilangkan untuk autoassign'),
(60203, 4286, 16, 'pada'),
(60204, 4287, 16, 'Pada'),
(60205, 4288, 16, 'Pada Tangan'),
(60206, 4289, 16, 'Pada Urutan'),
(60207, 4290, 16, 'Pada Situs'),
(60208, 4291, 16, 'Setelah Fasilitas Bisnis Primer diatur, seharusnya tidak diubah. Mengubah fasilitas tersebut akan mempengaruhi kerja di NewCrop ePrescription.'),
(60209, 4292, 16, 'Setelah Anda mengubah pasword, Anda harus login kembali.'),
(60210, 4297, 16, 'Dukungan Online'),
(60211, 4298, 16, 'Link Dukungan Online'),
(60212, 4299, 16, 'Hanya Aktif'),
(60213, 4302, 16, 'hanya jika lokasi tagihan'),
(60214, 4303, 16, 'Hanya Nonaktif'),
(60215, 4304, 16, 'Hanya Milik Saya'),
(60216, 4307, 16, 'Hanya mengupload resep aktif'),
(60217, 4310, 16, 'Serangan Penyakit:'),
(60218, 4311, 16, 'Serangan Penyakit: '),
(60219, 4312, 16, 'Timbulnya Pembengkakan:'),
(60220, 4313, 16, 'Tanggal Mulai:'),
(60221, 4314, 16, 'Alamat Situs Portal Onsite(Ruang) Pasien'),
(60222, 4315, 16, 'Ups!'),
(60223, 4316, 16, 'Buka'),
(60224, 4321, 16, 'Buka Kunjungan Hari Ini'),
(60225, 4322, 16, 'LibreEHR telah memiliki Otoritas Sertifikat dikonfigurasi.'),
(60226, 4324, 16, 'Upgrade Database LibreEHR'),
(60227, 4325, 16, 'Upgrade Database LibreEHR untuk de-identifikasi'),
(60228, 4327, 16, 'LibreEHR harus dikonfigurasi untuk menggunakan sertifikat sebelum dapat membuat sertifikat klien.'),
(60229, 4328, 16, 'LibreEHR membutuhkan Javascript untuk melakukan otentikasi pengguna.'),
(60230, 4329, 16, 'Pengguna LibreEHR'),
(60231, 4330, 16, 'Membuka'),
(60232, 4332, 16, 'Kedokteran Mata'),
(60233, 4333, 16, 'Pilihan'),
(60234, 4335, 16, 'Pilihan untuk mendukung persediaan dan penjualan produk'),
(60235, 4336, 16, 'Opsional'),
(60236, 4337, 16, 'Nama kategori opsional untuk gambar Kartu ID(KTP) yang dapat dilihat dari halaman rangkuman pasien.'),
(60237, 4338, 16, 'Nama kategori opsional untuk gambar foto yang dapat dilihat dari halaman rangkuman pasien.'),
(60238, 4339, 16, 'Nama kategori opsional dari dokumen untuk melakukan link dari halaman rangkuman pasien. Memungkinkan anda klik pada nama pasien untuk melihat Kartu ID(KTP) mereka.'),
(60239, 4340, 16, 'Range(jangkauan) standar opsional untuk entri(masukan) manual dari hasil'),
(60240, 4341, 16, 'Unit(satuan) standar opsional untuk entri(masukan) manual dari hasil'),
(60241, 4342, 16, 'Nama Tujuan Opsional'),
(60242, 4343, 16, 'Nama obat opsional, gunakan % sebagai wildcard'),
(60243, 4345, 16, 'Informasi opsional tentang event ini'),
(60244, 4346, 16, 'Nomor lot opsional, gunakan % sebagai wildcard'),
(60245, 4347, 16, 'ID pasien numerik opsional'),
(60246, 4348, 16, 'Kode prosedur opsional'),
(60247, 4350, 16, 'Pilihan'),
(60248, 4351, 16, 'Atau'),
(60249, 4352, 16, 'ATAU'),
(60250, 4353, 16, 'atau pilih'),
(60251, 4354, 16, 'atau klik dan drag(tarik) untuk pemilihan lebih cepat'),
(60252, 4356, 16, 'Atau Keluar'),
(60253, 4358, 16, 'atau Shift-kli untuk menguranginya'),
(60254, 4359, 16, 'Atau upload file ERA:'),
(60255, 4360, 16, 'Lisan'),
(60256, 4361, 16, 'Mulut mukosa merah muda, tenggorokan jernih'),
(60257, 4362, 16, 'Pesanan'),
(60258, 4363, 16, 'Jenis Hasil dan Pesanan'),
(60259, 4364, 16, 'Katalog Pesanan'),
(60260, 4365, 16, 'Tanggal Pesanan'),
(60261, 4367, 16, 'Pesanan Dari'),
(60262, 4369, 16, 'Pesanan harus berupa angka antara 1 dan 999'),
(60263, 4370, 16, 'Nama Pesanan'),
(60264, 4371, 16, 'Prioritas Pesanan'),
(60265, 4372, 16, 'Prosesor Pesanan'),
(60266, 4375, 16, 'Status Pesanan'),
(60267, 4378, 16, 'Tipe Pesanan'),
(60268, 4380, 16, 'Jenis Pesanan/Hasil'),
(60269, 4381, 16, 'Dipesan'),
(60270, 4384, 16, 'Provider Pemesanan'),
(60271, 4386, 16, 'Cedera organ'),
(60272, 4387, 16, 'Organisasi'),
(60273, 4388, 16, 'Nama Organisasi'),
(60274, 4389, 16, 'Nama Unit Organisasi'),
(60275, 4390, 16, 'Organisasi'),
(60276, 4391, 16, 'Berorientasi x 3'),
(60277, 4392, 16, 'Orisinil/Asli'),
(60278, 4396, 16, 'OROFARING: '),
(60279, 4397, 16, 'Ortopnea'),
(60280, 4398, 16, 'OS'),
(60281, 4399, 16, 'Osetoarthritis'),
(60282, 4402, 16, 'Lainnya'),
(60283, 4403, 16, 'lainnya'),
(60284, 4404, 16, 'Lainnya (sebutkan)'),
(60285, 4405, 16, 'Lainnya - Tertentu'),
(60286, 4406, 16, 'Program Federal Lainnya'),
(60287, 4407, 16, 'HCFA Lainnya'),
(60288, 4408, 16, 'Cedera laiinya tidak dirinci'),
(60289, 4409, 16, 'Kewajiban Asuransi Lainnya adalah Primer'),
(60290, 4410, 16, 'bulan lainnya'),
(60291, 4411, 16, 'Program Non-Federal Lainnya'),
(60292, 4412, 16, 'Catatan Lainnya'),
(60293, 4413, 16, 'Gejala Relevan Lainnya'),
(60294, 4414, 16, 'Gejala Relevan Lainnya:'),
(60295, 4415, 16, 'Pt resp lainnya'),
(60296, 4416, 16, 'Stres lainnya/cedera berlebihan'),
(60297, 4417, 16, 'Bedah Lainnya'),
(60298, 4418, 16, 'Lain-lain/Aborsi-Terkait Generik'),
(60299, 4420, 16, 'Lainnya'),
(60300, 4421, 16, 'jika tidak anda akan menghancurkan referensi ke/dari data yang ada'),
(60301, 4422, 16, 'Aturan Pergelangan Kaki Ottawa'),
(60302, 4423, 16, 'OU'),
(60303, 4424, 16, 'KELUAR'),
(60304, 4425, 16, 'Diluar Kantor'),
(60305, 4426, 16, 'Rujukan Outbound'),
(60306, 4427, 16, 'Hasil'),
(60307, 4428, 16, 'Pandangan'),
(60308, 4431, 16, 'TERLAMBAT'),
(60309, 4432, 16, 'Berlebihan'),
(60310, 4434, 16, 'Kegemukan'),
(60311, 4435, 16, 'Timpa pilihan HIPAA'),
(60312, 4437, 16, 'Saturasi Oksigen'),
(60313, 4439, 16, 'P'),
(60314, 4440, 16, 'p.c.'),
(60315, 4441, 16, 'p.m.'),
(60316, 4442, 16, 'p.r.n.'),
(60317, 4443, 16, 'Kepulauan Pasifik'),
(60318, 4444, 16, 'Paedeatric'),
(60319, 4445, 16, 'Halaman'),
(60320, 4446, 16, 'Halaman'),
(60321, 4447, 16, 'Dibayar'),
(60322, 4448, 16, 'Jumlah dibayar yang akan anda alokasikan'),
(60323, 4450, 16, 'Dibayar Via'),
(60324, 4451, 16, 'Sakit'),
(60325, 4453, 16, 'Debaran Jantung'),
(60326, 4455, 16, 'Pap Smear'),
(60327, 4457, 16, 'Ukuran Kertas'),
(60328, 4458, 16, 'Kelumpuhan'),
(60329, 4461, 16, 'Parse HL7'),
(60330, 4463, 16, 'Mitra/Rekan'),
(60331, 4464, 16, 'Nama Mitra'),
(60332, 4467, 16, 'Frase Pasword'),
(60333, 4468, 16, 'Frase Pasword untuk mendekripsi dokumen'),
(60334, 4469, 16, 'Pasien Lulus'),
(60335, 4470, 16, 'Pemberitahuan Pasif'),
(60336, 4471, 16, 'Aturan Pemberitahuan Pasif'),
(60337, 4472, 16, 'Pasword'),
(60338, 4473, 16, 'Ubah Pasword'),
(60339, 4475, 16, 'Perubahan pasword berhasil'),
(60340, 4477, 16, 'Periode Kadaluarsa Pasword'),
(60341, 4479, 16, 'Pasword untuk Gateway Telepon. Layanan VOIP otomatis disediakan oleh Maviq. Silahkan kunjungi http://signup.maviq.com untuk informasi lebih lanjut.'),
(60342, 4480, 16, 'Pasword untuk SMS Gateway'),
(60343, 4481, 16, 'Pasword untuk SMS Gateway.'),
(60344, 4483, 16, 'Keamanan pasword telah baru saja diupgrade/ditingkatkan.'),
(60345, 4486, 16, 'Pasword:'),
(60346, 4490, 16, 'Batas yang lalu'),
(60347, 4491, 16, 'Batas yang Lalu'),
(60348, 4492, 16, 'Interval Batas yang Lalu (Pengingat Klinis)'),
(60349, 4493, 16, 'Interval Batas yang Lalu (Pengingat Pasien)'),
(60350, 4494, 16, 'Daftar Encounter(Pertemuan) Pasien'),
(60351, 4495, 16, 'Encounter(Pertemuan) yang Lalu'),
(60352, 4496, 16, 'Encounter(Pertemuan) dan Dokumen yang Lalu'),
(60353, 4497, 16, 'Encounter(Pertemuan) untuk'),
(60354, 4498, 16, 'Sisipkan Data HL7'),
(60355, 4499, 16, 'Sisipkan data untuk diimpor kedalam area teks dibawah ini:'),
(60356, 4500, 16, 'Pat'),
(60357, 4502, 16, 'Patch'),
(60358, 4508, 16, 'Jalan untuk Backup Log Event'),
(60359, 4509, 16, 'Jalan ke File Sertifikat CA'),
(60360, 4510, 16, 'Jalan ke File Kunci CA'),
(60361, 4511, 16, 'Jalan ke Binari MySQL'),
(60362, 4512, 16, 'Jalan ke Binari Perl'),
(60363, 4513, 16, 'Jalan ke File Sementara'),
(60364, 4514, 16, 'Pasien'),
(60365, 4515, 16, 'pasien'),
(60366, 4516, 16, 'PASIEN'),
(60367, 4517, 16, 'Alamat Pasien'),
(60368, 4518, 16, 'Alamat Pasien tidak ada'),
(60369, 4521, 16, 'Alergi pasien'),
(60370, 4522, 16, 'Alergi Pasien'),
(60371, 4523, 16, 'Janji Temu Pasien'),
(60372, 4528, 16, 'ID Grafik pasien'),
(60373, 4529, 16, 'Pemeriksaan Pasien'),
(60374, 4530, 16, 'Pemeriksaan Pasien untuk '),
(60375, 4531, 16, 'Kota Pasien'),
(60376, 4532, 16, 'Kota Pasien tidak ada'),
(60377, 4533, 16, 'Komunikasi pasien terkirim'),
(60378, 4534, 16, 'Komunikasi Pasien Terkirim'),
(60379, 4535, 16, 'Negara Pasien'),
(60380, 4536, 16, 'Negara Pasien tidak ada. Juga anda belum menetapkan standar Negara Pasien dalam Pengaturan Global'),
(60381, 4539, 16, 'Data pasien'),
(60382, 4541, 16, 'Tanggal Lahir Pasien tidak ada'),
(60383, 4542, 16, 'Rincian Pasien'),
(60384, 4543, 16, 'Tanggal Lahir Pasien'),
(60385, 4544, 16, 'Dokumen Pasien'),
(60386, 4545, 16, 'Pendidikan Pasien'),
(60387, 4546, 16, 'Materi Edukasi Pasien'),
(60388, 4547, 16, 'Pasien Encounter'),
(60389, 4548, 16, 'Pasien Encounter Formulir'),
(60390, 4549, 16, 'Pasien Encounters'),
(60391, 4550, 16, 'Pencari Pasien'),
(60392, 4551, 16, 'Nama awal Pasien'),
(60393, 4553, 16, 'Nama awal Pasien tidak ada'),
(60394, 4558, 16, 'Jenis Kelamin Pasien'),
(60395, 4559, 16, 'Jenis Kelamin Pasien tidak ada'),
(60396, 4560, 16, 'Pasien tidak diizinkan Portal Pasien'),
(60397, 4561, 16, 'Riwayat Pasien'),
(60398, 4562, 16, 'Riwayat/Gaya Hidup Pasien'),
(60399, 4563, 16, 'Telepon rumah Pasien'),
(60400, 4564, 16, 'ID Pasien'),
(60401, 4566, 16, 'Katu ID(KTP) Pasien'),
(60402, 4567, 16, 'Nama Kategori Kartu ID(KTP) Pasien'),
(60403, 4568, 16, 'Imunisasi Pasien'),
(60404, 4569, 16, 'Informasi Pasien'),
(60405, 4570, 16, 'Instruksi Pasien'),
(60406, 4571, 16, 'Distribusi Asuransi Pasien'),
(60407, 4572, 16, 'Laporan Distribusi Asuransi Pasien'),
(60408, 4573, 16, 'Isu(Masalah) Pasien'),
(60409, 4575, 16, 'Nama akhir Pasien'),
(60410, 4577, 16, 'Nama akhir Pasien tidak ada'),
(60411, 4581, 16, 'Daftar Pasien'),
(60412, 4586, 16, 'Kesalahan Lookup Pasien'),
(60413, 4587, 16, 'Masalah Medis Pasien'),
(60414, 4588, 16, 'Pengobatan Pasien'),
(60415, 4589, 16, 'Nama Pasien'),
(60416, 4590, 16, 'Nama & Alamat Pasien'),
(60417, 4593, 16, 'Nama Pasien Diperlukan'),
(60418, 4595, 16, 'Catatan Pasien'),
(60419, 4596, 16, 'Jenis Catatan Pasien'),
(60420, 4597, 16, 'Catatan Pasien'),
(60421, 4598, 16, 'Catatan Pasien (tulis, hanya tambah opsional)'),
(60422, 4599, 16, 'Nomor Pasien'),
(60423, 4600, 16, 'Pembayaran Pasien'),
(60424, 4602, 16, 'Nama Kategori Foto Pasien'),
(60425, 4603, 16, 'Portal Pasien'),
(60426, 4605, 16, 'Portal Pasien dimatikan'),
(60427, 4606, 16, 'Login Portal Pasien'),
(60428, 4607, 16, 'Alamat Web Portal Pasien'),
(60429, 4608, 16, 'Laporan Tercetak Pasien'),
(60430, 4609, 16, 'Laporan Record(Catatan) Pasien'),
(60431, 4610, 16, 'Permintaan Record(Catatan) Pasien'),
(60432, 4611, 16, 'Permintaan Record(Catatan) Pasien'),
(60433, 4613, 16, 'Pengingat Pasien'),
(60434, 4614, 16, 'Pengingat Batch Job Pasien'),
(60435, 4616, 16, 'Aturan Pengingat Pasien'),
(60436, 4617, 16, 'Email Pengirim Pengingat Pasien'),
(60437, 4618, 16, 'Nama Pengirim Pengingat Pasien'),
(60438, 4619, 16, 'Pengingat Pasien'),
(60439, 4620, 16, 'Laporan Pasien'),
(60440, 4621, 16, 'Permintaan Pasien'),
(60441, 4622, 16, 'Catatan Medis yang Diminta Pasien'),
(60442, 4623, 16, 'Hasil Pasien'),
(60443, 4624, 16, 'Gaya Hasil Pencarian Pasien'),
(60444, 4625, 16, 'Layar Pencarian/Tambah Pasien'),
(60445, 4626, 16, 'Pengaturan Pasien'),
(60446, 4627, 16, 'Negara Pasien'),
(60447, 4629, 16, 'Rangkuman Pasien'),
(60448, 4630, 16, 'Transaksi Pasien'),
(60449, 4631, 16, 'Zip Pasien'),
(60450, 4632, 16, 'pasien dalam database yang cocok dengan informasi demografis yang anda masukkan'),
(60451, 4633, 16, 'Pasien/Klien'),
(60452, 4634, 16, 'Pasien:'),
(60453, 4635, 16, 'ID Pasien'),
(60454, 4636, 16, 'Pasien'),
(60455, 4638, 16, 'Membayar'),
(60456, 4639, 16, 'Perhatikan bagian "Selesai dengan" checkbox. Setelah asuransi ditandai selesai maka kita akan mulai menanyakan pasien untuk membayar sisa saldo, jika anda gagal untuk menandai semua asuransi yang lengkap, maka jumlah yang tersisa tidak akan dikumpulkan! Juga jika ada keseimbangan bahwa pasien harus bayar, kemudian menetapkan tanggal jatuh tempo dengan tepat, karena hal ini akan mempengaruhi bahasa yang muncul pada pasien pernyataan.'),
(60457, 4640, 16, 'Tanggal Bayar:'),
(60458, 4643, 16, 'Pembayar'),
(60459, 4644, 16, 'Jenis pembayar'),
(60460, 4645, 16, 'Membayar'),
(60461, 4646, 16, 'Entitas Pembayaran'),
(60462, 4647, 16, 'Pembayaran'),
(60463, 4648, 16, 'pembayaran'),
(60464, 4649, 16, 'Kode Pengaturan Pembayaran'),
(60465, 4651, 16, 'Jumlah Pembayaran'),
(60466, 4652, 16, 'Jumlah Pembayaran harus berupa numerik(angka)'),
(60467, 4653, 16, 'Kategori Pembayaran'),
(60468, 4654, 16, 'Tanggal Pembayaran'),
(60469, 4655, 16, 'pembayaran dimasukkan pada'),
(60470, 4656, 16, 'Pembayaran Dari'),
(60471, 4658, 16, 'Asuransi Pembayaran'),
(60472, 4659, 16, 'Daftar Pembayaran'),
(60473, 4660, 16, 'Metode Pembayaran'),
(60474, 4661, 16, 'Pembayaran Urut Berdasarkan'),
(60475, 4662, 16, 'Status Pembayaran'),
(60476, 4663, 16, 'Tipe/Jenis Pembayaran'),
(60477, 4664, 16, 'Nilai pembayaran untuk kode '),
(60478, 4665, 16, 'Pembayaran'),
(60479, 4667, 16, 'PCP'),
(60480, 4669, 16, 'PDF'),
(60481, 4670, 16, 'Download PDF Pernyataan yang Dipilih'),
(60482, 4672, 16, 'Panggul dan pantat'),
(60483, 4673, 16, 'Pemphigus'),
(60484, 4674, 16, 'Pending/Tertunda'),
(60485, 4676, 16, 'Tertunda F/U'),
(60486, 4677, 16, 'Menunggu tindak lanjut'),
(60487, 4678, 16, 'Menunggu Tindak Lanjut dari Hasil'),
(60488, 4679, 16, 'Menunggu Pesanan/Pesanan Tertunda'),
(60489, 4680, 16, 'Menunggu Res/Res Tertunda'),
(60490, 4681, 16, 'Menunggu Tinjauan/Tinjauan Tertunda'),
(60491, 4682, 16, 'Menunggu Jumlah Rx/Jumlah Rx Tertunda'),
(60492, 4684, 16, 'Kantor Pennington LibreEHR v'),
(60493, 4685, 16, 'Penyakit Maag'),
(60494, 4687, 16, 'per min'),
(60495, 4688, 16, 'Per Lubang Hidung'),
(60496, 4689, 16, 'per lubang hidung'),
(60497, 4690, 16, 'Per Oris'),
(60498, 4691, 16, 'per oris'),
(60499, 4692, 16, 'Per Dubur'),
(60500, 4693, 16, 'per dubur'),
(60501, 4694, 16, 'Persen'),
(60502, 4697, 16, 'Persentil'),
(60503, 4698, 16, 'Berlubang Kanan:'),
(60504, 4699, 16, 'Melakukan Pencarian'),
(60505, 4700, 16, 'Lakukan tindakan ini'),
(60506, 4701, 16, 'Persentase Kinerja'),
(60507, 4703, 16, 'Melakukan Fasilitas Laboratorium'),
(60508, 4705, 16, 'Periode'),
(60509, 4706, 16, 'Periode dalam hari dimana pengguna dapat login dengan pasword yang sudah kadaluarsa.'),
(60510, 4707, 16, 'Perawatan Perioperatif'),
(60511, 4708, 16, 'Peripheral(Sekeliling)'),
(60512, 4712, 16, 'Orang'),
(60513, 4713, 16, 'Personalisasi'),
(60514, 4714, 16, 'PG'),
(60515, 4715, 16, 'Apotek'),
(60516, 4716, 16, 'Jumpah Perusahaan Apotek'),
(60517, 4717, 16, 'Apotek'),
(60518, 4718, 16, 'Farmasi/Apotek'),
(60519, 4719, 16, 'Farmasi Apotek'),
(60520, 4720, 16, 'Pheumothorax'),
(60521, 4729, 16, 'Telepon'),
(60522, 4730, 16, 'Daftar panggilan telepon'),
(60523, 4733, 16, 'Pasword Gateway Telepon'),
(60524, 4734, 16, 'URL Gateway Telepon'),
(60525, 4735, 16, 'Nama Pengguna Gateway Telepon'),
(60526, 4737, 16, 'Waktu Notifikasi/Pemberitahuan Telepon'),
(60527, 4738, 16, 'Nomor Telepon'),
(60528, 4740, 16, 'Photophobia'),
(60529, 4741, 16, 'Foto'),
(60530, 4742, 16, 'PHP dikompresi'),
(60531, 4743, 16, 'Modul PHP CURL harus diaktfkan pada server anda.'),
(60532, 4744, 16, 'PHP diekstrak'),
(60533, 4745, 16, 'Akses kontrol php-GACL dimatikan'),
(60534, 4746, 16, 'PHP-gacl tidak diinstal'),
(60535, 4747, 16, 'Pemeriksaan Fisik'),
(60536, 4749, 16, 'Permintaan Dokter'),
(60537, 4750, 16, 'Tanda Tangan Dokter'),
(60538, 4752, 16, 'Dokter'),
(60539, 4753, 16, 'pilih'),
(60540, 4754, 16, 'Pilih'),
(60541, 4755, 16, 'Pilih tema CSS.'),
(60542, 4756, 16, 'PID'),
(60543, 4757, 16, 'PID (Penyakit Inflamasi Panggul)'),
(60544, 4758, 16, 'Ukuran Pil'),
(60545, 4759, 16, 'Pil'),
(60546, 4760, 16, 'Tempatkan file zip database dalam direktori berikut jika ingin pilihan untuk menginstal'),
(60547, 4765, 16, 'Placeholder'),
(60548, 4766, 16, 'Placeholder (Menjaga ACL kosong)'),
(60549, 4767, 16, 'Teks Biasa'),
(60550, 4768, 16, 'Rencana'),
(60551, 4771, 16, 'Nama Rencana'),
(60552, 4775, 16, 'Set Rencana'),
(60553, 4779, 16, 'Rencana:'),
(60554, 4782, 16, 'Rencana'),
(60555, 4784, 16, 'Pemain'),
(60556, 4785, 16, 'Posisi Bermain'),
(60557, 4786, 16, 'Silahkan hubungi jika ada informasi diatas yang tidak benar'),
(60558, 4787, 16, 'Silahkan ubah pasword anda.'),
(60559, 4788, 16, 'Silahkan Pilih file'),
(60560, 4789, 16, 'Silahkan pilih pasien'),
(60561, 4790, 16, 'Silahkan pilih pemilihan yang valid dari daftar.'),
(60562, 4791, 16, 'Silahkan pilih pemilihan yang valid.'),
(60563, 4792, 16, 'Silahkan pilih nilai untuk'),
(60564, 4793, 16, 'Silahkan pilih kriteria range(jarak) tanggal diatas, dan klik Refresh untuk melihat hasil.'),
(60565, 4794, 16, 'Silahkan pilih file EDI-271 format yang tepat'),
(60566, 4795, 16, 'Silahkan Klik tombol download untuk mendownload data De Identifikasi'),
(60567, 4796, 16, 'Silahkan Klik tombol download untuk mendownload data Re Identifikasi'),
(60568, 4797, 16, 'Silahkan tutup jendela ini.'),
(60569, 4798, 16, 'Silahkan bandingkan nama baru'),
(60570, 4802, 16, 'Jangan terima resep ini kecuali diterima melalui faksimil.'),
(60571, 4803, 16, 'Jangan terima resep ini kecuali diterima melalui faksimil.'),
(60572, 4804, 16, 'Mohon TIDAK menggunakan tombol berhenti atau reload browser sementara halaman ini sedang berjalan kecuali lebih dari 10 menit telah berlalu, ini tidak akan menyebabkan proses berhenti pada server dan akan mengkonsumsi sumber daya yang tidak perlu.'),
(60573, 4805, 16, 'SILAHKAN AKTIFKAN EKSTENSI CURL'),
(60574, 4806, 16, 'SILAHKAN AKTIFKAN EKSTENSI OPENSSL'),
(60575, 4807, 16, 'SILAHKAN AKTIFKAN EKSTENSI SOAP'),
(60576, 4808, 16, 'SILAHKAN AKTIFKAN EKSTENSI XML'),
(60577, 4809, 16, 'Silahkan masukkan tanggal untuk Tinjauan Terakhir'),
(60578, 4810, 16, 'Silahkan masukkan tanggal.'),
(60579, 4811, 16, 'Silahkan masukkan batas tanggal'),
(60580, 4812, 16, 'Silahkan masukkan pesan'),
(60581, 4813, 16, 'Silahkan masukkan jumlah uang menggunakan hanya angka dan titik desimal.'),
(60582, 4814, 16, 'Silahkan Masukkan Pasword Baru'),
(60583, 4815, 16, 'Silahkan masukkan judul!'),
(60584, 4819, 16, 'Silahkan masukkan kode Re Identifikasi yang benar'),
(60585, 4821, 16, 'Silahkan masukkan string pencarian baru'),
(60586, 4822, 16, 'Silahkan masukkan kode Re Identifikasi yang benar'),
(60587, 4823, 16, 'Silahkan masukkan pasword'),
(60588, 4824, 16, 'Silahkan Isi Nomor Cek'),
(60589, 4826, 16, 'SIlahkan Isi Tanggal'),
(60590, 4827, 16, 'Silahkan Isi Jumlah Pembayaran'),
(60591, 4828, 16, 'Silahkan Isi Kategori Pembayaran'),
(60592, 4829, 16, 'Silahkan Isi Pembayaran Dari'),
(60593, 4830, 16, 'Silahkan Isi Post Ke Tanggal'),
(60594, 4831, 16, 'Silahkan isi mereka sebelum melanjutkan.'),
(60595, 4832, 16, 'Silahkan sebutkan alasan kunjungan'),
(60596, 4834, 16, 'Silahkan masukkan kriteria pencarian diatas, dan klik Serahkan untuk melihat hasil.'),
(60597, 4835, 16, 'Silahkan masukkan kriteria pencarian diatas, dan klik Serahkan untuk melihat hasil. (Hasil akan ditampilkan pada jendela pop up)'),
(60598, 4836, 16, 'Silahkan login kembali.'),
(60599, 4837, 16, 'Perlu diketahui bahwa hal ini bisa memakan waktu yang cukup lama, hingga beberapa menit, browser Anda mungkin tidak terlihat sangat aktif saat ini, tetapi menghasilkan tagihan adalah proses yang rumit dan browser web Anda hanya menunggu untuk informasi lebih lanjut.'),
(60600, 4838, 16, 'Harap Dicatat: konstan adalah case sensitive, dan setiap string diperbolehkan.'),
(60601, 4839, 16, 'Harap hanya menggunakan karakter abjad'),
(60602, 4840, 16, 'Harap hanya menggunakan karakter abjad tanpa spasi'),
(60603, 4841, 16, 'Harap membayar jumlah ini'),
(60604, 4843, 16, 'Silahkan lihat'),
(60605, 4844, 16, 'Silahkan reset pasword.'),
(60606, 4845, 16, 'Silahkan restart server apache sebelum memulai dengan de-identifikasi'),
(60607, 4849, 16, 'Silahkan pilh bahasa'),
(60608, 4850, 16, 'Silahkan Pilih Pasien.'),
(60609, 4851, 16, 'Silahkan pilih fasilitas Entitat/Badan Bisnis Primer dengan ''ID Pajak'' sebagai fasilitas ID Pajak anda. Jika anda adalah seorang praktisi individu, gunakan id pajak anda. Ini digunakan untuk mengidentifikasi anda dalam sistem NewCrop.'),
(60610, 4854, 16, 'Silahkan Pilih Penerima'),
(60611, 4855, 16, 'Silahkan pilih tanggal awal dan tanggal akhir'),
(60612, 4856, 16, 'Silahkan pilih penerima yang valid'),
(60613, 4858, 16, 'Silahkan pilih alasan pengaturan/penyesuaian untuk kode '),
(60614, 4859, 16, 'Silakan pilih sebuah event'),
(60615, 4860, 16, 'Silahkan pilih Pilihan Pencarian.'),
(60616, 4863, 16, 'Silahkan pilih setidaknya satu resep!'),
(60617, 4865, 16, 'Silakan pilih halaman yang dikehendaki untuk menyalin atau meneruskan:'),
(60618, 4866, 16, 'Silahkan Pilih Metode Pembayaran'),
(60619, 4869, 16, 'Silahkan pilih mitra X12, dibutuhkan untuk membuat batch 270'),
(60620, 4870, 16, 'Silahkan set'),
(60621, 4871, 16, 'Silahkan set variabel de_identification_config kembali ke nol'),
(60622, 4873, 16, 'Silahkan mulai proses De Identifikasi baru'),
(60623, 4874, 16, 'Silahkan upgrade Database LibreEHR untuk memasukkan prosedur, fungsi, tabel De Identifikasi'),
(60624, 4875, 16, 'Silahkan lihat tabel log kesalahan De Identifikasi untuk lebih jelasnya'),
(60625, 4876, 16, 'Silahkan kunjungi layar De Identifikasi setelah beberapa waktu'),
(60626, 4877, 16, 'Silahkan kunjungi layar Re Identifikasi setelah beberapa waktu'),
(60627, 4878, 16, 'Silahkan kunjungi layar setelah beberapa waktu'),
(60628, 4882, 16, 'PM'),
(60629, 4883, 16, 'Program PM'),
(60630, 4884, 16, 'Metode Pmt'),
(60631, 4885, 16, 'PND'),
(60632, 4886, 16, 'Pneumococcal Conjugate (Konjugasi Radang Paru) 1'),
(60633, 4887, 16, 'Pneumococcal Conjugate (Konjugasi Radang Paru) 2'),
(60634, 4888, 16, 'Pneumococcal Conjugate (Konjugasi Radang Paru) 3'),
(60635, 4889, 16, 'Pneumococcal Conjugate (Konjugasi Radang Paru) 4'),
(60636, 4890, 16, 'Vaksin Radang Paru'),
(60637, 4891, 16, 'Vaksinasi Radang Paru-paru'),
(60638, 4892, 16, 'Status Vaksinasi Radang Paru untuk Dewasa Lebih Tua'),
(60639, 4893, 16, 'Status Vaksinasi Radang Paru untuk Dewasa Lebih Tua (CQM)'),
(60640, 4894, 16, 'Podiatric'),
(60641, 4896, 16, 'Point of Service (POS) (Titik Layanan)'),
(60642, 4897, 16, 'Kebijakan'),
(60643, 4898, 16, 'Nomor Kebijakan'),
(60644, 4899, 16, 'Nomor Kebijakan'),
(60645, 4900, 16, 'Polandia'),
(60646, 4901, 16, 'Polydypsia'),
(60647, 4902, 16, 'Polyps'),
(60648, 4903, 16, 'Poliuria'),
(60649, 4904, 16, 'Nafsu Makan Rendah'),
(60650, 4905, 16, 'Sirkulasi Rendah'),
(60651, 4906, 16, 'Kurang Pendengaran'),
(60652, 4907, 16, 'Pop up harus diaktifkan untuk melihat laporan ini'),
(60653, 4908, 16, 'Isi tampilan tahun dengan event?'),
(60654, 4909, 16, 'Popup'),
(60655, 4911, 16, 'Portal Aktifitas/Kegiatan'),
(60656, 4917, 16, 'Portugis'),
(60657, 4918, 16, 'Portugis (Brasil)'),
(60658, 4919, 16, 'Portugis (Eropa)'),
(60659, 4920, 16, 'Kode POS'),
(60660, 4922, 16, 'Positif'),
(60661, 4923, 16, 'Positif'),
(60662, 4925, 16, 'Post Untuk'),
(60663, 4926, 16, 'Post Nasal Drip'),
(60664, 4927, 16, 'Post Pembayaran'),
(60665, 4928, 16, 'Post Pembedahan'),
(60666, 4929, 16, 'Posting ke akuntansi dan tandai sebagai tagihan'),
(60667, 4930, 16, 'Post ke Tanggal'),
(60668, 4931, 16, 'Post ke Tanggal Tidak bisa lebih besar dari Hari Ini'),
(60669, 4932, 16, 'Post ke Tanggal Harus lebih besar dari Tanggal Penutupan Keuangan.'),
(60670, 4933, 16, 'Perawatan Post-Abortion'),
(60671, 4934, 16, 'Kontrasepsi Post-Abortion'),
(60672, 4935, 16, 'Konseling Post-Abortion'),
(60673, 4936, 16, 'Menindaklanjuti Post-Abortion'),
(60674, 4937, 16, 'Pos'),
(60675, 4938, 16, 'Kode Pos'),
(60676, 4939, 16, 'Kode pos'),
(60677, 4941, 16, 'PostCalendar'),
(60678, 4942, 16, 'Administrasi PostCalendar'),
(60679, 4943, 16, 'Pengaturan Kategori PostCalendar'),
(60680, 4944, 16, 'Pengaturan Global PostCalendar'),
(60681, 4945, 16, 'Diposkan pada'),
(60682, 4946, 16, 'Tanggal Posting'),
(60683, 4948, 16, 'Didukung oleh');
INSERT INTO `lang_definitions` VALUES
(60684, 4949, 16, 'PPE + Pengobatan/Pembedahan Sebelumnya Hx'),
(60685, 4950, 16, 'PQRI'),
(60686, 4951, 16, 'ID Pendaftaran PQRI'),
(60687, 4952, 16, 'Nama Pendaftaran PQRI'),
(60688, 4953, 16, 'Praktek'),
(60689, 4954, 16, 'Pengaturan Standar Praktek'),
(60690, 4955, 16, 'Pengaturan Praktek'),
(60691, 4956, 16, 'Praktisi'),
(60692, 4959, 16, 'Pembayaran Dimuka'),
(60693, 4960, 16, 'Konsultasi Pre-Abortion'),
(60694, 4961, 16, 'Konseling Pre-Abortion'),
(60695, 4962, 16, 'Pref Cat'),
(60696, 4964, 16, 'Preferensi'),
(60697, 4965, 16, 'Kategori Event Pilihan'),
(60698, 4966, 16, 'Bahasa Pilihan'),
(60699, 4967, 16, 'Farmasi Pilihan'),
(60700, 4968, 16, 'Organisasi Provider Pilihan (PPO)'),
(60701, 4969, 16, 'Tes Preg'),
(60702, 4970, 16, 'Pendahuluan'),
(60703, 4972, 16, 'Pembayaran Langsung'),
(60704, 4973, 16, 'Resep'),
(60705, 4974, 16, 'resep telah mencapai batasnya dari'),
(60706, 4975, 16, 'Riwayat Resep'),
(60707, 4976, 16, 'Impor Riwayat Resep telah berhasil'),
(60708, 4977, 16, 'Label Resep'),
(60709, 4978, 16, 'Laporan Resep'),
(60710, 4979, 16, 'Resep'),
(60711, 4980, 16, 'Resep dan Dispensasi'),
(60712, 4981, 16, 'Resep dan rujukan lainnya'),
(60713, 4982, 16, 'Resep dan/atau rujukan oleh ahli'),
(60714, 4983, 16, 'Laporan Resep'),
(60715, 4984, 16, 'Resep/Rujukan'),
(60716, 4985, 16, 'Mengajukan'),
(60717, 4986, 16, 'Mengajukan Keluhan'),
(60718, 4988, 16, 'Tekan Lanjut untuk meneruskan'),
(60719, 4989, 16, 'Diagnosa yang Diduga'),
(60720, 4990, 16, 'Diagnosa yang DIduga oleh pakar'),
(60721, 4991, 16, 'Sebelumnya'),
(60722, 4992, 16, 'Pengobatan/Pembedahan Sebelumnya'),
(60723, 4993, 16, 'Bulan sebelumnya (tahan untuk menu)'),
(60724, 4994, 16, 'Tahun sebelumnya (tahan untuk menu)'),
(60725, 4995, 16, 'Perawatan Pencegahan'),
(60726, 4998, 16, 'Pratinjau Event'),
(60727, 5000, 16, 'Pratinjau dari'),
(60728, 5001, 16, 'Sebelumnya'),
(60729, 5002, 16, 'Konsultasi Sebelumnya'),
(60730, 5003, 16, 'Hari Sebelumnya'),
(60731, 5004, 16, 'Riwayat Sebelumnya/Penyaringan'),
(60732, 5005, 16, 'Bulan Sebelumnya'),
(60733, 5006, 16, 'Minggu Sebelumnya'),
(60734, 5007, 16, 'Harga'),
(60735, 5008, 16, 'Diskon Harga'),
(60736, 5009, 16, 'Tingkat Harga'),
(60737, 5010, 16, 'Tingkat Harga:'),
(60738, 5011, 16, 'Harga'),
(60739, 5012, 16, 'Utama/Primer'),
(60740, 5013, 16, 'Entitas/Badan Bisnis Primer'),
(60741, 5014, 16, 'ID pajak Entitas/Badan Bisnis Primer digunakan sebagai id rekening untuk NewCrop ePrescription. Mengubah fasilitas tersebut akan mempengaruh i kerja pada NewCrop.'),
(60742, 5022, 16, 'Asuransi Primer'),
(60743, 5023, 16, 'Asuransi Primer'),
(60744, 5024, 16, 'Data Asuransi Primer'),
(60745, 5025, 16, 'Provider Asuransi Primer'),
(60746, 5026, 16, 'Provider Primer'),
(60747, 5027, 16, 'Cetak'),
(60748, 5028, 16, 'Cetak (HTML)'),
(60749, 5029, 16, 'Cetak (PDF)'),
(60750, 5031, 16, 'Cetak Encounter(Pertemuan) Apapun'),
(60751, 5032, 16, 'Cetak Formulir Rujukan Kosong'),
(60752, 5033, 16, 'Perintah Cetak'),
(60753, 5039, 16, 'Format Cetakan'),
(60754, 5040, 16, 'Panel Empat Cetakan'),
(60755, 5042, 16, 'Pesan cetakan'),
(60756, 5043, 16, 'Cetak Beberapa'),
(60757, 5044, 16, 'Cetak Beberapa Ke Fax'),
(60758, 5045, 16, 'Nama cetakan, tanda dan tanggal.'),
(60759, 5046, 16, 'Cetak Catatan'),
(60760, 5047, 16, 'Cetak Halaman 1'),
(60761, 5048, 16, 'Cetak Halaman 2'),
(60762, 5051, 16, 'Penerima Cetakan oleh Provider'),
(60763, 5052, 16, 'Cetak Record(Catatan)'),
(60764, 5053, 16, 'Cetak Pernyataan yang Dipilih'),
(60765, 5054, 16, 'Cetak Shot Record'),
(60766, 5056, 16, 'Cetak Encounter(Pertemuan) Ini'),
(60767, 5057, 16, 'Cetak catatan ini'),
(60768, 5058, 16, 'Cetak Catatan Ini'),
(60769, 5060, 16, 'Cetak Ke Fax'),
(60770, 5061, 16, 'Tampilan Cetakan'),
(60771, 5062, 16, 'dapat dicetak'),
(60772, 5063, 16, 'Versi Cetakan'),
(60773, 5064, 16, 'Dicetak'),
(60774, 5066, 16, 'Mencetak hasil:'),
(60775, 5067, 16, 'Pencetakan dilewati; lihat output tes di'),
(60776, 5068, 16, 'Pencetakan dilewati; lihat output tes di '),
(60777, 5069, 16, 'Otorisasi Sebelumnya'),
(60778, 5070, 16, 'Formulir Otorisasi Sebelumnya'),
(60779, 5071, 16, 'Kunjungan Sebelumnya'),
(60780, 5072, 16, 'Prioritas'),
(60781, 5073, 16, 'Prioritas '),
(60782, 5074, 16, 'Swasta'),
(60783, 5075, 16, 'Masalah'),
(60784, 5076, 16, 'Masalah DX'),
(60785, 5077, 16, 'Daftar Masalah'),
(60786, 5079, 16, 'Masalah/Isu'),
(60787, 5080, 16, 'Proc Bat'),
(60788, 5081, 16, 'Proc Cat'),
(60789, 5083, 16, 'Proc Pending Rev'),
(60790, 5085, 16, 'Proc Res'),
(60791, 5086, 16, 'Prosedur'),
(60792, 5087, 16, 'Situs Badan Prosedur'),
(60793, 5088, 16, 'Hasil Boolean Prosedur'),
(60794, 5089, 16, 'Kode Prosedur'),
(60795, 5091, 16, 'Lateralitas Prosedur'),
(60796, 5093, 16, 'Prosedur Pesanan'),
(60797, 5095, 16, 'Prosedur Pesanan Untuk'),
(60798, 5102, 16, 'Laporan Prosedur'),
(60799, 5103, 16, 'Status Laporan Prosedur'),
(60800, 5104, 16, 'Hasil Prosedur Abnormal'),
(60801, 5105, 16, 'Status Hasil Prosedur'),
(60802, 5106, 16, 'Hasil Prosedur Abnormal'),
(60803, 5107, 16, 'Rute Prosedur'),
(60804, 5108, 16, 'Jenis Spesimen Prosedur'),
(60805, 5109, 16, 'Laporan Statistik Prosedur'),
(60806, 5110, 16, 'Jenis Prosedur'),
(60807, 5111, 16, 'Jenis Prosedur'),
(60808, 5112, 16, 'Unit(Satuan) Prosedur'),
(60809, 5114, 16, 'Prosedur'),
(60810, 5115, 16, 'Proses'),
(60811, 5117, 16, 'Proses File ERA'),
(60812, 5121, 16, 'Diproses'),
(60813, 5122, 16, 'Diproses oleh'),
(60814, 5123, 16, 'Tanggal Diproses'),
(60815, 5125, 16, 'Pengolahan'),
(60816, 5129, 16, 'Produk'),
(60817, 5130, 16, 'Produk Metode Kontrasepsi'),
(60818, 5132, 16, 'Produk'),
(60819, 5133, 16, 'Produk namun tanpa resep obat dan tanpa template'),
(60820, 5134, 16, 'Prof.'),
(60821, 5135, 16, 'Catatan Perkembangan'),
(60822, 5136, 16, 'Kanker Prostat'),
(60823, 5137, 16, 'Penyaringan Kanker Prostat'),
(60824, 5138, 16, 'Pemeriksaan Prostat'),
(60825, 5139, 16, 'Masalah Prostat'),
(60826, 5140, 16, 'Prostat w/o pembesaran, bengkak, perih'),
(60827, 5142, 16, 'Sediakan path absolut'),
(60828, 5143, 16, 'Sediakan path dari file yang absolut'),
(60829, 5145, 16, 'Sediakan rangkuman klinis untuk pasien untuk setiap kunjungan kantor.'),
(60830, 5146, 16, 'Menyediakan pasien dengan salinan elektronik dari informasi kesehatan mereka (termasuk hasil tes diagnostik, daftar masalah, daftar obat/pengobatan, alergi obat/pengobatan), atas permintaan.'),
(60831, 5147, 16, 'Menyediakan pasien dengan akses elektronik yang tepat terhadap informasi kesehatan mereka (termasuk hasil lab, dafta masalah, daftar obat/pengobatan, alergi obat/pengobatan) dalam waktu empat hari kerja dari informasi yang tersedia untuk EP.'),
(60832, 5148, 16, 'Sediakan Record(Catatan) untuk Pasien untuk Kunjungan'),
(60833, 5149, 16, 'Sediakan Alamat Email yang valid'),
(60834, 5150, 16, 'Sediakan Rangkuman Klinis?'),
(60835, 5151, 16, 'Sediakan Sumber Daya Pendidikan?'),
(60836, 5152, 16, 'Provider/Penyedia'),
(60837, 5156, 16, 'Kesalahan Kecocokan Provider'),
(60838, 5159, 16, 'Nomor Provider'),
(60839, 5162, 16, 'Provider:'),
(60840, 5163, 16, 'Provider'),
(60841, 5164, 16, 'Provider NPI'),
(60842, 5165, 16, 'Provider Melihat Keseluruhan Kalender'),
(60843, 5166, 16, 'Prv'),
(60844, 5167, 16, 'PSA'),
(60845, 5168, 16, 'Psorias'),
(60846, 5169, 16, 'Diagnosa Psikiatrik'),
(60847, 5170, 16, 'Pengobatan Psikiatrik'),
(60848, 5171, 16, 'Psikiatrik'),
(60849, 5172, 16, 'Surat Singkat Psikiatrik'),
(60850, 5173, 16, 'Diagnosa Psikiatrik'),
(60851, 5174, 16, 'Pemeriksaan Psikiatrik'),
(60852, 5175, 16, 'Riwayat Psikiatrik'),
(60853, 5176, 16, 'Intake Psikiatrik'),
(60854, 5177, 16, 'Pengobatan Psikiatrik'),
(60855, 5178, 16, 'Pt %'),
(60856, 5179, 16, 'Catatan Pt'),
(60857, 5180, 16, 'Catatan/Otentikasi Pt'),
(60858, 5181, 16, 'Pt kelebihan pembayaran'),
(60859, 5182, 16, 'Pt Dibayar'),
(60860, 5183, 16, 'Pt Rec Request'),
(60861, 5184, 16, 'Pt pengembalian dana'),
(60862, 5185, 16, 'Pt dirilis'),
(60863, 5186, 16, 'Pt Lapor'),
(60864, 5187, 16, 'PT Siswa, atau biarkan kosong'),
(60865, 5188, 16, 'PT_KOTA'),
(60866, 5189, 16, 'PT_TGLLHR'),
(60867, 5191, 16, 'PT_NAMAAWL'),
(60868, 5192, 16, 'PT_NAMATGH'),
(60869, 5193, 16, 'PT_NAMAAKHR'),
(60870, 5196, 16, 'PT_POS'),
(60871, 5198, 16, 'PT_NEGARA'),
(60872, 5199, 16, 'PT_JALAN'),
(60873, 5201, 16, 'Publik'),
(60874, 5203, 16, 'Layanan Kesehatan Publik (PHS) atau Badan Federal Lainnya'),
(60875, 5204, 16, 'Puerto Rico'),
(60876, 5205, 16, 'Paru-paru'),
(60877, 5206, 16, 'Nadi'),
(60878, 5207, 16, 'Punjabi'),
(60879, 5208, 16, 'Pembelian'),
(60880, 5209, 16, 'Pembelian/Kembali'),
(60881, 5210, 16, 'Pembelian'),
(60882, 5213, 16, 'q.3h'),
(60883, 5214, 16, 'q.4h'),
(60884, 5215, 16, 'q.5h'),
(60885, 5216, 16, 'q.6h'),
(60886, 5217, 16, 'q.8h'),
(60887, 5218, 16, 'q.d.'),
(60888, 5219, 16, 'q.i.d.'),
(60889, 5220, 16, 'QOH'),
(60890, 5221, 16, 'QOH kurang dari pemakaian bulanan'),
(60891, 5222, 16, 'Qty'),
(60892, 5223, 16, 'QTY'),
(60893, 5224, 16, 'Kualitas'),
(60894, 5225, 16, 'Ukuran Kualitas (CQM)'),
(60895, 5226, 16, 'Kuantitas'),
(60896, 5227, 16, 'Kuantitas untuk NDC'),
(60897, 5228, 16, 'Kuantitas Pada Tangan'),
(60898, 5229, 16, 'kuantitas tampaknya tidak dapat digunakan'),
(60899, 5231, 16, 'Tanda Tanya'),
(60900, 5232, 16, 'Antrian untuk batch pengolahan HCFA'),
(60901, 5233, 16, 'Antrian untuk batch pengolahan dan pencetakan HCFA'),
(60902, 5234, 16, 'Antrian untuk batch pengolahan UB-92'),
(60903, 5235, 16, 'Antrian untuk batch pengolahan dan pencetakan UB-92'),
(60904, 5236, 16, 'Antri'),
(60905, 5237, 16, 'Antri Kegiatan Administrasi'),
(60906, 5238, 16, 'Antri untuk'),
(60907, 5240, 16, 'Antri Administrasi Pengiriman'),
(60908, 5241, 16, 'Keluar'),
(60909, 5242, 16, 'Berhenti Alkohol'),
(60910, 5243, 16, 'Ras'),
(60911, 5245, 16, 'Ras'),
(60912, 5246, 16, 'Ras dan Etnis'),
(60913, 5247, 16, 'Ras/Etnis'),
(60914, 5248, 16, 'Radio'),
(60915, 5249, 16, 'Tombol radio'),
(60916, 5251, 16, 'Range(Jarak)'),
(60917, 5252, 16, 'Ruam'),
(60918, 5253, 16, 'Laju'),
(60919, 5254, 16, 'Rasio'),
(60920, 5255, 16, 'Laporan Baku'),
(60921, 5256, 16, 'Identifikasi Kembali'),
(60922, 5257, 16, 'Proses Identifikasi Kembali selesai'),
(60923, 5258, 16, 'Proses identifikasi Kembali sedang berlangsung'),
(60924, 5259, 16, 'File Identifikasi kembali akan disimpan dalam'),
(60925, 5260, 16, 'Kembali cedera?'),
(60926, 5261, 16, 'Kembali Membuka'),
(60927, 5262, 16, 'Kembali dibuka'),
(60928, 5263, 16, 'Reaksi'),
(60929, 5264, 16, 'Reaksi'),
(60930, 5265, 16, 'Baca'),
(60931, 5268, 16, 'Nama Asli'),
(60932, 5269, 16, 'Benar-benar menghapus'),
(60933, 5270, 16, 'Alasan'),
(60934, 5271, 16, 'Alasan Meninggal'),
(60935, 5272, 16, 'Alasan Kematian'),
(60936, 5274, 16, 'Alasan rujukan'),
(60937, 5275, 16, 'Alasan Kunjungan'),
(60938, 5276, 16, 'Alasan/Formulir'),
(60939, 5277, 16, 'Penerimaan'),
(60940, 5278, 16, 'Terima untuk Pembayaran'),
(60941, 5279, 16, 'Terima yang Dihasilkan'),
(60942, 5280, 16, 'Penerimaan oleh Laporan Metode Pembayaran'),
(60943, 5281, 16, 'Rangkuman Penerimaan'),
(60944, 5282, 16, 'Diterima'),
(60945, 5283, 16, 'Diterima Oleh'),
(60946, 5284, 16, 'Faks yang Diterima'),
(60947, 5287, 16, 'Penerima'),
(60948, 5288, 16, 'ID Penerima'),
(60949, 5289, 16, 'ID Penerima (ISA08)'),
(60950, 5290, 16, 'Kualifikasi ID Penerima (ISA07)'),
(60951, 5292, 16, 'Tiga pasword terakhir tidak diperbolehkan.'),
(60952, 5293, 16, 'Penerima'),
(60953, 5294, 16, 'Daftar Penerima Kosong'),
(60954, 5295, 16, 'Nama Penerima'),
(60955, 5296, 16, 'Penerima dari Pembukaan'),
(60956, 5298, 16, 'Rekomendasi'),
(60957, 5300, 16, 'Rekomendasi'),
(60958, 5301, 16, 'Rekomendasi dan perawatan'),
(60959, 5302, 16, 'Rekomendasi oleh pakar'),
(60960, 5303, 16, 'Record(Catatan)'),
(60961, 5304, 16, 'Catatan telah ada'),
(60962, 5310, 16, 'Penggantian grafik dan catatan pada tanda vital.'),
(60963, 5311, 16, 'Rekam demografis.'),
(60964, 5312, 16, 'Rekam Pengungkapan'),
(60965, 5313, 16, 'Catatan Kebugaran'),
(60966, 5314, 16, 'Rekam Pembayaran'),
(60967, 5315, 16, 'Rekam Tanggal Permintaan'),
(60968, 5316, 16, 'Rekam status merokok untuk pasien 13 tahun atau lebih.'),
(60969, 5317, 16, 'Record(Catatan)'),
(60970, 5318, 16, 'catatan ditemukan'),
(60971, 5319, 16, 'catatan ditemukan.'),
(60972, 5320, 16, 'Penggunaan obat rekreasi'),
(60973, 5321, 16, 'Obat Rekreasi'),
(60974, 5322, 16, 'Rektal'),
(60975, 5323, 16, 'Pemeriksaan Rektal(Dubur)'),
(60976, 5324, 16, 'rektal'),
(60977, 5325, 16, 'Redirection'),
(60978, 5326, 16, 'Kemerahan'),
(60979, 5327, 16, 'dikurangi:'),
(60980, 5328, 16, 'Mengaci'),
(60981, 5329, 16, 'Mengacu oleh/dengan'),
(60982, 5330, 16, 'Mengacu Tanggal'),
(60983, 5331, 16, 'Mengacu Ke'),
(60984, 5332, 16, 'Referensi klasifikasi (tingkat resiko)'),
(60985, 5333, 16, 'Referensi berbagai hasil'),
(60986, 5334, 16, 'Alasan Referensi'),
(60987, 5336, 16, 'Nama dan tanda tangan perujuk'),
(60988, 5337, 16, 'Rujukan'),
(60989, 5338, 16, 'Rujukan Oleh'),
(60990, 5339, 16, 'Kartu Rujukan'),
(60991, 5340, 16, 'Tanggal Rujukan'),
(60992, 5341, 16, 'Formulir Rujukan'),
(60993, 5342, 16, 'FORMULIR RUJUKAN'),
(60994, 5343, 16, 'ID Rujukan'),
(60995, 5345, 16, 'Sumber Rujukan'),
(60996, 5346, 16, 'Sumber Rujukan untuk Encounter(Pertemuan)'),
(60997, 5347, 16, 'Rujukan Ke'),
(60998, 5348, 16, 'Rujukan'),
(60999, 5349, 16, 'Laporan Rujukan'),
(61000, 5350, 16, 'Dirujuk oleh'),
(61001, 5351, 16, 'Dirujuk Oleh'),
(61002, 5352, 16, 'Dirujuk ke'),
(61003, 5353, 16, 'Perujuk'),
(61004, 5355, 16, 'Diagnosa Perujuk'),
(61005, 5356, 16, 'Diagnosa perujuk'),
(61006, 5357, 16, 'Merujuk dokter dan praktek'),
(61007, 5358, 16, 'Merujuk Provider'),
(61008, 5359, 16, 'Isi Ulang'),
(61009, 5360, 16, 'Isi Ulang'),
(61010, 5361, 16, 'isi ulang'),
(61011, 5362, 16, 'Refleks Normal'),
(61012, 5363, 16, 'Refresh'),
(61013, 5365, 16, 'Merefresh Pengingat'),
(61014, 5368, 16, 'Menolak Menyatakan'),
(61015, 5369, 16, 'reg_re'),
(61016, 5370, 16, 'mendaftar'),
(61017, 5372, 16, 'Terdaftar'),
(61018, 5373, 16, 'terdaftar'),
(61019, 5375, 16, 'Tanggal Registrasi'),
(61020, 5376, 16, 'Formulir Registrasi'),
(61021, 5377, 16, 'Rehabilitasi'),
(61022, 5381, 16, 'Berhubungan Ke'),
(61023, 5382, 16, 'Terkait'),
(61024, 5383, 16, 'Isu(Masalah) Terkait'),
(61025, 5385, 16, 'Hubungan/Anak-anak'),
(61026, 5386, 16, 'Hubungan'),
(61027, 5387, 16, 'Hubungan'),
(61028, 5388, 16, 'Urutan relatif entitas ini'),
(61029, 5389, 16, 'Saudara'),
(61030, 5399, 16, 'Mandat Relay(Penyampaian) Kesehatan tidak ada dari akun pengguna.'),
(61031, 5400, 16, 'ID Relay Kesehatan'),
(61032, 5403, 16, 'Agama'),
(61033, 5406, 16, 'Login kembali'),
(61034, 5407, 16, 'Remdr'),
(61035, 5408, 16, 'Ingat Fasilitas yand Dipilih'),
(61036, 5409, 16, 'Pengingat'),
(61037, 5410, 16, 'Interval pengingat'),
(61038, 5411, 16, 'Pengingat Belum Terkirim'),
(61039, 5412, 16, 'Pengingat Dikirim Pada'),
(61040, 5413, 16, 'Pengingat'),
(61041, 5414, 16, 'MENGIRIMKAN KE'),
(61042, 5416, 16, 'Hapus'),
(61043, 5419, 16, 'Hapus Grup'),
(61044, 5420, 16, 'Hapus Formulir Grup'),
(61045, 5421, 16, 'Hapus dukungan untuk imunisasi'),
(61046, 5422, 16, 'Hapus dukungan untuk phpMyAdmin'),
(61047, 5423, 16, 'Hapus dukungan untuk resep'),
(61048, 5425, 16, 'Hapus fitur Pelacak Bagan/Grafik'),
(61049, 5426, 16, 'Batu Ginjal'),
(61050, 5427, 16, 'Ubah Nama'),
(61051, 5428, 16, 'Ubah Nama Grup'),
(61052, 5429, 16, 'Merender'),
(61053, 5430, 16, 'Merender Provider'),
(61054, 5431, 16, 'Merender Nomor Provider'),
(61055, 5432, 16, 'Susun Ulang'),
(61056, 5433, 16, 'Susun Ulang Pada'),
(61057, 5434, 16, 'Angka pemesanan kembali telah tercapai'),
(61058, 5435, 16, 'Angka pemesanan kembali, 0 jika tidak berlaku'),
(61059, 5436, 16, 'Rep'),
(61060, 5438, 16, 'Mengulang event'),
(61061, 5439, 16, 'Mengulangi Info:'),
(61062, 5440, 16, 'Mengulang'),
(61063, 5444, 16, 'Tanggal Balasan'),
(61064, 5445, 16, 'Balasan Dari'),
(61065, 5446, 16, 'Laporan'),
(61066, 5447, 16, 'Laporan - Klinis'),
(61067, 5449, 16, 'Laporan oleh'),
(61068, 5457, 16, 'Status Laporan'),
(61069, 5458, 16, 'Total Laporan'),
(61070, 5460, 16, 'Dilaporkan'),
(61071, 5461, 16, 'Dilaporkan'),
(61072, 5462, 16, 'Tanggal Dilaporkan'),
(61073, 5463, 16, 'Laporan'),
(61074, 5467, 16, 'Permintaan diabaikan - mengklaim telah menjalankan proses!'),
(61075, 5474, 16, 'Layanan yang Diminta'),
(61076, 5475, 16, 'Membutuhkan Pasword Kuat'),
(61077, 5476, 16, 'Membutuhkan Pasword Unik'),
(61078, 5477, 16, 'Diperlukan'),
(61079, 5479, 16, 'Field(Bagian) yang diperlukan tidak ada: Silahkan pilih file EDI-271 untuk mengupload'),
(61080, 5480, 16, 'Field(Bagian) yang diperlukan tidak ada: Silahkan masukkan Nama awal'),
(61081, 5481, 16, 'Field(Bagian) yang diperlukan tidak ada: Silahkan masukkan Nama akhir'),
(61082, 5482, 16, 'Field(Bagian) yang diperlukan tidak ada: SIlahkan masukkan Nama Pengguna'),
(61083, 5483, 16, 'Bagian yang dibutuhkan'),
(61084, 5484, 16, 'Persyaratan'),
(61085, 5485, 16, 'DIPESAN'),
(61086, 5486, 16, 'Dipesan'),
(61087, 5487, 16, 'Dicadangkan untuk digunakan mendefinisikan Waktu Liburan Terjadwal'),
(61088, 5488, 16, 'Dicadangkan untuk mendefinisikan ketika provider mungkin tidak memiliki janji temu yang tersedia.'),
(61089, 5489, 16, 'Dicadangkan untuk mendefinisikan ketika sebuah event tidak terjadi seperti yang telah ditentukan.'),
(61090, 5490, 16, 'Dicadangkan untuk mendefinisikan ketika provider mungkin tidak memilik janji temu yang tersedia.'),
(61091, 5491, 16, 'Reset'),
(61092, 5492, 16, 'Reset Mandat Portal Offsite'),
(61093, 5493, 16, 'Reset Mandat Portal Onsite'),
(61094, 5495, 16, 'Resn'),
(61095, 5496, 16, 'Terselesaikan'),
(61096, 5497, 16, 'Pernapasan'),
(61097, 5498, 16, 'Upaya alat pernapasan tidak bekerja'),
(61098, 5499, 16, 'Pernapasan'),
(61099, 5501, 16, 'Membatasi pengguna non-resmi ke Fasilitas Jadwal diatur dalam admin Pengguna.'),
(61100, 5502, 16, 'Membatasi Pengguna ke Fasilitas'),
(61101, 5503, 16, 'Pelatihan Dibatasi'),
(61102, 5504, 16, 'Hasil'),
(61103, 5506, 16, 'Status Hasil'),
(61104, 5507, 16, 'Status hasil atau abmormalitas tidak ada'),
(61105, 5508, 16, 'Hasil, gunakan % sebagai wildcard'),
(61106, 5510, 16, 'Hasil dan'),
(61107, 5511, 16, 'Hasil Ditemukan Untuk Pencarian'),
(61108, 5512, 16, 'Grup Hasil'),
(61109, 5515, 16, 'Hasil per halaman'),
(61110, 5516, 16, 'Hasil/Rincian'),
(61111, 5517, 16, 'Pemeriksaan Retina'),
(61112, 5518, 16, 'Retracted Kanan:'),
(61113, 5519, 16, 'Kembali'),
(61114, 5520, 16, 'Kembali bagian atas dengan pembayaran anda'),
(61115, 5521, 16, 'Kembali ke kalender'),
(61116, 5527, 16, 'Nilai Kembali'),
(61117, 5528, 16, 'Kembali Kunjungi'),
(61118, 5529, 16, 'Kembali ke Bermain'),
(61119, 5534, 16, 'Tinjauan PMH:'),
(61120, 5535, 16, 'Tinjauan Sistem'),
(61121, 5536, 16, 'Tinjauan Cek/Pengujian Sistem'),
(61122, 5537, 16, 'Diulas'),
(61123, 5538, 16, 'Revisi'),
(61124, 5539, 16, 'Arthritis Radang Sendi'),
(61125, 5540, 16, 'Rheumotoid Radang Sendi'),
(61126, 5541, 16, 'Kanan'),
(61127, 5542, 16, 'Telinga Kanan'),
(61128, 5543, 16, 'telinga kanan'),
(61129, 5545, 16, 'Right:'),
(61130, 5546, 16, 'Dering di Telinga'),
(61131, 5547, 16, 'Dering Di Telinga'),
(61132, 5549, 16, 'Faktor-faktor Risiko'),
(61133, 5550, 16, 'Tingkat Risiko'),
(61134, 5551, 16, 'RLL:'),
(61135, 5552, 16, 'ROM'),
(61136, 5553, 16, 'Rumania'),
(61137, 5560, 16, 'Roster'),
(61138, 5561, 16, 'Rute'),
(61139, 5562, 16, 'Rute administrasi, jika berlaku/ada'),
(61140, 5563, 16, 'Rute'),
(61141, 5564, 16, 'Baris'),
(61142, 5565, 16, 'RRR tanpa MOR'),
(61143, 5566, 16, 'Kesulitan:'),
(61144, 5567, 16, 'Kesulitan:'),
(61145, 5568, 16, 'Aturan'),
(61146, 5569, 16, 'Tambah Aturan'),
(61147, 5570, 16, 'Rincian Aturan'),
(61148, 5572, 16, 'Edit Aturan'),
(61149, 5575, 16, 'Set Aturan'),
(61150, 5578, 16, 'Aturan'),
(61151, 5580, 16, 'Konfigurasi Aturan'),
(61152, 5581, 16, 'Perintah yang Berjalan: '),
(61153, 5582, 16, 'Perpecahan/Putus'),
(61154, 5583, 16, 'Rusia'),
(61155, 5584, 16, 'Rx'),
(61156, 5585, 16, 'RX'),
(61157, 5586, 16, 'Rx Batas Bawah (px)'),
(61158, 5587, 16, 'Rx Aktifkan DEA #'),
(61159, 5588, 16, 'Rx Aktifkan NPI'),
(61160, 5589, 16, 'Rx Aktifkan Lisensi Negara #'),
(61161, 5590, 16, 'Rx Batas Kiri (px)'),
(61162, 5591, 16, 'Rx Ukuran Kertas'),
(61163, 5592, 16, 'Rx Batas Kanan (px)'),
(61164, 5593, 16, 'Rx Tampilkan DEA #'),
(61165, 5594, 16, 'Rx Tampilkan NPI'),
(61166, 5595, 16, 'Rx Tampilkan Lisensi Negara'),
(61167, 5596, 16, 'Rx Batas Atas (px)'),
(61168, 5598, 16, 'RxNorm'),
(61169, 5599, 16, 'Database RxNorm'),
(61170, 5600, 16, 'S'),
(61171, 5601, 16, 'S.S.'),
(61172, 5602, 16, 'S3:'),
(61173, 5603, 16, 'S4:'),
(61174, 5604, 16, 'SA * * Untuk membaca lisensi silahkan baca docs/license.txt atau kunjungi http://www.gnu.org/copyleft/gpl.html * * * / //============ ================================================== =========== / / '),
(61175, 5605, 16, 'Penjualan'),
(61176, 5606, 16, 'Penjualan'),
(61177, 5607, 16, 'Penjualan Item'),
(61178, 5608, 16, 'Penjualan Laporan Produk'),
(61179, 5609, 16, 'Air Liur'),
(61180, 5610, 16, 'Hari yang Sama'),
(61181, 5611, 16, 'Samoa'),
(61182, 5612, 16, 'Contoh'),
(61183, 5613, 16, 'Jenis Sanksi'),
(61184, 5617, 16, 'Sabtu'),
(61185, 5618, 16, 'Sabtu & Minggu'),
(61186, 5619, 16, 'Sabtu'),
(61187, 5620, 16, 'Simpan'),
(61188, 5621, 16, 'SIMPAN'),
(61189, 5622, 16, 'Simpan dan Tutup'),
(61190, 5624, 16, 'Simpan dan Keluarkan'),
(61191, 5626, 16, 'Simpan sebagai Baru'),
(61192, 5627, 16, 'Simpan sebagai catatan baru'),
(61193, 5628, 16, 'Simpan Pengaturan Sertifikat'),
(61194, 5629, 16, 'Simpan Perubahan'),
(61195, 5630, 16, 'Simpan Formulir'),
(61196, 5631, 16, 'Simpan Imunisasi'),
(61197, 5632, 16, 'Simpan Field(Bagian) baru'),
(61198, 5633, 16, 'Simpan Grup Baru'),
(61199, 5634, 16, 'Simpan Daftar Baru'),
(61200, 5635, 16, 'Simpan template baru'),
(61201, 5637, 16, 'Simpan Demografi Pasien'),
(61202, 5638, 16, 'Penyimpanan Berhasil untuk ID Bagan/Grafik'),
(61203, 5639, 16, 'Simpan Transaksi'),
(61204, 5641, 16, 'Discan'),
(61205, 5642, 16, 'Discan Catatan Encounter (Pertemuan)'),
(61206, 5643, 16, 'Direktori Scanner'),
(61207, 5644, 16, 'Scanner Didalam'),
(61208, 5645, 16, 'Jadwal'),
(61209, 5646, 16, 'Fasilitas Jadwal:'),
(61210, 5647, 16, 'CATATAN SEKOLAH'),
(61211, 5648, 16, 'Scoliosis'),
(61212, 5651, 16, 'SE'),
(61213, 5652, 16, 'SE Alamat'),
(61214, 5653, 16, 'SE Kota'),
(61215, 5654, 16, 'SE Negara'),
(61216, 5655, 16, 'SE Lokalitas'),
(61217, 5656, 16, 'SE Kode Pos'),
(61218, 5657, 16, 'SE Negara'),
(61219, 5658, 16, 'SE Kode Zip'),
(61220, 5659, 16, 'Cari'),
(61221, 5661, 16, 'cari'),
(61222, 5662, 16, 'cari lagi'),
(61223, 5664, 16, 'Cari dengan:'),
(61224, 5665, 16, 'Cari untuk'),
(61225, 5666, 16, 'Cari untuk:'),
(61226, 5668, 16, 'Cari di'),
(61227, 5669, 16, 'Cari atau Tambah Pasien'),
(61228, 5670, 16, 'Cari Pembayaran'),
(61229, 5672, 16, 'Hasil Pencarian:'),
(61230, 5673, 16, 'Cari yang Dipilih'),
(61231, 5674, 16, 'Pencarian string tidak cocok dengan daftar yang ada dalam database'),
(61232, 5675, 16, 'Pencarian string harus setidaknya memiliknya tiga karakter'),
(61233, 5676, 16, 'Cari Teks'),
(61234, 5677, 16, 'Cari Event'),
(61235, 5678, 16, 'Cari/Tambah'),
(61236, 5679, 16, 'Cari/Tambah Penanggung'),
(61237, 5680, 16, 'Mencari janji temu'),
(61238, 5681, 16, 'Mencari...'),
(61239, 5682, 16, 'Pengunaan Sabuk Pengaman'),
(61240, 5683, 16, 'Penggunaan sabuk pengaman'),
(61241, 5684, 16, 'Kedua'),
(61242, 5687, 16, 'Sekunder'),
(61243, 5688, 16, 'Asuransi Sekunder'),
(61244, 5689, 16, 'Data Asuransi Sekunder'),
(61245, 5690, 16, 'Provider Asuransi Sekunder'),
(61246, 5691, 16, 'Jenis Medicare Sekunder'),
(61247, 5698, 16, 'Keamanan'),
(61248, 5699, 16, 'Lihat Semua'),
(61249, 5700, 16, 'Lihat Kewenangan/Otorisasi'),
(61250, 5701, 16, 'Lihat Grafik-Pertumbuhan'),
(61251, 5702, 16, 'Lihat pesan dari set terakhir dari klaim yang dihasilkan'),
(61252, 5704, 16, 'Terlihat sejak'),
(61253, 5707, 16, 'Kejang'),
(61254, 5708, 16, 'Sel'),
(61255, 5709, 16, 'Pilih'),
(61256, 5710, 16, 'pilih'),
(61257, 5712, 16, 'Pilih Konteks'),
(61258, 5714, 16, 'Pilih Jangka Waktu'),
(61259, 5715, 16, 'Pilih Pengguna'),
(61260, 5716, 16, 'Pilih Semua'),
(61262, 5720, 16, 'Pilih kategori'),
(61263, 5722, 16, 'Pilih kotak centang yang sesuai untuk menghapus'),
(61264, 5723, 16, 'Pilih Kriteria untuk'),
(61265, 5725, 16, 'Pilih Data yang Dibutuhkan untuk De Identifikasi'),
(61266, 5726, 16, 'Pilih data yang akan dimasukkan kedalam De Identifikasi data'),
(61267, 5727, 16, 'Pilih tanggal'),
(61268, 5728, 16, 'Pilih regu yang diinginkan'),
(61269, 5729, 16, 'Pilih Diagnosa'),
(61270, 5730, 16, 'Pilih Diagnosa untuk permintaan De Identifikasi'),
(61271, 5731, 16, 'Pilih Obat'),
(61272, 5732, 16, 'Pilih Obat'),
(61273, 5733, 16, 'Pilih Obat untuk permintaan De Identifikasi'),
(61274, 5734, 16, 'Pilih file EDI-271'),
(61275, 5736, 16, 'Pilih field(bagian)'),
(61276, 5737, 16, 'Pilih Field(Bagian)'),
(61277, 5738, 16, 'Pilih untuk pencetakan'),
(61278, 5739, 16, 'Pilih Imunisasi'),
(61279, 5740, 16, 'Pilih Imunisasi untuk permintaan De Identifikasi'),
(61280, 5741, 16, 'Pilih Asuransi, dengan mengetik'),
(61281, 5742, 16, 'Pilih Isu(Masalah)'),
(61282, 5744, 16, 'Pilih Bahasa'),
(61283, 5746, 16, 'Pilih satu atau lebih kode diagnosa untuk membenarkan layanan'),
(61284, 5754, 16, 'Pilih item konfigurasi untuk ekspor'),
(61285, 5755, 16, 'Pilih isu(masalah) terutama yang bertanggung jawab atas event yang terlewat hari ini'),
(61286, 5759, 16, 'Pilih Pengguna'),
(61287, 5760, 16, 'Pilih Pengguna Dari Daftar Dropdown'),
(61288, 5761, 16, 'Pilih bahasa, jika ada, dapat dipilih saat login. (hanya relevan jika Semua Bahasa yang Diizinkan diatas dimatikan)'),
(61289, 5762, 16, 'Pilih Ya untuk mengkonfirmasi penghapusan grup'),
(61290, 5765, 16, 'Dipilih'),
(61291, 5766, 16, 'Encounter(Pertemuan) yang Dipilih'),
(61292, 5767, 16, 'Memilih ini akan membuat pesan yang perlu diproses oleh setiap penerima secara individu (ini bukan tugas kelompok)'),
(61293, 5768, 16, 'Diri(Sendiri)'),
(61294, 5769, 16, 'Cukup Bayar/Bayar Sendiri'),
(61295, 5771, 16, 'Kirim'),
(61296, 5772, 16, 'Kirim Pengingat Bertanggal'),
(61297, 5773, 16, 'Kirim Pengingat'),
(61298, 5774, 16, 'Kirim dalam proses'),
(61299, 5775, 16, 'Kirim pesan'),
(61300, 5776, 16, 'Kirim Batch Pengingat'),
(61301, 5777, 16, 'Kirim pengingat kepada pasien tiap keinginan pasien untuk perawatan tindak lanjut/pencegahan'),
(61302, 5778, 16, 'Kirim Rangkuman dengan Rujukan'),
(61303, 5779, 16, 'Kirim file ini'),
(61304, 5780, 16, 'Kirim Pesan Ini'),
(61305, 5781, 16, 'Kirim ke'),
(61306, 5784, 16, 'Kirim ke semua'),
(61307, 5788, 16, 'Pengirim'),
(61308, 5789, 16, 'ID Pengirim'),
(61309, 5790, 16, 'ID Pengirim (ISA06)'),
(61310, 5791, 16, 'Kualifikasi ID Pengirim (ISA05)'),
(61311, 5794, 16, 'Sensitivitas'),
(61312, 5795, 16, 'Sensitivitas:'),
(61313, 5796, 16, 'Pemeriksaan sensorik normal'),
(61314, 5799, 16, 'Dikirim Oleh, Biarkan Kosong Untuk Semua'),
(61315, 5801, 16, 'Tanggal Dikirim'),
(61316, 5802, 16, 'Item Terkirim'),
(61317, 5803, 16, 'Record(Catatan) Medis Terkirim?'),
(61318, 5804, 16, 'Berhasil dikirim'),
(61319, 5807, 16, 'dikirim ke printer.'),
(61320, 5808, 16, 'Dikirim Ke, Biarkan Kosong Untuk Semua'),
(61321, 5812, 16, 'September'),
(61322, 5813, 16, 'Dipisahkan'),
(61323, 5814, 16, 'September'),
(61324, 5815, 16, 'Rangkaian/Urutan'),
(61325, 5816, 16, 'Rangkaian/Urutan'),
(61326, 5821, 16, 'Layanan'),
(61327, 5822, 16, 'Kategori Layanan'),
(61328, 5823, 16, 'Kode Layanan'),
(61329, 5825, 16, 'Kode Layanan'),
(61330, 5826, 16, 'Tanggal Layanan'),
(61331, 5827, 16, 'Tanggal Layanan:'),
(61332, 5829, 16, 'Lokasi Layanan'),
(61333, 5831, 16, 'Layanan disediakan oleh pakar/ahli'),
(61334, 5834, 16, 'Layanan'),
(61335, 5835, 16, 'Layanan dengan Kategori'),
(61336, 5836, 16, 'Layanan disediakan'),
(61337, 5837, 16, 'Layanan Disediakan'),
(61338, 5838, 16, 'Layanan/Produk'),
(61339, 5839, 16, 'Jenis/Tipe Sesi'),
(61340, 5840, 16, 'Set'),
(61341, 5841, 16, 'Set cookie fasilitas untuk mengingat fasilitas yang dipilih antara login.'),
(61342, 5842, 16, 'Set Sebagai Selesai'),
(61343, 5845, 16, 'Set ini ke path absolut penuh. Untuk membuat sertifikat klien SSL untuk HTTPS.'),
(61344, 5846, 16, 'Set Ke/Mulai'),
(61345, 5847, 16, 'Set Default/Standar'),
(61346, 5848, 16, 'Mengatur nomor versi dalam database...'),
(61347, 5849, 16, 'Pengaturan'),
(61348, 5851, 16, 'Migrain Parah'),
(61349, 5853, 16, 'Sakit Parah'),
(61350, 5854, 16, 'Sakit Parah:'),
(61351, 5855, 16, 'Seks(Jenis Kelamin)'),
(61352, 5856, 16, 'Penyakit Seksual Menular'),
(61353, 5858, 16, 'Sha-1 Hash'),
(61354, 5859, 16, 'Berbagi'),
(61355, 5860, 16, 'Perintah Shell untuk mencetak dari server.'),
(61356, 5864, 16, 'Sesak Napas'),
(61357, 5865, 16, 'Sesak Napas'),
(61358, 5866, 16, 'Sesak Napas 2'),
(61359, 5867, 16, 'Rekam Foto'),
(61360, 5868, 16, 'Rekam Foto sebagai:'),
(61361, 5870, 16, 'harus seperti nnnnn-nnnn-nn'),
(61362, 5871, 16, 'Harus dua huruf'),
(61363, 5872, 16, 'harus berisi 10 digit'),
(61364, 5873, 16, 'harus berisi hanya 10 digit'),
(61365, 5874, 16, 'Bahu'),
(61366, 5875, 16, 'Bahu + tulang selangka'),
(61367, 5876, 16, 'Masalah Bahu'),
(61368, 5877, 16, 'Tampilkan'),
(61369, 5880, 16, 'Tampilkan Semua'),
(61370, 5883, 16, 'Tampilkan Semua Transaksi'),
(61371, 5884, 16, 'Tampilkan sebagai Sibuk'),
(61372, 5885, 16, 'Tampilkan Hanya yang Diizinkan'),
(61373, 5886, 16, 'Tampilkan Waktu yang Tersedia'),
(61374, 5887, 16, 'Tampilkan US dan metrik (unit utama adalah metrik)'),
(61375, 5888, 16, 'Tampilkan US dan metrik (unit utama adalah US)'),
(61376, 5889, 16, 'Tampilkan Rincian'),
(61377, 5891, 16, 'Tampilkan Grafik'),
(61378, 5892, 16, 'Tampilkan teks event melayang pada mouse?'),
(61379, 5893, 16, 'Tampilkan berapa banyak event pada halaman admin?'),
(61380, 5896, 16, 'Tampilkan Menu'),
(61381, 5897, 16, 'Tampilkan metrik saja'),
(61382, 5898, 16, 'Tampilkan Catatan'),
(61383, 5901, 16, 'Tampilkan Catatan Pasien'),
(61384, 5904, 16, 'Tampilkan Primer Lengkap'),
(61385, 5905, 16, 'Tampilkan Pengingat'),
(61386, 5906, 16, 'Tampilkan Laporan'),
(61387, 5907, 16, 'Tampilkan link pencarian/penyeraham pad blok?'),
(61388, 5910, 16, 'Tampilkan formulir negara custom untuk menambah daftar widget (akan meminta untuk judul dan singkatan).'),
(61389, 5913, 16, 'Tampilkan Hanya yang Belum Ditagih'),
(61390, 5914, 16, 'Tampilkan US saja'),
(61391, 5920, 16, 'Saudara Kandung'),
(61392, 5921, 16, 'Sel Sabit/Arit'),
(61393, 5922, 16, 'Sig'),
(61394, 5923, 16, 'Sigmoid/Colonoscopy'),
(61395, 5925, 16, 'Tanda Tangan Hasil Lab (tulis, hanya tambah opsional)'),
(61396, 5926, 16, 'Tanda Tangan Hasil'),
(61397, 5927, 16, 'Tanda Tangan'),
(61398, 5929, 16, 'Tanda Tangan:'),
(61399, 5930, 16, 'Rx yang Ditandatangani'),
(61400, 5932, 16, 'Pembengkakan yang Signifikan:'),
(61401, 5934, 16, 'Co-Pay Sederhana'),
(61402, 5935, 16, 'Demografis Sederhana'),
(61403, 5936, 16, 'Resep Sederhana'),
(61404, 5937, 16, 'Sejak'),
(61405, 5938, 16, 'Sungguh-sungguh,'),
(61406, 5940, 16, 'Tunggal'),
(61407, 5941, 16, 'Daftar pemilihan-tunggal'),
(61408, 5942, 16, 'Daftar pemilihan-tunggal dengan kemampuan untuk menambah ke daftar'),
(61409, 5946, 16, 'Masalah Sinus'),
(61410, 5947, 16, 'Bedah Sinus'),
(61411, 5948, 16, 'KELEMBUTAN SINUS'),
(61412, 5949, 16, 'Sinusitis'),
(61413, 5951, 16, 'ID Situs'),
(61414, 5953, 16, 'ID Situs untuk Dukungan LibreEHR Lab Exchange Service (Layanan Pertukaran Lab).'),
(61415, 5956, 16, 'Ukuran'),
(61416, 5957, 16, 'Ukuran harus berupa angka antara 1 dan 999'),
(61417, 5958, 16, 'Ukuran/Daftar'),
(61418, 5959, 16, 'Kulit'),
(61419, 5960, 16, 'Kanker Kulit'),
(61420, 5961, 16, 'Penyakit Kulit'),
(61421, 5962, 16, 'Kulit Lainnya'),
(61422, 5963, 16, 'Lewat Otorisasi Catatan Pasien'),
(61423, 5964, 16, 'Melewatkan bagian'),
(61424, 5965, 16, 'Melewatkan SQL-Ledger dump - tidak diimplementasikan untuk Windows server'),
(61425, 5967, 16, 'Pola Tidur'),
(61426, 5968, 16, 'Pola tidur'),
(61427, 5969, 16, 'Tidur'),
(61428, 5970, 16, 'Slovakia'),
(61429, 5972, 16, 'Sm hutang w/o'),
(61430, 5973, 16, 'Smarty Cache telah dikosongkan'),
(61431, 5974, 16, 'Perokok, status sekarang tidak diketahui'),
(61432, 5976, 16, 'Status Merokok'),
(61433, 5977, 16, 'SMS Otentikasi'),
(61434, 5978, 16, 'SMS Gateway'),
(61435, 5979, 16, 'Kunci API SMS Gateway'),
(61436, 5980, 16, 'Kunci API SMS Gateway'),
(61437, 5981, 16, 'Pasword SMS Gateway'),
(61438, 5982, 16, 'Nama Pengguna SMS Gateway'),
(61439, 5983, 16, 'SMS Notifikasi/Pemberitahuan'),
(61440, 5984, 16, 'Waktu Notifikasi/Pemberitahuan SMS'),
(61441, 5985, 16, 'Mengirim SMS sebelum'),
(61442, 5986, 16, 'SMS dikirim'),
(61443, 5987, 16, 'Teks SMS, Tag yang Dapat Digunakan: ***NAMA***, ***PROVIDER***, ***TANGGAL***, ***WAKTUMULAI***, ***WAKTUAKHIR***<br> yakni Yang terhormat ***NAMA***'),
(61444, 5988, 16, 'Pengaturan Tanda/Sinyal SMS/Email'),
(61445, 5989, 16, 'Pasword SMTP untuk Otentikasi'),
(61446, 5992, 16, 'Nama Host Server SMTP'),
(61447, 5993, 16, 'Nomor Port Server SMTP'),
(61448, 5994, 16, 'Pengguna SMTP untuk Otentikasi'),
(61449, 5995, 16, 'SNOMED'),
(61450, 6001, 16, 'Database SNOMED'),
(61451, 6004, 16, 'Dengkur'),
(61452, 6005, 16, 'SOAP'),
(61453, 6006, 16, 'Kesulitan Sosial'),
(61454, 6009, 16, 'Riwayat Sosial:'),
(61455, 6010, 16, 'Nomor Keamanan Sosial'),
(61456, 6011, 16, 'solusi'),
(61457, 6013, 16, 'Konteks Somatic'),
(61458, 6014, 16, 'Beberapa otorisasi tidak ditampilkan. Klik disini untuk melihat semua'),
(61459, 6015, 16, 'Beberapa kode tidak ditampilkan.'),
(61460, 6016, 16, 'Beberapa encounter(pertemuan) tidak ditampilkan. Klik di sini untuk melihat semua.'),
(61461, 6017, 16, 'Beberapa kesalahan telah terjadi selama Proses De Identifikasi'),
(61462, 6018, 16, 'Beberapa catatan tidak ditampilkan.'),
(61463, 6020, 16, 'beberapa kata'),
(61464, 6023, 16, 'Sesuatu yang salah terjadi. Silahkan coba lagi.'),
(61465, 6024, 16, 'Interval Batas Segera (Pengingat Klinis)'),
(61466, 6025, 16, 'Interval Batas Segera (Pengingat Pasien)'),
(61467, 6026, 16, 'Sakit Tenggorokan'),
(61468, 6028, 16, 'Maaf, ada masalah mengupload file anda'),
(61469, 6029, 16, 'Urut berdasarkan'),
(61470, 6030, 16, 'Urut Berdasarkan'),
(61471, 6031, 16, 'Urut berdasarkan Checksum'),
(61472, 6032, 16, 'Urut berdasarkan Komentar'),
(61473, 6033, 16, 'Urut berdasarkan Pengguna Crt'),
(61474, 6034, 16, 'Urut berdasarkan tanggal'),
(61475, 6035, 16, 'Urut berdasarkan tanggal/waktu'),
(61476, 6036, 16, 'Urut berdasarkan Event'),
(61477, 6037, 16, 'Urut berdasarkan Grup'),
(61478, 6040, 16, 'Urut berdasarkan ID Pasien'),
(61479, 6041, 16, 'Urut berdasarkan Sukses'),
(61480, 6043, 16, 'Urut berdasarkan Pengguna'),
(61481, 6044, 16, 'Urut berdasarkan vaksin'),
(61482, 6045, 16, 'Urut Kebawah'),
(61483, 6046, 16, 'Urut Hasil berdasarkan'),
(61484, 6047, 16, 'Urut Keatas'),
(61485, 6048, 16, 'Sumber'),
(61486, 6049, 16, 'Fiel Sumber'),
(61487, 6050, 16, 'Path File Sumber'),
(61488, 6051, 16, 'Sumber tersebut tidak ada untuk kode '),
(61489, 6052, 16, 'Sumber Lot'),
(61490, 6057, 16, 'Sumber:'),
(61491, 6060, 16, 'Spasi'),
(61492, 6061, 16, 'SPASI'),
(61493, 6062, 16, 'Spanyol'),
(61494, 6063, 16, 'Sapnyol (Amerika Latin)'),
(61495, 6064, 16, 'Spanyol (Spanyol)'),
(61496, 6068, 16, 'Spesialis'),
(61497, 6069, 16, 'Nama dan tanda tangan spesialis'),
(61498, 6071, 16, 'Khusus'),
(61499, 6072, 16, 'Sistem Khusus'),
(61500, 6073, 16, 'Khusus(Keahlian/Bidang):'),
(61501, 6074, 16, 'Spesifik'),
(61502, 6075, 16, 'Aplikasi Spesifik'),
(61503, 6076, 16, 'Layanan Kontrasepsi Spesifik'),
(61504, 6077, 16, 'Hasil Spesifik'),
(61505, 6078, 16, 'Layanan Spesifik'),
(61506, 6079, 16, 'Ditentukan'),
(61507, 6080, 16, 'Tentukan pengaturan untuk kode. # = digit, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61508, 6081, 16, 'Tentukan pengaturan untuk kode. # = digit, @ = alfa, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61509, 6082, 16, 'Tentukan pengaturan untuk nomor referensi faktur/tagihan. # = digit, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61510, 6083, 16, 'Tentukan pengaturan untuk nomor referensi faktur/tagihan. # = digit, @ = alfa, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61511, 6084, 16, 'Tentukan pengaturan untuk field(bagian) produk NDC. # = digit, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61512, 6085, 16, 'Tentukan pengaturan untuk field(bagian) produk NDC. # = digit, @ = alfa, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61513, 6086, 16, 'Tentukan pengaturan untuk ID pasien eksternal. # = digit, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61514, 6087, 16, 'Tentukan pengaturan untuk ID pasien eksternal. # = digit, @ = alfa, * = karakter apapun. Kosongkan jika tidak digunakan.'),
(61515, 6088, 16, 'Contoh/Sampel'),
(61516, 6089, 16, 'Nomor/Identifier Contoh'),
(61517, 6090, 16, 'Jenis Contoh'),
(61518, 6092, 16, 'Ucapan/Bahasa Dikte'),
(61519, 6093, 16, 'Spermisida'),
(61520, 6094, 16, 'Splenektomi'),
(61521, 6095, 16, 'Pasangan'),
(61522, 6097, 16, 'Dahak'),
(61523, 6098, 16, 'Dahak:'),
(61524, 6099, 16, 'SQ'),
(61525, 6102, 16, 'Regu'),
(61526, 6103, 16, 'Keanggotaan Regu'),
(61527, 6104, 16, 'Regu'),
(61528, 6105, 16, 'SRH'),
(61529, 6106, 16, 'SRH - Keluarga Berencana'),
(61530, 6107, 16, 'SRH Non Keluarga Berencana'),
(61531, 6108, 16, 'SRH Rujukan'),
(61532, 6109, 16, 'SRH Formulir Kunjungan'),
(61533, 6110, 16, 'Tanggal Srv'),
(61534, 6111, 16, 'SS'),
(61535, 6112, 16, 'Administrasi Sertifikat SSL'),
(61536, 6113, 16, 'SSN'),
(61537, 6114, 16, 'Stabilitas'),
(61538, 6116, 16, 'Standar'),
(61539, 6117, 16, 'Kode Standar'),
(61540, 6118, 16, 'Ukuran Standar'),
(61541, 6122, 16, 'Nama Standar'),
(61542, 6124, 16, 'Mulai'),
(61543, 6125, 16, 'Mulai (yyyy-mm-dd): '),
(61544, 6128, 16, 'Tanggal Mulai'),
(61545, 6129, 16, 'Tanggal Mulai pada Klinik Ini'),
(61546, 6130, 16, 'Tanggal Mulai tidak boleh lebih besar dari Tanggal Akhir'),
(61547, 6131, 16, 'Tanggal mulai:'),
(61548, 6132, 16, 'Tanggal Mulai:'),
(61549, 6133, 16, 'Waktu Mulai'),
(61550, 6134, 16, 'Tanggal Mulai'),
(61551, 6135, 16, 'status'),
(61552, 6136, 16, 'Negara(Bagian)'),
(61553, 6137, 16, 'Jenis Data Negara'),
(61554, 6138, 16, 'Lisensi Negara #'),
(61555, 6139, 16, 'Nomor Lisensi Negara'),
(61556, 6140, 16, 'Daftar negara'),
(61557, 6141, 16, 'Daftar Negara (tulis, hanya tambah opsional)'),
(61558, 6142, 16, 'Field(Bagian) Custom Widget Daftar Negara'),
(61559, 6143, 16, 'Negara Atau Propinsi'),
(61560, 6144, 16, 'Negara/Daerah'),
(61561, 6145, 16, 'Negara/Paroki'),
(61562, 6146, 16, 'RANGKUMAN PERNYATAAN'),
(61563, 6147, 16, 'pernyataan dan updatean faktur/tagihan.'),
(61564, 6148, 16, 'Pernyataan Dikirim:'),
(61565, 6149, 16, 'pernyataan; faktur/tagihan tidak akan diupdate'),
(61566, 6150, 16, 'Teks Statis'),
(61567, 6151, 16, 'Statistik'),
(61568, 6152, 16, 'Status'),
(61569, 6153, 16, 'Status'),
(61570, 6156, 16, 'Status quo'),
(61571, 6158, 16, 'Konseling STD/AIDS'),
(61572, 6159, 16, 'Stength dan Pengkondisian'),
(61573, 6169, 16, 'Kaku Sendi'),
(61574, 6170, 16, 'Kekakuan'),
(61575, 6171, 16, 'Persediaan Bulanan'),
(61576, 6172, 16, 'Sakit Perut'),
(61577, 6174, 16, 'Hash Tersimpan'),
(61578, 6175, 16, 'Ketegangan otot'),
(61579, 6176, 16, 'Aliran'),
(61580, 6177, 16, 'Jalan'),
(61581, 6178, 16, 'Alaman Jalan'),
(61582, 6179, 16, 'Jalan dan Nomor'),
(61583, 6180, 16, 'Kekuatan'),
(61584, 6182, 16, 'Radang Tenggorokan'),
(61585, 6183, 16, 'Tekanan patah tulang'),
(61586, 6184, 16, 'Pemeriksaan Tekanan'),
(61587, 6185, 16, 'Serangan Otak'),
(61588, 6186, 16, 'Pasword yang kuat berarti minimal 8 karakter, dan setidaknya tiga dari: angka, huruf kecil, huruf besar, karakter khusus.'),
(61589, 6188, 16, 'Gaya formulir yang digunakan untuk menambah pasien baru'),
(61590, 6189, 16, 'Sub-kategori'),
(61591, 6190, 16, 'Sub-Total'),
(61592, 6191, 16, 'Subkategori'),
(61593, 6192, 16, 'subkategori'),
(61594, 6193, 16, 'subkutan'),
(61595, 6194, 16, 'Subyek'),
(61596, 6195, 16, 'Subyektif'),
(61597, 6196, 16, 'Sublingual'),
(61598, 6197, 16, 'sublingual'),
(61599, 6198, 16, 'Menyerahkan'),
(61600, 6199, 16, 'menyerahkan'),
(61601, 6200, 16, 'Serahkan Semua Konten'),
(61602, 6202, 16, 'Serahkan Event'),
(61603, 6203, 16, 'serahkan formulir'),
(61604, 6204, 16, 'Serahkan Konten yang Dipilih'),
(61605, 6205, 16, 'diserahkan'),
(61606, 6206, 16, 'Diserahkan oleh'),
(61607, 6207, 16, 'Nomor Akses EDI Pengirim (PER06)'),
(61608, 6208, 16, 'Pelanggan'),
(61609, 6209, 16, 'Alamat Langganan'),
(61610, 6213, 16, 'Perusahaan/Majikan Pelanggan'),
(61611, 6214, 16, 'Perusahaan/Majikan Pelanggan(SE)'),
(61612, 6215, 16, 'Alamat Perusahaan/Majikan Pelanggan'),
(61613, 6216, 16, 'Kota Pelanggan Perusahaan/Majikan'),
(61614, 6217, 16, 'Negara Pelanggan Perusahaan/Majikan'),
(61615, 6218, 16, 'Negara Pelanggan Perusahaan/Majikan'),
(61616, 6221, 16, 'Kode Pos Pelanggan Perusahaan/Majikan'),
(61617, 6225, 16, 'Telepon Pelanggan'),
(61618, 6226, 16, 'Hubungan Pelanggan'),
(61619, 6227, 16, 'Hubungan pelanggan bukanlah diri tapi namanya sama! Apakah ini benar-benar OK?'),
(61620, 6228, 16, 'Hubungan pelanggan bukanlah diri tapi nomor SS sama! Apakah ini benar-benar OK?'),
(61621, 6229, 16, 'Hubungan pelanggan bukanlah diri tapi namanya berbeda! Apakah ini benar-benar OK?'),
(61622, 6230, 16, 'Hubungan pelanggan bukanlah diri tapi nomor SS berbeda! Apakah ini benar-benar OK?'),
(61623, 6231, 16, 'Seks(Jenis Kelamin) Pelanggan'),
(61624, 6237, 16, 'Penggantian'),
(61625, 6238, 16, 'penggantian diizinkan'),
(61626, 6240, 16, 'Sukses'),
(61627, 6241, 16, 'sukses'),
(61628, 6242, 16, 'Berhasil mengkonfirmasikan penerimaan hasil laboratorium'),
(61629, 6243, 16, 'Berhasil mendapatkan hasil laboratorium'),
(61630, 6244, 16, 'Berhasil mengambil hasil dari Lab Exchange Network'),
(61631, 6246, 16, 'Berhasil ditambahkan kategori'),
(61632, 6247, 16, 'berhasil ditambahkan kategori,'),
(61633, 6248, 16, 'Berhasil Dihapus'),
(61634, 6250, 16, 'Berhasil menginstal database'),
(61635, 6252, 16, 'Berhasil Diubah'),
(61636, 6253, 16, 'Berhasil Disimpan. Apakah anda ingin alokasikan?'),
(61637, 6254, 16, 'Berhasil Disimpan. Apakah anda ingin bagikan?'),
(61638, 6256, 16, 'berhasil disimpan.'),
(61639, 6257, 16, 'Berhasil mengupgrade database.'),
(61640, 6259, 16, 'berhasil.'),
(61641, 6260, 16, 'Bunuh Diri'),
(61642, 6261, 16, 'Rangkuman'),
(61643, 6262, 16, 'Rangkuman dari'),
(61644, 6265, 16, 'Minggu'),
(61645, 6267, 16, 'Minggu'),
(61646, 6268, 16, 'Superbill'),
(61647, 6269, 16, 'Kode Superbill'),
(61648, 6270, 16, 'Administrasi Kode Superbill'),
(61649, 6271, 16, 'Laporan Superbill'),
(61650, 6272, 16, 'Superbill/Lembar Biaya'),
(61651, 6273, 16, 'Superbill'),
(61652, 6274, 16, 'Superbill, kadang-kadang disebut sebagai Encounter Forms atau Routing Slips, adalah bagian penting sebagian besat praktek-praktek medis.'),
(61653, 6275, 16, 'Superuser'),
(61654, 6276, 16, 'Pengawasan'),
(61655, 6278, 16, 'Dokter Pengawasan DEA'),
(61656, 6279, 16, 'Nama awal Dokter Pengawasan'),
(61657, 6280, 16, 'Nama akhir Dokter Pengawasan'),
(61658, 6281, 16, 'Dokter Pengawasan NPI'),
(61659, 6282, 16, 'Dokter Pengawasan UPIN'),
(61660, 6283, 16, 'Nama fasilitas pemasok'),
(61661, 6284, 16, 'Dukungan kalender event yang berlaku untuk beberapa provider'),
(61662, 6285, 16, 'Dukungan ekspor/impor dari konfigurasi data melalui halaman Backup.'),
(61663, 6286, 16, 'Dukungan Multi-Provider Event'),
(61664, 6288, 16, 'Dukungan enkripsi/dekripsi TripleDES saja.'),
(61665, 6289, 16, 'Jenis Permukaan/Latar'),
(61666, 6290, 16, 'Operasi'),
(61667, 6291, 16, 'Operasi'),
(61668, 6293, 16, 'Ditunda'),
(61669, 6294, 16, 'penangguhan'),
(61670, 6295, 16, 'Tanggal Svc'),
(61671, 6296, 16, 'Tanggal Svc:'),
(61672, 6299, 16, 'Berkeringat:'),
(61673, 6300, 16, 'Swedia'),
(61674, 6301, 16, 'Pembengkakan'),
(61675, 6302, 16, 'Pembengkakan Tepat'),
(61676, 6303, 16, 'Pembengkakan Sendi'),
(61677, 6304, 16, 'Pembengkakan Kelenjar Getah Bening'),
(61678, 6305, 16, 'Simbol digunakan sebagai titik desimal untuk mata uang. Tidak digunakan jika Tempat Desimal adalah 0.'),
(61679, 6306, 16, 'Simbol digunakan untuk memisahkan bilangan ribuan untuk mata uang.'),
(61680, 6307, 16, 'Gejala'),
(61681, 6308, 16, 'Sinkronisasi'),
(61682, 6309, 16, 'Sinkronisasi terjemahan dengan tabel bahasa custom.'),
(61683, 6310, 16, 'Sinkronisasi konstan custom baru:'),
(61684, 6311, 16, 'Sinkronisasi bahasa custom baru:'),
(61685, 6312, 16, 'Sinkronisasi definisi baru (Bahasa, Konstan, Definisi):'),
(61686, 6313, 16, 'Sinkop'),
(61687, 6314, 16, 'Pengawasan Sindromik'),
(61688, 6315, 16, 'Pengawasan Sindromik - Non Masalah yang Dilaporkan'),
(61689, 6317, 16, 'Sinovitis, Tubrukan, Radang kandung lendir'),
(61690, 6318, 16, 'Sistem'),
(61691, 6322, 16, 'T'),
(61692, 6323, 16, 't.i.d.'),
(61693, 6324, 16, 'T.V.'),
(61694, 6325, 16, 'Tabel'),
(61695, 6327, 16, 'Pembuatan tabel gagal'),
(61696, 6328, 16, 'Update tabel gagal'),
(61697, 6330, 16, 'tablet'),
(61698, 6332, 16, 'Tagalog'),
(61699, 6335, 16, 'Ambil'),
(61700, 6336, 16, 'Ambil Asuransi, dari Drop Down'),
(61701, 6337, 16, 'Ambil Pembayaran Dari, dari Drop Down'),
(61702, 6338, 16, 'Takeback'),
(61703, 6339, 16, 'Memakan waktu lama'),
(61704, 6340, 16, 'Area Navigasi Tinggi'),
(61705, 6347, 16, 'Tanggal Target'),
(61706, 6351, 16, 'Target/Tindakan Grup'),
(61707, 6354, 16, 'ID Pajak'),
(61708, 6355, 16, 'Persentase Pajak'),
(61709, 6356, 16, 'Pajak'),
(61710, 6357, 16, 'Taksonomi'),
(61711, 6358, 16, 'Td'),
(61712, 6359, 16, 'Tinjauan Cedera Tim'),
(61713, 6360, 16, 'Daftar(Pemain) Tim'),
(61714, 6361, 16, 'Lihat Daftar(Pemain) Tim'),
(61715, 6362, 16, 'Tim/Regu'),
(61716, 6363, 16, 'Telepon'),
(61717, 6364, 16, 'Kode Telepon Negara'),
(61718, 6366, 16, 'Template'),
(61719, 6367, 16, 'Lokasi Template'),
(61720, 6368, 16, 'Metode Template'),
(61721, 6369, 16, 'Temperatur'),
(61722, 6370, 16, 'Template'),
(61723, 6371, 16, 'Nama Template'),
(61724, 6372, 16, 'Nama template tidak bisa dimulai dengan angka.'),
(61725, 6373, 16, 'Template:'),
(61726, 6374, 16, 'Template'),
(61727, 6375, 16, 'Arteri Sementara'),
(61728, 6376, 16, 'Cedera tendon(urat daging)'),
(61729, 6377, 16, 'Tendonitis / osis / radang kandung lendir'),
(61730, 6378, 16, 'Nomor Referensi Faktur Sementara'),
(61731, 6379, 16, 'Tersier'),
(61732, 6380, 16, 'Asuransi Tersier'),
(61733, 6381, 16, 'Data Asuransi Tersier'),
(61734, 6382, 16, 'Provider Asuransi Tersier'),
(61735, 6383, 16, 'Tes Penjadwalan'),
(61736, 6384, 16, 'Tes Sistem'),
(61737, 6385, 16, 'Teks'),
(61738, 6386, 16, 'Teks Diagnosa'),
(61739, 6387, 16, 'Field(Bagian) teks'),
(61740, 6393, 16, 'Tanggal-teks'),
(61741, 6394, 16, 'tanggal-teks'),
(61742, 6395, 16, 'Areateks'),
(61743, 6396, 16, 'areateks'),
(61744, 6397, 16, 'Textbox'),
(61745, 6398, 16, 'textbox'),
(61746, 6399, 16, 'Daftar textbox'),
(61747, 6400, 16, 'textbox daftar'),
(61748, 6401, 16, 'Thai'),
(61749, 6402, 16, 'Terima Kasih'),
(61750, 6403, 16, 'Terima kasih telah memilih'),
(61751, 6404, 16, 'Tombol ''Bersih'' akan menghapus semua pernyataan.'),
(61752, 6405, 16, 'Pernyataan diatas gagal'),
(61753, 6406, 16, 'Sertifikat server SSL Apache dan kunci publik'),
(61754, 6407, 16, 'Sertifikat Otoritas Sertifikat'),
(61755, 6408, 16, 'File klaim: '),
(61756, 6410, 16, 'Kunci privat yang sesuai'),
(61757, 6413, 16, 'Kunci Penolakan adalah'),
(61758, 6414, 16, 'Kunci Grup Penolakan adalah'),
(61759, 6415, 16, 'Tujuan formulir ditutup'),
(61760, 6416, 16, 'Tujuan formulir ditutup, saya tidak bisa bertindak atas pilihan Anda.'),
(61761, 6418, 16, 'EP, rumah sakit yang memenuhi syarat atau CAH yang menerima pasien dari pengaturan lain atau provider perawatan atau percaya encounter(pertemuan) adalah relevan harus melakukan rekonsiliasi pengobatan.'),
(61762, 6421, 16, 'EP, rumah sakit yang memenuhi syarat atau CAH yang mentransisi pasien mereka ke pengaturan lain dari perawatan atau provider perawatan atau merujuk pasien mereka ke provider perawatan lainnya harus menyediakan rangkuman dari record(catatan) perawatan untuk setiap transisi perawatan atau rujukan.'),
(61763, 6422, 16, 'Event telah disetujui.'),
(61764, 6423, 16, 'Event telah tersembunyi.'),
(61765, 6424, 16, 'Data yang diekspor muncul di area teks dibawah ini. Anda dapat salin dan sisipkan ini ke email atau tujuan lain yang diinginkan.'),
(61766, 6426, 16, 'Data yang diekspor muncul di area teks dibawah ini. Anda dapat salin dan sisipkan ini ke email atau tujuan lain yang diinginkan.'),
(61767, 6427, 16, 'Data yang diekspor muncul di area teks dibawah ini. Anda dapat salin dan sisipkan ini ke email atau tujuan lain yang diinginkan.'),
(61768, 6429, 16, 'File tidak berhasil diganti nama, kesalahan ini biasanya berkaitan dengan masalah hak akses pada sistem penyimpanan.'),
(61769, 6434, 16, 'Event kalender berikut telah ditambahkan:'),
(61770, 6435, 16, 'Event kalender berikut telah dimodifikasi:'),
(61771, 6436, 16, 'Kategori-kategori berikut akan dihapus dari daftar Kategori anda'),
(61772, 6437, 16, 'Rilis database berikut saat ini diinstal'),
(61773, 6439, 16, 'File EDI berikut telah diupload'),
(61774, 6440, 16, 'Login Pengguna Berikut telah diaktifkan:'),
(61775, 6441, 16, 'Kesalahan berikut terjadi'),
(61776, 6444, 16, 'Field(Bagian) berikut dibutuhkan'),
(61777, 6446, 16, 'Field-field berikut harus diisi untuk mengirim permintaan.'),
(61778, 6449, 16, 'Nama host dari mesin repositori audit ATNA.'),
(61779, 6450, 16, 'Jendela awal adalah halaman pencarian faktur. Di bagian atas anda dapat memasukkan sumber (misalnya nomor cek), tanggal bayar dan cek jumlah. Alasan untuk sumber dan tanggal bayar adalah agar anda tidak perlu memasukkannya lagi dan lagi untuk setiap klaim. Jumlah yang anda masukkan akan menurun setiap faktur yang merupakan bagian yang diberikan dari pembayaran, dan mudah-mudahan akan berakhir pada nol ketika anda selesai.'),
(61780, 6456, 16, 'Label yang muncul untuk pengguna pada formulir'),
(61781, 6457, 16, 'Panjang tidak boleh melebihi jumlah karakter berikut'),
(61782, 6460, 16, 'Kategori baru akan menjadi sub-kategori dari '),
(61783, 6461, 16, 'Pasword yang baru tidak bisa sama dengan pasword saat ini.'),
(61784, 6462, 16, 'Field pasword yang baru tidak sama.'),
(61785, 6465, 16, 'Halaman akan diarahkan ke Demografi. Anda dapat mengedit field negara dan mengklik ke NewCrop lagi.'),
(61786, 6466, 16, 'Pasword harus minimal 8 karakter, dan harus'),
(61787, 6468, 16, 'Permintaan record(catatan) pasien telah direkam.'),
(61788, 6469, 16, 'Pengingat pasien telah dikirim'),
(61789, 6470, 16, 'Pengingat pasien telah diupdate'),
(61790, 6472, 16, 'Posting pembayaran tidak bisa menuju dibawah tanggal ini. Ini memastikan bahwa setelah mengambil laporan akhir tidak ada lagi yang mempos untuk tanggal sebelumnya.'),
(61791, 6475, 16, 'Informasi yang tersisa di bawah ini hanya berlaku jika anda posting secara manual, atau jika anda melakukan koreksi manual.'),
(61792, 6477, 16, 'Dokumen yang diminta tidak ada pada lokasi yang diharapkan pada filesystem atau tidak ada cukup izin untuk mengaksesnya.'),
(61793, 6480, 16, 'Sumber dan kolom Tanggal disalin dari halaman pertama, jadi secara normal anda tidak akan perlu untuk menyentuh mereka. Anda dapat menempatkan jumlah pembayaran pada kolom Bayar, jumlah penyesuaian pada kolom Penyesuaian, atau keduanya. Anda juga dapat mengklik "W" di sebelah kanan untuk secara otomatis menghitung nilai penyesuaian yang menulis sisa biaya untuk baris item tersebut'),
(61794, 6484, 16, 'Granularity waktu kalender dan interval terkecil dalam menit untuk slot janji temu.'),
(61795, 6485, 16, 'Label yang diterjemahkan yang akan muncul pada form dalam bahasa saat ini'),
(61796, 6486, 16, 'Judul yang diterjemahkan yang akan muncul dalam bahasa saat ini'),
(61797, 6487, 16, 'Terjemahan dari deskripsi dalam bahasa saat ini'),
(61798, 6488, 16, 'Tabel terjemahan disinkronisasi.'),
(61799, 6489, 16, 'Jenis entitas ini'),
(61800, 6490, 16, 'Kode vendor-khusus mengidentifikasi proses atau hasil ini'),
(61801, 6491, 16, 'File X12 serta laporan output yang dihasilkan HTML diarsipkan dalam subdirektori "era" dari direktori instalasi utama LibreEHR. Anda akan ingin melihat arsip ini dari waktu ke waktu. URL tersebut adalah'),
(61802, 6492, 16, 'File zip akan berisi item berikut'),
(61803, 6493, 16, 'Tema');
INSERT INTO `lang_definitions` VALUES
(61804, 6495, 16, 'Terapi Suntikan'),
(61805, 6496, 16, 'Ada'),
(61806, 6497, 16, 'Saat ini tidak ada resep'),
(61807, 6498, 16, 'Ada beberapa kesalahan dengan penyerahan. Hal ini dijelaskan di bawah ini.'),
(61808, 6500, 16, 'Tidak ada grafik diperiksa.'),
(61809, 6501, 16, 'Tidak ada pengungkapan direkam untuk pasien ini.'),
(61810, 6502, 16, 'Tidak ada Kiriman Baru'),
(61811, 6503, 16, 'Tidak ada catatan pada file untuk pasien ini.'),
(61812, 6504, 16, 'Tidak ada transaksi pada file untuk pasien ini.'),
(61813, 6505, 16, 'Telah ada kesalahan mengirim surat ke'),
(61814, 6506, 16, 'Sudah ada kategori bernama'),
(61815, 6507, 16, 'Sudah ada subkategori bernama'),
(61816, 6508, 16, 'Sudah ada item bernama'),
(61817, 6509, 16, 'Sudah ada permintaan record(catatan) pasien terbuka.'),
(61818, 6510, 16, 'Tidak ada entri COA untuk akun AR '),
(61819, 6511, 16, 'Tidak ada entri COA untuk rekening kas '),
(61820, 6512, 16, 'Tidak ada entri COA untuk akun pendapatan '),
(61821, 6513, 16, 'Tidak ada pasien saat ini'),
(61822, 6515, 16, 'Tidak ada kecocokan untuk id faktur'),
(61823, 6516, 16, 'Tidak ada kecocokan untuk id faktur = '),
(61824, 6517, 16, 'Tidak ada entri bagian untuk layanan ID '),
(61825, 6520, 16, 'Ada kesalahan saat memproses permintaan Anda.'),
(61826, 6523, 16, 'Menebal Kanan:'),
(61827, 6524, 16, 'Paha'),
(61828, 6525, 16, 'Paha + hamstring(urat lutut)'),
(61829, 6527, 16, 'Hal-hal yang back office dapat baca dan masuki namun tidak mengubah'),
(61830, 6528, 16, 'Hal-hal yang back office dapat baca dan ubah'),
(61831, 6531, 16, 'Hal-hal yang dokter dapat baca dan masuki namun tidak mengubah'),
(61832, 6532, 16, 'Hal-hal yang dokter dapat baca dan ubah'),
(61833, 6535, 16, 'Hal-hal yang front office dapat baca dan masuki namun tidak mengubah'),
(61834, 6536, 16, 'Hal-hal yang front office dapat baca dan ubah'),
(61835, 6539, 16, 'Hal-hal yang dokter dapat baca dan ubah'),
(61836, 6540, 16, 'Hal-hal yang dokter dapat baca dan masuki namun tidak mengubah'),
(61837, 6542, 16, 'Ketiga'),
(61838, 6544, 16, 'Tindakan ini TIDAK DAPAT dibatalkan.'),
(61839, 6545, 16, 'Tindakan ini tidak dapat dibatalkan.'),
(61840, 6547, 16, 'Tindakan ini akan dicatat,'),
(61841, 6551, 16, 'Kalender Tahun Ini'),
(61842, 6554, 16, 'Klaim ini telah ditolak. Alasan:-'),
(61843, 6555, 16, 'Klaim ini telah diteruskan ke tingkat berikutnya.'),
(61844, 6556, 16, 'Jenis kode ini tidak menerima hubungan.'),
(61845, 6557, 16, 'Konteks ini berisi kategori, yang akan dihapus. Apakah anda masih ingin melanjutkan?'),
(61846, 6558, 16, 'Ini menentukan bagaimana janji temu ditampilkan pada kalender.'),
(61847, 6559, 16, 'Ini menentukan bagaimana skema warna yang digunakan untuk janji temu'),
(61848, 6561, 16, 'Encounter(Pertemuan) Ini'),
(61849, 6565, 16, 'Fitur ini sangat eksperimental dan tidak sepenuhnya diuji. Gunakan dengan resiko anda sendiri!'),
(61850, 6566, 16, 'Nomor faktur ini telah diubah menjadi '),
(61851, 6575, 16, 'Modul ini dalam mode tes. Database tidak akan diubah.'),
(61852, 6576, 16, 'Modul ini mempromosikan entri yang efisien dari data EOB.'),
(61853, 6577, 16, 'Bulan Ini untuk Tanggal'),
(61854, 6581, 16, 'Halaman ini akan menyertakan inline temasuk halaman login, sehingga kita tidak perlu klik login kembali setiap waktu.'),
(61855, 6582, 16, 'Pasien ini tidak memiliki kegiatan.'),
(61856, 6583, 16, 'ID pasien ini sudah digunakan!'),
(61857, 6584, 16, 'Produk ini memungkinkan hanya satu lot per gudang.'),
(61858, 6591, 16, 'Langkah ini akan menghasilkanm file yang anda harus simpan untuk penggunaan masa depan. File ini tidak dapat dihasilkan kembali. Apakah anda ingin meneruskan?'),
(61859, 6592, 16, 'Pengguna ini bukan anggota dari grup manapun'),
(61860, 6595, 16, 'Kunjungan ini memulai menggunakan kontrasepsi baru'),
(61861, 6596, 16, 'Kunjungan ini akan membutuhkan form GCAC, rujukan atau layanan prosedur.'),
(61862, 6597, 16, 'Ini merupakan form Vital hanya-metrik yang lama, sekarang ditinggalkan.'),
(61863, 6598, 16, 'Minggu Ini untuk Tanggal'),
(61864, 6600, 16, 'Ini akan mengaktifkan pelaporan CCR(Continuity of Care Record) dan CCD(Continuity of Care Document).'),
(61865, 6602, 16, 'Ini akan memungkinkan pemilihan debugging bahasa (''dummy'').'),
(61866, 6606, 16, 'Ini akan membuat backup dalam format tar dan kemudian mengirimkannya ke browser web anda sehingga anda dapat menyimpannya'),
(61867, 6607, 16, 'Ini akan menonaktifkan pendokumentasian fitur enkripsi dan dekripsi, dan menyembunyikannya pada UI.'),
(61868, 6613, 16, 'Hal ini akan memaksa Widget Tagihan dalam layar Rangkuman Pasien untuk selalu terbuka.'),
(61869, 6617, 16, 'Ini tidak akan mencegah anda ke situs e-Resep.'),
(61870, 6619, 16, 'Ini akan menggunakan daftar imunisasi custom daripada daftar imunisasi CVX standar.'),
(61871, 6622, 16, 'Dada tulang belakang'),
(61872, 6623, 16, 'Thous/CU.MM'),
(61873, 6625, 16, 'Tenggorokan'),
(61874, 6626, 16, 'Kanker Tenggorokan'),
(61875, 6627, 16, 'Bedah Kanker Tenggorokan'),
(61876, 6628, 16, 'Trombosa/Struk(Serangan Otak)'),
(61877, 6629, 16, 'Kam'),
(61878, 6630, 16, 'Kamis'),
(61879, 6631, 16, 'Kamis'),
(61880, 6632, 16, 'Tiroid norlam'),
(61881, 6633, 16, 'Masalah Tiroid'),
(61882, 6634, 16, 'TIA'),
(61883, 6636, 16, 'TID'),
(61884, 6638, 16, 'Waktu'),
(61885, 6639, 16, 'Format Tampilan Waktu'),
(61886, 6640, 16, 'Selisih Waktu untuk Tambah (menit 1-60)'),
(61887, 6641, 16, 'Pemilihan waktu'),
(61888, 6647, 16, 'Jangka waktu event'),
(61889, 6648, 16, 'Kali array (N/A)'),
(61890, 6649, 16, 'Timestamp dan Teks'),
(61891, 6650, 16, 'TIN'),
(61892, 6651, 16, 'Tinnitus'),
(61893, 6652, 16, 'Judul'),
(61894, 6653, 16, 'Judul V'),
(61895, 6654, 16, 'KolomJudul harus berupa angka antara 1 dan 999'),
(61896, 6655, 16, 'Judul'),
(61897, 6656, 16, 'TM''S:'),
(61898, 6657, 16, 'TMs/EAMs/EE, ext nose'),
(61899, 6658, 16, 'Ke'),
(61900, 6659, 16, 'KE'),
(61901, 6660, 16, 'ke'),
(61902, 6661, 16, 'ke path absolut dari file'),
(61903, 6662, 16, 'Untuk menambah catatan, silahkan klik '),
(61904, 6663, 16, 'Untuk menambah catatan, silahkan klik disini'),
(61905, 6664, 16, 'Untuk Area yang Terkena'),
(61906, 6665, 16, 'untuk area yang terkena'),
(61907, 6666, 16, 'Untuk secara otomatis membuka form tertentu. Beberapa tim olahraga menggunakan football_injury_audit disini.'),
(61908, 6667, 16, 'Ke Tampilan Tagihan'),
(61909, 6668, 16, 'ke kategori'),
(61910, 6669, 16, 'ke Tampilan Klinis'),
(61911, 6670, 16, 'ke copay'),
(61912, 6672, 16, 'Ke ded''ble'),
(61913, 6673, 16, 'Ke Dems'),
(61914, 6674, 16, 'Untuk Nonaktifkan sertifikat SSL sisi klien, komentar diatas baris dalam file konfigurasi Apache dan set'),
(61915, 6675, 16, 'Untuk Nonaktifkan HTTPS, komentar diatas baris dalam file konfigurasi Apache dan restart server Apache.'),
(61916, 6676, 16, 'Untuk mengaktifkan sertifikat ssl sisi Klien'),
(61917, 6677, 16, 'Untuk Aktifkan otentikasi sertifikat SSL sisi Klien, HTTPS harus diaktifkan.'),
(61918, 6678, 16, 'Untuk Aktifkan hanya HTTPS, lakukan perubahan diatas dan restart server Apache. Jika anda ingin mengkonfigurasikan sertifikat sisi klien juga, silahkan konfigurasikan pada bagian berikutnya.'),
(61919, 6679, 16, 'Ke Enctr(Pertemuan)'),
(61920, 6680, 16, 'Untuk menyaring berdasarkan jenis kelamin'),
(61921, 6681, 16, 'Ke Riwayat'),
(61922, 6682, 16, 'Ke Isu(Masalah)'),
(61923, 6683, 16, 'Untuk menghubungkan encounter(pertemuan)/konsultasi ini ke isu(masalah) yang ada, klik '),
(61924, 6684, 16, 'Untuk menghubungkan encounter(pertemuan)/konsultasi ini ke isu(masalah) yang ada, klik isu(masalah) yang diinginkan diatas untuk menyorotnya, lalu klik [Simpan].Tahan tombol [Ctrl] untuk memilih beberapa isu(masalah).'),
(61925, 6685, 16, 'untuk login kembali'),
(61926, 6686, 16, 'Untuk merekam pengungkapan, silahkan klik'),
(61927, 6687, 16, 'untuk menjalankan'),
(61928, 6688, 16, 'Untuk mengatur akses https dengan otentikasi sertifikat klien, lakukan hal berikut'),
(61929, 6689, 16, 'Untuk Kulit'),
(61930, 6690, 16, 'untuk kulit'),
(61931, 6691, 16, 'untuk kunjungan ini?'),
(61932, 6693, 16, 'Kepada:'),
(61933, 6694, 16, 'Kepada: '),
(61934, 6695, 16, 'KE_KOTA'),
(61935, 6696, 16, 'KE_FAKS'),
(61936, 6697, 16, 'KE_NAMAAWL'),
(61937, 6698, 16, 'KE_NAMAAKHR'),
(61938, 6699, 16, 'KE_NAMATGH'),
(61939, 6700, 16, 'KE_ORGANISASI'),
(61940, 6703, 16, 'KE_POS'),
(61941, 6704, 16, 'KE_NEGARA'),
(61942, 6705, 16, 'KE_JALAN'),
(61943, 6706, 16, 'KE_JUDUL'),
(61944, 6707, 16, 'KE_PDTPRPISAHAN'),
(61945, 6708, 16, 'Tembakau'),
(61946, 6709, 16, 'Intervensi Penghentian Tembakau'),
(61947, 6710, 16, 'Intervensi Penghentian Tembakau (CQM)'),
(61948, 6712, 16, 'Penggunaan tembakau'),
(61949, 6713, 16, 'Penilaian Penggunaan Tembakau'),
(61950, 6714, 16, 'Penilaian Penggunaan Tembakau (CQM)'),
(61951, 6715, 16, 'Hari ini'),
(61952, 6716, 16, 'HARI INI'),
(61953, 6717, 16, 'hari ini'),
(61954, 6718, 16, 'Saldo Hari Ini'),
(61955, 6719, 16, 'Biaya Hari Ini'),
(61956, 6720, 16, 'Tanggal Hari Ini'),
(61957, 6721, 16, 'Event Hari Ini'),
(61958, 6724, 16, 'ID Token untuk dukungan LibreEHR LLC Lab Exchange Service'),
(61959, 6726, 16, 'Operasi Amandel'),
(61960, 6728, 16, 'Atas'),
(61961, 6730, 16, 'Topik'),
(61962, 6731, 16, 'Total'),
(61963, 6732, 16, 'total'),
(61964, 6733, 16, 'Jumlah tindakan aktif'),
(61965, 6734, 16, 'Jumlah pengingat aktif setelah update'),
(61966, 6735, 16, 'Jumlah pengingat aktif sebelum update'),
(61967, 6737, 16, 'Total batas jumlah'),
(61968, 6738, 16, 'Total Jumlah Dibayar'),
(61969, 6741, 16, 'Biaya Total'),
(61970, 6742, 16, 'Total Klien'),
(61971, 6743, 16, 'Total Harga'),
(61972, 6744, 16, 'Distribusi Total untuk nomor cek berikut tidak penuh'),
(61973, 6746, 16, 'Jumlah pengingat gagal dikirim melalui email'),
(61974, 6747, 16, 'Jumlah pengingat gagal dikirim melalui telepon'),
(61975, 6748, 16, 'Total untuk'),
(61976, 6749, 16, 'Total untuk '),
(61977, 6750, 16, 'Total untuk kategori'),
(61978, 6751, 16, 'Total pengingat tidak aktif'),
(61979, 6752, 16, 'Total pengingat baru'),
(61980, 6755, 16, 'Angka Total dari Imunisasi'),
(61981, 6756, 16, 'Angka Total dari Isu(Masalah)'),
(61982, 6758, 16, 'Angka Totatl dari Pasien'),
(61983, 6760, 16, 'Jumlah Saldo Pasien'),
(61984, 6761, 16, 'Jumlah Pasien'),
(61985, 6764, 16, 'Jumlah Record(Catatan) Ditemukan'),
(61986, 6765, 16, 'Total SRH & Keluarga Berencana'),
(61987, 6766, 16, 'Jumlah pengingat berhasil dikirim melalui email'),
(61988, 6767, 16, 'Jumlah pengingat berhasil dikirim melalui telepon'),
(61989, 6770, 16, 'Jumlah pengingat belum diubah'),
(61990, 6771, 16, 'Jumlah pengingat tidak terkirim setelah proses pengiriman'),
(61991, 6772, 16, 'Jumlah pengingat tidak terkirim setelah update'),
(61992, 6773, 16, 'Jumlah pengingat tidak terkirim sebelum proses pengiriman'),
(61993, 6774, 16, 'Jumlah pengingat tidak terkirim sebelum update'),
(61994, 6775, 16, 'Jumlah pengingat yang diupdate'),
(61995, 6776, 16, 'Total'),
(61996, 6777, 16, 'Total untuk'),
(61997, 6778, 16, 'Total untuk '),
(61998, 6785, 16, 'Jenis Pelatihan'),
(61999, 6786, 16, 'Transaksi'),
(62000, 6787, 16, 'Transaksi'),
(62001, 6788, 16, 'transaksi'),
(62002, 6789, 16, 'Transaksi gagal, jumlah yang tidak cukup pada lot tujuan'),
(62003, 6790, 16, 'Transaksi gagal, jumlah kurang dari nol'),
(62004, 6791, 16, 'Jenis Transaksi'),
(62005, 6792, 16, 'transaksi'),
(62006, 6793, 16, 'Transaksi'),
(62007, 6794, 16, 'Transaksi (tulis opsional)'),
(62008, 6795, 16, 'Transaksi/Rujukan'),
(62009, 6797, 16, 'Transfer'),
(62010, 6799, 16, 'Transfer gagal, jumlah yang tidak cukup pada lot sumber'),
(62011, 6804, 16, 'Transfer'),
(62012, 6806, 16, 'Transisi/Transfer dari Perawatan?'),
(62013, 6807, 16, 'Terjemahkan Grup Kontrol Akses'),
(62014, 6808, 16, 'Terjemahkan Kategori Janji Temu'),
(62015, 6809, 16, 'Terjemahkan Kategori Dokumen'),
(62016, 6810, 16, 'Terjemahkan Tata Letak'),
(62017, 6811, 16, 'Terjemahkan Daftar'),
(62018, 6812, 16, 'Terjemahkan Judul Catatan Pasien'),
(62019, 6813, 16, 'terjemahkan ini'),
(62020, 6814, 16, 'Terjemahan'),
(62021, 6815, 16, 'Terjemahan'),
(62022, 6819, 16, 'Trauma'),
(62023, 6820, 16, 'Perawatan'),
(62024, 6822, 16, 'Tujuan Perawatan'),
(62025, 6823, 16, 'Rencana Perawatan'),
(62026, 6826, 16, 'Perawatan:'),
(62027, 6827, 16, 'Perawatan: '),
(62028, 6828, 16, 'Trend'),
(62029, 6829, 16, 'trftime ($month_format, mktime (0, 0, 0, $ i, 1, 2000)) ); $month_value'),
(62030, 6830, 16, 'Pemicu titik / sindrom kompartemen / DOMS / kram'),
(62031, 6831, 16, 'Trimalleolar'),
(62032, 6832, 16, 'Batang dan perut'),
(62033, 6837, 16, 'tsp'),
(62034, 6839, 16, 'TTS'),
(62035, 6840, 16, 'Tuberkulosis'),
(62036, 6841, 16, 'Sel'),
(62037, 6842, 16, 'Sel & Kam'),
(62038, 6843, 16, 'Selasa'),
(62039, 6844, 16, 'Tumor'),
(62040, 6845, 16, 'Turki'),
(62041, 6848, 16, 'dua kali sehari'),
(62042, 6850, 16, 'Selaput Membran'),
(62043, 6851, 16, 'Tipe/Jenis'),
(62044, 6852, 16, 'Ketik ID atau Nama. 3 karakter minimal (termasuk spasi).'),
(62045, 6853, 16, 'Jenis kolom yang ditampilkan untuk hasil pencarian pasien'),
(62046, 6854, 16, 'Jenis Pengungkapan'),
(62047, 6855, 16, 'Jenis Event'),
(62048, 6856, 16, 'Jenis tata letak layar'),
(62049, 6857, 16, 'Ketik atau scan identifier pasien disini'),
(62050, 6858, 16, 'Ketik pesan Anda disini'),
(62051, 6859, 16, 'Jenis Order dan Hasil'),
(62052, 6864, 16, 'Kode UCSMC yang diberikan oleh University of Calgary Sports Medicine Centre'),
(62053, 6865, 16, 'Ukraina'),
(62054, 6866, 16, 'Pemborokan'),
(62055, 6867, 16, 'Radang Usus Besar Ulceratif'),
(62056, 6868, 16, 'Ulkus:'),
(62057, 6871, 16, 'Tidak bisa membuat'),
(62058, 6876, 16, 'Tidak diterapkan'),
(62059, 6877, 16, 'Tidak ditugaskan'),
(62060, 6879, 16, 'Akses yang tidak sah ke eResep'),
(62061, 6880, 16, 'Akses yang tidak sah.'),
(62062, 6882, 16, 'Hanya yang Tidak Ditagih'),
(62063, 6884, 16, 'di bawah lidah'),
(62064, 6885, 16, 'Underweight'),
(62065, 6886, 16, 'Tidak Didiagnosa'),
(62066, 6887, 16, 'TIDAK DIBAGIKAN'),
(62067, 6888, 16, 'Tidak Dibagikan'),
(62068, 6889, 16, 'Tidak Dibagikan adalah'),
(62069, 6890, 16, 'Batalkan Checkout'),
(62070, 6892, 16, 'Klien Unik'),
(62071, 6893, 16, 'Identifier manusia-terbaca yang unik untuk jenis ini'),
(62072, 6894, 16, 'Klien Baru unik'),
(62073, 6895, 16, 'Identifier numerik unik untuk jenis ini'),
(62074, 6896, 16, 'Pasien Dilihat Unik'),
(62075, 6897, 16, 'Laporan Pasien Terlihat Unik'),
(62076, 6898, 16, 'SP Unik'),
(62077, 6899, 16, 'Unit'),
(62078, 6900, 16, 'Unit'),
(62079, 6901, 16, 'unit'),
(62080, 6903, 16, 'Unit untuk Form Kunjungan'),
(62081, 6904, 16, 'Unit harus berupa angka'),
(62082, 6905, 16, 'Unit tidak didefinisikan'),
(62083, 6906, 16, 'Unit/L'),
(62084, 6907, 16, 'Tidak diketahui'),
(62085, 6910, 16, 'Tidak diketahui jika pernah merokok'),
(62086, 6911, 16, 'Tidak diketahui atau N/A'),
(62087, 6913, 16, 'unlink pasien'),
(62088, 6914, 16, 'Perusahaan asuransi tanpa nama'),
(62089, 6915, 16, 'Tidak Terdaftar'),
(62090, 6918, 16, 'Batalkan Semua'),
(62091, 6919, 16, 'Tidak Dipilih'),
(62092, 6920, 16, 'Tidak Ditentukan'),
(62093, 6921, 16, 'Tidak Terstruktur'),
(62094, 6924, 16, 'sampai'),
(62095, 6925, 16, 'Pengajuan sebelum waktunya'),
(62096, 6926, 16, 'Tidak Digunakan'),
(62097, 6927, 16, 'UOR'),
(62098, 6928, 16, 'Hingga'),
(62099, 6929, 16, 'Janji Temu Mendatang'),
(62100, 6930, 16, 'Event Mendatang'),
(62101, 6931, 16, 'Update'),
(62102, 6932, 16, 'update'),
(62103, 6933, 16, 'Update aktif'),
(62104, 6934, 16, 'Update file'),
(62105, 6935, 16, 'Update Info'),
(62106, 6936, 16, 'Update Daftar'),
(62107, 6937, 16, 'Update Nomor Provider'),
(62108, 6938, 16, 'Update Item yang Dipilih'),
(62109, 6939, 16, 'Update variabel berikut dalam file'),
(62110, 6940, 16, 'Update Informasi Pengguna'),
(62111, 6942, 16, 'Update demografi tidak diizinkan'),
(62112, 6946, 16, 'Upgrade'),
(62113, 6947, 16, 'Upgrade Database'),
(62114, 6948, 16, 'Upgrade database LibreEHR untuk memasukkan Prosedur, Fungsi, dan tabel yang diperlukan untuk proses De-identifikasi'),
(62115, 6949, 16, 'Pengupgradean akan berlanjut'),
(62116, 6950, 16, 'UPIN'),
(62117, 6951, 16, 'Upload'),
(62118, 6954, 16, 'Upload data konfigurasi'),
(62119, 6955, 16, 'Upload Dokumen'),
(62120, 6956, 16, 'Upload gagal!'),
(62121, 6957, 16, 'Upload Gambar ke'),
(62122, 6958, 16, 'Upload file impor:'),
(62123, 6961, 16, 'Upload Laporan'),
(62124, 6963, 16, 'Upload file ini:'),
(62125, 6964, 16, 'Setelah mengklik nomor faktur "jendela postingan manual" muncul. Di sini Anda dapat mengubah tanggal jatuh tempo dan catatan untuk faktur, pilih pihak untuk siapa yang Anda posting, dan pilih asuransi yang semua pembayaran yang diharapkan telah diterima. Yang paling penting, untuk setiap kode tagihan yang besarnya telah dibebankan, Anda dapat memasukkan informasi pembayaran dan penyesuaian.'),
(62126, 6965, 16, 'Setelah pencarian Anda disajikan dengan daftar faktur/tagihan. Anda bisa mengklik pada salah satu nomor faktur untuk membuka jendela kedua, yang merupakan halaman entri data untuk posting manual. Anda juga dapat mengklik nama pasien jika ingin memasukkan catatan bahwa staf front office akan melihat ketika pasien melakukan check in, dan Anda dapat memilih faktur untuk tampil di laporan pasien dan mencetak laporan itu.'),
(62127, 6966, 16, 'Lengan atas'),
(62128, 6968, 16, 'Urgensi'),
(62129, 6970, 16, 'Air Seni'),
(62130, 6971, 16, 'Menggiring Urin'),
(62131, 6972, 16, 'Frekuensi Urin'),
(62132, 6973, 16, 'Keraguan Urin'),
(62133, 6974, 16, 'Urin Microalbumin'),
(62134, 6975, 16, 'Aliran Urin'),
(62135, 6976, 16, 'Urgensi Urin'),
(62136, 6977, 16, 'URL'),
(62137, 6979, 16, 'URL untuk dukungan LibreEHR'),
(62138, 6981, 16, 'URL untuk Gateway Telepon. Layanan VOIP otomatis disediakan oleh Maviq. Silahkan kunjungi http://signup.maviq.com untuk informasi lebih lanjut.'),
(62139, 6986, 16, 'Indikator Penggunaan (ISA15)'),
(62140, 6987, 16, 'Gunakan % saja pada field untuk hanya mengurutkan pada kolom tersebut'),
(62141, 6988, 16, 'Gunakan format waktu 24 jam?'),
(62142, 6990, 16, 'Gunakan teknologi EHR bersertifikat untuk mengidentifikasikan sumber daya pasien-spesifik dan menyediakan sumber daya tersebut jika sesuai.'),
(62143, 6991, 16, 'Gunakan Panel Biaya'),
(62144, 6992, 16, 'Gunakan CPOE untuk order pengobatan secara langsung dimasukkan oleh setiap profesional kesehatan berlisensi yang bisa memasukkan perintah ke record(catatan) medis per pedoman negara, lokal dan profesional.'),
(62145, 6997, 16, 'Gunakan Daftar Imunisasi Custom'),
(62146, 6999, 16, 'Gunakan Rentang Tanggal'),
(62147, 7000, 16, 'Gunakan Default/Standar'),
(62148, 7001, 16, 'Gunakan Pilihan Hapus untuk Menghapus'),
(62149, 7002, 16, 'Gunakan gaya tanggal internasional?'),
(62150, 7003, 16, 'Gunakan nama file sumber'),
(62151, 7004, 16, 'Gunakan field dibawah ini untuk pembelian atau transfer.'),
(62152, 7005, 16, 'Gunakan fitur ini hanya dengan situs yang baru diinstal, '),
(62153, 7006, 16, 'Gunakan topik?'),
(62154, 7007, 16, 'Pengguna'),
(62155, 7009, 16, 'Pengguna / Grup'),
(62156, 7010, 16, 'Administrasi User'),
(62157, 7011, 16, 'Administrasi Fasilitas dan Pengguna'),
(62158, 7012, 16, 'Administrasi Grup dan Pengguna'),
(62159, 7014, 16, 'Otentikasi Sertifikat Pengguna dinonaktifkan'),
(62160, 7015, 16, 'Pengguna yang Ditetapkan'),
(62161, 7016, 16, 'Area Pengguna yang Ditetapkan 11'),
(62162, 7017, 16, 'Area Pengguna yang Ditetapkan 12'),
(62163, 7018, 16, 'Field Pengguna yang Ditetapkan'),
(62164, 7019, 16, 'Daftar Pengguna yang Ditetapkan 1'),
(62165, 7020, 16, 'Daftar Pengguna yang Ditetapkan 2'),
(62166, 7021, 16, 'Daftar Pengguna yang Ditetapkan 3'),
(62167, 7022, 16, 'Daftar Pengguna yang Ditetapkan 4'),
(62168, 7023, 16, 'Daftar Pengguna yang Ditetapkan 5'),
(62169, 7024, 16, 'Daftar Pengguna yang Ditetapkan 6'),
(62170, 7025, 16, 'Daftar Pengguna yang Ditetapkan 7'),
(62171, 7026, 16, 'Teks Pengguna yang Ditetapkan 1'),
(62172, 7027, 16, 'Teks Pengguna yang Ditetapkan 2'),
(62173, 7028, 16, 'Teks Pengguna yang Ditetapkan 3'),
(62174, 7029, 16, 'Teks Pengguna yang Ditetapkan 4'),
(62175, 7030, 16, 'Teks Pengguna yang Ditetapkan 5'),
(62176, 7031, 16, 'Teks Pengguna yang Ditetapkan 6'),
(62177, 7032, 16, 'Teks Pengguna yang Ditetapkan 7'),
(62178, 7033, 16, 'Teks Pengguna yang Ditetapkan 8'),
(62179, 7034, 16, 'Nama Awal Pengguna'),
(62180, 7039, 16, 'Manual Pengguna'),
(62181, 7040, 16, 'Keanggotaan Pengguna'),
(62182, 7041, 16, 'Nama Pengguna'),
(62183, 7042, 16, 'Nama Pengguna atau nama Host tidak boleh kosong'),
(62184, 7043, 16, 'Nama Host atau Pengguna'),
(62185, 7046, 16, 'Pengaturan Pengguna'),
(62186, 7047, 16, 'Pengaturan Pengguna Spesifik/Khusus'),
(62187, 7049, 16, 'Nama pengguna'),
(62188, 7051, 16, 'Nama pengguna untuk Gateway Telepon. Layanan VOIP otomatis disediakan oleh Maviq. Silahkan kunjungi http://signup.maviq.com untuk informasi lebih lanjut.'),
(62189, 7052, 16, 'Nama pengguna untuk SMS Gateway'),
(62190, 7053, 16, 'Nama pengguna untuk SMS Gateway.'),
(62191, 7055, 16, 'Nama pengguna:'),
(62192, 7056, 16, 'Pengguna'),
(62193, 7057, 16, 'Pengguna/Grup/Log Administrasi'),
(62194, 7058, 16, 'gunakan format php<a href="http://php.net/strftime">strftime</a>'),
(62195, 7059, 16, 'UTI'),
(62196, 7062, 16, 'LIBURAN'),
(62197, 7063, 16, 'Liburan'),
(62198, 7064, 16, 'Vaksin'),
(62199, 7065, 16, 'Cincin Vagina'),
(62200, 7066, 16, 'Pidato Perpisahan'),
(62201, 7067, 16, 'mengesahkan'),
(62202, 7068, 16, 'Nilai'),
(62203, 7069, 16, 'Nilai 1'),
(62204, 7070, 16, 'Nilai 2'),
(62205, 7072, 16, 'Nilai harus berupa angka'),
(62206, 7073, 16, 'Var1'),
(62207, 7074, 16, 'Var2'),
(62208, 7075, 16, 'variabel ke satu untuk menjalankan script upgrade de-identifikasi'),
(62209, 7076, 16, 'Varicella 1'),
(62210, 7077, 16, 'Varicella 2'),
(62211, 7078, 16, 'Pembuluh darah(vena) Varises'),
(62212, 7079, 16, 'Kondisi vaskular'),
(62213, 7080, 16, 'Cedera Vaskular'),
(62214, 7081, 16, 'Bedah Vaskular'),
(62215, 7083, 16, 'Vendor'),
(62216, 7084, 16, 'Versi'),
(62217, 7085, 16, 'Vertigo'),
(62218, 7086, 16, 'Administrasi Veteran'),
(62219, 7087, 16, 'Rencana Administrasi Veteran'),
(62220, 7088, 16, 'VFC'),
(62221, 7089, 16, 'Vietnam'),
(62222, 7090, 16, 'lihat'),
(62223, 7091, 16, 'Lihat'),
(62224, 7092, 16, 'Lihat Alergi'),
(62225, 7097, 16, 'Lihat Komprehensif Pasien Lapor'),
(62226, 7100, 16, 'Lihat dokumen'),
(62227, 7101, 16, 'Lihat encounter(pertemuan)'),
(62228, 7103, 16, 'Lihat event di jendela popup?'),
(62229, 7107, 16, 'Lihat Log'),
(62230, 7108, 16, 'Lihat Halaman 1'),
(62231, 7109, 16, 'Lihat Halaman 2'),
(62232, 7110, 16, 'Lihat Pengingat yang Lalu dan yang Akan Datang'),
(62233, 7111, 16, 'Lihat Pasien'),
(62234, 7116, 16, 'Lihat encounter(pertemuan) terkait'),
(62235, 7121, 16, 'Lihat/Edit Alergi'),
(62236, 7122, 16, 'Lihat/edit isu(masalah)'),
(62237, 7123, 16, 'Lihat/Print'),
(62238, 7124, 16, 'Lihat:'),
(62239, 7125, 16, 'VISA'),
(62240, 7126, 16, 'VISA/MC/AMEX/Dis'),
(62241, 7127, 16, 'Kerusakan mendalam/trauma/operasi'),
(62242, 7133, 16, 'Kategori Kunjungan'),
(62243, 7134, 16, 'Tanggal Kunjungan'),
(62244, 7135, 16, 'Lihat tanggal'),
(62245, 7137, 16, 'Form Kunjungan'),
(62246, 7138, 16, 'Riwayat Kunjungan'),
(62247, 7140, 16, 'Kunjungan'),
(62248, 7141, 16, 'Form Kunjungan'),
(62249, 7142, 16, 'Tanda Vital'),
(62250, 7143, 16, 'Vital'),
(62251, 7144, 16, 'Vital (Metrik)'),
(62252, 7146, 16, 'Suara'),
(62253, 7147, 16, 'Suara Dikirim'),
(62254, 7149, 16, 'Muntah'),
(62255, 7151, 16, 'W'),
(62256, 7152, 16, 'Lingkar Pinggang'),
(62257, 7153, 16, 'Lingkar Pinggang'),
(62258, 7154, 16, 'Menunggu'),
(62259, 7155, 16, 'Masuk'),
(62260, 7157, 16, 'Walt Pennington'),
(62261, 7158, 16, 'Gudang'),
(62262, 7159, 16, 'Gudang maksimum, 0 jika tidak berlaku'),
(62263, 7160, 16, 'Gudang minimum, 0 jika tidak berlaku'),
(62264, 7161, 16, 'Gudang'),
(62265, 7162, 16, 'Hangat'),
(62266, 7163, 16, 'Peringatan'),
(62267, 7164, 16, 'PERINGATAN'),
(62268, 7166, 16, 'Peringatan, Nomor Cek telah ada dalam database'),
(62269, 7168, 16, 'Peringatan: Kunjungan telah dibuat untuk pasien hari ini!'),
(62270, 7170, 16, 'Peringatan: ID Pasien tidak unik!'),
(62271, 7171, 16, 'PERINGATAN: ini akan menimpa informasi konfigurasi dengan data dari file yang diupload!'),
(62272, 7173, 16, 'Peringatan'),
(62273, 7175, 16, 'telah diupload'),
(62274, 7177, 16, 'Kami menghargai pembayaran cepat dari batas saldo'),
(62275, 7178, 16, 'kami telah melihat pasien atas anda untuk evaluasi dan perawatan pada klinik psikiatri rawat jalan kami. Terima kasih atas rujukan ini.'),
(62276, 7179, 16, 'Kelemahan'),
(62277, 7181, 16, 'Pencarian Web'),
(62278, 7182, 16, 'Situs Web'),
(62279, 7183, 16, 'Link Situs Web untuk Portal Pasien Onsite'),
(62280, 7184, 16, 'Rab'),
(62281, 7185, 16, 'Rabu'),
(62282, 7186, 16, 'Minggu'),
(62283, 7187, 16, 'minggu'),
(62284, 7188, 16, 'Tampilan Minggu'),
(62285, 7189, 16, 'Minggu'),
(62286, 7190, 16, 'Eksposur Mingguan'),
(62287, 7192, 16, 'Minggu'),
(62288, 7193, 16, 'Berat'),
(62289, 7194, 16, 'Penilaian Berat dan Konseling untuk Anak dan Remaja'),
(62290, 7195, 16, 'Penilaian Berat dan Konseling untuk Anak dan Remaja (CQM)'),
(62291, 7196, 16, 'Perubahan Berat'),
(62292, 7197, 16, 'Berat Badan'),
(62293, 7198, 16, 'Klinik berat bedan'),
(62294, 7199, 16, 'Selamat Datang'),
(62295, 7202, 16, 'Apa yang akan dihitung?'),
(62296, 7203, 16, 'Desah:'),
(62297, 7204, 16, 'Desah:'),
(62298, 7205, 16, 'Desah:'),
(62299, 7208, 16, 'Dimana mungkin kertas dokumen atau yang discan terkait ditemukan?'),
(62300, 7211, 16, 'Salah urat(kepala)'),
(62301, 7212, 16, 'Putih'),
(62302, 7213, 16, 'Siapa'),
(62303, 7214, 16, 'Siapa yang menjawab?'),
(62304, 7215, 16, 'Janda'),
(62305, 7217, 16, 'Lebar dalam piksel dari bingkai navigasi kiri'),
(62306, 7221, 16, 'Dengan dipilih:'),
(62307, 7222, 16, 'dengan nama lama'),
(62308, 7224, 16, 'Dengan siapa kita dapat meninggalkan pesan?'),
(62309, 7225, 16, 'Dirahasiakan'),
(62310, 7226, 16, 'dalam hitungan jam'),
(62311, 7227, 16, 'dalam hitungan jam:'),
(62312, 7228, 16, 'dalam hitungan menit'),
(62313, 7229, 16, 'dalam beberapa menit:'),
(62314, 7232, 16, 'Tanpa Update'),
(62315, 7233, 16, 'Saksi'),
(62316, 7234, 16, 'mggu'),
(62317, 7235, 16, 'WNL(DBN)'),
(62318, 7237, 16, 'Perempuan'),
(62319, 7238, 16, 'Hanya perempuan'),
(62320, 7240, 16, 'Bekerja'),
(62321, 7241, 16, 'CATATAN KERJA'),
(62322, 7242, 16, 'Telepon Kerja'),
(62323, 7243, 16, 'Nomor Telepon Kerja'),
(62324, 7244, 16, 'Pekerjaan yang berkaitan?'),
(62325, 7245, 16, 'Pekerjaan/ Pendidikan/ Hobi'),
(62326, 7246, 16, 'Catatan Kerja/ Sekolah'),
(62327, 7247, 16, 'hari kerja'),
(62328, 7248, 16, 'Kompensasi Pekerja'),
(62329, 7249, 16, 'Kompensasi Rencana Kesehatan Pekerja'),
(62330, 7250, 16, 'Penerima Berumur Pekerjaan atau Pasangan dengan Kelompok Kerja Rencana Kesehatan'),
(62331, 7252, 16, 'Bertambah Buruk'),
(62332, 7253, 16, 'Apakah anda ingin jumlah saldo berlaku untuk Akun Global?'),
(62333, 7254, 16, 'Apakah Anda Ingin mereka Ditandai sebagai Diselesaikan.'),
(62334, 7255, 16, 'Apakah anda ingin Alokasikan?'),
(62335, 7256, 16, 'Apakah anda ingin Batalkan Distribusi untuk Pasien ini?'),
(62336, 7257, 16, 'Apakah anda ingin Menghapus Distribusi Pembayaran?'),
(62337, 7258, 16, 'Apakah anda ingin Menghapus Pembayaran?'),
(62338, 7259, 16, 'Apakah anda ingin Memodifikasi dan Menyelesaikan Pembayaran?'),
(62339, 7260, 16, 'Apakah anda ingin Memodifikasi Pembayaran?'),
(62340, 7261, 16, 'Apakah anda ingin Memasang dan Menyelesaikan Pembayaran?'),
(62341, 7262, 16, 'Apakah anda ingin Memasang Pembayaran?'),
(62342, 7263, 16, 'Apakah anda ingin menyimpan?'),
(62343, 7264, 16, 'Pergelangan tangan'),
(62344, 7265, 16, 'Pergelangan tangan dan tangan'),
(62345, 7266, 16, 'Masalah Pergelangan Tangan'),
(62346, 7267, 16, 'tulis'),
(62347, 7268, 16, 'mencoret/hapus'),
(62348, 7270, 16, 'tulis'),
(62349, 7271, 16, 'WT'),
(62350, 7273, 16, 'x Dibatalkan'),
(62351, 7274, 16, 'x Dibatalkan'),
(62352, 7275, 16, 'Sinar X'),
(62353, 7276, 16, 'Interpretasi SINAR X:'),
(62354, 7277, 16, 'Interpretasi Sinar X:'),
(62355, 7278, 16, 'Hanya X12: Klaim Penggantian '),
(62356, 7279, 16, 'Mitra X12'),
(62357, 7280, 16, 'Mitra X12'),
(62358, 7284, 16, 'Y'),
(62359, 7285, 16, 'Tahun'),
(62360, 7286, 16, 'tahun'),
(62361, 7287, 16, 'Lihat Tahun'),
(62362, 7288, 16, 'Tahun'),
(62363, 7289, 16, 'Tahun'),
(62364, 7292, 16, 'YA'),
(62365, 7293, 16, 'Ya'),
(62366, 7294, 16, 'ya'),
(62367, 7295, 16, 'YA!'),
(62368, 7296, 16, 'Ya, Hapus dan Log'),
(62369, 7298, 16, 'Ya/Tidak'),
(62370, 7299, 16, 'Ya:'),
(62371, 7300, 16, 'Yiddi'),
(62372, 7303, 16, 'Anda akan secara permanen menggantikan template anda. Anda yakin ingin melanjutkan?'),
(62373, 7304, 16, 'Anda berada pada periode Login Tenggang. Ubah pasword anda sebelum'),
(62374, 7305, 16, 'Anda tidak diperbolehkan untuk menghapus event ini'),
(62375, 7306, 16, 'Anda tidak diperbolehkan untuk mengedit event ini'),
(62376, 7307, 16, 'Anda tidak diizinkan untuk ini.'),
(62377, 7308, 16, 'Anda tidak diizinkan untuk mengakses satuan ini.'),
(62378, 7309, 16, 'Anda tidak diizinkan untuk menambah/edit isu(masalah)'),
(62379, 7310, 16, 'Anda tidak diizinkan untuk menjadwalkan janji-temu.'),
(62380, 7311, 16, 'Anda tidak diizinkan untuk melihat encounter(pertemuan) ini.'),
(62381, 7313, 16, 'Anda tidak dapat mengakses fungsi ini secara langsung.'),
(62382, 7314, 16, 'Anda tidak dapat mengakses halaman ini secara langsung.'),
(62383, 7315, 16, 'Anda tidak dapat menambahkan nilai kosong untuk kategori!'),
(62384, 7316, 16, 'Anda tidak dapat menambahkan nilai kosong untuk subkategori!'),
(62385, 7317, 16, 'Anda tidak dapat menambahkan nilai kosong untuk item!'),
(62386, 7318, 16, 'Anda tidak dapat memasukkan tanggal yang akan datang dengan nilai dari YA.'),
(62387, 7319, 16, 'Anda tidak memilih tindakan.'),
(62388, 7320, 16, 'Anda tidak memiliki akses untuk melihat/mengedit catatan ini'),
(62389, 7321, 16, 'Anda telah mencoba mengubah konten yang terkunci. Singkirkan kunci jika anda ingin melakukan ini. Untuk membuka kunci, hapus baris, ''/*lock::*/'''),
(62390, 7322, 16, 'Anda telah berhasi keluar.'),
(62391, 7323, 16, 'Anda hanya dapat mengupload file .txt'),
(62392, 7325, 16, 'Anda dapat menempatkan teks disini sebagai keluhan standar dalam form Encounter(Pertemuan) Pasien Baru'),
(62393, 7326, 16, 'Anda harus memasukkan kombinasi pasword untuk mengenkripsi dokumen ini'),
(62394, 7329, 16, 'Anda harus terlebih dahulu memilih atau menambahkan pasien.'),
(62395, 7330, 16, 'Anda harus terlebih dahulu memilih atau membuat encounter(pertemuan).'),
(62396, 7331, 16, 'Anda harus memilih kategori kunjungan'),
(62397, 7332, 16, 'Anda harus memilih kategori kunjungan.'),
(62398, 7333, 16, 'Anda harus mengisi beberapa bagian untuk melanjutkan.'),
(62399, 7334, 16, 'Anda harus menjalankan tes ini jika klaim ini muncul untuk menghasilkan dengan sukses tetapi file klaim sebenarnya tidak berisi data atau hanya bagian yang belum selesai dari jumlah data yang seharusnya berisi. Hal ini jelas dengan klaim HCFA karena mereka dapat dibaca manusia, dengan klaim X12 prosesnya lebih sulit untuk menentukan apakah klaim tersebut benar-benar lengkap.'),
(62400, 7335, 16, 'Anda harus memilih setidaknya satu konteks'),
(62401, 7336, 16, 'Anda harus memilih setidaknya satu Provider'),
(62402, 7339, 16, 'Tanggal berakhir tidak valid'),
(62403, 7340, 16, 'Event Anda telah dihapus.'),
(62404, 7341, 16, 'Event Anda telah dimodifikasi.'),
(62405, 7342, 16, 'Event Anda telah dikirimkan.'),
(62406, 7343, 16, 'File anda terlalu besar'),
(62407, 7345, 16, 'Daftar nama anda telah diubah untuk memenuhi persyaratan penamaan.'),
(62408, 7347, 16, 'Nama anda untuk kategori ini, prosedur atau hasil'),
(62409, 7349, 16, 'Pasword Anda Kadaluarsa. Silahkan ubah pasword anda.'),
(62410, 7350, 16, 'Pasword Anda Berakhir pada'),
(62411, 7351, 16, 'Pasword Anda Berakhir hari ini. Silahkan ubah pasword anda.'),
(62412, 7353, 16, 'Konfigurasi PostCalendar anda telah direset untuk menggunakan yang default/standar.'),
(62413, 7354, 16, 'Konfigurasi PostCalendar anda telah diupdate.'),
(62414, 7355, 16, 'Frekuensi pengulangan anda harus berupa angka.'),
(62415, 7356, 16, 'Frekuensi pengulangan anda harus minimal 1.'),
(62416, 7357, 16, 'Tanggal mulai anda lebih besar dari tanggal akhir anda'),
(62417, 7358, 16, 'Tanggal mulai anda tidak valid'),
(62418, 7359, 16, 'Kiriman anda gagal.'),
(62419, 7360, 16, 'yyyy-mm-dd'),
(62420, 7361, 16, 'YYYY-MM-DD'),
(62421, 7362, 16, 'yyyy-mm-dd tanggal yang terkait dengan dokumen ini'),
(62422, 7363, 16, 'yyyy-mm-dd tanggal dihancurkan'),
(62423, 7364, 16, 'yyyy-mm-dd tanggal lahir'),
(62424, 7365, 16, 'yyyy-mm-dd Tanggal Lahir'),
(62425, 7366, 16, 'yyyy-mm-dd berakhirnya tanggal'),
(62426, 7367, 16, 'yyyy-mm-dd Tanggal mulai atau rumah sakit'),
(62427, 7368, 16, 'yyyy-mm-dd tanggal mulai, operasi atau mulai pengobatan'),
(62428, 7369, 16, 'yyyy-mm-dd tanggal pembelian atau transfer'),
(62429, 7370, 16, 'yyyy-mm-dd tanggal pemulihan atau akhir pengobatan'),
(62430, 7371, 16, 'yyyy-mm-dd Tanggal kembali bermain'),
(62431, 7372, 16, 'yyyy-mm-dd Tanggal layanan'),
(62432, 7373, 16, 'yyyy-mm-dd tanggal surat ini'),
(62433, 7374, 16, 'yyyy-mm-dd tanggal untuk memutar kembali'),
(62434, 7375, 16, 'yyyy-mm-dd tanggal dokumen'),
(62435, 7376, 16, 'yyyy-mm-dd tanggal event atau tanggal mulai'),
(62436, 7381, 16, 'yyyy-mm-dd hh:mm:ss'),
(62437, 7383, 16, 'yyyy-mm-dd tanggal terakhir dari event ini'),
(62438, 7387, 16, 'Kosong'),
(62439, 7389, 16, 'Zip'),
(62440, 7390, 16, 'Kode Pos'),
(62441, 7391, 16, 'Zip/Negara:'),
(62442, 7392, 16, 'Zulu'),
(62443, 7393, 16, ' Tapi '),
(62444, 7394, 16, ' tidak dapat diakses.'),
(62445, 7395, 16, 'Apakah Anda benar-benar ingin menghapus'),
(62446, 7396, 16, 'Obat'),
(62447, 7397, 16, 'email tidak terkirim'),
(62448, 7398, 16, 'dari'),
(62449, 7399, 16, 'telah dibuat. '),
(62450, 7400, 16, 'telah dibuka kembali.'),
(62451, 7401, 16, 'Riwayat'),
(62452, 7402, 16, 'bukan angka'),
(62453, 7403, 16, 'siap kembali ditagih.'),
(62454, 7404, 16, 'LLL:'),
(62455, 7405, 16, 'Lot'),
(62456, 7406, 16, 'No. Referensi Asli Kesehatan '),
(62457, 7407, 16, 'min'),
(62458, 7408, 16, 'tidak ditemukan!'),
(62459, 7409, 16, 'Keanehan di banyak browser bisa berarti bahwa output dibawah ini memasuk layar anda dengan tersentak tiba-tiba dan bahwa ada jeda panjang selama beberapa detik dimana ia muncul seolah-olah hal tersebut mungkin mengalami crash(hancur). Hal tersebut tidak terjadi, anda akhirnya akan melihat output yang keluar baris demi baris. Mungkin ada nomor berurutan muncul dibawah, ini adalah untuk menunjukkan bahwa meskipun tidak ada yang lain yang ditampilkan namun ada aktivitas yang terjadi. Angka ini akan diselingi dengan isi dari tagihan dan hal tersebut bersifat normal.'),
(62460, 7410, 16, 'resep telah mencapai batas'),
(62461, 7411, 16, 'sampai'),
(62462, 7412, 16, 'update gagal, bukan di database?'),
(62463, 7413, 16, 'telah ditandai sebagai tagihan saja.'),
(62464, 7414, 16, 'antrian telah berhasil.'),
(62465, 7415, 16, '! Kiri w/o kunjungan'),
(62466, 7416, 16, '" untuk kode'),
(62467, 7417, 16, '" yang DIPERIKSA dalam Pengaturan PostCalendar!'),
(62468, 7418, 16, '# Ins/fin issue'),
(62469, 7419, 16, 'Jumlah tablet:'),
(62470, 7420, 16, '$'),
(62471, 7421, 16, '$ Coding dilakukan'),
(62472, 7422, 16, '$ label (yyyy-mm-dd): '),
(62473, 7423, 16, '%'),
(62474, 7424, 16, '% Dibatalkan <24h'),
(62475, 7425, 16, '% Dibatalkan <24h '),
(62476, 7426, 16, 'harus ada tapi tidak.'),
(62477, 7427, 16, '(% cocok dengan string apapun, _ cocok dengan karakter apapun)'),
(62478, 7428, 16, '([ctrl] + klik untuk memilih beberapa penerima)'),
(62479, 7429, 16, '(Kembali)'),
(62480, 7430, 16, '(Klik untuk mengedit)'),
(62481, 7431, 16, '(Pengiriman email adalah langsung, sedangkan VOIP otomatis dikirim ke penyedia layanan untuk diproses lebih lanjut.)'),
(62482, 7432, 16, '(Lagi)'),
(62483, 7433, 16, '(Pasien Baru)'),
(62484, 7434, 16, '(Catatan dan Kewenangan)'),
(62485, 7435, 16, '(Catatan Pasien)'),
(62486, 7436, 16, '(Pilih salah satu, atau ketik judul anda sendiri)'),
(62487, 7437, 16, '(Shift-)Klik atau tarik untuk mengubah nilai'),
(62488, 7438, 16, '* Pengingat selesai'),
(62489, 7439, 16, '** Harap pindahkan operasi ke Isu(masalah)!'),
(62490, 7440, 16, '*Diperlukan'),
(62491, 7441, 16, '+ Chart diambil'),
(62492, 7442, 16, '- Tidak Ada'),
(62493, 7445, 16, '.'),
(62494, 7446, 16, '0'),
(62495, 7447, 16, '0-10'),
(62496, 7448, 16, '0-24'),
(62497, 7451, 16, '1'),
(62498, 7452, 16, '1 = Amerika Utara. Lihat http://www.wtng.info/ untuk daftar kode dari negara lainnya.'),
(62499, 7453, 16, '1 Hari Dari Sekarang'),
(62500, 7454, 16, '1 Bulan Dari Sekarang'),
(62501, 7455, 16, '1 Minggu Dari Sekarang'),
(62502, 7456, 16, '1 Tahun Dari Sekarang'),
(62503, 7457, 16, '1.Rest 2. Es selama dua hari 3. Kompresi, meninggalkan dressing kecuali di tempat kaki mengembangkan rasa atau warna pucat 4. Meninggikan kaki dan kaki'),
(62504, 7458, 16, '11 - 14'),
(62505, 7459, 16, '12 jam'),
(62506, 7460, 16, '15-19'),
(62507, 7462, 16, '2'),
(62508, 7463, 16, '2 Hari Dari Sekarang'),
(62509, 7464, 16, '2 Bulan Dari Sekarang'),
(62510, 7465, 16, '2 Minggu Dari Sekaran'),
(62511, 7466, 16, '2 Tahun Dari Sekarang'),
(62512, 7468, 16, '20-24'),
(62513, 7477, 16, '2111-13'),
(62514, 7478, 16, '24 jam'),
(62515, 7479, 16, '25+'),
(62516, 7480, 16, '25-29'),
(62517, 7481, 16, '2'),
(62518, 7482, 16, '3 Hari Dari Sekarang'),
(62519, 7483, 16, '3 bulan'),
(62520, 7484, 16, '3 Bulan Dari Sekarang'),
(62521, 7485, 16, '3 kali sehari-hari'),
(62522, 7486, 16, '3 Minggu Dari Sekarang'),
(62523, 7487, 16, '30-34'),
(62524, 7488, 16, '35-39'),
(62525, 7489, 16, '3'),
(62526, 7490, 16, '4 Hari Dari Sekarang'),
(62527, 7491, 16, '4 bulan'),
(62528, 7492, 16, '4 Bulan Dari Sekarang'),
(62529, 7493, 16, '4 kali sehari-hari'),
(62530, 7494, 16, '4 Minggu Dari Sekarang'),
(62531, 7495, 16, '40-44'),
(62532, 7496, 16, '45+'),
(62533, 7497, 16, '465,9, URI'),
(62534, 7498, 16, '466,0, Bronkitis, Akut NOS'),
(62535, 7499, 16, '486,0, Radang Paru-paru, Akut'),
(62536, 7500, 16, '491,21, COPD Exacerbation'),
(62537, 7501, 16, '491,8, Bronkitis, Kronis'),
(62538, 7502, 16, '493,92, Asma, Exac akut.'),
(62539, 7503, 16, '496,0, COPD'),
(62540, 7504, 16, '4'),
(62541, 7505, 16, '5 Hari Dari Sekarang'),
(62542, 7506, 16, '5 Bulan Dari Sekarang'),
(62543, 7507, 16, '5 Minggu Dari Sekarang'),
(62544, 7508, 16, '519,7, Bronchospasm'),
(62545, 7509, 16, '5'),
(62546, 7510, 16, '6 Hari Dari Sekarang'),
(62547, 7511, 16, '6 bulan'),
(62548, 7512, 16, '6 Bulan Dari Sekarang'),
(62549, 7513, 16, '6 Minggu Dari Sekarang'),
(62550, 7514, 16, '6'),
(62551, 7515, 16, '7 Bulan Dari Sekarang'),
(62552, 7516, 16, '8 Bulan Dari Sekarang'),
(62553, 7517, 16, '824,0 patah, di tengah-tengah malleolus, ditutup'),
(62554, 7518, 16, '824,2 patah, rusuk malleolus, ditutup'),
(62555, 7519, 16, '824,6 retak, Trimalleolar, ditutup'),
(62556, 7520, 16, '825,32 patah, dari Navicular (pergelangan kaki)'),
(62557, 7521, 16, '825,35 retak, Berdasarkan dari kelima (5.) Metatarsal'),
(62558, 7522, 16, '845,00 pergelangan kaki keselo NOS'),
(62559, 7523, 16, '845,01 keseleo di tengah-tengah (Delta) Lig.'),
(62560, 7524, 16, '845,02 keseleo, Calcaneal fibular'),
(62561, 7525, 16, '9 Bulan Dari Sekarang'),
(62562, 7526, 16, 'Didirikan 99212 - Tanpa Komplikasi'),
(62563, 7527, 16, 'Didirikan 99213 - Kompleksitas Rendah'),
(62564, 7528, 16, '<Dalam ruang pemeriksaan'),
(62565, 7529, 16, '> Dicentang out'),
(62566, 7531, 16, '? Tidak menunjukkan'),
(62567, 7532, 16, '@ Tiba'),
(62568, 7533, 16, '[Ubah Tampilan]'),
(62569, 7534, 16, '[Tanggal Terakhir Encounter(Pertemuan)]'),
(62570, 7535, 16, '[Hari Sejak Terakhir Encounter(Pertemuan)]'),
(62571, 7536, 16, '[EOB]'),
(62572, 7537, 16, '[Ekspor OFX]'),
(62573, 7538, 16, '[tidak disarankan]'),
(62574, 7539, 16, '[Jumlah Encounters]'),
(62575, 7540, 16, '[Laporan]'),
(62576, 7541, 16, '[Select All]'),
(62577, 7542, 16, '[SQL-Ledger]'),
(62578, 7543, 16, '[Mulai Memproses Batch]'),
(62579, 7544, 16, '[Lihat Log]'),
(62580, 7545, 16, '[Lihat Laporan Tercetak]'),
(62581, 7546, 16, '_PC_DUR_HOURS'),
(62582, 7547, 16, '_PC_DUR_MINUTES'),
(62583, 7548, 16, '_PC_LOCALE'),
(62584, 7549, 16, '~ Tiba terlambat'),
(62585, 1, 17, 'Ένα'),
(62586, 2, 17, 'Αριθ. Επιταγής ή Αιτήματος αποζημίωσης, προς ταυτοποίηση πληρωμής'),
(62587, 3, 17, 'Ένα πιστοποιητικό πελάτη για τον Διαχειριστή'),
(62588, 5, 17, 'Προσετέθη ένα κλινικό έγγραφο.'),
(62589, 7, 17, 'Απαιτείται ένας αντιπρόσωπος'),
(62590, 8, 17, 'Μια επίσκεψη GCAC πρέπει να προστεθεί σε αυτήν την επίσκεψη.'),
(62591, 9, 17, 'Απαιτείται αριθμός παρτίδας'),
(62592, 10, 17, 'Απαιτείται αριθμός παρτίδας!'),
(62593, 11, 17, 'Ένα μικρό γράμμα'),
(62594, 12, 17, 'Ένας αριθμός'),
(62595, 14, 17, 'Υπάρχει ήδη ασθενής με αυτόν τον Κωδικό.'),
(62596, 15, 17, 'Υπάρχει ήδη ασθενής με αυτό το όνομα.'),
(62597, 16, 17, 'Υπάρχει ήδη ασθενής με αυτόν τον ΑΜΚΑ.'),
(62598, 18, 17, 'Ένας θετικός αριθμός θα εμφανίσει πολλά περασμένα ραντεβού σε ένα Widget στην οθόνη με την Πρίληψη Πελάτη.'),
(62599, 19, 17, 'Μπορεί να οριστεί μια πηγή παραπομπής για κάθε επίσκεψη.'),
(62600, 20, 17, 'Απαιτείται ένας σχετικός κωδικός IPPF'),
(62601, 21, 17, 'Ένας ειδικός χαρακτήρας'),
(62602, 22, 17, 'Μία μοναδική τιμή για την αναγνώριση αυτού του πεδίου, μη ορατή στο χρήστη'),
(62603, 24, 17, 'προ φαγητού'),
(62604, 25, 17, 'π.μ.'),
(62605, 26, 17, 'Υδραερικό επίπεδο Δεξιά:'),
(62606, 28, 17, 'Συντόμευση'),
(62607, 29, 17, 'Απόστημα:'),
(62608, 30, 17, 'Κοιλιακό'),
(62609, 31, 17, 'Εις θέση να σηκώσει βάρος για τέσσερα (4) βήματα:'),
(62610, 32, 17, 'Παθολ.'),
(62611, 34, 17, 'Παθολογικό'),
(62612, 35, 17, 'Παθολογική εξέταση αίματος'),
(62613, 36, 17, 'Παθολογική τριχοφυΐα'),
(62614, 37, 17, 'Παθολογική μαστογραφία'),
(62615, 39, 17, 'Άμβλωση'),
(62616, 40, 17, 'Θέματα άμβλωσης'),
(62617, 41, 17, 'Μέθοδος άμβλωσης'),
(62618, 42, 17, 'Κατηγορίες σχετικές με την άμβλωση'),
(62619, 43, 17, 'Αμβλώσεις'),
(62620, 44, 17, 'Σχετικά με το ημερολόγιο'),
(62621, 46, 17, 'Απουσίες ανά διάγνωση'),
(62622, 47, 17, 'Αποδοχή ανάθεσης'),
(62623, 48, 17, 'Αποδοχή πληρωμής για'),
(62624, 49, 17, 'Αποδοχή πληρωμής για '),
(62625, 50, 17, 'Αποδέχεται την ανάθεση'),
(62626, 51, 17, 'Έλεγχος Πρόσβασης'),
(62627, 52, 17, 'Έλεγχος Διαχείρισης δικαιωμάτων πρόσβασης'),
(62628, 54, 17, 'Δεν επιτρέπεται η πρόσβαση'),
(62629, 55, 17, 'Δεν επιτρέπεται η πρόσβαση'),
(62630, 56, 17, 'Πρόσβαση στο Portal Ασθενούς σας'),
(62631, 59, 17, 'Όνομα Λογαριασμού'),
(62632, 62, 17, 'Λογιστικά'),
(62633, 64, 17, 'Άλγη'),
(62634, 65, 17, 'Υπεβλήθη αίτημα επιβεβαίωσης (ISA14)'),
(62635, 66, 17, 'Ευχαριστίες, Αδειοδότηση και Πιστοποίηση'),
(62636, 67, 17, 'Δικαιώμ. Πρόσβ. ACL'),
(62637, 68, 17, 'Διαχείριση ΔΠ ACL'),
(62638, 69, 17, 'Δεν έχετε δικαίωμα να αλλάξετε τα δικαιώματα πρόσβασης ACL'),
(62639, 71, 17, 'Ακμή'),
(62640, 72, 17, 'Ενέργεια'),
(62641, 73, 17, 'Ημερομ. ενεργοποίησης'),
(62642, 74, 17, 'Ενέργεια'),
(62643, 75, 17, 'Ενέργειες'),
(62644, 77, 17, 'Ενεργοποίηση Αναφοράς CCR/CCD'),
(62645, 78, 17, 'Ενεργό'),
(62646, 79, 17, 'Ενεργός Ειδοποίηση'),
(62647, 80, 17, 'Κανόνες ενεργούς ειδοποίησης'),
(62648, 81, 17, 'Ενεργές Ειδοποιήσεις/Υπενθυμίσεις'),
(62649, 82, 17, 'Ενεργός Επίσκεψη'),
(62650, 84, 17, 'Ενεργοί κατάλογοι'),
(62651, 85, 17, 'Ενεργός Ασθενής'),
(62652, 86, 17, 'Ενεργό πλάνο'),
(62653, 87, 17, 'Δραστηριότητα'),
(62654, 88, 17, 'Τύπος δραστηριότητας'),
(62655, 90, 17, 'Οξεία Δηλητηρίαση/Στέρηση'),
(62656, 92, 17, 'Οξύ επί χρονίου'),
(62657, 93, 17, 'προσθήκη'),
(62658, 94, 17, 'Προσθήκη'),
(62659, 95, 17, 'ΠΡΟΣΘΗΚΗ'),
(62660, 96, 17, 'Προσθήκη Εταιρείας'),
(62661, 98, 17, 'Προσθήκη Φαρμακείου'),
(62662, 100, 17, 'προσθήκη συμβάντος για '),
(62663, 101, 17, 'Προσθήκη ως νέα σημείωση'),
(62664, 102, 17, 'Προσθήκη ως Νέο'),
(62665, 104, 17, 'Προσθήκη Κουμπιών'),
(62666, 105, 17, 'Προσθήκη Κουμπιών για Ειδικούς Χαρακτήρες, Κείμενα που θα εμφανίζονται πάνω από τον Editor, για ενσωμάτωση στο κείμενο με ένα Κλικ.'),
(62667, 106, 17, 'Προσθ. Κατηγορίας'),
(62668, 107, 17, 'Προσθ. Σταθεράς'),
(62669, 108, 17, 'Προσθήκη Πλαισίου'),
(62670, 109, 17, 'Προσθ. Συμμετοχής'),
(62671, 110, 17, 'Προσθ. Κριτηρίου'),
(62672, 111, 17, 'Προσθ. Ειδικού Κουμπιού'),
(62673, 112, 17, 'Προσθ. Διάγνωσης'),
(62674, 113, 17, 'Προσθ. Φαρμάκου'),
(62675, 114, 17, 'Προσθ. Επίσκεψης'),
(62676, 115, 17, 'Προσθ. Επίσκεψης/Σημείωσης'),
(62677, 116, 17, 'Προσθ. Έδρας'),
(62678, 117, 17, 'Προσθ. Πεδίου'),
(62679, 118, 17, 'Προσθήκη των ακόλουθων γραμμών στο αρχείο ρυθμίσεων του Apache'),
(62680, 119, 17, 'Προσθήκη Ομάδος'),
(62681, 120, 17, 'Προσθ. Κωδ. ICD'),
(62682, 121, 17, 'Προσθ. Εμβολίου'),
(62683, 122, 17, 'Μη εξουσιοδοτημένη προσθήκη!'),
(62684, 123, 17, 'Προσθ. Διάγνωσης'),
(62685, 125, 17, 'Προσθ. Γλώσσας'),
(62686, 126, 17, 'Προσθήκη Νέο/α'),
(62687, 127, 17, 'Προσθήκη νέο/α'),
(62688, 128, 17, 'Προσθ. νέας κατηγορίας '),
(62689, 129, 17, 'Προσθ. νέων πιστοποιητικών στο αρχείο ρυθμίσεων του Apache'),
(62690, 132, 17, 'Προσθ. Νέας Ομάδας'),
(62691, 134, 17, 'Προσθ. νέας παρτίδας και συναλλαγής'),
(62692, 135, 17, 'Προσθ. Νέας Σημείωσης'),
(62693, 136, 17, 'Προσθ. νέας σημείωσης'),
(62694, 137, 17, 'Προσθ. Νέου Συνεργάτη'),
(62695, 140, 17, 'Προσθ. Σημείωσης'),
(62696, 141, 17, 'Προσθ. Φακέλου Ασθενούς'),
(62697, 142, 17, 'Προσθ. Συνταγής'),
(62698, 143, 17, 'Προσθ. διαδικασίας'),
(62699, 144, 17, 'Προσθ. Αριθμ. Παρόχου'),
(62700, 145, 17, 'Προσθ. Αποκατάστασης'),
(62701, 146, 17, 'Προσθήκη κανόνα'),
(62702, 147, 17, 'Προσθήκη σε'),
(62703, 148, 17, 'Προσθ. στον Κατάλ. Φαρμάκων'),
(62704, 149, 17, 'Προσθήκη Ανωτ. Επιπέδου'),
(62705, 150, 17, 'Προσθ. Συναλλαγής'),
(62706, 151, 17, 'Προσθήκη Χρήστη'),
(62707, 152, 17, 'Καταχώρηση Χρήστη σε Ομάδα'),
(62708, 153, 17, 'Προσθ./Επεξεργ. ηλεκτρ. συνταγογράφησης'),
(62709, 154, 17, 'Προσθ./ Επεξεργ. Συναλλαγής με ασθενή'),
(62710, 155, 17, 'προστέθηκε'),
(62711, 156, 17, 'Δεν επιτρέπεται προσθήκη δημογραφ. στοιχείων.'),
(62712, 158, 17, 'Σύνδρ. Addison'),
(62713, 159, 17, 'Σύνδρ. Addison'),
(62714, 160, 17, 'Πρόσθετα χαρακτηριστικά'),
(62715, 161, 17, 'Πρόσθετη Διάγνωση:'),
(62716, 162, 17, 'Πρόσθετο Ιστορικό'),
(62717, 163, 17, 'Πρόσθετες σημειώσεις ιστορικού'),
(62718, 164, 17, 'Πρόσθετες πληροφορίες'),
(62719, 165, 17, 'Πρόσθετα Εργαστηριακά'),
(62720, 166, 17, 'Πρόσθετες Σημειώσεις'),
(62721, 167, 17, 'Πρόσθετες Σημειώσεις για το αποτέλεσμα αυτό ή για τη σύσταση αυτή'),
(62722, 168, 17, 'Πρόσθετες Σημειώσεις:'),
(62723, 169, 17, 'Πρόσθετες Σημειώσεις: '),
(62724, 170, 17, 'Πρόσθετες σημειώσεις Ακτινογραφιών:'),
(62725, 171, 17, 'Επιπλέον, το αντίστοιχο πακέτο επέκτασης US SnoMed μπορεί να εισαχθεί χωριστά, μετά την εγκατάσταση της Διεθνούς Έκδοσης (Αγγλική έκδοση) του Snomed'),
(62726, 172, 17, 'μόνο προσθήκη'),
(62727, 173, 17, 'Βιβλίο Διευθ.'),
(62728, 174, 17, 'Βιβλίο Διευθ.'),
(62729, 175, 17, 'Διεύθυνση'),
(62730, 178, 17, 'Βιβλίο Διευθύνσεων'),
(62731, 179, 17, 'Καταχώρηση εταιρείας που εκτελεί αυτή τη διαδικασία, στον βιβλίο διευθύνσεων'),
(62732, 180, 17, 'Καταχώρηση διανομέως στο βιβλίο διθευθύνσεων'),
(62733, 181, 17, 'Καταχώρηση πωλητού στο βιβλίο διθευθύνσεων'),
(62734, 182, 17, 'Τύποι βιβλίων διθευθύνσεων'),
(62735, 187, 17, 'Διεύθυνση 1'),
(62736, 188, 17, 'Διεύθυνση 2'),
(62737, 189, 17, 'Παραλήπτης'),
(62738, 190, 17, 'Ρυθμ'),
(62739, 191, 17, 'Ρυθμ Ποσού'),
(62740, 192, 17, 'Ρύθμιση'),
(62741, 193, 17, 'Αναπροσαρμογή'),
(62742, 194, 17, 'Ποσό αναπροσαρμογής'),
(62743, 195, 17, 'Λόγοι αναπροσαρμογής'),
(62744, 196, 17, 'Αναπροσαρμογή τιμής για κωδικό '),
(62745, 197, 17, 'Αναπροσαρμογές'),
(62746, 198, 17, 'Αναπροσαρμογή διαχ.'),
(62747, 199, 17, 'Διαχειριστής'),
(62748, 200, 17, 'E-mail Διαχειριστή'),
(62749, 201, 17, 'Διαχειρίση μέσω'),
(62750, 202, 17, 'Υπό διαχείριση'),
(62751, 203, 17, 'Υπό διαχείριση από'),
(62752, 205, 17, 'Ιστότοπος υπό διαχείριση'),
(62753, 206, 17, 'Διαχείριση'),
(62754, 207, 17, 'Ιστότοπος Διαχείρισης'),
(62755, 208, 17, 'Διαχειριστές'),
(62756, 209, 17, 'Οι διαχειριστές μπορούν να κάνουν τα πάντα'),
(62757, 210, 17, 'Ημερομ. εισαγωγής'),
(62758, 212, 17, 'Ελεγχος Βάρους ενήλικα και επανεκτίμηση'),
(62759, 213, 17, 'Επιτήρηση Βάρους ενήλικα και επανεκτίμηση (CQM)'),
(62760, 214, 17, 'Οδηγία προώθησης'),
(62761, 215, 17, 'Οδηγίες προώθησης');
INSERT INTO `lang_definitions` VALUES
(62762, 216, 17, 'Προειδοποίηση οδηγιών προώθησης'),
(62763, 218, 17, 'Για προχωρημένους'),
(62764, 219, 17, 'Συμβουλή'),
(62765, 221, 17, 'Επίδραση στο φυσιολογικό'),
(62766, 223, 17, 'Κλήσεις εκτός ωραρίου εργασίας'),
(62767, 224, 17, 'Όταν ολοκληρωθεί η μετάβαση από τους παλιούς μηχανισμούς κωδικού πρόσβασης, όπου οι κωδικοί αποθηκεύονται στον πίνακα χρηστών χωρίς αλάτι, αυτό το flag πρέπει να ορισθεί στη τιμή false έτσι ώστε να είναι δυνατή μόνον η διαπίστευση μέσω της νέας μεθόδου'),
(62768, 225, 17, 'Μετά την πραγματοποίηση των ανωτέρω ρυθμίσεων, εισάγετε το πιστοποιητικό του πελάτη admin στον φυλλομετρητή και επανεκινήστε τον Apache server (κενό password).'),
(62769, 226, 17, 'Μετά την αποθήκευση του PDF, κάντε click στο [Προβολή Log] για έλεγχο λαθών.'),
(62770, 227, 17, 'Μετά την αποθήκευση του/των ΤΕΧΤ αρχείου/ων, κάντε click στο [Προβολή Log] για έλεγχο λαθών.'),
(62771, 228, 17, 'Μετά την αποθήκευση της δέσμης ενεργειών σας, κάντε click στο [Προβολή Log] για έλεγχο λαθών'),
(62772, 230, 17, 'Αν οι πληροφορίες που εισάγατε είναι σωστές, πατήστε το κουμπί Αποθήκευση'),
(62773, 232, 17, 'Σχεδιασμός συνέχισης φροντίδας'),
(62774, 233, 17, 'Ξανά'),
(62775, 234, 17, 'Ηλικία'),
(62776, 235, 17, 'Ηλικία ανά'),
(62777, 236, 17, 'Κατηγορία ηλικίας'),
(62778, 237, 17, 'Τα στοιχεία ηλικίας είναι έκτος ορίων'),
(62779, 238, 17, 'Μορφή εμφάνισης ηλικίας'),
(62780, 239, 17, 'Η μορφή της ηλικίας για "ηλικία από" δεν είναι έγκυρη'),
(62781, 240, 17, 'Η μορφή της ηλικίας για "ηλικία μέχρι" δεν είναι έγκυρη'),
(62782, 241, 17, 'Ηλικία από'),
(62783, 242, 17, 'Ηλικία σε έτη για την αλλαγή του τύπου εμφάνισης'),
(62784, 243, 17, 'Μέγιστη ηλικία'),
(62785, 244, 17, 'Ελάχ. ηλικία'),
(62786, 245, 17, 'Όριο ηλικίας'),
(62787, 247, 17, 'Στήλες Ηλικίας:'),
(62788, 249, 17, 'Αλβανικά'),
(62789, 250, 17, 'Αλκοόλ'),
(62790, 251, 17, 'Κατανάλωση αλκοόλ'),
(62791, 253, 17, 'Αριθμός Ειδοποιήσεων'),
(62792, 255, 17, 'Ειδοποιήσεις'),
(62793, 259, 17, 'Όλα'),
(62794, 260, 17, 'ΟΛΑ'),
(62795, 261, 17, 'Όλα (σελιδοποιημένη μορφή Α)'),
(62796, 262, 17, 'Όλα (σελιδοποιημένη μορφή Β)'),
(62797, 263, 17, 'Όλα (σωρευτικά)'),
(62798, 266, 17, 'Όλες οι κατηγορίες'),
(62799, 268, 17, 'Όλοι οι κωδικοί'),
(62800, 269, 17, 'Ολοήμερο'),
(62801, 270, 17, 'Ολοήμερο συμβάν'),
(62802, 271, 17, 'Όλα τα πεδία Δημογραφικών. με αναζήτηση και έλεγχο διπλοκαταχωρήσεων'),
(62803, 272, 17, 'Όλες οι εγκαταστάσεις'),
(62804, 273, 17, 'Όλες οι Βλάβες/Προβλήματα/Θέματα'),
(62805, 274, 17, 'Επιτρέπονται όλες οι γλώσσες'),
(62806, 276, 17, 'Μικρό Όνομα ή τμήμα του'),
(62807, 277, 17, 'Επώνυμο ή τμήμα του'),
(62808, 278, 17, 'Οργανισμός ή τμήμα του'),
(62809, 280, 17, 'Όλα τα Προϊόντα'),
(62810, 281, 17, 'Όλοι οι Πάροχοι'),
(62811, 282, 17, 'Όλα ελέγχθηκαν και ήταν αρνητικά:'),
(62812, 283, 17, 'Όλα τα θέματα:'),
(62813, 284, 17, 'Όλοι οι Χρήστες'),
(62814, 285, 17, 'Αλλεργικός/ή'),
(62815, 286, 17, 'Αλλεργίες'),
(62816, 287, 17, 'Αλλεργίες:'),
(62817, 288, 17, 'Αλλεργία'),
(62818, 289, 17, 'Η εισαγωγή αλλεργιών ήταν επιτυχής'),
(62819, 290, 17, 'Λίστα προβλημάτων αλλεργίας'),
(62820, 291, 17, 'Αλλεργική αντίδραση'),
(62821, 294, 17, 'Κατανομή'),
(62822, 295, 17, 'Να επιτρέπεται'),
(62823, 296, 17, 'Όταν κάνετε login, επιτρέψτε όλες τις διαθέσιμες γλώσσες ως επιλογές του μενού'),
(62824, 297, 17, 'Επιτρέψτε δημιουργία Αιτημάτων Αποζημίωσης που περιέχουν Διαγνώσεις, αλλά όχι Διαδικασίες ή Χρεώσεις. Τα περισσότερα Ιατρεία δεν το θέλουν αυτό.'),
(62825, 298, 17, 'Να επιτρέπεται η γλώσα αποσφαλμάτωσης'),
(62826, 299, 17, 'Να επιτρέπεται αποστολή e-mail'),
(62827, 300, 17, 'Να επιτρέπεται αποστολή μηνυμάτων e-mail;'),
(62828, 301, 17, 'Να επιτρέπεται αποστολή e-mail;'),
(62829, 302, 17, 'Να επιτρέπονται Αιτήματα Αποζημίωσης Επισκέψεων'),
(62830, 303, 17, 'Να επιτρέπεται η Ανταλλαγή Πληροφοριών Υγείας'),
(62831, 304, 17, 'Να επιτρέπεται ο Διαμοιρασμός Πληροφοριών Ανοσοποίησης'),
(62832, 305, 17, 'Να επιτρέπεται η Χρήση Αρχείου Ανοσοποίησης'),
(62833, 306, 17, 'Να επιτρέπεται Μήνυμα Ταχυδρομείου'),
(62834, 308, 17, 'Να επιτρέπεται το Portal Ασθενούς'),
(62835, 309, 17, 'Να επιτρέπονται τα SMS'),
(62836, 310, 17, 'Να επιτρέπονται τα SMS (μήνυμ. κειμένου);'),
(62837, 311, 17, 'Τα συμβάντα που υπεβλήθησαν να γίνονται αμέσως ενεργά;'),
(62838, 312, 17, 'Να επιτρέπονται τηλεφωνικά μηνύματα;'),
(62839, 313, 17, 'Οι χρήστες μπορούν να δημοσιεύουν Ολικά Συμβάντα'),
(62840, 314, 17, 'Οι χρήστες μπορούν να δημοσιεύουν Προσωπικά Ημερολόγια'),
(62841, 315, 17, 'Να επιτρέπονται φωνητικά μηνύματα'),
(62842, 316, 17, 'Επιτρέπεται'),
(62843, 317, 17, 'Επιτρεπτές γλώσσες'),
(62844, 318, 17, 'Επιτρέπεται(c)'),
(62845, 323, 17, 'υπάρχει ήδη'),
(62846, 324, 17, 'υπάρχει ήδη.'),
(62847, 325, 17, 'Χρησιμοποιείται ήδη, επιλέξτε άλλο αναγνωριστικό'),
(62848, 326, 17, 'Χρησιμοποιείται ήδη, επιλέξτε άλλο τίτλο'),
(62849, 327, 17, 'Εναλλ. Διεύθυνση'),
(62850, 328, 17, 'αλλαγή'),
(62851, 329, 17, 'Εναλλακτικά, μπορείτε να χρησιμοποιήσετε τη σελίδα αναζήτησης για να φορτώσετε ένα αρχείο ηλεκτρον. εμβάσματος (X12 835) που έχετε λάβει από τον πληρωτή ή το γραφείο clearinghouse, κάνοντας κλικ στο κουμπί "Περιήγηση" και επιλέγοντας το αρχείο για να φορτώσετε, και στη συνέχεια, επιλέξτε Αναζήτηση για να εκτελεστεί η μεταφόρτωση και η απεικόνιση των αντίστοιχων τιμολογίων. Στην περίπτωση αυτή, οι λοιπές παράμετροι που αναφέρονται παραπάνω δεν ισχύουν και θα πρέπει να αγνοηθούν. Η μεταφόρτωση αποθηκεύει το αρχείο, αλλά δεν επεξεργάζεται ακόμη το περιεχόμενό του - αυτό γίνεται ξεχωριστά, όπως περιγράφεται κατωτέρω.'),
(62852, 330, 17, 'ΠΜ'),
(62853, 331, 17, 'Πρόγραμμα π.μ.'),
(62854, 332, 17, 'AMC'),
(62855, 333, 17, 'Εντοπισμός AMC'),
(62856, 338, 17, 'Τροποποίηση υφιστάμενης σημείωσης'),
(62857, 343, 17, 'Αμερικανός Ινδιάνος'),
(62858, 344, 17, 'Αμερικανός Ινδιάνος ή Γηγενής εξ'' Αλάσκας'),
(62859, 345, 17, 'American Express'),
(62860, 346, 17, 'Αμαρικά'),
(62861, 347, 17, 'Ποσό'),
(62862, 348, 17, 'Ποσό που χορηγήθηκε'),
(62863, 349, 17, 'Ποσά χρέωσης'),
(62864, 350, 17, 'Ποσό για προηγούμ, λογαριασμούς'),
(62865, 351, 17, 'Ποσό για αυτή την επίσκεψη'),
(62866, 352, 17, 'Καταβληθέν Ποσό'),
(62867, 353, 17, 'Ποσό:'),
(62868, 354, 17, 'Ποσό που χρεώθηκε:'),
(62869, 355, 17, 'Για τα εαναλαμβανόμενα γεγονότα, χρειάζεται μια ημερομηνία τέλους μετά την ημερομ. έναρξης.'),
(62870, 357, 17, 'Προέκυψε σφάλμα κατά το dumping του web directory του LibreEHR'),
(62871, 358, 17, 'Προέκυψε σφάλμα κατά το dumping του web directory του phpGACL'),
(62872, 359, 17, 'Προέκυψε σφάλμα κατά το dumping του web directory του SQL-Ledger'),
(62873, 360, 17, 'Ένα ατελές θέμα GCAC δημιουργήθηκε και συνδέθηκε. Κάποιος θα πρέπει να το ολοκληρώσει αργότερα.'),
(62874, 362, 17, 'Προέκυψε μη αναμενόμενο σφάλμα'),
(62875, 363, 17, 'Ενα κεφαλαίο γράμμα'),
(62876, 365, 17, 'Και'),
(62877, 366, 17, 'ΚΑΙ'),
(62878, 367, 17, 'και'),
(62879, 368, 17, 'και '),
(62880, 369, 17, 'και όλα τα συμπληρωματικά στοιχεία; Η ενέργεια αυτή θα καταγραφεί'),
(62881, 370, 17, 'και τροποποιητής'),
(62882, 371, 17, 'και επεξεργασμένο.'),
(62883, 372, 17, 'και επανεκκινήστε τον Apache server.'),
(62884, 373, 17, 'και ο λόγος είναι'),
(62885, 374, 17, 'Αναιμία'),
(62886, 375, 17, 'Αστράγαλος'),
(62887, 376, 17, 'Αστράγαλος + πτέρνα'),
(62888, 377, 17, 'Έντυπο εκτίμησης του αστραγάλου'),
(62889, 378, 17, 'Προβλήμ. αστραγάλου'),
(62890, 379, 17, 'Αγκυλοποιητική Σπονδυλίτιδα'),
(62891, 380, 17, 'Αγκυλοποιητική Σπονδυλίτιδα'),
(62892, 381, 17, 'Ανορεξία'),
(62893, 382, 17, 'Στο παράθυρο αποστολής μπορείτε επίσης να ζητήσετε δευτερεύουσα χρέωση. Αν επιλέξετε αυτό το πλαίσιο πριν την αποθήκευση, τότε η αρχική αγωγή θα ανοιχθεί ξανά και θα μπει στην ουρά στη σελίδα Χρεώσεων, και θα διεκπεραιωθεί κατά την επόμενη διαδικασία χρέωσης.'),
(62894, 383, 17, 'προ'),
(62895, 384, 17, 'Πρωκτικός Δακτύλιος κ.φ., χωρίς ορθική ευαισθησία/μάζα'),
(62896, 385, 17, 'Άγχος'),
(62897, 386, 17, 'Όλοι'),
(62898, 387, 17, 'Οποιαδήποτε Κατηγορία'),
(62899, 388, 17, 'Οποιοδήποτε τμήμα του επιθυμητού κωδικού ή της περιγραφής του'),
(62900, 389, 17, 'Οποιοδήποτε τμήμα της επιθυμητής ειδικότητας'),
(62901, 390, 17, 'Οποιοδήποτε τμήμα κωδικού του φαρμάκου ή του ονόματος του φαρμάκου'),
(62902, 391, 17, 'Οποιοδήποτε τμήμα κωδικού του εμβολίου ή του ονόματος του εμβολίου'),
(62903, 392, 17, 'Οποιοδήποτε τμήμα του ονόματος του ασθενούς η “επώνυμο,όνομα” η “Χ-Υ”'),
(62904, 393, 17, 'Οποιαδήποτε άλλη σημαντική πληροφορία'),
(62905, 394, 17, 'Κλειδί API για την πύλη SMS'),
(62906, 395, 17, 'Άπνοια'),
(62907, 396, 17, 'Εμφάνιση'),
(62908, 397, 17, 'Εμφάνιση:'),
(62909, 398, 17, 'Προσαρτήστε αυτή τη σημείωση'),
(62910, 399, 17, 'Προσαρτήστε στην υπάρχουσα σημείωση'),
(62911, 400, 17, 'Προσαρτήστε σε αυτή τη σημείωση'),
(62912, 401, 17, 'Προσαρτήστε σε αυτή τη σημείωση'),
(62913, 402, 17, 'Σκωληκοειδεκτομή'),
(62914, 404, 17, 'Εφαρμόζονται σε Ασθενείς'),
(62915, 405, 17, 'Εφαρμογή'),
(62916, 406, 17, 'Όνομα εφαρμογής για τη σελίδα login και τίτλος βασικού παραθύρου'),
(62917, 407, 17, 'Κωδικός Αίτησης Παραλήπτη (GS03 - Αν το πεδίο είναι κενό θα χρησιμοποιηθεί ο ISA08)'),
(62918, 408, 17, 'Κωδικός Aίτησης Aποστολέα (GS02)'),
(62919, 409, 17, 'Όνομα εφαρμογής'),
(62920, 410, 17, 'Ισχύει για την φόρμα των Ζωτικών και την Καμπύλη Ανάπτυξης'),
(62921, 411, 17, 'Ισχύει για την φόρμα των Ζωτικών'),
(62922, 412, 17, 'Εφαρμόστε τις αλλαγές μόνο στο Τρέχον γεγονός, σε αυτή και σε όλες τις Μελλοντικές εμφανίσεις ή σε Ολες τις εμφανίσεις.'),
(62923, 413, 17, 'Εφαρμογή στην προσβεβλημένη περιοχή'),
(62924, 414, 17, 'Εφαρμογή στο δέρμα'),
(62925, 415, 17, 'Εφαρμογή'),
(62926, 416, 17, 'Εφαρμογή patch στην περιοχή'),
(62927, 417, 17, 'Ραντεβού'),
(62928, 418, 17, 'Ημερομ. Ραντεβού'),
(62929, 419, 17, 'Στυλ εμφάνισης των Ραντεβού'),
(62930, 420, 17, 'Κανόνας υπενθύμισης ραντεβού'),
(62931, 421, 17, 'Κατάσταση ραντεβού'),
(62932, 422, 17, 'Κατάσταση ραντεβού'),
(62933, 423, 17, 'Ραντεβού εντός'),
(62934, 424, 17, 'Χρώμα Ραντεβού/Γεγονότος'),
(62935, 425, 17, 'Ραντεβού'),
(62936, 426, 17, 'Ραντεβού (εγγραφή προαιρετικά)'),
(62937, 427, 17, 'Ραντεβού (εγγραφή, με ορισμένες προαιρετικές επιλογές)'),
(62938, 430, 17, 'Ραντεβού και Επισκέψεις'),
(62939, 431, 17, 'Αναφορά Ραντεβού'),
(62940, 432, 17, 'Αναφορά Ραντεβού-Επισκέψεων'),
(62941, 434, 17, 'Έγκριση'),
(62942, 436, 17, 'Εγκρίθηκε'),
(62943, 437, 17, 'Διαχείριση Εγκεκριμ. Συμβάντων'),
(62944, 440, 17, 'Ραντ-Επισκ'),
(62945, 441, 17, 'Ραντ'),
(62946, 442, 17, 'Απρ'),
(62947, 443, 17, 'Απρίλιος'),
(62948, 444, 17, 'Αραβικά'),
(62949, 446, 17, 'Αρχείο'),
(62950, 447, 17, 'Τα ονόματα ομάδων για τον έλεγχο πρόσβασης πρέπει να μεταφρασθούν;'),
(62951, 448, 17, 'Τα ονόματα κατηγοριών επίσκεψης πρέπει να μεταφρασθούν;'),
(62952, 449, 17, 'Τα ονόματα για τις διάφορες κατηγορίες εγγράφων πρέπει να μεταφρασθούν;'),
(62953, 450, 17, 'Γίνεται κάποια χρέωση για αυτό τον τύπο;'),
(62954, 451, 17, 'Οι τίτλοι από τον φάκελο ασθενούς χρειάζεται να μεταφρασθούν;'),
(62955, 452, 17, 'Είναι αποθηκευμένοι οι κωδικοί σε εξωτερικούς πίνακες SQL [0-Όχι, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)];'),
(62956, 453, 17, 'Είστε έτοιμος να συμπληρώσετε ένα νέο θέμα GCAC για αυτή την επίσκεψη;'),
(62957, 454, 17, 'Είστε βέβαιος ότι θέλετε να το ταχυδρομήσετε σήμερα;'),
(62958, 455, 17, 'Είστε σίγουρος ότι θέλετε να επικυρώσετε αυτά τα συμβάντα;'),
(62959, 457, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε πλήρως αυτό το Έντυπο;'),
(62960, 459, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε αυτή τη γνωστοποίηση;'),
(62961, 460, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε αυτό το συμβάν;'),
(62962, 461, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε αυτό το αντικείμενο από τη βάση δεδομένων;'),
(62963, 462, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε αυτή τη σημείωση;'),
(62964, 464, 17, 'Είστε σίγουρος ότι θέλετε να τροποποιήσετε αυτά τα συμβάντα;'),
(62965, 465, 17, 'Είστε σίγουρος ότι θέλετε να αποκρύψετε αυτά τα συμβάντα;'),
(62966, 467, 17, 'Είστε σίγουρος ότι θέλετε να δείτε αυτά τα συμβάντα;'),
(62967, 468, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε ολόκληρη την ονομασθείσα ομάδα'),
(62968, 469, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε ολόκληρη τη λίστα'),
(62969, 470, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε τα περιεχόμενα του πεδίου'),
(62970, 471, 17, 'Είστε σίγουρος ότι θέλετε να διαγράψετε τα επιλεγμένα πεδία;'),
(62971, 472, 17, 'Είστε σίγουρος ότι θέλετε να προχωρήσετε με αυτές τις ενέργειες;'),
(62972, 473, 17, 'Μη καθορισθείσα περιοχή'),
(62973, 474, 17, 'Βραχίονας'),
(62974, 475, 17, 'Αρμενικά'),
(62975, 477, 17, 'Αρρυθμία'),
(62976, 478, 17, 'Αρθρίτιδα'),
(62977, 479, 17, 'Αρθρίτιδα / Εκφυλ. νόσος αρθρώσεων'),
(62978, 480, 17, 'Αρθρίτιδα / Εκφυλ. νόσος αρθρώσεων'),
(62979, 481, 17, 'όπως'),
(62980, 482, 17, 'Με έναρξη από'),
(62981, 484, 17, 'Ασιάτης'),
(62982, 487, 17, 'Εκτίμηση'),
(62983, 488, 17, 'Ανετέθη στον'),
(62984, 489, 17, 'Επικουρικός'),
(62985, 490, 17, 'Άσθμα'),
(62986, 491, 17, 'στο'),
(62987, 492, 17, 'Απαιτείται τουλάχιστον μια παράμετρος αναζήτησης αν επιλέξετε Ολα.'),
(62988, 493, 17, 'Στη σκαφοειδική'),
(62989, 494, 17, 'Στη σκαφοειδική:'),
(62990, 495, 17, 'Αθλητική ομάδα'),
(62991, 496, 17, 'Αθλητική Ομάδα'),
(62992, 497, 17, 'Αθλητική/Κάκωση'),
(62993, 503, 17, 'Προσοχή'),
(62994, 504, 17, 'Προσοχή'),
(62995, 506, 17, 'Ερωτήματα μηχανής για το Audit CDR'),
(62996, 509, 17, 'Αντίγραφα ασφαλείας για την καταγραφή του audit'),
(62997, 510, 17, 'Διάφορα για την καταγραφή του audit'),
(62998, 511, 17, 'Εντολή καταγραφής audit'),
(62999, 512, 17, 'Αρχείο καταγραφής audit στον φάκελλο ασθενούς'),
(63000, 513, 17, 'Προγραμματισμός καταγραφής audit'),
(63001, 514, 17, 'Διαχείριση Ασφαλείας καταγραφής audit'),
(63002, 515, 17, 'Ερώτημα SELECT Λογιστικού Ελέγχου'),
(63003, 516, 17, 'Αυγ'),
(63004, 517, 17, 'Αύγουστος'),
(63005, 519, 17, 'Εξουσ'),
(63006, 520, 17, 'Εξουσ/Σημειώσεις'),
(63007, 523, 17, 'Ομάδα εξουσιοδότησης'),
(63008, 524, 17, 'Κατάσταση εξουσιοδότησης'),
(63009, 525, 17, 'Εξουσιοδοτήσεις'),
(63010, 526, 17, 'Εξουσιοδοτήστε'),
(63011, 527, 17, 'Εξουσιοδότησε – οποιεσδήποτε επισκέψεις'),
(63012, 528, 17, 'Εξουσιοδότησε – οι επισκέψεις μου'),
(63013, 529, 17, 'Authorize.net'),
(63014, 530, 17, 'Εξουσιοδοτημένος/η'),
(63015, 531, 17, 'Μόνον εξουσιοδοτημένα άτομα'),
(63016, 532, 17, 'Αυτόματη Αποστολή'),
(63017, 535, 17, 'Αυτόματη δημιουργία νέων Επισκέψεων'),
(63018, 536, 17, 'Αυτόματη δημιουργία'),
(63019, 537, 17, 'Υπολογισμοί Αυτόματων Μετρήσεων'),
(63020, 542, 17, 'Παρακολούθηση Υπολογισμών Αυτόματων Μετρήσεων'),
(63021, 543, 17, 'Αυτόματες Μετρήσεις'),
(63022, 544, 17, 'Αυτόματο'),
(63023, 546, 17, 'Αυτόματη δημιουργία Νέας Επίσκεψης, όταν η κατάσταση επισκέψεως δείχνει "@" (έφτασε")'),
(63024, 549, 17, 'Ιατρικό αυτοκίνητο'),
(63025, 550, 17, 'αυτόματα αποθηκευμένο'),
(63026, 551, 17, 'Διαθέσιμες κατηγορίες'),
(63027, 552, 17, 'Διαθέσιμα ωράρια'),
(63028, 557, 17, 'Μηνιαίος ΜΟ'),
(63029, 558, 17, 'Αποκόλληση / Αποκολληθέν κάταγμα'),
(63030, 559, 17, 'Αποκόλληση έξω σφυρού'),
(63031, 560, 17, 'Αποκόλληση έσω σφυρού '),
(63032, 561, 17, 'Με βάση την επίγνωση'),
(63033, 562, 17, 'Μασχάλη'),
(63034, 565, 17, '2 φορές την ημέρα'),
(63035, 566, 17, 'Επιστροφή'),
(63036, 567, 17, 'επιστροφή'),
(63037, 568, 17, 'Πίσω κατά 8 επισκέψεις'),
(63038, 569, 17, 'Πίσω κατά 11 επισκέψεις'),
(63039, 570, 17, 'Πίσω κατά 5 επισκέψεις'),
(63040, 571, 17, 'Πίσω κατά 4 επισκέψεις'),
(63041, 572, 17, 'Πίσω κατά 9 επισκέψεις'),
(63042, 573, 17, 'Πίσω κατά 1 επίσκεψη'),
(63043, 574, 17, 'Πόνος στη μέση'),
(63044, 575, 17, 'Προβλήματα οσφύος'),
(63045, 576, 17, 'Πίσω κατά 7 επισκέψεις'),
(63046, 577, 17, 'Πίσω κατά 6 επισκέψεις'),
(63047, 578, 17, 'Εγχείριση στην οσφύ'),
(63048, 579, 17, 'Πίσω κατά 10 επισκέψεις'),
(63049, 580, 17, 'Πίσω κατά 3 επισκέψεις'),
(63050, 581, 17, 'Επιστροφή στη σελίδα Διαχείρισης'),
(63051, 584, 17, 'Επιστροφή στον Ασθενή'),
(63052, 585, 17, 'Επιστροφή στους χρήστες'),
(63053, 586, 17, 'Πίσω στην Προβολή'),
(63054, 587, 17, 'Πίσω κατά 12 επισκέψεις'),
(63055, 588, 17, 'Πίσω κατά 2 επισκέψεις'),
(63056, 589, 17, 'Υπηρεσίες στο υπόβαθρο'),
(63057, 590, 17, 'Αντίγραφα ασφαλείας'),
(63058, 591, 17, 'Δημιουργήθηκε αρχείο για backup . Τώρα θα σταλεί για download'),
(63059, 593, 17, 'Το Backup ελήφθη επιτυχώς στο'),
(63060, 594, 17, 'Κακός έλεγχος'),
(63061, 595, 17, 'Κακό χρέος'),
(63062, 596, 17, 'Ινδονησιακά Bahasa'),
(63063, 597, 17, 'Υπόλ.'),
(63064, 598, 17, 'Υπόλοιπο'),
(63065, 599, 17, 'υπόλοιπο'),
(63066, 600, 17, 'Υπόλοιπο ποσό'),
(63067, 601, 17, 'Οφειλόμενο υπόλοιπο'),
(63068, 603, 17, 'Τραπεζική επιταγή'),
(63069, 607, 17, 'Βάση του 5ου μεταταρσίου'),
(63070, 608, 17, 'Βάση του 5ου μεταταρσίου:'),
(63071, 611, 17, 'Μαζική Αξίωση'),
(63072, 612, 17, 'Εργαλείο για μαζική επικοινωνία'),
(63073, 613, 17, 'Καταχώρηση Ομαδικών πληρωμών'),
(63074, 614, 17, 'Ομαδικές πληρωμές'),
(63075, 615, 17, 'Ξεκίνησε η επεξεργασία δέσμης. Μπορεί να διαρκέσει κάποιο χρόνο.'),
(63076, 616, 17, 'Αποτελέσματα δέσμης'),
(63077, 617, 17, 'Δέσμη ενεργειών'),
(63078, 619, 17, 'επειδή εκείνο το αναγνωριστικό δεν υπάρχει'),
(63079, 620, 17, 'Έναρξη'),
(63080, 621, 17, 'Ημερομ. Έναρξης'),
(63081, 623, 17, 'Αρχική ημερομ. επίσκεψης εεεε-μμ-ηη'),
(63082, 624, 17, 'Ώρα έναρξης της ημέρας για τα συμβάντα του ημερολογίου'),
(63083, 626, 17, 'Ερυγές'),
(63084, 628, 17, 'Μπενγκάλι'),
(63085, 630, 17, 'μεταξύ'),
(63086, 633, 17, 'Αμφοτερόπλευρο'),
(63087, 634, 17, 'Αμφοτερόπλευρο:'),
(63088, 636, 17, 'Ημερομ. χρέωσης:'),
(63089, 637, 17, 'Χρέωση/Πληρωμή'),
(63090, 638, 17, 'Χρεώθηκε'),
(63091, 640, 17, 'Χρέωση'),
(63092, 641, 17, 'Χρέωση (εγγραφή προαιρετικά)'),
(63093, 642, 17, 'Προσοχή Χρέωσης'),
(63094, 644, 17, 'Κωδικός χρεώσεων για αιτούμενες υπηρεσίες'),
(63095, 645, 17, 'Κωδικοί χρεώσης'),
(63096, 646, 17, 'Δεδομένα χρέωσης'),
(63097, 647, 17, 'Τμήμα Χρεώσεων'),
(63098, 648, 17, 'Εγκατάσταση χρέωσης'),
(63099, 649, 17, 'Πληροφορίες χρέωσης'),
(63100, 650, 17, 'Τοποθεσίες χρέωσης'),
(63101, 655, 17, 'Διαχείριση Χρεώσεων'),
(63102, 656, 17, 'Σημείωμα χρεώσης'),
(63103, 657, 17, 'Ενημερωτικό χρέωσης για '),
(63104, 658, 17, 'Ενημερωτικό χρέωσης:'),
(63105, 659, 17, 'Αποτελέσματα ουράς χρέωσης:'),
(63106, 660, 17, 'Αναφορά χρέωσης:'),
(63107, 661, 17, 'Κατάσταση Χρέωσης = Αχρέωτο'),
(63108, 662, 17, 'Κατάσταση Χρέωσης = Δεν χρεώθηκε'),
(63109, 663, 17, 'χρέωση στον/στην '),
(63110, 665, 17, 'Βιοψία'),
(63111, 666, 17, 'Ημερομ. Γεννήσεως'),
(63112, 667, 17, 'Γέννηση-24 μηνών'),
(63113, 669, 17, 'Μαύρος /η'),
(63114, 670, 17, 'Μελανός πνεύμων'),
(63115, 671, 17, 'Μαύρος ή Αφροαμερικανός'),
(63116, 672, 17, 'Καρκίνος ουροδόχου κύστεως'),
(63117, 673, 17, 'Λοιμώξεις ουροδόχου κύστεως'),
(63118, 674, 17, 'Λευκά Έντυπα'),
(63119, 675, 17, 'Πρόβλημα αιμορραγίας'),
(63120, 676, 17, 'Τυφλά σημεία'),
(63121, 677, 17, 'Αίσθημα τυμπανισμού'),
(63122, 678, 17, 'Αποκλεισμένο'),
(63123, 679, 17, 'Αίμα'),
(63124, 680, 17, 'Αρτηρ. Πίεση'),
(63125, 681, 17, 'Αρτηρ. Πίεση'),
(63126, 682, 17, 'Ρινορραγία'),
(63127, 683, 17, 'Μπλε λογότυπο Κυανού Σταυρού'),
(63128, 684, 17, 'Οι μπλε γραμμές σε αυτήν την αναφορά είναι για πληροφόρηση. Οι μαύρες αναφέρονται σε προϋπάρχοντα στοιχεία. Οι πράσινες δείχνουν τις επιτυχημένες αλλαγές. Οι κόκκινες δείχνουν λάθη, ή αλλαγές που δεν υλοποιήθηκαν και θα πρέπει να γίνει επεξεργασία χειρονακτικά Προς το παρόν οι αρνήσεις και επιστροφές πληρωμών δεν γίνονται αυτόματα και γι''αυτό εμφανίζονται με κόκκινο.'),
(63129, 685, 17, 'Θολή όραση'),
(63130, 686, 17, 'ΔΜΣ'),
(63131, 687, 17, 'Κατάσταση του Δ.Μ.Σ.'),
(63132, 689, 17, 'Περιοχή σώματος'),
(63133, 690, 17, 'Σημείο του σώματος'),
(63134, 691, 17, 'Περιοχή σώματος, αν ισχύει'),
(63135, 692, 17, 'Οστικό άλγος/ευαισθησία:'),
(63136, 693, 17, 'Οστικό άλγος/ευαισθησία: Έσω σφυρός'),
(63137, 694, 17, 'Λογική μεταβλητή/ Boolean'),
(63138, 696, 17, 'Κάτω'),
(63139, 697, 17, 'Αμφότερα Ώτα'),
(63140, 698, 17, 'αμφότερα ώτα'),
(63141, 699, 17, 'Κάτω'),
(63142, 701, 17, 'Πεδίο 10 Α. Σχετ. με την απασχόληση '),
(63143, 702, 17, 'Πεδίο 10 Β. Αυτοκιν/κό Ατύχημα '),
(63144, 703, 17, 'Πεδίο 10 C. Άλλο Ατύχημα '),
(63145, 706, 17, 'Πεδίο 15. Ημερομ. ίδιας ή παρόμοιας ασθένειας (εεεε-μμ-ηη):'),
(63146, 708, 17, 'Πεδίο 16. Ανικανότητα για εργασία από (εεεε-μμ-ηη)'),
(63147, 709, 17, 'Πεδίο 16. Ανικανότητα για εργασία έως (εεεε-μμ-ηη)'),
(63148, 710, 17, 'Πεδίο 18. Νοσηλεύθηκε από (εεεε-μμ-ηη) '),
(63149, 711, 17, 'Πεδίο 18. Νοσηλεύθηκε έως (εεεε-μμ-ηη) '),
(63150, 712, 17, 'Πεδίο 20. Χρησιμοποιήθηκε εξωτερ. εργαστήριο;'),
(63151, 713, 17, 'Πεδίο 22. Κωδικός επαναποστολής στο Medicaid (ICD-9) '),
(63152, 714, 17, 'Πεδίο 23. Αριθμός προηγούμενης εξουσιοδότησης. '),
(63153, 715, 17, 'ΑΠ'),
(63154, 716, 17, 'Διαστολική ΑΠ'),
(63155, 717, 17, 'Συστολική ΑΠ'),
(63156, 719, 17, 'ΔΑΠ'),
(63157, 721, 17, 'ΣΑΠ'),
(63158, 722, 17, 'Βραζιλιανά Πορτογαλικά'),
(63159, 723, 17, 'Μαστός'),
(63160, 724, 17, 'Βιοψία μαστού'),
(63161, 725, 17, 'Έκκριμα μαστού'),
(63162, 726, 17, 'Νόσος μαστών'),
(63163, 727, 17, 'Εξέταση μαστών'),
(63164, 728, 17, 'Μάζα μαστού'),
(63165, 730, 17, 'Αναπνευστικοί ήχοι:'),
(63166, 732, 17, 'Κατάγματα'),
(63167, 734, 17, 'Έντυπο βρογχίτιδας'),
(63168, 735, 17, 'Αναζήτηση'),
(63169, 736, 17, 'Αναζήτηση Φακέλου'),
(63170, 737, 17, 'Μώλωπας/Αιμάτωμα'),
(63171, 739, 17, 'Πρόπτωση Δεξιά:'),
(63172, 741, 17, 'Καύσος κατά την ούρηση'),
(63173, 742, 17, 'Καύσος Κατά Την Ούρηση'),
(63174, 744, 17, 'Απασχολημένος/η'),
(63175, 745, 17, 'αλλά δεν έγινε ακόμα επεξεργασία.'),
(63176, 746, 17, 'Γλουτός'),
(63177, 747, 17, 'Γλουτός και Ιερολαγόνια'),
(63178, 748, 17, 'με το'),
(63179, 749, 17, 'Με το'),
(63180, 750, 17, 'από το στόμα'),
(63181, 751, 17, 'Με/Πηγή'),
(63182, 752, 17, 'Έως:'),
(63183, 753, 17, 'C'),
(63184, 755, 17, 'Διάρκεια αποθήκευσης πρωσωρ. δεδομένων (σε δευτερόλ.)'),
(63185, 756, 17, 'Έξοδος προτύπου της cache ;'),
(63186, 757, 17, 'Κατανάλωση Καφεΐνης'),
(63187, 758, 17, 'Ημερολόγιο'),
(63188, 759, 17, 'Ώρα τέλους στο Ημερολόγιο'),
(63189, 760, 17, 'Διάστημα στο Ημερολόγιο'),
(63190, 761, 17, 'Οθόνη Ημερολογίου'),
(63191, 762, 17, 'Ρυθμίσεις Ημερολογίου'),
(63192, 763, 17, 'Ώρα έναρξης στο Ημερολόγιο'),
(63193, 764, 17, 'Εμφάνιση Ημερολογίου'),
(63194, 765, 17, 'Προβολή Ημερολογίου'),
(63195, 766, 17, 'Η κλήση στην addForm() πηγαίνει εδώ.<br>'),
(63196, 767, 17, 'Θερμίδες'),
(63197, 768, 17, 'Καμπότζης'),
(63199, 774, 17, 'Ακύρωση'),
(63200, 775, 17, 'Ακύρωση αλλαγών'),
(63201, 776, 17, 'Ακυρώθηκε'),
(63202, 777, 17, 'Καρκίνος'),
(63203, 778, 17, 'Προληπτικός έλεγχος καρκίνου: Προληπτικός έλεγχος καρκίνος του παχέος εντέρου'),
(63204, 779, 17, 'Προληπτικός έλεγχος καρκίνου: Μαστογραφία'),
(63205, 780, 17, 'Προληπτικός έλεγχος καρκίνου: Τεστ Παπανικολάου'),
(63206, 781, 17, 'Προληπτικός έλεγχος καρκίνου: Προληπτικός έλεγχος καρκίνου του προστάτη'),
(63207, 782, 17, 'Αδύνατη η προσθήκη αυτής της καταχώρησης, διότι υπάρχει ήδη!'),
(63208, 783, 17, 'Αδύνατη η προσθήκη/αλλαγή, διότι υπάρχει ήδη μία ίδια διπλή εγγραφή στη βάση!'),
(63209, 784, 17, 'δεν μπορεί να αρχειοθετηθεί, αγνοείται'),
(63210, 785, 17, 'αδύνατη η μετατροπή σε JPEG. Ίσως να μην είναι εγκατεστημένο το ImageMagick;'),
(63211, 786, 17, 'δεν μπορεί να διαγραφεί, αγνοείται'),
(63212, 787, 17, 'αδύνατη η εμφάνιση inline, διότι ο browser δεν υποστηρίζει αυτον τον τύπο'),
(63213, 788, 17, 'αδύνατη η εμφάνιση inline, διότι ο browser δεν υποστηρίζει αυτον τον τύπο'),
(63214, 789, 17, 'αδύνατη η εμφάνιση inline, διότι ο browser δεν υποστηρίζει αυτον τον τύπο'),
(63215, 790, 17, 'Δεν είναι δυνατή η δημιουργία'),
(63216, 795, 17, 'Δεν είναι δυνατή η εύρεση '),
(63217, 796, 17, 'Δεν είναι δυνατή η εύρεση αρχείου ονόματος προορισμού'),
(63218, 799, 17, 'Αδύνατη η εύρεση του ασθενούς από το SQL-Ledger με βάση το customer id'),
(63219, 800, 17, 'Αδύνατη η εύρεση αναφοράς για το postscript έγγραφο στο '),
(63220, 801, 17, 'Αδύνατη η εύρεση παρόχου από το SQL-Ledger employee= '),
(63221, 802, 17, 'Αδύνατη η τροποποίηση Πληρωμών. Τα αδιανέμητα είναι αρνητικά.'),
(63222, 803, 17, 'Δεν είναι δυνατό το άνοιγμα '),
(63223, 804, 17, 'Αδύνατη η αποστολή για την Ασφάλ. εταιρεία. Αυτός που επιλέχθηκε ως καταβάλλων την πληρωμή, είναι ασθενής.'),
(63224, 805, 17, 'Αδύνατη η αποστολή για για Ασθενή. Αυτός που επιλέχθηκε ως καταβάλλων την πληρωμή, είναι μια Ασφαλ. εταιρεία.'),
(63225, 806, 17, 'Αδύνατη η αποστολή Πληρωμών. Τα αδιανέμητα είναι αρνητικά.'),
(63226, 807, 17, 'Δεν είναι δυνατή η ανάγνωση'),
(63227, 808, 17, 'Δεν είναι δυνατή η ανάγνωση καταλόγου'),
(63228, 809, 17, 'Αδύνατη η ενημέρωση, διότι δεν επεξεργάζεσθε μία υπάρχουσα καταχώρηση!'),
(63229, 810, 17, 'Κεφαλαιοποίηση'),
(63230, 812, 17, 'καψάκιο (caps)'),
(63231, 813, 17, 'Κάρτα'),
(63232, 814, 17, 'Καρδιακός καθετηριασμός'),
(63233, 815, 17, 'Καρδιακό υπερηχογράφημα'),
(63234, 816, 17, 'Καρδιαγγειακό'),
(63235, 821, 17, 'Βλάβη χόνδρου / δίσκου'),
(63236, 822, 17, 'Κάκωση χόνδρου'),
(63237, 823, 17, 'Σφύξεις καρωτίδας κ.φ., Ραχιαίων Αρτηρ. του ποδός κ.φ.'),
(63238, 824, 17, 'μετρητά'),
(63239, 825, 17, 'Μετρητά'),
(63240, 826, 17, 'Απόδειξη για Μετρητά'),
(63241, 827, 17, 'Αποδείξεις Μετρητών ανά Πάροχο'),
(63242, 829, 17, 'Εγχείριση καταρράκτη'),
(63243, 830, 17, 'Καταρράκτης'),
(63244, 831, 17, 'Κατηγορίες'),
(63245, 832, 17, 'Κατηγορίες για'),
(63246, 833, 17, 'Κατηγορία'),
(63247, 834, 17, 'κατηγορία'),
(63248, 835, 17, 'Κατηγορία '),
(63249, 836, 17, 'Λεπτομέρειες κατηγορίας'),
(63250, 837, 17, 'Όρια κατηγορίας'),
(63251, 838, 17, 'Όνομα κατηγορίας'),
(63252, 839, 17, 'Το όνομα της κατηγορίας είναι κενό'),
(63253, 840, 17, 'Κατηγορία/Τίτλος'),
(63254, 841, 17, 'Λευκής φυλής'),
(63255, 842, 17, 'οδηγεί στην Εκτύπωση αποδέιξεων/ Πληροφ. για Πάροχο Πρωτοβ. φροντίδας ή για τις Επισκέψεις'),
(63256, 850, 17, 'CDR'),
(63257, 851, 17, 'Προτεραιότητα Επεξεργασίας των Εκθέσεων CDR'),
(63258, 852, 17, 'Κύτταρο'),
(63259, 853, 17, 'Κινητό τηλέφωνο'),
(63260, 855, 17, 'Αριθ. κινητού τηλεφ.'),
(63261, 856, 17, 'Κεντρική Πιστοποίηση'),
(63262, 857, 17, 'Κεντρο/Νοτιο-Αμερικανός'),
(63263, 858, 17, 'Τα αρχείο crt για την Εξουσιοδ. Πιστοποίησης δεν μπορεί να είναι άδειο'),
(63264, 859, 17, 'Τα αρχείο με το κλειδί για την Εξουσιοδ. Πιστοποίησης δεν μπορεί να είναι κενό'),
(63265, 860, 17, 'Πιστοποίηση που θα σταλεί στον διακομιστή RFC 5425 TLS syslog.'),
(63266, 861, 17, 'Χρήστης Πιστοποίησης'),
(63267, 862, 17, 'Πιστοποιητικά'),
(63268, 864, 17, 'Πολιτικό Πρόγραμμα Υγείας και Ιατρικής για τους Ένστολους'),
(63269, 865, 17, 'Πολιτικό Πρόγραμμα Υγείας και Ιατρικής για τους Ένστολους Βετεράνους'),
(63270, 866, 17, 'αλλαγή'),
(63271, 867, 17, 'Αλλαγή'),
(63272, 868, 17, 'Ενεργή/Ανενεργή'),
(63273, 869, 17, 'Η αλλαγή απέτυχε! Σφάλμα σύνδεσης με το CouchDB;'),
(63274, 870, 17, 'Αλλαγή στην όραση'),
(63275, 871, 17, 'Αλλαγή στην όραση'),
(63276, 872, 17, 'Αλλαγή κωδικού πρόσβασης'),
(63277, 874, 17, 'Τροποποιήθηκε'),
(63278, 875, 17, 'Αλλαγή συνηθειών εντέρου'),
(63279, 876, 17, 'Αλλαγή του ID ασθενούς για το έγγραφο'),
(63280, 877, 17, 'Χαρακτηριστικά'),
(63281, 878, 17, 'Χαρακτήρες που απομένουν'),
(63282, 879, 17, 'Χρέωση'),
(63283, 880, 17, 'Προσαρμογή Χρέωσης'),
(63284, 881, 17, 'Η χρέωση πήρε έναν κωδικό'),
(63285, 882, 17, 'Χρεώσεις'),
(63286, 883, 17, 'Φάκελος'),
(63287, 884, 17, 'Καταγραφή Δραστηριότητας'),
(63288, 885, 17, 'Καταγραφή αναφορών Εισερχομένων/Εξερχομένων'),
(63289, 886, 17, 'Κωδικός φακέλου'),
(63290, 887, 17, 'Κωδικός φακέλου:'),
(63291, 889, 17, 'Καταγραφή Τοποθεσίας Φακέλου'),
(63292, 890, 17, 'Σημείωση Φακέλου'),
(63293, 891, 17, 'Αριθμός Φακέλου'),
(63294, 892, 17, 'Τοποθεσίες Αποθήκευσης Φακέλων'),
(63295, 893, 17, 'Ευρετήριο Φακέλων'),
(63296, 894, 17, 'Ευρετ. Φακελ.'),
(63297, 895, 17, 'Ελεγμένοι Φάκελοι'),
(63298, 896, 17, 'Έλεγχος φακέλων'),
(63299, 898, 17, 'Έλεγχος'),
(63300, 899, 17, 'έλεγχος'),
(63301, 900, 17, 'Επιλογή όλων'),
(63302, 902, 17, 'Ποσό Ελέγχου'),
(63303, 903, 17, 'Ημερομηνία Ελέγχου'),
(63304, 904, 17, 'Ελέγξτε για διαφορές μετάφρασης με τον custom πίνακα γλώσσας.'),
(63305, 906, 17, 'Έλεγχος μέσα στο'),
(63306, 907, 17, 'Έλεγχος δεδομένων εισόδου'),
(63307, 909, 17, 'Έλεγχος εργαστηριακών αποτελεσμάτων'),
(63308, 911, 17, 'Αρ. ελέγχου'),
(63309, 912, 17, 'Αριθμός ελέγχου'),
(63310, 915, 17, 'Έλεγχος Πληρωμής'),
(63311, 916, 17, 'Τσεκάρετε το κουτάκι επιλογής, αν πρόκειται για κρυπτογραφ. αρχείο'),
(63312, 917, 17, 'Επιλέξτε αυτό, αν θέλετε οι Πάροχοι να βλέπουν εξ ορισμού όλα τα ραντεβού και όχι μόνο τα δικά τους'),
(63313, 918, 17, 'Επιλέξτε για δημιουργία προβλήματος από αυτή τη διάγνωση'),
(63314, 919, 17, 'Έλεγχος/ Ημερομ. Εμβασμ. Πληρωμής (EOB):'),
(63315, 920, 17, 'Έλεγχος/ Αριθμός Εμβασμ. Πληρωμής (ΕΟΒ):'),
(63316, 921, 17, 'Έλεγχος/ Αριθμός Αναφ.'),
(63317, 922, 17, 'Έλεγχος/ Αριθμός αναφοράς'),
(63318, 923, 17, 'Λίστα με κουτάκια επιλογών'),
(63319, 924, 17, 'λίστα με κουτάκια επιλογών'),
(63320, 925, 17, 'Λίστα με κουτάκια επιλογών με κείμενο'),
(63321, 926, 17, 'Λίστα με κουτάκια επιλογών με κείμενο'),
(63322, 928, 17, 'Επιλέχθηκε'),
(63323, 929, 17, 'Επιλεγμένο κουτάκι = Ναι, Άδειο = Όχι'),
(63324, 932, 17, 'Έλεγχος εξόδου'),
(63325, 933, 17, 'Checksum'),
(63326, 934, 17, 'Θώρακας'),
(63327, 935, 17, 'Ακρόαση πνευμόνων καθαρή άμφω'),
(63328, 936, 17, 'Θωρακικό άλγος'),
(63329, 937, 17, 'Θωρακικό άλγος:'),
(63330, 938, 17, 'Θωρακικά Άλγη'),
(63331, 940, 17, 'Αλλαγές'),
(63332, 942, 17, 'Κύριο Ενόχλημα'),
(63333, 943, 17, 'Παιδί'),
(63334, 945, 17, 'Κατάσταση εμβολ. παιδιού'),
(63335, 946, 17, 'Φρίκια'),
(63336, 947, 17, 'Κινεζικά'),
(63337, 948, 17, 'Κινεζικά (Απλοπ.)'),
(63338, 949, 17, 'Κινεζικά (Παραδοσιακά)'),
(63339, 951, 17, 'Επιλογές'),
(63340, 952, 17, 'Χολοκυστεκτομή'),
(63341, 954, 17, 'Χολοκυστοστομία'),
(63342, 955, 17, 'Επιλέξτε'),
(63343, 956, 17, 'Επιλέξτε μια ενότητα και κάντε κλικ σε ένα αντικείμενο μέσα σε αυτή. Τότε, στο άλλο τμήμα, θα δείτε τονισμένα τα σχετικά αντικείμενα και μπορείτε να κάνετε κλικ εκεί, για να προσθέσετε και να διαγράψετε σχέσεις.'),
(63344, 957, 17, 'Επιλέξτε κριτήρια'),
(63345, 959, 17, 'Επιλέξτε Αρχείο'),
(63346, 960, 17, 'Επιλέξτε λίστα'),
(63347, 962, 17, 'Επιλέξτε λίστα'),
(63348, 965, 17, 'Επιλέξτε τρόπο εκτύπωσης για αυτήν την αναφορά επίσκεψης.'),
(63349, 967, 17, 'Χρόνια βρογχίτιδα'),
(63350, 968, 17, 'Χρόνια αρθραλγία'),
(63351, 969, 17, 'Χρόνια νεφρική νόσος'),
(63352, 970, 17, 'Χρόνια υμενίτιδα / συλλογή υγρού / αρθραλγία / ποδάγρα'),
(63353, 971, 17, 'Χρόνιο/ Υποτροπιάζον'),
(63354, 973, 17, 'Κίρρωση του ήπατος'),
(63355, 974, 17, 'Κίρρωση του ήπατος'),
(63356, 975, 17, 'Πόλη'),
(63357, 976, 17, 'Όνομα πόλης'),
(63358, 977, 17, 'Πόλη, Νομός'),
(63359, 978, 17, 'Πόλη, Νομός ΤΚ'),
(63360, 979, 17, 'Πόλη/ Νομός'),
(63361, 980, 17, 'Απαίτηση'),
(63362, 981, 17, 'Απαίτηση '),
(63363, 982, 17, 'Κατάσταση απαιτήσεων'),
(63364, 983, 17, 'Ο έλεγχος των απαιτήσεων ολοκληρώθηκε'),
(63365, 984, 17, 'Τύπος απαίτησης'),
(63366, 985, 17, 'Η απαίτηση οδήγησε στη δημιουργία αρχείου'),
(63367, 986, 17, 'Η απαίτηση οδήγησε στη δημιουργία αρχείου '),
(63368, 987, 17, 'Απαιτήσεις'),
(63369, 988, 17, 'Ταξινόμηση'),
(63370, 989, 17, 'Καθαρισμός'),
(63371, 990, 17, 'ΚΑΘΑΡΙΣΜΟΣ ΕΝΕΡΓΟΥ ΑΣΘΕΝΟΥΣ'),
(63372, 991, 17, 'Καθαρισμός όλων'),
(63373, 992, 17, 'Καθαρισμός δεδομένων HL7'),
(63374, 993, 17, 'Καθαρισμός Αιτιολόγησης'),
(63375, 994, 17, 'Καθαρισμός Ημερολογίου'),
(63376, 996, 17, 'Αριθμός CLIA'),
(63377, 997, 17, 'Κλικ'),
(63378, 998, 17, 'Πατήστε “Εξαγωγή” για να εξάγετε τα δεδομένα Κατηγορίας, Υποκατηγορίας και Αντικειμένου, σε ένα αρχείο. Οποιαδήποτε ομοιότητα αυτού του αρχείου με αρχείο XML είναι καθαρά συμπτωματική. Το άνοιγμα και το κλείσιμο ετικετών πρέπει να είναι στην ίδια γραμμή με πεζά γράμματα, χωρίς κενά. Για εισαγωγή, αναζητήστε ένα αρχείο και κάντε κλικ στο κουμπί “Εισαγωγή”. Εάν τα δεδομένα είναι εντελώς διαφορετικά, θα συγχωνευτούν με τα υπάρχοντα. Αν υπάρχουν ίδια ονόματα αντικειμένων, το παλιό όνομα θα διατηρηθεί και το νέο θα αποθηκευθείμε την προσθήκη ενός αριθμού στο τέλος του.'),
(63379, 999, 17, 'Κάντε κλικ σε ένα σημείο στην εικόνα για να προσθέσετε νέα επισήμανση. Κάντε κλικ ξανά στο ίδιο σημείο για να την αφαιρέσετε.'),
(63380, 1000, 17, 'Πατήστε Κατέβασμα Πιστοποιητικών για να κατεβάσετε τα πιστοποιητικά στο αρχείο ssl.zip'),
(63381, 1001, 17, 'κάντε κλικ για περισσότερες'),
(63382, 1002, 17, 'Κάντε κλικ για περισσότερες πληροφορίες'),
(63383, 1003, 17, 'Κάντε κλικ για σύνοψη παραγγελίας'),
(63384, 1004, 17, 'Κάντε κλικ για αποτελέσματα'),
(63385, 1005, 17, 'Κλικ εδώ'),
(63386, 1006, 17, 'Κλικ εδώ για την προσθήκη Νέου Ασθενούς'),
(63387, 1007, 17, 'Κλικ εδώ για την προσθήκη νέας κατάστασης αλλαγής τραύματος και την επεξεργασία της καθμερινής δραστηριότητας'),
(63388, 1008, 17, 'Κλικ εδώ για επιλογή ημερομηνίας'),
(63389, 1009, 17, 'Κλικ εδώ για επιλογή ημερομ. και ώρας'),
(63390, 1010, 17, 'Κλικ εδώ για επιλογή ημερομ. έναρξης'),
(63391, 1020, 17, 'Κλικ εδώ για αναζήτηση'),
(63392, 1021, 17, 'Κλικ εδώ για ενημέρωση των ρυθμίσεων προτεραιότητας, κατηγορίας και ψευδωνύμου'),
(63393, 1022, 17, 'Κλικ εδώ για προβολή όλων'),
(63394, 1023, 17, 'Κλικ εδώ για προβολή και γράφημα'),
(63395, 1025, 17, 'Κάντε κλικ εδώ για προβολή και γράφημα όλων των ζωτικών.'),
(63396, 1026, 17, 'Κάντε κλικ εδώ για να δείτε τα στοιχεία των ασθενών'),
(63397, 1027, 17, 'Κάντε κλικ εδώ για να τα δείτε όλα.'),
(63398, 1028, 17, 'Κάντε κλικ εδώ για να δείτε/επεξεργαστείτε περισσότερες πληροφορίες'),
(63399, 1029, 17, 'Κάντε κλικ στο "Εγκατάσταση" για να εγκαταστήσετε την έκδοση βάσης δεδομένων από τις ακόλουθες ημερομηνίες'),
(63400, 1030, 17, 'Κάντε κλικ σε οποιοδήποτε τμήμα χρόνου για να το αυξήσετε'),
(63401, 1031, 17, 'Κάντε κλικ στο Όνομα του Ασθενούς για να ανοίξετε το Αρχείο Ασθενούς.'),
(63402, 1032, 17, 'Κλικ στο Ανανέωση για να δείτε όλα τα αποτελέσματα, ή ορίστε κριτήρια αναζήτησης πιο πάνω, για να δείτε συγκεκριμμένα αποτελέσματα'),
(63403, 1033, 17, 'Κάντε κλικ για προσθήκη μιας διάγνωσης'),
(63404, 1034, 17, 'Κάντε κλικ για προσθήκη νέων συστατικών'),
(63405, 1035, 17, 'Κάντε κλικ για προσθήκη νέας εκτίμησης'),
(63406, 1037, 17, 'Κάντε κλικ για να κατεβάσετε'),
(63407, 1038, 17, 'Κάντε κλικ για επεξεργασία'),
(63408, 1039, 17, 'Κάντε κλικ για την επεξεργασία της περιγραφής'),
(63409, 1040, 17, 'Κάντε κλικ για επεξεργασία αυτού του συμβάντος'),
(63410, 1041, 17, 'Κάντε κλικ για δημιουργία της αναφοράς'),
(63411, 1043, 17, 'Κάντε κλικ για εκτύπωση'),
(63412, 1044, 17, 'Κάντε κλικ για λήψη (προσθήκη) νέας παρτίδας'),
(63413, 1045, 17, 'Κάντε κλικ για να επιλέξετε'),
(63414, 1046, 17, 'Κάντε κλικ για Επιλογή'),
(63415, 1047, 17, 'Κάντε κλικ για επιλογή ενός προτυποποιημένου κωδικού για αυτή τη διαδικασία');
INSERT INTO `lang_definitions` VALUES
(63416, 1048, 17, 'Κάντε κλικ για να επιλέξετε έναν προαιρετκό κωδικό για αυτή τη διαδικασία'),
(63417, 1050, 17, 'Κάντε κλικ για επιλογή ή αλλαγή κωδικού CVX'),
(63418, 1051, 17, 'Κάντε κλικ για επιλογή ή αλλαγή διαγνώσεων'),
(63419, 1052, 17, 'Κάντε κλικ για επιλογή ή αλλαγή των κωδικών των υπηρεσιών'),
(63420, 1053, 17, 'Κάντε κλικ για επιλογή ασθενούς'),
(63421, 1054, 17, 'Κάντε κλικ για επιλογή σχετικού κώδικα'),
(63422, 1055, 17, 'Κάντε κλικ για επιλογή υπηρεσιών προς εκτέλεση αν αυτό το αποτέλεσμα είναι παθολογικό'),
(63423, 1056, 17, 'Κάντε κλικ για επιλογή της επιθυμητής διαδικασίας'),
(63424, 1057, 17, 'Κάντε κλικ για να κάνετε κατάταξη'),
(63425, 1058, 17, 'Kάντε κλικ για προβολή'),
(63426, 1059, 17, 'Kάντε κλικ για προβολή ή επεξεργασία'),
(63427, 1060, 17, 'Kάντε κλικ για προβολή/επεξεργασία'),
(63428, 1061, 17, 'Κάντε κλικ στο κουμπί "Αναβάθμιση" για να αναβαθμίσετε την έκδοση βάσης δεδομένων από την ακόλουθη ημερομηνία'),
(63429, 1063, 17, 'Κάντε κλικ:'),
(63430, 1064, 17, 'Ημέρες μέχρι τη Λήξη Πιστοποιητικού Πελάτη'),
(63431, 1065, 17, 'Περίοδος επικύρωσης πιστοποιητικού πελάτη'),
(63432, 1066, 17, 'Η κύρωση πιστοποιητικού πελάτη πρέπει να είναι έγκυρος αριθμός.'),
(63433, 1067, 17, 'Αντίγραφο για τον Ασθενή'),
(63434, 1069, 17, 'Περίληψη ιατρικού ιστορικού ασθενούς'),
(63435, 1070, 17, 'Όνομα Πελάτη'),
(63436, 1071, 17, 'Αριθμός Πελάτη'),
(63437, 1072, 17, 'Προφίλ Ασθενούς - Νέοι Ασθενείς'),
(63438, 1073, 17, 'Προφίλ Ασθενούς - Μοναδικοί Ασθενείς'),
(63439, 1074, 17, 'Ασθενείς'),
(63440, 1075, 17, 'Κλινική'),
(63441, 1076, 17, 'Αντίγραφο για την Κλινική'),
(63442, 1077, 17, 'Ημερήσια αναφορά κλινικής/ ιατρείου'),
(63443, 1078, 17, 'Αναγνωριστικό κλινικής'),
(63444, 1079, 17, 'Κλινικό'),
(63445, 1080, 17, 'Διαχειριστής Ειδοποιήσεων για Πρωτόκολλα λήψης Κλινικών Αποφάσεων'),
(63446, 1081, 17, 'Κλινικό Ιστορικό'),
(63447, 1083, 17, 'Κλινικά Πλάνα'),
(63448, 1084, 17, 'Μετρήσεις δεικτών κλινικής ποιότητας (CQM)'),
(63449, 1087, 17, 'Κλινικές Υπενθυμίσεις'),
(63450, 1088, 17, 'Κλινικές Εκθέσεις/Αναφορές'),
(63451, 1089, 17, 'Κατηγορία Δράσης Κλινικών Κανόνων'),
(63452, 1090, 17, 'Αντικείμενο Δράσης Κλινικών Κανόνων'),
(63453, 1091, 17, 'Μέθοδοι Φίλτραρίσματος Κλινικών Κανόνων'),
(63454, 1092, 17, 'Μέθοδοι-Στόχοι Κλινικών Κανόνων'),
(63455, 1093, 17, 'Κλινικοί Κανόνες'),
(63456, 1094, 17, 'Ηλικιακά Ορια Κλινικών Κανόνων'),
(63457, 1095, 17, 'Συγκρίσεις Κλινικών Κανόνων'),
(63458, 1096, 17, 'Τύποι Επισκέψεων Κλινικών Κανόνων'),
(63459, 1097, 17, 'Επιλογές Υπενθύμισης Κλινικών Κανόνων'),
(63460, 1098, 17, 'Επιλογές Απενεργοποίησης της Υπενθύμισης Κλινικών Κανόνων'),
(63461, 1099, 17, 'Διαστήματα Υπενθύμισης Κλινικών Κανόνων'),
(63462, 1100, 17, 'Μέθοδοι Υπενθύμισης Κλινικών Κανόνων'),
(63463, 1101, 17, 'Διαστήματα-Στόχοι Κλινικών Κανόνων'),
(63464, 1102, 17, 'Κλινικοί στόχοι'),
(63465, 1103, 17, 'Κλινικός Όρος'),
(63466, 1104, 17, 'Κωδικός Κλινικού Όρου'),
(63467, 1106, 17, 'Κλινικοί ιατροί'),
(63468, 1107, 17, 'Κλωνοποίηση'),
(63469, 1108, 17, 'Κλωνοποίηση παρελθούσας επίσκεψης'),
(63470, 1109, 17, 'Κλείσιμο'),
(63471, 1111, 17, 'Κλείσιμο παραθύρου'),
(63472, 1112, 17, 'Κλεισμένο'),
(63473, 1113, 17, 'εκατ.'),
(63474, 1114, 17, 'Περιθώρια του CSM 1500'),
(63475, 1118, 17, 'Κωδικός ταυτοπ. για το CSM 1500'),
(63476, 1127, 17, 'Κρανιακά νεύρα 2-12 ακέραια'),
(63477, 1128, 17, 'Συμμετοχή'),
(63478, 1129, 17, 'Η συμμετοχή πληρώθηκε'),
(63479, 1130, 17, 'ΣΥΜΜΕΤΟΧΗ'),
(63480, 1131, 17, 'Κωδικός'),
(63481, 1132, 17, 'κωδικός'),
(63482, 1133, 17, 'Εύρεση κωδικού'),
(63483, 1134, 17, 'Ο κωδικός πρέπει να είναι δύο μικρά γράμματα'),
(63484, 1135, 17, 'Κωδικός ή σύμβολο για να υποδείξετε το είδος νομίσματος'),
(63485, 1136, 17, 'Κείμενο κωδικού'),
(63486, 1138, 17, 'τύπος κωδικού'),
(63487, 1141, 17, 'Τύποι κωδικού'),
(63488, 1142, 17, 'Κωδικός'),
(63489, 1143, 17, 'Κωδικοποιημένο'),
(63490, 1144, 17, 'Κωδικοί'),
(63491, 1145, 17, 'Κωδικοποίηση'),
(63492, 1147, 17, 'Κωδικοποίηση – οποιαδήποτε επίσκεψη (εγγραφή, μερικά προαιρετικά)'),
(63493, 1148, 17, 'Κωδικοποίηση – οι επισκέψεις μου (εγγραφή, μερικα προαιρετικά)'),
(63494, 1149, 17, 'Η κωδικοποίηση δεν επιτρέπεται'),
(63495, 1150, 17, 'Καφές'),
(63496, 1152, 17, 'Συν-ασφάλιση'),
(63497, 1153, 17, 'Συνεργ με'),
(63498, 1154, 17, 'Σύμπτυξη'),
(63499, 1155, 17, 'σύμπτυξη'),
(63500, 1156, 17, 'Σύμπτυξη Όλων'),
(63501, 1157, 17, 'Σύμπτυξη όλων'),
(63502, 1158, 17, 'σύμπτυξη όλων'),
(63503, 1160, 17, 'Ημερομ. συλλογής'),
(63504, 1161, 17, 'Συλλογές'),
(63505, 1162, 17, 'Αναφορά συλλογών'),
(63506, 1163, 17, 'Καρκίνος παχέος εντέρου'),
(63507, 1164, 17, 'Έλεγχος για Καρκίνο παχέος εντέρου'),
(63508, 1165, 17, 'Εγχείριση καρκίνου παχέος εντέρου'),
(63509, 1166, 17, 'Κολονοσκόπηση'),
(63510, 1167, 17, 'κολονοσκόπηση'),
(63511, 1168, 17, 'Χρώμα'),
(63512, 1169, 17, 'Χρώμα:Συντμ'),
(63513, 1170, 17, 'Στήλη'),
(63514, 1171, 17, 'Στήλες'),
(63515, 1172, 17, 'Συνδυασμός παρτίδων'),
(63516, 1173, 17, 'Κόμμα'),
(63517, 1174, 17, 'Σχόλιο'),
(63518, 1175, 17, 'Σχόλια'),
(63519, 1176, 17, 'Σχόλια για αυτό το αποτέλεσμα ή τη σύσταση'),
(63520, 1177, 17, 'Εταιρεία εμπορικών ασφαλίσεων'),
(63521, 1178, 17, 'Απόπειρα αλλαγών'),
(63522, 1180, 17, 'Επικοινωνίες'),
(63523, 1182, 17, 'Εταιρεία'),
(63524, 1183, 17, 'Όνομα Εταιρείας'),
(63525, 1184, 17, 'Ολοκληρωμένο'),
(63526, 1186, 17, 'Ολοκληρώθηκε'),
(63527, 1188, 17, 'Ολοκληρώθηκε;'),
(63528, 1190, 17, 'Επιπλοκές ανά Πάροχο Υπηρεσιών'),
(63529, 1191, 17, 'Επιπλοκές Άμβλωσης'),
(63530, 1192, 17, 'Συστατικά'),
(63532, 1194, 17, 'Συμπεράσματα'),
(63533, 1199, 17, 'Ρύθμιση'),
(63534, 1200, 17, 'Εξαγωγή/ Εισαγωγή Ρυθμίσεων'),
(63535, 1202, 17, 'Ρύθμιση του Apache και του LibreEHR για χρήση πιστοποιητικών SSL από τη μεριά του Πελάτη'),
(63536, 1203, 17, 'Ρύθμιση του Apache για χρήση πιστοποιητικών SSL από τη μεριά του Πελάτη'),
(63537, 1204, 17, 'Ρύθμιση του Apache για χρήση HTTPS.'),
(63538, 1205, 17, 'Ρύθμιση του LibreEHR για χρήση πιστοποιητικών SSL από τη μεριά του Πελάτη'),
(63539, 1208, 17, 'Επιβεβαίωση δημιουργίας Νέου Ασθενούς'),
(63540, 1209, 17, 'Επιβεβαίωση Νέου Κωδικού'),
(63541, 1210, 17, 'Επιβεβαίωση Πληρωμής'),
(63542, 1214, 17, 'Συγγενής'),
(63543, 1215, 17, 'Επιπεφυκότες, κόρες'),
(63544, 1217, 17, 'Συνδέσεις'),
(63545, 1218, 17, 'Σταθερά'),
(63546, 1219, 17, 'όνομα σταθεράς'),
(63547, 1220, 17, 'Το όνομα της σταθεράς είναι κενό'),
(63548, 1221, 17, 'σταθερές'),
(63549, 1222, 17, 'Δυσκοιλιότητα'),
(63550, 1223, 17, 'Γενική κατάσταση'),
(63551, 1226, 17, 'Παρούσα Νόσος (Σύντομη αναφορά εκτίμησης)'),
(63552, 1227, 17, 'Επαφή'),
(63553, 1228, 17, 'Email της Επαφής'),
(63554, 1229, 17, 'Διεύθ. E-mail'),
(63555, 1231, 17, 'Πληροφ. Επικοινωνίας'),
(63556, 1232, 17, 'Φακοί επαφής'),
(63557, 1236, 17, 'Όνομα Επικοινωνίας'),
(63558, 1237, 17, 'Άτομο Επικοινωνίας'),
(63559, 1239, 17, 'Τηλέφωνο Επικοινωνίας'),
(63560, 1240, 17, 'Επικοινωνήστε με την ZMG LLC (zmghealth@gmail.com) για να εγγραφείτε στην υπηρεσία eRx'),
(63561, 1241, 17, 'συμπεριλάβετε τουλάχιστον 3 από τα ακόλουθα 4 αντικείμενα:'),
(63562, 1243, 17, 'Περιεχόμενο'),
(63563, 1244, 17, 'περιεχόμενο'),
(63564, 1245, 17, 'Πλαίσιο'),
(63565, 1246, 17, 'Το όνομα πλαισίου δεν μπορεί να είναι κενό'),
(63566, 1247, 17, 'Συνεχίστε'),
(63567, 1248, 17, 'Έγγραφο Συνέχισης Φροντίδας'),
(63568, 1249, 17, 'Εγγραφή Συνέχισης Φροντίδας'),
(63569, 1251, 17, 'Αντισύλληψη'),
(63570, 1252, 17, 'Θέματα αντισύλληψης'),
(63571, 1253, 17, 'Επιπλοκές αντισύλληψης'),
(63572, 1254, 17, 'Μέθοδος αντισύλληψης'),
(63573, 1255, 17, 'Προϊόντα αντισύλληψης'),
(63574, 1256, 17, 'Προηγούμενη έναρξη υπηρεσιών αντισύλληψης'),
(63575, 1257, 17, 'Έναρξη αντισυλληπτικών'),
(63576, 1258, 17, 'ID Ελέγχου'),
(63577, 1259, 17, 'Αριθμ. Ελέγχου'),
(63578, 1261, 17, 'ΣΥΜΜΕΤΟΧΗ'),
(63579, 1262, 17, 'Συμμετοχή στην πληρωμή'),
(63580, 1263, 17, 'Συμμετοχή στην πληρωμή'),
(63581, 1264, 17, 'Συμμετοχή μη θετικό'),
(63582, 1266, 17, 'Συμμετοχές'),
(63583, 1267, 17, 'ΧΑΠ'),
(63584, 1268, 17, 'Αντιγραφή Σελίδων στο Φάκελο ασθενούς'),
(63585, 1269, 17, 'Αντιγραφή Τιμών'),
(63586, 1270, 17, 'Αντιγραφή του αρχείου της βάσης Αυτό θα πάρει λίγο χρόνο...'),
(63587, 1271, 17, 'Σημείωμα περί Πνευματ. Δικαιωμάτων'),
(63588, 1273, 17, 'Αορτοστεφανιαία παράκαμψη'),
(63589, 1274, 17, 'Μόσχευμα Αορτοστεφανιαίας παράκαμψης'),
(63590, 1275, 17, 'Διορθώθηκε'),
(63591, 1277, 17, 'Βάση δεδομένων CouchDB'),
(63592, 1278, 17, 'Απέτυχε η σύνδεση με τη Βάση δεδομένων CouchDB'),
(63593, 1279, 17, 'Βάση δεδομένων CouchDB'),
(63594, 1280, 17, 'Όνομα της Βάσης δεδομένων CouchDB'),
(63595, 1281, 17, 'Ο host της Βάσης δεδομένων CouchDB'),
(63596, 1282, 17, 'Το όνομα του host της Βάσης δεδομένων CouchDB'),
(63597, 1283, 17, 'Ενεργοποίηση σύνδεσης με τη Βάση δεδομένων CouchDB'),
(63598, 1284, 17, 'Κωδικός πρόσβασης στη Βάση δεδομένων CouchDB'),
(63599, 1285, 17, 'Θύρα για τη Βάση δεδομένων CouchDB'),
(63600, 1286, 17, 'Θύρα για τη Βάση δεδομένων CouchDB'),
(63601, 1288, 17, 'Όνομα χρήστη στη Θύρα για τη Βάση δεδομένων CouchDB'),
(63602, 1289, 17, 'Βήχας'),
(63603, 1290, 17, 'Βήχας:'),
(63604, 1294, 17, 'Το αρχείο δεν μπορεί να διαβαστεί'),
(63605, 1296, 17, 'Το e-mail δεν μπορεί να σταλεί, λόγω προβλήματος του εξυπηρετητή, '),
(63606, 1297, 17, 'Το e-mail δεν μπορεί να σταλεί, λόγω προβλήματος του εξυπηρετητή, '),
(63607, 1298, 17, 'Δεν ήταν δυνατή δημιουργία καταλόγου με αντίγραφα ασφαλείας:'),
(63608, 1299, 17, 'Δεν ήταν δυνατή η διαγραφή καταλόγου dir:'),
(63609, 1300, 17, 'Αδύνατη η διαγραφή παλαιού φακέλου με αντίγραφα ασφαλείας:'),
(63610, 1301, 17, 'Δεν ήταν δυνατή η διαγραφή παλαιού αρχείου εξαγωγής:'),
(63611, 1302, 17, 'Χειρισμός αντιπηκτικής αγωγής - Παρακολούθηση INR'),
(63612, 1303, 17, 'Συμβουλευτική ανά μέθοδο'),
(63613, 1304, 17, 'Συμβουλευτική'),
(63614, 1305, 17, 'Συμβουλευτικές δραστηριότητες'),
(63615, 1306, 17, 'Έντυπο επιστρεφόμενων παραπομπών'),
(63616, 1307, 17, 'Επιστροφή παραπομπής'),
(63617, 1308, 17, 'Χώρα'),
(63618, 1309, 17, 'Τύπος δεδομένων Χώρας'),
(63619, 1310, 17, 'Λίστα χωρών'),
(63620, 1311, 17, 'Λίστα Χωρών (εγγραφή)'),
(63621, 1312, 17, 'Τό όνομα της χώρας πρέπει να συμβολίζεται με δύο γράμματα (πχ. η Ελλάδα είναι GR)'),
(63622, 1313, 17, 'Επαρχία'),
(63623, 1315, 17, 'Κουπόνι'),
(63624, 1318, 17, 'CPT'),
(63625, 1319, 17, 'Κωδικός CPT'),
(63626, 1320, 17, 'Κωδικοί CPT'),
(63627, 1321, 17, 'Διαδικασία/Υπηρεσία CPT4'),
(63628, 1322, 17, 'Μετρήσεις Επιδόσεων CPTΙΙ'),
(63629, 1323, 17, 'CQM'),
(63630, 1324, 17, 'Ρόγχοι:'),
(63631, 1325, 17, 'κρέμα (cream)'),
(63632, 1326, 17, 'Δημιουργία ενός πιστοποιητικού SSL για τον πελάτη για κάθε χρήστη ή μηχανή πελάτη.'),
(63633, 1327, 17, 'Δημιουργία ενός πιστοποιητικού SSL από τη πλευρά του πελάτη, για κάθε χρήστη ή για κάθε όνομα μηχανής πελάτη.'),
(63634, 1329, 17, 'Δημιουργία Συμβάντος'),
(63635, 1330, 17, 'Δημιουργία και κατέβασμα πλήρους αντιγράφου ασφαλείας'),
(63636, 1332, 17, 'Δημιουργία αντιγράφου ασφαλείας'),
(63637, 1333, 17, 'Δημιουργία δέσμης'),
(63638, 1334, 17, 'Δημιουργία Πιστοποιητικού Πελάτη'),
(63639, 1335, 17, 'Δημιουργία Πιστοποιητικών από την πλευρά του Πελάτη'),
(63640, 1336, 17, 'Δημιουργία αντιγράφου'),
(63641, 1338, 17, 'Δημιουργία αρχείου καταγραφής αντιγράφων ασφαλείας'),
(63642, 1339, 17, 'Δημιουργία νέου θέματος'),
(63643, 1340, 17, 'Δημιουργία Νέου Ασθενούς'),
(63644, 1342, 17, 'Δημιουργία Διαπιστευτηρίων Offsite Πύλης'),
(63645, 1343, 17, 'Δημιουργία Διαπιστευτηρίων Onsite Πύλης'),
(63646, 1344, 17, 'Δημιουργία Σημείωσης Ασθενούς'),
(63647, 1345, 17, 'Δημιουργία Εξουσιοδότησης Πιστοποιητικού SSL και πιστοποιητικών Εξυπηρετητή.'),
(63648, 1346, 17, 'Δημιουργία Επίσκεψης'),
(63649, 1347, 17, 'Δημιουργήθηκε'),
(63650, 1348, 17, 'Δημιουργία αρχείου εξαγωγής'),
(63651, 1350, 17, 'Η δημιουργία αυτού του αρχείου στον απομεμακρυσμένο host απέτυχε'),
(63652, 1351, 17, 'Δημιουργός'),
(63653, 1352, 17, 'πίστωση'),
(63654, 1353, 17, 'Πιστωτική Κάρτα'),
(63655, 1354, 17, 'Πιστώσεις'),
(63656, 1356, 17, 'Κριτήρια'),
(63657, 1358, 17, 'Νόσος του Crohn'),
(63658, 1359, 17, 'Νόσος του Crohn'),
(63659, 1360, 17, 'Εξαγωγή σε CSV'),
(63660, 1361, 17, 'Αρχείο CSV'),
(63661, 1362, 17, 'Πίνακες CSV'),
(63662, 1363, 17, 'κυβ. χιλιοστό'),
(63663, 1364, 17, 'Κουβανέζικα'),
(63664, 1365, 17, 'Δεκαδικά ψηφία νομίσματος'),
(63665, 1366, 17, 'Σύμβολο δεκαδικών ψηφίων νομίσματος'),
(63666, 1367, 17, 'Προσδιοριστής νομίσματος'),
(63667, 1368, 17, 'Διαχωριστικό χιλιάδων νομίσματος'),
(63668, 1369, 17, 'Τρέχουσα'),
(63669, 1370, 17, 'Τρέχουσα χρήση Αλκοόλ'),
(63670, 1371, 17, 'Τρέχουσα Εκτίμηση'),
(63671, 1372, 17, 'Τρέχοντα Κριτήρια'),
(63672, 1373, 17, 'Χρώμα τονισμού της τρέχουσας ημέρας'),
(63673, 1374, 17, 'Καθημερινός καπνιστής'),
(63674, 1375, 17, 'Το τρέχον άνομα αρχείου άλλαξε σε'),
(63675, 1376, 17, 'Τρέχον Hash'),
(63676, 1377, 17, 'Τρέχουσα Θέση'),
(63677, 1378, 17, 'Τρέχουσα Αγωγή'),
(63678, 1379, 17, 'Τρέχων Κωδικός'),
(63679, 1380, 17, 'Τρέχων Ασθενής'),
(63680, 1382, 17, 'Τρέχουσα χρήση εθιστικών ουσιών'),
(63681, 1383, 17, 'Περιστασιακός καπνιστής'),
(63682, 1386, 17, 'Τρεχόντως Ενεργός'),
(63683, 1387, 17, 'Εκτελείται τρεχόντως'),
(63684, 1388, 17, 'Τρεχόντως δεν υπάρχουν έδρες.'),
(63685, 1389, 17, 'Σύνδρομο Cushing'),
(63686, 1390, 17, 'Σύνδρομο Cushing'),
(63687, 1392, 17, 'Προσαρμοσμένος/η/ο'),
(63688, 1393, 17, 'Προσαρμοσμένη είσοδος;'),
(63689, 1394, 17, 'Προσαρμοσμένος Πίνακας'),
(63690, 1396, 17, 'Κωδικός CVX'),
(63691, 1397, 17, 'Χαρτογράφηση Κωδικού CVX'),
(63692, 1398, 17, 'Εμβολιασμός CVX'),
(63693, 1399, 17, 'Κύκλος'),
(63694, 1400, 17, 'Έτη προστασίας ζευγαριού (ΕΠΖ)'),
(63695, 1401, 17, 'Παράγοντας ΕΠΖ'),
(63696, 1402, 17, 'Αναφορά ΕΠΖ'),
(63697, 1403, 17, 'Τσεχικά'),
(63698, 1405, 17, 'Φάρμακα και Καλλυντικά'),
(63699, 1406, 17, 'Παρουσίαση και Αξιολόγηση'),
(63700, 1407, 17, 'Ημ. Γενν.'),
(63701, 1408, 17, 'ημερησίως'),
(63702, 1409, 17, 'Ημερήσια καταγραφή'),
(63703, 1410, 17, 'Δανέζικος'),
(63704, 1411, 17, 'Tα δεδομένα είναι ήδη στη βάση δεδομένων. Παρακαλώ αλλάξτε τον κωδικό και/ή την περιγραφή'),
(63705, 1412, 17, 'Tα δεδομένα είναι ήδη στη βάση δεδομένων. Παρακαλώ αλλάξτε το όνομα της σταθεράς'),
(63706, 1413, 17, 'Στήλες δεδομένων'),
(63707, 1416, 17, 'Σφάλμα δεδομένων'),
(63708, 1420, 17, 'Τύπος δεδομένων'),
(63709, 1421, 17, 'Βάση δεδομένων'),
(63710, 1422, 17, 'Η βάση δεδομένων δεν είναι εγκατεστημένη.'),
(63711, 1423, 17, 'Διορθωτικό patch της Βάσης δεδομένων'),
(63712, 1424, 17, 'Αναφορά βάσης δεδομένων'),
(63713, 1425, 17, 'Η αναβάθμιση της βάσης δεδομένων ολοκληρώθηκε.'),
(63714, 1426, 17, 'Τα Δεδομένα Στηλών πρέπει να είναι αριθμός μεταξύ 1 και 999'),
(63715, 1427, 17, 'Ημερομηνία'),
(63716, 1428, 17, 'ΗΜΕΡΟΜΗΝΙΑ'),
(63717, 1429, 17, 'Ημερομ. και χρόνος χορήγησης'),
(63718, 1431, 17, 'Ημερομ. χορήγησης'),
(63719, 1432, 17, 'Ημερομ. και ώρα συλλογής δείγματος'),
(63720, 1433, 17, 'Ημερομ. και ώρα αυτής της παρατήρησης'),
(63721, 1435, 17, 'Ημερομ. και ώρα που συνελέγη το δείγμα'),
(63722, 1436, 17, 'Η ημερομ. δεν μπορεί να είναι μεγαλύτερη από Σήμερα'),
(63723, 1437, 17, 'Αρχική Ημερομ. παροχής αντισυλληπτ. υπηρεσιών'),
(63724, 1438, 17, 'Ημερομ. δημιουγίας'),
(63725, 1439, 17, 'Ημερομ. θανάτου'),
(63726, 1440, 17, 'Ημερομ. καταστροφής'),
(63727, 1441, 17, 'Τρόπος εμφάνισης ημερομηνίας'),
(63728, 1442, 17, 'Ο τύπος ημερομ. για “τέλος ραντεβού” δεν είναι έγκυρος'),
(63729, 1443, 17, 'Ο τύπος ημερομ. για “έναρξη ραντεβού” δεν είναι έγκυρος'),
(63730, 1444, 17, 'Ο τύπος ημερομ. για “επόμενο ραντεβού” δεν είναι έγκυρος'),
(63731, 1445, 17, 'Ο τύπος ημερομ. για “μη εκτιμηθείς από” δεν είναι έγκυρος'),
(63732, 1446, 17, 'Ο τύπος ημερομ. για “εκτιμηθείς από” δεν είναι έγκυρος'),
(63733, 1447, 17, 'Δόθηκαν Πληροφορίες για Ημερομ. Εμβολιασμού'),
(63734, 1448, 17, 'Η ημερομ. για τον κωδικό λείπει '),
(63735, 1450, 17, 'Ημερομ. τραπεζικής κατάθεσης εεεε-μμ-ηη'),
(63736, 1451, 17, 'Ημερομ. χρέωσης'),
(63737, 1452, 17, 'Ημερομ. Γέννησης'),
(63738, 1453, 17, 'Ημερομ. γέννησης'),
(63739, 1454, 17, 'Ημερομ. Γέννησης'),
(63740, 1455, 17, 'Ημερομ. καταχώρησης'),
(63741, 1456, 17, 'Ημερομ. Κάκωσης'),
(63742, 1458, 17, 'Ημερομ. πληρωμής εεεε-μμ-ηη'),
(63743, 1459, 17, 'Ημερομ. παραπομπής'),
(63744, 1460, 17, 'Ημερομ. απάντησης'),
(63745, 1461, 17, 'Ημερομ. αναφοράς'),
(63746, 1462, 17, 'Ημερομ. παροχής της υπηρεσίας'),
(63747, 1463, 17, 'Ημερομ. παροχής της υπηρεσίας'),
(63748, 1464, 17, 'Ημερομ. παροχής της υπηρεσίας = Σήμερα'),
(63749, 1465, 17, 'Ημερομ. παροχής της υπηρεσίας μμ-ηη-εεεε'),
(63750, 1466, 17, 'Ημερομ. παροχής της υπηρεσίας:'),
(63751, 1467, 17, 'Ημερομ. Υπογραφής'),
(63752, 1468, 17, 'Ημερομ. αλλαγής κατάστασης'),
(63753, 1469, 17, 'Ημερομ, αυτής της εντολής'),
(63754, 1470, 17, 'Ημερομ. αυτής της αναφοράς'),
(63755, 1471, 17, 'Ημερομ. Έκδοσης Πληροφοριών Εμβολίων'),
(63756, 1472, 17, 'Ημερομ. Εντολής'),
(63757, 1475, 17, 'Σύστημα Επιλογής ημερομηνίας'),
(63758, 1476, 17, 'Ημερομ. αποστολής'),
(63759, 1477, 17, 'Ημερομ. Αποστολής Μηνύματος'),
(63760, 1479, 17, 'Οι τιμές Ημερομηνίας δεν μπορεί να είναι κενές.'),
(63761, 1480, 17, 'Ημερομ./Ραντεβού'),
(63762, 1481, 17, 'Ημερομ./Σημειώσεις'),
(63763, 1482, 17, 'Ημερομ./Πρόσφατες Σημειώσεις'),
(63764, 1483, 17, 'Ημερομ./Ώρα'),
(63765, 1484, 17, 'Ημερομηνία:'),
(63766, 1485, 17, 'Αρχείο καταγραφής ημερομ. των μηνυμάτων'),
(63767, 1486, 17, 'Ημέρα'),
(63768, 1487, 17, 'Ημέρα'),
(63769, 1489, 17, 'Προβολή Ημέρας'),
(63770, 1490, 17, 'Ημέρα(ες)'),
(63771, 1491, 17, 'Ημέρα(ες) Α-Θ'),
(63772, 1492, 17, 'Ημέρες'),
(63773, 1493, 17, 'Ημέρες'),
(63774, 1494, 17, 'ημέρες πριν'),
(63775, 1495, 17, 'Χαμένες ημέρες και παιχνίδια'),
(63776, 1496, 17, 'Ημέρες από την τελευταία επίσκεψη'),
(63777, 1497, 17, 'Ημέρες που απωλέσθηκαν'),
(63778, 1498, 17, 'Ημέρες ανά Στήλη:'),
(63779, 1500, 17, 'Ημέρες/Στήλη:'),
(63780, 1501, 17, 'Η βάση δεδομένων έχει εγκατασταθεί'),
(63781, 1502, 17, 'ΗΗ/ΜΜ/ΕΕΕΕ'),
(63782, 1503, 17, 'Αποταυτοποίηση'),
(63783, 1504, 17, 'Η διαδικασία αποταυτοποίησης τελείωσε'),
(63784, 1505, 17, 'Η διαδικασία αποταυτοποίησης ξεκίνησε'),
(63785, 1506, 17, 'Η διαδικασία αποταυτοποίησης άρχισε και τρέχει στο υπόβαθρο'),
(63786, 1507, 17, 'Τα δεδομένα αποταυτοποίησης δεν μπορούν να είναι πλήρη'),
(63787, 1508, 17, 'Τα αρχεία αποταυτοποίησης θα αποθηκευθούν'),
(63788, 1509, 17, 'Έλεγχος Φαρμάκων'),
(63789, 1511, 17, 'Κωφάλαλος'),
(63790, 1512, 17, 'Πληροφορίες αποσφαλμάτωσης'),
(63791, 1514, 17, 'Αποσφαλμάτωση'),
(63792, 1515, 17, 'Δεκ'),
(63793, 1516, 17, 'ΑΠΕΒΙΩΣΕ'),
(63794, 1517, 17, 'Δεκέμβριος'),
(63795, 1520, 17, 'Εκπιπτόμενο'),
(63796, 1522, 17, 'Προεπιλογή'),
(63797, 1523, 17, 'Προεπιλεγμ. Εμφάνιση Ημερολογίου'),
(63798, 1524, 17, 'Προεπιλεγμ. ID Εντύπου Επίσκεψης'),
(63799, 1526, 17, 'Προεπιλεγμένη Έδρα'),
(63800, 1527, 17, 'Προεπιλεγμένη Γλώσσα'),
(63801, 1528, 17, 'Προεπιλεγμ. Γλώσσα αν καμιά άλλη δεν επιτρέπεται ή δεν έχει επιλεχθεί'),
(63802, 1529, 17, 'Προεπιλεγμ. Λίστα (εγγραφή, προαιρετικά προσθήκη)'),
(63803, 1530, 17, 'Προεπιλεγμ. Μέθοδος'),
(63804, 1531, 17, 'Προεπιλεγμ. Ημέρες Λήξης Κωδικού'),
(63805, 1532, 17, 'Προεπιλεγμ. Περίοδος λήξης Κωδικού σε μέρες. Το 0 σημαίνει ότι αυτή η λειτουργία έχει απενεργοποιηθεί.'),
(63806, 1533, 17, 'Προεπιλεγμένη Χώρα Ασθενούς'),
(63807, 1535, 17, 'Προεπιεγμένη προτεραιότητα'),
(63808, 1536, 17, 'Προεπιλεγμένος Πάροχος'),
(63809, 1537, 17, 'Προεπιλεγμένο Εύρος'),
(63810, 1538, 17, 'Προεπιλεγμένη Αιτία Επίσκεψης'),
(63811, 1540, 17, 'Προεπιλεγμένη ρύθμιση'),
(63812, 1541, 17, 'Προεπιλεγμένη κατάσταση του κουτιού επλογής του Νέου Παραθύρου στη λίστα ασθενών.'),
(63813, 1542, 17, 'Προεπιλεγμένη διάταξη'),
(63814, 1546, 17, 'Προεπιλεγμένες Μονάδες'),
(63815, 1547, 17, 'Προεπιλεγμένη Τιμή'),
(63816, 1548, 17, 'Προεπιλεγμένη Αποθήκη'),
(63817, 1549, 17, 'Προεπιλεγμ. Χ12 συνεργάτης'),
(63818, 1550, 17, 'Προεπιλεγμ./ Γενικός'),
(63819, 1551, 17, 'Διαγρ'),
(63820, 1552, 17, 'διαγρ'),
(63821, 1553, 17, 'Καθυστερημένη υποτροπή (>12 μήνες)'),
(63822, 1554, 17, 'Διαγραφή'),
(63823, 1555, 17, 'διαγραφή'),
(63824, 1556, 17, 'Διαγραφή κατηγοριών με αναγνωριστικά: '),
(63825, 1557, 17, 'Διαγραφή Κατηγορίας'),
(63826, 1559, 17, 'Η διαγραφή απέτυχε!'),
(63827, 1560, 17, 'Διαγραφή Ομάδας'),
(63828, 1561, 17, 'Διαγραφή Λίστας'),
(63829, 1562, 17, 'Διαγραφή Σελίδων'),
(63830, 1563, 17, 'Διαγραφή Ασθενούς, Επίσκεψης, Εντύπου, Προβλήματος, Εγγράφου, Πληρωμής, Χρέωσης ή Συναλλαγής'),
(63831, 1565, 17, 'Διαγραφή γραμμής'),
(63832, 1566, 17, 'Διαγραφή επιλεγμένων αντικειμένων'),
(63833, 1568, 17, 'Διαγραφή επιτυχής'),
(63834, 1569, 17, 'Διαγραφή αυτού του εγγράφου'),
(63835, 1570, 17, 'Διαγραφή αυτής του εντύπου'),
(63836, 1571, 17, 'Διαγραφή αυτής της σημείωσης'),
(63837, 1573, 17, 'Διαγραφή επιτυχής.'),
(63838, 1574, 17, 'Γίνεται διαγραφή'),
(63839, 1575, 17, 'Η διαγραφή αυτού του συμβάντος δεν μπορεί να αντιστραφεί. Άπαξ και σβησθεί, δεν μπορεί να ανακτηθεί. Είστε σίγουροι ότι θέλετε να διαγράψετε αυτό το συμβάν;'),
(63840, 1576, 17, 'Η παράδοση επιβεβαιώθηκε'),
(63841, 1578, 17, 'Η παράδοση επί του παρόντος δεν επιτρέπεται στην καθορισμένη Άμεση Διεύθυνση.'),
(63842, 1580, 17, 'Η παράδοση του συνημμένου κλινικού εγγράφου ζητήθηκε από τον ασθενή.'),
(63843, 1581, 17, 'Άνοια'),
(63844, 1582, 17, 'Δημογραφικά'),
(63845, 1583, 17, 'Δημογραφικά (εγγραφή)'),
(63846, 1585, 17, 'Κριτήρια φίλτρου Δημογραφικών'),
(63847, 1586, 17, 'Δεν επιτρέπονται Δημογραφικά'),
(63848, 1587, 17, 'Δεν επιτρέπονται Δημογραφικά.'),
(63849, 1588, 17, 'Απερρίφθη'),
(63850, 1589, 17, 'Παρονομαστής'),
(63851, 1590, 17, 'Οδοντιατρικός'),
(63852, 1591, 17, 'Λίστα οδοντιατρικών θεμάτων'),
(63853, 1592, 17, 'Οδοντιατρ. προβλήματα'),
(63854, 1595, 17, 'Ανάλογα με τον τύπο λογαριασμού που δοκιμάζετε, θα δείτε ένα αποτέλεσμα τύπου HCFA σε μια κενή σελίδα για λογαριασμούς HCFA. Θα δείτε πολλές γραμμές μη κατανοητών χαρακτήρων και πληροφοριών αν δοκιμάσετε μια αίτηση X12. Αυτή είναι η μορφή X12 EDI 4010A. Περιστασιακά θα δείτε περίεργους χαρακτήρες που μοιάζουν με ντόμινο. Αυτοί είναι χαρακτήρες ελέγχου (π.χ. τροφοδοσίες σελίδας) και είναι φυσιολογικοί.'),
(63855, 1596, 17, 'Ημερομηνία Κατάθεσης'),
(63856, 1597, 17, 'Η ημερομηνία Κατάθεσης δεν μπορεί να είναι μεγαλύτερη από Σήμερα'),
(63857, 1598, 17, 'Ημερομηνία κατάθεσης:'),
(63858, 1599, 17, 'Καταθλιπτικό'),
(63859, 1600, 17, 'Κατάθλιψη'),
(63860, 1602, 17, 'Περιγραφή'),
(63861, 1603, 17, 'περιγραφή'),
(63862, 1605, 17, 'Περιγραφή της γνωστοποίησης'),
(63863, 1606, 17, 'Περιγραφή αυτής της διαδικασίας ή του κωδικού αποτελέσματος'),
(63864, 1607, 17, 'Μετάφραση περιγραφής'),
(63865, 1609, 17, 'Προορισμός'),
(63866, 1610, 17, 'Όνομα αρχείου προορισμού'),
(63867, 1611, 17, 'Απόσυρση παρτίδας'),
(63868, 1612, 17, 'Καταστροφή...'),
(63869, 1613, 17, 'Απεσύρθη'),
(63870, 1614, 17, 'Απόσυρση φαρμάκων'),
(63871, 1615, 17, 'Αναφορά απόσυρσης φαρμάκων'),
(63872, 1616, 17, 'Λεπτομέρεια'),
(63873, 1617, 17, 'Λεπτομέρειες'),
(63874, 1619, 17, 'Αναπτυξιακή ανωμαλία'),
(63875, 1620, 17, 'Διαβήτης'),
(63876, 1621, 17, 'Σακχαρώδης Διαβήτης'),
(63877, 1622, 17, 'Διαβήτης: Ρύθμιση Αρτηριακής Πίεσης (CQM)'),
(63878, 1623, 17, 'Διαβήτης: Οφθαλμολογικός Έλεγχος'),
(63879, 1624, 17, 'Διαβήτης: Οφθαλμολογικός Έλεγχος (CQM)'),
(63880, 1625, 17, 'Διαβήτης: Εξέταση Ποδιών'),
(63881, 1626, 17, 'Διαβήτης: Εξέταση Ποδιών (CQM)'),
(63882, 1627, 17, 'Διαβήτης: Ελλιπής Έλεγχος HbA1c (CQM)'),
(63883, 1628, 17, 'Διαβήτης: Αιμοσφαιρίνη A1C'),
(63884, 1629, 17, 'Διαβήτης: Ρύθμιση και Έλεγχος LDL'),
(63885, 1630, 17, 'Διαβήτης: Μικροαλβουμινουρία'),
(63886, 1631, 17, 'Διαγν'),
(63887, 1632, 17, 'Διαγνώσεις'),
(63888, 1633, 17, 'Διάγνωση'),
(63889, 1634, 17, 'Κωδικός Διάγνωσης'),
(63890, 1636, 17, 'Ημερομ. Διάγνωσης'),
(63891, 1637, 17, 'Η διάγνωση πρέπει να κωδικοποιηθεί στα πλαίσια μιας συνδεδεμένης επίσκεψης'),
(63892, 1638, 17, 'Όνομα Διάγνωσης'),
(63893, 1639, 17, 'Αναφορά Διάγνωσης'),
(63894, 1640, 17, 'Έκθεση για την διάγνωση'),
(63895, 1641, 17, 'Μόνο δημιουργία έκθεσης για τη διάγνωση'),
(63896, 1642, 17, 'Τίτλος Διάγνωσης'),
(63897, 1643, 17, 'Διάγνωση:'),
(63898, 1644, 17, 'Διάγνωση: '),
(63899, 1645, 17, 'Διαγνωστικοί έλεγχοι:'),
(63900, 1646, 17, 'Καλεί'),
(63901, 1647, 17, 'Διαφράγματα / Τραχηλικά Caps'),
(63902, 1648, 17, 'Διάρροια'),
(63903, 1650, 17, 'Υπαγόρευση'),
(63904, 1651, 17, 'Υπαγόρευση: '),
(63905, 1652, 17, 'Λάβατε το αντίγραφο της αίτησης χορήγησης ιατρικών δεδομένων;'),
(63906, 1653, 17, 'Διάχυτο:'),
(63907, 1654, 17, 'Ψηφιακά υπογεγραμμένο'),
(63908, 1657, 17, 'Άμεσο Ταχυδρομείο'),
(63909, 1658, 17, 'Log Άμεσου Ταχυδρομείου'),
(63910, 1659, 17, 'Ελήφθη άμεσο μήνυμα.'),
(63911, 1660, 17, 'Το σύστημα άμεσων μηνυμάτων δεν είναι τρεχόντως διαθέσιμο'),
(63912, 1661, 17, 'Όνομα Διευθυντού'),
(63913, 1663, 17, 'Όνομα Διευθυντού'),
(63914, 1664, 17, 'Απέτυχε η διαγραφή καταλόγου. Συνεχίζεται...'),
(63915, 1665, 17, 'Αναπηρία'),
(63916, 1667, 17, 'Απενεργοπ. Ημερολογίου'),
(63917, 1668, 17, 'Απενεργοπ. ευρετηρίου φακέλων'),
(63918, 1669, 17, 'Απενεργοπ. Εμβολιασμών'),
(63919, 1670, 17, 'Απενεργοπ. Εντύπου παλαιών μετρικών τιμών Ζωτικών'),
(63920, 1672, 17, 'Απενεργοπ. phpMyAdmin'),
(63921, 1673, 17, 'Απενεργοπ. Συνταγών'),
(63922, 1674, 17, 'Απενεργοπ. Ομάδων Χρηστών'),
(63923, 1675, 17, 'απενεργοποιημένο'),
(63924, 1676, 17, 'Aπενεργοποιημένο'),
(63925, 1678, 17, 'Εκπτωτική Κάρτα'),
(63926, 1681, 17, 'Έκκριμα'),
(63927, 1682, 17, 'Έκκριμα από την ουρήθρα'),
(63928, 1684, 17, 'Απαλλαγή από δικαιώματα'),
(63929, 1685, 17, 'Απαλλαγή από δικαιώματα:'),
(63930, 1689, 17, 'Πληροφορίες Γνωστοποίησης'),
(63931, 1690, 17, 'Τύπος Γνωστοποίησης'),
(63932, 1691, 17, 'Τύποι Γνωστοποίησης'),
(63933, 1692, 17, 'Γνωστοποιήσεις'),
(63934, 1694, 17, 'Έκπτωση'),
(63935, 1695, 17, 'Ποσό έκπτωσης'),
(63936, 1696, 17, 'Επίπεδο έκπτωσης'),
(63937, 1697, 17, 'Ποσοστό Εκπτωσης'),
(63938, 1698, 17, 'Εκπτώσεις σε ποσότητα νομίσματος'),
(63939, 1699, 17, 'Οι εκπτώσεις την ώρα της αποχώρησης εισάγονται σε ποσά χρήματος, σε αντίθεση με το ποσοστό.'),
(63940, 1700, 17, 'Διακριτό Αποτέλεσμα'),
(63941, 1701, 17, 'Νόσος'),
(63942, 1702, 17, 'Εξάρθρωμα'),
(63943, 1703, 17, 'Αριθ.αποστ'),
(63944, 1704, 17, 'Αποστολή'),
(63945, 1705, 17, 'Έγγραφό λήψης αποστολής'),
(63946, 1706, 17, 'Χορηγείται'),
(63947, 1707, 17, 'Εμφάνιση προκαταβολικών οδηγιών στη σελίδα δημογραφικών.'),
(63948, 1709, 17, 'Εμφάνιση ημερομ. συμβάντων στο block;'),
(63949, 1710, 17, 'Μορφή εμφάνισης για Βάρη US'),
(63950, 1711, 17, 'Πόσα συμβάντα να εμφανιστούν;'),
(63951, 1713, 17, 'Εμφάνιση θέσης στο block;'),
(63952, 1714, 17, 'Εμφάνιση Ονόματος'),
(63953, 1715, 17, 'Εμφάνιση ημερολογίου;'),
(63954, 1718, 17, 'Εμφάνιση σημερινών συμβάντων στο block;'),
(63955, 1719, 17, 'Εμφάνιση συμβάντος σε block;'),
(63956, 1720, 17, 'Εμφάνιση επερχόμενων συμβάντων στο block;'),
(63957, 1721, 17, 'Εμφανιζόμενες Στήλες'),
(63958, 1722, 17, 'Εμφάνιση του ακόλουθου αριθμού των πιο πρόσφατων γνωστοποιήσεων:'),
(63959, 1723, 17, 'Εμφάνιση του ακόλουθου αριθμού των πιο πρόσφατων σημειώσεων'),
(63960, 1724, 17, 'Εμφάνιση του ακόλουθου αριθμού των πιο πρόσφατων σημειώσεων:'),
(63961, 1725, 17, 'Κατανομή'),
(63962, 1726, 17, 'Κατανομές'),
(63963, 1727, 17, 'Διανομέας'),
(63964, 1729, 17, 'Εκκολπωματίτιδα'),
(63965, 1730, 17, 'Εγχείριση εκκολπωματίτιδας'),
(63966, 1731, 17, 'Εκκολπωματίτιδα'),
(63967, 1732, 17, 'Εγχείριση εκκολπωματίτιδας'),
(63968, 1733, 17, 'Διεζευγμένος/η'),
(63969, 1734, 17, 'Ζάλη:'),
(63970, 1735, 17, 'Μη το τροποποιήσετε'),
(63971, 1742, 17, 'Να μην εμφανίζεται το ημερολόγιο.'),
(63972, 1744, 17, 'Μην κάνετε απογραφή ούτε πώληση οποιωνδήποτε προϊόντων'),
(63973, 1745, 17, 'Μην απαιτείτε εξουσιοδότηση για τις σημειώσεις ασθενούς'),
(63974, 1746, 17, 'Εντολή για Μη Ανάνηψη'),
(63975, 1747, 17, 'να μην αποθηκευθεί'),
(63976, 1748, 17, 'να μην υποκατασταθεί'),
(63977, 1749, 17, 'καμία ενέργεια'),
(63978, 1751, 17, 'Θέλετε πραγματικά να διαγραφεί η επιλογή'),
(63979, 1752, 17, 'Θέλετε πραγματικά να διαγραφεί η επιλογή;'),
(63980, 1753, 17, 'Θέλετε πραγματικά να διαγραφεί αυτή η ομάδα'),
(63981, 1755, 17, 'Επιθυμείτε να συνεχίσετε;'),
(63982, 1756, 17, 'Επιθυμείτε να το διαγράψετε;'),
(63983, 1757, 17, 'Επιθυμείτε να διαγράψετε;'),
(63984, 1758, 17, 'Επιθυμείτε να αφαιρέσετε αυτήν την εγγραφή;'),
(63985, 1759, 17, 'Επιθυμείτε να συνεχίσετε την προσθήκη του νέου ασθενούς;'),
(63986, 1760, 17, 'Επιθυμείτε να συνεχίσετε με το νέο όνομα;'),
(63987, 1761, 17, 'Είστε σίγουροι ότι θέλετε να διαγραφεί ΜΟΝΙΜΑ αυτή η καταχώρηση εμβολιασμού;'),
(63988, 1762, 17, 'Ημερ. Γενν.'),
(63989, 1763, 17, 'Λείπει η Ημερ. Γενν. Αν μπορείτε εισάγετέ την'),
(63990, 1764, 17, 'Έγγραφα'),
(63991, 1765, 17, 'Ιατρός'),
(63992, 1766, 17, 'Ιατρός:'),
(63993, 1767, 17, 'Όνομα και Υπογραφή Ιατρού'),
(63994, 1768, 17, 'Έγγραφο'),
(63995, 1769, 17, 'εγγραφο'),
(63996, 1770, 17, 'Κατηγορίες Εγγράφων'),
(63997, 1775, 17, 'Το εγγραφο δεν μπορει να μεταφερθει στον κωδικό ασθενούς'),
(63998, 1777, 17, 'Ημερομ. εγγράφου'),
(63999, 1778, 17, 'Η ημερομηνία και το θέμα του εγγράφου ενημερώθηκαν επιτυχώς'),
(64000, 1779, 17, 'ID Εγγράφου'),
(64001, 1780, 17, 'Το έγγραφο μεταφέρθηκε σε νέα κατηγορία'),
(64002, 1781, 17, 'Το έγγραφο μεταφέρθηκε στον κωδικό ασθενούς'),
(64003, 1783, 17, 'Το αρχείο πέρασε το τεστ ακεραιότητας.'),
(64004, 1784, 17, 'Μέθοδος αποθήκευσης εγγράφων'),
(64005, 1785, 17, 'Το αρχείο μετονομάσθηκε επιτυχώς.'),
(64006, 1790, 17, 'Αποθήκ. Εγγράφου/ Εικόνας'),
(64007, 1791, 17, 'Έγγραφα'),
(64008, 1792, 17, 'Έγγραφα (εγγραφή, προαιρετ. προσθήκη)'),
(64009, 1794, 17, 'Ημερομ. Εισαγ.'),
(64010, 1797, 17, 'δεν μοιάζει να είνα έγκυρο'),
(64011, 1798, 17, 'Αυτός ο τύπος επιτρέπει σχετικούς κωδικούς;'),
(64012, 1799, 17, 'Συζεί'),
(64013, 1800, 17, 'Να μην αποθηκευθεί'),
(64014, 1801, 17, 'Να μην αποθηκευθεί'),
(64015, 1802, 17, 'Να μην αποθηκευθούν οι αλλαγές'),
(64016, 1803, 17, 'Έγινε'),
(64017, 1804, 17, 'Έγινε με:'),
(64018, 1805, 17, 'Έγινε. Θα σταλεί τώρα το download.'),
(64019, 1806, 17, 'Ημερομ. Εξέτασης'),
(64020, 1807, 17, 'Δοσολογία'),
(64021, 1809, 17, 'Κάντε διπλό κλικ για επεξεργασία'),
(64022, 1810, 17, 'Διπλωπία'),
(64023, 1811, 17, 'Κατέβασμα'),
(64024, 1814, 17, 'Κατέβασμα οπωσδήποτε'),
(64025, 1815, 17, 'Κατεβάστε το αρχείο χρέωσης, στείλτε το στο λογιστήριο και σημειώστε το ως χρεωθέν'),
(64026, 1817, 17, 'Κατέβασμα Πιστοποιητικών'),
(64027, 1818, 17, 'Κατέβασμα δεδομένων ρύθμισης'),
(64028, 1820, 17, 'κατέβασμα κρυπτογρφημένου αρχείου'),
(64029, 1825, 17, 'Μεταφόρτωση PDF'),
(64030, 1827, 17, 'Κατέβασμα επιλεγμένων καταστάσεων'),
(64031, 1828, 17, 'Ιατρ. Έλεγχος'),
(64032, 1829, 17, 'Ιατρ. Επίσκεψη'),
(64033, 1830, 17, 'Δρ.'),
(64034, 1831, 17, 'Σύρετε για να μετακινήσετε'),
(64035, 1832, 17, 'Ακούσια σιελόρροια'),
(64036, 1833, 17, 'Άδεια Οδήγησης ή Α.Δ. Ταυτότητος'),
(64037, 1834, 17, 'Φάρμακο'),
(64038, 1835, 17, 'Ευρετήριο φαρμάκων'),
(64039, 1836, 17, 'Τύποι φαρμάκου'),
(64040, 1837, 17, 'Λείπει ο κωδικός αναγνώρισης φαρμάκου!'),
(64041, 1838, 17, 'Διαστήματα δόσεων'),
(64042, 1839, 17, 'Απογραφή φαρμάκων'),
(64043, 1840, 17, 'Όνομα φαρμάκου'),
(64044, 1841, 17, 'Οδοί χορήγησης'),
(64045, 1845, 17, 'Μονάδες φαρμάκου'),
(64046, 1846, 17, 'Φάρμακα'),
(64047, 1847, 17, 'Φάρμακα και Προϊόντα'),
(64048, 1848, 17, 'Ξηροστομία'),
(64049, 1849, 17, 'Διάγνωση DSMIV'),
(64050, 1850, 17, 'DT 1'),
(64051, 1851, 17, 'DT 2'),
(64052, 1852, 17, 'DT 3'),
(64053, 1853, 17, 'DT 4'),
(64054, 1854, 17, 'DT 5'),
(64055, 1855, 17, 'DTaP 1'),
(64056, 1856, 17, 'DTaP 2'),
(64057, 1857, 17, 'DTaP 3'),
(64058, 1858, 17, 'DTaP 4'),
(64059, 1859, 17, 'DTaP 5'),
(64060, 1860, 17, 'Προβλέπεται να γίνει'),
(64061, 1861, 17, 'Ημερομ. κατά την οποία αναμένεται'),
(64062, 1862, 17, 'Ημερομ. κατά την οποία προβλέπεται μμ/ηη/εεε ή εεε-μμ-ηη'),
(64063, 1863, 17, 'Ημερομ. κατά την οποία προβλέπεται:'),
(64064, 1864, 17, 'Ημερομ. για την Ασφάλεια'),
(64065, 1865, 17, 'Αναμενόμ. ασθενής'),
(64066, 1866, 17, 'Αναμένεται σύντομα'),
(64067, 1867, 17, 'Αναμενόμενη κατάσταση'),
(64068, 1868, 17, 'Ενημέρωση της αναμενόμενης κατάστασης'),
(64069, 1869, 17, 'Καταγραφή της βάσης δεδομένων LibreEHR'),
(64070, 1870, 17, 'Καταγραφή του φακέλου LibreEHR web με μορφή δένδρου'),
(64071, 1871, 17, 'Καταγραφή της βάσης δεδομένων phpGACL'),
(64072, 1872, 17, 'Καταγραφή του φακέλου web με μορφή δένδρου phpGACL'),
(64073, 1873, 17, 'Καταγραφή της βάσης δεδομένων SQL-Ledger'),
(64074, 1874, 17, 'Καταγραφή του φακέλου web με μορφή δένδρου SQL-Ledger'),
(64075, 1875, 17, 'Ελεγχος διπλών καταγραφών'),
(64076, 1876, 17, 'Διπλοκαταχώρηση Κωδικού Ταυτοποίησης on line'),
(64077, 1877, 17, 'Διπλοκαταχωρημένο Όνομα on line'),
(64078, 1878, 17, 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ ΔΙΠΛΗΣ ΚΑΤΑΧΩΡΗΣΗΣ'),
(64079, 1879, 17, 'Πληρεξούσιο δικηγόρου'),
(64080, 1880, 17, 'διάρκεια'),
(64081, 1881, 17, 'Διάρκεια'),
(64082, 1882, 17, 'Ολλανδικά'),
(64083, 1884, 17, 'Δυσφαγία'),
(64084, 1885, 17, 'Δύσπνοια:'),
(64085, 1886, 17, 'Δυσουρία'),
(64086, 1888, 17, 'Ηλ. Συνταγογράφηση;'),
(64087, 1889, 17, 'e-Αναφορές'),
(64088, 1890, 17, 'Ηλεκτρ. Συνταγή'),
(64089, 1892, 17, 'Ανανέωση Ηλεκτρ. Συνταγής'),
(64090, 1893, 17, 'Ο κάθε αποδέκτης πρέπει να βλέπει τα δικά του μηνύματα όταν ολοκληρώσει.'),
(64091, 1894, 17, 'Πρώιμη υποτροπή (<2 μήνες)'),
(64092, 1895, 17, 'Ώτα'),
(64093, 1896, 17, 'ΗΚΓ'),
(64094, 1897, 17, 'eΑιτήματα'),
(64095, 1898, 17, 'Οίδημα'),
(64096, 1904, 17, 'Επεξεργασία'),
(64097, 1905, 17, 'επεξεργασία'),
(64098, 1906, 17, 'Επεξεργ. Αλλεργιών'),
(64099, 1907, 17, 'Επεξεργ. Κατηγοριών'),
(64100, 1908, 17, 'Επεξεργ. Ορισμών'),
(64101, 1909, 17, 'Επεξεργ. ορισμών'),
(64102, 1910, 17, 'Επεξεργ. Διαγνώσεων για'),
(64103, 1911, 17, 'Επεξεργ. γνωστοποίησης'),
(64104, 1912, 17, 'Επεξεργ. Εδρών'),
(64105, 1913, 17, 'Επεξεργ. Έδρας'),
(64106, 1914, 17, 'Επεξεργ. Πληροφοριών Έδρας'),
(64107, 1915, 17, 'Επεξεργασία πληροφοριών χρήστη ειδικά για κάποια από τις Έδρες'),
(64108, 1916, 17, 'Επεξεργ. αρχείου στο'),
(64109, 1917, 17, 'Επεξεργ. εντύπου'),
(64110, 1918, 17, 'Επεξεργ. Γενικών Ρυθμίσεων'),
(64111, 1919, 17, 'Μη εξουσιοδοτημένη επεξεργασία!'),
(64112, 1920, 17, 'Επεξεργ. εμφάνισης'),
(64113, 1921, 17, 'Επεξεργ. λίστας'),
(64114, 1922, 17, 'Επεξεργ. Πληρωμής'),
(64115, 1923, 17, 'Επεξεργ. Δομής'),
(64116, 1924, 17, 'Επεξεργ. Χρήστη'),
(64117, 1925, 17, 'Επεξ. Ρυθμ. Χρήστη'),
(64118, 1928, 17, 'Εκπαίδευση'),
(64119, 1929, 17, 'Ημερομ. εκπαίδευσης'),
(64120, 1931, 17, 'Αυτό το πρόγραμμα είναι ελεύθερο λογισμικό: Μπορείτε να το αναδιανείμετε και/ή να το τροποποιήσετε σύμφωνα με τους όρους της Γενικής Δημόσιας Άδειας Χρήσης GNU (GNU General Public License), όπως αυτοί δημοσιεύονται από το Ίδρυμα Ελεύθερου Λογισμικού (Free Software Foundation), είτε της έκδοσης 3 της Άδειας ή (κατά την επιλογή σας) οποιαδήποτε μεταγενέστερης έκδοσης. Αυτό το πρόγραμμα διανέμεται με την ελπίδα ότι θα είναι χρήσιμο, αλλά ΧΩΡΙΣ ΟΠΟΙΑΔΗΠΟΤΕ ΕΓΓΥΗΣΗ, ακόμα και χωρίς την υπονοούμενη εγγύηση της ΕΜΠΟΡΕΥΣΙΜΟΤΗΤΑΣ ή ΚΑΤΑΛΛΗΛΟΤΗΤΑΣ ΓΙΑ ΣΥΓΚΕΚΡΙΜΕΝΟ ΣΚΟΠΟ. Δείτε την Γενική Δημόσια Άδεια Χρήσης GNU για περισσότερες λεπτομέρειες. Πρέπει να έχετε λάβει ένα αντίγραφο της Γενικής Δημόσιας Άδειας Χρήσης GNU μαζί με αυτό το πρόγραμμα. Αν δεν έχετε λάβει ένα αντίγραφο, τότε δείτε στο <http://www.gnu.org/licenses/>. '),
(64121, 1932, 17, 'Ενεργός ημερομηνία'),
(64122, 1934, 17, 'Αποτελεσματικότητα'),
(64123, 1935, 17, 'Κωδικός Αριθμός Εργαζόμενου/Εργοδότη'),
(64124, 1936, 17, 'Εκσπερματώσεις'),
(64125, 1937, 17, 'Αγκώνας'),
(64126, 1938, 17, 'Προβλήμ. αγκώνος'),
(64127, 1939, 17, 'Ηλεκτρονικός'),
(64128, 1942, 17, 'Ηλεκτρον. εμβάσματα'),
(64129, 1943, 17, 'Ηλεκτρον. αναφορές');
INSERT INTO `lang_definitions` VALUES
(64130, 1944, 17, 'Αρμοδιότητα'),
(64131, 1946, 17, 'Απάντηση αρμοδιότητας'),
(64132, 1948, 17, 'Επιλέξιμος'),
(64133, 1949, 17, 'E-mail'),
(64134, 1951, 17, 'Διεύθυνση E-mail'),
(64135, 1953, 17, 'Διεύθυνση e-mail του αποστολέα, για υπενθυμίσεις προς τους ασθενείς. Απαντήσεις στις υπενθυμίσεις προς τους ασθενείς θα απευθύνονται σε αυτήν τη διεύθυνση. Είναι σημαντικό να χρησιμοποιείται μια διεύθυνση από το domain της κλινικής σας, για να μην καταλήγουν οι υπενθυμίσεις προς τους ασθενείς στο φάκελο ανεπιθύμητων μηνυμάτων.'),
(64136, 1954, 17, 'Διεύθυνση e-mail (αν υπάρχει) για λήψη διοικητικών ειδοποιήσεων.'),
(64137, 1955, 17, 'Διεύθυνση e-mail (αν υπάρχει) για λήψη μυνημάτων επείγουσας ενεργοποίησης σύνδεσης χρήστη'),
(64138, 1956, 17, 'Εξουσιοδ E-mail'),
(64139, 1957, 17, 'E-mail από δέσμη ενεργειών'),
(64140, 1958, 17, 'Ειδοποίηση e-mail'),
(64141, 1959, 17, 'Ωρες ειδοποίησης με e-mail'),
(64142, 1960, 17, 'Αναφορά ειδοποιήσεων με e-mail'),
(64143, 1961, 17, 'Το e-mail να σταλεί πριν από'),
(64144, 1962, 17, 'Αποστολέας e-mail'),
(64145, 1963, 17, 'Το e-mail εστάλη'),
(64146, 1964, 17, 'Το e-mail εστάλη στον/στην'),
(64147, 1965, 17, 'Θέμα e-mail'),
(64148, 1966, 17, 'Κείμενο e-mail, χρησιμοποιήσιμη Ετικέτα: ***ΟΝΟΜΑ*** , π.χ. Αγαπητέ/ή ***ΟΝΟΜΑ***'),
(64149, 1967, 17, 'Κείμενο e-mail, χρησιμοποιήσιμη Ετικέτα: ***ΟΝΟΜΑ*** , π.χ. Αγαπητέ/ή ***ΟΝΟΜΑ***{{Μη μεταφράζετε τα στοιχεία στο ***ΟΝΟΜΑ*** αυτής της σταθεράς.}}'),
(64150, 1968, 17, 'Μέθοδος μεταφοράς e-mail'),
(64151, 1969, 17, 'Το e-mail εστάλη στην ακόλουθη διεύθυνση'),
(64152, 1971, 17, 'Επαφή έκτακτης ανάγκης'),
(64153, 1972, 17, 'Άτομο επικοινωνίας έκτακτης ανάγκης'),
(64154, 1973, 17, 'Τηλέφωνο επικοινωνίας έκτακτης ανάγκης'),
(64155, 1974, 17, 'Επείγουσα αντισύλληψη'),
(64156, 1975, 17, 'Επείγουσα σύνδεση'),
(64157, 1976, 17, 'Επιλέχθηκε η Επείγουσα σύνδεση ACL. Ο χρήστης είναι ακόμα σε ενεργό κατάσταση. Παρακαλώ απενεργοποιήστε το χρήστη και ενεργοποιήστε τον πάλι, εφόσον απαιτείται, σε επείγουσες καταστάσεις. Επισκεφθείτε το Διαχείριση->Χρήστες για ενεργοποίηση, ή απενεργοποίηση.'),
(64158, 1977, 17, 'Το e-mail ενεργοποίησης Επείγουσας Σύνδεσης θα διανεμηθεί μόνο εάν έχουν γίνει οι παρακάτω ρυθμίσεις στο αρχείο interface/globals.php:'),
(64159, 1978, 17, 'Διεύθυνση e-mail επείγουσας σύνδεσης'),
(64160, 1979, 17, 'Ο χρήστης Επείγουσας Σύνδεσης μπορεί να κάνει ο,τιδήποτε'),
(64161, 1980, 17, 'Τηλέφωνο έκτακτης ανάγκης'),
(64162, 1981, 17, 'Συγκινησιακές/ Συμπεριφορικές Καταστάσεις & Επιπλοκές'),
(64163, 1982, 17, 'Εμφύσημα'),
(64164, 1983, 17, 'Εργαζόμενος'),
(64165, 1984, 17, 'Εργοδότης'),
(64166, 1985, 17, 'Διεύθυνση εργοδότη'),
(64167, 1986, 17, 'Δεδομένα εργοδότη'),
(64168, 1987, 17, 'Όνομα εργοδότη'),
(64169, 1988, 17, 'ΚΕΝΟ'),
(64170, 1989, 17, 'Κενό'),
(64171, 1990, 17, 'Δεν επιτρέπεται κενός κωδικός'),
(64172, 1991, 17, 'Κενή τιμή στο "Ώρες Email"'),
(64173, 1992, 17, 'Κενή τιμή στο "Αποστολέα Email"'),
(64174, 1993, 17, 'Κενή τιμή στο "Θέμα Email"'),
(64175, 1994, 17, 'Κενή τιμή στο "Κείμενο Email"'),
(64176, 1995, 17, 'Κενή τιμή στο "Όνομα του Παρόχου"'),
(64177, 1996, 17, 'Κενή τιμή στον "Κωδικό πρόσβασης"'),
(64178, 1997, 17, 'Κενή τιμή στο "Ώρες SMS"'),
(64179, 1998, 17, 'Κενή τιμή στο "Κείμενο SMS"'),
(64180, 1999, 17, 'Κενή τιμή στο "Όνομα Χρήστη"'),
(64181, 2006, 17, 'Ενεργοποίηση Προτροπής Αυτόματων Υπολογισμών Μετρήσεων'),
(64182, 2008, 17, 'Ενεργοποίηση Αναφοράς Αυτόματων Υπολογισμών Μετρήσεων'),
(64183, 2009, 17, 'Ενεργοποίηση Παρακολούθησης Αυτόματων Υπολογισμών Μετρήσεων'),
(64184, 2015, 17, 'Ενεργοποίηση Αναφοράς Αυτόματων Υπολογισμών Μετρήσεων'),
(64185, 2016, 17, 'Ενεργοποίηση SSL Πελάτη'),
(64186, 2017, 17, 'Ενεργοποίηση Επιβεβαίωσης του πιστοποιητικού SSL Πελάτη'),
(64187, 2019, 17, 'Ενεργοποίηση Κανόνων Κλινικών Αποφάσεων'),
(64188, 2022, 17, 'Ενεργοποίηση Αναφοράς Κλινικών Ποιοτικών Μετρήσεων (CQM)'),
(64189, 2023, 17, 'Ενεργοποίηση Popup Κλινικής Υπενθύμισης'),
(64190, 2024, 17, 'Ενεργοποίηση Widget Κλινικής Υπενθύμισης'),
(64191, 2027, 17, 'Ενεργοποίηση Αναφοράς Κλινικών Ποιοτικών Μετρήσεων (CQM)'),
(64192, 2030, 17, 'Ενεργοποίηση χρέωσης αμοιβής στο αριστερό μενού'),
(64193, 2031, 17, 'Ενεργοποίηση Υποστήριξης Hylafax'),
(64194, 2037, 17, 'Ενεργοποίηση Ανταλλαγής Εργαστηριακών'),
(64195, 2039, 17, 'Ενεργοποίηση αρχείου καταγραφής για μεταφορτώσεις (uploads-downloads) στην CouchDB'),
(64196, 2040, 17, 'Ενεργοποίηση καταγραφής όλων των SQL SELECT ερωτημάτων.'),
(64197, 2041, 17, 'Ενεργοποίηση καταγραφής των δραστηριοτήτων που σχετίζονται με λήψη αντγράφων ασφαλείας'),
(64198, 2043, 17, 'Ενεργοποίηση καταγραφής διαφόρων δραστηριοτήτων.'),
(64199, 2044, 17, 'Ενεργοποίηση καταγραφής του backup δραστηριοτήτων παραγγελιών.'),
(64200, 2045, 17, 'Ενεργοποίηση καταγραφής των τροποποίσεων εγγραφών ασθενών.'),
(64201, 2046, 17, 'Ενεργοποίηση καταγραφής των δραστηριοτήτων προγραμματισμού.'),
(64202, 2047, 17, 'Ενεργοποίηση καταγραφής δραστηριοτήτων ασφαλείας και διεύθυνσης.'),
(64203, 2051, 17, 'Ενεργοποίηση Οffsite Πύλης Ασθενή'),
(64204, 2052, 17, 'Ενεργοποίηση Οffsite Πύλης Ασθενή.'),
(64205, 2053, 17, 'Ενεργοποίηση Οnsite Πύλης Ασθενή'),
(64206, 2055, 17, 'Ενεργοποίηση Οnsite Πύλης Ασθενή.'),
(64207, 2056, 17, 'Ενεργοποίηση Widget Υπενθύμισης Ασθενή'),
(64208, 2058, 17, 'Ενεργοποίηση Προτροπής Δεδομένων Αυτόματων Υπολογισμών Μετρήσεων'),
(64209, 2060, 17, 'Ενεργοποίηση Αναφοράς Αυτοματοποιημένης Υπολογισμών'),
(64210, 2061, 17, 'Ενεργοποίηση Παρακολούθησης Αυτοματοποιημένης Υπολογισμών'),
(64211, 2065, 17, 'Ενεργοποίηση της υπηρεσίας υποστήριξης του LibreEHR LLC Ανταλλαγής Εργαστηρ. αποτελεσμάτων'),
(64212, 2066, 17, 'Ενεργοποίηση Επιβεβαίωσης του Πιστοπ. Χρήστη'),
(64213, 2067, 17, 'Ενεργοποίηση της υπηρεσίας ZMG, LLC eRx'),
(64214, 2068, 17, 'ενεργοποιήθηκε'),
(64215, 2070, 17, 'Ενεργοποιεί το παλιό πάνελ Χρεώσεων, για εισαγωγή κωδικών χρέωσης και πληρωμών. Δεν συνιστάται, χρησιμοποιήστε αντ'' αυτού το Έντυπο Αμοιβής.'),
(64216, 2071, 17, 'Επισκ.'),
(64217, 2072, 17, 'Επίσκεψη'),
(64218, 2073, 17, 'Επίσκεψη'),
(64219, 2074, 17, 'επίσκεψη'),
(64220, 2075, 17, 'Επίσκεψη '),
(64221, 2076, 17, 'Επίσκεψη σε θερμό περιστατικό νοσηλευόμενου ασθενούς'),
(64222, 2081, 17, 'Ημερομ. Επίσκεψης'),
(64223, 2086, 17, 'Έντυπα επίσκεψης'),
(64224, 2087, 17, 'Επίσκεψη με εκτίμηση υγείας και συμπεριφοράς'),
(64225, 2088, 17, 'Ιστορικό επίσκεψης'),
(64226, 2089, 17, 'Κωδικός επίσκεψης'),
(64227, 2090, 17, 'Επίσκεψη Γρίππη'),
(64228, 2091, 17, 'Αριθμός επίσκεψης'),
(64229, 2093, 17, 'επίσκεψη για ετοιμασία εξιτηρίου από τη νοσηλευτική πλευρά'),
(64230, 2094, 17, 'επίσκεψη νοσηλευτικής έδρας'),
(64231, 2095, 17, 'επίσκεψη εργοθεραπείας'),
(64232, 2096, 17, 'επίσκεψη γραφείου'),
(64233, 2097, 17, 'επίσκεψη εξωτερ. ιατρείου'),
(64234, 2099, 17, 'Μέγεθος Σελίδας Επίσκεψης'),
(64235, 2100, 17, 'Πληρωμή επίσκεψης'),
(64236, 2101, 17, 'επίσκεψη εγκυμοσύνης'),
(64237, 2102, 17, 'επίσκεψη προληπτικής ιατρικής - ατομικής συμβουλευτικής'),
(64238, 2103, 17, 'επίσκεψη προληπτικής ιατρικής 40 και άνω'),
(64239, 2104, 17, 'επίσκεψη προληπτικής ιατρικής και ομαδικής συμβουλευτικής'),
(64240, 2105, 17, 'επίσκεψη προληπτικής ιατρικής λοιπές υπηρεσίες'),
(64241, 2106, 17, 'επίσκεψη προληπτικής ιατρικής 18 και άνω'),
(64242, 2107, 17, 'επίσκεψη ψυχολογική και ψυχιατρική'),
(64243, 2108, 17, 'Στατιστικά επισκέψεων'),
(64244, 2109, 17, 'Σύνοψη επισκέψεων'),
(64245, 2110, 17, 'Η επίσκεψη κωδικοποιήθηκε'),
(64246, 2111, 17, 'Επίσκεψη:'),
(64247, 2112, 17, 'Επίσκεψη: μη-οξεία νοσηλεία, εξωτερ. ιατρείων, ή οφθαλμιατρική'),
(64248, 2113, 17, 'Επισκέψεις'),
(64249, 2114, 17, 'Επισκέψεις και Έντυπα'),
(64250, 2115, 17, 'Επισκέψεις και Έντυπα'),
(64251, 2116, 17, 'Μη εγκεκριμμένες επισκέψεις'),
(64252, 2117, 17, 'Αναφορά επισκέψεων'),
(64253, 2118, 17, 'Τμήμα επισκέψεων'),
(64254, 2120, 17, 'Κρυπτογράφηση'),
(64255, 2121, 17, 'Τέλος'),
(64256, 2122, 17, 'Τέλος (εεεε-μμ-ηη) '),
(64257, 2123, 17, 'Ημερομ. Λήξης'),
(64258, 2124, 17, 'Ημερομ. λήξης'),
(64259, 2126, 17, 'Η ημερομ. λήξης πρέπει να έπεται της ημερομ. έναρξης'),
(64260, 2127, 17, 'Ημερομ. λήξης:'),
(64261, 2131, 17, 'Ώρα λήξης'),
(64262, 2132, 17, 'Νεφρική Ανεπάρκεια Τελικού Σταδίου, Δικαιούχος MCP με ένα Ομαδικό Πλάνο του Εργοδότη'),
(64263, 2133, 17, 'Ημερομ. λήξης της υπηρεσίας εεεε-μμ-ηη'),
(64264, 2134, 17, 'Τελική Ημερ.Υπηρεσίας μμ/ηη/εεε εάν επιθυμείτε να εισάγετε ένα εύρος.'),
(64265, 2135, 17, 'Ώρα λήξης για γεγονότα ημερολογίου.'),
(64266, 2136, 17, 'Ενδοκοιλιακό αίμα'),
(64267, 2137, 17, 'Ενδοκρινικό'),
(64268, 2138, 17, 'Ενδοσκόπηση'),
(64269, 2141, 17, 'Αγγλικά'),
(64270, 2142, 17, 'Αγγλικά '),
(64271, 2143, 17, 'Αγγλικά (Ινδικά)'),
(64272, 2144, 17, 'Αγγλικά (Standard)'),
(64273, 2146, 17, 'Βεβαιωθείτε ότι το LibreEHR έχει δικαιώματα εγγραφής σε αυτόν τον κατάλογο'),
(64274, 2147, 17, 'Έκκριμα ΩΡΛ'),
(64275, 2148, 17, 'Πόνος ΩΡΛ'),
(64276, 2149, 17, 'Εισάγετε έναν κωδικό διάγνωσης για την εξαίρεση όλων των τιμολογίων που δεν τον περιέχουν'),
(64277, 2151, 17, 'Εισάγετε το κείμενο της επιστολής εδώ'),
(64278, 2152, 17, 'Εισάγετε τον κωδικό διαχειριστή (root) της βάσης δεδομένων'),
(64279, 2153, 17, 'Εισάγετε το όνομα χρήστη του διαχειριστή (root) της βάσης δεδομένων'),
(64280, 2154, 17, 'Εισαγωγή Διάγνωσης'),
(64281, 2155, 17, 'Εισαγωγή Φαρμάκου'),
(64282, 2156, 17, 'Εισαγωγή επίσκεψης'),
(64283, 2157, 17, 'Εισαγωγή Αριθμού επίσκεψης'),
(64284, 2158, 17, 'Εισαγωγή Εμβολίιων'),
(64285, 2159, 17, 'Πλήκτρο Enter'),
(64286, 2161, 17, 'Εισαγωγή νέας Πολιτείας'),
(64287, 2162, 17, 'Εισαγωγή άμεσης διεύθυνσης παραλήπτη'),
(64288, 2164, 17, 'Εισάγετε τον Κωδικό Αναγνώρισης'),
(64289, 2165, 17, 'Εισάγετε τα κριτήρια αναζήτησής σας παραπάνω'),
(64290, 2166, 17, 'Εισήχθη κατά λάθος'),
(64291, 2167, 17, 'καταχωρήσεις'),
(64292, 2168, 17, 'Περιβαλλοντικό'),
(64293, 2169, 17, 'Εισαγ. δεδομένων για Εμβάσματα Πληρωμών (ΕΟΒ)'),
(64294, 2170, 17, 'Αποστολή δεδομένων για Εμβάσμ. Πληρωμής (ΕΟΒ) – Ηλεκτρον. Αποστολή'),
(64295, 2171, 17, 'Αποστολή δεδομένων για Εμβάσμ. Πληρωμής (ΕΟΒ) – Οδηγίες'),
(64296, 2172, 17, 'Αποστολή δεδομένων για Εμβάσμ. Πληρωμής (ΕΟΒ) – Απόδειξη'),
(64297, 2173, 17, 'Αποστολή δεδομένων για Εμβάσμ. Πληρωμής (ΕΟΒ) – Σημείωση ασθενούς'),
(64298, 2174, 17, 'Αποστολή δεδομένων για Εμβάσμ, Πληρωμής (ΕΟΒ) – Αναζήτηση'),
(64299, 2176, 17, 'Επιληψία'),
(64300, 2178, 17, 'ERA'),
(64301, 2179, 17, 'Αρχεία ERA'),
(64302, 2181, 17, 'Διαγραφή'),
(64303, 2182, 17, 'Στύσεις'),
(64304, 2183, 17, 'Σφάλμα'),
(64305, 2185, 17, 'Σφάλμα στην επιβεβαίωση λήψης εργαστηρ. αποτελεσμάτων'),
(64306, 2187, 17, 'Σφάλμα στην λήψη εργαστηρ. αποτελεσμ. από το Δίκτυο Ανταλλαγής του Εργαστηρίου'),
(64307, 2188, 17, 'Σφάλμα στην επιλογή "Ισότητα”'),
(64308, 2189, 17, 'Σφάλμα στην επιλογή "HIPAA"'),
(64309, 2190, 17, 'Σφάλμα στην επιλογή "Διαδικασία"'),
(64310, 2191, 17, 'Σφάλμα στην επιλογή "SMS Gateway"'),
(64311, 2192, 17, 'Σφάλμα στην επιλογή "Ταξινόμησε κατά”'),
(64312, 2193, 17, 'Σφάλμα συμπίεσης gzip του αρχείου: '),
(64313, 2194, 17, 'Σφάλμα στην επιλογή ΝΑΙ ή ΟΧΙ'),
(64314, 2195, 17, 'Σφάλμα κατά το άνοιγμα του ανεβασμένου αρχείου ανάγνωσης'),
(64315, 2196, 17, 'Σφάλμα κατά την επεξεργασία αρχείου'),
(64316, 2197, 17, 'Σφάλμα κατά την επεξεργασία του upload'),
(64317, 2198, 17, 'Σφάλμα κατά τη Διαγραφή του Μηνύματος'),
(64318, 2199, 17, 'Σφάλμα κατά την ανάκτηση αποτελεσμάτων από το Δίκτυο Ανταλλαγής Εργαστηριακών'),
(64319, 2200, 17, 'Σφάλμα κατά την ανάκτηση τιμών'),
(64320, 2202, 17, 'Σφάλμα κατά την απόδοση δικαιωμάτων αρχείου στον χρήστη LibreEHR'),
(64321, 2205, 17, 'Σφάλμα κατά την καταχώρηση του εντύπου!'),
(64322, 2206, 17, 'Σφάλμα κατά την αποθήκευση στο αρχείο'),
(64323, 2208, 17, 'Σφάλμα κατά την εγγραφή σε αρχείο'),
(64324, 2209, 17, 'εντοπίσθηκε σφάλμα(τα) από τα νέα αποτελέσματα'),
(64325, 2210, 17, 'Σφάλμα, το αρχείο δεν υπάρχει'),
(64326, 2211, 17, 'ΣΦΑΛΜΑ, αδύνατη η συλλογή δεδομένων από τον εξυπηρετητή'),
(64327, 2212, 17, 'Σφάλμα, αδύνατη η δημιουργία πιστοπ. χρήστη.'),
(64328, 2213, 17, 'Σφάλμα, αδύνατη η δημιουργία του πιστοπ. admin.p12.'),
(64329, 2214, 17, 'Σφάλμα, αδύνατη η δημιουργία του πιστοπ. Εξουσιοδ. Πιστοποιητικού.'),
(64330, 2215, 17, 'Σφάλμα, αδύνατη η δημιουργία πιστοποιητικού Εξυπηρετητή.'),
(64331, 2216, 17, 'Σφάλμα, αδύνατο το άνοιγμα αρχείου'),
(64332, 2217, 17, 'Σφάλμα, αδύνατη η δημιουργία πιστοπ. γνησιότητος χρήστη.'),
(64333, 2218, 17, 'Σφάλμα. Χρειάζεται να εγκατασταθεί το Archive/Tar.php php module.'),
(64334, 2219, 17, 'ΣΦΑΛΜΑ: αδύνατο το άνοιγμα του table.sql, εσφαλμένο έντυπο?'),
(64335, 2220, 17, 'Σφάλμα: διπλός κωδικός στη γραμμή'),
(64336, 2221, 17, 'Σφάλμα: διπλό όνομα στη γραμμή'),
(64337, 2222, 17, 'ΣΦΑΛΜΑ: Πεδίο'),
(64338, 2223, 17, 'ΣΦΑΛΜΑ: Απουσιάζει το ZipArchive PHP Module'),
(64339, 2224, 17, 'ΣΦΑΛΜΑ: Δεν υπάρχει κατάλογος εισαγωγής ICD'),
(64340, 2225, 17, 'Σφάλμα: οι κωδικοί δεν συμφωνούν. Παρακαλώ ελέγξτε την πληκτρολόγηση σας.'),
(64341, 2226, 17, 'Σφάλμα: οι κωδικοί δεν συμφωνούν. Παρακαλώ ελέγξτε την πληκτρολόγηση σας.'),
(64342, 2227, 17, 'Σφάλμα: το αρχείο δεν υπάρχει'),
(64343, 2228, 17, 'ΣΦΑΛΜΑ: Η ακόλουθη μεταβλητή περιέχει μη αποδεκτούς χαρακτήρες'),
(64344, 2229, 17, 'ΣΦΑΛΜΑ: Αδύνατον να αντιγραφεί το αρχείο'),
(64345, 2230, 17, 'Σφάλμα: Αδύνατη η δημιουργία αρχείου προς κατέβασμα'),
(64346, 2231, 17, 'ΣΦΑΛΜΑ: Αδύνατο να δημιουργηθεί το ZIP αρχείο.'),
(64347, 2232, 17, 'ΣΦΑΛΜΑ: Αδύνατον να αποσυμπιεστεί το αρχείο.'),
(64348, 2233, 17, 'ΣΦΑΛΜΑ: Αδύνατον να φορτωθεί το αρχείο στη βάση δεδομένων.'),
(64349, 2234, 17, 'ΣΦΑΛΜΑ: Αδύνατον να τεθεί ο αριθμός έκδοσης.'),
(64350, 2235, 17, 'Σφάλματα'),
(64351, 2236, 17, 'Κατάσταση του λογαριασμού eRx'),
(64352, 2237, 17, 'Αρχείο καταγραφής eRx'),
(64353, 2238, 17, 'Όνομα eRx'),
(64354, 2239, 17, 'Κωδικός πρόσβασης στο eRx'),
(64355, 2240, 17, 'Ρόλος του eRx'),
(64356, 2241, 17, 'Χρήστης του eRx'),
(64357, 2242, 17, 'Ερύθημα:'),
(64358, 2245, 17, 'Εσκιμώος'),
(64359, 2247, 17, 'Καταχωρημένος ασθενής'),
(64360, 2249, 17, 'Εθνότητα'),
(64361, 2250, 17, 'Εθνότητα ή Φυλή'),
(64362, 2251, 17, 'Λίστα Εθνότητας- Φυλής (εγγραφή, προαιρ. προσθήκη)'),
(64363, 2252, 17, 'Αναγνωριστικός αριθμός ηλεκτρονικής αποστολής'),
(64364, 2253, 17, 'Συμβάν'),
(64365, 2254, 17, 'Έναρξη συμβάντος'),
(64366, 2255, 17, 'Κατηγορία συμβάντος'),
(64367, 2256, 17, 'Ημερομ. συμβάντος'),
(64368, 2257, 17, 'Περιγραφή συμβάντος'),
(64369, 2258, 17, 'Λεπτομέρειες συμβάντος'),
(64370, 2259, 17, 'Το συμβάν δεν επαναλαμβάνεται'),
(64371, 2260, 17, 'Διάρκεια συμβάντος'),
(64372, 2261, 17, 'Διάρκεια συμβάντος σε λεπτά'),
(64373, 2262, 17, 'Αμοιβή σχετική με το συμβάν'),
(64374, 2263, 17, 'Τόπος συμβάντος'),
(64375, 2264, 17, 'Το συμβάν επαναλαμβάνεται κάθε'),
(64376, 2265, 17, 'Το συμβάν επαναλαμβάνεται επί'),
(64377, 2266, 17, 'Ώρα έναρξης γεγονότος'),
(64378, 2267, 17, 'Τίτλος συμβάντος'),
(64379, 2268, 17, 'Τίτλος συμβάντος'),
(64380, 2269, 17, 'Ιστοσελίδα συμβάντος'),
(64381, 2270, 17, 'Συμβάντα'),
(64382, 2271, 17, 'Συμβάντα για'),
(64383, 2272, 17, 'Άνοιγμα συμβάντων σε νέο παράθυρο'),
(64384, 2273, 17, 'κάθε'),
(64385, 2274, 17, 'Κάθε'),
(64386, 2275, 17, 'κάθε 3 ώρες'),
(64387, 2276, 17, 'κάθε 4 ώρες'),
(64388, 2277, 17, 'κάθε 5 ώρες'),
(64389, 2278, 17, 'κάθε 6 ώρες'),
(64390, 2279, 17, 'κάθε 8 ώρες'),
(64391, 2280, 17, 'Κάθε τέταρτο'),
(64392, 2281, 17, 'Κάθε άλλο'),
(64393, 2282, 17, 'Κάθε τρίτο'),
(64394, 2283, 17, 'Κάθε, κάθε δύο, κάθε τρεις, κτλ.'),
(64395, 2285, 17, 'Αποτελέσματα εξετάσεων και δοκιμών'),
(64396, 2286, 17, 'Αποτελέσματα εξετάσεων'),
(64397, 2289, 17, 'Εξέταση'),
(64398, 2290, 17, 'Ημερομ. εξέτασης'),
(64399, 2291, 17, 'Παράδειγμα'),
(64400, 2292, 17, 'Παραδείγματα'),
(64401, 2293, 17, 'Εξετάσεις/ Δοκιμασίες'),
(64402, 2294, 17, 'Εκτός από'),
(64403, 2295, 17, 'Υπερβολική χρήση/φθορά'),
(64404, 2296, 17, 'Αποκλειόμενοι Ασθενείς'),
(64405, 2297, 17, 'Αποκλεισμός'),
(64406, 2298, 17, 'Οργαν. Αποκλειστ. Παρόχου (ΕΡΟ)'),
(64407, 2299, 17, 'Μέγεθος Χαρτιού Executive'),
(64408, 2300, 17, 'Εξάσκηση'),
(64409, 2301, 17, 'Μορφές άσκησης'),
(64410, 2302, 17, 'Προφίλ ασκήσεων'),
(64411, 2303, 17, 'Ύπαρξη'),
(64412, 2304, 17, 'Έξοδος από τη Διαχείριση'),
(64413, 2305, 17, 'Επέκτ.'),
(64414, 2306, 17, 'Eπέκταση'),
(64415, 2307, 17, 'επέκταση'),
(64416, 2308, 17, 'Ανάπτυξη όλων'),
(64417, 2311, 17, 'Λεπτομερής Προβολή'),
(64418, 2312, 17, 'O κωδικός για το έντυπο_επίσκεψης.pid αναμένεται να είναι '),
(64419, 2313, 17, 'Λήξη'),
(64420, 2314, 17, 'Ημερομ. λήξης'),
(64421, 2315, 17, 'Λήγει'),
(64422, 2316, 17, 'λήγει στις'),
(64423, 2317, 17, 'Εξαγωγή'),
(64424, 2318, 17, 'Εξαγωγή ως CSV'),
(64425, 2319, 17, 'Εξαγωγή ρυθμίσεων'),
(64426, 2322, 17, 'Εξαγωγή δημογραφικών ασθενούς'),
(64427, 2323, 17, 'Εξαγωγή Αναφοράς PQRI'),
(64428, 2325, 17, 'Εξαγωγή Επιλεγμένων ως CSV'),
(64429, 2326, 17, 'Εξαγωγή Επιλεγμένων σε Συλλογές'),
(64430, 2327, 17, 'Εξαγωγή σε CSV'),
(64431, 2328, 17, 'Εξαγωγή σε εξωτ. σύστημα χρέωσης'),
(64432, 2329, 17, 'Έκθεση σε Ξένες Χώρες'),
(64433, 2330, 17, 'Έκθεση Σε Ξένες Χώρες'),
(64434, 2331, 17, 'Εξωτερ. Χρόνος Συλλογής'),
(64435, 2332, 17, 'Εξωτερικός'),
(64436, 2334, 17, 'Φόρτωση εξωτερικών δεδομένων'),
(64437, 2335, 17, 'Βοηθητικό πρόγραμμα εισαγωγής εξωτερ. βάσης δεδομένων'),
(64438, 2336, 17, 'Εξωτερ. Κωδικός'),
(64439, 2337, 17, 'Εξωτερ. Κωδικός'),
(64440, 2338, 17, 'Εξωτερ. ταυτοποίηση'),
(64441, 2339, 17, 'Μόνο εξωτερικό'),
(64442, 2342, 17, 'Εξωτερ. παραπομπή'),
(64443, 2343, 17, 'Παραλούθηση (followup) εξωτερ. Παραπομπών'),
(64444, 2344, 17, 'Εξωτερ. παραπομπή;'),
(64445, 2345, 17, 'Εξωτερ. παραπομπές'),
(64446, 2346, 17, 'Αποσυμπίεση του αρχείου zip'),
(64447, 2347, 17, 'Αποσυμπίεση του αρχείου. Αυτό θα διαρκέσει λίγη ώρα...'),
(64448, 2348, 17, 'Εξίδρωμα:'),
(64449, 2349, 17, 'Ερεθισμός οφθαλμού'),
(64450, 2350, 17, 'Πόνος οφθαλμού'),
(64451, 2351, 17, 'Ερυθρότητα οφθαλμού'),
(64452, 2352, 17, 'Οφθαλμοί'),
(64453, 2353, 17, 'F'),
(64454, 2354, 17, 'F/H Αιματολογικά προβλήματα'),
(64455, 2356, 17, 'Έδρες'),
(64456, 2357, 17, 'Έδρα'),
(64457, 2358, 17, 'έδρα'),
(64458, 2359, 17, 'Διαχείριση Έδρας'),
(64459, 2360, 17, 'Πόλη Εδρας'),
(64460, 2361, 17, 'Κωδικός Έδρας'),
(64461, 2362, 17, 'Κωδικός Χώρας Εδρας'),
(64462, 2363, 17, 'Fax Έδρας'),
(64463, 2364, 17, 'Ονομασία Έδρας'),
(64464, 2365, 17, 'Εθνικό Αναγνωριστικό Εδρας'),
(64465, 2366, 17, 'Τηλέφ. Έδρας'),
(64466, 2368, 17, 'Νομός Έδρας'),
(64467, 2369, 17, 'Οδός Έδρας'),
(64468, 2370, 17, 'ΤΚ Έδρας'),
(64469, 2372, 17, 'Έδρα:'),
(64470, 2373, 17, 'ΑΠΟΤΥΧΙΑ'),
(64471, 2374, 17, 'αποτυχημένο'),
(64472, 2375, 17, 'Απέτυχε'),
(64473, 2380, 17, 'Αποτυχία δημιουργία προσωρινού φακέλου. Η βάση CouchDB δε θα λειτορυγήσει.'),
(64474, 2382, 17, 'Απέτυχε.'),
(64475, 2383, 17, 'αποτυχία'),
(64476, 2390, 17, 'Οικογεν. ιστορικό'),
(64477, 2391, 17, 'Ιστορικό γλαυκώματος'),
(64478, 2392, 17, 'Οικογενειακό ιστορικό:'),
(64479, 2394, 17, 'Οικογενειακή Πληρωμή'),
(64480, 2395, 17, 'Μέγεθος οικογένειας'),
(64481, 2396, 17, 'Παράξενο'),
(64482, 2398, 17, 'Περσικά'),
(64483, 2400, 17, 'Πατέρας'),
(64484, 2402, 17, 'Κόπωση'),
(64485, 2403, 17, 'Καταβεβλημένος'),
(64486, 2404, 17, 'Φαξ'),
(64487, 2405, 17, 'Καταμέτρηση Φαξ'),
(64488, 2406, 17, 'Αριθμ. Φαξ'),
(64489, 2408, 17, 'Fax/Σαρωτής'),
(64490, 2409, 17, 'Είσοδος Fax'),
(64491, 2410, 17, 'Έξοδος Fax'),
(64492, 2411, 17, 'Χαρακτηριστικά'),
(64493, 2412, 17, 'Φεβ'),
(64494, 2413, 17, 'Φεβρουάριος'),
(64495, 2414, 17, 'Εθνική πράξη αποκατάστασης υπαλλήλων'),
(64496, 2415, 17, 'Εθν. Κωδικός φαρμάκου'),
(64497, 2416, 17, 'Κωδικός εργαζομένου/ εργοδότη'),
(64498, 2417, 17, 'ΑΦΜ'),
(64499, 2418, 17, 'Αμοιβή'),
(64500, 2419, 17, 'αμοιβή'),
(64501, 2420, 17, 'Η αμοιβή δεν επιτρέπεται'),
(64502, 2421, 17, 'Έντυπο αμοιβής'),
(64503, 2422, 17, 'Παράμετροι εντύπου αμοιβής'),
(64504, 2423, 17, 'Αμοιβές'),
(64505, 2424, 17, 'Θήλυ'),
(64506, 2426, 17, 'Γυναικεία προφυλακτικά'),
(64507, 2430, 17, 'Συμπτώματα θήλεως'),
(64508, 2431, 17, 'Οικειοθελής χειρουργ. αντισύλ. γυναίκας'),
(64509, 2434, 17, 'Πυρετός'),
(64510, 2435, 17, 'Πυρετός:'),
(64511, 2436, 17, 'Πρόβλημα οικογ. υπερχοληστερολαιμίας'),
(64512, 2437, 17, 'Ινομυώματα'),
(64513, 2441, 17, 'Τύπος πεδίου προς χρήση από τον εργοδότη, ή για τη χώρα του συνδρομητή, στα δημογραφικά.'),
(64514, 2442, 17, 'Τύπος πεδίου για χρήση στο νομό του εργοδότη ή του Νομού του συνδρομητή, στα δημογραφικά.'),
(64515, 2443, 17, 'Λείπουν πεδία!'),
(64516, 2447, 17, 'Αρχείο'),
(64517, 2448, 17, 'το αρχείο στο φάκελο Τεκμηρίωση για να μάθετε πως να αυτοματοποιήσετε τη διαδικασία δημιουργίας αρχείου καταγραφής αντιγράφων ασφαλείας'),
(64518, 2449, 17, 'θέση αρχείου'),
(64519, 2450, 17, 'Διαχείριση Αρχείου'),
(64520, 2453, 17, 'Το δικαίωμα αρχείου δόθηκε στον χρήστη LibreEHR.'),
(64521, 2454, 17, 'Απέτυχε η ανάκτηση αρχείων από την CouchDB'),
(64522, 2455, 17, 'Χώρος Αρχείων'),
(64523, 2456, 17, 'Αρχείο για ανέβασμα'),
(64524, 2457, 17, 'Αρχείο για ανέβασμα'),
(64525, 2458, 17, 'Αρχείο με το ίδιο όνομα υπάρχει ήδη στη θέση:'),
(64526, 2459, 17, 'Όνομα αρχείου'),
(64527, 2461, 17, 'Αρχεία'),
(64528, 2462, 17, 'Φιλιπινέζικα'),
(64529, 2463, 17, 'Συμπληρώστε οποιαδήποτε από τις κάτωθι γραμμές'),
(64530, 2464, 17, 'Συμπληρώστε εδώ μόνο αν στέλνετε ειδοποίηση με email στους ασθενείς'),
(64531, 2465, 17, 'Συμπληρώστε τις παρακάτω τιμές'),
(64532, 2467, 17, 'Συμπληρώστε τη γραμμή.'),
(64533, 2468, 17, 'Φίλτρο'),
(64534, 2469, 17, 'Φίλτρο για Σταθερές'),
(64535, 2470, 17, 'Φίλτρο για Ορισμούς'),
(64536, 2471, 17, 'έχει φιλτραριστεί από'),
(64537, 2472, 17, 'φίλτρα'),
(64538, 2473, 17, 'Φίλτρα'),
(64539, 2474, 17, 'Τελικό'),
(64540, 2475, 17, 'Τελική Διάγνωση'),
(64541, 2476, 17, 'Τελική διάγνωση ανά ειδικό'),
(64542, 2478, 17, 'Οικονομικά'),
(64543, 2479, 17, 'Ημερομ. Οικονομικού Κλεισίματος (εεεε-μμ-ηη)'),
(64544, 2480, 17, 'Οικονομ. αναφορά – ο,τιδήποτε'),
(64545, 2481, 17, 'Οικονομ. αναφορά – οι επισκέψεις μου'),
(64546, 2482, 17, 'Ημερομ. οικονομ. ανασκόπησης'),
(64547, 2483, 17, 'Οικονομική Σύνοψη ανά Κωδικό υπηρεσιών'),
(64548, 2484, 17, 'Εύρεση'),
(64549, 2485, 17, 'Εύρεση διαθεσίμου'),
(64550, 2486, 17, 'Εύρεση διαθέσιμων ραντεβού'),
(64551, 2487, 17, 'Εύρεση ασθενούς'),
(64552, 2488, 17, 'Εύρεση Υλικών εκπαίδευσης ασθενούς'),
(64553, 2489, 17, 'Ευρήματα'),
(64554, 2490, 17, 'Ευρήματα ανά ειδικό'),
(64555, 2491, 17, 'Πρόστιμο'),
(64556, 2492, 17, 'Τέλος Πληρωμών'),
(64557, 2493, 17, 'τελείωσε'),
(64558, 2495, 17, 'Πρώτο'),
(64559, 2497, 17, '1η μέρα της εβδομάδας'),
(64560, 2498, 17, 'Μικρό όνομα'),
(64561, 2499, 17, 'Μικρό όνομα'),
(64562, 2500, 17, 'Μικρό όνομα:'),
(64563, 2503, 17, 'Φυσική κατάσταη'),
(64564, 2504, 17, 'Επίπ. φυσικής κατάστασης'),
(64565, 2505, 17, 'Επίπ. φυσικής κατάστασης γι'' αυτό τον παίκτη, αυτή την ημέρα'),
(64566, 2507, 17, 'Καταλληλότητα για συμμετοχή στο παιγνίδι'),
(64567, 2508, 17, 'Διόρθωση ημερομ. επισκέψεων- όλων των επισκέψεων'),
(64568, 2509, 17, 'Διορθώστε αυτό'),
(64569, 2510, 17, 'Διόρθωση αυτού'),
(64570, 2511, 17, 'Μετεωρισμός'),
(64571, 2512, 17, 'Ροή'),
(64572, 2514, 17, 'Εποχή γρίππης'),
(64573, 2515, 17, 'Εποχή γρίππης'),
(64574, 2516, 17, 'Εμβολ. γρίππης'),
(64575, 2517, 17, 'Πρόβλημα υγρών και ηλεκτρολυτών'),
(64576, 2518, 17, 'Ινομυαλγία'),
(64577, 2519, 17, 'Μέγεθος Χαρτιού Folio'),
(64578, 2520, 17, 'Ακολουθήστε χειροκίνητα'),
(64579, 2521, 17, 'Ακολουθήστε αυτές τις οδηγίες για να εγκαταστήσετε, ή να αναβαθμίσετε, την εξής βάση δεδομένων'),
(64580, 2522, 17, 'Επανεκτίμηση'),
(64581, 2524, 17, 'Αιτία Επανεκτίμησης'),
(64582, 2525, 17, 'Ακολουθεί μια νέα παραμετροποιημένη (custom) Σταθερά:'),
(64583, 2526, 17, 'Ακολουθεί μια νέα παραμετροποιημένη (custom) Γλώσσα:'),
(64584, 2527, 17, 'Ακολουθεί ένας νέος ορισμός (Γλώσσας, Σταθεράς, Ορισμός):'),
(64585, 2529, 17, 'Υπηρεσίες επανεκτίμησης'),
(64586, 2530, 17, 'Ενδείκνυνται επανεκτιμήσεις'),
(64587, 2531, 17, 'Δυσανεξία σε τροφή'),
(64588, 2532, 17, 'Πόδι'),
(64589, 2533, 17, 'Προβλήμ. ποδός'),
(64590, 2534, 17, 'Πόδι:'),
(64591, 2535, 17, 'Κακώσεις ποδοσφαίρου'),
(64592, 2536, 17, 'Κάκωση ποδοσφαίρου'),
(64593, 2537, 17, 'Αναφορά ποδοσφαιρικής κάκωσης'),
(64594, 2538, 17, 'Τύπος υποδημάτων'),
(64595, 2539, 17, 'για'),
(64596, 2540, 17, 'Για'),
(64597, 2541, 17, 'Για κωδικό'),
(64598, 2543, 17, 'Για Αιτήματα πληρωμής επίσκεψης'),
(64599, 2544, 17, 'Για παράδειγμα:'),
(64600, 2547, 17, 'για Τιμολόγιο'),
(64601, 2548, 17, 'Μόνο στην περίπτωση του Medicare, απαιτείται ο παραπέμπων πάροχος να είναι ο ίδιος με τον πάροχο που έκανε την εκτίμηση.'),
(64602, 2552, 17, 'Για τον αναφερόμενο Οργανισμό/ Ιατρό'),
(64603, 2553, 17, 'Για το παρελθόν'),
(64604, 2554, 17, 'για μεταβλητή'),
(64605, 2555, 17, 'για:'),
(64606, 2556, 17, 'Το widget χρέωσης να διατηρείται υποχρεωτικά ανοικτό'),
(64607, 2557, 17, 'Υποχρεωτ. δημιουργία Νέου Ασθενούς'),
(64608, 2558, 17, 'Υποχρεωτ. εμφάνιση'),
(64609, 2559, 17, 'Πήχυς'),
(64610, 2560, 17, 'Έντυπο'),
(64611, 2561, 17, 'έντυπο'),
(64612, 2564, 17, 'Μορφοποίηση'),
(64613, 2565, 17, 'μορφοποίηση'),
(64614, 2566, 17, 'Μορφή για την εμφάνιση ηλικίας'),
(64615, 2567, 17, 'Άκυρη μορφή κωδικού φαρμάκου'),
(64616, 2568, 17, 'Μορφή εμφάνισης των περισσότερων ημερομηνιών.'),
(64617, 2569, 17, 'Μορφή εμφάνισης των περισσότερων ωρών.'),
(64618, 2570, 17, 'Μορφοποιημένη έκθεση/αναφορά'),
(64619, 2571, 17, 'Πρώην καπνιστής'),
(64620, 2572, 17, 'Έντυπα'),
(64621, 2573, 17, 'Έντυπα Διαχείρισης'),
(64622, 2575, 17, 'Προώθηση'),
(64623, 2576, 17, 'Προώθηση σελίδων μέσω Fax'),
(64624, 2577, 17, 'Προωθήθηκε'),
(64625, 2579, 17, 'Τέταρτο'),
(64626, 2581, 17, 'Κάταγμα'),
(64627, 2582, 17, 'Κάταγμα σκαφοειδούς'),
(64628, 2583, 17, 'Κάταγμα έξω σφυρού'),
(64629, 2584, 17, 'Κάταγμα έσω σφυρού'),
(64630, 2585, 17, 'Κάταγμα βάσης 5ου μεταταρσίου'),
(64631, 2587, 17, 'Γαλλικά'),
(64632, 2588, 17, 'Γαλλικά (Καναδικά)'),
(64633, 2589, 17, 'Γαλλικά (Τυπικά)'),
(64634, 2590, 17, 'Συχνότητα'),
(64635, 2591, 17, 'Συχνά κρυολογήματα'),
(64636, 2592, 17, 'Συχνή νόσηση'),
(64637, 2593, 17, 'Παρ'),
(64638, 2594, 17, 'Παρασκευή'),
(64639, 2595, 17, 'Από'),
(64640, 2596, 17, 'ΑΠΟ'),
(64641, 2597, 17, 'από'),
(64642, 2598, 17, 'Η Ημερομ. του Εντύπου δεν μπορεί να είναι μεγαλύτερη από σήμερα.'),
(64643, 2599, 17, 'Από:'),
(64644, 2600, 17, 'Από: '),
(64645, 2613, 17, 'Γραφείο υποδοχής/Reception'),
(64646, 2614, 17, 'Αποδείξεις γραφείου υποδοχής'),
(64647, 2615, 17, 'Αναφορά αποδείξεων γραφείου υποδοχής'),
(64648, 2616, 17, 'Γραφείο υποδοχής'),
(64649, 2617, 17, 'Μετωπιαία δεξιά:'),
(64650, 2619, 17, 'Πλήρες όνομα'),
(64651, 2620, 17, 'Πλήρης διαδρομή για τον κατάλογο που περιέχει τα εκτελέσιμα αρχεία της MySQL.'),
(64652, 2621, 17, 'Πλήρης διαδρομή για τον κατάλογο που περιέχει τα εκτελέσιμα αρχεία της Perl.'),
(64653, 2622, 17, 'Πλήρες path στον κατάλογο backup της καταγραφής logs.'),
(64654, 2623, 17, 'Πλήρες path στον κατάλογο των προσωρινών αρχείων:'),
(64655, 2625, 17, 'Πλήρης εκπαίδευση'),
(64656, 2626, 17, 'Πλήρως εξοφλημένο'),
(64657, 2636, 17, 'Πάθηση χοληδόχου κύστης'),
(64658, 2637, 17, 'Χολόλιθοι'),
(64659, 2638, 17, 'Περίοδος παιχνιδιού'),
(64660, 2639, 17, 'Παιχνίδια'),
(64661, 2640, 17, 'Απωλεσθέντα παιγνίδια'),
(64662, 2641, 17, 'παιχνίδια/ συμβάντα'),
(64663, 2642, 17, 'Απωλεσθέντα παιχνίδια/ συμβάντα'),
(64664, 2644, 17, 'Γαστρίτιδα'),
(64665, 2645, 17, 'Επιγάστριον άλγος'),
(64666, 2646, 17, 'Πεπτικό'),
(64667, 2647, 17, 'Αναφορά στατιστικών GCAC'),
(64668, 2648, 17, 'Στατιστ. GCAC'),
(64669, 2649, 17, 'Το έντυπο επίσκεψης GCAC λείπει'),
(64670, 2650, 17, 'Φύλο'),
(64671, 2651, 17, 'Φύλο '),
(64672, 2652, 17, 'Γενικά'),
(64673, 2653, 17, 'Λίστα γενικών θεμάτων'),
(64674, 2655, 17, 'Γεν. κατηγορία υπηρεσιών'),
(64675, 2657, 17, 'Δημιουργία και κατέβασμα εγγράφου αιτήσεων CMS 1500'),
(64676, 2658, 17, 'Δημιουργία και κατέβασμα εγγράφου αιτήσεων HCFA 1500'),
(64677, 2659, 17, 'Δημιουργία και κατέβασμα ενεργειών Χ12'),
(64678, 2660, 17, 'Δημιουργία και κατέβασμα δέσμης ενεργειών με αιτήσεις πληρωμής Χ12'),
(64679, 2663, 17, 'Δημιουργία και μετάδοση επιτρεπόμενων συνταγών ηλεκτρονικά.'),
(64680, 2664, 17, 'Δημιουργία CMS 1500'),
(64681, 2665, 17, 'Δημιουργ. PDF CMS 1500'),
(64682, 2666, 17, 'Δημιουργ. TEXT CMS 1500'),
(64683, 2667, 17, 'Δημιουργία HCFA'),
(64684, 2668, 17, 'Δημιουργία Τιμιολογίου'),
(64685, 2669, 17, 'Δημιουργία επιστολής'),
(64686, 2670, 17, 'Δημιουργία επιστολής σχετικά με '),
(64687, 2671, 17, 'Δημιουργία αναφοράς PQRI (Μέθοδος Α)'),
(64688, 2673, 17, 'Δημιουργία αναφοράς PQRI (Μέθοδος Ε)'),
(64689, 2677, 17, 'Δημιουργ. Αναφοράς'),
(64690, 2678, 17, 'Δημιουργία Ονόματος χρήστη και Κωδικού για'),
(64691, 2679, 17, 'Δημιουργ. Χ12'),
(64692, 2680, 17, 'Δημιουργ. Επίσκεψης Χ12'),
(64693, 2682, 17, 'Δημιουργήθηκε στις'),
(64694, 2683, 17, 'Δημιουργεί'),
(64695, 2684, 17, 'Ουρογεννητικό'),
(64696, 2687, 17, 'Γερμανικά'),
(64697, 2691, 17, 'Λάβετε το HL7'),
(64698, 2692, 17, 'Γλαύκωμα'),
(64699, 2693, 17, 'Οικογεν. ιστορικό γλαυκώματος'),
(64700, 2694, 17, 'Γενικό'),
(64701, 2696, 17, 'Γεν. Κωδικός αναγνώρισης'),
(64702, 2697, 17, 'Γεν. Ρυθμίσεις'),
(64703, 2698, 17, 'Γενικές'),
(64704, 2700, 17, 'Ξεκινήστε'),
(64705, 2701, 17, 'Ξεκινήστε'),
(64706, 2704, 17, 'Μετάβαση στο'),
(64707, 2705, 17, 'Μετάβαση στην εβδομάδα'),
(64708, 2706, 17, 'Μετάβαση στο σήμερα'),
(64709, 2707, 17, 'Στόχος Α'),
(64710, 2708, 17, 'Στόχος και Μέθοδοι'),
(64711, 2709, 17, 'Στόχος Β'),
(64712, 2710, 17, 'Στόχος Γ'),
(64713, 2711, 17, 'Βαθμός κάκωσης'),
(64714, 2712, 17, 'Βαθμός:'),
(64715, 2713, 17, 'γραμμ.'),
(64716, 2714, 17, 'Γενικό Σύνολο'),
(64717, 2715, 17, 'Γενικά Σύνολα'),
(64718, 2718, 17, 'Γραφικό'),
(64719, 2720, 17, 'Μεγαλύτερο από'),
(64720, 2721, 17, 'Μεγαλύτερο ή ίσο από'),
(64721, 2722, 17, 'Ελληνικά'),
(64722, 2724, 17, 'Ομάδα'),
(64723, 2725, 17, 'Όνομα ομάδας'),
(64724, 2726, 17, 'Τα ονόματα ομάδας δεν μπορούν να είναι κενά'),
(64725, 2727, 17, 'Τα ονόματα ομάδας δεν μπορούν να αρχίζουν με αριθμούς ή κενά'),
(64726, 2728, 17, 'Τα ονόματα ομάδας δεν μπορούν να αρχίζουν με αριθμούς'),
(64727, 2729, 17, 'Αριθμός ομάδας'),
(64728, 2730, 17, 'Πληρωμή ομάδας'),
(64729, 2731, 17, 'Ομάδα:'),
(64730, 2732, 17, 'Όνομα ομάδας'),
(64731, 2733, 17, 'Ομάδες και έλεγχος πρόσβασης'),
(64732, 2734, 17, 'Καμπύλη Ανάπτυξης'),
(64733, 2735, 17, 'Καμπύλη Ανάπτυξης'),
(64734, 2736, 17, 'σταγόνες (drops)'),
(64735, 2737, 17, 'Μικρονησιακή γλώσσα Γουάμ'),
(64736, 2739, 17, 'Όνομα Κηδεμόνος'),
(64737, 2741, 17, 'Γυναικολογική εξέταση'),
(64738, 2742, 17, 'ώρες'),
(64739, 2743, 17, 'με την κατάκλιση'),
(64740, 2744, 17, 'Ιστορικό Ηπατίτιδος'),
(64741, 2745, 17, 'είχαν διαγραφεί επιτυχώς. Όλες οι υποκατηγορίες, αν υπάρχουν, μεταφέρθηκαν παρακάτω'),
(64742, 2746, 17, 'Αιμάτωμα / μώλωπες'),
(64743, 2750, 17, 'Χέρι + δάκτυλα'),
(64744, 2751, 17, 'Προβλήμ. χειρός'),
(64745, 2752, 17, 'Σκληρός Δίσκος'),
(64746, 2753, 17, 'Δυσκολίες με'),
(64747, 2754, 17, 'συνδέθηκε με επίσκεψη'),
(64748, 2755, 17, 'έληξε'),
(64749, 2756, 17, 'Hash'),
(64750, 2757, 17, 'Δεν υπάρχει hash για αυτό το αρχείο. Ένα νέο hash δημιουργήθηκε.'),
(64751, 2758, 17, 'Το hash δεν ταιριάζει. Η ακεραιότητα των δεδομένων έχει παραβιαστεί.'),
(64752, 2760, 17, 'Χαβανέζικα'),
(64753, 2761, 17, 'Επικίνδυνες δραστηριότητες'),
(64754, 2762, 17, 'Επικίνδυνες δραστηριότητες'),
(64755, 2763, 17, 'Αριστερό όριο HCFA σε σημεία'),
(64756, 2764, 17, 'Όρια HCFA'),
(64757, 2765, 17, 'Άνω όριο HCFA σε σημεία'),
(64758, 2766, 17, 'Διαδικασία/Υπηρεσία HCPCS'),
(64759, 2768, 17, 'Κεφαλή'),
(64760, 2769, 17, 'Περίμ. Κεφ.'),
(64761, 2770, 17, 'Περίμετρος Κεφαλής'),
(64762, 2771, 17, 'Κεφαλαλγία'),
(64763, 2772, 17, 'Κεφαλαλγίες'),
(64764, 2773, 17, 'λειτουργίες φροντίδας υγείας'),
(64765, 2774, 17, 'Λειτουργίες Φροντίδας Υγείας'),
(64766, 2775, 17, 'Κέντρο Υγείας/Κλινική/Ιατρείο'),
(64767, 2776, 17, 'Οργανισμός Διατήρησης Υγείας'),
(64768, 2777, 17, 'Οργανισμός Φροντίδας Υγείας Medicare Risk'),
(64769, 2778, 17, 'Απώλεια ακοής'),
(64770, 2779, 17, 'Έμφραγμα μυοκαρδίου'),
(64771, 2780, 17, 'Καρδιοπάθεια'),
(64772, 2781, 17, 'Καρδιακή ανεπάρκεια'),
(64773, 2782, 17, 'Πρόβλημα καρδιάς'),
(64774, 2783, 17, 'Καρδιαγγειακό'),
(64775, 2784, 17, 'Καρδιοχειρουργική επέμβαση'),
(64776, 2785, 17, 'Μεταμόσχευση καρδιάς'),
(64777, 2786, 17, 'ΚΑΡΔΙΑ:'),
(64778, 2787, 17, 'Αίσθηση οπισθοστερνικού καύσους'),
(64779, 2788, 17, 'Ζέστη ή κρύο'),
(64780, 2789, 17, 'Ζέστη ή κρύο'),
(64781, 2790, 17, 'Εντατικός καπνιστής'),
(64782, 2791, 17, 'Εβραϊκά'),
(64783, 2793, 17, 'Κεφαλή, οφθαλμοί, ώτα, μύτη και φάρυγξ'),
(64784, 2794, 17, 'Ύψος'),
(64785, 2796, 17, 'Βοήθεια'),
(64786, 2797, 17, 'βοήθεια'),
(64787, 2798, 17, 'Αιματέμεση'),
(64788, 2799, 17, 'Αιματοχεσία'),
(64789, 2800, 17, 'Αιματολογικό'),
(64790, 2801, 17, 'Αιματουρία'),
(64791, 2802, 17, 'Αιμοσφαιρίνη'),
(64792, 2803, 17, 'Αιμοσφαιρίνη A1C'),
(64793, 2804, 17, 'Αιμόπτυση'),
(64794, 2805, 17, 'Ηπατίτιδα'),
(64795, 2806, 17, 'Ηπατ. Α 1'),
(64796, 2807, 17, 'Ηπατ. Α 2'),
(64797, 2808, 17, 'Ηπατ. Β 1'),
(64798, 2809, 17, 'Ηπατ. Β 2'),
(64799, 2810, 17, 'Ηπατ. Β 3'),
(64800, 2811, 17, 'εδώ'),
(64801, 2813, 17, 'Διόρθωση Κήλης'),
(64802, 2814, 17, 'Κήλη δίσκου'),
(64803, 2815, 17, 'Έρπης'),
(64804, 2816, 17, 'Δισταγμός'),
(64805, 2817, 17, 'Ήσασταν εδώ για '),
(64806, 2818, 17, 'Αιμόφιλος 1'),
(64807, 2819, 17, 'Αιμόφιλος 2'),
(64808, 2820, 17, 'Αιμόφιλος 3'),
(64809, 2821, 17, 'Αιμόφιλος 4'),
(64810, 2822, 17, 'Κρυφό'),
(64811, 2823, 17, 'Διαχείριση κρυφών Συμβάντων'),
(64812, 2824, 17, 'Απόκρυψη'),
(64813, 2825, 17, 'Απόκρυψη λεπτομερειών'),
(64814, 2827, 17, 'Απόκρυψη Επιλογών Κρυπτογράφησης/Αποκρυπτογράφησης στο Διαχειριστή Εγγράφων'),
(64815, 2828, 17, 'Απόκρυψη μενού'),
(64816, 2830, 17, 'Απόκρυψη Υπενθυμίσεων'),
(64817, 2831, 17, 'Απόκρ./ Εμφάνιση Στηλών'),
(64818, 2833, 17, 'Υψηλό'),
(64819, 2834, 17, 'Αρτηρ. Υπέρταση'),
(64820, 2835, 17, 'Ινδικά'),
(64821, 2836, 17, 'Ισχίο + βουβωνική χώρα'),
(64822, 2837, 17, 'Ισχίο και βουβωνική χώρα'),
(64823, 2838, 17, 'Προβλήμ. ισχίου'),
(64824, 2839, 17, 'Αντικατάσταση ισχίου'),
(64825, 2840, 17, 'Ελήφθη Αίτημα Χορήγησης Ιατρικών Δεδομένων στον Ασθενή'),
(64826, 2842, 17, 'Υπερτρίχωση'),
(64827, 2843, 17, 'Ισπανόφωνος'),
(64828, 2844, 17, 'Ισπανόφωνος - Αλλο (Γενν. στις ΗΠΑ)'),
(64829, 2845, 17, 'Ισπανόφωνος - Αλλο (Γενν. εκτός ΗΠΑ)'),
(64830, 2846, 17, 'Ισπανόφωνος ή Λατίνος'),
(64831, 2847, 17, 'Ιστορικό'),
(64832, 2848, 17, 'Δεδομένα Ιστορικού'),
(64833, 2849, 17, 'Ημερομ. Ιστορικού'),
(64834, 2851, 17, 'Ιστορικό φυσημάτων'),
(64835, 2852, 17, 'Μη εξουσιοδοτημένο ιστορικό'),
(64836, 2853, 17, 'Ιστορικό καρδιακών φυσημάτων'),
(64837, 2854, 17, 'Επιτυχίες'),
(64838, 2855, 17, 'HIV'),
(64839, 2858, 17, 'Σύστημα εμφάνισης του HL7'),
(64840, 2862, 17, 'Κρατήστε το [Ctrl] πατημένο για πολλαπλή επιλογή ή αποεπιλογή'),
(64841, 2863, 17, 'Κρατήστε το [Ctrl] πατημένο για επιλογή πολλών αντικειμένων'),
(64842, 2864, 17, 'Κρατήστε το [Ctrl] πατημένο για επιλογή πολλών ομάδων'),
(64843, 2865, 17, 'ΑΡΧΗ'),
(64844, 2866, 17, 'Τηλέφ. οικίας'),
(64845, 2867, 17, 'Αριθμ. τηλεφ. Οικίας'),
(64846, 2868, 17, 'Άστεγος ή παρόμοιο;'),
(64847, 2869, 17, 'Άστεγος, κτλ'),
(64848, 2870, 17, 'Άστεγος, κτλ'),
(64849, 2872, 17, 'Όνομα Host'),
(64850, 2873, 17, 'Το όνομα Host δεν μπορεί να είναι κενό.'),
(64851, 2875, 17, 'Ώρα'),
(64852, 2876, 17, 'Ώρες'),
(64853, 2878, 17, 'Πως συνέβη η κάκωση;'),
(64854, 2879, 17, 'Πως συνέβη η κάκωση;'),
(64855, 2880, 17, 'Πως ακούσανε για εμάς'),
(64856, 2881, 17, 'Σε βάθος πόσων μηνών στο μέλλον, να ρωτήσω για επερχόμενα συμβάντα;'),
(64857, 2882, 17, 'Επιτροπή Προαγωγής Υγείας:'),
(64858, 2884, 17, 'HTML'),
(64859, 2886, 17, 'Ασφαλής σύνδεση https για την υπηρεσία υποστήριξης LibreEHR LLC LAB exchange'),
(64860, 2887, 17, 'Ουγγρικά'),
(64861, 2888, 17, 'Κατάλογος Hylafax'),
(64862, 2890, 17, 'Διακομιστής Hylafax'),
(64863, 2891, 17, 'Διακομιστής Hylafax'),
(64864, 2892, 17, 'Υπερκινητικό'),
(64865, 2893, 17, 'Υπέρταση'),
(64866, 2894, 17, 'Υπέρταση: Μέτρηση Αρτηριακής Πίεσης');
INSERT INTO `lang_definitions` VALUES
(64867, 2895, 17, 'Υπέρταση: Μέτρηση Αρτηριακής Πίεσης'),
(64868, 2896, 17, 'Υπερθυρεοειδισμός'),
(64869, 2897, 17, 'Υποθυρεοειδισμός'),
(64870, 2898, 17, 'Υστερεκτομή'),
(64871, 2899, 17, 'Εγώ'),
(64872, 2900, 17, 'Είμαι απασχολημένος/η αυτό τον καιρό'),
(64873, 2901, 17, 'Δεν έχω την άδεια να διαβάσω '),
(64874, 2902, 17, 'ICD'),
(64875, 2903, 17, 'Διάγνωση ICD10'),
(64876, 2904, 17, 'Διαδικασία/Υπηρεσία ICD10'),
(64877, 2905, 17, 'ICD9'),
(64878, 2906, 17, 'Διάγνωση ICD9'),
(64879, 2907, 17, 'Διαδικασία/Υπηρεσία ICD9'),
(64880, 2909, 17, 'Κωδικός'),
(64881, 2910, 17, 'Κωδικός'),
(64882, 2911, 17, 'Ο κωδικός δεν μπορεί να είναι κενός'),
(64883, 2912, 17, 'Κάρτα Κωδικού'),
(64884, 2914, 17, 'αναγνωρίστηκε ως'),
(64885, 2915, 17, 'κωδικός αναγνώρισης (μια λέξη)'),
(64886, 2916, 17, 'Κωδικός ταυτοποίησης'),
(64887, 2917, 17, 'Δευτερόλ. μέχρι τη λήξη μίας Αδρανούς Συνεδρίας'),
(64888, 2919, 17, 'Αν όλα τα δεδομένα για όλες τις στήλες είναι πλήρη για αυτό το έντυπο'),
(64889, 2920, 17, 'Αν χρησιμοποιήσετε αιτιολόγηση χρέωσης, βάλτε το όνομα του κωδικού διάγνωσης'),
(64890, 2921, 17, 'αν εισάγετε, επιλέξτε μόνο αυτούς που είχαν αυτήν την υπηρεσία'),
(64891, 2922, 17, 'αν όνομα, οποιοδήποτε τμήμα του επωνύμου ή επώνυμο,όνομα'),
(64892, 2923, 17, 'Εάν πληρώνει με'),
(64893, 2924, 17, 'Εάν ο ασθενής έχει πεθάνει, τότε εισάγετε την ημερομ. θανάτου.'),
(64894, 2925, 17, 'Εάν χρησιμοποιείται SMTP, εισάγετε το όνομα του host ή τη διεύθυνση IP.'),
(64895, 2926, 17, 'Εάν χρησιμοποιείται SMTP, ο αριθμός θύρας TCP του server (συνήθως 25).'),
(64896, 2927, 17, 'αν άνεργος εισάγετε Φοιτητής'),
(64897, 2929, 17, 'Εάν αλλάξετε τον ρόλο του e-RX για την ηλεκτρονική συνταγογράφηση, μπορεί να επηρεάσει τη ροή εργασίας της ηλεκτρονικής συνταγογράφησης. Αν αντιμετωπίζετε οποιαδήποτε δυσκολία, επικοινωνήστε με τον προμηθευτή της ηλεκτρονικής συνταγογράφησης.'),
(64898, 2931, 17, 'Εάν επιλέξατε να ανεβάσετε ηλεκτρον. εμβάσματα, τότε το παράθυρο αναζήτησης θα επανεμφανισθεί, με τα τιμολόγια που ταιριάζουν από το αρχείο X12. Μπορείτε να κάνετε κλικ σε οποιονδήποτε αριθμό τιμολογίου (όπως περιγράφεται παρακάτω), εάν θέλετε να κάνετε διορθώσεις πριν να οριστικοποιηθούν οι πληροφορίες εμβάσματος. Για να εφαρμόσετε τις αλλαγές, κάντε κλικ στο κουμπί "Επεξεργασία ERA" στο κάτω μέρος της σελίδας. Θα εμφανισθεί ένα νέο παράθυρο με μια λεπτομερή αναφορά.'),
(64899, 2932, 17, 'Εάν έχετε εισάγει μια Ημερομηνία Πληρωμής στη σελίδα αναζήτησης, αυτή θα υπερισχύσει της ημερομηνίας αποστολής των πληρωμών και των προσαρμογών, που λαμβάνονται ούτως ή άλλως από το αρχείο X12. Αυτό μπορεί να είναι χρήσιμο για λόγους αναφοράς, αν θέλετε οι αναφορές των αποδείξεών σας να κάνουν χρήση της ημερομηνίας αποστολής σας αντί της ημερομηνίας επεξεργασίας από την ασφαλιστική εταιρείας. Σημειώστε ότι αυτό θα επηρεάσει επίσης τις ημερομηνίες των προηγούμενων πληρωμών και τις προσαρμογές που έχουν τεθεί σε δευτερεύουσες απαιτήσεις.'),
(64900, 2933, 17, 'Αν θέλετε να αλλάξετε τους τύπους δεδομένων, ή να προσθέσετε γραμμές ή στήλες'),
(64901, 2934, 17, 'Αν θέλετε να αναβαθμίσετε τη βάση δεδομένων, τοποθετήστε το αρχείο zip της βάσης δεδομένων στον ακόλουθο κατάλογο.'),
(64902, 2936, 17, 'Αγνόησε'),
(64903, 2937, 17, 'Νόσος'),
(64904, 2938, 17, 'Ενδομυϊκά'),
(64905, 2941, 17, 'Υπηρεσία απεικόνισης'),
(64906, 2942, 17, 'Εμβολιασμός'),
(64907, 2943, 17, 'Κωδικός εμβολιασμού'),
(64908, 2945, 17, 'Ημερομ. εμβολιασμού'),
(64909, 2946, 17, 'Ημερομ. λήξης Ανοσοποίησης'),
(64910, 2947, 17, 'Αριθμός παρτίδας εμβολίου'),
(64911, 2948, 17, 'Κατασκευαστής εμβολίου'),
(64912, 2949, 17, 'Μητρώο εμβολιασμών'),
(64913, 2951, 17, 'Υπηρεσία εμβολιασμών'),
(64914, 2952, 17, 'Τίτλος εμβολιασμού'),
(64915, 2953, 17, 'Εμβολιασμοί'),
(64916, 2954, 17, 'Ανοσοποίηση'),
(64917, 2955, 17, 'Ανοσολογικό'),
(64918, 2956, 17, 'Εμφυτεύματα'),
(64919, 2957, 17, 'Εισαγωγή'),
(64920, 2961, 17, 'Εισαγ. του πιστοποιητικού στον browser'),
(64921, 2962, 17, 'Εισαγ. Ρυθμίσεων'),
(64922, 2964, 17, 'Εισαγ. Ασθενούς'),
(64923, 2965, 17, 'Εισαγ. δημογραφ. ασθενούς'),
(64924, 2966, 17, 'Σημαντικοί Κωδικοί'),
(64925, 2967, 17, 'ΣΗΜΑΝΤΙΚΟ: Αυτό το εργαλείο upload είναι μόνο για να ανεβάζετε έγγραφα για ασθενείς που δεν εισήχθησαν ακόμη στο σύστημα. Για να ανεβάσετε αρχεία για ασθενείς που έχουν ήδη εισαχθεί στο σύστημα, παρακαλώ χρησιμοποιήστε το εργαλείο για upload που είναι συνδεδεμένο μέσα στηνοθόνη για την Περίληψη Ασθενούς.'),
(64926, 2969, 17, 'Εισήχθη από το Λογιστήριο'),
(64927, 2972, 17, 'Βελτιωμένο'),
(64928, 2973, 17, 'ίντσες'),
(64929, 2974, 17, 'Σε'),
(64930, 2975, 17, 'σε κάθε οφθαλμό'),
(64931, 2976, 17, 'στον Αριστ. οφθαλμό'),
(64932, 2977, 17, 'στον Ρώθωνα'),
(64933, 2978, 17, 'Στο γραφείο'),
(64934, 2979, 17, 'Στο Δεξιό οφθαλμό'),
(64935, 2980, 17, 'Κατ'' οίκον'),
(64936, 2981, 17, 'Ανενεργό'),
(64937, 2982, 17, 'Ανενεργές ημέρες'),
(64938, 2983, 17, 'Εισερχόμενα'),
(64939, 2986, 17, 'Να συμπεριληφθεί το Checksum'),
(64940, 2987, 17, 'Να συμπεριληφθούν τα συμπληρωμένα'),
(64941, 2988, 17, 'Να συμπεριληφθούν τους ανενεργούς χρήστες'),
(64942, 2989, 17, 'Να συμπεριληφθούν τα μη κατηγοριοποιημενα'),
(64943, 2990, 17, 'Να συμπεριληφθούν τα μη δομημένα δεδομένα'),
(64944, 2991, 17, 'Να συμπεριληφθούν τα ζωτικά'),
(64945, 2992, 17, 'Να συμπεριληφθούν τα ζωτικά;'),
(64946, 2993, 17, 'Συμπερίληψη'),
(64947, 2994, 17, 'Εισόδημα'),
(64948, 2996, 17, 'Ατελής'),
(64949, 2997, 17, 'Ατελής θεραπεία άμβλωσης'),
(64950, 2998, 17, 'Ακράτεια'),
(64951, 2999, 17, 'Ενσωμάτωση αποτελεσμάτων κλινικών εργαστηριακών εξετάσεων σε πιστοποιημένη τεχνολογία EHR ως δομημένα δεδομένα.'),
(64952, 3000, 17, 'Λάθος κωδικός πρόσβασης!'),
(64953, 3001, 17, 'αυξημένο:'),
(64954, 3002, 17, 'Αποζημίωση από Ασφαλ.εταιρεία'),
(64955, 3003, 17, 'Απροσδιόριστο'),
(64956, 3004, 17, 'Ινδικά'),
(64957, 3005, 17, 'Υποδεικνύει ανωμαλία'),
(64958, 3006, 17, 'Δείχνει αν αυτό το θέμα είναι ενεργό'),
(64959, 3008, 17, 'Δείκτης για ειδική χρήση'),
(64960, 3009, 17, 'Άποροι ασθενείς'),
(64961, 3010, 17, 'Αναφορά απόρου ασθενούς'),
(64962, 3011, 17, 'Άποροι'),
(64963, 3014, 17, 'Προκλητή άμβλωση'),
(64964, 3016, 17, 'Αναρμόδιος'),
(64965, 3017, 17, 'Λοίμωξη / Απόστημα'),
(64966, 3018, 17, 'Λοιμώξεις'),
(64967, 3019, 17, 'Συμβουλ. Στειρότητος'),
(64968, 3020, 17, 'Υπογονιμότητα'),
(64969, 3021, 17, 'Γρίπη 1'),
(64970, 3022, 17, 'Γρίπη 2'),
(64971, 3023, 17, 'Εμβολιασμός γρίππης για ασθενείς >= 50 ετών'),
(64972, 3024, 17, 'Εμβολιασμός γρίππης για ασθενείς >= 50 ετών'),
(64973, 3025, 17, 'Εμβόλιο γρίππης'),
(64974, 3026, 17, 'Πληροφορίες'),
(64975, 3027, 17, 'Δοκιμή πληροφορίας 1'),
(64976, 3028, 17, 'Δοκιμή πληροφορίας 2'),
(64977, 3029, 17, 'Δοκιμή πληροφορίας 3'),
(64978, 3030, 17, 'Δοκιμή πληροφορίας 4'),
(64979, 3031, 17, 'Δοκιμή πληροφορίας 5'),
(64980, 3032, 17, 'Δοκιμή πληροφορίας 6'),
(64981, 3034, 17, 'εισπνοές (inh)'),
(64982, 3035, 17, 'εισπνοές'),
(64983, 3037, 17, 'Αρχικός Χρήστης'),
(64984, 3038, 17, 'Ενέσ./Αποκατάστ.'),
(64985, 3039, 17, 'ενέσιμα'),
(64986, 3040, 17, 'Ένεση'),
(64987, 3041, 17, 'Τραυματισμένο τμήμα σώματος'),
(64988, 3043, 17, 'Κάκωση'),
(64989, 3044, 17, 'Μηχανισμός κάκωσης'),
(64990, 3045, 17, 'Περιληπτική Αναφορά κάκωσης'),
(64991, 3046, 17, 'Παρακολούθηση κάκωσης'),
(64992, 3047, 17, 'Τύπος κάκωσης'),
(64993, 3048, 17, 'Σχετιζόμενο με κάκωση/νόσο'),
(64994, 3051, 17, 'Πεδίου Εισόδου'),
(64995, 3052, 17, 'INR'),
(64996, 3053, 17, 'Ασφαλ 1'),
(64997, 3054, 17, 'Ασφαλ 2 ή Ασφαλ 3'),
(64998, 3055, 17, 'Διεύθ. Ασφαλ'),
(64999, 3056, 17, 'Προσαρμογή Ασφαλ'),
(65000, 3057, 17, 'Ομαδοποίηση Ασφαλ'),
(65001, 3058, 17, 'Κωδικός Ασφαλ'),
(65002, 3059, 17, 'Ομάδα Ασφαλ'),
(65003, 3060, 17, 'Όνομα Ασφαλ'),
(65004, 3061, 17, 'Η Ασφ πλήρωσε παραπάνω'),
(65005, 3062, 17, 'Ασφαλ Συμβόλαιο'),
(65006, 3063, 17, 'Επιστρ. χρημάτων στην Ασφ'),
(65007, 3064, 17, 'Περίληψη Ασφ'),
(65008, 3065, 17, 'Ασφ1'),
(65009, 3066, 17, 'Ασφ2'),
(65010, 3067, 17, 'Ασφ3'),
(65011, 3069, 17, 'Εισαγωγή απέτυχε: '),
(65012, 3070, 17, 'Τοποθέτηση παλαιών συμβάντων σε πίνακες'),
(65013, 3072, 17, 'Αϋπνία'),
(65014, 3073, 17, 'Ελέγξτε το αρχείο καταγραφής'),
(65015, 3074, 17, 'Επισκόπηση'),
(65016, 3075, 17, 'Αστάθεια / εξάρθρημα'),
(65017, 3076, 17, 'ΕΓΚΑΤΑΣΤΑΣΗ'),
(65018, 3077, 17, 'Εγκατάσταση'),
(65019, 3079, 17, 'Εγκατάσταση ΒΔ'),
(65020, 3080, 17, 'Εγκαταστάθηκε η έκδοση'),
(65021, 3081, 17, 'Ενημερωμένο'),
(65022, 3082, 17, 'Ενημέρωση'),
(65023, 3084, 17, 'Οδηγίες:'),
(65024, 3085, 17, 'Ανεπαρκής απογραφή αποθεμάτων για τον Κωδικό του προϊόντος'),
(65025, 3086, 17, 'Ινσουλινοεξαρτώμενος διαβήτης'),
(65026, 3087, 17, 'Ασφάλιση'),
(65027, 3088, 17, 'ασφάλιση'),
(65028, 3091, 17, 'Υπόλοιπο Ασφαλ. εταιρείας'),
(65029, 3093, 17, 'Ασφαλιστ. Εταιρ.'),
(65030, 3094, 17, 'Ασφαλιστ. Εταιρείες'),
(65031, 3095, 17, 'Ασφαλιστ. Εταιρεία'),
(65032, 3096, 17, 'Ασφαλ. Εταιρία Αναζήτ./ Προσθήκη'),
(65033, 3098, 17, 'Στοιχεία Ασφάλισης'),
(65034, 3099, 17, 'Πληροφ. ασφάλισης στο αρχείο'),
(65035, 3100, 17, 'Αριθμοί Ασφάλισης'),
(65036, 3101, 17, 'Πληρωμή Ασφάλισης'),
(65037, 3103, 17, 'Πάροχος Ασφάλισης'),
(65038, 3106, 17, 'Ασφαλισμένος/η'),
(65039, 3107, 17, 'Συμπέρασμα λήψης'),
(65040, 3108, 17, 'Ημερομηνία λήψης'),
(65041, 3109, 17, 'Έκπτωση νοητικών λειτουργιών'),
(65042, 3113, 17, 'Εσωτ. σφάλμα – δεν επελέγησαν σελίδες!'),
(65043, 3114, 17, 'Εσωτ. σφάλμα – το ID ασθενούς δεν δόθηκε!'),
(65044, 3115, 17, 'Εσωτ. σφάλμα προσπελάζοντας το αρχείο που ανέβηκε!'),
(65045, 3116, 17, 'Εσωτ. σφάλμα!'),
(65046, 3117, 17, 'Εσωτ. σφάλμα, δεν δόθηκε κωδικός φαρμάκου!'),
(65047, 3118, 17, 'Εσωτ. σφάλμα: Αδύνατη η εντόπιση MSH-10'),
(65048, 3119, 17, 'Εσωτ. σφάλμα: αξίωση '),
(65049, 3120, 17, 'Εσωτ. σφάλμα: επίσκεψη'),
(65050, 3121, 17, 'Εσωτ. σφάλμα: λείπει κωδικός ασθενούς ή επίσκεψης.'),
(65051, 3122, 17, 'Εσωτ. σφάλμα: δε φαίνεται να είμαστε σε επίσκεψη!'),
(65052, 3123, 17, 'Εσωτ. κωδικός (pid)'),
(65053, 3126, 17, 'Εσωτ. παραπομπές'),
(65054, 3127, 17, 'Εσωτερική ώρα συλλογής'),
(65055, 3128, 17, 'Διεθνές Καθήκον'),
(65056, 3129, 17, 'Διερμηνέας'),
(65057, 3130, 17, 'Απαιτείται διερμηνέας;'),
(65058, 3131, 17, 'Διάμεση πνευμονική νόσος'),
(65059, 3132, 17, 'Μεσοδιάστημα'),
(65060, 3133, 17, 'Μεσοδιάστημα (λεπτά)'),
(65061, 3135, 17, 'Παρέμβαση'),
(65062, 3136, 17, 'Προσεφέρθη Παρέμβαση'),
(65063, 3137, 17, 'Ανοχή'),
(65064, 3139, 17, 'ενδομυϊκά'),
(65065, 3140, 17, 'ενδοφλέβια'),
(65066, 3141, 17, 'Εισαγωγή'),
(65067, 3144, 17, 'Άκυρος χαρακτήρας στο'),
(65068, 3147, 17, 'Άκυρο μήκος για'),
(65069, 3148, 17, 'Άκυρος μη-αριθμητικός χαρακτήρας στο'),
(65070, 3149, 17, 'Άκυρος ή ελλιπής πληρωτής στην πηγή για τον κωδικό '),
(65071, 3150, 17, 'Άκυρη διεύθυνση παραλήπτη. Παρακαλώ προσπαθήστε ξανά.'),
(65072, 3151, 17, 'Άκυροι Κωδικοί Υπηρεσίας'),
(65073, 3152, 17, 'Άκυρος προσδιορισμός πηγής'),
(65074, 3153, 17, 'Άκυρο όνομα χρήστη ή κωδικός πρόσβασης'),
(65075, 3154, 17, 'Ποσό απογραφής'),
(65076, 3155, 17, 'Απογραφή'),
(65077, 3156, 17, 'Δραστηριότητα απογραφής'),
(65078, 3157, 17, 'Απογραφή και πώληση φαρμάκων και μη φαρμακευτ. προϊόντων'),
(65079, 3158, 17, 'Απογραφή και πώληση μόνο φαρμάκων'),
(65080, 3159, 17, 'Η απογραφή δεν είναι διαθέσιμη για αυτήν την παραγγελία'),
(65081, 3160, 17, 'Λίστα απογραφής'),
(65082, 3161, 17, 'Συναλλαγές αποθήκης'),
(65083, 3162, 17, 'Τιμολόγιο'),
(65084, 3163, 17, 'τιμολόγιο'),
(65085, 3164, 17, 'Λογαριασμός Τιμολογίου'),
(65086, 3165, 17, 'Αδύνατη η αποστολή Τιμολογίου. Δεν δημιουργήθηκε καμία επίσκεψη.'),
(65087, 3166, 17, 'Ημερομ. τιμολογίου'),
(65088, 3167, 17, 'Το τιμολόγιο δεν έχει ημερομηνία!'),
(65089, 3168, 17, 'Αριθμός τιμολογίου'),
(65090, 3169, 17, 'Αριθμός αναφοράς τιμολογίου.'),
(65091, 3170, 17, 'Σύνολο αριθμών αναφοράς τιμολογίων, αν χρησιμοποιείται'),
(65092, 3171, 17, 'Σύνολα αριθμών αναφοράς τιμολογίων'),
(65093, 3172, 17, 'Σύνολο αριθ αναφ τιμολογίων'),
(65094, 3173, 17, 'Τιμολόγιο:'),
(65095, 3177, 17, 'Δεδομένα IPPF SRH για'),
(65096, 3178, 17, 'Στατιστική αναφορά IPPF'),
(65097, 3179, 17, 'Στατιστικά IPPF'),
(65098, 3180, 17, 'Εμβόλ. πολυομυελ. IPV 1'),
(65099, 3181, 17, 'Εμβόλ. πολυομυελ. IPV 2'),
(65100, 3182, 17, 'Εμβόλ. πολυομυελ. IPV 3'),
(65101, 3183, 17, 'Εμβόλ. πολυομυελ. IPV 4'),
(65102, 3185, 17, 'Άρρυθμος καρδιακός παλμός'),
(65103, 3186, 17, 'Ευερεθιστότητα'),
(65104, 3187, 17, 'Ερεθισμός'),
(65105, 3188, 17, 'είναι μια διαφορετική έκδοση γλώσσας της ακόλουθης βάσης δεδομένων'),
(65106, 3189, 17, 'είναι μια διαφορετική έκδοση της ακόλουθης βάσης δεδομένων'),
(65107, 3190, 17, 'είναι μια πιο νέα έκδοση της ακόλουθης βάσης δεδομένων'),
(65108, 3191, 17, 'είναι υποχρεωτικό πεδίο.'),
(65109, 3192, 17, 'είναι βασικός κόμβος και δεν μπορεί να σβηστεί'),
(65110, 3193, 17, 'είναι μια επέκταση της ακόλουθης βάσης δεδομένων'),
(65111, 3195, 17, 'είναι άστοχο ή άγνωστο'),
(65112, 3197, 17, 'δεν είναι έγκυρο (τα δεκαδικά κλάσματα είναι εντάξει).'),
(65113, 3198, 17, 'Η PHP χρησιμοποιεί Safe Mode;'),
(65114, 3200, 17, 'Να μεταφραστεί το κείμενο από τη διάταξη των εντύπων;'),
(65115, 3201, 17, 'Να μεταφραστεί το κείμενο από τις λίστες;'),
(65116, 3202, 17, 'Είναι το αρχείο κρυπτογραφημένο;'),
(65117, 3203, 17, 'Πρόκειται για έναν τύπο κωδικού Κλινικού Όρου;'),
(65118, 3204, 17, 'Πρόκειται για έναν τύπο διάγνωσης;'),
(65119, 3205, 17, 'Πρόκειται για έναν τύπο κωδικού Ιατρικού Προβλήματος;'),
(65120, 3207, 17, 'Αυτό είναι ένα είδος διαδικασίας/υπηρεσίας;'),
(65121, 3208, 17, 'Είναι ενεργό;'),
(65122, 3209, 17, 'Είναι ενεργός αυτός ο τύπος κώδικα;'),
(65123, 3210, 17, 'Χρησιμοποιείται αυτός ο κωδικός στα αιτήματα αποζημίωσης;'),
(65124, 3212, 17, 'Αυτός ο τύπος είναι κρυμένος στο Φύλλο Αμοιβής;'),
(65125, 3213, 17, 'Αυτό χρησιμοποιεί εξωτερ. πίνακες SQL; Αν ναι, τότε επιλέξτε τη μορφή'),
(65126, 3214, 17, 'είναι πολύ μακρύ'),
(65127, 3216, 17, 'Ιατρικό Θέμα'),
(65128, 3217, 17, 'ιατρικό θέμα'),
(65129, 3218, 17, 'Ημερομ. Ιατρ. θέματος'),
(65130, 3219, 17, 'Κωδικός Ιατρ. θέματος'),
(65131, 3220, 17, 'Τίτλος ιατρ. θέματος'),
(65132, 3221, 17, 'Είδος θέματος'),
(65133, 3222, 17, 'Είδη θεμάτων'),
(65134, 3223, 17, 'Ιατρικά θέματα'),
(65135, 3224, 17, 'Ιατρικά θέματα (Κακώσεις/Ιατρικά/Αλλεργία):'),
(65136, 3225, 17, 'Ιατρικά θέματα (Κακώσεις/Ιατρικά/Αλλεργία):'),
(65137, 3226, 17, 'Ιατρικά θέματα και Επισκέψεις'),
(65138, 3227, 17, 'Συνοδές Νόσοι/Παθήσεις και Επισκέψεις για'),
(65139, 3228, 17, 'Μη εξουσιοδοτημένα Ιατρικά θέματα'),
(65140, 3229, 17, 'Τμήμα ιατρ. θεμάτων'),
(65141, 3230, 17, 'Ιταλικά'),
(65142, 3231, 17, 'Αντικείμενο'),
(65143, 3232, 17, 'αντικείμενο'),
(65144, 3233, 17, 'αντικείμενα'),
(65145, 3234, 17, 'Η φόρτωση των αντικειμένων απέτυχε'),
(65146, 3236, 17, 'Ενδομήτρια αντισύλληψη'),
(65147, 3237, 17, 'Ενδοφλέβια'),
(65148, 3238, 17, 'Ιαν'),
(65149, 3239, 17, 'Ιανουάριος'),
(65150, 3240, 17, 'Ιαπωνικά'),
(65151, 3241, 17, 'Ίκτερος'),
(65152, 3243, 17, 'Περιγραφή Εργασίας'),
(65153, 3244, 17, 'Κωδικός εργασίας'),
(65154, 3245, 17, 'Εξαρθρήματα'),
(65155, 3246, 17, 'Αρθραλγίες'),
(65156, 3247, 17, 'Διαστρέμματα'),
(65157, 3248, 17, 'Ιουλ'),
(65158, 3249, 17, 'Ιούλιος'),
(65159, 3250, 17, 'Ιουν'),
(65160, 3251, 17, 'Ιούνιος'),
(65161, 3252, 17, 'Ακριβώς κάτω από τις πληροφορίες ελέγχου είναι μια μπλε περιοχή όπου τοποθετείτε τις παραμέτρους της αναζήτησής σας. Μπορείτε να αναζητήσετε με βάση το όνομα του ασθενούς, τον αριθμό γραφήματος, τον αριθμό επίσκεψης ή την ημερομηνία της υπηρεσίας, ή οποιοδήποτε συνδυασμό αυτών. Μπορείτε επίσης να επιλέξετε αν θέλετε να δείτε όλα τα τιμολόγια, τα ανοικτά τιμολόγια, ή μόνο τα τιμολόγια που οφείλονται (από τον ασθενή). Κάντε κλικ στο κουμπί Αναζήτηση για να εκτελέσετε την αναζήτηση.'),
(65162, 3253, 17, 'Προβολή μόνο των δικών μου'),
(65163, 3254, 17, 'Καταχωρήσεις αιτιολόγησης'),
(65164, 3255, 17, 'Αιτιολόγηση'),
(65165, 3256, 17, 'Αιτιολόγηση/ Αποθήκευση'),
(65166, 3258, 17, 'Εντάξει, ορίστε και τα υπόλοιπα'),
(65167, 3264, 17, 'Κλειδί'),
(65168, 3265, 17, 'Λέξεις κλειδιά'),
(65169, 3266, 17, 'κιλά'),
(65170, 3267, 17, 'kgr/m^2'),
(65171, 3269, 17, 'Καρκίνος νεφρού'),
(65172, 3270, 17, 'Νεφρική ανεπάρκεια'),
(65173, 3271, 17, 'Λοιμώξεις νεφρού'),
(65174, 3272, 17, 'Νεφρολιθίαση'),
(65175, 3273, 17, 'Μεταμοσχεύση νεφρού'),
(65176, 3277, 17, 'Γόνατο'),
(65177, 3278, 17, 'Προβλήματα γόνατος'),
(65178, 3279, 17, 'Αντικατάσταση γόνατος'),
(65179, 3282, 17, 'Κορεατικά'),
(65180, 3286, 17, 'Εργαστήριο'),
(65181, 3288, 17, 'Διεύθ. Ιστοσελίδας ανταλλαγής εργαστηριακών'),
(65182, 3289, 17, 'ID Ιστοσελίδας ανταλλαγής εργαστηριακών'),
(65183, 3290, 17, 'Κωδικός κουπονιού για την Ανταλλαγή εργαστηριακών'),
(65184, 3294, 17, 'Κατάσταση ερωτήματος εργαστηριακών'),
(65185, 3295, 17, 'Αναφορά εργαστηριακών'),
(65186, 3296, 17, 'Αποτελέσμα εργαστηριακών'),
(65187, 3297, 17, 'Αποτελέσματα εργαστηρ.'),
(65188, 3299, 17, 'Αναφορά Αποτελεσμάτων εργαστηριακών'),
(65189, 3300, 17, 'Υπηρεσίες εργαστηριακών'),
(65190, 3301, 17, 'Αποτελέσματα εργαστηριακών τεστ'),
(65191, 3303, 17, 'Ετικέτα'),
(65192, 3304, 17, 'Η ετικέτα δεν μπορεί να είναι κενή'),
(65193, 3305, 17, 'Στήλες ετικέτας'),
(65194, 3306, 17, 'Ετικέτες γι''αυτόν τον τύπο'),
(65195, 3307, 17, 'Οι Στήλες Ετικέτας πρέπει να είναι αριθμός μεταξύ 1 και 999'),
(65196, 3308, 17, 'Ετικέτες'),
(65197, 3311, 17, 'Εργαστήρια'),
(65198, 3312, 17, 'Θλαστικό/ κατάσταση δέρματος'),
(65199, 3313, 17, 'Θλαστικό / Εκδορά'),
(65200, 3316, 17, 'Γλώσσα'),
(65201, 3317, 17, 'Κωδικός γλώσσας'),
(65202, 3318, 17, 'Ο ορισμός της γλώσσας προστέθηκε'),
(65203, 3319, 17, 'Εργαλείο Διεπαφής Γλώσσας'),
(65204, 3320, 17, 'Λίστα γλωσσών (εγγραφή, προαιρ. προσθήκη)'),
(65205, 3321, 17, 'Όνομα γλώσσας'),
(65206, 3322, 17, 'Γλώσσα:'),
(65207, 3324, 17, 'Κατάγεται από το Λάος'),
(65208, 3325, 17, 'Επίθετο'),
(65209, 3326, 17, 'Ημερομ. τελευτ. δραστηριότητας'),
(65210, 3328, 17, 'Ημερομ. τελευτ. χρέωσης:'),
(65211, 3330, 17, 'Ετος τελευταίου ημερολογίου'),
(65212, 3333, 17, 'Τελευταία επίσκεψη'),
(65213, 3340, 17, 'Τελευταίο επίπεδο που χρεώθηκε'),
(65214, 3343, 17, 'Τελευταίος μήνας'),
(65215, 3344, 17, 'Επώνυμο'),
(65216, 3345, 17, 'Επώνυμο'),
(65217, 3346, 17, 'Επώνυμο:'),
(65218, 3350, 17, 'Τελευταία ανασκόπηση'),
(65219, 3351, 17, 'Η τελευταί εκτέλεση άρχισε στις'),
(65220, 3352, 17, 'Τελευταία αποθήκευση'),
(65221, 3356, 17, 'Τελευταία ενημέρωση από'),
(65222, 3357, 17, 'Τελευταία επαλήθευση στις'),
(65223, 3358, 17, 'Τελευταία επίσκεψη'),
(65224, 3360, 17, 'Όψιμη υποτροπή (2-12 μήνες)'),
(65225, 3361, 17, 'Έξω σφυρό'),
(65226, 3362, 17, 'Έξω σφυρό:'),
(65227, 3363, 17, 'Πλαγίωση'),
(65228, 3364, 17, 'Πλαγίωση αυτής της διαδικασίας (αν ταιριάζει)'),
(65229, 3365, 17, 'πλαγίως παρεκτοπισμένο σημείο μέγιστης ακρόασης:'),
(65230, 3373, 17, 'Βασίζεται στη Διάταξη'),
(65231, 3374, 17, 'Επεξεργ. της Διάταξης'),
(65232, 3375, 17, 'Ομάδες Διάταξης'),
(65233, 3376, 17, 'Στυλ Διάταξης'),
(65234, 3378, 17, 'Έντυπα επίσκεψης βασισμένα στη Διάταξη'),
(65235, 3379, 17, 'Διάταξη εντύπων'),
(65236, 3380, 17, 'λίβρες'),
(65237, 3381, 17, 'λίβρες'),
(65238, 3382, 17, 'LDL'),
(65239, 3383, 17, 'αφήστε κενό αν είναι ακόμα ενεργό'),
(65240, 3384, 17, 'Αφήστε κενό για να κρατήσετε το πρωτότυπο όνομα αρχείου'),
(65241, 3385, 17, 'Αφήστε κενό για να διατηρηθεί αμετάβλητος ο κωδικός πρόσβασης.'),
(65242, 3386, 17, 'Να σταλεί μήνυμα με'),
(65243, 3387, 17, 'Αφήστε το έντυπο'),
(65244, 3388, 17, 'Αφήνοντας την φράση πρόσβασης κενή δεν θα κρυπτογραφηθεί το έγγραφο'),
(65245, 3390, 17, 'Αριστερά'),
(65246, 3391, 17, 'Αριστ. αυτί'),
(65247, 3392, 17, 'αριστ. αυτί'),
(65248, 3394, 17, 'Αριστερά:'),
(65249, 3395, 17, 'Αριστερά: '),
(65250, 3396, 17, 'Άλγος κάτω άκρου/ Μυϊκή σύσπαση'),
(65251, 3397, 17, 'Νομικό'),
(65252, 3399, 17, 'Μέγεθος Χαρτιού Legal'),
(65253, 3400, 17, 'Υπόμνημα:'),
(65254, 3401, 17, 'Μήκος'),
(65255, 3402, 17, 'Μήκος τροποποιητή, 0 αν κανένας'),
(65256, 3403, 17, 'Μικρότερο από'),
(65257, 3404, 17, 'Μικρότερο ή ίσο από'),
(65258, 3405, 17, 'Λιγότερο Ευαίσθητα προσωπ. δεδομένα (εγγραφή, προαιρετ. προσθήκη)'),
(65259, 3406, 17, 'Επιστολή'),
(65260, 3407, 17, 'Δημιουργ. Επιστολής'),
(65261, 3408, 17, 'Μέγεθος Χαρτιού Letter'),
(65262, 3409, 17, 'Επιστολή που υπογράφει ο ιατρός'),
(65263, 3410, 17, 'Επιστολή που υπογράφει ο ασθενής'),
(65264, 3411, 17, 'Βαθμός επείγοντος'),
(65265, 3412, 17, 'Ευθύνη'),
(65266, 3413, 17, 'Ιατρική ευθύνη'),
(65267, 3414, 17, 'Αρ. άδειας οδήγησης / Α.Δ.Τ.'),
(65268, 3419, 17, 'Επώνυμο Αδειοδοτημένου Συνταγογράφου'),
(65269, 3420, 17, 'Εθνικός Κωδικός Αδειοδοτημένου Συνταγογράφου'),
(65270, 3421, 17, 'UPIN Αδειοδοτημένου Συνταγογράφου'),
(65271, 3423, 17, 'Τρόπος ζωής'),
(65272, 3424, 17, 'Κατάσταση τρόπου ζωής'),
(65273, 3425, 17, 'Ρήξη συνδέσμου ή Διάστρεμμα'),
(65274, 3426, 17, 'Ελαφρός καπνιστής'),
(65275, 3428, 17, 'Όριο συμβάντων'),
(65276, 3429, 17, 'Όρια'),
(65277, 3431, 17, 'Σύνδεσμος'),
(65278, 3432, 17, 'Σύνδεσμος με τον Ασθενή'),
(65279, 3433, 17, 'Συνδεδεμένο'),
(65280, 3434, 17, 'Συνδεδεμένο έγγραφο'),
(65281, 3436, 17, 'συνδεδεμένο με έγγραφο'),
(65282, 3438, 17, 'Κατάλογος'),
(65283, 3439, 17, 'πλαίσιο λίστας'),
(65284, 3440, 17, 'πλαίσιο λίστας'),
(65285, 3441, 17, 'πλαίσιο λίστας με προσθήκη'),
(65286, 3442, 17, 'πλαίσιο λίστας με προσθήκη'),
(65287, 3443, 17, 'Επεξεργ. Καταλόγου'),
(65288, 3444, 17, 'Κατάλογος επισκέψεων'),
(65289, 3445, 17, 'Κατάλογος ομάδων'),
(65290, 3446, 17, 'Κατάλογος Ασφαλ. Εταιρειών'),
(65291, 3448, 17, 'Ο κατάλογος αντικειμ. δεν μπορεί να αρχίζει με αριθμό.'),
(65292, 3449, 17, 'Ο κατάλογος αντικειμ. περιέχει ανεπίτρεπτους χαρακτήρες.'),
(65293, 3451, 17, 'Κατάλογος καταλόγων'),
(65294, 3452, 17, 'Κατάλογος ονόματος'),
(65295, 3453, 17, 'Τα ονόματα καταλόγου δεν μπορεί να ξεκινούν με αριθμούς.'),
(65296, 3454, 17, 'Κατάλογος Συνταγών'),
(65297, 3455, 17, 'Λίστα που χρησιμοποιείται από την παραπάνω επιλογή Τύπου Δεδομένου Χώρας.'),
(65298, 3456, 17, 'Λίστα που χρησιμοποιείται από την παραπάνω επιλογή Τύπου Δεδομένου Νομού.'),
(65299, 3457, 17, 'Η θύρα στην οποία ακούει ο διακομιστής syslog RFC 5425 TLS'),
(65300, 3458, 17, 'Κατάλογοι'),
(65301, 3459, 17, 'Λιθουανικά'),
(65302, 3460, 17, 'Διαθήκη συνταχθείσα εν ζωή'),
(65303, 3461, 17, 'Αριστερός κάτω λοβός:'),
(65304, 3462, 17, 'Τελευταία έμμηνος ρύση'),
(65305, 3464, 17, 'Φόρτωση Ορισμών'),
(65306, 3465, 17, 'Φόρτωση Ρυθμίσεων Εργαστηρίου'),
(65307, 3466, 17, 'Φόρτωση Ρυθμίσεων Ερωτήσεων QE'),
(65308, 3467, 17, 'Φόρτωση Ορισμών Παραγγελίας'),
(65309, 3470, 17, 'ΦΟΡΤΩΝΕΤΑΙ'),
(65310, 3471, 17, 'Φόρτωση των αρχείων στη βάση δεδομένων. Αυτό θα πάρει λίγο χρόνο...'),
(65311, 3472, 17, 'Επίπεδο συνείδησης'),
(65312, 3473, 17, 'Τοπικό'),
(65313, 3476, 17, 'Γλώσσα'),
(65314, 3477, 17, 'Τοπικότητα'),
(65315, 3478, 17, 'Τοποθεσία'),
(65316, 3479, 17, 'εντοπισμός της μηχανής LibreEHR. Μπορεί να περιέχει ευαίσθητα δεδομένα. Συνιστάται να διαγράψετε χειροκίνητα τα αρχεία μετά τη χρήση του'),
(65317, 3480, 17, 'Τοποθεσία αυτής της παρτίδας'),
(65318, 3481, 17, 'Άγνωστη Τοποθεσία'),
(65319, 3482, 17, 'Τοποθεσία αποθήκευσης των Fax από το Hylafax.'),
(65320, 3483, 17, 'Τοποθεσία όπου αποθηκεύονται οι σαρώσεις.'),
(65321, 3484, 17, 'Τοποθεσία:'),
(65322, 3485, 17, 'Κλείδωμα'),
(65323, 3492, 17, 'Είσοδος'),
(65324, 3493, 17, 'Είσοδος'),
(65325, 3494, 17, 'Έξοδος'),
(65326, 3495, 17, 'Συνδέθηκε σε'),
(65327, 3496, 17, 'Συνδέθηκε ως'),
(65328, 3497, 17, 'Συνδέθηκε ως: '),
(65329, 3498, 17, 'Αποσυνδέθηκε.'),
(65330, 3499, 17, 'Γίνεται σύνδεση'),
(65331, 3500, 17, 'Σύνδεση'),
(65332, 3501, 17, 'σύνδεση'),
(65333, 3503, 17, 'Σύνδεση με απομεμακρυσμένο host'),
(65334, 3504, 17, 'Η σύνδεση με αυτόν τον απομεμακρυσμένο host απέτυχε'),
(65335, 3505, 17, 'Αποσύνδεση'),
(65336, 3506, 17, 'αποσύνδεση'),
(65337, 3507, 17, 'Αρχεία Καταγραφής'),
(65338, 3508, 17, 'Προβολή Καταγραφών'),
(65339, 3510, 17, 'Αναζήτηση'),
(65340, 3511, 17, 'Παρτίδα'),
(65341, 3512, 17, 'Λείπει ο Κωδικός παρτίδας!'),
(65342, 3513, 17, 'Αριθμός παρτίδας'),
(65343, 3514, 17, 'Χαμηλό'),
(65344, 3515, 17, 'Χαμηλή προτεραιότητα'),
(65345, 3516, 17, 'Κάτω άκρο'),
(65346, 3517, 17, 'Η χαμηλώτερη προτεραιότητα'),
(65347, 3519, 17, 'Οσφ.Μ.Σ.Σ.'),
(65348, 3520, 17, 'ΓΕΥΜΑ'),
(65349, 3521, 17, 'Γεύμα'),
(65350, 3522, 17, 'Καρκίνος του πνεύμονα'),
(65351, 3523, 17, 'Εγχείρηση καρκίνου του πνεύμονα'),
(65352, 3524, 17, 'ΠΝΕΥΜΟΝΕΣ:'),
(65353, 3525, 17, 'Πνεύμονες:'),
(65354, 3526, 17, 'Λύκος'),
(65355, 3528, 17, 'Μ'),
(65356, 3529, 17, 'Κύρια Κατηγορία'),
(65357, 3533, 17, 'Μηνύματα ταχυδρομείου απεστάλησαν'),
(65358, 3534, 17, 'Βασικό'),
(65359, 3535, 17, 'Κύρια Διεύθυνση'),
(65360, 3536, 17, 'Βασικό πάνω παράθυρο στην οθόνη'),
(65361, 3537, 17, 'Διατήρηση ενεργούς λίστας φαρμακευτικών αλλεργιών.'),
(65362, 3538, 17, 'Διατήρηση ενεργούς λίστας φαρμάκων.'),
(65363, 3539, 17, 'Διατήρηση ενημερωμένης λίστας προβλημάτων τρεχουσών και ενεργών διαγνώσεων.'),
(65364, 3540, 17, 'Κάντε αλλαγές στις τρέχουσες κατηγορίες.'),
(65365, 3541, 17, 'Νέο ραντεβού για'),
(65366, 3542, 17, 'Βεβαιωθείτε ότι "'),
(65367, 3545, 17, 'Αδιαθεσία:'),
(65368, 3548, 17, 'Άρρεν'),
(65369, 3549, 17, 'Ανδρικά προφυλακτικά'),
(65370, 3550, 17, 'Εκούσια χειρουργ. στείρωση του άνδρα'),
(65371, 3552, 17, 'Μαστογραφία'),
(65372, 3553, 17, 'διαχείριση'),
(65373, 3556, 17, 'Διαχείριση Μεταφράσεων'),
(65374, 3557, 17, 'Διαχείριση'),
(65375, 3558, 17, 'Υποχρεωτ. και συγκεκριμένα πεδία'),
(65376, 3559, 17, 'Μόνον υποχρεωτ. ή συγκεκριμένα πεδία, έλεγχος διπλής απάντησης (dup check), χωρίς αναζήτηση'),
(65377, 3560, 17, 'Μόνον υποχρεωτ. ή συγκεκριμένα πεδία, αναζήτηση και έλεγχος διπλής απάντησης (dup check)'),
(65378, 3561, 17, 'Εγχειρίδιο'),
(65379, 3562, 17, 'Χειροκίνητη αποστολή'),
(65380, 3563, 17, 'Κατασκευαστής'),
(65381, 3565, 17, 'Μάρτ.'),
(65382, 3568, 17, 'Μάρτιος'),
(65383, 3569, 17, 'Οικογεν. κατάσταση'),
(65384, 3571, 17, 'Επισημάντε ως Χρεωθέν αλλά παραλείψτε την χρέωση'),
(65385, 3572, 17, 'Επισημάντε ως Εκκαθαρισθέν'),
(65386, 3573, 17, 'Επισημάντε ως Μη Χρεωθέν'),
(65387, 3574, 17, 'Επισήμανση αυτών των αναφορών ως Αναθεωρημένες'),
(65388, 3575, 17, 'Επισημάνθηκε ως Εκκαθαρισθέν'),
(65389, 3576, 17, 'Έγγαμος/η'),
(65390, 3578, 17, 'Μάσκα'),
(65391, 3579, 17, 'Μάσκα για Αριθμ. Τιμολογίου'),
(65392, 3580, 17, 'Μάσκα για Κωδ. Ασθενών'),
(65393, 3581, 17, 'Μάσκα για Κωδ. Προϊόντων'),
(65394, 3582, 17, 'Ταίριασμα'),
(65395, 3583, 17, 'Ταίριασμα πεζών-κεφαλαίων'),
(65396, 3591, 17, 'Μεγ.'),
(65397, 3592, 17, 'μέγιστος αριθμών αρχείων - φορτώστε ξανά τα ονόματα παρακάτω'),
(65398, 3594, 17, 'Δεξιά άνω γνάθος:'),
(65399, 3595, 17, 'Μέγιστη Ηλικία'),
(65400, 3596, 17, 'Μέγιστοι χαρακτήρες'),
(65401, 3597, 17, 'Max χρόνος αδρανείας σε secs, πριν την αποσύνδεση. Ο προκαθορισμένος είναι 7200 (2 ώρες)'),
(65402, 3600, 17, 'Μέγιστο μέγεθος εύλογης απογραφής αποθεμάτων και, εάν δεν ισχύει, θα μπει το 0'),
(65403, 3601, 17, 'Μέγιστο μέγεθος'),
(65404, 3602, 17, 'Μέγιστο μέγεθος (αν εισάγετε το 0 θα επιτραπεί οποιοδήποτε μέγεθος)'),
(65405, 3603, 17, 'Μάιος'),
(65406, 3604, 17, 'Master Card'),
(65407, 3605, 17, 'mcg'),
(65408, 3607, 17, 'Κανένας από τους 3 τελευταίους κωδικούς δεν επιτρέπονται όταν αλλάζετε κωδικό πρόσβασης.'),
(65409, 3609, 17, 'Κωδικός Ομάδας Μέτρησης'),
(65410, 3611, 17, 'Μέτρηση'),
(65411, 3612, 17, 'Έσω σφυρός:'),
(65412, 3613, 17, 'Ταμείο Κοινων. Πρόνοιας (Medicaid)'),
(65413, 3614, 17, 'Ιατρικό'),
(65414, 3615, 17, 'Ιατρική Άμβλωση'),
(65415, 3616, 17, 'Ιατρική Διοίκηση'),
(65416, 3617, 17, 'Ιατρικό Ιστορικό'),
(65417, 3618, 17, 'Ιατρικό Θέμα'),
(65418, 3619, 17, 'Ιατρικό θέμα'),
(65419, 3620, 17, 'Συνοδός Νόσος/Πάθηση'),
(65420, 3621, 17, 'Ιατρικό Πρόβλημα'),
(65421, 3622, 17, 'Ιατρικά Προβλήματα'),
(65422, 3623, 17, 'Συνοδές Νόσοι/Παθήσεις'),
(65423, 3624, 17, 'Ιατρικός Φάκελος'),
(65424, 3625, 17, 'Αριθμ. Φακέλου'),
(65425, 3626, 17, 'Ιατρικοί φάκελοι'),
(65426, 3627, 17, 'Ιατρικοί φάκελοι εστάλησαν'),
(65427, 3629, 17, 'Η Ιατρική Περίληψη δώθηκε'),
(65428, 3630, 17, 'Ιατρικό σύστημα'),
(65429, 3631, 17, 'Ιατρικός Τύπος'),
(65430, 3632, 17, 'Ιατρικό Ιστορικό (εγγραφή, προαιρετ. προσθήκη)'),
(65431, 3633, 17, 'Ταμείο Κοινων. Πρόνοιας (Medicaid) μέρος Β'),
(65432, 3635, 17, 'Φάρμακο'),
(65433, 3636, 17, 'Λίστα Φαρμακευτικών Αλλεργιών'),
(65434, 3637, 17, 'Λίστα Ιατρικών Προβλημάτων'),
(65435, 3638, 17, 'Λίστα Φαρμάκων'),
(65436, 3640, 17, 'Φάρμακα'),
(65437, 3641, 17, 'Φάρμακα:'),
(65438, 3642, 17, 'Μονάδες μέτρησης φαρμάκου'),
(65439, 3643, 17, 'Μέσο'),
(65440, 3645, 17, 'Έκθεση στατιστικών των μελών του Συλλόγου'),
(65441, 3646, 17, 'Προβλ. μνήμης'),
(65442, 3647, 17, 'Άνδρες'),
(65443, 3648, 17, 'Άνδρες και Γυναίκες'),
(65444, 3649, 17, 'Μόνον άνδρες'),
(65445, 3650, 17, 'Εμμηναρχή'),
(65446, 3651, 17, 'Εμμηνόπαυση'),
(65447, 3652, 17, 'Καταμήνια ροή'),
(65448, 3653, 17, 'Καταμήνια συχνότητα'),
(65449, 3654, 17, 'Ψυχική Ασθένεια'),
(65450, 3657, 17, 'Συγχώνευση'),
(65451, 3658, 17, 'Πλήρης συγχώνευση'),
(65452, 3659, 17, 'Συγχώνευση ασθενών'),
(65453, 3661, 17, 'Μήνυμα'),
(65454, 3662, 17, 'Κέντρο Μηνυμάτων και Υπενθυμίσεων'),
(65455, 3663, 17, 'Το περιεχόμενο του μηνύματος δεν ειναι απλό κείμενο και, έτσι, αποθκεύθηκε ως έγγραφο.'),
(65456, 3665, 17, 'Το μήνυμα εστάλη'),
(65457, 3666, 17, 'Κατάσταση Μηνυμάτων'),
(65458, 3669, 17, 'Είδος μηνύματος'),
(65459, 3670, 17, 'ΜΗΝΥΜΑ:'),
(65460, 3671, 17, 'Μηνύματα'),
(65461, 3672, 17, 'Μηνύματα που στείλατε σήμερα'),
(65462, 3673, 17, 'Μέθοδος'),
(65463, 3674, 17, 'Μέθοδος και Ειδικό Προϊόν'),
(65464, 3675, 17, 'Μέθοδος αποστολής εξερχομ. e-mails'),
(65465, 3676, 17, 'Μέθοδος Kαταστροφής'),
(65466, 3677, 17, 'Μεξικανικά'),
(65467, 3679, 17, 'mg'),
(65468, 3680, 17, 'mg/1cc'),
(65469, 3681, 17, 'mg/2cc'),
(65470, 3682, 17, 'mg/3cc'),
(65471, 3683, 17, 'mg/4cc'),
(65472, 3684, 17, 'mg/5cc'),
(65473, 3685, 17, 'mg/dl'),
(65474, 3686, 17, 'Μέσο'),
(65475, 3687, 17, 'Μεσαίο όνομα'),
(65476, 3688, 17, 'Μεσαίο όνομα'),
(65477, 3696, 17, 'Μετανάστης ή εποχιακά εργαζόμενος;'),
(65478, 3697, 17, 'Μετανάστης/Εποχιακός'),
(65479, 3702, 17, 'MimeType'),
(65480, 3703, 17, 'Ελαχ.'),
(65481, 3704, 17, 'λεπτά'),
(65482, 3705, 17, 'Ελάχιστη Ηλικία'),
(65483, 3706, 17, 'Ήπιο διάστρεμμα άρθρωσης +/- Θυλακίτις'),
(65484, 3708, 17, 'Λεπτό'),
(65485, 3709, 17, 'λεπτά'),
(65486, 3710, 17, 'λεπτά'),
(65487, 3712, 17, 'Διάφορα'),
(65488, 3713, 17, 'Διάφορες Eπιλογές χρέωσης'),
(65489, 3714, 17, 'Διάφορες Eπιλογές χρέωσης HCFA-1500'),
(65490, 3715, 17, 'Διάφορες Eπιλογές χρέωσης HCFA'),
(65491, 3716, 17, 'Διάφορα'),
(65492, 3717, 17, 'Λείπει'),
(65493, 3718, 17, 'λείπει'),
(65494, 3719, 17, 'Λείπει ένα απαραίτητο πεδίο'),
(65495, 3720, 17, 'Αμοιβή λείπει'),
(65496, 3722, 17, 'Λείπει ή είναι άκυρο'),
(65497, 3723, 17, 'Κωδικός ασθενούς λείπει'),
(65498, 3724, 17, 'Λείπει ημερομ. αναφοράς'),
(65499, 3725, 17, 'Λείπει η κάθετος μετά τον πληρωτή στην πηγή για τον κώδικα '),
(65500, 3726, 17, 'Μικτό'),
(65501, 3727, 17, 'ml'),
(65502, 3728, 17, 'Μήνας/Ημέρα/Έτος'),
(65503, 3729, 17, 'mm/Hg'),
(65504, 3730, 17, 'mmHg'),
(65505, 3731, 17, 'MMR 1'),
(65506, 3732, 17, 'MMR 2'),
(65507, 3733, 17, 'Κινητό'),
(65508, 3734, 17, 'Κινητό τηλέφ.'),
(65509, 3735, 17, 'Τροποπ'),
(65510, 3738, 17, 'Μέτρια Προτεραιότητα'),
(65511, 3740, 17, 'Μέτρια/Χαμηλή Προτεραιότητα'),
(65512, 3741, 17, 'Τροποποιητής'),
(65513, 3742, 17, 'Τροποποιητές'),
(65514, 3743, 17, 'Τροποποίηση'),
(65515, 3745, 17, 'Τροποποίηση πληρωμών'),
(65516, 3746, 17, 'ΜήκοςΤροποποιητή'),
(65517, 3753, 17, 'Δευτ.'),
(65518, 3754, 17, 'Δευτ.- Παρ.'),
(65519, 3755, 17, 'Δευτ., Τετ. &amp; Παρ.'),
(65520, 3756, 17, 'Δευτέρα'),
(65521, 3758, 17, 'Μήνας'),
(65522, 3759, 17, 'μήνας'),
(65523, 3760, 17, 'Προβολή Μηνός'),
(65524, 3761, 17, 'Μήνας (-ες)'),
(65525, 3762, 17, 'Μηνιαίο εισόδημα'),
(65526, 3763, 17, 'Μήνες'),
(65527, 3765, 17, 'Βρέθηκαν πάνω από 100 καταχωρήσεις. Παρακαλώ περιορίστε τα κριτήρια αναζήτησης.'),
(65528, 3766, 17, 'Πάνω από 50 αποτελέσματα, παρακαλώ εξειδικεύστε την αναζήτηση σας.'),
(65529, 3767, 17, 'Μπορείτε να κάνετε κλικ στις περισσότερες κεφαλίδες στηλών για να αλλάξετε τη σειρά ταξινόμησης.'),
(65530, 3768, 17, 'Πλέον πρόσφατο από'),
(65531, 3770, 17, 'Πλέον πρόσφατα ζωτικά από:'),
(65532, 3771, 17, 'Μητέρα'),
(65533, 3772, 17, 'Όνομα μητέρας'),
(65534, 3774, 17, 'Στόμα'),
(65535, 3775, 17, 'Κίνηση'),
(65536, 3776, 17, 'Μετακίνηση Εγγράφου στην Κατηγορία:'),
(65537, 3777, 17, 'Μετακίνηση προς τα κάτω'),
(65538, 3778, 17, 'Η μετακίνηση απέτυχε!'),
(65539, 3779, 17, 'Μετακίνηση σε Ασθενή'),
(65540, 3780, 17, 'Μετακίνηση σε ...'),
(65541, 3781, 17, 'Μετακίνηση προς τα πάνω'),
(65542, 3782, 17, 'Γίνεται μετακίνηση'),
(65543, 3783, 17, 'Κος.'),
(65544, 3785, 17, 'Κα.'),
(65545, 3786, 17, 'Δις.'),
(65546, 3796, 17, 'Πολυγλωσσικό εργαλείο'),
(65547, 3797, 17, 'Πολλαπλές περιοχές'),
(65548, 3798, 17, 'Πολλαπλά αρχεία μπορούν να φορτωθούν σε ένα χρόνο με την επιλογή τους χρησιμοποιώντας το συνδυασμό πλήκτρων CTRL + κλικ ή Shift + κλικ.'),
(65549, 3799, 17, 'Πολλαπλοί κωδικοί παρτίδας'),
(65550, 3800, 17, 'Πολλαπλοί τροποποιητές μπορούν να διαχωριστούν με άνω και κάτω τελείες ή κενά, μέγιστο 4 (M1: M2: M3: Μ4)'),
(65551, 3802, 17, 'Πολυφυλετικό'),
(65552, 3803, 17, 'Φύσημα:'),
(65553, 3804, 17, 'Μυαλγία'),
(65554, 3805, 17, 'Μυαλγίες'),
(65555, 3806, 17, 'Μυϊκή ερυθρότητα'),
(65556, 3807, 17, 'Μυϊκή δυσκαμψία'),
(65557, 3808, 17, 'Μυϊκό οίδημα'),
(65558, 3809, 17, 'Μυϊκή θερμότης'),
(65559, 3810, 17, 'Μυς'),
(65560, 3811, 17, 'Κάκωση μυός'),
(65561, 3812, 17, 'Μυοσκελετικό'),
(65562, 3813, 17, 'Πρέπει να είναι κενό αν δεν χρησιμοποιείται η πιστοποίηση SMTP'),
(65563, 3814, 17, 'Αμοιβαίως καθορισμένο'),
(65564, 3815, 17, 'Αυτοκιν/κό ατύχημα'),
(65565, 3818, 17, 'Εγώ ο ίδιος'),
(65566, 3821, 17, 'ΜΗ ΔΙΑΘ.'),
(65567, 3822, 17, 'μή διαθ.'),
(65568, 3823, 17, 'Όνομα'),
(65569, 3825, 17, 'Όνομα (κάντε κλικ για περισσότερα)'),
(65570, 3826, 17, 'Όνομα 1'),
(65571, 3827, 17, 'Όνομα 2'),
(65572, 3828, 17, 'Όνομα και Τίτλος του Εμβολιαστού'),
(65573, 3831, 17, 'Όνομα των Συμβάντων'),
(65574, 3832, 17, 'Όνομα Ασφαλ. Εταιρείας'),
(65575, 3833, 17, 'Όνομα Παρόχου'),
(65576, 3834, 17, 'Όνομα αποστολέα για τις υπενθυμίσεις ασθενών'),
(65577, 3835, 17, 'Μετάφραση ονόματος'),
(65578, 3836, 17, 'Όνομα/Αξία'),
(65579, 3837, 17, 'Όνομα:'),
(65580, 3838, 17, 'ΡΩΘΩΝΕΣ:'),
(65581, 3839, 17, 'Ρώθωνες: Δεξιά κ.φ.'),
(65582, 3840, 17, 'Ρινικός βλεννογόνος ροζ, Διάφραγμα στη μέση γραμμή'),
(65583, 3844, 17, 'Εθνικότητα'),
(65584, 3847, 17, 'Αυτόχθων εκ Χαβάης ή άλλης Νήσου του Ειρηνικού'),
(65585, 3852, 17, 'Ναυτία'),
(65586, 3854, 17, 'Πλοήγηση'),
(65587, 3855, 17, 'Η περιοχή πλοήγησης περιέχει έντυπα επίσκεψης'),
(65588, 3856, 17, 'Η περιοχή πλοήγησης χρησιμοποιεί όλο το ύψος του πλαισίου'),
(65589, 3857, 17, 'Έντυπα Επίσκεψης Περιοχής Πλοήγησης'),
(65590, 3858, 17, 'Εύρος περιοχής πλοήγησης'),
(65591, 3859, 17, 'Μενού πλοήγησης αποτελείται από ζεύγη radio buttons'),
(65592, 3860, 17, 'To Μενού πλοήγησης είναι προβολή δέντρου'),
(65593, 3861, 17, 'Η Πλοήγηση χρήσιμοποιεί μενού ολίσθησης'),
(65594, 3862, 17, 'Κωδικός φαρμάκου'),
(65595, 3863, 17, 'Δεδομένα NDC'),
(65596, 3864, 17, 'Αριθμός κωδικού φαρμάκου'),
(65597, 3866, 17, 'Αυχένας'),
(65598, 3867, 17, 'Προβλ. αυχένος'),
(65599, 3868, 17, 'Υποστήριξη αυχένος'),
(65600, 3869, 17, 'Πρέπει να εισάγετε μια περιγραφή'),
(65601, 3870, 17, 'Πρέπει να εισάγετε μια Τιμή Επιστροφής'),
(65602, 3871, 17, 'Πρέπει να εισάγετε κωδ. αναγνώρισης'),
(65603, 3872, 17, 'Πρέπει να εισάγετε τίτλο'),
(65604, 3873, 17, 'Απαιτείται Εξουσιοδ.'),
(65605, 3874, 17, 'Απαιτείται Αιτιολόγηση'),
(65606, 3875, 17, 'Απαιτεί δευτερογενή χρέωση'),
(65607, 3876, 17, 'Αρνητικό'),
(65608, 3877, 17, 'Αρνητικά'),
(65609, 3880, 17, 'Κάκωση νεύρου'),
(65610, 3881, 17, 'Νευρολ. κατάσταση / Βλάβη νεύρου'),
(65611, 3882, 17, 'Νευρολ. αιμωδία'),
(65612, 3883, 17, 'Νευρολ. Αδυναμία'),
(65613, 3884, 17, 'Νευρολογικό'),
(65614, 3885, 17, 'Ποτέ'),
(65615, 3886, 17, 'Ποτέ οινόπνευμα'),
(65616, 3887, 17, 'Ποτέ καπνιστής'),
(65617, 3888, 17, 'Νέο'),
(65618, 3889, 17, 'Νέο =>');
INSERT INTO `lang_definitions` VALUES
(65619, 3890, 17, 'Νέοι Αποδέκτες'),
(65620, 3892, 17, 'Νέα Αλλεργία'),
(65621, 3894, 17, 'Νέο Ραντεβού'),
(65622, 3895, 17, 'Νέες Κατηγορίες'),
(65623, 3896, 17, 'Νέα Κατηγορία'),
(65624, 3897, 17, 'Νέοι Πελάτες'),
(65625, 3898, 17, 'Νέα Επίσκεψη'),
(65626, 3900, 17, 'Νέο σύνολο Ορισμών εισήχθη'),
(65627, 3901, 17, 'Νέο Έγγραφο'),
(65628, 3902, 17, 'Νέα Έγγραφα'),
(65629, 3904, 17, 'Νέα Επίσκεψη'),
(65630, 3905, 17, 'Δημιουργήθηκε νέα επίσκεψη με αναγνωριστικό'),
(65631, 3906, 17, 'Νέο Έντυπο Επίσκεψης'),
(65632, 3907, 17, 'Νέες επισκέψεις δεν επιτρέπονται'),
(65633, 3908, 17, 'Νέα επισκ'),
(65634, 3909, 17, 'Πληροφ. Νέας Έδρας'),
(65635, 3910, 17, 'Νέο αρχείο'),
(65636, 3911, 17, 'Νέα αρχεία'),
(65637, 3912, 17, 'Νέα Ομάδα'),
(65638, 3913, 17, 'Πληροφ. για Νέα Ομάδα'),
(65639, 3916, 17, 'Νέο Όριο Συμβάντων'),
(65640, 3917, 17, 'Νέος Κατάλογος'),
(65641, 3918, 17, 'Νέες Εντολές'),
(65642, 3919, 17, 'Νέα Παράγραφος'),
(65643, 3920, 17, 'Νέος Κωδικός'),
(65644, 3921, 17, 'Νέος Ασθενής'),
(65645, 3922, 17, 'ΝΕΟΣ ΑΣΘΕΝΗΣ'),
(65646, 3923, 17, 'Νέα Επίσκεψη ασθενούς'),
(65647, 3924, 17, 'Νέο Έντυπο Ασθενούς'),
(65648, 3925, 17, 'Νέος Κωδικός Ασθενούς'),
(65649, 3926, 17, 'Νέα Πληρωμή'),
(65650, 3928, 17, 'Νέος Ασθ'),
(65651, 3929, 17, 'Νέα αποτελέσματα από την Ανταλλαγή Εργαστηριακών'),
(65652, 3930, 17, 'Νέα Αναζήτηση'),
(65653, 3931, 17, 'Νέες Αποστολές'),
(65654, 3932, 17, 'Νέος Χρήστης'),
(65655, 3934, 17, 'Νέα Επίσκεψη'),
(65656, 3935, 17, 'Νέος/Αναζήτηση'),
(65657, 3961, 17, 'Εφημερίδα'),
(65658, 3962, 17, 'Επόμενο'),
(65659, 3964, 17, 'Επόμενη Ημέρα'),
(65660, 3965, 17, 'Επόμενος Μήνας'),
(65661, 3966, 17, 'Επόμ. Μήνας (κρατήστε πατημένο για εμφάνιση μενού)'),
(65662, 3967, 17, 'Επόμενη προγραμματισμένη εκτέλεση'),
(65663, 3968, 17, 'Επόμενη Εβδομάδα'),
(65664, 3969, 17, 'Επόμ. έτος (κρατήστε πατημένο για εμφάνιση μενού)'),
(65665, 3971, 17, 'Ψευδώνυμο'),
(65666, 3973, 17, 'Νυχτερινές εφιδρώσεις'),
(65667, 3974, 17, 'έξω γεννητ. όργανα, κολπικός βλενν., τράχηλος'),
(65668, 3975, 17, 'Όχι'),
(65669, 3976, 17, 'ΟΧΙ'),
(65670, 3977, 17, 'Καμία πρόσβαση'),
(65671, 3978, 17, 'Καμία ενεργός υπενθύμιση ασθενούς.'),
(65672, 3979, 17, 'Καμία αδενοπάθεια (απαιτούνται 2 περιοχές)'),
(65673, 3980, 17, 'Δεν βρέθηκε καμία προσαρμογή του είδους αιτιολόγησης για'),
(65674, 3981, 17, 'Καμία ευαισθησία των εξαρτημάτων/μάζες'),
(65675, 3983, 17, 'Κανένα Ραντεβού'),
(65676, 3985, 17, 'Κανένα σύστημα χρέωσης δεν είναι ενεργό'),
(65677, 3986, 17, 'Δεν βρέθηκαν καθόλου λογαριασμοί να περιληφθούν στην εξαγωγή OFX'),
(65678, 3987, 17, 'Δεν βρέθηκαν χρεώσεις να περιληφθούν στην Εξαγωγή Ανοικτής Οικονομ. Ανταλλαγής <br>'),
(65679, 3989, 17, 'Δεν έχει καθοριστεί κωδικός!'),
(65680, 3992, 17, 'Καμία Διάγνωση'),
(65681, 3993, 17, 'Δεν βρέθηκαν Έγγραφα'),
(65682, 3994, 17, 'Αδύνατη η δημιουργία Επίσκεψης'),
(65683, 3995, 17, 'Καμία ημερομ. λήξης'),
(65684, 3996, 17, 'Δεν βρέθηκαν εγγραφές, χρησιμοποιήστε την παρακάτω φόρμα για να προσθέσετε μια καταχώρηση.'),
(65685, 3997, 17, 'Δεν βρέθηκαν σφάλματα'),
(65686, 3998, 17, 'Κανένα συμβάν'),
(65687, 4001, 17, 'Καμία ομάδα δεν έχει επιλεγεί'),
(65688, 4002, 17, 'Καμία κήλη'),
(65689, 4005, 17, 'Καμία κάκωση/ νόσος'),
(65690, 4006, 17, 'Δεν βρέθηκαν Ασφαλιστικές Εταιρείες'),
(65691, 4007, 17, 'Κανένα Θέμα'),
(65692, 4008, 17, 'Δεν υπάρχουν θέματα σε αυτή την επίσκεψη'),
(65693, 4009, 17, 'Δεν υπάρχουν αντικείμενα στην επιλεγμένη κατηγορία'),
(65694, 4010, 17, 'Δεν έχουν επιλεγεί αντικείμενα!'),
(65695, 4025, 17, 'Δεν υπάρχει αρχείο καταγραφής για την επιλεχθείσα ημερομηνία'),
(65696, 4027, 17, 'Χωρίς μάζες, ευαισθησία'),
(65697, 4028, 17, 'Για τον Κωδικό Επαναταυτοποίησης που ζητάτε, ΔΕΝ βρέθηκε καμία αντιστοιχία με Φάκελο Ασθενούς'),
(65698, 4029, 17, 'Δεν βρέθηκε καμία αντιστοιχία. Δοκιμάστε ξανά μια αναζήτηση.'),
(65699, 4030, 17, 'Δε βρέθηκαν αντιστοιχίες.'),
(65700, 4031, 17, 'Δεν βρέθηκαν αντιστοιχίες. Να δημιουργηθεί τώρα Νέος Ασθενής;'),
(65701, 4032, 17, 'Δεν βρέθηκαν φάκελοι που να ταιριάζουν'),
(65702, 4033, 17, 'Δεν βρέθηκαν νέα αποτελέσματα'),
(65703, 4034, 17, 'Καμμία σημείωση'),
(65704, 4035, 17, 'Χωρίς οργανομεγαλία'),
(65705, 4036, 17, 'Δεν βρέθηκαν ανοίγματα για αυτήν την περίοδο.'),
(65706, 4037, 17, 'Δεν καταγράφεται άλλος τηλεφωνικός αριθμός'),
(65707, 4039, 17, 'Δεν βρέθηκαν Συνεργάτες'),
(65708, 4040, 17, 'Δεν βρέθηκε Φάκελος Ασθενούς με αυτά τα κριτήρια επιλογής'),
(65709, 4041, 17, 'ΔΕΝ βρέθηκε Φάκελος Ασθενούς για τον κωδικό που αναζητάτε,'),
(65710, 4042, 17, 'Χωρίς περιφερικό οίδημα'),
(65711, 4043, 17, 'Δεν βρέθηκαν Φαρμακεία'),
(65712, 4044, 17, 'Δεν βρέθηκαν Συνταγές'),
(65713, 4045, 17, 'Καμία παρούσα ασθένεια/ κάκωση'),
(65714, 4046, 17, 'Καμία προηγούμενη εγγραφή.'),
(65715, 4047, 17, 'Δεν επιλέχθηκε καμία Πρωτογενής Επιχειρηματική Οντότητα στη λίστα με τις Έδρες'),
(65716, 4048, 17, 'Χωρίς προηγούμενες επισκέψεις'),
(65717, 4049, 17, 'Δεν υπάρχουν διαδικασίες σε αυτή την επίσκεψη'),
(65718, 4051, 17, 'Δεν βρέθηκαν Πάροχοι'),
(65719, 4052, 17, 'Χωρίς εξάνθημα ή ανώμαλες βλάβες'),
(65720, 4053, 17, 'Δεν βρέθηκαν καταχωρήσεις'),
(65721, 4055, 17, 'Δεν βρέθηκαν καταχωρήσεις. Παρακαλώ επεκτείνατε τα κριτήρια αναζήτησης σας.'),
(65722, 4056, 17, 'Καμία Υπενθύμιση'),
(65723, 4057, 17, 'Δεν βρέθηκαν αποτελέσματα για τα ανωτέρω κριτήρια.'),
(65724, 4058, 17, 'Χωρίς αποτελέσματα'),
(65725, 4059, 17, 'Δεν βρέθηκαν αποτελέσματα'),
(65726, 4060, 17, 'Χωρίς αποτελέσματα από την Αναζήτηση'),
(65727, 4061, 17, 'Χωρίς αποτελέσματα, παρακαλώ ξαναδοκιμάστε.'),
(65728, 4062, 17, 'Χωρίς αποτέλεσμα, παρακαλώ δοκιμάστε ξανά.'),
(65729, 4063, 17, 'Χωρίς αποτέλεσμα, παρακαλώ δοκιμάστε ξανά.'),
(65730, 4065, 17, 'Δεν προσήλθε'),
(65731, 4067, 17, 'Χωρίς ευαισθησία ηγμορίων'),
(65732, 4068, 17, 'Χωρίς εισολκή δέρματος η οζίδια μαστού'),
(65733, 4070, 17, 'Δεν επελέγη πίνακας! Επιλέξτε έναν Πίνακα'),
(65734, 4071, 17, 'Χωρίς ορχική ευαισθησία, μάζες'),
(65735, 4072, 17, 'Χωρίς ρίγη ή αναγούλες'),
(65736, 4075, 17, 'Καμία επίσκεψη'),
(65737, 4076, 17, 'Δεν κατεγράφησαν ζωτικά.'),
(65738, 4077, 17, 'Όχι, Ακύρωση'),
(65739, 4079, 17, 'Όχι:'),
(65740, 4080, 17, 'Νυκτουρία'),
(65741, 4081, 17, 'Μη πληρωμένο'),
(65742, 4082, 17, 'Αναφορά Μη Αναφερθέντων'),
(65743, 4083, 17, 'Μη ειδική κάκωση'),
(65744, 4084, 17, 'Μη-ηλεκτρονικά'),
(65745, 4085, 17, 'Μη Ινσουλινοεξαρτώμενος Διαβήτης'),
(65746, 4086, 17, 'Ανασφάλιστος/η'),
(65747, 4087, 17, 'Μη-αναπαραγωγική υγεία (Ιατρικό)'),
(65748, 4088, 17, 'Μη-αναπαραγωγική υγεία (Μη-ιατρικό)'),
(65749, 4089, 17, 'Κανένα'),
(65750, 4090, 17, 'κανένα'),
(65751, 4091, 17, 'Δεν ορίστηκε κανένα'),
(65752, 4092, 17, 'Δεν κατεγράφη τίποτα'),
(65753, 4093, 17, 'Κανένα από τα παραπάνω'),
(65754, 4094, 17, 'Καμία από τις επάνω γραμμές κατανομής δεν μπορεί να είναι τελείως κενή.'),
(65755, 4095, 17, 'Μη Ινσουλινοεξαρτώμενος Διαβήτης'),
(65756, 4096, 17, 'ΚΦ'),
(65757, 4097, 17, 'Κανονική'),
(65758, 4099, 17, 'Φυσιολ. εξέταση καρδιάς:'),
(65759, 4100, 17, 'Φυσιολ. εξέταση καρδιάς: '),
(65760, 4101, 17, 'Φυσιολ. εξέταση πνεύμονα:'),
(65761, 4102, 17, 'Φυσιολ. εξέταση πνεύμονα: '),
(65762, 4103, 17, 'Κανονική επίσκεψη γραφείου'),
(65763, 4104, 17, 'Φυσιολ. οροφάρυγγας:'),
(65764, 4105, 17, 'Φυσιολ. Δεξιά'),
(65765, 4106, 17, 'Φυσιολ. Δεξιά:'),
(65766, 4107, 17, 'Φυσιολ. Όψη'),
(65767, 4108, 17, 'φυσιολογικό:'),
(65768, 4109, 17, 'Κανονικά αυτό θα έπρεπε να ελεγχθεί. Άσχετο με τον έλεγχο πρόσβασης'),
(65769, 4112, 17, 'Νορβηγικά'),
(65770, 4115, 17, 'Μύτη'),
(65771, 4116, 17, 'Ρινορραγία'),
(65772, 4117, 17, 'δεν είναι γράμμα ή αριθμός'),
(65773, 4119, 17, 'Δεν είναι απαραίτητα όλα τα πεδία, για όλους τους τύπους κωδικών.'),
(65774, 4120, 17, 'Δεν επιτρέπεται'),
(65775, 4121, 17, 'Δεν επιτρέπεται να διαγράψετε την ομάδα με τους Διαχειριστές'),
(65776, 4122, 17, 'Δεν επιτρέπεται η Επεξεργασία'),
(65777, 4123, 17, 'Δεν επιτρέπεται η απενεργοποίηση όλων των αντικειμένων ασφαλείας'),
(65778, 4124, 17, 'Κατάλογος ελέγχου πρόσβασης (ACL)'),
(65779, 4125, 17, 'Δεν επιτρέπεται η κατάργηση του χρήστη admin από την ομάδα Διαχειριστές'),
(65780, 4126, 17, 'Δεν επιτρέπεται να καταργήσετε αυτόν τον χρήστη από την ομάδα Διαχειριστές'),
(65781, 4127, 17, 'Δεν ισχύει'),
(65782, 4128, 17, 'Δεν έχετε δικαίωμα πρόσβασης στο άρθρωμα PostCalendar'),
(65783, 4129, 17, 'Δεν επιτρέπεται'),
(65784, 4130, 17, 'Δεν Επιτρέπεται'),
(65785, 4131, 17, 'Δεν επιτρέπεται για αυτή την ομάδα!'),
(65786, 4132, 17, 'Δεν επιτρέπεται για αυτή την ομάδα.'),
(65787, 4133, 17, 'Δεν επιτρέπεται η διαχείρηση χρηστών!'),
(65788, 4134, 17, 'Δεν επιτρέπεται η υπογραφή αποτελεσμάτων'),
(65789, 4135, 17, 'Μη διαθέσιμο'),
(65790, 4137, 17, 'Μη Xρεωθέν'),
(65791, 4138, 17, 'Δεν επιλέχθηκε'),
(65792, 4139, 17, 'Δεν ελέγχθηκε'),
(65793, 4140, 17, 'Δεν έχει μπει κωδικός'),
(65794, 4141, 17, 'Δεν αναμένεται'),
(65795, 4143, 17, 'Δεν εξετάστηκε'),
(65796, 4144, 17, 'Δεν εξετάστηκε:'),
(65797, 4145, 17, 'Δεν εξετάστηκε: '),
(65798, 4146, 17, 'δεν βρέθηκε'),
(65799, 4148, 17, 'δεν βρέθηκε!'),
(65800, 4149, 17, 'Μη Ισπανόφωνος ή Λατίνος'),
(65801, 4150, 17, 'Δεν εγκαταστάθηκε'),
(65802, 4152, 17, 'Δεν έχει εμφανιστεί εδώ και'),
(65803, 4154, 17, 'Δεν εστάλη ακόμα'),
(65804, 4155, 17, 'Δεν Ορίστηκε'),
(65805, 4156, 17, 'Δεν Ορίστηκε.'),
(65806, 4157, 17, 'Σημείωση'),
(65807, 4158, 17, 'Κωδικοί Σημειώσεων'),
(65808, 4159, 17, 'Σημείωση: Θα απαιτηθούν 5-10 λεπτά για την πλήρη επεξεργασία μετά το κλικ που κάνετε στην εγκατάσταση'),
(65809, 4160, 17, 'Σημείωση: Θα απαιτηθούν 5-10 λεπτά για την πλήρη επεξεργασία, μετά το κλικ που κάνετε στην αναβάθμιση'),
(65810, 4161, 17, 'Σημειώστε ότι η Καταγραφή Audit πρέπει να ενεργοποιηθεί παραπάνω'),
(65811, 4162, 17, 'Τύπος σημείωσης'),
(65812, 4163, 17, 'Σημείωση: η 12:00 μεσημβρινή νοείται ωε μ.μ. και όχι ως π.μ.'),
(65813, 4164, 17, 'ΣΗΜΕΙΩΣΗ: Η εισαγωγή εξωτερ. δεδομένων μπορεί να πάρει πάνω από μια ώρα, ανάλογα με τις ρυθμίσεις του δικού σας hardware. Π.χ., ένας από τους Πίνακες RxNorm data περιέχει πάνω από 6 εκατομ. γραμμές.'),
(65814, 4165, 17, 'ΣΗΜΕΙΩΣΗ: Υποστηρίζεται μόνον η διετής Διεθνής έκδοση Snomed'),
(65815, 4166, 17, 'ΣΗΜΕΙΩΣΗ: Υποστηρίζεται, επί του παρόντος, μόνον η πλήρης Μηνιαία έκδοση RxNorm'),
(65816, 4168, 17, 'Προσοχή: Αυτές οι γραμμές κώδικα δεν έχουν γραφεί από έναν εξουσιοδοτημένο χρήστη. Μόνο εξουσιοδοτημένοι κώδικες μπορούν να φορτωθούν στο Open Medical Billing Network. Αν θέλετε να ανεβάσετε αυτές τις αλλαγές, παρακαλώ επιλέξτε έναν εξουσιοδοτημένο χρήστη εδώ.'),
(65817, 4170, 17, 'Προσοχή: Όταν γίνεται προσθήκη αρχείων με όνομα που ήδη υπάρχει, το πρόγραμμα θα μετονομάζει αυτόματα το αρχείο (π.χ. το αρχείο file.jpg θα μετονομαστεί σε file.1.jpg). Μοναδικά θεωρούνται τα ονόματα αρχείου για κάθε ασθενή, και όχι για κάθε κατηγορία.'),
(65818, 4171, 17, 'Προσοχή: Όταν γίνεται προσθήκη αρχείων με όνομα που ήδη υπάρχει, το πρόγραμμα θα μετονομάζει αυτόματα το αρχείο. Π.χ. το αρχείο file.jpg θα μετονομαστεί σε file.jpg.1. Μοναδικά θεωρούνται τα αρχεία για κάθε ασθενή, όχι για κάθε κατηγορία.'),
(65819, 4172, 17, 'Σημειώσεις'),
(65820, 4173, 17, 'Σημειώσεις – όλες οι επισκέψεις (εγγραφή, προαιρ.προσθήκη)'),
(65821, 4174, 17, 'Σημειώσεις – οι επισκέψεις μου (εγγραφή, προαιρ. προσθήκη)'),
(65822, 4175, 17, 'Σημειώσεις δεν επιτρέπονται'),
(65823, 4177, 17, 'Τίποτα δεν κατεγράφη'),
(65824, 4179, 17, 'Τίποτα για εισαγωγή στις Αλλεργίες'),
(65825, 4180, 17, 'Τίποτα για εισαγωγή στα Φάρμακα'),
(65826, 4181, 17, 'Δεν υπάρχει τίποτε προς εμφάνιση'),
(65827, 4182, 17, 'Τίποτα δεν επελέγη'),
(65828, 4184, 17, 'ΕΙΔΟΠΟΙΗΣΗ: Προσθήκη/ Αλλαγή στο PostCalendar'),
(65829, 4185, 17, 'Γνωστοποίηση'),
(65830, 4186, 17, 'Κοινοποίηση ηλεκτρον. διεύθυνσης'),
(65831, 4188, 17, 'Κοινοποιήσεις'),
(65832, 4189, 17, 'Να ειδοποιήσετε τον Διαχειριστή για Υποβολή/ Τροποποίηση Συμβάντος;'),
(65833, 4190, 17, 'Νοέμ.'),
(65834, 4191, 17, 'Νοέμβριος'),
(65835, 4192, 17, 'Αποστολή τώρα για:'),
(65836, 4193, 17, 'Εκτύπωση σε εξέλιξη'),
(65837, 4194, 17, 'Τώρα τυπώνει τις $stmt_count καταστάσεις και ενημερώνει τις επισκέψεις'),
(65838, 4195, 17, 'Τώρα τυπώνει τις $stmt_count καταστάσεις και ενημερώνει τια τιμολόγια'),
(65839, 4196, 17, 'Τώρα τυπώνει τις $stmt_count καταστάσεις. Οι επισκέψεις δεν θα ενημερωθούν'),
(65840, 4197, 17, 'Τώρα τυπώνει τις $stmt_count καταστάσεις. Τα τιμολόγια δε θα ενημερωθούν.'),
(65841, 4198, 17, 'AMKA'),
(65842, 4200, 17, 'Αριθμός'),
(65843, 4204, 17, 'Αριθμός στηλών στην προβολή έτους'),
(65844, 4211, 17, 'Αριθμός ημερών για τις οποίες το Πιστοποιητικό χρήστη ισχύει.'),
(65845, 4213, 17, 'Αριθμός ψηφίων, μετά την υποδιαστολή δεκαδικών, για το νόμισμα, σηνήθως 0 ή 2'),
(65846, 4214, 17, 'Αριθμός επισκέψεων για εμφάνιση ανά σελίδα.'),
(65847, 4215, 17, 'Αριθμός παιχνιδιών ή συμβάντων που λείπουν, αν υπάρχουν'),
(65848, 4216, 17, 'Πριν από πόσες ώρες να σταλούν ειδοποιήσιες με e-mail.'),
(65849, 4217, 17, 'Πριν από πόσες ώρες να σταλούν ειδοποιήσεις διά τηλεφώνου.'),
(65850, 4218, 17, 'Πριν από πόσες ώρες να σταλούν ειδοποιήσιες με μύνημα SMS.'),
(65851, 4221, 17, 'Αριθμός παλαιών στηλών ιστορικού'),
(65852, 4222, 17, 'Αριθμός ασθενών προς εμφάνιση ανά σελίδα, στη λίστα ασθενών'),
(65853, 4223, 17, 'Αιμωδίες'),
(65854, 4224, 17, 'Αριθμητής'),
(65855, 4225, 17, 'Σειρά εμφάνισης αριθμών'),
(65856, 4227, 17, 'Διατροφή'),
(65857, 4230, 17, 'Κορεσμός O2'),
(65858, 4231, 17, 'Παχυσαρκία Ι'),
(65859, 4232, 17, 'Παχυσαρκία ΙΙ'),
(65860, 4233, 17, 'Παχυσαρκία ΙΙΙ'),
(65861, 4234, 17, 'Κλινική εξέταση'),
(65862, 4237, 17, 'Επάγγελμα'),
(65863, 4239, 17, 'Εμφάνιση'),
(65864, 4240, 17, 'Οκτ.'),
(65865, 4241, 17, 'Οκτώβριος'),
(65866, 4242, 17, 'Δεξιός οφθαλμός'),
(65867, 4244, 17, 'της ποσότητος'),
(65868, 4245, 17, 'των δισκίων'),
(65869, 4246, 17, 'του μηνός κάθε'),
(65870, 4247, 17, 'Σημ. γραφείου'),
(65871, 4249, 17, 'Σημειώσεις γραφείου'),
(65872, 4250, 17, 'Επίσκεψη γραφείου'),
(65873, 4251, 17, 'Ομάδες Μέτρησης (CQM) Επισήμων Μετρήσεων Κλινικής Ποιότητας'),
(65874, 4252, 17, 'Σ̈́ύνδεσμος https για την offline σύνδεση στο Portal του ασθενούς'),
(65875, 4253, 17, 'Σ̈́ύνδεσμος https για την offline σύνδεση στην Πύλη Ασθενούς (σύνδεσμος Ασθενούς)'),
(65876, 4254, 17, 'Κωδικός για την Offsite Πύλη Ασθενούς'),
(65877, 4255, 17, 'Κωδικός για την Offsite Πύλη Ασθενούς (Κενό αν δεν έχει εγγραφεί)'),
(65878, 4258, 17, 'Διέυθυνση Ιστοσελίδας για την Offsite Πύλη Ασθενούς'),
(65879, 4260, 17, 'Όνομα χρήστη για την Offsite Πύλη Ασθενούς'),
(65880, 4261, 17, 'Όνομα χρήστη για την Offsite Πύλη Ασθενούς (Κενό αν δεν έχει Εγγραφεί)'),
(65881, 4263, 17, 'Απόγονοι'),
(65882, 4265, 17, 'αλοιφή (oint)'),
(65883, 4267, 17, 'Εντάξει'),
(65884, 4269, 17, 'ΟΚ σύνδεση του GCAG γεγονότος ημερομηνίας'),
(65885, 4270, 17, 'Παλαιό'),
(65886, 4272, 17, 'Παλιοί πελάτες'),
(65887, 4273, 17, 'Παλαιό κάταγμα μη / κακή επούλωση'),
(65888, 4274, 17, 'Παλαιό στυλ εμφάνισης χωρίς αριστερό μενού'),
(65889, 4275, 17, 'Παλαιό στυλ στατικού εντύπου, χωρίς αναζήτηση ή έλεγχο διπλοκαταχώρησης'),
(65890, 4279, 17, 'Παραλείψτε λεπτομέρειες εργοδότη στα Δημογραφικά ασθενούς'),
(65891, 4280, 17, 'Παραλείψτε τους Εργοδότες'),
(65892, 4281, 17, 'Παραλείψτε μορφή, οδό και μεσοδιαστήματα χορήγησης, που θα γίνουν, μετά, μέρος της δοσολογίας'),
(65893, 4282, 17, 'Παραλείψτε την Ασφαλ. Εταιρεία και μερικά άλλα πράγματα από το Έντυπο Δημογραφικών'),
(65894, 4283, 17, 'Να παραλειφθούν οι εσωτερικοί χρήστες;'),
(65895, 4284, 17, 'Στο πάνελ Συμμετοχής στην πληρωμή, παραλείψτε μέθοδο πληρωμής'),
(65896, 4285, 17, 'Αφήστε κενό, για αυτόματη συμπλήρωση από το σύστημα'),
(65897, 4286, 17, 'επί'),
(65898, 4288, 17, 'Στο χέρι'),
(65899, 4289, 17, 'Κατόπιν παραγγελίας'),
(65900, 4290, 17, 'Επιτοπίως'),
(65901, 4292, 17, 'Αν αλλάξετε τον κωδικό σας, θα πρέπει να επανασυνδεθείτε.'),
(65902, 4297, 17, 'Online Βοήθεια'),
(65903, 4298, 17, 'Link για online Βοήθεια'),
(65904, 4299, 17, 'Μόνο οι ενεργοί/ές'),
(65905, 4302, 17, 'μόνο αν πρόκειται για τοποθεσία χρέωσης'),
(65906, 4303, 17, 'Μόνο οι ανενεργοί/ές'),
(65907, 4304, 17, 'Μόνο τα δικά μου'),
(65908, 4305, 17, 'Να εμφανίζονται μόνον οι Κωδικοί Αναφοράς Διάγνωσης'),
(65909, 4307, 17, 'Να φορτώνονται μόνον οι ενεργές συνταγές'),
(65910, 4310, 17, 'Έναρξη της ασθένειας:'),
(65911, 4311, 17, 'Έναρξη της ασθένειας: '),
(65912, 4312, 17, 'Έναρξη του Οιδήματος:'),
(65913, 4313, 17, 'Έναρξη/ ημερομ. νοσηλείας:'),
(65914, 4314, 17, 'Διεύθυνση Ιστοσελίδας της Onsite Πύλης Ασθενούς'),
(65915, 4315, 17, 'Ώπα!'),
(65916, 4316, 17, 'Ανοικτό'),
(65917, 4318, 17, 'Άνοιγμα σε νέο παράθυρο'),
(65918, 4321, 17, 'Ανοιγμα σημερινής Επίσκεψης'),
(65919, 4322, 17, 'Το LibreEHR διαθέτει, ήδη εξ αρχής, ένα Πιστοπ. Εξουσιοδότησης.'),
(65920, 4323, 17, 'Κατηγορία Εφαρμογής LibreEHR'),
(65921, 4324, 17, 'Ενημέρωση βάσης δεδομένων του LibreEHR'),
(65922, 4325, 17, 'Ενημέρωση βάσης δεδομένων του LibreEHR για Απο-ταυτοποίηση'),
(65923, 4326, 17, 'Το LibreEHR δεν αναγνωρίζει το εισερχόμενο αρχείο στον κατάλογο των συνεισφορών (contrib dir). Αυτό συμβαίνει μάλλον διότι πρέπει να ρυθμίσετε την έκδοση στον Πίνακα με την υποστηριζόμενη_εξωτερική_φόρτωση_δεδομένων στη βάση δεδομένων MySQL.'),
(65924, 4327, 17, 'Το LibreEHR πρέπει να ρυθμισθεί για τη χρήση Πιστοποιητικών, πριν είναι σε θέση να δημιουργεί Πιστοποιητικά χρήστη.'),
(65925, 4328, 17, 'Το LibreEHR απαιτεί Javascript για να εκτελέσει την ταυτοποίηση του χρήστη.'),
(65926, 4329, 17, 'Χρήστες LibreEHR'),
(65927, 4330, 17, 'Ανοίγματα'),
(65928, 4332, 17, 'Οφθαλμικό'),
(65929, 4333, 17, 'Επιλογή'),
(65930, 4334, 17, 'Επιλογή μεθόδου αποθήκευσης εγγράφων.'),
(65931, 4335, 17, 'Επιλογή υποστήριξης απογραφής και πώλησης προϊόντων'),
(65932, 4336, 17, 'Προαιρετικό'),
(65933, 4337, 17, 'Προαιρετικό όνομα κατηγορίας ενός κωδικού εικόνας κάρτας που μπορεί να φαίνεται στη σελίδα σύνοψης ασθενούς'),
(65934, 4338, 17, 'Προαιρετικό όνομα κατηγορίας μιας φωτογραφίας που μπορεί να φαίνεται στη σελίδα σύνοψης ασθενούς'),
(65935, 4339, 17, 'Προαιρετικό όνομα κατηγορίας ενός εγγράφου με το οποίο να γίνεται σύνδεση, από την σελίδα Περίληψης Ασθενούς. Σας επιτρέπει να μπορείτε να δείτε το δελτίο ταυτότητας, όταν κάνετε κλικ σε έναν ασθενή'),
(65936, 4340, 17, 'Προαιρετ. default πεδίο τιμών για τη χειροκίνητη εισαγωγή αποτελεσμάτων'),
(65937, 4341, 17, 'Προαιρετ. default μονάδες για χειροκίνητη εισαγωγή αποτελεσμάτων'),
(65938, 4342, 17, 'Προαιρετ. Ονομα Προορισμού'),
(65939, 4343, 17, 'Προαιρετική ονομασία φαρμάκου, χρησιμοποιήστε το % ως wildcard'),
(65940, 4345, 17, 'Προαιρετική πληροφορία για αυτό το Συμβάν'),
(65941, 4346, 17, 'Προαιρετ. αριθμός παρτίδας, χρησιμοποιήστε το % ως wildcard'),
(65942, 4347, 17, 'Προαιρετ. αριθμητικός κωδικ. αναγνώρισης ασθενούς'),
(65943, 4348, 17, 'Προαιρετ. κωδικός διαδικασίας'),
(65944, 4349, 17, 'Προαιρετική διαδικασία/Υπηρεσία'),
(65945, 4350, 17, 'Επιλογές'),
(65946, 4351, 17, 'ή'),
(65947, 4352, 17, 'Ή'),
(65948, 4353, 17, 'ή επιλέξτε'),
(65949, 4354, 17, 'ή κάντε drag and drop για ταχύτερη επιλογή'),
(65950, 4356, 17, 'Ή να σταλεί προς'),
(65951, 4358, 17, 'ή κάντε Shift-click για να το μειώσετε'),
(65952, 4359, 17, 'Ή ανεβάστε αρχείο ηλεκτρον. εμβάσματος (ERA):'),
(65953, 4360, 17, 'Στόμα'),
(65954, 4361, 17, 'Στοματικός βλεννογόνος ροζ, λάρυγγας καθαρός'),
(65955, 4362, 17, 'Σειρά'),
(65956, 4363, 17, 'Σειρά και Τύποι αποτελεσμάτων'),
(65957, 4364, 17, 'Κατάταξη παραγγελιών'),
(65958, 4365, 17, 'Ημερομηνία Παραγγελίας'),
(65959, 4367, 17, 'Κατατάξτε από'),
(65960, 4368, 17, 'ID Παραγγελίας'),
(65961, 4369, 17, 'Η σειρά πρέπει να είναι ένας αριθμός μεταξύ 1 και 999'),
(65962, 4370, 17, 'Όνομα Παραγγελίας'),
(65963, 4371, 17, 'Προτεραιότητες παραγγελιών'),
(65964, 4372, 17, 'Επεξεργαστής παραγγελίας'),
(65965, 4373, 17, 'Αποτελέσματα παραγγελίας'),
(65966, 4374, 17, 'Κατάσταση παραγγελίας'),
(65967, 4375, 17, 'Καταστάσεις παραγγελίας'),
(65968, 4376, 17, 'Σύνοψη παραγγελίας'),
(65969, 4378, 17, 'Τύπος παραγγελίας'),
(65970, 4380, 17, 'Παραγγελία/ Τύπος αποτελεσμάτων'),
(65971, 4381, 17, 'Παραγγέλθηκε'),
(65972, 4382, 17, 'Παραγγέλθηκε από'),
(65973, 4383, 17, 'Παραγγελμένη Διαδικασία'),
(65974, 4384, 17, 'Παραγγέλων Πάροχος'),
(65975, 4386, 17, 'Βλάβη οργάνου'),
(65976, 4387, 17, 'Οργανισμός'),
(65977, 4388, 17, 'Όνομα Οργανισμού'),
(65978, 4389, 17, 'Όνομα Οργανωτική Μονάδος'),
(65979, 4390, 17, 'Οργανισμοί'),
(65980, 4391, 17, 'Προσανατολισμένο x 3'),
(65981, 4392, 17, 'Πρωτότυπο'),
(65982, 4396, 17, 'ΣΤΟΜΑΤΟΦΑΡΥΓΓΑΣ: '),
(65983, 4397, 17, 'Ορθόπνοια'),
(65984, 4398, 17, 'Αριστ. οφθαλμός'),
(65985, 4399, 17, 'Οστεοαρθρίτιδα'),
(65986, 4402, 17, 'Άλλα'),
(65987, 4403, 17, 'Άλλο'),
(65988, 4404, 17, 'Άλλο (προσδιορίστε)'),
(65989, 4405, 17, 'Άλλο - Προσδιορίστε'),
(65990, 4406, 17, 'Άλλο Ομοσπονδιακό Πρόγραμμα'),
(65991, 4407, 17, 'Άλλη Διεύθυνση Χρηματοδότησης Υγείας (HCFA)'),
(65992, 4408, 17, 'Άλλη βλάβη που δεν προσδιορίζεται αλλού'),
(65993, 4409, 17, 'Κάποια άλλη Ασφαλ. εταιρεία αστικής ευθύνης είναι Πρωτεύουσα'),
(65994, 4410, 17, 'άλλος μήνας'),
(65995, 4411, 17, 'Άλλα μη Ομοσπονδιακά Προγράμματα'),
(65996, 4412, 17, 'Άλλες σημειώσεις'),
(65997, 4413, 17, 'Άλλα σχετικά συμπτώματα'),
(65998, 4414, 17, 'Άλλα σχετικά Συμπτώματα:'),
(65999, 4415, 17, 'Άλλα σχετ. συμπτ.:'),
(66000, 4416, 17, 'Άλλες βλάβες από stress/υπερβολική χρήση'),
(66001, 4417, 17, 'Άλλα Χειρουργικά'),
(66002, 4418, 17, 'Άλλα/ Γενικώτερα, σχετικά με άμβλωση'),
(66003, 4420, 17, 'Άλλα'),
(66004, 4421, 17, 'αλλιώς θα καταστρέψετε αναφορές στα/ από τα υπάρχοντα δεδομένα.'),
(66005, 4422, 17, 'Οδηγίες αστραγάλου της Οτάβα'),
(66006, 4424, 17, 'ΕΞΩ'),
(66007, 4425, 17, 'Εκτός γραφείου'),
(66008, 4426, 17, 'Παραπομπή προς τα έξω'),
(66009, 4427, 17, 'Έκβαση'),
(66010, 4428, 17, 'Πρόγνωση'),
(66011, 4430, 17, 'Γενική κατάσταση εξιτηρίου'),
(66012, 4431, 17, 'ΕΚΠΡΟΘΕΣΜΟ'),
(66013, 4432, 17, 'Υπερβολ. χρήση'),
(66014, 4433, 17, 'Επισκόπηση'),
(66015, 4434, 17, 'Υπέρβαρος/η'),
(66016, 4435, 17, 'Επικαλύψτε την επιλογή HIPAA'),
(66017, 4437, 17, 'Κορεσμός οξυγόνου'),
(66018, 4438, 17, 'ουγγιά'),
(66019, 4440, 17, 'μετά φαγητό'),
(66020, 4441, 17, 'μ.μ.'),
(66021, 4442, 17, 'επί ανάγκης'),
(66022, 4444, 17, 'Παιδιατρικό'),
(66023, 4445, 17, 'Σελίδα'),
(66024, 4446, 17, 'Σελίδες'),
(66025, 4447, 17, 'Αμειβόμενος/η'),
(66026, 4448, 17, 'Πληρωμένο ποσό που θα κατανείμετε'),
(66027, 4449, 17, 'Καταβληθέν ποσό'),
(66028, 4450, 17, 'Πληρωμή μέσω'),
(66029, 4451, 17, 'Πόνος'),
(66030, 4453, 17, 'Αίσθημα παλμών'),
(66031, 4455, 17, 'Τεστ Παπανικολάου'),
(66032, 4456, 17, 'Χαρτί'),
(66033, 4457, 17, 'Μέγεθος Χαρτιού'),
(66034, 4458, 17, 'Παράλυση'),
(66035, 4461, 17, 'Ανάλυση HL7'),
(66036, 4463, 17, 'Συνεργάτης/ Συνεταίρος'),
(66037, 4464, 17, 'Όνομα Συνεργάτη'),
(66038, 4467, 17, 'Συνθηματικό'),
(66039, 4468, 17, 'Συνθηματικό για αποκρυπτογράφηση του αρχείου'),
(66040, 4470, 17, 'Παθητικός Συναγερμός'),
(66041, 4471, 17, 'Κανόνες Παθητικού Συναγερμού'),
(66042, 4472, 17, 'Κωδικός πρόσβασης'),
(66043, 4473, 17, 'Αλλαγή Κωδικού πρόσβασης'),
(66044, 4474, 17, 'Επιτυχής αλλαγή Κωδικού πρόσβασης'),
(66045, 4475, 17, 'Επιτυχής αλλαγή Κωδικού πρόσβασης.'),
(66046, 4477, 17, 'Περίοδος χάριτος μετά τη Λήξη του Κωδικού πρόσβασης'),
(66047, 4479, 17, 'Κωδικός για Τηλεφωνικό Gateway. Η αυτοματοποιημένη υπηρεσία VoIP παρέχεται από την Maviq. Παρακαλώ επισκεφθείτε την ιστοσελια http://signup.maviq.com για περισσότερες πληροφορίες.'),
(66048, 4480, 17, 'Κωδικός για το SMS Gateway'),
(66049, 4481, 17, 'Κωδικός για το SMS Gateway'),
(66050, 4483, 17, 'Ο κωδικός ασφαλείας αναβαθμίστηκε πρόσφατα'),
(66051, 4484, 17, 'Κωδικός σύνδεσης με τη βάση CouchDB'),
(66052, 4485, 17, 'Κωδικός πολύ μικρός. Απαιτούνται κατά το ελάχιστο 8 χαρακτήρες.'),
(66053, 4486, 17, 'Κωδικός Πρόσβασης:'),
(66054, 4487, 17, 'Οι κωδικοί δεν ταιριάζουν!'),
(66055, 4488, 17, 'Παρελθόντα Ραντεβού'),
(66056, 4490, 17, 'Καθυστέρηση'),
(66057, 4491, 17, 'Καθυστέρηση'),
(66058, 4492, 17, 'Καθυστέρηση του προβλεπόμενου διαστήματος (Υπενθύμιση για τον κλινικό)'),
(66059, 4493, 17, 'Καθυστέρηση του προβλεπόμενου διαστήματος (Υπενθύμιση για τον Ασθενή)'),
(66060, 4494, 17, 'Λίστα Προηγούμενων Επισκέψεων'),
(66061, 4495, 17, 'Προηγούμενες Επισκέψεις'),
(66062, 4496, 17, 'Προηγούμενες Επισκέψεις και Έγγραφα'),
(66063, 4497, 17, 'Προηγούμενες Επισκέψεις για'),
(66064, 4498, 17, 'Επικόλληση HL7 δεδομένων'),
(66065, 4499, 17, 'Επικολλήσετε τα δεδομένα προς εισαγωγή, στο παρακάτω πεδίο κειμένου:'),
(66066, 4500, 17, 'Ασθ'),
(66067, 4508, 17, 'Διαδρομή για Αντίγραφο ασφαλείας της Καταγραφής Συμβάντων'),
(66068, 4509, 17, 'Διαδρομή για το Αρχείο Πιστοποιητικών CA'),
(66069, 4510, 17, 'Διαδρομή για το Κλειδί του Αρχείου Πιστοποιητικών CA'),
(66070, 4511, 17, 'Διαδρομή για τα δυαδικά (binaries) της MySQL'),
(66071, 4512, 17, 'Διαδρομή για τα δυαδικά (binaries) PERT'),
(66072, 4513, 17, 'Διαδρομή για τα Προσωρινά Αρχεία'),
(66073, 4514, 17, 'Ασθενής'),
(66074, 4515, 17, 'ασθενής'),
(66075, 4516, 17, 'ΑΣΘΕΝΕΙΣ'),
(66076, 4517, 17, 'Διεύθυνση Ασθενούς'),
(66077, 4518, 17, 'Λείπει η Διεύθυνση Ασθενούς'),
(66078, 4521, 17, 'Αλλεργίες ασθενούς'),
(66079, 4522, 17, 'Αλλεργίες Ασθενούς'),
(66080, 4523, 17, 'Ραντεβού ασθενούς'),
(66081, 4528, 17, 'Κωδικός φακέλου ασθενούς'),
(66082, 4529, 17, 'Έλεγχος εξόδου του ασθενούς'),
(66083, 4530, 17, 'Έλεγχος εξόδου ασθενούς για τον/ την '),
(66084, 4531, 17, 'Πόλη ασθενούς'),
(66085, 4532, 17, 'Λείπε η Πόλη Ασθενούς'),
(66086, 4533, 17, 'Επικοινωνία ασθενούς απεστάλη'),
(66087, 4534, 17, 'Επικοινωνία ασθενούς απεστάλη'),
(66088, 4535, 17, 'Χώρα Ασθενούς'),
(66089, 4536, 17, 'Λείπει η Χώρα Ασθενούς. Επίσης, δεν έχετε ορίσει την Προεπιλεγμένη Χώρα Ασθενούς στις Γενικές Ρυθμίσεις.'),
(66090, 4537, 17, 'Κάλυψη ασθενούς'),
(66091, 4539, 17, 'Στοιχεία ασθενούς'),
(66092, 4541, 17, 'Λείπει η Ημερομηνία Γέννησης Ασθενούς'),
(66093, 4542, 17, 'Λεπτομέρειες ασθενούς'),
(66094, 4543, 17, 'Ημ. Γενν. ασθενούς'),
(66095, 4544, 17, 'Έγγραφο ασθενούς'),
(66096, 4545, 17, 'Εκπαίδευση Ασθενούς'),
(66097, 4546, 17, 'Υλικά Εκπαίδευσης Ασθενούς'),
(66098, 4547, 17, 'Επίσκεψη Ασθενούς'),
(66099, 4548, 17, 'Έντυπο Επίσκεψης Ασθενούς'),
(66100, 4549, 17, 'Επισκέψεις Ασθενούς'),
(66101, 4550, 17, 'Ευρετήριο Ασθενούς'),
(66102, 4551, 17, 'Όνομα Ασθενούς'),
(66103, 4553, 17, 'Λείπει το Όνομα Ασθενούς'),
(66104, 4558, 17, 'Φύλο Ασθενούς'),
(66105, 4559, 17, 'Λείπει το Φύλο του Ασθενούς'),
(66106, 4560, 17, 'Ο ασθενής δεν έχει εξουσιοδοτήσει την Πύλη Ασθενούς.'),
(66107, 4561, 17, 'Ιστορικό και προδιάθεση ασθενούς'),
(66108, 4562, 17, 'Ιστορικό και Προδιάθεση ασθενούς - Τρόπος ζωής'),
(66109, 4563, 17, 'Τηλέφωνο Οικίας Ασθενούς'),
(66110, 4564, 17, 'Κωδικός Ασθενούς'),
(66111, 4565, 17, 'Κωδικός Ασθενούς'),
(66112, 4566, 17, 'Κάρτα ταυτοποίησης ασθενούς'),
(66113, 4567, 17, 'Όνομα κατηγορίας ταυτοποίησης ασθενούς'),
(66114, 4568, 17, 'Εμβολιασμοί ασθενούς'),
(66115, 4569, 17, 'Πληροφορίες ασθενούς'),
(66116, 4570, 17, 'Οδηγίες προς Aσθενή'),
(66117, 4571, 17, 'Κατανομή Aσφάλισης Aσθενών'),
(66118, 4572, 17, 'Αναφορά Kατανομής Aσφάλισης Aσθενών'),
(66119, 4573, 17, 'Προβλήματα Ασθενούς'),
(66120, 4575, 17, 'Επώνυμο Ασθενούς'),
(66121, 4577, 17, 'Λείπει το Επώνυμο του Ασθενούς'),
(66122, 4581, 17, 'Κατάλογος Ασθενών'),
(66123, 4582, 17, 'Στήλες Λίστας Ασθενών'),
(66124, 4584, 17, 'Νέο παράθυρο Λίστας ασθενών'),
(66125, 4585, 17, 'Μέγεθος σελίδας Λίστας Ασθενών'),
(66126, 4586, 17, 'Λάθη Αναζήτησης Ασθενούς'),
(66127, 4587, 17, 'Ιατρικά Προβλήματα/ Παθήσεις Ασθενούς'),
(66128, 4588, 17, 'Φάρμακα Ασθενούς'),
(66129, 4589, 17, 'Όνομα Ασθενούς'),
(66130, 4590, 17, 'Όνομα & Διεύθυνση ασθενούς'),
(66131, 4593, 17, 'Απαιτείται Όνομα Ασθενούς'),
(66132, 4595, 17, 'Σημειωση για τον Ασθενή'),
(66133, 4596, 17, 'Τύποι Σημειώσεων Ασθενούς'),
(66134, 4597, 17, 'Σημειώσεις Ασθενούς'),
(66135, 4598, 17, 'Σημειώσεις Ασθενούς (εγγραφή, προαιρετικά προσθήκη)'),
(66136, 4599, 17, 'Αριθμός Ασθενούς'),
(66137, 4600, 17, 'Πληρωμή Ασθενούς'),
(66138, 4602, 17, 'Όνομα Κατηγορίας Φωτογραφιών Ασθενούς'),
(66139, 4603, 17, 'Πύλη Ασθενούς'),
(66140, 4605, 17, 'Η Πύλη Ασθενούς είναι απενεργοποιημένη'),
(66141, 4606, 17, 'Είσοδος Πύλης Ασθενούς'),
(66142, 4607, 17, 'Διεύθυνση Πύλης Ασθενούς'),
(66143, 4608, 17, 'Εκτυπωμένη Αναφορά Ασθενούς'),
(66144, 4609, 17, 'Αναφορά Φακέλου Ασθενούς'),
(66145, 4610, 17, 'Αίτηση Φακέλου Ασθενούς'),
(66146, 4611, 17, 'Αίτηση Φακέλων Ασθενούς'),
(66147, 4613, 17, 'Υπενθύμιση Ασθενούς'),
(66148, 4614, 17, 'Δέσμη Εργασιών Υπενθυμίσεων Ασθενούς/ών'),
(66149, 4616, 17, 'Κανόνες Υπενθύμισης Ασθενούς'),
(66150, 4617, 17, 'E-mail Αποστολέα Υπενθύμισης Ασθενούς'),
(66151, 4618, 17, 'Όνομα Αποστολέα Υπενθύμισης Ασθενούς'),
(66152, 4619, 17, 'Υπενθυμίσεις προς τον ασθενή'),
(66153, 4620, 17, 'Αναφορά Ασθενούς'),
(66154, 4621, 17, 'Αίτημα Ασθενούς'),
(66155, 4622, 17, 'Ο ασθενής αιτήθηκε Ιατρικού Φακέλου'),
(66156, 4623, 17, 'Αποτελέσματα Ασθενούς'),
(66157, 4624, 17, 'Στυλ Αποτελεσμάτων Αναζήτησης Ασθενούς'),
(66158, 4625, 17, 'Αναζήτηση Ασθενούς/Προσθήκη Οθόνης'),
(66159, 4626, 17, 'Ρυθμίσεις Ασθενούς'),
(66160, 4627, 17, 'Νομός Ασθενούς'),
(66161, 4629, 17, 'Περίληψη Ασθενούς'),
(66162, 4630, 17, 'Συναλλαγές ασθενούς'),
(66163, 4631, 17, 'ΤΚ Ασθενούς'),
(66164, 4632, 17, 'ασθενής(-είς) στη βάση δεδομένων που ταιριάζουν με τις δημογραφικές πληροφορίες που έχετε εισάγει.'),
(66165, 4633, 17, 'Ασθενής'),
(66166, 4634, 17, 'Ασθενής:'),
(66167, 4635, 17, 'Κωδικός Ασθενούς'),
(66168, 4636, 17, 'Ασθενείς'),
(66169, 4637, 17, 'Ασθενείς επεξεργάστηκαν'),
(66170, 4638, 17, 'Πληρωμή'),
(66171, 4639, 17, 'Δώστε προσοχή στα κουτάκια "Έγινε με". Αφού οι ασφάλειες σημειωθούν ως πλήρεις, τότε θα ξεκινήσουμε ζητώντας από τον ασθενή να καταβάλει το υπόλοιπο ποσό. Αν αποτύχετε να μαρκάρετε όλες τις πλήρεις ασφάλειες, τότε το υπόλοιπο ποσό δεν θα εισπραχθεί! Επίσης, εάν υπάρχει ένα ποσό που ο ασθενής θα πρέπει να πληρώσει, τότε θέστε την ημερομηνία λήξης κατάλληλα, καθώς αυτό θα επηρεάσει τη γλώσσα που εμφανίζεται στις καταστάσεις του ασθενούς.'),
(66172, 4640, 17, 'Ημερομηνία Πληρωμής'),
(66173, 4641, 17, 'Κατάσταση Πληρωμής'),
(66174, 4642, 17, 'Όνομα Δικαιούχου'),
(66175, 4643, 17, 'Πληρωτής'),
(66176, 4644, 17, 'Τύπος Πληρωτή'),
(66177, 4645, 17, 'Πληρώνει'),
(66178, 4646, 17, 'Καταχώρηση καταβολής χρημάτων'),
(66179, 4647, 17, 'Πληρωμή'),
(66180, 4648, 17, 'πληρωμή'),
(66181, 4649, 17, 'Κωδικός Ρύθμισης Πληρωμής'),
(66182, 4650, 17, 'Πληρωμή έναντι'),
(66183, 4651, 17, 'Ποσό Πληρωμής'),
(66184, 4652, 17, 'Το ποσό πληρωμής πρέπει να είναι αριθμητικό'),
(66185, 4653, 17, 'Κατηγορία Πληρωμής'),
(66186, 4654, 17, 'Ημερομηνία Πληρωμής'),
(66187, 4655, 17, 'η πληρωμή εισήχθη στις'),
(66188, 4656, 17, 'Πληρωμή Από'),
(66189, 4657, 17, 'Gateways πληρωμής'),
(66190, 4658, 17, 'Ασφ Πληρωμής'),
(66191, 4659, 17, 'Λίστα Πληρωμής'),
(66192, 4660, 17, 'Τρόπος Πληρωμής'),
(66193, 4661, 17, 'Κατάταξη πληρωμών ανά'),
(66194, 4662, 17, 'Κατάσταση Πληρωμής'),
(66195, 4663, 17, 'Τύπος Πληρωμής'),
(66196, 4664, 17, 'Αξία πληρωμής για κωδικό '),
(66197, 4665, 17, 'Πληρωμές'),
(66198, 4669, 17, 'PDF'),
(66199, 4670, 17, 'Κατεβάστε Επιλεγμένους Λογαριασμούς σε PDF'),
(66200, 4672, 17, 'Πύελος και γλουτός'),
(66201, 4673, 17, 'Πέμφυξ'),
(66202, 4674, 17, 'Εκκρεμεί'),
(66203, 4676, 17, 'Εκκρεμεί F/U'),
(66204, 4677, 17, 'Εκκρεμεί επανεκτίμηση'),
(66205, 4678, 17, 'Εκκρεμεί επανεκτίμηση με βάση τα αποτελέσματα'),
(66206, 4679, 17, 'Παραγγελίες σε εκκρεμότητα'),
(66207, 4680, 17, 'Αποτέλεσμα εκκρεμεί'),
(66208, 4681, 17, 'Εκκρεμεί Επανεξέταση'),
(66209, 4682, 17, 'Αριθμός Εκκρεμών Θεραπείων'),
(66210, 4684, 17, 'Εταιρεία Pennington LibreEHR v'),
(66211, 4685, 17, 'Πεπτικό έλκος'),
(66212, 4686, 17, 'Ανά Επίσκεψη'),
(66213, 4687, 17, 'ανά λεπτό'),
(66214, 4688, 17, 'Ανά ρώθωνα'),
(66215, 4689, 17, 'ανά ρώθωνα'),
(66216, 4690, 17, 'Aπό το Στόμα'),
(66217, 4691, 17, 'από το στόμα'),
(66218, 4692, 17, 'Ορθικά'),
(66219, 4693, 17, 'ορθικά'),
(66220, 4694, 17, 'Επί τοις εκατό'),
(66221, 4697, 17, 'Εκατοστιαία θέση'),
(66222, 4698, 17, 'Διάτρηση Δεξιά:'),
(66223, 4699, 17, 'Εκτέλεση αναζήτησης'),
(66224, 4700, 17, 'Εκτέλεση αυτής της ενέργειας'),
(66225, 4701, 17, 'Ποσοστό Εκτέλεσης'),
(66226, 4703, 17, 'Εκτελόν Εργαστήριο'),
(66227, 4705, 17, 'Περίοδος'),
(66228, 4706, 17, 'Περίοδος σε ημέρες, κατά την οποία ένας χρήστης με ληγμένο κωδικό, μπορεί να συνδεθεί'),
(66229, 4707, 17, 'Περιεγχειρητική Φροντίδα'),
(66230, 4708, 17, 'Περιφερειακό'),
(66231, 4710, 17, 'Περσικά'),
(66232, 4712, 17, 'Άτομο'),
(66233, 4713, 17, 'Διαμόρφωση'),
(66234, 4715, 17, 'Φαρμ'),
(66235, 4717, 17, 'Φαρμακεία'),
(66236, 4718, 17, 'Φαρμακείο'),
(66237, 4719, 17, 'Αποθήκη φαρμακείου'),
(66238, 4720, 17, 'Πνευμοθώρακας'),
(66239, 4729, 17, 'Τηλέφωνο'),
(66240, 4730, 17, 'Λίστα τηλεφωνικών κλήσεων'),
(66241, 4731, 17, 'Αναφορά λίστας τηλεφωνημάτων'),
(66242, 4733, 17, 'Κωδικός Gateway Τηλεφώνου'),
(66243, 4734, 17, 'URL Gateway Τηλεφώνου'),
(66244, 4735, 17, 'Συνθηματικό Χρήστη Gateway Τηλεφώνου'),
(66245, 4737, 17, 'Ωρα Τηλεφωνικής Ειδοποίησης'),
(66246, 4738, 17, 'Αριθμός τηλεφώνου'),
(66247, 4740, 17, 'Φωτοφοβία'),
(66248, 4741, 17, 'Φωτογραφίες'),
(66249, 4742, 17, 'PHP compressed'),
(66250, 4744, 17, 'Έγινε εξαγωγή PHP'),
(66251, 4745, 17, 'Οι έλεγχοι πρόσβασης php=GACL είναι απενεργοποιημένοι'),
(66252, 4746, 17, 'Το PHP-gacl δεν έχει εγκατασαταθεί'),
(66253, 4747, 17, 'Φυσική εξέταση'),
(66254, 4749, 17, 'Αίτηση ιατρού'),
(66255, 4750, 17, 'Υπογραφή ιατρού'),
(66256, 4752, 17, 'Ιατροί'),
(66257, 4753, 17, 'διαλέξτε'),
(66258, 4754, 17, 'Διαλέξτε'),
(66259, 4755, 17, 'Διαλέξτε ένα θέμα CSS'),
(66260, 4756, 17, 'Προσωπικός κωδικός αναγνώρισης'),
(66261, 4757, 17, 'Φλεγμ. νόσος πυέλου'),
(66262, 4758, 17, 'Μέγεθος χαπιού'),
(66263, 4759, 17, 'Χάπια'),
(66264, 4760, 17, 'Τοποθετήστε το αρχείο βάσης δεδομένων zip στον ακόλουθο κατάλογο, αν θέλετε να εγκαταστήσετε αυτή τη δυνατότητα'),
(66265, 4761, 17, 'Τοποθετήστε τα συμπιεσμένα αρχεία της βάσης ICD10 που κατεβάσατε στον εξής κατάλογο'),
(66266, 4762, 17, 'Τοποθετήστε τα συμπιεσμένα αρχεία της βάσης ICD9 που κατεβάσατε στον εξής κατάλογο'),
(66267, 4763, 17, 'Τοποθετήστε τα συμπιεσμένα αρχεία της βάσης RxNorm που κατεβάσατε στον εξής κατάλογο'),
(66268, 4764, 17, 'Τοποθετήστε τα συμπιεσμένα αρχεία της βάσης Snomed που κατεβάσατε, στον εξής κατάλογο'),
(66269, 4767, 17, 'Απλό κείμενο'),
(66270, 4768, 17, 'Θεραπευτική Αγωγή'),
(66271, 4771, 17, 'Όνομα πλάνου'),
(66272, 4775, 17, 'Το πλάνο έχει οριστεί'),
(66273, 4779, 17, 'Πλάνο:'),
(66274, 4782, 17, 'Πλάνα'),
(66275, 4784, 17, 'Παίκτης'),
(66276, 4785, 17, 'Θέση παιχνιδιού'),
(66277, 4786, 17, 'Παρακαλώ τηλεφωνείστε αν κάποιο από τα παραπάνω στοιχεία είναι λάθος'),
(66278, 4787, 17, 'Παρακαλώ αλλάξτε τον κωδικό σας.'),
(66279, 4788, 17, 'Παρακαλώ επιλέξτε ένα αρχείο'),
(66280, 4789, 17, 'Παρακαλώ επιλέξτε έναν ασθενή'),
(66281, 4790, 17, 'Παρακαλώ επιλέξτε μια έγκυρη επιλογή από τη λίστα.'),
(66282, 4791, 17, 'Παρακαλώ επιλέξτε μια έγκυρη επιλογή.'),
(66283, 4792, 17, 'Παρακαλώ επιλέξτε μια τιμή για');
INSERT INTO `lang_definitions` VALUES
(66284, 4793, 17, 'Παρακαλώ επιλέξτε πιο πάνω τα κριτήρια για τα φάσματα ημερομηνιών και κάντε κλικ στο Ανανέωση, για να δείτε τα αποτελέσματα.'),
(66285, 4795, 17, 'Παρακαλώ κάντε κλικ στο κουμπί Download για να κατεβάσετε τα ΑποΤαυτοποιημένα δεδομένα'),
(66286, 4796, 17, 'Παρακαλώ κάντε κλικ στο κουμπί Download για να κατεβάσετε τα ΕπαναΤαυτοποιημένα δεδομένα'),
(66287, 4797, 17, 'Παρακαλώ κλείστε αυτό το παράθυρο'),
(66288, 4798, 17, 'Παρακαλώ συγκρίνετε το νέο όνομα'),
(66289, 4801, 17, 'Παρακαλώ δημιουργήστε τον εξής κατάλογο, πριν προχωρήσετε'),
(66290, 4802, 17, 'Παρακαλώ μη δέχεστε αυτή τη συνταγή, εκτός αν ελήφθη μέσω facimile.'),
(66291, 4803, 17, 'Παρακαλώ μη δέχεστε αυτή τη συνταγή, εκτός αν ελήφθη μέσω facimile.'),
(66292, 4804, 17, 'Παρακαλώ ΜΗ χρησιμοποιείτε τα κουμπιά Stop ή Reload του φυλλομετρητή σας, ενώ αυτή η σελίδα τρέχει. Αν δεν έχουν παρέλθει περισσότερα από 10 λεπτά, θα προκληθεί το σταμάτημα της διαδικασίας στο διακομιστή και θα καταναλώσει περιττούς πόρους.'),
(66293, 4805, 17, 'ΠΑΡΑΚΑΛΩ ΕΝΕΡΓΟΠΟΙΗΣΤΕ ΤΗΝ ΕΠΕΚΤΑΣΗ CURL'),
(66294, 4806, 17, 'ΠΑΡΑΚΑΛΩ ΕΝΕΡΓΟΠΟΙΗΣΤΕ ΤΗΝ ΕΠΕΚΤΑΣΗ OPENSSL'),
(66295, 4807, 17, 'ΠΑΡΑΚΑΛΩ ΕΝΕΡΓΟΠΟΙΗΣΤΕ ΤΗΝ ΕΠΕΚΤΑΣΗ SOAP'),
(66296, 4808, 17, 'ΠΑΡΑΚΑΛΩ ΕΝΕΡΓΟΠΟΙΗΣΤΕ ΤΗΝ ΕΠΕΚΤΑΣΗ XML'),
(66297, 4809, 17, 'Παρακαλώ βάλτε μία ημερομηνία για την τελευταία φορά που επανεξετάσατε'),
(66298, 4810, 17, 'Παρακαλώ εισάγετε μια ημερομηνία.'),
(66299, 4811, 17, 'Παρακαλώ είσάγετε μια ημερομηνία προθεσμίας'),
(66300, 4812, 17, 'Παρακαλώ είσάγετε ένα μήνυμα'),
(66301, 4813, 17, 'Παρακαλώ εισάγετε ένα χρηματικό ποσό χρησιμοποιώντας μόνο αριθμούς και ένα δεκαδικό ψηφίο'),
(66302, 4814, 17, 'Παρακαλώ Εισάγετε Νέο Κωδικό Πρόσβασης'),
(66303, 4815, 17, 'Παρακαλώ εισάγετε τίτλο!'),
(66304, 4819, 17, 'Παρακαλώ βάλτε έναν σωστό κωδικό Επαναταυτοποίησης'),
(66305, 4821, 17, 'Παρακαλώ εισάγετε νέα λέξη αναζήτησης'),
(66306, 4822, 17, 'Παρακαλώ βάλτε τον σωστό κωδικό Επαναταυτοποίησης'),
(66307, 4823, 17, 'Παρακαλώ βάλτε τον κωδικό πρόσβασης'),
(66308, 4824, 17, 'Παρακαλώ συμπληρώστε τον Αριθμό Επιταγής'),
(66309, 4825, 17, 'Παρακαλώ συμπληρώστε τον Αριθμό Επιταγής/αριθμό αναφοράς'),
(66310, 4826, 17, 'Παρακαλώ συμπληρώστε την Ημερομηνία'),
(66311, 4827, 17, 'Παρακαλώ συμπληρώστε το Ποσό Πληρωμής'),
(66312, 4828, 17, 'Παρακαλώ συμπληρώστε την Κατηγορία Πληρωμής'),
(66313, 4829, 17, 'Παρακαλώ συμπληρώστε την Πληρωμή Από'),
(66314, 4831, 17, 'Παρακαλώ συμπληρώστε τους πριν συνεχίσετε.'),
(66315, 4832, 17, 'Παρακαλώ υποδείξτε τον λόγο επίσκεψης'),
(66316, 4834, 17, 'Παρακαλώ εισάγετε κριτήρια αναζήτησης πιο πάνω και κάντε κλικ στο Υποβολή για να δείτε τα αποτελέσματα.'),
(66317, 4835, 17, 'Παρακαλώ εισάγετε κριτήρια αναζήτησης πιο πάνω και κάντε κλικ στο Υποβολή για να δείτε τα αποτελέσματα. (Τα αποτελέσματα θα εμφανιστούν σε ένα νέο παράθυρο)'),
(66318, 4836, 17, 'Παρακαλώ συνδεθείτε πάλι'),
(66319, 4837, 17, 'Παρακαλώ σημειώστε ότι αυτό μπορεί να πάρει πολύ χρόνο, έως και αρκετά λεπτά. Ο φυλλομετρητής σας μπορεί να μην εμφανίζεται πολύ δραστήριος κατά το διάστημα αυτό, αλλά η δημιουργία μιας χρέωσης είναι μια περίπλοκη διαδικασία και ο φυλλομετρητής σας απλώς περιμένει περισσότερες πληροφορίες.'),
(66320, 4838, 17, 'Σημείωση: στις σταθερές παίζουν ρόλο τα μικρά-κεφαλαία γράμματα και επιτρέπεται κάθε string.'),
(66321, 4839, 17, 'Παρακαλώ χρησιμοποιήστε μόνο αλφαβητικούς χαρακτήρες'),
(66322, 4840, 17, 'Παρακαλώ χρησιμοποιήστε μόνο αλφαβητικούς χαρακτήρες χωρίς κενά'),
(66323, 4841, 17, 'Παρακαλώ πληρώστε αυτό το ποσό'),
(66324, 4842, 17, 'Παρακαλώ τοποθετήστε τα αρχεία σας προς εγκατάσταση σε αυτό τον κατάλογο'),
(66325, 4843, 17, 'Παρακαλώ αναφερθείτε στο'),
(66326, 4844, 17, 'Παρακαλώ επανακαθορίστε τον κωδικό.'),
(66327, 4845, 17, 'Παρακαλώ επανεκκινήστε τον Apache server πριν παίξετε με την Αποταυτοποίηση'),
(66328, 4847, 17, 'Παρακαλώ επιλέξτε'),
(66329, 4849, 17, 'Παρακαλώ επιλέξτε μία γλώσσα'),
(66330, 4850, 17, 'Παρακαλώ επιλέξτε έναν Ασθενή'),
(66331, 4854, 17, 'Παρακαλώ Επιλέξτε έναν Παραλήπτη'),
(66332, 4855, 17, 'Παρακαλώ επιλέξτε μια ημερομηνία έναρξης και λήξης'),
(66333, 4856, 17, 'Παρακαλώ επιλέξτε έναν έγκυρο παραλήπτη'),
(66334, 4858, 17, 'Παρακαλώ επιλέξτε μια αιτιολογία διόρθωσης για τον κωδικό '),
(66335, 4859, 17, 'Παρακαλώ επιλέξτε ένα συμβάν'),
(66336, 4860, 17, 'Παρακαλώ επιλέξτε μια Επιλογή Αναζήτησης.'),
(66337, 4863, 17, 'Παρακαλώ επιλέξτε τουλάχιστον μία συνταγή!'),
(66338, 4865, 17, 'Παρακαλώ επιλέξτε τις επιθυμητές σελίδες προς αντιγραφή ή προώθηση:'),
(66339, 4866, 17, 'Παρακαλώ επιλέξτε μια Μέθοδο Πληρωμής'),
(66340, 4867, 17, 'Παρακαλώ επιλέξτε Μέθοδο Πληρωμής'),
(66341, 4870, 17, 'Παρακαλώ καθορίστε'),
(66342, 4871, 17, 'Παρακαλώ ορίστε την μεταβλητή de_identification_config ξανά στο μηδέν'),
(66343, 4873, 17, 'Παρακαλώ αρχίστε μία νέα διαδικασία Απο Ταυτοποίησης'),
(66344, 4874, 17, 'Παρακαλώ αναβαθμίστε τη βάση δεδομένων του LibreEHR, για να ενσωματώσει τις διαδικασίες Απο Ταυτοποίησης, λειτουργίες, πίνακες'),
(66345, 4875, 17, 'Παρακαλώ δείτε τον πίνακα καταγραφής σφαλμάτων Απο Ταυτοποίησης, για παραπάνω πληροφορίες'),
(66346, 4876, 17, 'Παρακαλώ, επισκεφθείτε ξανά την οθόνη Απο Ταυτοποίησης μετά από λίγο καιρό'),
(66347, 4877, 17, 'Παρακαλώ, επισκεφθείτε ξανά την οθόνη Επανα Ταυτοποίησης μετά από λίγο καιρό'),
(66348, 4878, 17, 'Παρακαλώ επισκεφθείτε την οθόνη μετά από λίγο καιρό'),
(66349, 4882, 17, 'ΜΜ'),
(66350, 4884, 17, 'Μέθοδος πληρωμής'),
(66351, 4885, 17, 'Κατάθλιψη μετά τον τοκετό'),
(66352, 4886, 17, 'Συζευγμ. εμβόλιο πνευμονιοκόκκου 1'),
(66353, 4887, 17, 'Συζευγμ. εμβόλιο πνευμονιοκόκκου 2'),
(66354, 4888, 17, 'Συζευγμ. εμβόλιο πνευμονιοκόκκου 3'),
(66355, 4889, 17, 'Συζευγμ. εμβόλιο πνευμονιοκόκκου 4'),
(66356, 4890, 17, 'Εμβόλιο Πνευμονιόκοκκου'),
(66357, 4891, 17, 'Εμβολιασμός για πνευμονία'),
(66358, 4892, 17, 'Κατάσταση Εμβολιασμού για πνευμονία για ηλικιωμένους'),
(66359, 4893, 17, 'Κατάσταση Εμβολιασμού για πνευμονία για ηλικιωμένους'),
(66360, 4894, 17, 'Ποδιατρική'),
(66361, 4896, 17, 'Σημείο εξυπηρέτησης'),
(66362, 4897, 17, 'Ασφαλ. Συμβόλαιο'),
(66363, 4898, 17, 'Αρ. Ασφαλ. Συμβολαίου'),
(66364, 4899, 17, 'Αριθμός ασφαλ. συμβολαίου'),
(66365, 4900, 17, 'Πολωνικά'),
(66366, 4901, 17, 'Πολυδιψία'),
(66367, 4902, 17, 'Πολύποδες'),
(66368, 4903, 17, 'Πολυουρία'),
(66369, 4904, 17, 'Κακή όρεξη'),
(66370, 4905, 17, 'Κακή κυκλοφορία'),
(66371, 4906, 17, 'Βαρηκοΐα'),
(66372, 4907, 17, 'Τα Pop ups πρέπει να είναι ενεργοποιημένη για να δείτε αυτές τις αναφορές'),
(66373, 4908, 17, 'Να συμπληρωθεί η εμφάνιση του έτους με συμβάντα;'),
(66374, 4909, 17, 'Popups'),
(66375, 4911, 17, 'Δραστηριότητα Πύλης'),
(66376, 4917, 17, 'Πορτογαλικά'),
(66377, 4918, 17, 'Πορτογαλικά (Βραζιλία)'),
(66378, 4919, 17, 'Πορτογαλικά (Ευρωπαϊκά)'),
(66379, 4920, 17, 'Κωδικός σημείου εξυπηρέτησης'),
(66380, 4922, 17, 'Θετικό'),
(66381, 4923, 17, 'Θετικά'),
(66382, 4926, 17, 'Ρινική καταρροή'),
(66383, 4928, 17, 'Μετεγχειρητικό'),
(66384, 4929, 17, 'Αποστολή στο λογιστήριο και σημείωση ως πληρωμένο'),
(66385, 4933, 17, 'Φροντίδα μετά την άμβλωση'),
(66386, 4934, 17, 'Αντισύλληψη μετά την άμβλωση'),
(66387, 4935, 17, 'Συμβουλευτική μετά την άμβλωση'),
(66388, 4936, 17, 'Παρακολούθηση μετά την άμβλωση'),
(66389, 4937, 17, 'Ταχυδρομικό'),
(66390, 4938, 17, 'Τ.Κ.'),
(66391, 4939, 17, 'ΤΚ.'),
(66392, 4941, 17, 'Ημερολόγιο'),
(66393, 4942, 17, 'Διαχείριση Ημερολογίου'),
(66394, 4943, 17, 'Ρύθμιση κατηγοριών Ημερολογίου'),
(66395, 4944, 17, 'Γενικές Ρυθμίσεις Ημερολογίου'),
(66396, 4945, 17, 'Απεστάλη στις'),
(66397, 4946, 17, 'Ημερομ. αποστολής'),
(66398, 4953, 17, 'Ιατρείο'),
(66399, 4954, 17, 'Προεπιλογές Ιατρείου'),
(66400, 4955, 17, 'Ρυθμίσεις Ιατρείου'),
(66401, 4956, 17, 'Επαγγελματίας Υγείας'),
(66402, 4959, 17, 'Προπληρωμή'),
(66403, 4960, 17, 'Συμβουλή προ της άμβλωσης'),
(66404, 4961, 17, 'Συμβουλευτική προ της άμβλωσης'),
(66405, 4962, 17, 'Προτιμ. κατηγ.'),
(66406, 4964, 17, 'Προτιμήσεις'),
(66407, 4965, 17, 'Προτιμώμενη κατηγορία συμβάντων'),
(66408, 4966, 17, 'Προτιμώμενη γλώσσα'),
(66409, 4967, 17, 'Προτιμώμενο φαρμακείο'),
(66410, 4968, 17, 'Προτιμώμενο οργανισμός Παρόχου'),
(66411, 4969, 17, 'Τέστ κύησης'),
(66412, 4970, 17, 'Προκαταρκτικό'),
(66413, 4972, 17, 'Προπληρωμή'),
(66414, 4973, 17, 'Συνταγή'),
(66415, 4974, 17, 'η συνταγή έφθασε στο όριό της των'),
(66416, 4975, 17, 'Ιστορικό Συνταγών'),
(66417, 4976, 17, 'Ιστορικό Συνταγών εισήχθει επιτυχώς'),
(66418, 4977, 17, 'Ετικέτα Συνταγογράφησης'),
(66419, 4978, 17, 'Αναφορά Συνταγογράφησης'),
(66420, 4979, 17, 'Συνταγές'),
(66421, 4980, 17, 'Συνταγές και σκευάσματα'),
(66422, 4981, 17, 'Συνταγές και άλλες παραπομπές'),
(66423, 4982, 17, 'Συνταγές ή/ και παραπομπές από ειδικό'),
(66424, 4983, 17, 'Αναφορά συνταγών'),
(66425, 4984, 17, 'Συνταγές/ Παραπομπές'),
(66426, 4985, 17, 'Παρών'),
(66427, 4986, 17, 'Κύριο ενόχλημα'),
(66428, 4988, 17, 'Πατήστε Συνέχεια για να προχωρήσετε'),
(66429, 4989, 17, 'Αρχική Διάγνωση'),
(66430, 4990, 17, 'Υποτιθέμενη διάγνωση από Ειδικό'),
(66431, 4991, 17, 'Προηγ'),
(66432, 4992, 17, 'Προηγ. Ιατρικό/ Χειρουργ. ιστορικό'),
(66433, 4993, 17, 'Προηγ. μήνας (κρατήστε πατημένο για να εμφανισθεί το μενού)'),
(66434, 4994, 17, 'Προηγ. έτος (κρατήστε πατημένο για να εμφανισθεί το μενού)'),
(66435, 4995, 17, 'Προληπτική Φροντίδα'),
(66436, 4998, 17, 'Προεπισκόπηση Συμβάντος'),
(66437, 5000, 17, 'Προεπισκόπηση του'),
(66438, 5001, 17, 'Προηγούμενο'),
(66439, 5002, 17, 'Προηγ. Συμβουλευτική (Επίσκεψη)'),
(66440, 5003, 17, 'Προηγ. ημέρα'),
(66441, 5004, 17, 'Προηγούμ. Ιστορικό/ Έλεγχος'),
(66442, 5005, 17, 'Προηγ. μήνας'),
(66443, 5006, 17, 'Προηγ. εβδομάδα'),
(66444, 5007, 17, 'Τιμή'),
(66445, 5008, 17, 'Έκπτωση τιμής'),
(66446, 5009, 17, 'Επίπεδο τιμής'),
(66447, 5010, 17, 'Επίπεδο τιμής:'),
(66448, 5011, 17, 'Τιμές'),
(66449, 5012, 17, 'Πρωτεύουσα'),
(66450, 5022, 17, 'Πρωτεύουσα Ασφαλ.'),
(66451, 5023, 17, 'Πρωτεύουσα Ασφάλιση'),
(66452, 5024, 17, 'Δεδομένα Πρωτεύουσας Ασφάλισης'),
(66453, 5025, 17, 'Πάροχος Πρωτεύουσας Ασφάλισης'),
(66454, 5026, 17, 'Πρωτεύων πάροχος'),
(66455, 5027, 17, 'Εκτύπωση'),
(66456, 5028, 17, 'Εκτύπ. σε HTML'),
(66457, 5029, 17, 'Εκτύπ. σε PDF'),
(66458, 5031, 17, 'Εκτύπ. όλων των επισκέψεων'),
(66459, 5032, 17, 'Εκτύπ. κενού εντύπου παραπομπής'),
(66460, 5033, 17, 'Εντολή εκτύπωσης'),
(66461, 5039, 17, 'Εκτύπωση εντύπου'),
(66462, 5040, 17, 'Εκτύπωση τετραπλού Panel'),
(66463, 5042, 17, 'Μήνυμα εκτύπωσης'),
(66464, 5043, 17, 'Πολλαπλή εκτύπωση'),
(66465, 5044, 17, 'Πολλαπλή εκτύπωση σε FAX'),
(66466, 5045, 17, 'Εκτύπ. ονόματος, υπογραφής και ημερομηνίας.'),
(66467, 5046, 17, 'Εκτύπωση σημειώσεων'),
(66468, 5047, 17, 'Εκτύπωση σελ. 1'),
(66469, 5048, 17, 'Εκτύπωση σελ. 2'),
(66470, 5051, 17, 'Εκτύπωση Αποδείξεων ανά Πάροχο'),
(66471, 5052, 17, 'Εκτύπωση Εγγραφής'),
(66472, 5053, 17, 'Εκτύπ. επιλεγμένων statements'),
(66473, 5054, 17, 'Εκτύπ. Καταγραφής Εμβολιασμού'),
(66474, 5056, 17, 'Εκτύπ. αυτής της επίσκεψης'),
(66475, 5057, 17, 'Εκτύπ. αυτής της σημείωσης'),
(66476, 5058, 17, 'Εκτύπ. Αυτής της Σημείωσης'),
(66477, 5060, 17, 'Εκτύπωση σε FAX'),
(66478, 5061, 17, 'Προβολή Εκτύπωσης'),
(66479, 5062, 17, 'εκτυπώσιμη'),
(66480, 5063, 17, 'Εκτυπώσιμη Έκδοση'),
(66481, 5064, 17, 'Εκτυπώθηκε'),
(66482, 5066, 17, 'Εκτύπωση αποτελεσμάτων:'),
(66483, 5067, 17, 'Η εκτύπωση παρελήφθη, δείτε την έξοδος του τεστ στο'),
(66484, 5068, 17, 'Η εκτύπωση παρελήφθη, δείτε την έξοδος του τεστ στο '),
(66485, 5069, 17, 'Προηγούμενη εξουσιοδότηση'),
(66486, 5070, 17, 'Προηγούμενο έντυπο άδειας'),
(66487, 5071, 17, 'Προηγούμενη Επίσκεψη'),
(66488, 5072, 17, 'Προτεραιότητα'),
(66489, 5073, 17, 'Προτεραιότητα '),
(66490, 5074, 17, 'Ιδιωτικό'),
(66491, 5075, 17, 'Πρόβλημα'),
(66492, 5076, 17, 'Διαγν Προβλήματος'),
(66493, 5077, 17, 'Λίστα προβλημάτων'),
(66494, 5079, 17, 'Προβλήματα/ Ιατρ. Θέματα'),
(66495, 5086, 17, 'Διαδικασία'),
(66496, 5087, 17, 'Διαδικασία Σημεία του Σώματος'),
(66497, 5088, 17, 'Διαδικασία Boolean αποτελέσματα'),
(66498, 5089, 17, 'Κωδικός Διαδικασίας'),
(66499, 5093, 17, 'Εντολή Διαδικασίας'),
(66500, 5095, 17, 'Εντολή Διαδικασίας για'),
(66501, 5102, 17, 'Αναφορά Διαδικασίας'),
(66502, 5103, 17, 'Διαδικασία Αναφορά καταστάσεως'),
(66503, 5104, 17, 'Διαδικασία Αναφορά καταστάσεως'),
(66504, 5105, 17, 'Καταστάσεις Αποτελέσματος διαδικασίας'),
(66505, 5106, 17, 'Αποτελέσματα διαδικασίας'),
(66506, 5107, 17, 'Οδοί Διαδικασίας'),
(66507, 5108, 17, 'Είδη δειγμάτων Διαδικασίας'),
(66508, 5109, 17, 'Αναφορά Στατιστ. Διαδικασίας'),
(66509, 5110, 17, 'Είδος Διαδικασίας'),
(66510, 5111, 17, 'Είδη Διαδικασίας'),
(66511, 5112, 17, 'Μονάδες Διαδικασίας'),
(66512, 5114, 17, 'Διαδικασίες'),
(66513, 5115, 17, 'Επεξεργασία'),
(66514, 5117, 17, 'Επεξεργ. αρχείου ηλεκτρον. εμβάσματος πληρωμής (ERA)'),
(66515, 5125, 17, 'Επεξεργάζεται'),
(66516, 5129, 17, 'Προϊόν'),
(66517, 5130, 17, 'Προϊόν Αντισυλληπτική Μέθοδος'),
(66518, 5132, 17, 'Προϊόντα'),
(66519, 5133, 17, 'Προϊόντα αλλά χωρίς συνταγογραφήσιμα φάρμακα και χωρίς templates'),
(66520, 5134, 17, 'Ποσό'),
(66521, 5135, 17, 'Πορεία νόσου/ Πρόοδος'),
(66522, 5136, 17, 'Καρκίνος προστάτη'),
(66523, 5137, 17, 'Προληπτικός Έλεγχος Καρκίνου Προστάτη'),
(66524, 5138, 17, 'Εξέταση προστάτη'),
(66525, 5139, 17, 'Προβλήμ. προστάτη'),
(66526, 5140, 17, 'Προστάτης χωρίς διόγκ, όζους, ευαισθησία'),
(66527, 5142, 17, 'Υποδείξτε την απόλυτη διαδρομή'),
(66528, 5143, 17, 'Υποδείξτε την απόλυτη διαδρομή του αρχείου'),
(66529, 5145, 17, 'Υποδείξτε κλινικές περιλήψεις για ασθενείς για κάθε επίσκεψη γραφείου.'),
(66530, 5146, 17, 'Υποδείξτε ασθενείς με ηλεκτρονικό αντίγραφο των πληροφοριών υγείας τους (συμπεριλαμβανομένων διαγνωστικών αποτελεσμάτων, λίστας προβλημάτων, λιστών φαρμάκων, φαρμακευτικών αλλεργίες), κατόπιν αιτήματος.'),
(66531, 5147, 17, 'Υποδείξτε ασθενείς με ηλεκτρονικό αντίγραφο των πληροφοριών υγείας τους (συμπεριλαμβανομένων των εργαστηριακών, λίστας προβλημάτων, λιστών φαρμάκων, φαρμακευτικών αλλεργίες) εντός τεσσάρων ημερών της πληροφορίας που είναι διαθέσιμη στο EP.'),
(66532, 5149, 17, 'Δώστε μία ισχύουσα ηλεκτρ. διεύθυνση'),
(66533, 5152, 17, 'Πάροχος'),
(66534, 5156, 17, 'Σφάλματα παρόχου'),
(66535, 5159, 17, 'Κωδικός παρόχου'),
(66536, 5162, 17, 'Πάροχος:'),
(66537, 5163, 17, 'Πάροχοι'),
(66538, 5164, 17, 'Εθνικά αναγνωριστικά παρόχων'),
(66539, 5165, 17, 'Πάροχοι Δείτε Όλο το Ημερολόγιο'),
(66540, 5166, 17, 'Προηγ'),
(66541, 5167, 17, 'PSA'),
(66542, 5168, 17, 'Ψωρίαση'),
(66543, 5169, 17, 'Ψυχ Διάγνωση'),
(66544, 5170, 17, 'Ψυχ Φάρμακα'),
(66545, 5171, 17, 'Ψυχιατρικό'),
(66546, 5172, 17, 'Ψυχιατρ. σύντομη επιστολή'),
(66547, 5173, 17, 'Ψυχιατρ. διάγνωση'),
(66548, 5174, 17, 'Ψυχιατρ. εξέταση'),
(66549, 5175, 17, 'Ψυχιατρ. ιστορικό'),
(66550, 5176, 17, 'Ψυχιατρ. Εισαγωγή'),
(66551, 5177, 17, 'Ψυχιατρ. φάρμακα'),
(66552, 5178, 17, 'Ασθ %'),
(66553, 5179, 17, 'Σημειώσεις ασθενούς'),
(66554, 5180, 17, 'Σημειώσ/Εξουσιοδ'),
(66555, 5181, 17, 'Ο ασθενής πλήρωσε παραπάνω'),
(66556, 5182, 17, 'Ο ασθ πλήρωσε'),
(66557, 5184, 17, 'Επιστροφή χρημ. στον ασθ'),
(66558, 5185, 17, 'Απολυμένος ασθ'),
(66559, 5186, 17, 'Αναφορά ασθ'),
(66560, 5187, 17, 'Φυσική θεραπεία φοιτητή, ή αφήστε κενό'),
(66561, 5188, 17, 'Ασθ_Πόλη'),
(66562, 5189, 17, 'Ασθ_ΗμερΓενν'),
(66563, 5191, 17, 'Ασθ_Όνομα'),
(66564, 5192, 17, 'Ασθ_Επώνυμο'),
(66565, 5193, 17, 'Ασθ_ΜεσαίοΌνομα'),
(66566, 5196, 17, 'Ασθ_ΤΚ'),
(66567, 5198, 17, 'Ασθ_Νομός'),
(66568, 5199, 17, 'Ασθ_Οδός'),
(66569, 5201, 17, 'Δημόσιο'),
(66570, 5204, 17, 'Πουέρτο Ρίκο'),
(66571, 5205, 17, 'Πνευμονικό'),
(66572, 5206, 17, 'Σφυγμός'),
(66573, 5208, 17, 'Αγορά'),
(66574, 5209, 17, 'Αγορά/Επιστροφή'),
(66575, 5210, 17, 'Αγορές'),
(66576, 5213, 17, 'κάθε 3 ώρες'),
(66577, 5214, 17, 'κάθε 4 ώρες'),
(66578, 5215, 17, 'κάθε 5 ώρες'),
(66579, 5216, 17, 'κάθε 6 ώρες'),
(66580, 5217, 17, 'κάθε 8 ώρες'),
(66581, 5218, 17, 'κάθε μέρα'),
(66582, 5219, 17, '4 φορές την ημέρα'),
(66583, 5220, 17, 'Διαθέσιμη ποσότητα'),
(66584, 5221, 17, 'Η διαθέσιμη ποσότητα είναι μικρότερη από τη μηνιαία χρήση'),
(66585, 5222, 17, 'Ποσοτ'),
(66586, 5223, 17, 'ΠΟΣΟΤ'),
(66587, 5224, 17, 'Ποιότητα'),
(66588, 5225, 17, 'Μετρήσεις Ποιότητας'),
(66589, 5226, 17, 'Ποσότητα'),
(66590, 5227, 17, 'Ποσότητα Εθνικού Κωδικού Φαρμάκων'),
(66591, 5228, 17, 'Ποσότητα στο χέρι'),
(66592, 5229, 17, 'η ποσότητα αυτή μοιάζει μη χρησιμοποιήσιμη'),
(66593, 5232, 17, 'Ουρά για επεξεργ. δέσμης ενεργειών HCFA'),
(66594, 5233, 17, 'Ουρά για επεξεργ. και εκτύπ. δέσμης ενεργειών HCFA'),
(66595, 5234, 17, 'Ουρά για επεξεργ. δέσμης ενεργειών UB-92'),
(66596, 5235, 17, 'Ουρά για επεξεργ. και εκτύπ. δέσμης ενεργειών UB-92'),
(66597, 5236, 17, 'Σε ουρά'),
(66598, 5237, 17, 'Διαχείριση συμβάντων ουράς'),
(66599, 5238, 17, 'Ουρά για'),
(66600, 5240, 17, 'Διαχείριση αποστολών ουράς'),
(66601, 5241, 17, 'Έξοδος'),
(66602, 5242, 17, 'Διακοπή αλκοόλ'),
(66603, 5245, 17, 'Φυλή'),
(66604, 5246, 17, 'Φυλή και Εθνικότητα'),
(66605, 5247, 17, 'Φυλή/Εθνικότητα'),
(66606, 5248, 17, 'Ραδιόφωνο'),
(66607, 5249, 17, 'Κουμπιά επιλογής'),
(66608, 5251, 17, 'Πεδίο τιμών'),
(66609, 5252, 17, 'Εξανθήματα'),
(66610, 5253, 17, 'Ρυθμός'),
(66611, 5254, 17, 'Σχέση'),
(66612, 5255, 17, 'Στεγνή Αναφορά'),
(66613, 5256, 17, 'Σχετ. Ταυτοποίηση'),
(66614, 5257, 17, 'Σχετ. Διαδικασία ταυτοποίησης τελείωσε'),
(66615, 5258, 17, 'Σχετ. Διαδικασία ταυτοποίησης εν ενεργεία'),
(66616, 5259, 17, 'Τα αρχεία επαναταυτοποίησης θα αποθηκευθούν στο'),
(66617, 5260, 17, 'Επανάληψη βλάβης;'),
(66618, 5261, 17, 'Άνοιγμα εκ νέου'),
(66619, 5262, 17, 'Ανοίχθηκε εκ νέου'),
(66620, 5263, 17, 'Αντίδραση'),
(66621, 5264, 17, 'Αντιδράσεις'),
(66622, 5265, 17, 'Διαβάστε'),
(66623, 5268, 17, 'Πραγματικό Όνομα'),
(66624, 5269, 17, 'Πραγματική διαγραφή'),
(66625, 5270, 17, 'Αιτιολογία'),
(66626, 5271, 17, 'Αιτία Θανάτου'),
(66627, 5272, 17, 'Αιτία Θανάτου'),
(66628, 5274, 17, 'Αιτία παραπομπής'),
(66629, 5275, 17, 'Αιτία επίσκεψης'),
(66630, 5276, 17, 'Αιτιολογία/ Μορφή'),
(66631, 5277, 17, 'Απόδειξη'),
(66632, 5278, 17, 'Απόδειξη πληρωμής'),
(66633, 5279, 17, 'Η απόδειξη δημιουργήθηκε'),
(66634, 5280, 17, 'Αναφορά αποδείξεων με βάση τη μέθοδο πληρωμής'),
(66635, 5281, 17, 'Σύνοψη Αποδείξεων'),
(66636, 5282, 17, 'Ελήφθη'),
(66637, 5283, 17, 'Ελήφθη από'),
(66638, 5284, 17, 'Ληφθέντα Fax'),
(66639, 5287, 17, 'Δέκτης'),
(66640, 5288, 17, 'Κωδικός αναγνώρισης δέκτη'),
(66641, 5289, 17, 'Κωδικός αναγνώρισης δέκτη (ISA08)'),
(66642, 5290, 17, 'Αρμόδιο αναγνωριστικό δέκτη (ISA07)'),
(66643, 5292, 17, 'Οι τελευταίοι τρεις κωδικοί πρόσβασης δεν έγιναν δεκτοί'),
(66644, 5293, 17, 'Παραλήπτης'),
(66645, 5294, 17, 'Η λίστα παραληπτών είναι κενή'),
(66646, 5295, 17, 'Όνομα παραλήπτη'),
(66647, 5296, 17, 'Αποδέκτης της Γνωστοποίησης'),
(66648, 5298, 17, 'Σύσταση'),
(66649, 5300, 17, 'Συστάσεις'),
(66650, 5301, 17, 'Συστάσεις και θεραπεία'),
(66651, 5302, 17, 'Συστάσεις από ειδικό'),
(66652, 5303, 17, 'Εγγραφή'),
(66653, 5310, 17, 'Καταγραφή και παράσταση αγωγών στα ζωτικά σημεία.'),
(66654, 5311, 17, 'Καταγραφή δημογραφικών.'),
(66655, 5312, 17, 'Γνωστοποίηση εγγραφής'),
(66656, 5313, 17, 'Καταγραφή φυσικής κατάστασης'),
(66657, 5314, 17, 'Φάκελος Πληρωμών'),
(66658, 5316, 17, 'Καταγραφή κατάστασης καπνίσματος για ασθενείς ηλικίας άνω των 13 ετών.'),
(66659, 5317, 17, 'Εγγραφές'),
(66660, 5318, 17, 'βρέθηκαν εγγραφές'),
(66661, 5319, 17, 'βρέθηκαν εγγραφές.'),
(66662, 5320, 17, 'Χρήση ναρκωτικών ουσιών'),
(66663, 5321, 17, 'Ναρκωτικά'),
(66664, 5322, 17, 'Ορθό'),
(66665, 5323, 17, 'Εξέταση ορθού'),
(66666, 5324, 17, 'ορθικά'),
(66667, 5325, 17, 'Ανακατεύθυνση'),
(66668, 5326, 17, 'Ερυθρότητα'),
(66669, 5327, 17, 'ελαττωμένο:'),
(66670, 5328, 17, 'Παραπομπή'),
(66671, 5329, 17, 'Παραπεμφθέν από'),
(66672, 5330, 17, 'Ημερομηνία παραπομπής'),
(66673, 5331, 17, 'Παραπομπή σε'),
(66674, 5332, 17, 'Ταξινόμηση παραπομπής (επίπεδο κινδύνου)'),
(66675, 5333, 17, 'Φάσμα τιμών για τα αποτελέσματα'),
(66676, 5334, 17, 'Αιτιολογία παραπομπής'),
(66677, 5336, 17, 'Όνομα και υπογραφή παραπεμποντος'),
(66678, 5337, 17, 'Παραπομπή'),
(66679, 5338, 17, 'Παραπομπή από'),
(66680, 5339, 17, 'Κάρτα παραπομπής'),
(66681, 5340, 17, 'Ημερομηνία παραπομπής'),
(66682, 5341, 17, 'Έντυπο παραπομπής'),
(66683, 5342, 17, 'ΕΝΤΥΠΟ ΠΑΡΑΠΟΜΠΗΣ'),
(66684, 5343, 17, 'Κωδικός Παραπομπής'),
(66685, 5345, 17, 'Πηγή παραπομπής'),
(66686, 5346, 17, 'Πηγή παραπομπής για τις επισκέψεις'),
(66687, 5347, 17, 'Παραπομπή σε'),
(66688, 5348, 17, 'Παραπομπές'),
(66689, 5349, 17, 'Αναφορά παραπομπών'),
(66690, 5350, 17, 'Παραπομπή από'),
(66691, 5351, 17, 'Παραπομπή από'),
(66692, 5352, 17, 'Παραπομπή σε'),
(66693, 5353, 17, 'Παραπέμπων'),
(66694, 5355, 17, 'Διάγνωση παραπομπής'),
(66695, 5356, 17, 'Διάγνωση παραπομπής'),
(66696, 5357, 17, 'Παραπέμπων ιατρός και ιατρείο'),
(66697, 5358, 17, 'Πάροχος παραπομπής'),
(66698, 5359, 17, 'Επαναγέμισμα'),
(66699, 5360, 17, 'Ανταλλακτικά'),
(66700, 5361, 17, 'ανταλλακτικά'),
(66701, 5362, 17, 'Αντανακλαστικά φυσιολογικά'),
(66702, 5363, 17, 'Ανανέωση'),
(66703, 5365, 17, 'Ανανεώνονται οι Υπενθυμίσεις'),
(66704, 5368, 17, 'Άρνηση αναφοράς'),
(66705, 5370, 17, 'μητρώο'),
(66706, 5372, 17, 'Ενεγράφη'),
(66707, 5373, 17, 'ενεγράφη'),
(66708, 5375, 17, 'Ημ/νια Εγγραφής'),
(66709, 5376, 17, 'Έντυπο Εγγραφής'),
(66710, 5377, 17, 'Φυσική Αποκατάσταση'),
(66711, 5381, 17, 'Αφορά σε'),
(66712, 5382, 17, 'Σχετικό'),
(66713, 5383, 17, 'Σχετικό θέμα'),
(66714, 5385, 17, 'Σχέση/εις / Παιδιά'),
(66715, 5386, 17, 'Σχέσεις'),
(66716, 5387, 17, 'Σχέση'),
(66717, 5388, 17, 'Σχετική ταξινόμηση αυτής της οντότητας'),
(66718, 5389, 17, 'Συγγενείς'),
(66719, 5399, 17, 'Οι πιστοποιήσεις υγείας λείπουν από το λογαριασμό αυτό του χρήστη.'),
(66720, 5400, 17, 'Αναγνωριστικό πιστοποιήσεων υγείας'),
(66721, 5403, 17, 'Θρησκεία'),
(66722, 5406, 17, 'Επανασύνδεση'),
(66723, 5407, 17, 'Υπενθ.'),
(66724, 5408, 17, 'Να θυμάσαι την επιλεχθείσα έδρα'),
(66725, 5409, 17, 'Υπενθύμιση'),
(66726, 5410, 17, 'Διάστημα Υπενθύμισης'),
(66727, 5411, 17, 'Η Υπενθύμιση δεν απεστάλη'),
(66728, 5412, 17, 'Η Υπενθύμιση αποστέλλεται'),
(66729, 5413, 17, 'Υπενθυμίσεις'),
(66730, 5414, 17, 'ΑΠΟΣΤΟΛΗ ΠΡΟΣ'),
(66731, 5416, 17, 'Αφαίρεση'),
(66732, 5419, 17, 'Κατάργηση ομάδας'),
(66733, 5420, 17, 'Κατάργηση εντύπου ομάδας'),
(66734, 5421, 17, 'Αφαιρεί υποστήριξη για ανοσοποιήσεις'),
(66735, 5422, 17, 'Αφαιρεί υποστήριξη για την phpMyAdmin'),
(66736, 5423, 17, 'Αφαιρέι υποστήριξη για τις συναταγογραφήσεις'),
(66737, 5425, 17, 'Αφαιρεί το εργαλείο ανεύρεσης φακέλου'),
(66738, 5426, 17, 'Νεφρικοί λίθοι'),
(66739, 5427, 17, 'Μετονομασία'),
(66740, 5428, 17, 'Μετονομασία ομάδας'),
(66741, 5429, 17, 'Απόδοση'),
(66742, 5430, 17, 'Πάροχος απόδοσης'),
(66743, 5431, 17, 'Αριθμός παρόχου απόδοσης'),
(66744, 5432, 17, 'Επαναταξινόμηση'),
(66745, 5433, 17, 'Επαναταξινόμηση σε'),
(66746, 5434, 17, 'Το σημείο αναδιάταξης έχει φτάσει'),
(66747, 5436, 17, 'Επαν'),
(66748, 5438, 17, 'Επαναληπτικό γεγονός'),
(66749, 5439, 17, 'Επανάληψη Πληροφορίας :'),
(66750, 5440, 17, 'Επαναλήψεις'),
(66751, 5444, 17, 'Ημερομηνία απάντησης'),
(66752, 5445, 17, 'Απάντηση από'),
(66753, 5446, 17, 'Αναφορά'),
(66754, 5447, 17, 'Αναφορά - Κλινική'),
(66755, 5449, 17, 'Αναφορά από'),
(66756, 5457, 17, 'Αναφορά Κατάστασης'),
(66757, 5458, 17, 'Αναφορά συνόλων'),
(66758, 5460, 17, 'Κατάλληλο προς αναφορά'),
(66759, 5461, 17, 'Αναφερθέν'),
(66760, 5462, 17, 'Αναφερθείσα Ημερομηνία'),
(66761, 5463, 17, 'Αναφορές'),
(66762, 5467, 17, 'Η αίτηση αγνοήθηκε – η επεξεργασία αιτήσεων πληρωμής εκτελείται ήδη!'),
(66763, 5474, 17, 'Αιτηθείσα υπηρεσία'),
(66764, 5475, 17, 'Απαιτούνται ισχυροί κωδικοί πρόσβασης'),
(66765, 5476, 17, 'Απαιτούνται Μοναδικοί Κωδικοί πρόσβασης'),
(66766, 5477, 17, 'Απαιτείται'),
(66767, 5479, 17, 'Το υποχρεωτικό πεδίο απουσιάζει: Παρακαλώ επιλέξτε το αρχείο EDI-271 αρχείο για upload'),
(66768, 5480, 17, 'Λείπει υποχρεωτικό πεδίο: Παρακαλώ εισάγετε το Όνομα'),
(66769, 5481, 17, 'Λείπει υποχρεωτικό πεδίο: Παρακαλώ εισάγετε το Επώνυμο'),
(66770, 5482, 17, 'Λείπει υποχρεωτικό πεδίο: Παρακαλώ εισάγετε το Όνομα Χρήστη'),
(66771, 5483, 17, 'Υποχρεωτικά πεδία'),
(66772, 5484, 17, 'Απαιτήσεις'),
(66773, 5485, 17, 'ΔΕΣΜΕΥΜΕΝΟ'),
(66774, 5486, 17, 'Δεσμευμένη'),
(66775, 5487, 17, 'Χρησιμοποιείται προς καθορισμό της Ώρας Προγραμματισμένων Διακοπών'),
(66776, 5488, 17, 'Χρησιμοποιείται για να οριστεί πότε ένας πάροχος δεν έχει διαθέσιμα ραντεβού μετά.'),
(66777, 5489, 17, 'Χρησιμοποιείται για να οριστεί αν ένα συμβάν δεν συνέβη όπως προσδιορίστηκε.'),
(66778, 5490, 17, 'Κρατημένο για να οριστεί αν ο πάροχος έχει διαθέσιμα ραντεβού μετά.'),
(66779, 5491, 17, 'Επαναφορά'),
(66780, 5492, 17, 'Επαναφορά Διαπιστευτηρίων της Offsite Πύλης'),
(66781, 5493, 17, 'Επαναφορά Διαπιστευτηρίων της Onsite Πύλης'),
(66782, 5496, 17, 'Επιλύθηκε'),
(66783, 5497, 17, 'Αναπνοή'),
(66784, 5498, 17, 'Αναπνευστ. κινήσεις χωρίς προσπάθεια'),
(66785, 5499, 17, 'Αναπνευστικό'),
(66786, 5501, 17, 'Περιορίστε τους μη εξουσιοδοτ. χρήστες στις Schedule facilities που έχουν ορισθεί στη Διαχείριση Χρηστών'),
(66787, 5502, 17, 'Περιορίστε τους χρήστες στα Facilities'),
(66788, 5503, 17, 'Περιορισμένη κατάρτιση'),
(66789, 5504, 17, 'Αποτέλεσμα'),
(66790, 5506, 17, 'Κατάσταση αποτελεσμάτων'),
(66791, 5507, 17, 'Κατάσταση αποτελεσμάτων ή ανωμαλία λείπει'),
(66792, 5508, 17, 'Αποτέλεσμα, χρησιμοποιήστε % ως wildcard'),
(66793, 5510, 17, 'Αποτελέσματα και'),
(66794, 5511, 17, 'Βρέθηκαν αποτελέσματα για την αναζήτηση'),
(66795, 5512, 17, 'Ομάδα Απατελεσμάτων'),
(66796, 5515, 17, 'Αποτελέσματα ανά σελίδα'),
(66797, 5516, 17, 'Αποτελέσματα/Λεπτομέρειες'),
(66798, 5517, 17, 'Εξέταση αμφιβληστροειδούς'),
(66799, 5518, 17, 'Συρρικνωμένο δεξιά:'),
(66800, 5519, 17, 'Επιστροφή'),
(66801, 5520, 17, 'Επιστρέψτε το ως άνω μέρος με την πληρωμή σας'),
(66802, 5521, 17, 'Επιστροφή στο ημερολόγιο'),
(66803, 5527, 17, 'Τιμή επιστροφής'),
(66804, 5528, 17, 'Επίσκεψη παρακολούθησης'),
(66805, 5529, 17, 'Επέστρεψε στο Play'),
(66806, 5534, 17, 'Ανασκόπηση παλαιού ιστορικού:'),
(66807, 5535, 17, 'Ανασκόπηση συστημάτων'),
(66808, 5536, 17, 'Ανασκόπηση Ελέγχων Συστημάτων'),
(66809, 5537, 17, 'Ανασκοπήθηκε'),
(66810, 5538, 17, 'Αναθεώρηση'),
(66811, 5539, 17, 'Ρευματοειδής Αρθρίτιδα'),
(66812, 5540, 17, 'Ρευματοειδής αρθρίτιδα'),
(66813, 5541, 17, 'Δεξιά'),
(66814, 5542, 17, 'Δεξί αυτί'),
(66815, 5543, 17, 'δεξί αυτί'),
(66816, 5545, 17, 'Δεξιά:'),
(66817, 5546, 17, 'Εμβοές στα αυτιά'),
(66818, 5547, 17, 'Εμβοές στα αυτιά'),
(66819, 5549, 17, 'Παράγοντες κινδύνου'),
(66820, 5550, 17, 'Επίπεδο κινδύνου'),
(66821, 5551, 17, 'Δεξιός κάτω λοβός:'),
(66822, 5552, 17, 'Κίνδυνος θνητότητας'),
(66823, 5553, 17, 'Ρουμάνικα'),
(66824, 5560, 17, 'Μητρώο'),
(66825, 5561, 17, 'Διαδρομή'),
(66826, 5562, 17, 'Οδός χορήγησης, αν ισχύει'),
(66827, 5563, 17, 'Δρομολογήθηκε'),
(66828, 5564, 17, 'Σειρές'),
(66829, 5565, 17, 'Σχετικός κίνδυνος χωρίς Ιατρική αναφορά'),
(66830, 5566, 17, 'Εντριβή:'),
(66831, 5567, 17, 'Εντριβές:'),
(66832, 5568, 17, 'Κανόνας'),
(66833, 5569, 17, 'Προσθήκη Κανόνα'),
(66834, 5570, 17, 'Λεπτομέρεια Κανόνα'),
(66835, 5572, 17, 'Επεξεργασία Κανόνα'),
(66836, 5575, 17, 'Σύνολο Κανόνων'),
(66837, 5578, 17, 'Κανόνες'),
(66838, 5580, 17, 'Ρυθμίσεις Κανόνων'),
(66839, 5581, 17, 'Τρέχουσα εντολή: '),
(66840, 5582, 17, 'Ρήξη'),
(66841, 5583, 17, 'Ρωσικά'),
(66842, 5584, 17, 'Θεραπεία'),
(66843, 5585, 17, 'Φάρμακα'),
(66844, 5598, 17, 'RxNorm'),
(66845, 5599, 17, 'Βάση RxNorm'),
(66846, 5601, 17, 'ΑΜΚΑ'),
(66847, 5602, 17, 'Τόνος S3'),
(66848, 5603, 17, 'Τόνος S3'),
(66849, 5604, 17, 'ΠΑΡΑΠΟΜΠΗ * * Για να διαβάσετε την άδεια χρήσης, φορτώστε το αρχείο docs/license.txt ή επισκεφθείτε την ιστοσελίδα * http://www.gnu.org/copyleft/gpl.html * */ //========================================================================= // '),
(66850, 5605, 17, 'Πώληση'),
(66851, 5606, 17, 'Πωλήσεις'),
(66852, 5607, 17, 'Πωλήσεις ανά Τεμάχιο'),
(66853, 5608, 17, 'Πωλήσεις ανά Αναφορά Προϊόντος'),
(66854, 5609, 17, 'Σίελος'),
(66855, 5610, 17, 'Ίδια Ημέρα'),
(66856, 5611, 17, 'Σαμόα'),
(66857, 5612, 17, 'Δείγμα'),
(66858, 5613, 17, 'Τύπος έγκρισης'),
(66859, 5617, 17, 'Σάβ'),
(66860, 5618, 17, 'Σάβ &'),
(66861, 5619, 17, 'Σάββατο'),
(66862, 5620, 17, 'Αποθήκευση'),
(66863, 5621, 17, 'ΑΠΟΘΗΚΕΥΣΗ'),
(66864, 5622, 17, 'Αποθήκευση και Κλείσιμο'),
(66865, 5624, 17, 'Αποθήκευση και Διανομή'),
(66866, 5626, 17, 'Αποθήκευση ως νέο'),
(66867, 5627, 17, 'Αποθήκευση ως νέα σημείωση'),
(66868, 5628, 17, 'Αποθήκευση ρυθμίσεων Πιστοποιητικού'),
(66869, 5629, 17, 'Αποθήκευση Αλλαγών'),
(66870, 5630, 17, 'Αποθήκευση Εντύπου'),
(66871, 5631, 17, 'Αποθήκευση Ανοσοποίησης'),
(66872, 5632, 17, 'Αποθήκευση Νέου Πεδίου'),
(66873, 5633, 17, 'Αποθήκευση Νέας Ομάδας'),
(66874, 5634, 17, 'Αποθήκευση Νέου Καταλόγου'),
(66875, 5635, 17, 'Αποθήκευση Νέας διάταξης'),
(66876, 5637, 17, 'Αποθήκευση Δημογραφικών στοιχείων ασθενούς'),
(66877, 5638, 17, 'Επιτυχής αποθήκευση για το αναγνωριστικό γραφήματος'),
(66878, 5639, 17, 'Αποθήκευση Συναλλαγής'),
(66879, 5641, 17, 'Σαρώθηκε'),
(66880, 5642, 17, 'Η Σημείωση επίσκεψης σαρώθηκε'),
(66881, 5643, 17, 'Κατάλογος σαρωτή'),
(66882, 5644, 17, 'Σαρωτής σε'),
(66883, 5645, 17, 'Πρόγραμμα'),
(66884, 5646, 17, 'Πρόγραμμα Έδρας:'),
(66885, 5647, 17, 'ΣΗΜΕΙΩΣΗ ΣΧΟΛΕΙΟΥ'),
(66886, 5648, 17, 'Σκολίωση'),
(66887, 5651, 17, 'Εργοδότης'),
(66888, 5652, 17, 'Διεύθυνση Εργοδότη'),
(66889, 5653, 17, 'Πόλη Εργοδότη'),
(66890, 5654, 17, 'Χώρα Εργοδότη'),
(66891, 5655, 17, 'Περιοχή Εργοδότη'),
(66892, 5656, 17, 'Τ.Κ. Εργοδότη'),
(66893, 5657, 17, 'Νομός Εργοδότη'),
(66894, 5658, 17, 'Τ.Κ. Εργοδότη'),
(66895, 5659, 17, 'Αναζήτηση'),
(66896, 5661, 17, 'αναζήτηση'),
(66897, 5662, 17, 'αναζήτησε πάλι'),
(66898, 5663, 17, 'Αναζήτηση σε όλες τις στήλες'),
(66899, 5664, 17, 'Αναζήτηση με βάση:'),
(66900, 5665, 17, 'Αναζήτηση για'),
(66901, 5666, 17, 'Αναζήτηση για:'),
(66902, 5668, 17, 'Αναζήτηση σε'),
(66903, 5669, 17, 'Αναζήτηση ή προσθήκη ασθενούς'),
(66904, 5670, 17, 'Αναζήτηση πληρωμής'),
(66905, 5672, 17, 'Αποτελέσματα Αναζήτησης'),
(66906, 5673, 17, 'Αναζήτηση επιλέχθηκε'),
(66907, 5674, 17, 'Η λέξη αναζήτησης δεν ταιριάζει με τη λίστα στη βάση δεδομένων'),
(66908, 5675, 17, 'Η λέξη αναζήτησης πρέπει να έχει τουλάχιστον 3 χαρακτήρες'),
(66909, 5676, 17, 'Αναζήτηση Κειμένου'),
(66910, 5677, 17, 'Αναζήτηση στα Γεγονότα'),
(66911, 5678, 17, 'Αναζήτηση/ Προσθήκη'),
(66912, 5679, 17, 'Αναζήτηση/ Προσθήκη Ασφαλιστή'),
(66913, 5680, 17, 'Αναζήτηση για ραντεβού'),
(66914, 5681, 17, 'Αναζήτηση...'),
(66915, 5682, 17, 'Χρήση Ζώνης Ασφαλείας'),
(66916, 5683, 17, 'Χρήση ζώνης ασφαλείας'),
(66917, 5684, 17, 'Δεύτερο'),
(66918, 5687, 17, 'Δευτερεύουσα'),
(66919, 5688, 17, 'Δευτερέυουσα Ασφάλιση'),
(66920, 5689, 17, 'Δεδομένα Δευτερεύουσας Ασφάλισης'),
(66921, 5690, 17, 'Πάροχος Δευτερεύουσας Ασφάλισης'),
(66922, 5691, 17, 'Τύπος Δευτερεύουσας Πρόνοιας'),
(66923, 5698, 17, 'Ασφάλεια'),
(66924, 5699, 17, 'Προβολή Όλων'),
(66925, 5700, 17, 'Δείτε τις εξουσιοδοτήσεις'),
(66926, 5701, 17, 'Δείτε τις καμπύλες ανάπτυξης'),
(66927, 5702, 17, 'Δείτε τα μηνύματα από το τελευταίο σύνολο των δημιουργημένων απαιτήσεων'),
(66928, 5704, 17, 'Προβολή από'),
(66929, 5707, 17, 'Επιληπτικές κρίσεις'),
(66930, 5708, 17, 'Επιλ'),
(66931, 5709, 17, 'Επιλογή'),
(66932, 5710, 17, 'επιλέξτε'),
(66933, 5712, 17, 'Επιλογή Πλαισίου'),
(66934, 5714, 17, 'Επιλέξτε Χρονικό Πλαίσιο'),
(66935, 5715, 17, 'Επιλογή Χρήστη'),
(66936, 5716, 17, 'Επιλογή Όλων'),
(66938, 5720, 17, 'Επιλογή κατηγορίας'),
(66939, 5722, 17, 'Επιλέξτε αντίστοιχα πλαίσια για διαγραφή'),
(66940, 5723, 17, 'Επιλέξτε κριτήρια για αφαίρεση'),
(66941, 5725, 17, 'Επιλογή δεδομένων που απαιτούνται για Απο Ταυτοποίηση'),
(66942, 5726, 17, 'Επιλογή δεδομένων για να περιληφθούν στα Απο Ταυτοποιημένα δεδομένα'),
(66943, 5727, 17, 'Επιλογή ημερομηνίας'),
(66944, 5729, 17, 'Επιλογή διάγνωσης'),
(66945, 5730, 17, 'Επιλογή διάγνωσης για αίτημα Απο Ταυτοποίησης'),
(66946, 5731, 17, 'Επιλογή Φαρμάκου'),
(66947, 5732, 17, 'Επιλογή Φαρμάκων'),
(66948, 5733, 17, 'Επιλογή Φαρμάκων για αίτημα Απο Ταυτοποίησης'),
(66949, 5734, 17, 'Επιλογή αρχείου EDI-271'),
(66950, 5736, 17, 'Επιλογή Πεδίου'),
(66951, 5737, 17, 'Επιλογή Πεδίων'),
(66952, 5738, 17, 'Επιλογή για εκτύπωση'),
(66953, 5739, 17, 'Επιλογή Εμβολίων'),
(66954, 5740, 17, 'Επιλογή Εμβολίων για αίτημα Απο Ταυτοποίησης'),
(66955, 5741, 17, 'Επιλογή Ασφάλεια, πληκτρολογώντας'),
(66956, 5742, 17, 'Επιλογή Ιατρικού θέματος'),
(66957, 5744, 17, 'Επιλογή Γλώσσας'),
(66958, 5746, 17, 'Επιλέξτε ένα ή περισσότερους διαγνωστικούς κωδικούς για να δικαιολογήσετε την υπηρεσία'),
(66959, 5754, 17, 'Επιλέξτε τα στοιχεία ρύθμισης για εξαγωγή'),
(66960, 5755, 17, 'Επιλέξτε τον κυρίως υπεύθυνο παράγοντα για όποια συμβάντα δεν έλαβαν χώρα σε αυτή την ημέρα'),
(66961, 5759, 17, 'Επιλέξτε Χρήστη'),
(66962, 5760, 17, 'Επιλέξτε Χρήστες από τη Λίστα'),
(66963, 5761, 17, 'Εάν πρέπει, επιλέξτε ποιες γλώσσες μπορούν να επιλεγούν κατά την είσοδο στο πρόγραμμα (ισχύει μόνο αν η παραπάνω επιλογή Επιτρέπονται Όλες οι Γλώσσες είναι απενεργοποιημένη)'),
(66964, 5762, 17, 'Επιλέξτε Ναι για να επιβεβαιώσετε τη Διαγραφή της ομάδας'),
(66965, 5765, 17, 'Επιλεγμένο'),
(66966, 5766, 17, 'Επιλεγμένη Επίσκεψη'),
(66967, 5768, 17, 'Εαυτός'),
(66968, 5769, 17, 'Αυτο-πληρωμή'),
(66969, 5771, 17, 'Αποστολή'),
(66970, 5773, 17, 'Αποστολή Υπενθύμισης'),
(66971, 5774, 17, 'Αποστολή σε εξέλιξη'),
(66972, 5775, 17, 'Αποστολή μηνύματος'),
(66973, 5777, 17, 'Προτίμηση ανά ασθενή για Αποστολή υπενθυμίσεων σε ασθενείς για προληπτική παρακολούθηση.'),
(66974, 5778, 17, 'Αποστολή Σύνοψης με την Παραπομπή'),
(66975, 5779, 17, 'Αποστολή αυτού του αρχείου'),
(66976, 5780, 17, 'Αποστολή αυτού του Μηνύματος'),
(66977, 5781, 17, 'Αποστολή σε'),
(66978, 5784, 17, 'Αποστολή σε όλους'),
(66979, 5788, 17, 'Αποστολέας'),
(66980, 5789, 17, 'Αναγνωριστικό αποστολέα'),
(66981, 5790, 17, 'Αναγνωριστικό αποστολέα (ISA06)'),
(66982, 5791, 17, 'Αρμόδιο αναγνωριστικό αποστολέα (ISA05)'),
(66983, 5794, 17, 'Ευαισθησίες'),
(66984, 5795, 17, 'Ευαισθησία:'),
(66985, 5796, 17, 'Αισθητική εξέταση φυσιολογική'),
(66986, 5799, 17, 'Εστάλη Από (Αφήστε Κενό για Όλους)'),
(66987, 5801, 17, 'Ημερομηνία Αποστολής'),
(66988, 5802, 17, 'Αποσταλθέντα αντικείμενα'),
(66989, 5803, 17, 'Σταλθέντες Ιατρικοί Φάκελοι;'),
(66990, 5804, 17, 'Απεστάλη επιτυχώς'),
(66991, 5807, 17, 'απεστάλη στον εκτυπωτή'),
(66992, 5808, 17, 'Εστάλη Πρός (Αφήστε Κενό για Όλους)'),
(66993, 5812, 17, 'Σεπ'),
(66994, 5813, 17, 'Χωρισμένος/η'),
(66995, 5814, 17, 'Σεπτέμβριος'),
(66996, 5815, 17, 'Σειρά'),
(66997, 5816, 17, 'Αλληλουχία'),
(66998, 5821, 17, 'Υπηρεσία'),
(66999, 5822, 17, 'Κατηγορία υπηρεσιών'),
(67000, 5823, 17, 'Κωδικός υπηρεσίας'),
(67001, 5824, 17, 'Κωδικός υπηρεσίας για την Αναφορά Οικονομικών'),
(67002, 5825, 17, 'Κωδικοί υπηρεσίας'),
(67003, 5826, 17, 'Ημερομ. παροχής Υπηρεσίας'),
(67004, 5827, 17, 'Ημερομ. παροχής υπηρεσίας:'),
(67005, 5829, 17, 'Τοποθεσία παροχής υπηρεσίας'),
(67006, 5831, 17, 'Η υπηρεσία παρεσχέθη από Ειδικό'),
(67007, 5834, 17, 'Υπηρεσίες'),
(67008, 5835, 17, 'Υπηρεσίες ανά Κατηγορία'),
(67009, 5836, 17, 'Οι υπηρεσίες παρεσχέθησαν'),
(67010, 5837, 17, 'Οι υπηρεσίες παρεσχέθησαν'),
(67011, 5838, 17, 'Υπηρεσίες/Προϊόντα'),
(67012, 5839, 17, 'Τύπος Συνεδρίας'),
(67013, 5840, 17, 'Ρυθμίστε'),
(67014, 5841, 17, 'Ορίστε ένα cookie Έδρας, για να θυμάται, μεταξύ των logins, την επιλεχθείσα Έδρα.'),
(67015, 5842, 17, 'Ορίστε ως Συμπληρωμένο'),
(67016, 5845, 17, 'Ορίστε αυτή ως την πλήρη απόλυτη διαδρομή. Για τη δημιουργία πιστοποιητικά πελάτη SSL για HTTPS.3');
INSERT INTO `lang_definitions` VALUES
(67017, 5846, 17, 'Ορισμός ως'),
(67018, 5847, 17, 'Ορισμός ως προεπιλογή'),
(67019, 5848, 17, 'Ορισμός του αριθμού έκδοσης στη βάση δεδομένων ...'),
(67020, 5849, 17, 'Ρυθμίσεις'),
(67021, 5851, 17, 'Ημικρανία'),
(67022, 5853, 17, 'Βαρύτητα πόνου'),
(67023, 5854, 17, 'Βαρύτητα πόνου:'),
(67024, 5855, 17, 'Φύλο'),
(67025, 5856, 17, 'Σεξουαλικά μεταδιδ. νόσημα'),
(67026, 5858, 17, 'Sha-1 Hash'),
(67027, 5859, 17, 'Διαμοιρασμός'),
(67028, 5860, 17, 'Εντολή Κελύφους για εκτύπωση από τον server'),
(67029, 5864, 17, 'Δύσπνοια'),
(67030, 5865, 17, 'Δύσπνοια'),
(67031, 5866, 17, 'Δύσπνοια 2'),
(67032, 5867, 17, 'Καταγραφή Εμβολιασμού'),
(67033, 5868, 17, 'Καταγραφή Εμβολιασμών από τις:'),
(67034, 5870, 17, 'θα πρέπει να είναι ως nnnnn-nnnn-nn'),
(67035, 5871, 17, 'θα πρέπει να είναι δύο γράμματα'),
(67036, 5872, 17, 'πρέπει να περιέχει 10 ψηφία'),
(67037, 5873, 17, 'πρέπει να περιέχει μόνο 10 ψηφία'),
(67038, 5874, 17, 'Ώμος'),
(67039, 5875, 17, 'Ώμος + κλείδα'),
(67040, 5876, 17, 'Προβλήμ. ώμου'),
(67041, 5877, 17, 'Προβολή'),
(67042, 5878, 17, 'Προβολή ενεργών'),
(67043, 5880, 17, 'Προβολή Ολων'),
(67044, 5883, 17, 'Προβολή Ολων των Συναλλαγών'),
(67045, 5884, 17, 'Προβολή ως απασχολημένο'),
(67046, 5885, 17, 'Προβολή μόνο των εξουσιοδοτημένων'),
(67047, 5886, 17, 'Προβολή Διαθέσιμων Ωρών'),
(67048, 5887, 17, 'Προβολή και του Αμερικαν. και του Μετρικού συστήματος (η κύρια μονάδα θα είναι το μετρικό)'),
(67049, 5888, 17, 'Προβολή και του Αμερικαν. και του Μετρικού συστήμ. (η κύρια μονάδα θα είναι το Αμερικαν.)'),
(67050, 5889, 17, 'Προβολή Λεπτομερειών'),
(67051, 5891, 17, 'Προβολή Γραφήματος'),
(67052, 5892, 17, 'Να προβάλλεται βοηθητικό κείμενο κατά την κατάδειξη με το ποντίκι;'),
(67053, 5893, 17, 'Πόσα γεγονότα θέλετε να προβάλλονται στις σελίδες διαχείρισης;'),
(67054, 5894, 17, 'Προβολή ανενεργών'),
(67055, 5896, 17, 'Προβολή Mενού'),
(67056, 5897, 17, 'Προβολή μόνο του Μετρικού συστήματος'),
(67057, 5898, 17, 'Προβολή Σημειώσεων'),
(67058, 5901, 17, 'Προβολή Σημειώσεων Ασθενούς'),
(67059, 5905, 17, 'Προβολή Υπενθυμίσεων'),
(67060, 5906, 17, 'Προβολή Αναφοράς'),
(67061, 5907, 17, 'Προβολή δεσμών αναζήτησης/αποστολή σε μπλοκ;'),
(67062, 5913, 17, 'Προβολή μόνο μη χρεωμένων'),
(67063, 5914, 17, 'Προβολή μόνο του Αμερικαν. συστήματος'),
(67064, 5920, 17, 'Αδέλφια'),
(67065, 5921, 17, 'Δρεπανοκύτταρο'),
(67066, 5922, 17, 'Δόση'),
(67067, 5923, 17, 'Σιγμοειδο-/Κολονοσκόπηση'),
(67068, 5925, 17, 'Υπογραφή Εργαστηρ. αποτελεσμάτων (εγγραφή, προαιρετ. προσθήκη)'),
(67069, 5926, 17, 'Υπογραφή Εργαστηριακών'),
(67070, 5927, 17, 'Υπογραφή'),
(67071, 5929, 17, 'Υπογραφή:'),
(67072, 5930, 17, 'Υπογεγραμμένη συνταγή'),
(67073, 5932, 17, 'Έντονη διόγκωση:'),
(67074, 5934, 17, 'Απλοποιημένη Συμμετοχή στην πληρωμή'),
(67075, 5935, 17, 'Απλοποιημένα Δημογραφικά'),
(67076, 5936, 17, 'Απλοποιημένες Συνταγογραφήσεις'),
(67077, 5937, 17, 'Εδώ και'),
(67078, 5938, 17, 'Ειλικρινά,'),
(67079, 5940, 17, 'Άγαμος/η'),
(67080, 5941, 17, 'Λίστα μονής επιλογής'),
(67081, 5942, 17, 'Λίστα μονής επιλογής με δυνατότητα προσθήκης στη λίστα'),
(67082, 5946, 17, 'Προβλήμ. Ιγμορίων'),
(67083, 5947, 17, 'Εγχείριση Ιγμορίων'),
(67084, 5948, 17, 'Ευαισθησία Ιγμορίων:'),
(67085, 5949, 17, 'Ιγμορίτις'),
(67086, 5951, 17, 'Κωδικός ID ιστοσελίδας'),
(67087, 5953, 17, 'Κωδικός ID ιστοσελίδας για την υπηρεσία υποστήριξης LibreEHR Support LLC Lab Exchange'),
(67088, 5956, 17, 'Μέγεθος'),
(67089, 5957, 17, 'Το μέγεθος πρέπει να είναι αριθμός μεταξύ 1 και 999'),
(67090, 5958, 17, 'Μέγεθος/Κατάλογος'),
(67091, 5959, 17, 'Δέρμα'),
(67092, 5960, 17, 'Καρκίνος δέρματος'),
(67093, 5961, 17, 'Νόσος δέρματος'),
(67094, 5962, 17, 'Δέρμα – άλλο'),
(67095, 5963, 17, 'Παραλείψτε εξουσιοδ. του φακέλου ασθενούς'),
(67096, 5964, 17, 'Παράλειψη ενότητας'),
(67097, 5965, 17, 'Παράκαμψη του SQL-Ledger dump - δεν είναι υλοποιημένο σε Windows server'),
(67098, 5967, 17, 'Τύπος ύπνου'),
(67099, 5968, 17, 'Τύπος ύπνου'),
(67100, 5969, 17, 'Κοιμώμενο'),
(67101, 5970, 17, 'Σλοβακικά'),
(67102, 5973, 17, 'Η λανθάνουσα μνήμη Smarty έχει καθαριστεί'),
(67103, 5974, 17, 'Καπνιστής, άγνωστη τρέχουσα κατάσταση'),
(67104, 5976, 17, 'Κατάσταση Καπνίσματος'),
(67105, 5978, 17, 'SMS Gateway'),
(67106, 5979, 17, 'SMS Gateway API key'),
(67107, 5980, 17, 'SMS Gateway API key'),
(67108, 5981, 17, 'Κωδικός πρόσβασης για το SMS gateway'),
(67109, 5982, 17, 'Όνομα χρήστη για το SMS gateway'),
(67110, 5983, 17, 'Ειδοποίηση μέσω SMS'),
(67111, 5984, 17, 'Ωράρια ειδοποίησης με SMS'),
(67112, 5985, 17, 'Το SMS να σταλεί πριν από τις'),
(67113, 5986, 17, 'SMS εστάλη'),
(67114, 5988, 17, 'Ρυθμίσεις προειδοποίησης για SMS και e-mails'),
(67115, 5989, 17, 'Κωδικός SMTP για Πιστοποίηση'),
(67116, 5992, 17, 'Ονομα Host SMTP server'),
(67117, 5993, 17, 'Αριθμός θύρας SMTP server'),
(67118, 5994, 17, 'Χρήστης SMTP για Πιστοποίηση'),
(67119, 5995, 17, 'SNOMED'),
(67120, 5997, 17, 'Διάγνωση SNOMED (RF1)'),
(67121, 5999, 17, 'Διάγνωση SNOMED (RF2)'),
(67122, 6001, 17, 'Βάση δεδομένων SNOMED'),
(67123, 6002, 17, 'Διάγνωση SNOMED'),
(67124, 6004, 17, 'Ροχαλητό'),
(67125, 6005, 17, 'ΕΚΤΙΜΗΣΗ ασθενούς'),
(67126, 6006, 17, 'Κοινωνικές δυσκολίες'),
(67127, 6009, 17, 'Κοινωνικό Ιστορικό:'),
(67128, 6010, 17, 'Αριθμός Μητρώου Κοινωνικής Ασφάλισης'),
(67129, 6011, 17, 'διάλυμα (sol)'),
(67130, 6013, 17, 'Σωματική κατατομή'),
(67131, 6014, 17, 'Ορισμένες άδειες δεν εμφανίζονται. Κάντε κλικ εδώ για να τις δείτε όλες'),
(67132, 6015, 17, 'Ορισμένοι κωδικοί δεν εμφανίστηκαν'),
(67133, 6016, 17, 'Ορισμένες επισκέψεις δεν εμφανίστηκαν. Κάντε κλικ εδώ για να τις δείτε όλες.'),
(67134, 6017, 17, 'Συνέβη ένα σφάλμα κατά τη διαδικασία Απο-Ταυτοποίησης'),
(67135, 6018, 17, 'Ορισμένες σημειώσεις δεν εμφανίστηκαν'),
(67136, 6020, 17, 'ορισμένες λέξεις'),
(67137, 6023, 17, 'Κάτι πήγε στραβά. Παρακαλώ προσπαθήστε πάλι.'),
(67138, 6026, 17, 'Φαρυγγοδυνία'),
(67139, 6027, 17, 'Συγνώμη, δεν κλείστηκε κανένα ραντεβού'),
(67140, 6028, 17, 'Συγνώμη, υπήρξε πρόβλημα κατά το ανέβασμα του αρχείου σας'),
(67141, 6029, 17, 'Ταξινόμηση ανα'),
(67142, 6030, 17, 'Ταξινόμηση ανα'),
(67143, 6031, 17, 'Ταξινόμηση ανα Checksum'),
(67144, 6032, 17, 'Ταξινόμηση ανα Σχόλια'),
(67145, 6033, 17, 'Ταξινόμηση με βάση τον τρέχοντα χρήστη'),
(67146, 6034, 17, 'Ταξινόμηση ανά ημερομηνία'),
(67147, 6035, 17, 'Ταξινόμηση ανά ημερομηνία/ωρα'),
(67148, 6036, 17, 'Ταξινόμηση ανά Συμβάν'),
(67149, 6037, 17, 'Ταξινόμηση ανα Ομαδα'),
(67150, 6040, 17, 'Ταξινόμηση ανά Κωδικό ασθενούς'),
(67151, 6041, 17, 'Ταξινόμηση με βάση το βαθμό επιτυχίας'),
(67152, 6043, 17, 'Ταξινόμηση ανα Χρήστη'),
(67153, 6044, 17, 'Ταξινόμηση ανά εμβόλιο'),
(67154, 6045, 17, 'Ταξινόμηση κατά φθίνοντα αριθμό'),
(67155, 6046, 17, 'Ταξινόμηση αποτελέσματος ανα'),
(67156, 6047, 17, 'Ταξινόμηση κατ'' αύξοντα αριθμό'),
(67157, 6048, 17, 'Πηγή'),
(67158, 6049, 17, 'Αρχείο Πηγής'),
(67159, 6050, 17, 'Path Αρχείου Πηγής'),
(67160, 6051, 17, 'Η πηγή λείπει για τον κωδικό '),
(67161, 6052, 17, 'Κωδικός παρτίδας πηγής'),
(67162, 6057, 17, 'Πηγή:'),
(67163, 6060, 17, 'Χώρος'),
(67164, 6061, 17, 'ΧΩΡΟΣ'),
(67165, 6062, 17, 'Ισπανικά'),
(67166, 6063, 17, 'Ισπανικά (Λατινικής Αμερικής)'),
(67167, 6064, 17, 'Ισπανικά (Ισπανίας)'),
(67168, 6068, 17, 'Ειδικός'),
(67169, 6069, 17, 'Όνομα και υπογραφή ειδικού'),
(67170, 6071, 17, 'Ειδικότητα'),
(67171, 6072, 17, 'Συστήματα ειδικού'),
(67172, 6073, 17, 'Ειδικότητα:'),
(67173, 6074, 17, 'Ειδικό'),
(67174, 6075, 17, 'Ειδική εφαρμογή'),
(67175, 6076, 17, 'Ειδική παροχή υπηρεσίας αντισύλληψης'),
(67176, 6077, 17, 'Ειδικό αποτέλεσμα'),
(67177, 6078, 17, 'Ειδική Υπηρεσία'),
(67178, 6079, 17, 'Διευκρινίστηκε'),
(67179, 6088, 17, 'Δείγμα'),
(67180, 6089, 17, 'Αριθμός δείγματος/κωδικός'),
(67181, 6090, 17, 'Είδος δείγματος'),
(67182, 6092, 17, 'Υπαγόρευση ομιλίας'),
(67183, 6093, 17, 'Σπερματοκτόνο'),
(67184, 6094, 17, 'Σπληνεκτομή'),
(67185, 6095, 17, 'Σύζυγος'),
(67186, 6097, 17, 'Πτύελα'),
(67187, 6098, 17, 'Πτύελα:'),
(67188, 6099, 17, 'Υποδόρια'),
(67189, 6102, 17, 'Ομάδα'),
(67190, 6103, 17, 'Μέλος ομάδας'),
(67191, 6104, 17, 'Ομάδες'),
(67192, 6105, 17, 'Σεξουαλική και αναπαραγωγική υγεία'),
(67193, 6106, 17, 'Σεξουαλική και αναπαραγωγική υγεία – Οικογενειακός προγραμματισμός'),
(67194, 6107, 17, 'Σεξουαλική και αναπαραγωγική υγεία – Μη οικογενειακός προγραμματισμός'),
(67195, 6108, 17, 'Παραπομπές σεξουαλικής και αναπαραγωγικής υγείας'),
(67196, 6109, 17, 'Έντυπο επίσκεψης σεξουαλικής και αναπαραγωγικής υγείας'),
(67197, 6110, 17, 'Ημερ. Υπηρ.'),
(67198, 6111, 17, 'ΑΜΚΑ'),
(67199, 6112, 17, 'Πιστοποιητικό Διαχείρισης SSL'),
(67200, 6113, 17, 'ΑΜΚΑ'),
(67201, 6114, 17, 'Σταθερότητα'),
(67202, 6116, 17, 'Πρότυπο'),
(67203, 6117, 17, 'Standard Κωδικός'),
(67204, 6118, 17, 'Standard Μέτρηση'),
(67205, 6122, 17, 'Standard Ονομα'),
(67206, 6124, 17, 'Έναρξη'),
(67207, 6125, 17, 'Έναρξη (εεεε-μμ-ηη) '),
(67208, 6128, 17, 'Ημερομ. έναρξης'),
(67209, 6129, 17, 'Ημερομηνία έναρξης στην παρούσα Κλινική'),
(67210, 6130, 17, 'Ημερομ. Έναρξης δεν μπορεί να είναι μεταγενέστερη από Ημερομ. τέλους'),
(67211, 6131, 17, 'Ημερομ. έναρξης:'),
(67212, 6132, 17, 'Ημερομ. έναρξης:'),
(67213, 6133, 17, 'Ώρα έναρξης'),
(67214, 6134, 17, 'Ημερομηνία Έναρξης'),
(67215, 6135, 17, 'εφάπαξ'),
(67216, 6136, 17, 'Νομός'),
(67217, 6137, 17, 'Διευκρινίστε το είδος των Δεδομένων'),
(67218, 6138, 17, 'Αριθμ. Αδείας'),
(67219, 6139, 17, 'Αριθμός Αδείας'),
(67220, 6140, 17, 'Λίστα Καταστάσεων'),
(67221, 6141, 17, 'Λίστα Καταστάσεων (εγγραφή, προαιρετικά προσθήκη)'),
(67222, 6143, 17, 'Νομός ή Επαρχία'),
(67223, 6144, 17, 'Νομός/Περιοχή'),
(67224, 6145, 17, 'Νομός/Κοινότητα'),
(67225, 6146, 17, 'ΣΥΝΟΠΤΙΚΗ ΚΑΤΑΣΤΑΣΗ'),
(67226, 6147, 17, 'δηλώσεις και επικαιροποιητικά τιμολόγια.'),
(67227, 6148, 17, 'Δηλώσεις αποστάλησαν:'),
(67228, 6149, 17, 'δηλώσεις. Τα τιμολόγια δεν θα επικαιροποιηθούν.'),
(67229, 6150, 17, 'Στατικό Κείμενο'),
(67230, 6151, 17, 'Στατιστικά'),
(67231, 6152, 17, 'Στατιστικά'),
(67232, 6153, 17, 'Κατάσταση'),
(67233, 6156, 17, 'Status quo (Ιδία κατάσταση)'),
(67234, 6158, 17, 'Συμβουλευτική ΣΜΝ/AIDS'),
(67235, 6159, 17, 'Μυική ισχύς και conditioning'),
(67236, 6164, 17, 'Βήματα για την εγκατάσταση της βάσης δεδομένων DSM IV'),
(67237, 6165, 17, 'Βήματα για την εγκατάσταση της βάσης δεδομένων ICD10'),
(67238, 6166, 17, 'Βήματα για την εγκατάσταση της βάσης δεδομένων ICD9'),
(67239, 6167, 17, 'Βήματα για την εγκατάσταση της βάσης δεδομένων RxNorm'),
(67240, 6168, 17, 'Βήματα προς εγκατάσταση στη βάση δεδομένων Snomed'),
(67241, 6169, 17, 'Δυσκαμψία αρθρώσεων'),
(67242, 6170, 17, 'Δυσκαμψία'),
(67243, 6172, 17, 'Άλγη στομάχου'),
(67244, 6174, 17, 'Αποθηκευμένο hash'),
(67245, 6175, 17, 'Διάταση μυός'),
(67246, 6176, 17, 'Ροή'),
(67247, 6177, 17, 'Οδός'),
(67248, 6178, 17, 'Διεύθυνση οδού'),
(67249, 6179, 17, 'Οδός και Αριθμός'),
(67250, 6180, 17, 'Ισχύς'),
(67251, 6182, 17, 'Φάρυγγας Στρεπ'),
(67252, 6183, 17, 'Κάταγμα κόπωσης'),
(67253, 6184, 17, 'Δοκιμασία κόπωσης'),
(67254, 6185, 17, 'Αγγειακό εγκεφαλικό'),
(67255, 6186, 17, 'Δυνατός κωδικός πρόσβασης σημαίνει τουλάχ. 8 χαρακτήρες και τουλάχ. 3: αριθμούς, μικρά γράμματα, κεφαλαία γράμματα, ειδικούς χαρακτήρες.'),
(67256, 6188, 17, 'Στυλ εγγράφου σε χρήση, για την προσθήκη νέων ασθενών'),
(67257, 6189, 17, 'Υποκατηγορία'),
(67258, 6190, 17, 'Μερικό Σύνολο'),
(67259, 6191, 17, 'Υποκατηγορία'),
(67260, 6192, 17, 'υποκατηγορία'),
(67261, 6193, 17, 'υποδορίως'),
(67262, 6194, 17, 'Θέμα'),
(67263, 6195, 17, 'Ιστορικό'),
(67264, 6196, 17, 'Υπογλώσσιο'),
(67265, 6197, 17, 'υπογλώσσιο'),
(67266, 6198, 17, 'Υποβολή'),
(67267, 6199, 17, 'υποβολή'),
(67268, 6200, 17, 'Υποβολή όλου του περιεχομένου'),
(67269, 6202, 17, 'Υποβολή συμβάντος'),
(67270, 6203, 17, 'υποβολή εντύπου'),
(67271, 6204, 17, 'Υποβολή επιλεγμένου περιεχομένου'),
(67272, 6205, 17, 'Υπεβλήθη'),
(67273, 6206, 17, 'Υπεβλήθη από'),
(67274, 6207, 17, 'Αριθμός πρόσβασης υποβολέα EDI (PER06)'),
(67275, 6208, 17, 'Συνδρομητής'),
(67276, 6209, 17, 'Διεύθυνση Συνδρομητή'),
(67277, 6213, 17, 'Εργοδότης Συνδρομητή'),
(67278, 6214, 17, 'Εργοδότης Συνδρομητή'),
(67279, 6215, 17, 'Διεύθυνση Εργοδότη Συνδρομητή'),
(67280, 6216, 17, 'Πόλη Εργοδότη Συνδρομητή'),
(67281, 6217, 17, 'Χώρα Εργοδότη Συνδρομητή'),
(67282, 6218, 17, 'Νομός Εργοδότη Συνδρομητή'),
(67283, 6221, 17, 'Τ.Κ. Εργοδότη Συνδρομητή'),
(67284, 6225, 17, 'Τηλέφωνο Εργοδότη Συνδρομητή'),
(67285, 6226, 17, 'Σχέση Εργοδότη Συνδρομητή'),
(67286, 6227, 17, 'Η σχέση του συνδρομητή δεν είναι αφ'' εαυτή αλλά το όνομα είναι το ίδιο! Είναι πραγματικά εντάξει;'),
(67287, 6228, 17, 'Η σχέση του συνδρομητή δεν είναι αφ'' εαυτή αλλά το όνομα είναι το ίδιο!'),
(67288, 6229, 17, 'Η σχέση του συνδρομητή είναι αφ'' εαυτή αλλά το όνομα είναι διαφορετικό! Είναι πραγματικά εντάξει;'),
(67289, 6230, 17, 'Η σχέση του συνδρομητή είναι αφ'' εαυτή αλλά ο αριθμός SS είναι διαφορετικός!'),
(67290, 6231, 17, 'Φύλο Συνδρομητή'),
(67291, 6237, 17, 'Υποκατάσταση'),
(67292, 6238, 17, 'Επιτρέπεται η υποκατάσταση'),
(67293, 6240, 17, 'Επιτυχία'),
(67294, 6241, 17, 'επιτυχία'),
(67295, 6242, 17, 'Επιτυχής επικύρωση λήψης εργαστηρ. αποτελεσμάτων'),
(67296, 6243, 17, 'Επιτυχής λήψη εργαστηρ. αποτελεσμάτων'),
(67297, 6244, 17, 'Επιτυχής λήψη αποτελεσμάτων από το Δίκτυο Ανταλλαγής Εργαστηρίου'),
(67298, 6246, 17, 'Επιτυχής προσθήκη κατηγορίας'),
(67299, 6247, 17, 'προσετέθη επιτυχώς στην κατηγορία,'),
(67300, 6248, 17, 'Διαγράφηκε επιτυχώς'),
(67301, 6250, 17, 'Η βάση δεδομένων εγκαταστάθηκε με επιτυχία.'),
(67302, 6251, 17, 'Εγκαταστάθηκε επιτυχώς η παρακάτω βάση δεδομένων:'),
(67303, 6252, 17, 'Τροποποιήθηκε επιτυχώς'),
(67304, 6253, 17, 'Σώθηκε επιτυχώς. Θέλετε να κατανεμηθεί;'),
(67305, 6254, 17, 'Σώθηκε επιτυχώς. Θέλετε να διανεμηθεί;'),
(67306, 6256, 17, 'αποθηκεύτηκε επιτυχώς'),
(67307, 6257, 17, 'Η βάση δεδομένων αναβαθμίστηκε με επιτυχία.'),
(67308, 6258, 17, 'Έγινε επιτυχής αναβάθμιση της παρακάτω βάσης δεδοιμένων:'),
(67309, 6259, 17, 'επιτυχώς.'),
(67310, 6260, 17, 'Αυτοκτονία'),
(67311, 6261, 17, 'Περίληψη'),
(67312, 6262, 17, 'Περίληψη του'),
(67313, 6265, 17, 'Κυρ.'),
(67314, 6267, 17, 'Κυριακή'),
(67315, 6268, 17, 'Υπερχρέωση'),
(67316, 6269, 17, 'Κώδικες υπερχρέωσης'),
(67317, 6270, 17, 'Διαχείριση κωδίκων υπερχρέωσης'),
(67318, 6271, 17, 'Αναφορά υπερχρέωσης'),
(67319, 6272, 17, 'Υπερχρέωση/Φύλλο αμοιβών'),
(67320, 6273, 17, 'Υπερχρεώσεις'),
(67321, 6274, 17, 'Οι υπερχρεώσεις, μερικές φορές αναφέρονται ως Εντυπα Επίσκεψης, αποτελούν ουσιαστικό μέρος των περισσότερων ιατρείων.'),
(67322, 6275, 17, 'Υπερχρήστης'),
(67323, 6276, 17, 'Επιβλέπων'),
(67324, 6278, 17, 'Επιβλέπων Ιατρός DEA'),
(67325, 6279, 17, 'Μικρό όνομα Επιβλέποντος Ιατρού'),
(67326, 6280, 17, 'Επίθετο Επιβλέποντος Ιατρού'),
(67327, 6281, 17, 'NPI του Επιβλέποντος Ιατρού'),
(67328, 6282, 17, 'UPIN του Επιβλέποντος Ιατρού'),
(67329, 6283, 17, 'Στοιχεία Έδρας προμηθευτή'),
(67330, 6284, 17, 'Υποστήριξη συμβάντων ημερολογίου που ισχύουν για πολλαπλούς παρόχους'),
(67331, 6285, 17, 'Υποστήριξη εισαγ./ εξαγ. δεδομένων ρύθμισης, μέσω της σελίδας Backup'),
(67332, 6286, 17, 'Υποστήρ. Συμβάντων για πολλαπλούς παρόχους (multi-Provider)'),
(67333, 6288, 17, 'Υποστηρίζει μόνο κρυπτογράφηση/αποκρυπτογράφηση TripleDES.'),
(67334, 6289, 17, 'Τύπος επιφανείας'),
(67335, 6290, 17, 'Χειρουργεία'),
(67336, 6291, 17, 'Εγχείριση'),
(67337, 6293, 17, 'Ανεστάλη'),
(67338, 6294, 17, 'εναιώρημα (susp)'),
(67339, 6295, 17, 'Ημερομ. παροχής υπηρ.'),
(67340, 6296, 17, 'Ημερομ. παροχής υπηρ.:'),
(67341, 6299, 17, 'Εφίδρωση:'),
(67342, 6300, 17, 'Σουηδικά'),
(67343, 6301, 17, 'Διόγκωση'),
(67344, 6302, 17, 'Διόγκωση δεξιά'),
(67345, 6303, 17, 'Διογκωμένες αρθρώσεις'),
(67346, 6304, 17, 'Διογκωμένοι λεμφαδένες'),
(67347, 6305, 17, 'Σύμβολο που χρησιμοποιείται ως δεκαδικό σημείο για το νόμισμα. Δεν χρησιμοποιείται αν τα δεκαδικά ψηφία είναι 0.'),
(67348, 6306, 17, 'Το σύμβολο σε χρήση για διαχωρισμό των χιλιάδων, στα νομίσματα.'),
(67349, 6307, 17, 'Συμπτώματα'),
(67350, 6308, 17, 'Συγχρονισμός'),
(67351, 6309, 17, 'Συγχρονισμός μεταφράσεων με τον πίνακα της custom γλώσσας.'),
(67352, 6310, 17, 'Συγχρονισμένη νέα custom Σταθερά:'),
(67353, 6311, 17, 'Συγχρονισμένη νέα custom Γλώσσα:'),
(67354, 6312, 17, 'Συγχρονισμένη νέος ορισμός (Γλώσσα, Σταθερά, Ορισμός):'),
(67355, 6313, 17, 'Συγκοπή'),
(67356, 6314, 17, 'Επιτήρηση συνδρόμων'),
(67357, 6315, 17, 'Επιτήρηση συνδρόμων - Μη αναφερθείσες Περιπτώσεις'),
(67358, 6316, 17, 'Αναφορά Επιτήρησης συνδρόμων'),
(67359, 6317, 17, 'Υμενίτις, Impingement, Θυλακίτις'),
(67360, 6318, 17, 'Σύστημα'),
(67361, 6322, 17, 'Τ'),
(67362, 6323, 17, '3 φορές την ημέρα'),
(67363, 6324, 17, 'T.V.'),
(67364, 6325, 17, 'Πίνακας'),
(67365, 6327, 17, 'Απέτυχε η δημιουργία πίνακα'),
(67366, 6328, 17, 'Απέτυχε η ενημέρωση πίνακα'),
(67367, 6330, 17, 'δισκίο (tab)'),
(67368, 6335, 17, 'Δόση'),
(67369, 6336, 17, 'Επιλογή Ασφαλιστικής, από Drop Down'),
(67370, 6337, 17, 'Επιλογή πληρωμής από, από Drop Down'),
(67371, 6338, 17, 'Επιστροφή'),
(67372, 6339, 17, 'Απαιτεί χρόνο'),
(67373, 6347, 17, 'Ημερομηνία στόχος'),
(67374, 6351, 17, 'Ομάδες στόχος/ενέργειας'),
(67375, 6354, 17, 'Κωδικός εφορίας'),
(67376, 6355, 17, 'Φορολογικός συντελεστής'),
(67377, 6356, 17, 'Φόροι'),
(67378, 6357, 17, 'Ταξινόμηση'),
(67379, 6358, 17, 'Μέγιστη δόση'),
(67380, 6359, 17, 'Περίληψη ομάδας κακώσεων'),
(67381, 6360, 17, 'Μητρώο Ομάδας'),
(67382, 6361, 17, 'Προβολή Μητρώου Ομάδας'),
(67383, 6362, 17, 'Ομάδα'),
(67384, 6363, 17, 'Τηλ'),
(67385, 6364, 17, 'Τηλεφωνικός Κωδικός Χώρας'),
(67386, 6366, 17, 'Θερμομέτρηση'),
(67387, 6367, 17, 'Θέση θερμομέτρησης'),
(67388, 6368, 17, 'Μέθοδος θερμομέτρησης'),
(67389, 6369, 17, 'Θερμοκρασία'),
(67390, 6370, 17, 'Template'),
(67391, 6371, 17, 'Όνομα Template'),
(67392, 6372, 17, 'Τα ονόματα των Template δεν μπορούν να αρχίσουν με αριθμούς'),
(67393, 6373, 17, 'Template:'),
(67394, 6374, 17, 'Templates'),
(67395, 6375, 17, 'Κροταφική αρτ'),
(67396, 6376, 17, 'Κάκωση τένοντα'),
(67397, 6377, 17, 'Τενοντίτιδα/θυλακίτιδα'),
(67398, 6378, 17, 'Αριθμός αβέβαιου τιμολογίου'),
(67399, 6379, 17, 'Τριτεύουσα'),
(67400, 6380, 17, 'Τριτεύουσα Ασφάλιση'),
(67401, 6381, 17, 'Δεδομένα Τριτεύουσας Ασφάλισης'),
(67402, 6382, 17, 'Πάροχος Τριτεύουσας Ασφάλισης'),
(67403, 6383, 17, 'Έλεγχος χρονοδιαγράμματος'),
(67404, 6384, 17, 'Πειραματικό σύστημα'),
(67405, 6385, 17, 'Κείμενο'),
(67406, 6386, 17, 'Κείμενο διάγνωσης'),
(67407, 6387, 17, 'Πεδίο κειμένου'),
(67408, 6393, 17, 'κείμενο-ημερομηνία'),
(67409, 6394, 17, 'κείμενο-ημερομηνία'),
(67410, 6395, 17, 'χώρος κειμένου'),
(67411, 6396, 17, 'χώρος κειμένου'),
(67412, 6397, 17, 'πλαίσιο κειμένου'),
(67413, 6398, 17, 'πλαίσιο κειμένου'),
(67414, 6399, 17, 'Λίστα πλαισίων κειμένου'),
(67415, 6400, 17, 'λίστα πλαισίων κειμένου'),
(67416, 6401, 17, 'Ταϊλανδικά'),
(67417, 6402, 17, 'Σας ευχαριστούμε'),
(67418, 6403, 17, 'Σας ευχαριστούμε που επιλέξατε'),
(67419, 6404, 17, 'Το κουμπί "Καθαρισμός" θα αφαιρέσει όλες τις επισημάνσεις.'),
(67420, 6405, 17, 'Η παραπάνω δήλωση/ statement απέτυχε'),
(67421, 6406, 17, 'Το πιστοποιητικό για τον Apache SSL server και το Δημόσιο Κλειδί'),
(67422, 6407, 17, 'Το πιστοποιητικό της Αρχής Πιστοποίησης'),
(67423, 6408, 17, 'Αρχείο απαιτήσεων: '),
(67424, 6410, 17, 'Το αντίστοιχο ιδιωτικό κλειδί'),
(67425, 6413, 17, 'Ο κωδικός άρνησης είναι'),
(67426, 6414, 17, 'Ο ομαδικός κωδικός άρνησης είναι'),
(67427, 6415, 17, 'Το έντυπο προωρισμού έκλεισε'),
(67428, 6416, 17, 'Το έντυπο προορισμού έκλεισε, δεν μπορώ να ενεργήσω στην επιλογή σας.'),
(67429, 6418, 17, 'Ο επιλέξιμος Πάροχος, το επιλέξιμο νοσοκομείο ή το νοσοκομείο επείγουσας πρόσβασης που λαμβάνει έναν ασθενή από κάποια άλλη μονάδα περίθαλψης ή πάροχο περίθαλψης ή πιστεύει ότι μια επίσκεψη είναι σχετική θα πρέπει να συμβιβαστεί με τη φαρμακευτική αγωγή.'),
(67430, 6421, 17, 'Ο επιλέξιμος Πάροχος, το επιλέξιμο νοσοκομείο ή το νοσοκομείο επείγουσας πρόσβασης που μεταβιβάζει έναν ασθενή του σε κάποια άλλη μονάδα περίθαλψης ή πάροχο περίθαλψης ή παραπέμπει έναν ασθενή του σε άλλο πάροχο περίθαλψης θα πρέπει να παρέχει περίληψη των αναφορών περίθαλψης για κάθε μετάβαση ή παραπομπή.'),
(67431, 6422, 17, 'Τα συμβάντα έχουν εγκριθεί.'),
(67432, 6423, 17, 'Τα συμβάντα έχουν κρυφτεί.'),
(67433, 6424, 17, 'Τα δεδομένα που εξάγονται εμφανίζονται στην περιοχή κείμενου που ακολουθεί. Μπορείτε να αντιγράψετε και να επικολλήσετε αυτά σε ένα email ή σε οποιοδήποτε άλλο επιθυμητό προορισμό.'),
(67434, 6426, 17, 'Τα δεδομένα που εξάγονται εμφανίζονται στην περιοχή κείμενου που ακολουθεί. Μπορείτε να αντιγράψετε και να επικολλήσετε αυτά σε ένα email ή σε οποιοδήποτε άλλο επιθυμητό προορισμό.'),
(67435, 6427, 17, 'Τα εξαγόμενα δεδομένα εμφανίζονται στην περιοχή του κειμένου που ακολουθεί. Μπορείτε να αντιγράψετε και να επικολλήσετε αυτά σε ένα μήνυμα ηλεκτρονικού ταχυδρομείου ή σε οποιαδήποτε άλλο επιθυμητό προορισμό.'),
(67436, 6428, 17, 'Το αρχείο δεν μπορούσε να αποθηκευθεί στο CouchDB.'),
(67437, 6429, 17, 'Το αρχείο δεν μπόρεσε να μετονομαστεί με επιτυχία, αυτό το σφάλμα σχετίζεται συνήθως προβλήματα δικαιωμάτων στο σύστημα αποθήκευσης.'),
(67438, 6430, 17, 'Το αρχείο δεν αποθηκεύθηκε επιτυχώς. Αυτό το σφάλμα σχετίζεται συνήθως με προβλήματα δικαιωμάτων στο σύστημα αποθήκευσης.'),
(67439, 6433, 17, 'Το πρώτο βήμα είναι να ανοίξετε έναν λογαριασμό στον ιστότοπο του Unified Medical Language.'),
(67440, 6434, 17, 'Προσετέθη το ακόλουθο συμβάν ημερολογίου:'),
(67441, 6435, 17, 'Τροποποιήθηκε το ακόλουθο συμβάν ημερολογίου:'),
(67442, 6436, 17, 'Οι ακόλουθες κατηγορίες θα αφαιρεθούν από τη Λίστα κατηγοριών σας'),
(67443, 6437, 17, 'Η ακόλουθη έκδοση βάσης δεδομένων έχει εγκατασταθεί'),
(67444, 6439, 17, 'Το ακόλουθο αρχείο EDI ανέβηκε'),
(67445, 6440, 17, 'Eνεργοποιήθηκε η Επείγουσα Σύνδεση του εξής Χρήστη:'),
(67446, 6441, 17, 'Συνέβησαν τα ακόλουθα σφάλματα'),
(67447, 6444, 17, 'Τα ακόλουθα πεδία απαιτούνται'),
(67448, 6446, 17, 'Τα ακόλουθα πεδία πρέπει να συμπληρωθούν για να αποσταλεί το αίτημα.'),
(67449, 6450, 17, 'Το αρχικό παράθυρο είναι η σελίδα αναζήτησης του τιμολογίου. Στην κορυφή μπορείτε να δώσετε μια πηγή (π.χ. αριθμός ελέγχου), ημερομηνία πληρωμής και ποσό ελέγχου. Ο λόγος για την ημερομηνία πηγής και πληρωμής είναι αυτός, ώστε δεν χρειάζεται να τα εισάγετε ξανά και ξανά για κάθε αξίωση. Το ποσό που εισάγετε θα μειωθεί για κάθε τιμολόγιο που δίνεται μέρος της πληρωμής και ελπίζουμε ότι θα τελειώσει στο μηδέν όταν τελειώσετε.'),
(67450, 6451, 17, 'Πρέπει να δημιουργηθεί ο κατάλογος εγκατάστασης.'),
(67451, 6456, 17, 'Η ετικέτα που φαίνεται στο χρήστη πάνω στο έντυπο'),
(67452, 6457, 17, 'Το μήκος δεν θα πρέπει να υπερβαίνει τον ακόλουθο αριθμό χαρακτήρων'),
(67453, 6460, 17, 'Ο νέος κατάλογος θα είναι μια υπο-κατηγορία του/της '),
(67454, 6461, 17, 'Ο νέος κωδικός πρόσβασης δεν μπορεί να είναι ο ίδιος με τον τρέχοντα κωδικό πρόσβασης.'),
(67455, 6462, 17, 'Τα πεδία του νέου κωδικού πρόσβασης δεν είναι ίδια.'),
(67456, 6465, 17, 'Η σελίδα θα ανακατευθυνθεί στα Δημογραφικά. Μπορείτε να επεξεργαστείτε το πεδίο "Χώρα" και να προχωρήσετε στο NewCrop ξανά.'),
(67457, 6466, 17, 'Ο κωδικός πρόσβασης πρέπει να είναι τουλάχ. με 8 χαρακτήρες και θα πρέπει'),
(67458, 6468, 17, 'Η αίτηση αναφοράς ασθενούς έχει καταγραφεί.'),
(67459, 6469, 17, 'Οι υπενθυμίσεις προς ασθενή(-είς) έχουν σταλεί'),
(67460, 6470, 17, 'Οι υπενθυμίσεις προς ασθενή(-είς) έχουν ενημερωθεί'),
(67461, 6472, 17, 'Οι πληρωμές που απεστάλησαν δεν μπορούν να είναι κάτω από αυτήν την ημερομηνία. Αυτό εξασφαλίζει ότι μετά τη λήψη της τελικής αναφοράς, κανείς δεν αποστέλει για προηγούμενες ημερομηνίες.'),
(67462, 6475, 17, 'Οι υπόλοιπες πληροφορίες παρακάτω ισχύουν μόνο αν αποστέλλετε χειρωνακτικά, ή αν κάνετε διορθώσεις με το χέρι.'),
(67463, 6477, 17, 'Το ζητούμενο έγγραφο δεν είναι παρών στην αναμενόμενη θέση στο σύστημα αρχείων ή δεν υπάρχουν επαρκή δικαιώματα για πρόσβαση σε αυτό.'),
(67464, 6480, 17, 'Οι στήλες Πηγής και Ημερομηνίας αντιγράφονται από την πρώτη σελίδα, έτσι κανονικά δεν θα χρειαστεί να τις αγγίξετε. Μπορείτε να τοποθετήσετε ένα ποσό πληρωμής στη στήλη Πληρωμή, ένα ποσό προσαρμογής στην στήλη Ρύθμιση, ή και τα δύο. Μπορείτε επίσης να κάνετε κλικ στο "W" στα δεξιά για να υπολογιστεί αυτόματα μια τιμή προσαρμογής που γράφει το υπόλοιπο του τέλους για το στοιχείο γραμμής.'),
(67465, 6484, 17, 'Η υποδιαίρεση του χρόνου του ημερολογίου και το μικρότερο διάστημα σε λεπτά για μια υποδοχή ραντεβού.'),
(67466, 6485, 17, 'Η μεταφρασμένη ετικέτα που θα εμφανιστεί στο έντυπο στην τρέχουσα γλώσσα'),
(67467, 6486, 17, 'Ο μεταφρασμένος Τίτλος που θα εμφανιστεί στην τρέχουσα γλώσσα'),
(67468, 6487, 17, 'Η μετάφραση της περιγραφής στην τρέχουσα γλώσσα'),
(67469, 6488, 17, 'Οι πίνακες μετάφρασης είναι συγχρονισμένοι'),
(67470, 6489, 17, 'Το είδος αυτής της οντότητος'),
(67471, 6490, 17, 'Ο ειδικός κωδικός πωλητού, που ταυτοποιεί την διαδικασία ή το αποτέλεσμα'),
(67472, 6491, 17, 'Τα αρχεία X12 και οι σχετικές αναφορές εξόδου HTML αρχειοθετούνται στον υποκατάλογο "era" του κυρίου καταλόγου εγκατάστασης του LibreEHR. Θα θέλατε να αναφερθείτε σε αυτά τα αρχεία κάπου κάπου. Η διεύθυνση URL είναι'),
(67473, 6492, 17, 'Το αρχείο zip θα περιέχει τα ακόλουθα στοιχεία'),
(67474, 6493, 17, 'Θέμα'),
(67475, 6495, 17, 'Θεραπευτικές ενέσεις'),
(67476, 6496, 17, 'Υπάρχουν'),
(67477, 6497, 17, 'Δεν υπάρχουν συνταγές προς το παρόν'),
(67478, 6498, 17, 'Υπάρχουν σφάλματα με την υποβολή σας. Αυτά σκιαγραφούνται παρακάτω.'),
(67479, 6500, 17, 'Δεν υπάρχουν ελεγμένοι φάκελοι.'),
(67480, 6501, 17, 'Δεν υπάρχουν καταγεγραμμένες γνωστοποιήσεις για αυτόν τον ασθενή.'),
(67481, 6502, 17, 'Δεν υπάρχουν νέες Υποβολές'),
(67482, 6503, 17, 'Δεν υπάρχουν σημειώσεις στο φάκελο, γι'' αυτό τον ασθενή.'),
(67483, 6504, 17, 'Δεν υπάρχουν συναλλαγές στο αρχείο γι'' αυτό τον ασθενή.'),
(67484, 6505, 17, 'Υπήρξε σφάλμα ταχυδρομείου που έστελνε σε'),
(67485, 6506, 17, 'Υπάρχει ήδη μια κατηγορία με το όνομα'),
(67486, 6507, 17, 'Υπάρχει ήδη μια υποκατηγορία με το όνομα'),
(67487, 6508, 17, 'Υπάρχει ήδη ένα αντικείμενο με το όνομα'),
(67488, 6509, 17, 'Υπάρχει ήδη ένα ανοιχτό αίτημα ιστορικού του ασθενούς.'),
(67489, 6510, 17, 'Δεν υπάρχει εγγραφή στο διάγραμμα λογαριασμού χρέωσης '),
(67490, 6511, 17, 'Δεν υπάρχει εγγραφή στο διάγραμμα τρέχοντος λογαριασμού '),
(67491, 6512, 17, 'Δεν υπάρχει εγγραφή στο διάγραμμα λογαριασμού εσόδων '),
(67492, 6513, 17, 'Δεν υπάρχει τρέχων ασθενής'),
(67493, 6515, 17, 'Δεν υπάρχει ταίριασμα για το αναγνωριστικό τιμολογίου'),
(67494, 6516, 17, 'Δεν υπάρχει ταίριασμα για το αναγνωριστικό τιμολογίου = '),
(67495, 6517, 17, 'Δεν υπάρχει εγγραφή τμήματος για το αναγνωριστικό υπηρεσιών '),
(67496, 6520, 17, 'Υπήρξε ένα σφάλμα κατά την επεξεργασία του αιτήματός σας'),
(67497, 6522, 17, 'Αυτοί είναι οι σύνδεσμοι του 2012'),
(67498, 6523, 17, 'Πυκνό δεξιά:'),
(67499, 6524, 17, 'Μηρός'),
(67500, 6525, 17, 'Μηρός + ιγνυακός τένοντας'),
(67501, 6527, 17, 'Πράγματα που το οπίσθιο γραφείο μπορεί να διαβάσει και να εισάγει αλλά όχι να τροποποιήσει'),
(67502, 6528, 17, 'Πράγματα που το οπίσθιο γραφείο μπορεί να διαβάσει και να τροποποιήσει'),
(67503, 6531, 17, 'Πράγματα που οι κλινικοί μπορούν να διαβάσουν και να εισάγουν αλλά όχι να τροποποιήσουν'),
(67504, 6532, 17, 'Πράγματα που οι κλινικοί μπορούν να διαβάσουν και να τροποποιήσουν'),
(67505, 6535, 17, 'Πράγματα που το πρόσθιο γραφείο μπορεί να διαβάσει και να εισάγει αλλά όχι να τροποποιήσει'),
(67506, 6536, 17, 'Πράγματα που το πρόσθιο μπορεί να διαβάσει και να τροποποιήσει'),
(67507, 6539, 17, 'Πράγματα που οι ιατροί μπορούν να διαβάσουν και να εισάγουν αλλά όχι να τροποποιήσουν'),
(67508, 6540, 17, 'Πράγματα που οι ιατροί μπορούν να διαβάσουν και να τροποποιήσουν'),
(67509, 6542, 17, 'Τρίτο'),
(67510, 6544, 17, 'Αυτή η ενέργεια ΔΕΝ ΜΠΟΡΕΙ να αναιρεθεί.'),
(67511, 6545, 17, 'Αυτή η ενέργεια δεν μπορεί να αναιρεθεί.'),
(67512, 6547, 17, 'Η ενέργεια αυτή θα καταγραφεί'),
(67513, 6549, 17, 'Αυτό το ωράριο ραντεβού χρησιμοποιείτασι ήδη. Να το χρησιμοποιήσετε έτσι κι αλλιώς;'),
(67514, 6550, 17, 'Αυτό το ωράριο ραντεβού είναι κατηλειμμένο. Παρακαλώ επιλέξτε κάποιο άλλλο.'),
(67515, 6551, 17, 'Αυτό το ημερολογιακό έτος'),
(67516, 6554, 17, 'Αυτή η Απαίτηση έχει αρνηθεί. Αιτία: -'),
(67517, 6555, 17, 'Η απαίτηση έχει διαβιβαστεί στο επόμενο επίπεδο.'),
(67518, 6556, 17, 'Αυτό ο τύπος κωδικού δεν αποδέχεται σχέσεις.'),
(67519, 6558, 17, 'Αυτό καθορίζει το πως εμφανίζονται τα ραντεβού στο ημερολόγιο.'),
(67520, 6559, 17, 'Αυτό καθορίζει ποιο schema χρωμάτων χρησιμοποιείται για το ραντεβού'),
(67521, 6561, 17, 'Αυτή η Επίσκεψη'),
(67522, 6562, 17, 'Αυτή η Επίσκεψη τιμολογήθηκε. Αν πρέπει να την αλλάξετε, τότε θα πρέπει να ξανανοιχθεί.'),
(67523, 6565, 17, 'Αυτή η δυνατότητα είναι σε πειραματικό στάδιο και δεν έχει ελεγχθεί πλήρως. Χρησιμοποιήστε τη με δική σας ευθύνη!'),
(67524, 6566, 17, 'Αυτός ο αριθμός τιμολογίου έχει αλλάξει σε '),
(67525, 6575, 17, 'Η ενότητα αυτή είναι σε φάση δοκιμής. Η βάση δεδομένων δεν θα αλλάξει.'),
(67526, 6576, 17, 'Η ενότητα αυτή προωθεί την αποτελεσματική είσοδο των δεδομένων Εξήγησης του Κέρδους'),
(67527, 6577, 17, 'Αυτός ο Μήνας μέχρι Σήμερα'),
(67528, 6581, 17, 'Αυτή η σελίδα θα περιλαμβάνει ενσωματωμένη τη σελίδα σύνδεσης, έτσι ώστε να μην χρειάζεται να κάνετε κλικ στην επανασύνδεση κάθε φορά.'),
(67529, 6582, 17, 'Αυτός ο ασθενής δεν έχει δραστηριότητες.'),
(67530, 6583, 17, 'Αυτό το αναγνωριστικό ασθενούς χρησιμοποιείται ήδη!'),
(67531, 6584, 17, 'Αυτό το προϊόν επιτρέπει μόνο μία παρτίδα ανά αποθήκη.'),
(67532, 6591, 17, 'Αυτή η ενέργεια θα δημιουργήσει ένα αρχείο που θα πρέπει να αποθηκεύσετε για μελλοντική χρήση. Tο αρχείο δε μπορεί να ξαναδημιουργηθεί. Θέλετε να προχωρήσετε;'),
(67533, 6592, 17, 'Αυτός ο χρήστης δεν είναι μέλος κάποιας ομάδας'),
(67534, 6595, 17, 'Αυτή η Επίσκεψη ξεκινά νέα χρήση αντισυλληπτικών'),
(67535, 6596, 17, 'Αυτή η επίσκεψη θα χρειαστεί ένα έντυπο GCAC, μια παραπομπή ή μια υπηρεσιακή διαδικασία.'),
(67536, 6597, 17, 'Αυτό ήταν το παλαιό μονάχα μετρικό έντυπο Ζωτικών, που έχει τώρα αποσυρθεί.'),
(67537, 6598, 17, 'Αυτή η Εβδομάδα μέχρι Σήμερα'),
(67538, 6600, 17, 'Αυτό θα ενεργοποιήσει την εγγραφή του CCR (Αναφορά Συνέχισης της Φροντίδας) και του CCD (Εγγραφο Συνέχισης της Φροντίδας).'),
(67539, 6602, 17, 'Αυτό θα επιτρέψει την επιλογή της αποσφαλμάτωσης ( ''εικονική '') γλώσσα.'),
(67540, 6606, 17, 'Αυτό θα δημιουργήσει ένα backup αρχείο σε tar format και θα το στείλει στον Web browser σας ώστε να μπορείτε να το αποθηκεύσετε.'),
(67541, 6607, 17, 'Αυτό θα απενεργοποιήσει την κρυπτογράφηση του εγγράφου και τις δυνατότητες αποκρυπτογράφησης και θα τις κρύψει στο UI.'),
(67542, 6613, 17, 'Αυτό θα αναγκάσει το Widget χρέωσης στην οθόνη Περίληψης του Ασθενή να είναι πάντα ανοιχτό.'),
(67543, 6617, 17, 'Αυτό δε θα σας αποτρέψει από το να πάτε στη σελίδα της ηλεκτρονικής συνταγογράφησης.'),
(67544, 6619, 17, 'Αυτό θα χρησιμοποιήσει την προσαρμοσμένη λίστα εμβολιασμών και όχι τον τυποποιημένο κατάλογο εμβολίων CVX.'),
(67545, 6622, 17, 'Θωρακική μοίρα της ΣΣ'),
(67546, 6623, 17, 'χιλ/κυβ.χιλ.'),
(67547, 6625, 17, 'Λάρυγγας'),
(67548, 6626, 17, 'Καρκίνος του λάρυγγα'),
(67549, 6627, 17, 'Εγχείριση καρκίνου του λάρυγγα'),
(67550, 6628, 17, 'Θρόμβωση/ΑΕΕ'),
(67551, 6629, 17, 'Πεμ'),
(67552, 6630, 17, 'Πέμπτη'),
(67553, 6631, 17, 'Πέμπτη'),
(67554, 6632, 17, 'Θυρεοειδής φυσιολογικός'),
(67555, 6633, 17, 'Προβλήμ. θυροειδη'),
(67556, 6634, 17, 'Παροδικό ισχαιμικό εγκεφαλικό επεισόδιο'),
(67557, 6636, 17, '1x3'),
(67558, 6638, 17, 'Χρόνος'),
(67559, 6639, 17, 'Μορφή εμφάνισης ημερομηνίας'),
(67560, 6640, 17, 'Προσαύξηση ώρας για Προσθήκη (λεπτά 1-60)'),
(67561, 6641, 17, 'Επιλογή ώρας'),
(67562, 6647, 17, 'Χρονικό σύμβαμα'),
(67563, 6648, 17, 'Συστοιχία χρόνων'),
(67564, 6649, 17, 'Χρονοθέτηση και Κείμενο'),
(67565, 6650, 17, 'ΑΦΜ'),
(67566, 6651, 17, 'Εμβοες'),
(67567, 6652, 17, 'Τίτλος'),
(67568, 6653, 17, 'Τίτλος V'),
(67569, 6654, 17, 'Οι στήλες του τίτλου πρέπει να είναι αριθμός μεταξύ 1 και 999'),
(67570, 6655, 17, 'Τίτλοι'),
(67571, 6657, 17, 'Τυμπανική μεμβράνη/Έξω ακουστικοί πόροι/έξω ους, έξω ρις'),
(67572, 6658, 17, 'Προς/Μέχρι'),
(67573, 6659, 17, 'Προς/Μέχρι'),
(67574, 6660, 17, 'Προς/Μέχρι'),
(67575, 6661, 17, 'στην απόλυτη διαδρομή του αρχείου'),
(67576, 6662, 17, 'Για προσθήκη σημειώσεων, παρακαλώ κάντε κλικ '),
(67577, 6663, 17, 'Για προσθήκη σημειώσεων, παρακαλώ κάντε κλικ εδώ'),
(67578, 6664, 17, 'Στην προσβεβλημένη περιοχή'),
(67579, 6665, 17, 'στην προσβεβλημένη περιοχή'),
(67580, 6666, 17, 'Για να ανοιχθεί αυτόματα το καθορισμένο έντυπο. Μερικές αθλητικές ομάδες χρησιμοποιούν το football_injury_audit εδώ.'),
(67581, 6667, 17, 'Στην προβολή Χρέωσης'),
(67582, 6668, 17, 'Στην κατηγορία'),
(67583, 6669, 17, 'Στην Κλινική προβολή'),
(67584, 6670, 17, 'Στη Συμμετοχή'),
(67585, 6673, 17, 'Στα Δημογρ'),
(67586, 6674, 17, 'Για Απενεργοποίηση του πιστοποιητικού από πλευράς του πελάτη, αφαιρέστε τις παραπάνω γραμμές από το αρχείο διαμόρφωσης του Apache και ρυθμίστε'),
(67587, 6675, 17, 'Για απενεργοποίηση του HTTPS, κάντε σχόλια τις παραπάνω γραμμές στο αρχείο ρυθμίσεων του Apache και κάντε επανεκκίνηση του Apache server.'),
(67588, 6676, 17, 'Για την ενεργοποίηση των πιστοποιητικών Client side SSL'),
(67589, 6677, 17, 'Για να ενεργοποιήσετε SSL πιστοποιητικά γνησιότητας από την πλευρά του πελάτη, το HTTPS θα πρέπει να είναι ενεργοποιημένο.'),
(67590, 6678, 17, 'Για Ενεργοποίηση μόνο HTTPS, εκτελέστε τις παραπάνω αλλαγές και κάντε επανεκκίνηση του Apache server. Εάν θέλετε να ρυθμίσετε των πιστοποιητικών από την πλευρά του πελάτη επίσης, παρακαλώ να τα ρυθμίσετε στην επόμενη ενότητα.'),
(67591, 6679, 17, 'Στην Επισκ.'),
(67592, 6680, 17, 'Για φιλτράρισμα κατά φύλο'),
(67593, 6681, 17, 'Στο Ιστορικό'),
(67594, 6682, 17, 'Στις Συνοδές Νόσους/Παθήσεις'),
(67595, 6683, 17, 'Για να συνδέσετε αυτήν την επίσκεψη/συμβουλή σε ένα υπάρχον θέμα, κάντε κλικ στο '),
(67596, 6684, 17, 'Για να συνδέσετε αυτήν την επίσκεψη/εκτίμηση με ένα υπάρχον πρόβλημα, κάντε κλικ στο θέμα που θέλετε παραπάνω για να το επιλέξετε και στη συνέχεια κάντε κλικ στο [Αποθήκευση]. Κρατήστε πατημένο το [Ctrl] για να επιλέξετε πολλά προβλήματα.'),
(67597, 6685, 17, 'για να συνδεθείτε ξανά');
INSERT INTO `lang_definitions` VALUES
(67598, 6686, 17, 'Για να καταγράψετε γνωστοποιήσεις, κάντε κλικ'),
(67599, 6687, 17, 'να τρέξει'),
(67600, 6688, 17, 'Για να ρυθμίσετε την πρόσβαση https με τον έλεγχο ταυτότητας πιστοποιητικού πελάτη, κάντε τα εξής:'),
(67601, 6689, 17, 'Στο δέρμα'),
(67602, 6690, 17, 'στο δέρμα'),
(67603, 6691, 17, 'Για αυτήν την επίσκεψη;'),
(67604, 6693, 17, 'Προς:'),
(67605, 6694, 17, 'Προς: '),
(67606, 6695, 17, 'TO_CITY'),
(67607, 6696, 17, 'TO_FAX'),
(67608, 6697, 17, 'TO_FNAME'),
(67609, 6698, 17, 'TO_LNAME'),
(67610, 6699, 17, 'TO_MNAME'),
(67611, 6700, 17, 'TO_ORGANIZATION'),
(67612, 6703, 17, 'TO_POSTAL'),
(67613, 6704, 17, 'TO_STATE'),
(67614, 6705, 17, 'TO_STREET'),
(67615, 6706, 17, 'TO_TITLE'),
(67616, 6707, 17, 'TO_VALEDICTORY'),
(67617, 6708, 17, 'Κάπνισμα'),
(67618, 6709, 17, 'Παρέμβαση διακοπής καπνίσματος'),
(67619, 6710, 17, 'Παρέμβαση διακοπής καπνίσματος'),
(67620, 6712, 17, 'Χρήση καπνού'),
(67621, 6713, 17, 'Εκτίμηση της χρήσης καπνού'),
(67622, 6714, 17, 'Εκτίμηση της χρήσης καπνού'),
(67623, 6715, 17, 'Σήμερα'),
(67624, 6716, 17, 'ΣΗΜΕΡΑ'),
(67625, 6717, 17, 'σήμερα'),
(67626, 6719, 17, 'Σημερινές χρεώσεις'),
(67627, 6720, 17, 'Σημερινή ήμερα'),
(67628, 6721, 17, 'Τα σημερινά συμβάντα'),
(67629, 6726, 17, 'Αμυγδαλεκτομή'),
(67630, 6728, 17, 'Πάνω'),
(67631, 6730, 17, 'Θέμα'),
(67632, 6731, 17, 'Σύνολο'),
(67633, 6732, 17, 'σύνολο'),
(67634, 6733, 17, 'Συνολικές ενεργές δράσεις'),
(67635, 6734, 17, 'Συνολικές ενεργές υπενθυμίσεις μετά την ενημέρωση'),
(67636, 6735, 17, 'Συνολικές ενεργές υπενθυμίσεις πριν από την ενημέρωση'),
(67637, 6737, 17, 'Συνολικός οφειλόμενο ποσό'),
(67638, 6738, 17, 'Συνολικό πληρωτέο ποσό'),
(67639, 6740, 17, 'Σύνολο χρέωσης'),
(67640, 6741, 17, 'Σύνολο Χρεώσεων'),
(67641, 6742, 17, 'Σύνολο Πελατών'),
(67642, 6743, 17, 'Σύνολο Κόστους'),
(67643, 6745, 17, 'συνολικές καταχωρήσεις'),
(67644, 6746, 17, 'Συνολικές αποτυχημένες υπενθυμίσεις που εστάλησαν μέσω e-mail'),
(67645, 6747, 17, 'Συνολικές αποτυχημένες υπενθυμίσεις που εστάλησαν μέσω τηλεφώνου'),
(67646, 6748, 17, 'Σύνολο για'),
(67647, 6749, 17, 'Σύνολο για '),
(67648, 6750, 17, 'Σύνολο για την κατηγορία'),
(67649, 6751, 17, 'Συνολικές απενεργοποιημένες ρυθμίσεις'),
(67650, 6752, 17, 'Συνολικές νέες υπενθυμίσεις'),
(67651, 6755, 17, 'Συνολικός αριθμός Ανοσοποιήσεων'),
(67652, 6756, 17, 'Συνολ. αριθμός Ιατρικών προβλημάτων'),
(67653, 6758, 17, 'Συνολ. αριθμός ασθενών'),
(67654, 6760, 17, 'Συνολ. Υπόλοιπο ασθενών'),
(67655, 6761, 17, 'Συνολικοί ασθενείς'),
(67656, 6764, 17, 'Συνολ. εγγραφές που βρέθηκαν'),
(67657, 6765, 17, 'Συνολ. σεξουαλική και αναπαραγ. υγεία και Οικογεν. προγραμματισμός'),
(67658, 6766, 17, 'Συνολ. επιτυχημένες υπενθυμίσεις που εστάλησαν μέσω e-mail'),
(67659, 6767, 17, 'Συνολ. επιτυχημένες υπενθυμίσεις που εστάλησαν μέσω τηλεφώνου'),
(67660, 6770, 17, 'Συνολ. αμετάβλητες υπενθυμίσεις'),
(67661, 6771, 17, 'Συνολ. υπενθυμίσεις που δεν έχουν σταλεί μετά από τη διαδικασία αποστολής'),
(67662, 6772, 17, 'Συνολ. υπενθυμίσεις που δεν έχουν σταλεί μετά από την ενημέρωση'),
(67663, 6773, 17, 'Συνολ. υπενθυμίσεις που δεν έχουν σταλεί πριν από τη διαδικασία αποστολής'),
(67664, 6774, 17, 'Συνολ. υπενθυμίσεις που δεν έχουν σταλεί πριν από την ενημέρωση'),
(67665, 6775, 17, 'Συνολ. ενημερωμένες υπενθυμίσεις'),
(67666, 6776, 17, 'Σύνολα'),
(67667, 6777, 17, 'Σύνολα για'),
(67668, 6778, 17, 'Σύνολα για '),
(67669, 6785, 17, 'Τύπος κατάρτισης'),
(67670, 6786, 17, 'Συναλλαγές'),
(67671, 6787, 17, 'Συναλλαγή'),
(67672, 6788, 17, 'συναλλαγή'),
(67673, 6789, 17, 'Η συναλλαγή απέτυχε, ανεπαρκής ποσότητα στον προορισμό παρτίδας'),
(67674, 6790, 17, 'Η συναλλαγή απέτυχε, η ποσότητα είναι μικρότερη του μηδενός'),
(67675, 6791, 17, 'Είδος συναλλαγής'),
(67676, 6792, 17, 'συναλλαγές'),
(67677, 6793, 17, 'Συναλλαγές'),
(67678, 6794, 17, 'Συναλλαγές (εγγραφή προαιρετικά)'),
(67679, 6795, 17, 'Συναλλαγές/Παραπομπές'),
(67680, 6797, 17, 'Μεταφορά'),
(67681, 6799, 17, 'Η μεταφορά απέτυχε, ανεπαρκής ποσότητα στην πηγή παρτίδας'),
(67682, 6804, 17, 'Μεταφορές'),
(67683, 6806, 17, 'Μεταφορά Φροντίδας;'),
(67684, 6807, 17, 'Μετάφραση Ομάδων Ελέγχου Πρόσβασης'),
(67685, 6808, 17, 'Ματάφραση Κατηγοριών Ραντεβού'),
(67686, 6809, 17, 'Μετάφραση Κατηγοριών Εγγράφου'),
(67687, 6810, 17, 'Μετάφραση Σχεδίου'),
(67688, 6811, 17, 'Μετάφραση Καταλόγων'),
(67689, 6812, 17, 'Μεταφράση Τίτλων της Σημείωσης ασθενούς'),
(67690, 6813, 17, 'Μεταφράστε αυτό'),
(67691, 6814, 17, 'Μετάφραση'),
(67692, 6815, 17, 'Μεταφράσεις'),
(67693, 6819, 17, 'Τραύμα'),
(67694, 6820, 17, 'Θεραπεία'),
(67695, 6822, 17, 'Στόχοι θεραπείας'),
(67696, 6823, 17, 'Σχέδιο θεραπείας'),
(67697, 6826, 17, 'Θεραπεία:'),
(67698, 6827, 17, 'Θεραπεία: '),
(67699, 6828, 17, 'Τάση'),
(67700, 6830, 17, 'Σημείο ερεθισμού / σύνδρομο διαμερίσματος / καθυστερημένος μυϊκός πόνος / κράμπα'),
(67701, 6831, 17, 'Τρισφύριος'),
(67702, 6832, 17, 'Κορμός και κοιλιά'),
(67703, 6837, 17, 'κουταλάκι (5ml)'),
(67704, 6839, 17, 'Διαδερμικό θεραπευτικό σύστημα'),
(67705, 6840, 17, 'Φυματίωση'),
(67706, 6841, 17, 'Τρί'),
(67707, 6842, 17, 'Τρίτη & Πέμπτη'),
(67708, 6843, 17, 'Τρίτη'),
(67709, 6844, 17, 'Όγκος'),
(67710, 6845, 17, 'Τουρκικά'),
(67711, 6848, 17, 'δύο φορές ημερησίως'),
(67712, 6850, 17, 'Τυμπανική μεμβράνη'),
(67713, 6851, 17, 'Τύπος'),
(67714, 6852, 17, 'Τύπος Ταυτότητας ή ονόματος. Τρεις χαρακτήρες το ελάχιστο (συμπεριλαμβανομένων των κενών).'),
(67715, 6853, 17, 'Τύπος των εμφανισθέντων στηλών για τα αποτελέσματα της αναζήτησης ασθενών'),
(67716, 6854, 17, 'Τύπος Γνωστοποίησης'),
(67717, 6855, 17, 'Τύπος συμβάντων'),
(67718, 6856, 17, 'Τύπο εμφάνισης της οθόνης'),
(67719, 6857, 17, 'Πληκτρολογήστε ή σαρώστε το αναγνωριστικό του ασθενούς εδώ'),
(67720, 6858, 17, 'Πληκτρολογήστε το μήνυμά σας εδώ'),
(67721, 6859, 17, 'Τύποι Παραγγελιών και Αποτελεσμάτων'),
(67722, 6864, 17, 'Οι κωδικοί UCSMC παρέχονται από το Πανεπιστ. Κέντρο Αθλητιατρικής του Calgary'),
(67723, 6865, 17, 'Ουκρανικά'),
(67724, 6866, 17, 'Εξελκώσεις'),
(67725, 6867, 17, 'Ελκώδης κολίτιδα'),
(67726, 6868, 17, 'Έλκη'),
(67727, 6871, 17, 'Αδυναμία δημιουργίας'),
(67728, 6876, 17, 'Εφαρμοσμένο'),
(67729, 6877, 17, 'Ακαταχώρητο'),
(67730, 6878, 17, 'Μη εγκεκριμμένο'),
(67731, 6879, 17, 'Μη εξουσιοδοτημένη πρόσβαση στην ηλεκτρονική συνταγογράφηση'),
(67732, 6880, 17, 'Αναρμόδια πρόσβαση.'),
(67733, 6882, 17, 'Μόνο Αχρέωτα'),
(67734, 6884, 17, 'Κάτωθεν της γλώσσας'),
(67735, 6885, 17, 'Ελλιποβαρής'),
(67736, 6886, 17, 'Αδιάγνωστο'),
(67737, 6887, 17, 'ΑΔΙΑΝΕΜΗΤΟ'),
(67738, 6888, 17, 'Αδιανέμητο'),
(67739, 6889, 17, 'Αδιανέμητο είναι'),
(67740, 6890, 17, 'Αναίρεση αποχώρησης'),
(67741, 6892, 17, 'Μοναδικοί Πελάτες'),
(67742, 6893, 17, 'Μοναδικός, αναγνώσιμος από άνθρωπο, ταυτοποιητής γι'' αυτό τον τύπο'),
(67743, 6894, 17, 'Μοναδικοί Νέοι Πελάτες'),
(67744, 6895, 17, 'Μοναδικόςαριθμητικός ταυτοποιητής γι'' αυτό τον τύπο'),
(67745, 6896, 17, 'Μοναδικοί εξετασθέντες Ασθενείς'),
(67746, 6897, 17, 'Αναφορά μοναδικών εξετασθέντων Ασθενών'),
(67747, 6898, 17, 'Απαξ εξετασθέντες'),
(67748, 6899, 17, 'Μονάδα'),
(67749, 6900, 17, 'Μονάδες'),
(67750, 6901, 17, 'μονάδες (units)'),
(67751, 6903, 17, 'Μονάδες για Εντυπα Επισκέψεων'),
(67752, 6904, 17, 'Οι μονάδες πρέπει να είναι ένας αριθμός'),
(67753, 6905, 17, 'Οι μονάδες δεν είναι ορισμένες'),
(67754, 6906, 17, 'Μονάδες/L'),
(67755, 6907, 17, 'Άγνωστο'),
(67756, 6910, 17, 'Άγνωστο αν έχει καπνίσει ποτέ'),
(67757, 6911, 17, 'Άγνωστο ή μη διαθέσιμο'),
(67758, 6913, 17, 'Αποσύνδεσε ασθενή'),
(67759, 6914, 17, 'Μη κατονομασθείσα ασφαλιστική εταιρεία'),
(67760, 6915, 17, 'Μη καταχωρηθέν'),
(67761, 6918, 17, 'Αποεπιλογη Όλων'),
(67762, 6919, 17, 'Μη επιλεγμένο'),
(67763, 6920, 17, 'Απροσδιόριστο'),
(67764, 6921, 17, 'αδόμητο'),
(67765, 6924, 17, 'μέχρι'),
(67766, 6925, 17, 'Άκαιρη πλήρωση'),
(67767, 6926, 17, 'Αχρησιμοποίητο'),
(67768, 6927, 17, 'Μονάδες ανάλυσης'),
(67769, 6928, 17, 'Μέχρι'),
(67770, 6929, 17, 'Προσεχή ραντεβού'),
(67771, 6930, 17, 'Προσεχή συμβάντα'),
(67772, 6931, 17, 'Ενημέρωση'),
(67773, 6932, 17, 'ενημέρωση'),
(67774, 6933, 17, 'Ενημέρωση Ενεργός'),
(67775, 6934, 17, 'Ενημέρωση αρχείων'),
(67776, 6935, 17, 'Ενημέρωση Πληροφοριών'),
(67777, 6936, 17, 'Ενημέρωση καταλόγου'),
(67778, 6937, 17, 'Ενημέρωση του Αριθμού Παρόχου'),
(67779, 6938, 17, 'Ενημέρωση Επιλεγμένων Αντικειμένων'),
(67780, 6939, 17, 'Ενημέρωση των ακόλουθων μεταβλητών στο αρχείο'),
(67781, 6940, 17, 'Ενημέρωση Πληροφοριών Χρήστη'),
(67782, 6942, 17, 'Η ενημέρωση των δημογραφικών δεν επιτρέπεται.'),
(67783, 6943, 17, 'Γίνεται αναβάθμιση των συνολικών ρυθμίσεων για τις προεπιλογές'),
(67784, 6945, 17, 'ΑΝΑΒΑΘΜΙΣΗ'),
(67785, 6946, 17, 'Αναβάθμιση'),
(67786, 6947, 17, 'Αναβάθμιση βάσης δεδομένων'),
(67787, 6948, 17, 'Αναβαθμίζει τη βάση δεδομένων του LibreEHR για να συμπεριλάβει Διαδικασίες, Συναρτήσεις και πίνακες που απαιτούνται για τη διαδικασία απο-ταυτοποίησης.'),
(67788, 6949, 17, 'Η αναβάθμιση θα συνεχίσει'),
(67789, 6950, 17, 'Προσ αριθμ'),
(67790, 6951, 17, 'Ανέβασμα'),
(67791, 6954, 17, 'Ανέβασμα δεδομένων ρύθμισης'),
(67792, 6955, 17, 'Ανέβασμα εγγράφου'),
(67793, 6956, 17, 'Το ανέβασμα απέτυχε!'),
(67794, 6957, 17, 'Ανέβασμα εικόνας στο'),
(67795, 6958, 17, 'Ανέβασμα αρχείου εισαγωγής:'),
(67796, 6961, 17, 'Ανέβασμα αναφοράς'),
(67797, 6963, 17, 'Ανέβασμα αυτού του αρχείου:'),
(67798, 6964, 17, 'Μόλις κάνετε κλικ στο αριθμό τιμολoγίου εμφανίζεται το "παράθυρο χειροκίνητης αποστολής". Εδώ μπορείτε να αλλάξετε την ημερομηνία λήξης της προθεσμίας και τις σημειώσεις για αυτό τιμολόγιο, να επιλέξτε το συνεργάτη για τον οποίο αποστέλετε και να επιλέξετε την ασφαλιστική κάλυψη των οποίων όλες οι αναμενόμενες πληρωμές έχουν ληφθεί. Το σημαντικότερο είναι, για κάθε κωδικό χρέωσης ο οποίος έχει επιβαρυνθεί με ένα ποσό, μπορείτε να εισαγάγετε την πληρωμή και προσαρμογή πληροφοριών.'),
(67799, 6965, 17, 'Κατά την αναζήτηση σας παρουσιάστηκε μια λίστα με τιμολόγια. Μπορείτε να κάνετε κλικ σε έναν από τους αριθμούς τιμολογίου για να ανοίξει ένα δεύτερο παράθυρο, το οποίο είναι η σελίδα εισόδου δεδομένων για χειροκίνητη αποστολή. Μπορείτε επίσης να κάνετε κλικ στο όνομα του ασθενούς, εάν θέλετε να εισάγετε μια σημείωση που θα δει το προσωπικό του γραφείου υποδοχής όταν ο ασθενής θα εισαχθεί και μπορείτε να επιλέξετε τιμολόγια για να εμφανιστούν στις καταστάσεις των ασθενών και να εκτυπώσετε αυτές.'),
(67800, 6966, 17, 'Άνω άκρο'),
(67801, 6968, 17, 'Κατεπείγον'),
(67802, 6970, 17, 'Ούρο'),
(67803, 6971, 17, 'Στραγγουρία'),
(67804, 6972, 17, 'Συχνότητα ούρησης'),
(67805, 6973, 17, 'Δισταγμός ούρησης'),
(67806, 6974, 17, 'Μικροαλβουμινουρία'),
(67807, 6975, 17, 'Ακτίνα ούρησης'),
(67808, 6976, 17, 'Επιτακτική ούρηση'),
(67809, 6977, 17, 'URL'),
(67810, 6979, 17, 'URL για υποστήριξη του LibreEHR.'),
(67811, 6981, 17, 'URL για το Phone Gateway. Προσφέρεται αυτόματη υπηρεσία VOIP από την Maviq. Παρακαλώ επισκεφθείτε το http://signup.maviq.com για περισσότερες πληροφορίες.'),
(67812, 6986, 17, 'Δείκτης χρήσης (ISA15)'),
(67813, 6987, 17, 'Χρησιμοποιήστε από μόνο του το % σε ένα πεδίο, για να κάνετε απλώς κατάταξη σε εκείνη την στήλη'),
(67814, 6988, 17, 'Χρήση μορφή ώρας 24 ωρών;'),
(67815, 6990, 17, 'Χρησιμοποιήστε πιστοποιημένη τεχνολογία EHR για την ταυτοποίηση εκπαιδευτικών πόρων για συγκεκριμένο ασθενή και για την παροχή αυτών των πόρων στον ασθενή εάν απαιτείται.'),
(67816, 6991, 17, 'Χρήση του πάνελ χρεώσεων'),
(67817, 6992, 17, 'Χρησιμοποιήστε μηχανογραφημένη ιατρική εντολή για παραγγελίες φαρμάκων που εισάγονται απευθείας από οποιονδήποτε επαγγελματία υγείας που μπορεί να εισάγει παραγγελίες στον ιατρικό φάκελο με βάση τις τοπικές επαγγελματικό κατευθύνσεις.'),
(67818, 6997, 17, 'Χρήσης προσαρμοσμένης λίστας Ανοσοποίησης'),
(67819, 6999, 17, 'Χρήση Εύρους Ημερομηνιών'),
(67820, 7000, 17, 'Χρήση Προεπιλογών'),
(67821, 7001, 17, 'Χρησιμοποιήστε την Επιλογή "Διαγραφή" για Αφαίρεση.'),
(67822, 7002, 17, 'Χρήση ημερομηνίας διεθνούς στυλ;'),
(67823, 7003, 17, 'Χρήση πηγαίου ονόματος αρχείου'),
(67824, 7004, 17, 'Χρησιμοποιήστε τα κάτωθι πεδία για μια αγορά ή μεταφορά.'),
(67825, 7005, 17, 'Χρησιμοποιήστε αυτή τη δυνατότητα μόνο με νέα εγκατεστημένες σελίδες, '),
(67826, 7006, 17, 'Χρήση θεμάτων;'),
(67827, 7007, 17, 'Χρήστης'),
(67828, 7009, 17, 'Χρήστης / Ομάδα'),
(67829, 7010, 17, 'Διαχείριση χρήστη'),
(67830, 7011, 17, 'Διαχειρηση χρήστη και έδρας'),
(67831, 7012, 17, 'Διαχείριση χρήστη και ομάδας'),
(67832, 7014, 17, 'Το Πιστοποιητικό Χρήστη έχει απενεργοποιηθεί'),
(67833, 7015, 17, 'Ορισμένο από τον Χρήστη'),
(67834, 7016, 17, 'Περιοχή ορισμένη από τον Χρήστη 11'),
(67835, 7017, 17, 'Περιοχή ορισμένη από τον Χρήστη 12'),
(67836, 7018, 17, 'Πεδίο ορισμένο από τον Χρήστη'),
(67837, 7019, 17, 'Λίστα ορισμένη από τον Χρήστη 1'),
(67838, 7020, 17, 'Λίστα ορισμένη από τον Χρήστη 2'),
(67839, 7021, 17, 'Λίστα ορισμένη από τον Χρήστη 3'),
(67840, 7022, 17, 'Λίστα ορισμένη από τον Χρήστη 4'),
(67841, 7023, 17, 'Λίστα ορισμένη από τον Χρήστη 5'),
(67842, 7024, 17, 'Λίστα ορισμένη από τον Χρήστη 6'),
(67843, 7025, 17, 'Λίστα ορισμένη από τον Χρήστη 7'),
(67844, 7026, 17, 'Κείμενο ορισμένο από τον Χρήστη 1'),
(67845, 7027, 17, 'Κείμενο ορισμένο από τον Χρήστη 2'),
(67846, 7028, 17, 'Κείμενο ορισμένο από τον Χρήστη 3'),
(67847, 7029, 17, 'Κείμενο ορισμένο από τον Χρήστη 4'),
(67848, 7030, 17, 'Κείμενο ορισμένο από τον Χρήστη 5'),
(67849, 7031, 17, 'Κείμενο ορισμένο από τον Χρήστη 6'),
(67850, 7032, 17, 'Κείμενο ορισμένο από τον Χρήστη 7'),
(67851, 7033, 17, 'Κείμενο ορισμένο από τον Χρήστη 8'),
(67852, 7034, 17, 'Μικρό όνομα χρήστη'),
(67853, 7039, 17, 'Εχγειρίδιο χρήσης'),
(67854, 7040, 17, 'Συμμετοχές μελών'),
(67855, 7041, 17, 'Όνομα χρήστη'),
(67856, 7042, 17, 'Το όνομα χρήστη ή το Hostname δεν μπορεί να είναι κενό'),
(67857, 7043, 17, 'Όνομα Χρήστη ή Υπολογιστή'),
(67858, 7046, 17, 'Ρυθμίσεις χρήστη'),
(67859, 7047, 17, 'Ειδική ρύθμιση χρήστη'),
(67860, 7049, 17, 'Όνομα Χρήστη'),
(67861, 7051, 17, 'Όνομα χρήστη για το Phone Gateway. Προσφέρεται αυτόματη υπηρεσία VOIP από την Maviq. Παρακαλώ επισκεφθείτε το http://signup.maviq.com για περισσότερες πληροφορίες.'),
(67862, 7052, 17, 'Όνομα χρήστη για το SMS Gateway'),
(67863, 7053, 17, 'Όνομα χρήστη για το SMS Gateway'),
(67864, 7055, 17, 'Όνομα Χρήστη:'),
(67865, 7056, 17, 'Χρήστες'),
(67866, 7057, 17, 'Διαχείριση Χρηστών/Ομάδων/Logs'),
(67867, 7059, 17, 'Λοιμώξεις ουροποιητικού'),
(67868, 7062, 17, 'ΑΡΓΙΑ'),
(67869, 7063, 17, 'Αργία'),
(67870, 7064, 17, 'Εμβόλιο'),
(67871, 7065, 17, 'Κολπικός δακτύλιος'),
(67872, 7066, 17, 'Προσφώνηση'),
(67873, 7067, 17, 'επικύρωση'),
(67874, 7068, 17, 'Τιμή'),
(67875, 7069, 17, 'Τιμή 1'),
(67876, 7070, 17, 'Τιμή 2'),
(67877, 7072, 17, 'Η τιμή πρέπει να είναι αριθμητική'),
(67878, 7073, 17, 'Μεταβλ 1'),
(67879, 7074, 17, 'Μεταβλ 2'),
(67880, 7075, 17, 'μεταβλητή στη μία για απο-ταυτοποίηση του script αναβάθμισης'),
(67881, 7076, 17, 'Ανεμευλογιά 1'),
(67882, 7077, 17, 'Ανεμευλογιά 2'),
(67883, 7078, 17, 'Κιρσοί φλεβών'),
(67884, 7079, 17, 'Αγγειακή κατάσταση'),
(67885, 7080, 17, 'Αγγειακή βλάβη'),
(67886, 7081, 17, 'Αγγειοχειρουργική'),
(67887, 7083, 17, 'Πωλητής'),
(67888, 7084, 17, 'Έκδοση'),
(67889, 7085, 17, 'Ίλιγγος'),
(67890, 7086, 17, 'Διαχείριση Βετεράνων'),
(67891, 7087, 17, 'Σχέδιο Διαχείρισης Βετεράνων'),
(67892, 7088, 17, 'Εμβόλια για παιδιά'),
(67893, 7089, 17, 'Βιετναμέζικα'),
(67894, 7090, 17, 'προβολή'),
(67895, 7091, 17, 'Προβολή'),
(67896, 7092, 17, 'Προβολή αλλεργιών'),
(67897, 7097, 17, 'Προβολή Αναλυτικής αναφοράς ασθενούς'),
(67898, 7100, 17, 'Προβολή εγγράφου'),
(67899, 7101, 17, 'Προβολή επίσκεψης'),
(67900, 7103, 17, 'Προβολή γεγονότων σε ένα αναδυόμενο παράθυρο'),
(67901, 7104, 17, 'Βλέπε πληροφορίες ασθενούς ειδικά για την κάθε έδρα'),
(67902, 7107, 17, 'Προβολή Log'),
(67903, 7108, 17, 'Προβολή σελίδας 1'),
(67904, 7109, 17, 'Προβολή σελίδας 2'),
(67905, 7110, 17, 'Προβολή Παλαιών και Μελλοντικών Υπενθυμίσεων'),
(67906, 7111, 17, 'Προβολή ασθενούς'),
(67907, 7116, 17, 'Δείτε σχετικές επισκέψεις'),
(67908, 7121, 17, 'Προβολή/Επεξεργ. Αλλεργιών'),
(67909, 7122, 17, 'Προβολή/Επεξεργ. προβλήματος'),
(67910, 7123, 17, 'Προβολή/Εκτύπωση'),
(67911, 7124, 17, 'Προβολή:'),
(67912, 7125, 17, 'VISA'),
(67913, 7126, 17, 'VISA/MC/AMEX/Dis'),
(67914, 7127, 17, 'Σπλαγχνική καταστροφή/τραύμα/εγχείριση'),
(67915, 7133, 17, 'Κατηγορία Επίσκεψης:'),
(67916, 7134, 17, 'Ημ/νια Επίσκεψης'),
(67917, 7135, 17, 'Ημ/νια Επίσκεψης'),
(67918, 7137, 17, 'Έντυπα επίσκεψης'),
(67919, 7138, 17, 'Ιστορικό Επισκέψεων'),
(67920, 7140, 17, 'Επισκέψεις'),
(67921, 7141, 17, 'Επισκέψεις από'),
(67922, 7142, 17, 'Ζωτικά'),
(67923, 7143, 17, 'Ζωτικά σημεία'),
(67924, 7144, 17, 'Ζωτικά σημεία (μετρικό)'),
(67925, 7146, 17, 'Φωνή'),
(67926, 7147, 17, 'Φωνή απεστάλη'),
(67927, 7149, 17, 'Εμετός'),
(67928, 7152, 17, 'Περιφ. μέσης'),
(67929, 7153, 17, 'Περιφέρεια Μέσης'),
(67930, 7154, 17, 'Αναμένοντας'),
(67931, 7155, 17, 'Υποδοχή'),
(67932, 7157, 17, 'Walt Pennington'),
(67933, 7158, 17, 'Αποθήκη'),
(67934, 7159, 17, 'Μέγιστο αποθηκών, 0 αν δεν ισχύει'),
(67935, 7160, 17, 'Ελάχιστο αποθηκών, 0 αν δεν ισχύει'),
(67936, 7161, 17, 'Αποθήκες'),
(67937, 7162, 17, 'Θερμό'),
(67938, 7163, 17, 'Προειδοποίηση'),
(67939, 7164, 17, 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ'),
(67940, 7166, 17, 'Προσοχή, ο αριθμός ελέγχου υπάρχει ήδη στη βάση δεδομένων'),
(67941, 7168, 17, 'Προειδοποίηση: Μια επίσκεψη έχει ήδη δημιουργηθεί για αυτόν τον ασθενή σήμερα!'),
(67942, 7170, 17, 'Προειδοποίηση: το αναγνωριστικό του ασθενούς δεν είναι μοναδικό!'),
(67943, 7171, 17, 'ΠΡΟΕΙΔΟΠΟΙΗΣΗ: Αυτό θα αντικαταστήσει πληροφορίες ρύθμισης με δεδομένα από το αρχείο!'),
(67944, 7173, 17, 'Προειδοποιήσεις'),
(67945, 7175, 17, 'ήταν ήδη ανεβασμένο'),
(67946, 7177, 17, 'Σας ευχαριστούμε για την άμεση καταβολή των οφειλόμενων υπολοίπων'),
(67947, 7178, 17, 'είδαμε τον παραπάνω ασθενή σας για εκτίμηση και θεραπεία στο τμήμα εξωτερικών ιατρείων της ψυχιατρικής κλινικής μας. Ευχαριστούμε για αυτήν την παραπομπή'),
(67948, 7179, 17, 'Αδυναμία'),
(67949, 7181, 17, 'Αναζήτηση στο δίκτυο'),
(67950, 7182, 17, 'Ιστοσελίδα'),
(67951, 7183, 17, 'Σύνδεσμος ιστοσελίδας του Portal του Ασθενούς'),
(67952, 7184, 17, 'Τετ'),
(67953, 7185, 17, 'Τετάρτη'),
(67954, 7186, 17, 'Εβδομάδα'),
(67955, 7187, 17, 'εβδομάδα'),
(67956, 7188, 17, 'Προβολή Εβδομάδας'),
(67957, 7189, 17, 'Εβδομάδα(ες)'),
(67958, 7190, 17, 'Εβδομάδες έκθεσης'),
(67959, 7192, 17, 'Εβδομάδες'),
(67960, 7193, 17, 'Βάρος'),
(67961, 7194, 17, 'Αξιολόγηση και συμβουλευτική σωματικού βάρους για Παιδιά και Εφήβους'),
(67962, 7195, 17, 'Αξιολόγηση και συμβουλευτική σωματικού βάρους για Παιδιά και Εφήβους'),
(67963, 7196, 17, 'Αλλαγή βάρους'),
(67964, 7197, 17, 'Απώλεια βάρους'),
(67965, 7198, 17, 'Κλινική απώλειας βάρους'),
(67966, 7199, 17, 'Καλωσορίσατε'),
(67967, 7202, 17, 'Τι πρέπει να συνυπολογιστεί;'),
(67968, 7203, 17, 'Συριγμοί:'),
(67969, 7204, 17, 'Συριγμός'),
(67970, 7205, 17, 'Συριγμός'),
(67971, 7208, 17, 'Που θα μπορούσαν να βρεθούν σχετικά σαρωμένα ή τυπωμένα έγγραφα;'),
(67972, 7212, 17, 'Λευκό(ς)'),
(67973, 7213, 17, 'Ταυτότητα'),
(67974, 7214, 17, 'Ποιος απάντησε;'),
(67975, 7215, 17, 'Χήρος/α'),
(67976, 7216, 17, 'Εύρος'),
(67977, 7217, 17, 'Εύρος σε pixel του αριστερού πλαισίου πλοήγησης.'),
(67978, 7221, 17, 'Με επιλεγμένα:'),
(67979, 7222, 17, 'με το παλιό όνομα'),
(67980, 7224, 17, 'Με ποιον θα μπορούσαμε να αφήσουμε ένα μήνυμα;'),
(67981, 7225, 17, 'Παρακρατηθέν'),
(67982, 7226, 17, 'μέσα σε ώρες'),
(67983, 7227, 17, 'μέσα σε ώρες:'),
(67984, 7228, 17, 'μέσα σε λεπτά'),
(67985, 7229, 17, 'μέσα σε λεπτά:'),
(67986, 7232, 17, 'Χωρίς Ενημέρωση'),
(67987, 7233, 17, 'Μάρτυρας'),
(67988, 7234, 17, 'εβδ'),
(67989, 7235, 17, 'ΕΦΟ'),
(67990, 7237, 17, 'Γυναίκες'),
(67991, 7238, 17, 'Μόνο γυναίκες'),
(67992, 7240, 17, 'Εργασία'),
(67993, 7241, 17, 'ΣΗΜΕΙΩΣΗ ΕΡΓΑΣΙΑΣ'),
(67994, 7242, 17, 'Τηλέφωνο εργασίας'),
(67995, 7243, 17, 'Αριθμός τηλεφώνου εργασίας'),
(67996, 7244, 17, 'Σχετικό με εργασία;'),
(67997, 7245, 17, 'Εργασία/Εκπαίδευση/Χομπυ'),
(67998, 7246, 17, 'Σημείωση εργασίας/σχολείου'),
(67999, 7247, 17, 'εργάσιμη μέρα'),
(68000, 7248, 17, 'Αποζημίωση Εργαζομένων'),
(68001, 7249, 17, 'Σχέδιο Αποζημίωσης Υγείας Εργαζομένων'),
(68002, 7252, 17, 'Επιδείνωση'),
(68003, 7253, 17, 'Θα θέλατε το υπόλοιπο ποσό να εφαρμοστεί στο Γενικό Λογαριασμό;'),
(68004, 7254, 17, 'Θα θέλατε να σημειωθούν ως Εκκαθαρισθέντα;'),
(68005, 7255, 17, 'Θα θέλατε να κατανεμηθούν;'),
(68006, 7256, 17, 'Θα θέλατε να ακυρώσετε τη διανομή για αυτόν τον ασθενή;'),
(68007, 7257, 17, 'Θα θέλατε να διαγράψετε τη διανομή πληρωμής;'),
(68008, 7258, 17, 'Θα θέλατε να διαγράψετε πληρωμές;'),
(68009, 7259, 17, 'Θα θέλατε να τροποποιήσετε και να τελειώσετε πληρωμές;'),
(68010, 7260, 17, 'Θα θέλατε να τροποποιήσετε πληρωμές;'),
(68011, 7261, 17, 'Θα θέλατε να αποστείλετε και να τελειώσετε πληρωμές;'),
(68012, 7262, 17, 'Θα θέλατε να αποστείλετε πληρωμές;'),
(68013, 7263, 17, 'Θα θέλατε να σώσετε;'),
(68014, 7264, 17, 'Καρπός'),
(68015, 7265, 17, 'Καρπός και χέρι'),
(68016, 7266, 17, 'Προβλήμ. καρπού'),
(68017, 7267, 17, 'εγγραφή'),
(68018, 7268, 17, 'διαγραφή'),
(68019, 7270, 17, 'μερικά'),
(68020, 7273, 17, 'x Ακυρωθέν'),
(68021, 7274, 17, 'x Ακυρωθέν'),
(68022, 7275, 17, 'Ακτινογραφίες'),
(68023, 7276, 17, 'Εκτίμηση ακτινογραφιών:'),
(68024, 7277, 17, 'Εκτίμηση ακτινογραφιών:'),
(68025, 7278, 17, 'Μόνο X12: Αίτηση αντικατάστασης '),
(68026, 7279, 17, 'Συνεργάτης Χ12'),
(68027, 7280, 17, 'Συνεργάτες Χ12'),
(68028, 7284, 17, 'Υ'),
(68029, 7285, 17, 'Έτος'),
(68030, 7286, 17, 'έτος'),
(68031, 7287, 17, 'Προβολή Χρονιάς'),
(68032, 7288, 17, 'Έτος(η)'),
(68033, 7289, 17, 'Έτη'),
(68034, 7292, 17, 'ΝΑΙ'),
(68035, 7293, 17, 'Ναι'),
(68036, 7294, 17, 'ναι'),
(68037, 7295, 17, 'ΝΑΙ!'),
(68038, 7296, 17, 'Ναι, διαγραφή και Log'),
(68039, 7298, 17, 'Ναι/Όχι'),
(68040, 7299, 17, 'Ναι:'),
(68041, 7303, 17, 'Πρόκειται να αντικαταστήσετε μόνιμα το υπάρχον πρότυπο. Είστε σίγουρος ότι θέλετε να συνεχίσετε;'),
(68042, 7304, 17, 'Είστε εντός Περιόδου χάριτος για το Login. Αλλάξτε κωδικό πρόσβασης πριν τη λήξη'),
(68043, 7305, 17, 'Δεν έχετε δικαίωμα να διαγράψετε αυτό το συμβάν'),
(68044, 7306, 17, 'Δεν έχετε δικαίωμα να τροποποιήσετε αυτό το συμβάν'),
(68045, 7307, 17, 'Δεν έχετε δικαίωμα για αυτό.'),
(68046, 7308, 17, 'Δεν έχετε δικαίωμα πρόσβασης αυτής την ομάδα.'),
(68047, 7309, 17, 'Δεν έχετε δικαίωμα να προσθέσετε/επεξεργαστείτε Συνοδές Νόσους/Παθήσεις'),
(68048, 7310, 17, 'Δεν έχετε δικαίωμα να προγραμματίζετε ραντεβού.'),
(68049, 7311, 17, 'Δεν έχετε δικαίωμα να δείτε αυτή την επίσκεψη.'),
(68050, 7313, 17, 'Δεν μπορείτε να προσπελάσετε αυτή τη λειτουργία άμεσα.'),
(68051, 7314, 17, 'Δεν μπορείτε να προσπελάσετε αυτή τη σελίδα άμεσα.'),
(68052, 7315, 17, 'Δεν μπορείτε να προσθέσετε μια κενή τιμή για κατηγορία!'),
(68053, 7316, 17, 'Δεν μπορείτε να προσθέσετε μια κενή τιμή για υποκατηγορία!'),
(68054, 7317, 17, 'Δεν μπορείτε να προσθέσετε μια κενή τιμή για αντικείμενο!'),
(68055, 7318, 17, 'Δεν μπορείτε να εισαγάγετε μια μελλοντική ημερομηνία με μια ολοκλρωμένη τιμή ΝΑΙ.'),
(68056, 7319, 17, 'Δεν έχετε επιλέξει καμία ενέργεια.'),
(68057, 7320, 17, 'Δεν έχετε πρόσβαση να δείτε/επεξεργαστείτε αυτό το σημείωμα'),
(68058, 7321, 17, 'Επιχειρήσατε να τροποποιήσετε περιεχόμενο το οποίο είναι κλειδωμένο. Αφαιρέστε το κλείδωμα αν θέλετε να το κάνετε. Για να το ξεκλειδώσετε, αφαιρέστε την γραμμή, ''/*lock::*/'''),
(68059, 7322, 17, 'Έχετε αποσυνδεθεί επιτυχώς.'),
(68060, 7323, 17, 'Μπορείτε να ανεβάσετε μόνο .txt αρχεία'),
(68061, 7325, 17, 'Μπορείτε να βάλετε κείμενο εδώ ως το προεπιλεγμένο ενόχλημα στο έντυπο Νέα Επίσκεψη ασθενούς.'),
(68062, 7326, 17, 'Πρέπει να πληκτρολογήσετε μια φράση πρόσβασης για την κρυπτογράφηση των εγγράφων'),
(68063, 7329, 17, 'Πρέπει πρώτα να επιλέξετε ασθενή ή να προσθέσετε νέο'),
(68064, 7330, 17, 'Πρέπει πρώτα να επιλέξετε επίσκεψη ή να δημιουργήσετε νέα'),
(68065, 7331, 17, 'Πρέπει να επιλέξετε μια κατηγορία επίσκεψης'),
(68066, 7332, 17, 'Πρέπει να επιλέξετε μια κατηγορία επίσκεψης.'),
(68067, 7333, 17, 'Πρέπει να επιλέξετε μερικά πεδία για να συνεχίσετε'),
(68068, 7334, 17, 'Θα πρέπει να εκτελείτε αυτή τη δοκιμή, εάν ο ισχυρισμός αυτός φαίνεται να παράγεται με επιτυχία αλλά το πραγματικό αρχείο αξίωσης δεν περιέχει δεδομένα ή μόνο ένα ημιτελές τμήμα του όγκου των δεδομένων που θα έπρεπε να περιέχει. Αυτό είναι προφανές με τις αξιώσεις HCFA επειδή είναι αναγνώσιμες από τον άνθρωπο, όμως με τις αξιώσεις X12 είναι πιο δύσκολη διαδικασία να προσδιοριστεί αν η αξίωση έχει ολοκληρωθεί δεόντως.'),
(68069, 7335, 17, 'Θα πρέπει να επιλέξετε τουλάχιστον ένα πλαίσιο'),
(68070, 7336, 17, 'Θα πρέπει να επιλέξετε τουλάχιστον έναν Πάροχο'),
(68071, 7339, 17, 'Η ημερομηνία λήξης σας είναι άκυρη'),
(68072, 7340, 17, 'Η συνεδρία διαγράφηκε'),
(68073, 7341, 17, 'Η συνεδρία τροποποιήθηκε'),
(68074, 7342, 17, 'Η συνεδρία καταχωρήθηκε'),
(68075, 7343, 17, 'Το αρχείο σας είναι πολύ μεγάλο'),
(68076, 7345, 17, 'Το όνομα της λίστας έχει αλλάξει για να ανταποκρίνεται στις απαιτήσεις της ονοματοδοσίας.'),
(68077, 7347, 17, 'Το όνομά σας για αυτήν την κατηγορίας, διαδικασία ή αποτέλεσμα'),
(68078, 7349, 17, 'Ο κωδικός σας έληξε. Παρακαλώ αλλάξτε τον κωδικό σας.'),
(68079, 7350, 17, 'Ο κωδικός σας λήγει στις'),
(68080, 7351, 17, 'Ο κωδικός λήγει σήμερα. Παρακαλώ αλλάξτε τον κωδικό σας.'),
(68081, 7353, 17, 'Έγινε επαναφορά των ρυθμίσεών σας για το PostCalendar στη χρήση των προεπιλογών.'),
(68082, 7354, 17, 'Οι ρυθμίσεις σας του PostCalendar ενημερώθηκαν'),
(68083, 7355, 17, 'Η συχνότητα επανάληψής σας πρέπει να είναι ακέραιος.'),
(68084, 7356, 17, 'Η συχνότητα επανάληψής σας πρέπει να είναι τουλάχιστον 1.'),
(68085, 7357, 17, 'Η ημερομηνία έναρξής σας είναι μεγαλύτερη από την ημερομηνία λήξης σας'),
(68086, 7358, 17, 'Η ημερομηνία έναρξής σας είναι άκυρη'),
(68087, 7359, 17, 'Η υποβολή σας απέτυχε'),
(68088, 7360, 17, 'εεεε-μμ-ηη'),
(68089, 7361, 17, 'ΕΕΕΕ-ΜΜ-ΗΗ'),
(68090, 7362, 17, 'εεεε-μμ-ηη Ημερομηνία συνδεδεμένη με αυτό το έγγραφο'),
(68091, 7363, 17, 'εεεε-μμ-ηη Ημερομηνία καταστράφηκε'),
(68092, 7364, 17, 'εεεε-μμ-ηη ημερομηνία γέννησης'),
(68093, 7365, 17, 'εεεε-μμ-ηη Ημερομηνία γέννησης'),
(68094, 7366, 17, 'εεεε-μμ-ηη Ημερομηνία λήξης'),
(68095, 7367, 17, 'εεεε-μμ-ηη Ημερομηνία έναρξης ή νοσηλείας'),
(68096, 7368, 17, 'εεεε-μμ-ηη ημερομηνία έναρξης, εγχείρισης ή έναρξης της αγωγής'),
(68097, 7369, 17, 'εεεε-μμ-ηη ημερομηνία αγοράς ή μεταφοράς'),
(68098, 7370, 17, 'εεεε-μμ-ηη ημερομηνία ανάρρωσης ή διακοπής της αγωγής'),
(68099, 7372, 17, 'εεεε-μμ-ηη Ημερομηνία επίσκεψης'),
(68100, 7373, 17, 'εεεε-μμ-ηη ημερομηνία αυτής της επιστολής'),
(68101, 7375, 17, 'εεεε-μμ-ηη ημερομηνία εγγράφου'),
(68102, 7376, 17, 'εεεε-μμ-ηη ημερομηνία συμβάντος ή ημερομηνία έναρξης'),
(68103, 7381, 17, 'εεεε-μμ-ηη ωω:λλ:δδ'),
(68104, 7383, 17, 'εεεε-μμ-ηη τελευταία ημερομηνία αυτού του συμβάντος'),
(68105, 7387, 17, 'Μηδέν'),
(68106, 7389, 17, 'ΤΚ'),
(68107, 7390, 17, 'Τ.Κ'),
(68108, 7391, 17, 'Τ.Κ/Χώρα:'),
(68109, 7392, 17, 'Ζουλού'),
(68110, 7393, 17, ' αλλά ήταν '),
(68111, 7394, 17, ' δεν μπορούσε να προσπελαστεί.'),
(68112, 7395, 17, 'Είστε σίγουροι ότι θέλετε να διαγράψετε'),
(68113, 7396, 17, 'Φάρμακο'),
(68114, 7397, 17, 'τα e-mail δεν στάλθηκαν'),
(68115, 7398, 17, 'από'),
(68116, 7399, 17, 'έχει δημιουργηθεί. '),
(68117, 7400, 17, 'έχει ανοιχθεί εκ νέου.'),
(68118, 7401, 17, 'Ιστορικό'),
(68119, 7402, 17, 'δεν είναι αριθμός'),
(68120, 7403, 17, 'είναι έτοιμο για επανα-χρέωση.'),
(68121, 7404, 17, 'Αριστερός κάτω λοβός:'),
(68122, 7405, 17, 'Παρτίδα'),
(68123, 7406, 17, 'Πρωτότυπος Αρ. Αναφοράς Πρόνοιας '),
(68124, 7407, 17, 'λεπτά'),
(68125, 7408, 17, 'δεν βρέθηκε!'),
(68126, 7409, 17, 'Ιδιομορφίες σε πολλούς φυλλομετρητές μπορεί να οδηγήσουν στο να εισάγεται η κάτωθι έξοδος στην οθόνη σας με απότομα τινάγματα και μεγάλες παύσεις μερικών δευτερολέπτων, που δίνουν την εντύπωση ότι η εφαρμογή έχει κολλήσει. Αυτό δε συμβαίνει: θα δείτε τελικά την έξοδο να εμφανίζεται γραμμή προς γραμμή. Μπορεί να υπάρχουν διαδοχικοί αριθμοί που εμφανίζονται πιο κάτω. Αυτό είναι ένδειξη ότι, ακόμη και αν δεν εμφανίζεται τίποτε άλλο, υπάρχει συνεχιζόμενη δραστηριότητα. Οι αριθμοί αυτοί θα είναι διάσπαρτοι με το περιεχόμενο της χρέωσης και αυτό είναι φυσιολογικό.'),
(68127, 7410, 17, 'η συνταγή έχει φτάσει το όριό της που είναι'),
(68128, 7411, 17, 'μέχρι'),
(68129, 7412, 17, 'η ενημέρωση απέτυχε, δεν είναι στη βάση δεδομένων;'),
(68130, 7413, 17, 'χαρακτηρίστηκε ως χρεωμένο μόνο.'),
(68131, 7414, 17, 'τοποθετήθηκε στην ουρά με επιτυχία.'),
(68132, 7415, 17, '! Έμεινε ανεξέταστος/η'),
(68133, 7416, 17, '" για τον κωδικό'),
(68134, 7417, 17, '" ΕΛΕΓΧΘΗΚΕ στις παραμέτρους του PostCalendar'),
(68135, 7418, 17, '# Ασφαλ./Οικονομ. θέμα'),
(68136, 7419, 17, 'Αριθμ. δισκίων:'),
(68137, 7420, 17, 'Ευρώ'),
(68138, 7421, 17, '$ Η κωδικοποίηση έγινε'),
(68139, 7422, 17, '$ετικέτα (εεεε-μμ-ηη): '),
(68140, 7423, 17, '%'),
(68141, 7424, 17, '% Ακυρωθέντα < 24 ώρες'),
(68142, 7425, 17, '% Ακυρωθέντα < 24 ώρες '),
(68143, 7426, 17, 'θα έπρεπε να υπήρχε, αλλά δεν υπάρχει.'),
(68144, 7427, 17, '(το % ταιριάζει με οποιαδήποτε συμβολοσειρά, το _ ταιριάζει με οποιοδήποτε χαρακτήρα)'),
(68145, 7428, 17, '(κάντε αριστερό κλικ κρατώντας πατημένο το [ctrl] για να επιλέξετε πολλαπλούς παραλήπτες)'),
(68146, 7429, 17, '(Πίσω)'),
(68147, 7430, 17, '(κάντε κλικ για επεξεργασία)'),
(68148, 7431, 17, '(Η παράδοση e-mail είναι άμεση, ενώ τα αυτόματα μηνύματα VOIP αποστέλλονται στον πάροχο προς διεκπεραίωση.)'),
(68149, 7433, 17, '(Νέος ασθενής)'),
(68150, 7434, 17, '(Σημειώσεις και Άδειες)'),
(68151, 7435, 17, '(Σημειώσεις ασθενούς)'),
(68152, 7436, 17, '(Επιλέξτε έναν από αυτούς ή πληκτρολογήστε το δικό σας τίτλο)'),
(68153, 7437, 17, '(Shift-) Κάντε κλικ ή συρετε για να αλλαγή τιμής'),
(68154, 7438, 17, '* Να γίνει Υπενθύμιση'),
(68155, 7439, 17, '** Παρακαλώ μεταφέρετε τα χειρουργεία στα Θέματα!'),
(68156, 7440, 17, '*Απαραίτητο'),
(68157, 7441, 17, '(+) Φάκελος ανεσύρθη'),
(68158, 7442, 17, '- Κανένα'),
(68159, 7445, 17, '.'),
(68160, 7446, 17, '0'),
(68161, 7447, 17, '0-10'),
(68162, 7448, 17, '0-24'),
(68163, 7451, 17, '1'),
(68164, 7452, 17, '30 = Ελλάς. Αναφερθείτε στο http://www.wtng.info/ για λίστα κωδικών άλλων κρατών.'),
(68165, 7453, 17, '1 Μέρα από τώρα'),
(68166, 7454, 17, '1 Μήνας από τώρα'),
(68167, 7455, 17, '1 Εβδομάδα από τώρα'),
(68168, 7456, 17, '1 Έτος από τώρα'),
(68169, 7457, 17, '1.Ανάπαυση 2. Πάγος για δύο ημέρες 3. Συμπίεση, αφήστε την πίεση στη θέση της, εκτός αν το πόδι αναπτύξει μούδιασμα, ή ωχρό χρώμα 4. Ανυψώστε το πόδι και το κάτω άκρο'),
(68170, 7458, 17, '11-14'),
(68171, 7459, 17, '12 ώρ'),
(68172, 7460, 17, '15-19'),
(68173, 7462, 17, '2'),
(68174, 7463, 17, '2 Μέρες από τώρα'),
(68175, 7464, 17, '2 Μήνες από τώρα'),
(68176, 7465, 17, '2 Εβδομάδες από τώρα'),
(68177, 7466, 17, '2 Έτη από τώρα'),
(68178, 7468, 17, '20-24'),
(68179, 7477, 17, '2111-13'),
(68180, 7478, 17, '24 ωρ'),
(68181, 7479, 17, '25+'),
(68182, 7480, 17, '25-29'),
(68183, 7481, 17, '2ο'),
(68184, 7482, 17, '3 Μέρες από τώρα'),
(68185, 7483, 17, '3 μήνες'),
(68186, 7484, 17, '3 Μήνες από τώρα'),
(68187, 7485, 17, '3 φορές ημερησίως'),
(68188, 7486, 17, '3 Εβδομάδες από τώρα'),
(68189, 7487, 17, '30-34'),
(68190, 7488, 17, '35-39'),
(68191, 7489, 17, '3ο'),
(68192, 7490, 17, '4 Μέρες από τώρα'),
(68193, 7491, 17, '4 μήνες'),
(68194, 7492, 17, '4 Μήνες από τώρα'),
(68195, 7493, 17, '4 φορές ημερησίως'),
(68196, 7494, 17, '4 Εβδομάδες από τώρα'),
(68197, 7495, 17, '40-44'),
(68198, 7496, 17, '45+'),
(68199, 7497, 17, '465.9, Λοίμωξη ανώτερου ουροποιητικού'),
(68200, 7498, 17, '466.0, Βρογχίτιδα, Οξεία Συνθετάση του ΝΟ'),
(68201, 7499, 17, '486.0, Πνευμονία, οξεία'),
(68202, 7500, 17, '491.21, ΧΑΠ έξαρση'),
(68203, 7501, 17, '491.8, Βρογχίτιδα, Χρόνια'),
(68204, 7502, 17, '493.92, Άσθμα, οξεία έξαρση'),
(68205, 7503, 17, '496.0, ΧΑΠ'),
(68206, 7504, 17, '4ο'),
(68207, 7505, 17, '5 Μέρες από τώρα'),
(68208, 7506, 17, '5 Μήνες από τώρα'),
(68209, 7507, 17, '5 Εβδομάδες από τώρα'),
(68210, 7508, 17, '519.7, Βρογχόσπασμος'),
(68211, 7509, 17, '5ο'),
(68212, 7510, 17, '6 Μέρες από τώρα'),
(68213, 7511, 17, '6 μήνες'),
(68214, 7512, 17, '6 Μήνες από τώρα'),
(68215, 7513, 17, '6 Εβδομάδες από τώρα'),
(68216, 7514, 17, '6ο'),
(68217, 7515, 17, '7 Μήνες από τώρα'),
(68218, 7516, 17, '8 Μήνες από τώρα'),
(68219, 7517, 17, '824.0 Κάταγμα, έσω σφυρό, κλειστό'),
(68220, 7518, 17, '824.2 Κάταγμα, έξω σφυρό, κλειστό'),
(68221, 7519, 17, '824.6 Κάταγμα, τρισφύριο, κλειστό'),
(68222, 7520, 17, '825.32 Κάταγμα, σκαφοειδούς (αστράγαλο)'),
(68223, 7521, 17, '825.35 Κάταγμα, Βάση του πέμπτου (5ου) μεταταρσίου'),
(68224, 7522, 17, '845.00 διάστρεμμα ποδοκνημικής ΜΑΔ'),
(68225, 7523, 17, '845.01 Διάστρεμμα έσω (δελτοειδικού) συνδ.'),
(68226, 7524, 17, '845.02 Διάστρεμμα, περονιαίας πτέρνας'),
(68227, 7525, 17, '9 Μήνες από τώρα'),
(68228, 7526, 17, '99212 Βεβαιωμένο – Ανεπίπλεκτο'),
(68229, 7527, 17, '99213 Βεβαιωμένο – Ήπια πολυπλοκότητα'),
(68230, 7528, 17, '< Στο εξεταστήριο'),
(68231, 7529, 17, '> Έγινε έλεγχος εξόδου'),
(68232, 7531, 17, '? Μη προσέλευση'),
(68233, 7532, 17, '@ Έφτασε'),
(68234, 7533, 17, '[Αλλαγή Προβολής]'),
(68235, 7534, 17, '[Ημερομ. Τελευταίας επίσκεψης]'),
(68236, 7535, 17, '[Ημέρες από την Τελευταία επίσκεψη]'),
(68237, 7536, 17, '[Περιγραφή'),
(68238, 7537, 17, '[Εξαγωγή Ανοικτής Οικονομικής Συναλλαγής]'),
(68239, 7538, 17, '[δεν συνιστάται]'),
(68240, 7539, 17, '[Αριθμός Επισκέψεων]'),
(68241, 7540, 17, '[Αναφορές]'),
(68242, 7541, 17, '[Επιλογή Όλων]'),
(68243, 7542, 17, '[SQL-Ledger]'),
(68244, 7543, 17, '[Έναρξη Επεξεργασίας κατά Δέσμες]'),
(68245, 7544, 17, '[Προβολή αρχείου καταγραφής Log]'),
(68246, 7545, 17, '[Προβολή Εκτυπώσιμης Αναφοράς]'),
(68247, 7546, 17, '_PC_DUR_HOURS'),
(68248, 7547, 17, '_PC_DUR_MINUTES'),
(68249, 7548, 17, '_PC_LOCALE'),
(68250, 7549, 17, '~ Καθυστέρησε'),
(68251, 55, 18, 'Access Not Authorised'),
(68252, 69, 18, 'ACL Administration Not Authorised'),
(68253, 121, 18, 'Add Immunisation'),
(68254, 122, 18, 'Add is not authorised!'),
(68255, 156, 18, 'Adding demographics is not authorised.'),
(68256, 278, 18, 'All or part of the organisation'),
(68257, 304, 18, 'Allow Immunisation Info Sharing'),
(68258, 305, 18, 'Allow Immunisation Registry Use'),
(68259, 391, 18, 'Any part of the immunisation id or immunisation name'),
(68260, 424, 18, 'Appointment/Event Colour'),
(68261, 523, 18, 'Authorisation group'),
(68262, 524, 18, 'Authorisation Status'),
(68263, 525, 18, 'Authorisations'),
(68264, 526, 18, 'Authorise'),
(68265, 527, 18, 'Authorise - any encounters'),
(68266, 528, 18, 'Authorise - my encounters'),
(68267, 529, 18, 'Authorise.net'),
(68268, 530, 18, 'Authorised'),
(68269, 531, 18, 'Authorised Only'),
(68270, 710, 18, 'BOX 18. Hospitalisation date from (yyyy-mm-dd): '),
(68271, 711, 18, 'BOX 18. Hospitalisation date to (yyyy-mm-dd): '),
(68272, 714, 18, 'BOX 23. Prior Authorisation No. '),
(68273, 814, 18, 'Cardiac Catheterisation'),
(68274, 945, 18, 'Childhood immunisation Status (CQM)'),
(68275, 978, 18, 'City, State Pin'),
(68276, 1149, 18, 'Coding not authorised'),
(68277, 1168, 18, 'Colour'),
(68278, 1304, 18, 'Counselling'),
(68279, 1305, 18, 'Counselling activities'),
(68280, 1313, 18, 'district'),
(68281, 1373, 18, 'Current day highlight colour'),
(68282, 1389, 18, 'Cushing Syndrome'),
(68283, 1398, 18, 'CVX Immunisation'),
(68284, 1447, 18, 'Date Immunisation Information Statements Given'),
(68285, 1586, 18, 'Demographics not authorised'),
(68286, 1587, 18, 'Demographics not authorised.'),
(68287, 1669, 18, 'Disable Immunisations'),
(68288, 1745, 18, 'Do not require patient notes to be authorised'),
(68289, 1761, 18, 'Do you wish to PERMANENTLY delete this immunisation record?'),
(68290, 1919, 18, 'Edit is not authorised!'),
(68291, 1935, 18, 'PAN'),
(68292, 2087, 18, 'encounter health and behaviour assessment'),
(68293, 2102, 18, 'encounter preventive medicine - individual counseling'),
(68294, 2116, 18, 'Encounters not authorised'),
(68295, 2158, 18, 'Enter Immunisations');
INSERT INTO `lang_definitions` VALUES
(68296, 2298, 18, 'Exclusive Provider Organisation (EPO)'),
(68297, 2415, 18, 'MCI/State Registration No.'),
(68298, 2416, 18, 'TAN'),
(68299, 2417, 18, 'PAN'),
(68300, 2552, 18, 'For Referred Organisation/Practitioner'),
(68301, 2741, 18, 'Gynaecological Exam'),
(68302, 2776, 18, 'Health Maintenance Organisation'),
(68303, 2777, 18, 'Health Maintenance Organisation (HMO) Medicare Risk'),
(68304, 2798, 18, 'Haematemesis'),
(68305, 2799, 18, 'Haematochezia'),
(68306, 2800, 18, 'Haematologic'),
(68307, 2801, 18, 'Haematuria'),
(68308, 2802, 18, 'Haemoglobin'),
(68309, 2804, 18, 'Haemoptysis'),
(68310, 2852, 18, 'History not authorised'),
(68311, 2942, 18, 'Immunisation'),
(68312, 2943, 18, 'Immunisation Code'),
(68313, 2945, 18, 'Immunisation Date'),
(68314, 2946, 18, 'Immunisation Expiration Date'),
(68315, 2947, 18, 'Immunisation Lot Number'),
(68316, 2948, 18, 'Immunisation Manufacturer'),
(68317, 2949, 18, 'Immunisation Registry'),
(68318, 2950, 18, 'Immunisation Report'),
(68319, 2951, 18, 'Immunisation Service'),
(68320, 2952, 18, 'Immunisation Title'),
(68321, 2953, 18, 'Immunisations'),
(68322, 2954, 18, 'Immunise'),
(68323, 2989, 18, 'Include Uncategorised'),
(68324, 3008, 18, 'Indicator for specialised usage'),
(68325, 3023, 18, 'Influenza Immunisation for Patients >= 50 Years Old'),
(68326, 3024, 18, 'Influenza Immunisation for Patients >= 50 Years Old (CQM)'),
(68327, 3194, 18, 'Is it ok to map these CVX codes to already existent immunisations?'),
(68328, 3228, 18, 'Issues not authorised'),
(68329, 3828, 18, 'Name and Title of Immunisation Administrator'),
(68330, 3907, 18, 'New encounters not authorised'),
(68331, 4128, 18, 'Not authorised to access PostCalendar module'),
(68332, 4129, 18, 'Not authorised'),
(68333, 4130, 18, 'Not Authorised'),
(68334, 4131, 18, 'Not authorised for this squad!'),
(68335, 4132, 18, 'Not authorised for this squad.'),
(68336, 4133, 18, 'Not authorised to manage users!'),
(68337, 4134, 18, 'Not authorised to sign results'),
(68338, 4168, 18, 'Note: This code was not entered by an authorised user. Only authorised codes may be uploaded to the Open Medical Billing Network for processing. If you wish to upload these codes, please select an authorised user here.'),
(68339, 4175, 18, 'Notes not authorised'),
(68340, 4344, 18, 'Optional immunisation name or code, use % as a wildcard'),
(68341, 4387, 18, 'Organisation'),
(68342, 4388, 18, 'Organisation Name'),
(68343, 4389, 18, 'Organisational Unit Name'),
(68344, 4390, 18, 'Organisations'),
(68345, 4560, 18, 'Patient has not authorised the Patient Portal.'),
(68346, 4568, 18, 'Patient Immunisation'),
(68347, 4935, 18, 'Post-Abortion Counselling'),
(68348, 4968, 18, 'Preferred Provider Organisation (PPO)'),
(68349, 5070, 18, 'Prior Authorisation Form'),
(68350, 5421, 18, 'Removes support for immunisations'),
(68351, 5501, 18, 'Restrict non-authorised users to the Schedule Facilities set in User admin.'),
(68352, 5601, 18, 'Aadhaar Number'),
(68353, 5631, 18, 'Save Immunisation'),
(68354, 5658, 18, 'SE Pin Code'),
(68355, 5700, 18, 'See Authorisations'),
(68356, 5739, 18, 'Select Immunisations'),
(68357, 5740, 18, 'Select Immunisations for De Identification request'),
(68358, 5885, 18, 'Show Authorised Only'),
(68359, 5963, 18, 'Skip Authorisation of Patient Notes'),
(68360, 6014, 18, 'Some authorisations were not displayed. Click here to view all'),
(68361, 6111, 18, 'UID'),
(68362, 6113, 18, 'Aadhaar'),
(68363, 6221, 18, 'Subscriber Employer Pin Code'),
(68364, 6308, 18, 'Synchronise'),
(68365, 6309, 18, 'Synchronise translations with custom language table.'),
(68366, 6310, 18, 'Synchronised new custom constant:'),
(68367, 6311, 18, 'Synchronised new custom language:'),
(68368, 6312, 18, 'Synchronised new definition (Language, Constant, Definition):'),
(68369, 6488, 18, 'The translation tables are synchronised.'),
(68370, 6619, 18, 'This will use the custom immunisations list rather than the standard CVX immunisation list.'),
(68371, 6700, 18, 'TO_ORGANISATION'),
(68372, 6755, 18, 'Total Number of Immunisations'),
(68373, 6878, 18, 'Unauthorised'),
(68374, 6879, 18, 'Unauthorised access to ePrescription'),
(68375, 6880, 18, 'Unauthorised access.'),
(68376, 6942, 18, 'Updating demographics is not authorised.'),
(68377, 6950, 18, 'Registration No'),
(68378, 6997, 18, 'Use Custom Immunisation List'),
(68379, 7307, 18, 'You are not authorised for this.'),
(68380, 7308, 18, 'You are not authorised to access this squad.'),
(68381, 7309, 18, 'You are not authorised to add/edit issues'),
(68382, 7310, 18, 'You are not authorised to schedule appointments.'),
(68383, 7311, 18, 'You are not authorised to see this encounter.'),
(68384, 7367, 18, 'yyyy-mm-dd Date of onset or hospitalisation'),
(68385, 7389, 18, 'Pin'),
(68386, 7390, 18, 'Pin Code'),
(68387, 7391, 18, 'Pin/Country'),
(68388, 7420, 18, 'INR'),
(68389, 7421, 18, 'INR Coding done'),
(68390, 7434, 18, '(Notes and Authorisations)'),
(68391, 7457, 18, '1.Rest 2. Ice for two days 3. Compression, leave the dressing in place unless the foot develops numbness or pale colour 4. Elevate the foot and leg'),
(68392, 1, 19, 'Um'),
(68393, 2, 19, 'Número de cheque ou de crédito para identificar o pagamento'),
(68394, 3, 19, 'Certificado de cliente para o administrador do sistema'),
(68395, 8, 19, 'Um formulário GCAC deve ser acrescentado a esta visita'),
(68396, 9, 19, 'Falta o número de lote'),
(68397, 10, 19, 'Falta o número de lote!'),
(68398, 11, 19, 'Letra minúscula'),
(68399, 12, 19, 'Um número'),
(68400, 14, 19, 'Já existe um utentecom este ID.'),
(68401, 15, 19, 'Já existe um utentecom este nome.'),
(68402, 16, 19, 'Já existe um utente com este SS.'),
(68403, 19, 19, 'Uma fonte de referência pode ser especificada para cada visita'),
(68404, 20, 19, 'Necessario o codigo IPPF'),
(68405, 21, 19, 'Caractere especial'),
(68406, 22, 19, 'Um valor único para identificar este campo, não visível para o utilizador'),
(68407, 24, 19, 'a.c.'),
(68408, 25, 19, 'a.m.'),
(68409, 26, 19, 'A/F Nivel Direito'),
(68410, 27, 19, 'AB'),
(68411, 28, 19, 'Abreviatura'),
(68412, 29, 19, 'Abcesso:'),
(68413, 30, 19, 'Abdominal'),
(68414, 31, 19, 'Capaz de suportar o peso por quatro (4) passos:'),
(68415, 32, 19, 'Abn'),
(68416, 33, 19, 'ABN1'),
(68417, 34, 19, 'Anormal'),
(68418, 35, 19, 'Teste Sanguíneo Anormal'),
(68419, 36, 19, 'Crescimento Anormal do Cabelo'),
(68420, 37, 19, 'Mamografia Anormal'),
(68421, 39, 19, 'Aborto'),
(68422, 40, 19, 'Casos de Aborto'),
(68423, 41, 19, 'Método de Aborto'),
(68424, 42, 19, 'Categorias Relacionadas com Aborto'),
(68425, 43, 19, 'Abortos'),
(68426, 44, 19, 'Sobre o calendário'),
(68427, 46, 19, 'Ausências por Diagnóstico'),
(68428, 47, 19, 'Aceitar Tarefa'),
(68429, 49, 19, 'Aceite Pagamento para'),
(68430, 50, 19, 'Aceita Tarefa'),
(68431, 51, 19, 'Controlo de Acesso'),
(68432, 52, 19, 'Controlo de Acesso Lista de Administração'),
(68433, 56, 19, 'Acesso ao Portal do Cliente'),
(68434, 59, 19, 'Nome da Conta'),
(68435, 62, 19, 'Contabilidade'),
(68436, 64, 19, 'Dores'),
(68437, 65, 19, 'Verificacao pedida (ISA14)'),
(68438, 67, 19, 'ACL'),
(68439, 68, 19, 'Administração ACL'),
(68440, 69, 19, 'Administração ACL Não Autorizada'),
(68441, 71, 19, 'Acne'),
(68442, 72, 19, 'Procedimento'),
(68443, 73, 19, 'Data do Procedimento'),
(68444, 74, 19, 'Ação'),
(68445, 75, 19, 'Ações'),
(68446, 78, 19, 'Activo'),
(68447, 79, 19, 'Alerta Ativo'),
(68448, 80, 19, 'Regras de Alerta Ativas'),
(68449, 81, 19, 'Alertas/Lembranças Ativas'),
(68450, 82, 19, 'Consulta Ativa'),
(68451, 84, 19, 'Listas activas'),
(68452, 85, 19, 'Utente Activo'),
(68453, 86, 19, 'Planos Ativos'),
(68454, 87, 19, 'Actividade'),
(68455, 88, 19, 'Tipo de atividade'),
(68456, 92, 19, 'Agudização'),
(68457, 93, 19, 'adicionar'),
(68458, 94, 19, 'Adicionar'),
(68459, 95, 19, 'ADICIONAR'),
(68460, 96, 19, 'Adicionar uma Empresa'),
(68461, 98, 19, 'Adicionar uma Farmácia'),
(68462, 100, 19, 'adicionar um evento para '),
(68463, 101, 19, 'adicionar como uma nova nota'),
(68464, 102, 19, 'Adicionar como Novo'),
(68465, 104, 19, 'Adicionar Botões'),
(68466, 105, 19, 'Adicionar Botões para Caracteres ou Textos Especiais serem exibidos na parte de cima do editor para inclusão no texto através de um click no rato.'),
(68467, 106, 19, 'Adicionar Categoria'),
(68468, 107, 19, 'Adicionar Constante'),
(68469, 108, 19, 'Adicionar Contexto'),
(68470, 109, 19, 'Adicionar Copagamento'),
(68471, 110, 19, 'Adicionar critério'),
(68472, 111, 19, 'Adicionar botão costumizado'),
(68473, 112, 19, 'Adicionar Diagnóstico'),
(68474, 113, 19, 'Adicionar Medicamento'),
(68475, 114, 19, 'Adicionar Consulta'),
(68476, 115, 19, 'Adicionar consulta/notas'),
(68477, 116, 19, 'Adicionar Clínica'),
(68478, 117, 19, 'Adicionar Campo'),
(68479, 118, 19, 'Junte estas linhas ao ficheiro de configuração do Servidor Web'),
(68480, 119, 19, 'Adicionar Grupo'),
(68481, 120, 19, 'Adicionar Código CDI'),
(68482, 121, 19, 'Adicionar Imunização'),
(68483, 123, 19, 'Adicionar Ocorrência'),
(68484, 125, 19, 'Adicionar Idioma'),
(68485, 126, 19, 'Adicionar Novo'),
(68486, 127, 19, 'Adicionar novo'),
(68487, 128, 19, 'Adicionar nova categoria: '),
(68488, 129, 19, 'Junte novos certificados ao ficheiro de configuração do Servidor Web'),
(68489, 132, 19, 'Adicionar Novo Grupo'),
(68490, 134, 19, 'Junte novo lote e transação'),
(68491, 135, 19, 'Adicionar Nova Nota'),
(68492, 136, 19, 'Adicionar nova nota'),
(68493, 137, 19, 'Adicionar Novo Parceiro'),
(68494, 140, 19, 'Adicionar Nota'),
(68495, 141, 19, 'Adicionar Registo do Utente'),
(68496, 142, 19, 'Adicionar Receita'),
(68497, 144, 19, 'Adicionar Número do Clínico'),
(68498, 146, 19, 'Adicionar Regra'),
(68499, 147, 19, 'Adicionar a'),
(68500, 148, 19, 'Adicionar à Lista de Medicamentos'),
(68501, 149, 19, 'Adicionar Nível Topo'),
(68502, 150, 19, 'Adicionar Transação'),
(68503, 151, 19, 'Adicionar Utilizador'),
(68504, 152, 19, 'Adicionar Utilizador ao Grupo'),
(68505, 154, 19, 'Adicionar/Editar Transacção do Utente'),
(68506, 155, 19, 'adicionado'),
(68507, 156, 19, 'Não está autorizado a adicionar dados demográficos.'),
(68508, 158, 19, 'Síndroma de Addison'),
(68509, 159, 19, 'Síndroma de Addison'),
(68510, 160, 19, 'Atributos adicionais'),
(68511, 161, 19, 'Diagnósticos adicionais:'),
(68512, 162, 19, 'Historial Adicional'),
(68513, 163, 19, 'Notas do historial adicional'),
(68514, 164, 19, 'Informação Adicional'),
(68515, 165, 19, 'Laboratórios adicionais'),
(68516, 166, 19, 'Notas adicionais'),
(68517, 168, 19, 'Notas adicionais:'),
(68518, 169, 19, 'Notas adicionais: '),
(68519, 170, 19, 'Notas de RADIOGRAFIA adicionais:'),
(68520, 172, 19, 'Só adicionar'),
(68521, 173, 19, 'Contactos'),
(68522, 174, 19, 'Contactos'),
(68523, 175, 19, 'Endereço'),
(68524, 178, 19, 'Contactos'),
(68525, 179, 19, 'Contacto empresa que vai efectuar o procedimento'),
(68526, 180, 19, 'Contacto do fornecedor'),
(68527, 181, 19, 'Contacto do vendedor'),
(68528, 182, 19, 'Tipos de Contacto'),
(68529, 187, 19, 'Endereço1'),
(68530, 188, 19, 'Endereço2'),
(68531, 189, 19, 'DESTINATÁRIO'),
(68532, 190, 19, 'Ajt'),
(68533, 191, 19, 'Ajt Quant'),
(68534, 192, 19, 'Ajuste'),
(68535, 193, 19, 'Entendimento'),
(68536, 195, 19, 'Razões de ajuste'),
(68537, 196, 19, 'Valor de ajuste para código '),
(68538, 197, 19, 'Ajustes'),
(68539, 198, 19, 'Adm ajuste'),
(68540, 199, 19, 'Admin'),
(68541, 200, 19, 'Admin E-mail'),
(68542, 201, 19, 'Administrado Via'),
(68543, 202, 19, 'Administrado'),
(68544, 203, 19, 'Administrado por'),
(68545, 206, 19, 'Administração'),
(68546, 208, 19, 'Administradores'),
(68547, 209, 19, 'Administradores podem fazer qualquer operação'),
(68548, 214, 19, 'Directiva avançada'),
(68549, 215, 19, 'Directivas Avançadas'),
(68550, 218, 19, 'Avançado'),
(68551, 219, 19, 'Recomendação'),
(68552, 221, 19, 'Afecta o normal'),
(68553, 223, 19, 'Chamadas fora de horas'),
(68554, 226, 19, 'Depois de guardar o PDF, clique [Ver Reg] p/ conferir.'),
(68555, 227, 19, 'depois de guardar os ficheiro(s) Text , pressione [View Log ] para verificar os erros'),
(68556, 228, 19, 'Depois de economizar seu grupo, clique [Tronco de Visão] conferir para erros.'),
(68557, 230, 19, 'Depois que na informação é entrada corretamente, clique o Economize botão.'),
(68558, 233, 19, 'Novamente'),
(68559, 234, 19, 'Idade'),
(68560, 235, 19, 'Idade Por'),
(68561, 236, 19, 'Categoria de idade'),
(68562, 237, 19, 'Dados de idade é fora do alcance.'),
(68563, 239, 19, 'Formato de idade para "idade de" não é válido'),
(68564, 240, 19, 'Formato de idade para "idade até" não é válido'),
(68565, 241, 19, 'Idade a partir de'),
(68566, 243, 19, 'Idade máxima'),
(68567, 244, 19, 'Idade mínima'),
(68568, 245, 19, 'Intervalo de Idade'),
(68569, 247, 19, 'Colunas de Idade:'),
(68570, 250, 19, 'Álcool'),
(68571, 251, 19, 'Consumo de álcool'),
(68572, 253, 19, 'Contagem de Alertas'),
(68573, 255, 19, 'Alertas'),
(68574, 259, 19, 'Tudo'),
(68575, 260, 19, 'TUDO'),
(68576, 266, 19, 'Todas as Categorias'),
(68577, 268, 19, 'Todos os codigos'),
(68578, 269, 19, 'Todo o Dia'),
(68579, 270, 19, 'Evento para todo o dia'),
(68580, 271, 19, 'todos os campos demograficos, com pesquisa e duplo check'),
(68581, 272, 19, 'Todas as Clínicas'),
(68582, 273, 19, 'Todas as Feridas/Problemas/Assuntos'),
(68583, 274, 19, 'Todos os Idiomas Permitidos'),
(68584, 276, 19, 'Tudo ou parte do nome próprio'),
(68585, 277, 19, 'Tudo ou parte do último nome'),
(68586, 280, 19, 'Todos os produtos'),
(68587, 281, 19, 'Todos os Clínicos'),
(68588, 282, 19, 'Tudo Revisto e Negativo:'),
(68589, 283, 19, 'Todos os Tópicos'),
(68590, 284, 19, 'Todos os Utilizadores'),
(68591, 285, 19, 'Alérgico'),
(68592, 286, 19, 'Alergias'),
(68593, 287, 19, 'Alergias:'),
(68594, 288, 19, 'Alergia'),
(68595, 291, 19, 'Reação Alérgica'),
(68596, 294, 19, 'Alocar'),
(68597, 295, 19, 'Permitir'),
(68598, 296, 19, 'permitir todas as linguas disponiveis como escolha no menu do login'),
(68599, 299, 19, 'Permite E-mail'),
(68600, 300, 19, 'Permite mensagens de e-mail?'),
(68601, 301, 19, 'Permite E-mail?'),
(68602, 302, 19, 'Permitir reclamações de consulta'),
(68603, 303, 19, 'Permitir Troca de Informações de Saúde'),
(68604, 304, 19, 'Permitir Partilha de Informações sobre Imunizações'),
(68605, 305, 19, 'Permitir o Uso do Registo de Imunizações'),
(68606, 306, 19, 'Permitir Mensagem de Correio'),
(68607, 308, 19, 'Permitir Portal do Utente'),
(68608, 309, 19, 'Permitir SMS'),
(68609, 310, 19, 'Permitir SMS (mensagens de texto)?'),
(68610, 311, 19, 'Permitir tornar eventos propostos imediatamente ativos?'),
(68611, 312, 19, 'Permitir mensagens de telefone?'),
(68612, 313, 19, 'Permitir aos utilizadores publicar Eventos Globais'),
(68613, 314, 19, 'Permitir aos utilizadores publicar Calendários Pessoais'),
(68614, 315, 19, 'Permitir Mensagem de Voz'),
(68615, 316, 19, 'Permitido'),
(68616, 317, 19, 'Idiomas Permitidos'),
(68617, 323, 19, 'já existe'),
(68618, 324, 19, 'já existe.'),
(68619, 325, 19, 'Já usado, escolha outro identificador'),
(68620, 326, 19, 'Já usado, escolha outro título'),
(68621, 327, 19, 'Alt Address'),
(68622, 328, 19, 'alterar'),
(68623, 329, 19, 'Alternativamente, você pode usar a página de procura para transferir uma remessa eletrônica (X12 835), que obteve do sub-sistema pagador. Para isso, carregue no botão BROWSE e depois escolha o arquivo a transferir; depois, carregando em Procura para executar o carregamento e mostrar as facturas correspondentes. Neste caso não se aplicam os outros parâmetros mencionados acima. Upload guarda o arquivo mas não processa o seu conteúdo--isso é feito separadamente, como se explica abaixo.'),
(68624, 330, 19, 'AM'),
(68625, 338, 19, 'Emende Nota Existente'),
(68626, 345, 19, 'AMEX'),
(68627, 347, 19, 'Quantia'),
(68628, 349, 19, 'Total de valores'),
(68629, 350, 19, 'Chegue para Equilíbrio Passado'),
(68630, 351, 19, 'Chegue para Esta Visita'),
(68631, 352, 19, 'Valor pago'),
(68632, 353, 19, 'Quantia:'),
(68633, 357, 19, 'ocorreu um erro durante o «dumping» da árvore do directório LibreEHR'),
(68634, 358, 19, 'ocorreu um erro durante o "dumping" da árvore do directório phpGACL'),
(68635, 359, 19, 'ocorreu um erro durante o "dumping" da árvore do directório SQL-Ledger'),
(68636, 360, 19, 'Um assunto de GCAC incompleto foi criado e foi unido. Alguém precisará completar isto depois.'),
(68637, 362, 19, 'Um erro inesperado ocorreu.'),
(68638, 363, 19, 'Uma letra maiúscula'),
(68639, 365, 19, 'E'),
(68640, 366, 19, 'E'),
(68641, 367, 19, 'e'),
(68642, 368, 19, 'e '),
(68643, 369, 19, 'e todos os dados de subordinado? Esta acção ficará registada'),
(68644, 371, 19, 'e processado.'),
(68645, 372, 19, 'e reinicie o servidor Apache'),
(68646, 373, 19, 'e o Motivo é'),
(68647, 374, 19, 'Anemia'),
(68648, 375, 19, 'Tornozelo'),
(68649, 376, 19, 'tornozelo + calcanhar'),
(68650, 377, 19, 'Formulário de Avaliação do Tornozelo'),
(68651, 378, 19, 'Problemas de tornozelo'),
(68652, 379, 19, 'Espondilite Anquilosante'),
(68653, 380, 19, 'Espondilite Anquilosante'),
(68654, 381, 19, 'Anorexia'),
(68655, 382, 19, 'Outra coisa que você pode fazer na janela é pedir a facturação secundária. Se você selecionar este checkbox antes de economizar, então a reivindicação original será re-aberta e será feita fila na página de Faturamento, e será processado durante a próxima corrida de faturamento.'),
(68656, 383, 19, 'parada'),
(68657, 384, 19, 'Nl de ânus, sem dor/massa rectal,'),
(68658, 385, 19, 'Ansiedade'),
(68659, 386, 19, 'Qualquer'),
(68660, 387, 19, 'Qualquer Categoria'),
(68661, 388, 19, 'Qualquer parte do código desejado ou sua descrição'),
(68662, 389, 19, 'Qualquer parte da especialidade desejada'),
(68663, 390, 19, 'qualquer parte da especialidade no nosso nome da especialidade'),
(68664, 392, 19, 'Qualquer parte do nome do utente, ou "last,first ", ou "X-Y "'),
(68665, 395, 19, 'Apnéia'),
(68666, 396, 19, 'Aparência'),
(68667, 397, 19, 'Aparência:'),
(68668, 398, 19, 'Anexar nota'),
(68669, 399, 19, 'Junte à nota existente'),
(68670, 400, 19, 'Junte a esta nota'),
(68671, 401, 19, 'Junte a Esta Nota'),
(68672, 402, 19, 'Apendicectomia'),
(68673, 409, 19, 'Título do Programa'),
(68674, 413, 19, 'aplique a área afetada'),
(68675, 414, 19, 'aplique na pele'),
(68676, 415, 19, 'Aplicando'),
(68677, 417, 19, 'Marcação'),
(68678, 418, 19, 'Data de Marcação'),
(68679, 419, 19, 'Estilo Apresentação das Marcações'),
(68680, 420, 19, 'Regra de Lembrança de Marcação'),
(68681, 421, 19, 'Estado da Marcação'),
(68682, 422, 19, 'Estados da Marcação'),
(68683, 423, 19, 'Marcação dentro de'),
(68684, 424, 19, 'Marcação/Cor'),
(68685, 425, 19, 'Marcações'),
(68686, 426, 19, 'Marcações (escrita opcional)'),
(68687, 430, 19, 'Marcações e Consultas'),
(68688, 431, 19, 'Relatório das Marcações'),
(68689, 432, 19, 'Relatório Marcações-Consultas'),
(68690, 434, 19, 'Aprovar'),
(68691, 436, 19, 'Aprovado'),
(68692, 437, 19, 'Administração de Eventos Aprovados'),
(68693, 440, 19, 'Marc-Cons'),
(68694, 441, 19, 'Marc.'),
(68695, 442, 19, 'Abr'),
(68696, 443, 19, 'Abril'),
(68697, 444, 19, 'Arabe'),
(68698, 453, 19, 'Está preparado para completar um problema GCAC novo para essa visita?'),
(68699, 455, 19, 'Tem certeza que deseja aprovar esses eventos?'),
(68700, 457, 19, 'Tem certeza que quer remover completamente este formulário?'),
(68701, 460, 19, 'Tem certeza de que deseja excluir este evento?'),
(68702, 461, 19, 'Você tem certeza de que deseja excluir esse item do banco de dados?'),
(68703, 462, 19, 'Tem certeza de que deseja excluir esta nota?'),
(68704, 464, 19, 'Tem certeza que deseja editar estes eventos?'),
(68705, 465, 19, 'Tem certeza que deseja ocultar estes eventos?'),
(68706, 467, 19, 'Você tem certeza que quer ver estes eventos?'),
(68707, 468, 19, 'Tem certeza de que deseja apagar todo o grupo denominado'),
(68708, 469, 19, 'Tem certeza de que deseja apagar toda a lista'),
(68709, 470, 19, 'Tem certeza de que deseja excluir o campo em'),
(68710, 471, 19, 'Tem certeza de que deseja apagar os campos selecionados?'),
(68711, 472, 19, 'Tem certeza de que deseja continuar com estas ações?'),
(68712, 473, 19, 'Área não especificada'),
(68713, 474, 19, 'braço'),
(68714, 475, 19, 'Armênio'),
(68715, 477, 19, 'Arritmia'),
(68716, 478, 19, 'Artrite'),
(68717, 479, 19, 'Artrite / doenças articulares degen'),
(68718, 480, 19, 'Artrite / doenças articulares degen'),
(68719, 481, 19, 'como'),
(68720, 482, 19, 'A partir de'),
(68721, 484, 19, 'Asiático'),
(68722, 487, 19, 'Avaliação'),
(68723, 488, 19, 'Nomeado'),
(68724, 489, 19, 'Assistente'),
(68725, 490, 19, 'Asma'),
(68726, 491, 19, 'a'),
(68727, 492, 19, 'Pelo menos um parâmetro de procura é necessário se você selecionar Todos.'),
(68728, 493, 19, 'Ao Navicular'),
(68729, 494, 19, 'Ao Navicular:'),
(68730, 495, 19, 'atleta de competição'),
(68731, 497, 19, 'Athletic/Injury'),
(68732, 503, 19, 'Atenção'),
(68733, 504, 19, 'À atenção de'),
(68734, 516, 19, 'Ago'),
(68735, 517, 19, 'Agosto'),
(68736, 519, 19, 'Auth'),
(68737, 520, 19, 'Aut. / notas'),
(68738, 525, 19, 'Autorizações'),
(68739, 526, 19, 'Autorize'),
(68740, 527, 19, 'Autorize - qualquer encontro'),
(68741, 528, 19, 'Autorize - meus encontros'),
(68742, 530, 19, 'Autorizado'),
(68743, 531, 19, 'Autorizado apenas'),
(68744, 532, 19, 'auto enviado'),
(68745, 535, 19, 'Crear automaticamente novos encontros'),
(68746, 536, 19, 'Auto-gerado'),
(68747, 544, 19, 'Automático'),
(68748, 546, 19, 'automaticamente cria um novo encontro quando o estado do anterior é "@" (chegado)'),
(68749, 549, 19, 'Exame médico automóvel'),
(68750, 550, 19, 'autosaved'),
(68751, 551, 19, 'Categorias disponíveis'),
(68752, 552, 19, 'Horário Disponível'),
(68753, 557, 19, 'Média Mensal'),
(68754, 558, 19, 'Avulsão / fratura de avulsão'),
(68755, 559, 19, 'Avulsão malleolus lateral'),
(68756, 560, 19, 'Avulsão malleolus mediano '),
(68757, 561, 19, 'Consciência-baseado'),
(68758, 562, 19, 'Axilar'),
(68759, 565, 19, 'b.i.d.'),
(68760, 566, 19, 'voltar'),
(68761, 567, 19, 'voltar'),
(68762, 568, 19, 'Voltar oito visitas'),
(68763, 569, 19, 'voltar: 11 visitas'),
(68764, 570, 19, 'voltar: 5 visitas'),
(68765, 571, 19, 'voltar: 4 visitas'),
(68766, 572, 19, 'voltar: 9 visitas'),
(68767, 573, 19, 'voltar: 1 visita'),
(68768, 574, 19, 'Dor de costas'),
(68769, 575, 19, 'Problemas nas costas'),
(68770, 576, 19, 'voltar: 8 visitas'),
(68771, 577, 19, 'voltar: 6 visitas'),
(68772, 578, 19, 'antes da Cirurgia'),
(68773, 579, 19, 'voltar: 10 visitas'),
(68774, 580, 19, 'voltar: 3 visitas'),
(68775, 584, 19, 'voltar ao utente'),
(68776, 586, 19, 'voltar a "View"'),
(68777, 587, 19, 'voltar: 12 visitas'),
(68778, 588, 19, 'voltar: 2 visitas'),
(68779, 590, 19, 'Backup'),
(68780, 591, 19, 'Backup criado. Segue-se o descarregamento.'),
(68781, 594, 19, 'Cheque sem provimento'),
(68782, 595, 19, 'Dívida incobrável'),
(68783, 596, 19, 'Bahasa Indonésia'),
(68784, 597, 19, 'Bal'),
(68785, 598, 19, 'Saldo'),
(68786, 599, 19, 'equilíbrio'),
(68787, 601, 19, 'Saldo em Divida'),
(68788, 607, 19, 'Base de quinto (5º) Metarsico'),
(68789, 608, 19, 'Base de quinto (5º) Metarsico:'),
(68790, 612, 19, 'Ferramenta de Comunicação Diferida'),
(68791, 615, 19, 'Comunicação Diferida: pode demorar...'),
(68792, 617, 19, 'BatchCom'),
(68793, 619, 19, 'porque o ID não existe.'),
(68794, 620, 19, 'Começo'),
(68795, 621, 19, 'Data inicial'),
(68796, 623, 19, 'Data de início do serviço aaaa-mm-dd'),
(68797, 626, 19, 'Eructação'),
(68798, 630, 19, 'entre'),
(68799, 633, 19, 'Bilateral'),
(68800, 634, 19, 'Bilateral:'),
(68801, 636, 19, 'Conta: (data)'),
(68802, 637, 19, 'Conta: (receber)'),
(68803, 638, 19, 'Facturado'),
(68804, 640, 19, 'Facturado'),
(68805, 641, 19, 'Facturado (anote)'),
(68806, 642, 19, 'Facturado: à atn. de'),
(68807, 644, 19, 'Facturação: Código de serviço requisitado'),
(68808, 645, 19, 'Facturação: Códigos'),
(68809, 647, 19, 'Facturação: Departamento'),
(68810, 649, 19, 'Facturação: Informação'),
(68811, 650, 19, 'Facturação: Local'),
(68812, 656, 19, 'Facturação: Nota'),
(68813, 657, 19, 'Facturação: Nota para '),
(68814, 658, 19, 'Facturação: Nota:'),
(68815, 659, 19, 'Facturação: lista de resultados:'),
(68816, 660, 19, 'Facturação: Relatório'),
(68817, 662, 19, 'Estado da Factura = recibo não emitido'),
(68818, 663, 19, 'Facturado a '),
(68819, 665, 19, 'Biópsia'),
(68820, 666, 19, 'Data de Nascimento'),
(68821, 669, 19, 'Preto'),
(68822, 672, 19, 'Cancro da bexiga'),
(68823, 673, 19, 'Infecções de bexiga'),
(68824, 674, 19, 'Formulários em branco'),
(68825, 675, 19, 'Diátese Hemorrágica'),
(68826, 676, 19, 'Pontos cegos'),
(68827, 677, 19, 'Distendido'),
(68828, 678, 19, 'Bloqueado'),
(68829, 679, 19, 'Sangue'),
(68830, 680, 19, 'Pressão Arterial'),
(68831, 681, 19, 'Pressão arterial'),
(68832, 682, 19, 'Epistaxis'),
(68833, 683, 19, 'Blue Cross Blue Shield ORIG AMERICANO'),
(68834, 684, 19, 'Neste relatório: Linhas azuis são informativas; Linhas pretas mostram informação existente; Linhas verdes mostram modificações aceites; Linhas vermelhas indicam erros, ou mudanças não aceites e devem ser verificadas manualmente. Também a vermelho: reembolsos negados ou devoluções.'),
(68835, 685, 19, 'Visão turva'),
(68836, 686, 19, 'IMC'),
(68837, 687, 19, 'IMC Status'),
(68838, 689, 19, 'Região do corpo'),
(68839, 690, 19, 'lado do corpo'),
(68840, 691, 19, 'lado do corpo , se aplicavel'),
(68841, 692, 19, 'fragilidade óssea'),
(68842, 694, 19, 'Booleano'),
(68843, 696, 19, 'Inf.'),
(68844, 697, 19, 'Ambos os ouvidos'),
(68845, 698, 19, 'Ambos os ouvidos'),
(68846, 699, 19, 'Fundo'),
(68847, 701, 19, 'CAIXA 10 Emprego de A. relacionado '),
(68848, 702, 19, 'CAIXA 10 B. Acidente Automático '),
(68849, 703, 19, 'CAIXA 10 C. Outro Acidente '),
(68850, 708, 19, 'CAIXA 16. Data incapaz trabalhar de (yyyy-mm-dd):'),
(68851, 709, 19, 'CAIXA 16. Data incapaz trabalhar (yyyy-mm-dd):'),
(68852, 710, 19, 'CAIXA 18. Data de hospitalização de (yyyy-mm-dd): '),
(68853, 711, 19, 'CAIXA 18. Data de hospitalização para (yyyy-mm-dd): '),
(68854, 712, 19, 'CAIXA 20. Está Fora de Laboratório usado?'),
(68855, 713, 19, 'CAIXA 22. Medicaid Resubmission Código (ICD-9) '),
(68856, 714, 19, 'CAIXA 23. Autorização anterior Não. '),
(68857, 715, 19, 'TA'),
(68858, 716, 19, 'TA diastólica'),
(68859, 717, 19, 'TA sistólica'),
(68860, 719, 19, 'Bpd'),
(68861, 721, 19, 'Bps'),
(68862, 722, 19, 'Português do Brasil'),
(68863, 723, 19, 'Mama'),
(68864, 724, 19, 'Mama: Biópsia'),
(68865, 725, 19, 'Mama: Corrimento mamilar'),
(68866, 726, 19, 'Mama: Doença'),
(68867, 727, 19, 'Mama: Exame'),
(68868, 728, 19, 'Mama: Massa'),
(68869, 730, 19, 'Sons de respiração:'),
(68870, 732, 19, 'Fracturas'),
(68871, 734, 19, 'Bronquite: Formulário'),
(68872, 735, 19, 'Navegue'),
(68873, 736, 19, 'Navegue até à ficha'),
(68874, 737, 19, 'Contusão / hematoma'),
(68875, 739, 19, 'Abaulamento Direita:'),
(68876, 741, 19, 'Ardor ao urinar'),
(68877, 742, 19, 'Ardor ao urinar'),
(68878, 744, 19, 'Ocupado'),
(68879, 746, 19, 'nádega'),
(68880, 747, 19, 'Nádega + S.I.'),
(68881, 748, 19, 'por'),
(68882, 749, 19, 'por'),
(68883, 750, 19, 'per os'),
(68884, 751, 19, 'Por/Fonte'),
(68885, 752, 19, 'Por:'),
(68886, 753, 19, 'C'),
(68887, 755, 19, 'Cache Lifetime (in seconds)'),
(68888, 756, 19, 'Cache template output?'),
(68889, 757, 19, 'Cafeína: consumo'),
(68890, 758, 19, 'Calendário'),
(68891, 762, 19, 'Deefinições Calendário'),
(68892, 764, 19, 'Interface Calendário'),
(68893, 765, 19, 'Ver Calendário'),
(68894, 766, 19, 'Call to addForm() goes here.<br>'),
(68895, 767, 19, 'Calorias'),
(68897, 774, 19, 'Cancelar'),
(68898, 775, 19, 'Cancelar Alterações'),
(68899, 776, 19, 'Cancelado'),
(68900, 777, 19, 'Cancro'),
(68901, 782, 19, 'Não pode acrescentar isto porque já existe!'),
(68902, 783, 19, 'Não pode acrescentar/actualizar esta entrada porque já existe um duplicado'),
(68903, 785, 19, 'não pode ser convertido para JPEG. (O ImageMagick está instalado?)'),
(68904, 787, 19, 'não pode ser mostrado inline porque este formato não é suportado pelo browser.'),
(68905, 788, 19, 'não pode ser mostrado inline porque este formato não é suportado pelo browser.'),
(68906, 789, 19, 'não pode ser mostrado inline porque este formato não é suportado pelo browser.'),
(68907, 790, 19, 'Não é possível criar'),
(68908, 795, 19, 'Não é possível encontrar '),
(68909, 799, 19, 'Não consigo encontrar o paciente a partir do ID-SQL-Ledger de cliente'),
(68910, 800, 19, 'Não consigo encontrar ref. do documento PostScript em '),
(68911, 801, 19, 'Não consigo encontrar o prestador a partir do ID-SQL-Ledger de empregado '),
(68912, 803, 19, 'Não consigo abrir '),
(68913, 807, 19, 'Não consigo ler'),
(68914, 809, 19, 'Não consigo actualizar porque não está a editar uma entrada pre-existente!'),
(68915, 812, 19, 'cápsula'),
(68916, 813, 19, 'Cartão'),
(68917, 814, 19, 'Cateterização Cardíaca'),
(68918, 815, 19, 'Eco cardíaco'),
(68919, 816, 19, 'Cardiovascular'),
(68920, 821, 19, 'Lesões: cartilagem/condral/disco'),
(68921, 822, 19, 'Lesão da cartilagem'),
(68922, 823, 19, 'Pulsações Cartoid nl, nl dos pulsos'),
(68923, 824, 19, 'dinheiro'),
(68924, 825, 19, 'Dinheiro'),
(68925, 826, 19, 'Dinheiro Rec'),
(68926, 827, 19, 'Dinheiro Recibos por Prestador'),
(68927, 829, 19, 'Cataratas: Cirurgia'),
(68928, 830, 19, 'Cataratas'),
(68929, 831, 19, 'Categorias'),
(68930, 833, 19, 'Categoria'),
(68931, 834, 19, 'categoria'),
(68932, 835, 19, 'Categoria '),
(68933, 836, 19, 'Categoria: Detalhes'),
(68934, 837, 19, 'Categoria: Limites'),
(68935, 838, 19, 'Categoria: Nome'),
(68936, 841, 19, 'Caucasiano'),
(68937, 853, 19, 'Telemovel'),
(68938, 855, 19, 'Telemovel Nº'),
(68939, 856, 19, 'Certificação Central'),
(68940, 864, 19, 'ChampUS'),
(68941, 865, 19, 'ChampUSVA'),
(68942, 866, 19, 'alterar'),
(68943, 867, 19, 'Alterar'),
(68944, 868, 19, 'Alterar Actividade'),
(68945, 870, 19, 'Alterar Vista'),
(68946, 871, 19, 'Alterar Vista'),
(68947, 874, 19, 'Alterarado'),
(68948, 875, 19, 'Intestino Alterarado'),
(68949, 877, 19, 'Características'),
(68950, 879, 19, 'Custo'),
(68951, 882, 19, 'Custos'),
(68952, 883, 19, 'Processo'),
(68953, 884, 19, 'Registos do Processo'),
(68954, 885, 19, 'Relatório de Baixas/Altas'),
(68955, 886, 19, 'ID Processo'),
(68956, 887, 19, 'ID Processo:'),
(68957, 889, 19, 'Processo: Actividade Local?'),
(68958, 890, 19, 'Nota do Processo'),
(68959, 891, 19, 'Número de Processo'),
(68960, 892, 19, 'Arquivo Físico do Processo'),
(68961, 893, 19, 'Localizador de Processos'),
(68962, 894, 19, 'Loc. de Processos'),
(68963, 895, 19, 'Alta de Processos'),
(68964, 896, 19, 'Saídas'),
(68965, 898, 19, 'Verificar'),
(68966, 899, 19, 'verificar'),
(68967, 900, 19, 'Conferir Tudo'),
(68968, 902, 19, 'Conferir quantidade'),
(68969, 903, 19, 'Conferir Data'),
(68970, 906, 19, 'Entrada para'),
(68971, 907, 19, 'Verificar dados de entrada'),
(68972, 909, 19, 'Verificar Resultados das análises do Laboratório'),
(68973, 912, 19, 'Verificar Número'),
(68974, 919, 19, 'Verificar / EOB Data:'),
(68975, 920, 19, 'Verificar / EOB No.:'),
(68976, 921, 19, 'Verificar / Ref No.'),
(68977, 922, 19, 'Verificar / Número de Referência'),
(68978, 923, 19, 'Lista de seleção'),
(68979, 924, 19, 'lista de seleção'),
(68980, 925, 19, 'lista de seleção c/ texto'),
(68981, 926, 19, 'Lista de seleção c/ texto'),
(68982, 929, 19, 'Caixa conferida = sim , vazio = não'),
(68983, 932, 19, 'Saída'),
(68984, 934, 19, 'Torax'),
(68985, 935, 19, 'Torax CTAB'),
(68986, 936, 19, 'Dor Torácica'),
(68987, 937, 19, 'Dor Torácica:'),
(68988, 938, 19, 'Dores Torácicas'),
(68989, 940, 19, 'Chg'),
(68990, 942, 19, 'Queixa principal'),
(68991, 943, 19, 'Criança'),
(68992, 946, 19, 'Arrepios'),
(68993, 947, 19, 'Chinês'),
(68994, 948, 19, 'Chinês (simplif.)'),
(68995, 949, 19, 'Chinês (trad.)'),
(68996, 951, 19, 'Opções'),
(68997, 952, 19, 'Colecistectomia'),
(68998, 954, 19, 'Colecistectomia'),
(68999, 955, 19, 'Escolha'),
(69000, 956, 19, 'Escolha uma secção e clique num art. dentro dela e depois, noutra seção, poderá ver os itens relacionados em destaque, e pode clicar nesse ponto para adicionar e excluir relações.'),
(69001, 962, 19, 'Escolha: lista'),
(69002, 965, 19, 'Escolha: formato impressão p/ rel. consulta'),
(69003, 967, 19, 'Bronquite crônica'),
(69004, 968, 19, 'Artralgia crónica'),
(69005, 970, 19, 'Sinovite crónica / derrame / dor nas articulações / gota'),
(69006, 971, 19, 'Crónica/Recorrente'),
(69007, 973, 19, 'Cirrose Hepatica'),
(69008, 974, 19, 'Cirrose Hepatica'),
(69009, 975, 19, 'Localidade'),
(69010, 976, 19, 'Localidade: Nome'),
(69011, 977, 19, 'Localidade: Distrito'),
(69012, 978, 19, 'Localidade: Cod Postal'),
(69013, 979, 19, 'Localidade/Distrito'),
(69014, 980, 19, 'Lista de honorários'),
(69015, 981, 19, 'Lista de honorários '),
(69016, 983, 19, 'Lista de honorários: teste concluído'),
(69017, 986, 19, 'Lista de honorários: ficheiro criado '),
(69018, 988, 19, 'Classificação'),
(69019, 989, 19, 'Apagar'),
(69020, 991, 19, 'Apagar Tudo'),
(69021, 993, 19, 'Apagar Justificação'),
(69022, 994, 19, 'Apagar Cache do Smarty'),
(69023, 996, 19, 'CLIA Number'),
(69024, 997, 19, 'Clique'),
(69025, 998, 19, 'Clique ''export'' p/ exportar Categoria, Subcategoria, Item, Conteudo para um ficheiro. Este ficheiro NÃO É XML. As marcas de inicio e fim devem estar na mesma linha, em minusculas e sem espaços. Para importar, procure um ficheiro e clique ''import''. Se os dados forem diferentes serão adicionados aos dados existentes. Se houver nomes iguais, os mais antigos serão mantidos e os mais novos guardados com um no. adicionado no fim.'),
(69026, 1001, 19, 'clique para saber mais'),
(69027, 1005, 19, 'clique aqui.'),
(69028, 1006, 19, 'clique aqui para adicionar um novo utente.'),
(69029, 1008, 19, 'Clique aqui para escolher uma data'),
(69030, 1009, 19, 'Clique aqui para escolher data e hora.'),
(69031, 1010, 19, 'Clique aqui para escolher uma data de inicio'),
(69032, 1020, 19, 'clique aqui para procurar'),
(69033, 1021, 19, 'Clique aqui para actualizar prioridade, categoria e'),
(69034, 1022, 19, 'Clique aqui para ver tudo.'),
(69035, 1023, 19, 'Clique aqui para ver e fazer o gráfico'),
(69036, 1025, 19, 'Clique aqui para ver e fazer o gráfico de todos os sinais vitais'),
(69037, 1026, 19, 'Clique aqui para ver todos os detalhes dos utentes'),
(69038, 1027, 19, 'Clique aqui para ver todos'),
(69039, 1029, 19, 'Clique no botão de Instalar para instalar a base de dados com edição na seguinte data'),
(69040, 1030, 19, 'Clique em qualquer uma das secções temporais para a aumentar'),
(69041, 1032, 19, 'Clique Renovar para ver todos os resultados, ou então, por favor dê entrada ao critério de pesquisa acima para ver resultados específicos.'),
(69042, 1034, 19, 'Clique para adicionar novos componentes'),
(69043, 1035, 19, 'Clique para adicionar nova consulta'),
(69044, 1037, 19, 'Clique para carregar'),
(69045, 1038, 19, 'Clique para editar'),
(69046, 1040, 19, 'Clique para editar esta evento'),
(69047, 1041, 19, 'Clique para gerar o relatório'),
(69048, 1043, 19, 'Clique para imprimir'),
(69049, 1044, 19, 'Clique para receber (adicionar) novo lote'),
(69050, 1045, 19, 'Clique para seleccionar'),
(69051, 1046, 19, 'Clique para seleccionar'),
(69052, 1051, 19, 'Clique para selecionar ou mudança de diagnóstico'),
(69053, 1053, 19, 'Clique para seleccionar o utente'),
(69054, 1054, 19, 'Clique para selecionar o código relacionado'),
(69055, 1058, 19, 'Clique para ver'),
(69056, 1059, 19, 'Clique ver ou editar'),
(69057, 1060, 19, 'Clique para ver/editar'),
(69058, 1063, 19, 'Clique:'),
(69059, 1067, 19, 'Cópia do Utente'),
(69060, 1069, 19, 'Sumário da História Clinica'),
(69061, 1072, 19, 'Perfil do Utente - Novos Utentes'),
(69062, 1073, 19, 'Perfil do Utente- Utente Únicos'),
(69063, 1074, 19, 'Utentes'),
(69064, 1075, 19, 'Clínica'),
(69065, 1076, 19, 'Copia da Clinica'),
(69066, 1077, 19, 'Registro Diário da Clinica'),
(69067, 1078, 19, 'Clínica ID'),
(69068, 1106, 19, 'Clínicos'),
(69069, 1107, 19, 'copie'),
(69070, 1108, 19, 'copie a visita anterior'),
(69071, 1109, 19, 'Fechar'),
(69072, 1111, 19, 'Fechar a janela'),
(69073, 1112, 19, 'Fechado'),
(69074, 1113, 19, 'cm'),
(69075, 1118, 19, 'CMS ID'),
(69076, 1127, 19, 'CN2-12 íntima'),
(69077, 1131, 19, 'Código'),
(69078, 1132, 19, 'Código'),
(69079, 1133, 19, 'Codifique o descobridor'),
(69080, 1134, 19, 'Código deve ser duas letras minúsculs'),
(69081, 1138, 19, 'tipo de códig'),
(69082, 1144, 19, 'Códigos'),
(69083, 1145, 19, 'Codificando'),
(69084, 1147, 19, 'Codificando - qualquer encontro (escrever, aumentar opcional)'),
(69085, 1148, 19, 'Codificando - meu encontro (escrever, aumentar opcional)'),
(69086, 1149, 19, 'Código não autorizado'),
(69087, 1150, 19, 'Café'),
(69088, 1152, 19, 'Co-seguro'),
(69089, 1153, 19, 'Coll w/o'),
(69090, 1154, 19, 'Esconder'),
(69091, 1155, 19, 'esconder'),
(69092, 1156, 19, 'Esconder Tudo'),
(69093, 1157, 19, 'Esconder tudo'),
(69094, 1158, 19, 'esconder tudo'),
(69095, 1161, 19, 'Coleções'),
(69096, 1162, 19, 'Relatório de Coleções'),
(69097, 1163, 19, 'Cancror do Cólon'),
(69098, 1165, 19, 'Cirurgia do Cancro do Cólon'),
(69099, 1166, 19, 'Colonoscopia'),
(69100, 1167, 19, 'Colonoscopia'),
(69101, 1168, 19, 'Cor'),
(69102, 1171, 19, 'Colunas'),
(69103, 1173, 19, 'Vírgula'),
(69104, 1174, 19, 'Comentário'),
(69105, 1175, 19, 'Comentários'),
(69106, 1176, 19, 'Comentários ao resultado'),
(69107, 1177, 19, 'Cia. De Seguro comercial'),
(69108, 1178, 19, 'Faça mudanças'),
(69109, 1180, 19, 'Comunicações'),
(69110, 1182, 19, 'Empresa'),
(69111, 1184, 19, 'Concluir'),
(69112, 1186, 19, 'Concluído'),
(69113, 1190, 19, 'Complicações através do provedor de serviços'),
(69114, 1191, 19, 'Complicações do Aborto'),
(69115, 1193, 19, 'Computador Ajudou Sistema de Ordenamento de Exame médico'),
(69116, 1194, 19, 'Conclusões'),
(69117, 1199, 19, 'Configuração'),
(69118, 1200, 19, 'Configuração Exportar/Importar'),
(69119, 1208, 19, 'Confirme o Novo Utente'),
(69120, 1210, 19, 'Confirme Pagamento'),
(69121, 1214, 19, 'Congênito'),
(69122, 1215, 19, 'Conjuntiva, pupils'),
(69123, 1218, 19, 'Constante'),
(69124, 1219, 19, 'Nome Constante'),
(69125, 1221, 19, 'Constantes'),
(69126, 1222, 19, 'Obstipação'),
(69127, 1223, 19, 'Constitucional'),
(69128, 1226, 19, 'Descrição Breve da Consulta'),
(69129, 1227, 19, 'Contacto'),
(69130, 1228, 19, 'Correio eletrónico (email)'),
(69131, 1229, 19, 'Endereço Electrónico'),
(69132, 1231, 19, 'informação do contacto'),
(69133, 1232, 19, 'Lentes de Contacto'),
(69134, 1236, 19, 'Contate o Nome'),
(69135, 1237, 19, 'Contate a pessoa'),
(69136, 1239, 19, 'Contate o Número de Telefone'),
(69137, 1243, 19, 'Conteúdo'),
(69138, 1244, 19, 'conteúdo'),
(69139, 1247, 19, 'Continuar'),
(69140, 1250, 19, 'Clientes de Contra'),
(69141, 1251, 19, 'Contracepção'),
(69142, 1252, 19, 'Assuntos de Contracepção'),
(69143, 1253, 19, 'Complicação anticoncepcional (especifique)'),
(69144, 1254, 19, 'Métodos Anticontracepcional'),
(69145, 1256, 19, 'Sérviços anticontracepcionais começaram previamente'),
(69146, 1257, 19, 'Anticontracepciona Começou'),
(69147, 1259, 19, 'Control No'),
(69148, 1262, 19, 'Copay'),
(69149, 1263, 19, 'CoPay'),
(69150, 1264, 19, 'Copay não positivo'),
(69151, 1266, 19, 'Copays'),
(69152, 1267, 19, 'COPD'),
(69153, 1268, 19, 'Copia página do doente traçada'),
(69154, 1269, 19, 'Copia Valores'),
(69155, 1271, 19, 'Protegido por direitos de autor'),
(69156, 1273, 19, 'Bypass coronário'),
(69157, 1289, 19, 'Tosse'),
(69158, 1290, 19, 'Tosse:'),
(69159, 1294, 19, 'Não foi possível ler o ficheiro'),
(69160, 1296, 19, 'Não pode enviar e-mail devido a problema do servidor, '),
(69161, 1301, 19, 'Não pode remover o documento antigo exportado'),
(69162, 1303, 19, 'Acounselhamento através de Método'),
(69163, 1304, 19, 'Aconselhando'),
(69164, 1305, 19, 'Atividade de Aconselhamento'),
(69165, 1306, 19, 'CONTRA FORMA DE INDICAÇÃO'),
(69166, 1307, 19, 'Contra informação'),
(69167, 1308, 19, 'País'),
(69168, 1311, 19, 'Lista de Países (escrever,adicionar somente opcional)'),
(69169, 1313, 19, 'país'),
(69170, 1315, 19, 'Cupom'),
(69171, 1318, 19, 'CPT'),
(69172, 1320, 19, 'CPT Códigos'),
(69173, 1324, 19, 'Crackles:'),
(69174, 1325, 19, 'nata'),
(69175, 1329, 19, 'Criar um Evento'),
(69176, 1330, 19, 'Crie e carregue um auxílio cheio'),
(69177, 1332, 19, 'Criar um Auxílio'),
(69178, 1336, 19, 'Guardar Novo'),
(69179, 1340, 19, 'Novo Utente'),
(69180, 1344, 19, 'Nova Notas do Utente'),
(69181, 1346, 19, 'Nova Visita'),
(69182, 1347, 19, 'Criado'),
(69183, 1348, 19, 'Arquivo de exportação criado'),
(69184, 1352, 19, 'crédito'),
(69185, 1354, 19, 'Créditos'),
(69186, 1356, 19, 'Critérios'),
(69187, 1358, 19, 'Crohn''Doença de'),
(69188, 1359, 19, 'Crohn Doença de'),
(69189, 1360, 19, 'Exportar em CSV'),
(69190, 1361, 19, 'Ficheiro CSV'),
(69191, 1364, 19, 'Cubano'),
(69192, 1369, 19, 'Corrente'),
(69193, 1371, 19, 'Consulta atual'),
(69194, 1373, 19, 'Cor de destaque de dia atual'),
(69195, 1375, 19, 'O nome da pasta foi trocado para'),
(69196, 1377, 19, 'Localização atual'),
(69197, 1378, 19, 'Medicação atual'),
(69198, 1379, 19, 'Palavra chave atual'),
(69199, 1380, 19, 'Utente Corrente'),
(69200, 1386, 19, 'Atualmente ativo'),
(69201, 1389, 19, 'Síndrome de Cushing'),
(69202, 1390, 19, 'Síndrome de Cushing'),
(69203, 1392, 19, 'Costume'),
(69204, 1399, 19, 'Ciclo'),
(69205, 1400, 19, 'CYP'),
(69206, 1401, 19, 'Fator CYP'),
(69207, 1402, 19, 'Relatório CYP'),
(69208, 1404, 19, 'D'),
(69209, 1405, 19, 'D&C'),
(69210, 1406, 19, 'D&E'),
(69211, 1407, 19, 'D. Nasc.'),
(69212, 1408, 19, 'diariamente'),
(69213, 1409, 19, 'Registo Diário'),
(69214, 1410, 19, 'Dinamarquês'),
(69215, 1411, 19, 'Dado semelhante já está no banco de dados, por código de alteração e / ou descrição'),
(69216, 1412, 19, 'Dados Semelhantes já está em banco de dados, por favor mude npme'),
(69217, 1413, 19, 'Dados Cols'),
(69218, 1420, 19, 'Tipos de Dados'),
(69219, 1421, 19, 'Base de Dados'),
(69220, 1424, 19, 'Relatório da Base de Dados'),
(69221, 1425, 19, 'Finalizada a atualização da Base de Dados'),
(69222, 1426, 19, 'DataCols deve ser um número entre 1 e 999'),
(69223, 1427, 19, 'Data'),
(69224, 1428, 19, 'DATA'),
(69225, 1431, 19, 'Data Administrou'),
(69226, 1437, 19, 'Dada de Serviços anticoncepcionais inicialmente contanto'),
(69227, 1439, 19, 'Data do Óbito'),
(69228, 1440, 19, 'Destruído em'),
(69229, 1441, 19, 'Formato da Data'),
(69230, 1442, 19, 'Formato de data para "fim de compomisso" não é válido'),
(69231, 1443, 19, 'Formato de data para "início de compomisso" não é válido'),
(69232, 1444, 19, 'Formato de data para "Próximo compomisso" não é válido'),
(69233, 1445, 19, 'Formato de data para "não visto desde então" não é válido'),
(69234, 1446, 19, 'Formato de data para "visto desde então" não é válido'),
(69235, 1447, 19, 'Date Declarações de Informação de Imunização Dadas'),
(69236, 1448, 19, 'Data está perdendo para código '),
(69237, 1450, 19, 'Data do depósito bancário aaaa-mm-dd'),
(69238, 1452, 19, 'Data de Nascimento'),
(69239, 1453, 19, 'Data de nascimento'),
(69240, 1456, 19, 'Data da lesão'),
(69241, 1458, 19, 'Data do Pagamento aaaa-mm-dd'),
(69242, 1459, 19, 'Data de Indicação'),
(69243, 1460, 19, 'Data de resposta'),
(69244, 1463, 19, 'Data De Serviço'),
(69245, 1465, 19, 'Data de serviço mm-dd-aaaa'),
(69246, 1466, 19, 'Data de Serviço'),
(69247, 1467, 19, 'Data De Assinatura'),
(69248, 1471, 19, 'Data de Declaração de VIS'),
(69249, 1480, 19, 'Data/Appt'),
(69250, 1481, 19, 'Data/Notas'),
(69251, 1482, 19, 'Data/Ùltimas Notas'),
(69252, 1484, 19, 'Data:'),
(69253, 1486, 19, 'Dia'),
(69254, 1487, 19, 'dia'),
(69255, 1489, 19, 'Dia'),
(69256, 1490, 19, 'Dia(s)'),
(69257, 1491, 19, 'Dias úteis'),
(69258, 1492, 19, 'dias'),
(69259, 1493, 19, 'Days'),
(69260, 1494, 19, 'dias atrás'),
(69261, 1495, 19, 'Dias e Jogos Perderam'),
(69262, 1496, 19, 'Dias De Último Encontro'),
(69263, 1498, 19, 'Dias por Colunas'),
(69264, 1501, 19, 'BD Instalada'),
(69265, 1502, 19, 'DD/MM/AAAA'),
(69266, 1509, 19, 'DEA'),
(69267, 1511, 19, 'Surdo'),
(69268, 1512, 19, 'Depure Informação'),
(69269, 1515, 19, 'Dez'),
(69270, 1516, 19, 'FALECIDO'),
(69271, 1517, 19, 'Dezembro'),
(69272, 1520, 19, 'Dedutível'),
(69273, 1522, 19, 'Omissão'),
(69274, 1523, 19, 'Vista de Calendário Predefinida'),
(69275, 1524, 19, 'ID Formulário de Consulta Predefinido'),
(69276, 1526, 19, 'Clínica Predefinida'),
(69277, 1527, 19, 'Idioma Predefinido'),
(69278, 1528, 19, 'Idioma predefinido se não houver outra opção.'),
(69279, 1529, 19, 'Lista predefinida (escrever, adicionar opcional)'),
(69280, 1530, 19, 'Método Predefinido'),
(69281, 1531, 19, 'Dias de Expiração da Senha Predefinidos'),
(69282, 1532, 19, 'Dias de expiração da senha predefinidos. 0 é ilimitado.'),
(69283, 1536, 19, 'Clínico Predefinido'),
(69284, 1537, 19, 'Intervalo Predefinido'),
(69285, 1538, 19, 'Razão da Visita Predefinido'),
(69286, 1540, 19, 'Definição Predefinida'),
(69287, 1542, 19, 'Modelo Predefinido'),
(69288, 1546, 19, 'Unidades Predefinidas'),
(69289, 1547, 19, 'Valor Predefinido'),
(69290, 1548, 19, 'Armazém Predefinido'),
(69291, 1549, 19, 'Parceiro X12 Predefinido'),
(69292, 1550, 19, 'Predefinido/Global'),
(69293, 1551, 19, 'Eli'),
(69294, 1552, 19, 'eli'),
(69295, 1553, 19, 'Recorrência tardia (> 12 Mo)'),
(69296, 1554, 19, 'Eliminar'),
(69297, 1555, 19, 'eliminar'),
(69298, 1556, 19, 'Eliminar Categorias com ID(s): '),
(69299, 1560, 19, 'Eliminar Grupo'),
(69300, 1561, 19, 'Eliminar Lista'),
(69301, 1562, 19, 'Eliminar Páginas'),
(69302, 1563, 19, 'Eliminar Utente, Consulta, Formulário, edição, Documento, Pagamento, Cobrança ou Transacção'),
(69303, 1565, 19, 'Eliminar Linha'),
(69304, 1566, 19, 'Eliminar Itens Seleccionados'),
(69305, 1568, 19, 'Eliminado.'),
(69306, 1569, 19, 'Eliminar documento'),
(69307, 1570, 19, 'Eliminar formulário'),
(69308, 1571, 19, 'Eliminar nota'),
(69309, 1581, 19, 'Demência'),
(69310, 1582, 19, 'Informações demograficas'),
(69311, 1583, 19, 'Demograficas (escrever opcionalmente)'),
(69312, 1586, 19, 'Demograficas não autorizou'),
(69313, 1587, 19, 'Demographics não autorizou.'),
(69314, 1590, 19, 'Dental'),
(69315, 1592, 19, 'Problemas Dentários'),
(69316, 1595, 19, 'Dependendo do tipo de conta que você está testando você vai ver HCFA como a saída em uma página em branco para HCFA contas, você vai ver várias linhas de texto um tanto truncado e as informações se você está testando uma reivindicação X12. Esse texto ilegível é o X12 EDI 4010 formato. Ocasionalmente você vai ver caracteres estranhos que parecem dominós ou squiglies, estes são caracteres de controle como de alimentação de pagina e são normais.'),
(69317, 1598, 19, 'Data do Depósito'),
(69318, 1599, 19, 'Deprimido'),
(69319, 1600, 19, 'Depressão'),
(69320, 1602, 19, 'Descrição'),
(69321, 1603, 19, 'descrição'),
(69322, 1607, 19, 'Tradução de descrição'),
(69323, 1609, 19, 'Destino'),
(69324, 1611, 19, 'Destrua Lote'),
(69325, 1612, 19, 'Destruir'),
(69326, 1613, 19, 'Destruido'),
(69327, 1614, 19, 'Drogas Destruidas'),
(69328, 1615, 19, 'Relatório de Drogas Destruidas'),
(69329, 1617, 19, 'Detalhes'),
(69330, 1619, 19, 'anormalidade Desenvolvente'),
(69331, 1620, 19, 'Diabete'),
(69332, 1631, 19, 'Diag'),
(69333, 1633, 19, 'Diagnóstico:'),
(69334, 1637, 19, 'Diagnóstico deve ser codificado em um encontro único'),
(69335, 1643, 19, 'Diagnósticos:'),
(69336, 1644, 19, 'Diagnósticos: '),
(69337, 1645, 19, 'Testes do Diagnósticos'),
(69338, 1646, 19, 'Dials'),
(69339, 1647, 19, 'Diaphragms/Caps'),
(69340, 1648, 19, 'Diarréia'),
(69341, 1650, 19, 'Ditado'),
(69342, 1651, 19, 'Ditado: '),
(69343, 1652, 19, 'Voçê recebeu uma cópia da Notificação de HIPAA?'),
(69344, 1653, 19, 'Difunda:'),
(69345, 1654, 19, 'Assinado digitalmente'),
(69346, 1657, 19, 'Mala Direta'),
(69347, 1665, 19, 'Incapacidade'),
(69348, 1675, 19, 'inactivo'),
(69349, 1676, 19, 'Inactivo'),
(69350, 1678, 19, 'DISC'),
(69351, 1681, 19, 'corrimento'),
(69352, 1682, 19, 'corrimento uretral'),
(69353, 1684, 19, 'Descarregue Direto'),
(69354, 1685, 19, 'Descarregue Direto'),
(69355, 1692, 19, 'Informações'),
(69356, 1694, 19, 'Desconto'),
(69357, 1695, 19, 'Quantia de desconto'),
(69358, 1696, 19, 'Alavanc do Desconto'),
(69359, 1701, 19, 'Doença'),
(69360, 1702, 19, 'Luxação'),
(69361, 1703, 19, 'Disp #'),
(69362, 1704, 19, 'Despachado'),
(69363, 1705, 19, 'Expedição do documento recebido'),
(69364, 1706, 19, 'Dispensado'),
(69365, 1709, 19, 'Datas de eventos de exibição em bloco?'),
(69366, 1711, 19, 'Mostrar quantos eventos?'),
(69367, 1713, 19, 'Mostrar localização em bloco?'),
(69368, 1715, 19, 'Mostrar calendário?'),
(69369, 1718, 19, 'Mostrar eventos de hoje em bloco?'),
(69370, 1719, 19, 'Mostrar tópico em bloco?'),
(69371, 1720, 19, 'Mostrar eventos futuros em bloco?'),
(69372, 1722, 19, 'A mostrar o número de informação mais recentes:'),
(69373, 1724, 19, 'A mostrar o número de notas mais recentes:'),
(69374, 1725, 19, 'Distribuição'),
(69375, 1726, 19, 'Distribuições'),
(69376, 1727, 19, 'Distribuidor'),
(69377, 1729, 19, 'Diverticulitis'),
(69378, 1730, 19, 'Cirúrgia de Diverticulite'),
(69379, 1731, 19, 'Diverticulite'),
(69380, 1732, 19, 'Cirúrgia de Diverticulite'),
(69381, 1733, 19, 'Divorciado(a)'),
(69382, 1734, 19, 'Vertigem:'),
(69383, 1735, 19, 'Não alterar'),
(69384, 1742, 19, 'Não mostrar no calendário.'),
(69385, 1744, 19, 'Não inventariar e vender produtos'),
(69386, 1745, 19, 'Não exigir autorização das notas dos utentes'),
(69387, 1746, 19, 'Ordem de Não Ressuscitar'),
(69388, 1747, 19, 'não guardar'),
(69389, 1748, 19, 'não substituir'),
(69390, 1749, 19, 'não executar'),
(69391, 1751, 19, 'Confirma a eliminação'),
(69392, 1752, 19, 'Confirma a eliminação da selecção?'),
(69393, 1753, 19, 'Confirma a eliminação do grupo'),
(69394, 1755, 19, 'Deseja continuar ?'),
(69395, 1756, 19, 'Deseja eliminar isto ?'),
(69396, 1757, 19, 'Deseja eliminar?'),
(69397, 1758, 19, 'Confirma a eliminação do registo?'),
(69398, 1759, 19, 'Deseja continuar a criar este novo utente?'),
(69399, 1760, 19, 'Deseja continuar com o nome novo?'),
(69400, 1761, 19, 'Deseja eliminar PERMANENTEMENTE este registo de vacinação?'),
(69401, 1762, 19, 'D. Nascimento'),
(69402, 1763, 19, 'Data de nascimento em falta'),
(69403, 1764, 19, 'Docs'),
(69404, 1765, 19, 'Médico'),
(69405, 1766, 19, 'Médico:'),
(69406, 1767, 19, 'Nome do médico e assinatura'),
(69407, 1768, 19, 'Documento'),
(69408, 1769, 19, 'documento'),
(69409, 1770, 19, 'Categorias dos Documentos'),
(69410, 1775, 19, 'Documento não pode ser movido para o id utente'),
(69411, 1777, 19, 'Data do Documento'),
(69412, 1778, 19, 'Data do documento e assunto actualizados'),
(69413, 1779, 19, 'ID do Documento'),
(69414, 1780, 19, 'Documento movido para nova categória'),
(69415, 1781, 19, 'Documento movido para o id do utente'),
(69416, 1790, 19, 'Guarda Documento/Imagem'),
(69417, 1791, 19, 'Documentos'),
(69418, 1792, 19, 'Documentos (escrever opcionalmente)'),
(69419, 1794, 19, 'DOE'),
(69420, 1799, 19, 'Relação Estável'),
(69421, 1800, 19, 'Não guardar'),
(69422, 1801, 19, 'Não guardar'),
(69423, 1802, 19, 'Não Guardar Alterações'),
(69424, 1803, 19, 'Efectuado'),
(69425, 1804, 19, 'Efectuado com:'),
(69426, 1805, 19, 'Efectuado. A enviar descarga.'),
(69427, 1806, 19, 'DOS'),
(69428, 1807, 19, 'Dosagem'),
(69429, 1809, 19, 'Duplo-clique para editar'),
(69430, 1810, 19, 'Visão Dupla'),
(69431, 1811, 19, 'Descarregar');
INSERT INTO `lang_definitions` VALUES
(69432, 1814, 19, 'Descarregar'),
(69433, 1815, 19, 'Carregamento da faturamento do arquivo, poste para a contabilidade e marca'),
(69434, 1817, 19, 'Descarregar Certificados'),
(69435, 1818, 19, 'Carregamento da configuração de dados'),
(69436, 1828, 19, 'Dr: Verifica'),
(69437, 1829, 19, 'Dr: Visita'),
(69438, 1830, 19, 'Dr.'),
(69439, 1832, 19, 'Pingando'),
(69440, 1833, 19, 'Carta de Condução ou BI/CC'),
(69441, 1834, 19, 'Droga'),
(69442, 1836, 19, 'Formulários de Drogas'),
(69443, 1837, 19, 'Falta ID da Droga!'),
(69444, 1838, 19, 'Intervalo das Drogas'),
(69445, 1839, 19, 'Inventário de medicamentos'),
(69446, 1840, 19, 'Nome da medicamento'),
(69447, 1841, 19, 'Rotas de Droga'),
(69448, 1845, 19, 'Unidades do medicamento'),
(69449, 1846, 19, 'Medicamentos'),
(69450, 1848, 19, 'Boca seca'),
(69451, 1850, 19, 'DT 1'),
(69452, 1851, 19, 'DT 2'),
(69453, 1852, 19, 'DT 3'),
(69454, 1853, 19, 'DT 4'),
(69455, 1854, 19, 'DT 5'),
(69456, 1855, 19, 'DTaP 1'),
(69457, 1856, 19, 'DTaP 2'),
(69458, 1857, 19, 'DTaP 3'),
(69459, 1858, 19, 'DTaP 4'),
(69460, 1859, 19, 'DTaP 5'),
(69461, 1861, 19, 'Data de vencimento'),
(69462, 1862, 19, 'Data de vencimento m/dd/aaaa ou aaaa/mm/dd'),
(69463, 1863, 19, 'Data de vencimento'),
(69464, 1864, 19, 'Vencimento Ins'),
(69465, 1865, 19, 'Vencimento Pt'),
(69466, 1869, 19, 'Base de dados LibreEHR esvaziado'),
(69467, 1870, 19, 'Rede da árvore LibreEHR do diretório esvaziando'),
(69468, 1871, 19, 'Base de dados de phpGACL esvaziando'),
(69469, 1872, 19, 'Rede da árvore phpGACL do diretório esvaziando'),
(69470, 1873, 19, 'Base de dados SQL-Ledger esvaziado'),
(69471, 1874, 19, 'Rede da árvore SQL-Ledger do diretório esvaziando'),
(69472, 1878, 19, 'ADVERTÊNCIA DE DUPLICAÇÃO'),
(69473, 1880, 19, 'duração'),
(69474, 1881, 19, 'Duração'),
(69475, 1882, 19, 'Holandês'),
(69476, 1884, 19, 'Disfagia'),
(69477, 1885, 19, 'Dysphagia'),
(69478, 1886, 19, 'Dysuria'),
(69479, 1894, 19, 'Retorno Cedo (<2 Mo)'),
(69480, 1895, 19, 'Orelhas'),
(69481, 1896, 19, 'ECG'),
(69482, 1898, 19, 'Edema'),
(69483, 1904, 19, 'Editar'),
(69484, 1906, 19, 'Edite Alergias'),
(69485, 1907, 19, 'Editar Categorias'),
(69486, 1908, 19, 'Editar Definições'),
(69487, 1909, 19, 'Editar definições'),
(69488, 1910, 19, 'Editar Diagnósticos para'),
(69489, 1912, 19, 'Editar Clínicas'),
(69490, 1913, 19, 'Editar Clínicar'),
(69491, 1914, 19, 'Editar Informações da Clínica'),
(69492, 1916, 19, 'Editar Ficheiro em'),
(69493, 1917, 19, 'Edite formulário'),
(69494, 1918, 19, 'Editar Definições Globais'),
(69495, 1920, 19, 'Editar Plano'),
(69496, 1921, 19, 'Edite Lista'),
(69497, 1923, 19, 'Edite Estrutura'),
(69498, 1924, 19, 'Editar Utilizador'),
(69499, 1925, 19, 'Editar Definições do Utilizador'),
(69500, 1928, 19, 'Educação'),
(69501, 1929, 19, 'Data de Educação'),
(69502, 1931, 19, 'ee a GNU General Public License para mais detalhes. * Você deve ter recebido uma cópia da Licença Pública Geral GNU * junto com este programa, se não, escreva para a Free '),
(69503, 1932, 19, 'Data Efectiva'),
(69504, 1934, 19, 'Efetividade'),
(69505, 1936, 19, 'Ejaculações'),
(69506, 1937, 19, 'Cotovelo'),
(69507, 1938, 19, 'Ploblemas do Cotovelo'),
(69508, 1949, 19, 'E-mail'),
(69509, 1957, 19, 'E-mail de Batchcom'),
(69510, 1958, 19, 'Notificação de E-mail'),
(69511, 1961, 19, 'E-mail enviado antes'),
(69512, 1962, 19, 'E-mail Remetente'),
(69513, 1965, 19, 'Assunto de e-mail'),
(69514, 1966, 19, '***NOME***'),
(69515, 1971, 19, 'Contacto de Emergência'),
(69516, 1972, 19, 'Contacto da Pessoa de Emergêrcia'),
(69517, 1973, 19, 'Numero do Telefone de Emergência da Pessoa'),
(69518, 1974, 19, 'Anticontraceptivos de Emergência'),
(69519, 1980, 19, 'Telefone de Emergência'),
(69520, 1982, 19, 'Enfisema'),
(69521, 1983, 19, 'Empregado'),
(69522, 1984, 19, 'Emprego'),
(69523, 1985, 19, 'Endereço Empregador'),
(69524, 1986, 19, 'Data do Empregador'),
(69525, 1987, 19, 'Nome do Empregador'),
(69526, 1988, 19, 'VAZIO'),
(69527, 1989, 19, 'Vazio'),
(69528, 1991, 19, 'Valor vazio em "Hora do E-mail"'),
(69529, 1992, 19, 'Valor vazio em "Rementente do E-mail"'),
(69530, 1993, 19, 'Valor vazio em "Assunto de E-mail'),
(69531, 1994, 19, 'Valor vazio em "Testo de E-mail"'),
(69532, 1995, 19, 'Valor vazio em "Nome do Provedor"'),
(69533, 1996, 19, 'Valor vazio em "Senha"'),
(69534, 1997, 19, 'Valor vazio em "Horas do SMS"'),
(69535, 1998, 19, 'Valor vazio em "Testo do SMS"'),
(69536, 1999, 19, 'Valor vazio em "Nome do Ùsuario"'),
(69537, 2068, 19, 'activo'),
(69538, 2071, 19, 'Con'),
(69539, 2072, 19, 'Cons'),
(69540, 2073, 19, 'Consulta'),
(69541, 2074, 19, 'consulta'),
(69542, 2075, 19, 'Consulta '),
(69543, 2086, 19, 'Formulários da Consulta'),
(69544, 2088, 19, 'Histórico de Consultas'),
(69545, 2089, 19, 'ID Consulta'),
(69546, 2091, 19, 'Número de consulta'),
(69547, 2108, 19, 'Estatísticas da consulta'),
(69548, 2109, 19, 'Sumário da Consulta'),
(69549, 2110, 19, 'Consulta foi codificada'),
(69550, 2111, 19, 'Consulta:'),
(69551, 2113, 19, 'Consultas'),
(69552, 2114, 19, 'Consultas & Formulários'),
(69553, 2115, 19, 'Consultas & Formulários'),
(69554, 2116, 19, 'Consultas não autorizadas'),
(69555, 2117, 19, 'Relatório de Consultas'),
(69556, 2118, 19, 'Secção de Consultas'),
(69557, 2121, 19, 'Fim'),
(69558, 2122, 19, 'Fim (aaaa-mm-dd): '),
(69559, 2123, 19, 'Data do Fim'),
(69560, 2124, 19, 'Data do Fim'),
(69561, 2127, 19, 'Data do Fim'),
(69562, 2131, 19, 'Tempo do Fim'),
(69563, 2133, 19, 'Terminada a data de serviço aaaa-mm-dd'),
(69564, 2134, 19, 'Terminado DOS mm / dd / aaaa se deseja introduza um intervalo'),
(69565, 2136, 19, 'Endo Sangue anormal'),
(69566, 2137, 19, 'Endócrine'),
(69567, 2138, 19, 'Endoscopia'),
(69568, 2141, 19, 'Inglês'),
(69569, 2142, 19, 'Inglês '),
(69570, 2143, 19, 'Inglês (Indiano)'),
(69571, 2144, 19, 'Inglês (Defeito)'),
(69572, 2146, 19, 'Assegurar LibreEHR tem privilégios de gravação para o diretório'),
(69573, 2147, 19, 'ENT Descarga'),
(69574, 2148, 19, 'ENT Dor'),
(69575, 2149, 19, 'Execute em código de diagnóstico para excluir todas as facturas que não o contenham'),
(69576, 2151, 19, 'Execute aqui em corpo de carta'),
(69577, 2161, 19, 'Execute novo Estado'),
(69578, 2165, 19, 'Entre em seus critérios de pesquisa acima'),
(69579, 2168, 19, 'Ambiental'),
(69580, 2169, 19, 'Entrada de dados de EOB'),
(69581, 2170, 19, 'EOB Postando - Remessas Eletrônicas'),
(69582, 2171, 19, 'EOB Postando - Instruções'),
(69583, 2172, 19, 'EOB Postando - Fatura'),
(69584, 2173, 19, 'EOB Postando - Notas do Paciente'),
(69585, 2174, 19, 'EOB Postando - Procura'),
(69586, 2176, 19, 'Epilepsia'),
(69587, 2181, 19, 'Eliminar'),
(69588, 2182, 19, 'Ereção'),
(69589, 2183, 19, 'Erro'),
(69590, 2188, 19, 'Erro de seleção em "Gênero"'),
(69591, 2189, 19, 'Erro de seleção em "HIPAA"'),
(69592, 2190, 19, 'Erro de seleção em "Processo"'),
(69593, 2191, 19, 'Erro de seleção em "Portal de SMS"'),
(69594, 2192, 19, 'Erro de seleção em "Ordene Por"'),
(69595, 2194, 19, 'Erro de seleção em opções SIM ou NÂO'),
(69596, 2205, 19, 'erro enquanto registrando forma!'),
(69597, 2206, 19, 'Erro enquanto está guardando ão arquivo'),
(69598, 2208, 19, 'Erro enquanto está escrevendo ão arquivo'),
(69599, 2210, 19, 'Erro, o ficheiro não existe'),
(69600, 2211, 19, 'ERRO, Incapaz de colecionar dados do servidor'),
(69601, 2212, 19, 'Erro: incapaz de criar certificado cliente'),
(69602, 2213, 19, 'Erro: incapaz de criar certificado admin.p12'),
(69603, 2214, 19, 'Erro: incapaz de criar certificado ''Certificate Authority'''),
(69604, 2215, 19, 'Erro: incapaz de criar certificado ''Server'''),
(69605, 2216, 19, 'Erro: incapaz de abrir ficheiro'),
(69606, 2217, 19, 'Erro, ''User Certificate Authentication'' não está configurado no LibreEHR'),
(69607, 2218, 19, 'Erro. Tem de instalar o modulo ''Archive/Tar.php''.'),
(69608, 2219, 19, 'ERRO: não pude abrir ''table.sql'', formulário defeituoso?'),
(69609, 2222, 19, 'ERRO: campo'),
(69610, 2225, 19, 'Erro: senhas diferentes. Por favor confira.'),
(69611, 2226, 19, 'Erro: senhas diferentes. Por favor confira.'),
(69612, 2227, 19, 'Erro: o ficheiro não existe'),
(69613, 2230, 19, 'Erro: incapaz de criar o ficheiro para descarregar'),
(69614, 2235, 19, 'Erros'),
(69615, 2242, 19, 'Erythema:'),
(69616, 2247, 19, 'Utente habitual'),
(69617, 2249, 19, 'Etnia'),
(69618, 2250, 19, 'Etnia ou Raça'),
(69619, 2251, 19, 'Lista de Etnia-Raça (escrever,addonly opcional)'),
(69620, 2252, 19, 'ETIN'),
(69621, 2253, 19, 'Evento'),
(69622, 2254, 19, 'Início de Eventos'),
(69623, 2255, 19, 'Categoria de Eventos'),
(69624, 2256, 19, 'Data de Evento'),
(69625, 2257, 19, 'Descrição de Eventos'),
(69626, 2258, 19, 'Detalhes de Evento'),
(69627, 2259, 19, 'Evento não repete'),
(69628, 2260, 19, 'Duração de Evento'),
(69629, 2261, 19, 'Duração de Evento em minutos'),
(69630, 2262, 19, 'Evento Livre'),
(69631, 2263, 19, 'Localização de Evento'),
(69632, 2264, 19, 'Evento repete todo'),
(69633, 2265, 19, 'Evento repete em'),
(69634, 2266, 19, 'Tempo do começo de Evento'),
(69635, 2267, 19, 'título de Evento'),
(69636, 2268, 19, 'Título de Evento'),
(69637, 2269, 19, 'Site da Web de Evento'),
(69638, 2270, 19, 'Eventos'),
(69639, 2271, 19, 'Eventos para'),
(69640, 2272, 19, 'Evento aberto em nova janela'),
(69641, 2273, 19, 'cada um'),
(69642, 2274, 19, 'Cada um'),
(69643, 2275, 19, 'Cada 3 horas'),
(69644, 2276, 19, 'Cada 4 horas'),
(69645, 2277, 19, 'Cada 5 horas'),
(69646, 2278, 19, 'Cada 6 horas'),
(69647, 2279, 19, 'Cada 8 horas'),
(69648, 2280, 19, 'Cada Quarto'),
(69649, 2281, 19, 'Alternadamente'),
(69650, 2282, 19, 'Cada Terceiro'),
(69651, 2283, 19, 'Cada um, alternadamente, cada 3º, etc.'),
(69652, 2285, 19, 'Resultados do exame e testes'),
(69653, 2286, 19, 'Resultados do exame e testes'),
(69654, 2290, 19, 'Data do Exame'),
(69655, 2291, 19, 'Exemplo'),
(69656, 2292, 19, 'Exemplos'),
(69657, 2293, 19, 'Exames/Testes'),
(69658, 2295, 19, 'Excessivas Lágrimas'),
(69659, 2298, 19, 'Organização de provedor excessiva (EPO)'),
(69660, 2301, 19, 'Padrões de Exercício'),
(69661, 2302, 19, 'Padrões de exercício'),
(69662, 2304, 19, 'Sair da Administração'),
(69663, 2305, 19, 'Exp'),
(69664, 2306, 19, 'Expandir'),
(69665, 2307, 19, 'expandir'),
(69666, 2308, 19, 'Expandir Todos'),
(69667, 2311, 19, 'Vista Expandida'),
(69668, 2312, 19, 'Forma_encontro.pid esperado para ser '),
(69669, 2313, 19, 'Expiração'),
(69670, 2314, 19, 'Data de Expiração'),
(69671, 2315, 19, 'Expira'),
(69672, 2316, 19, 'expira em'),
(69673, 2317, 19, 'Exportar'),
(69674, 2318, 19, 'Exportar como CSV'),
(69675, 2319, 19, 'Exportar Configuração'),
(69676, 2322, 19, 'Exportar Demografia do Utente'),
(69677, 2326, 19, 'Seleção de Exportação para coleções'),
(69678, 2327, 19, 'Exporte para CSV'),
(69679, 2328, 19, 'Exporte para o sistema de faturamento externo'),
(69680, 2329, 19, 'estadia em países estrângeiros'),
(69681, 2330, 19, 'estadia em países estrângeiros'),
(69682, 2332, 19, 'Externo'),
(69683, 2336, 19, 'ID Externo'),
(69684, 2338, 19, 'Identificação Externo'),
(69685, 2339, 19, 'Somente Externo'),
(69686, 2342, 19, 'Indicação Externa'),
(69687, 2343, 19, 'Indicação Externa Followups'),
(69688, 2344, 19, 'Indicação Externa?'),
(69689, 2345, 19, 'Indicações Externa'),
(69690, 2346, 19, 'Extrair ficheiro zip'),
(69691, 2347, 19, 'A extrair...'),
(69692, 2348, 19, 'Exsudato:'),
(69693, 2349, 19, 'Irritação nos olhos'),
(69694, 2350, 19, 'Dor nos olhos'),
(69695, 2351, 19, 'Olhos Vermelhos'),
(69696, 2352, 19, 'Olhos'),
(69697, 2353, 19, 'S'),
(69698, 2354, 19, 'F/H Blood Problems'),
(69699, 2356, 19, 'Clínicas'),
(69700, 2357, 19, 'Clínica'),
(69701, 2358, 19, 'clínica'),
(69702, 2359, 19, 'Administração de Clínicas'),
(69703, 2361, 19, 'Código da Clínica'),
(69704, 2364, 19, 'Nome da Clínica'),
(69705, 2365, 19, 'NPI da Clínica'),
(69706, 2372, 19, 'Clínica:'),
(69707, 2374, 19, 'falha'),
(69708, 2375, 19, 'Falha'),
(69709, 2383, 19, 'erro'),
(69710, 2390, 19, 'História da Familia'),
(69711, 2391, 19, 'História da Familia de Glaucoma'),
(69712, 2392, 19, 'História da Familia:'),
(69713, 2395, 19, 'Tamanho da Familia'),
(69714, 2396, 19, 'Fantasia'),
(69715, 2400, 19, 'Pai'),
(69716, 2402, 19, 'Fadiga'),
(69717, 2403, 19, 'Cansado'),
(69718, 2404, 19, 'Fax'),
(69719, 2406, 19, 'Número do Fax'),
(69720, 2408, 19, 'Fax/Scan'),
(69721, 2409, 19, 'Envie Fax dentro'),
(69722, 2410, 19, 'Envie Fax Fora'),
(69723, 2411, 19, 'Propriedades'),
(69724, 2412, 19, 'Fev'),
(69725, 2413, 19, 'Fevereiro'),
(69726, 2414, 19, 'FECA'),
(69727, 2415, 19, 'Droga Federal ID'),
(69728, 2416, 19, 'NIF'),
(69729, 2417, 19, 'NIF'),
(69730, 2418, 19, 'Taxa'),
(69731, 2419, 19, 'taxa'),
(69732, 2420, 19, 'Taxa não é permitida'),
(69733, 2421, 19, 'Folha da Taxa'),
(69734, 2422, 19, 'Opções da Folha da Taxa'),
(69735, 2423, 19, 'Taxas'),
(69736, 2424, 19, 'Feminino'),
(69737, 2425, 19, 'AP Feminino'),
(69738, 2426, 19, 'preservativos femininos'),
(69739, 2427, 19, 'G Feminina'),
(69740, 2428, 19, 'LC Feminina'),
(69741, 2429, 19, 'P Feminina'),
(69742, 2430, 19, 'Sintomas Femeninos'),
(69743, 2431, 19, 'VSC Femenino'),
(69744, 2434, 19, 'Febre'),
(69745, 2435, 19, 'Febre:'),
(69746, 2436, 19, 'Problema no Sangue FH'),
(69747, 2437, 19, 'Fibroids'),
(69748, 2447, 19, 'Arquivo'),
(69749, 2455, 19, 'Quarto de Arquivo'),
(69750, 2456, 19, 'Arquive para transferir'),
(69751, 2458, 19, 'Arquivi com mesmo nome já existe neste local'),
(69752, 2459, 19, 'Nome do Arquivo'),
(69753, 2464, 19, 'Preencha aqui somente se enviarem notificação do e-mail para'),
(69754, 2467, 19, 'Preencha a Linha.'),
(69755, 2468, 19, 'Filtro'),
(69756, 2469, 19, 'Filtro para Constantes'),
(69757, 2473, 19, 'Filtros'),
(69758, 2474, 19, 'Final'),
(69759, 2475, 19, 'Diagnóstico Final'),
(69760, 2476, 19, 'Diagnóstico Final pelo especialista'),
(69761, 2478, 19, 'Financeiro'),
(69762, 2479, 19, 'Financeiro'),
(69763, 2481, 19, 'Relatório Financeiro - meus encontros'),
(69764, 2482, 19, 'Data da Revisão Financeira'),
(69765, 2484, 19, 'Procurar'),
(69766, 2485, 19, 'Procurar Hora'),
(69767, 2486, 19, 'Encontrar Compromissos Disponíveis'),
(69768, 2487, 19, 'Encontrar Utente'),
(69769, 2489, 19, 'Achados'),
(69770, 2490, 19, 'Achados por especialista'),
(69771, 2491, 19, 'Multa'),
(69772, 2495, 19, 'Primeiro'),
(69773, 2497, 19, 'Primeiro dia da Semana'),
(69774, 2498, 19, 'Primeiro Nome'),
(69775, 2499, 19, 'Primeiro nome'),
(69776, 2500, 19, 'Primeiro Nome'),
(69777, 2503, 19, 'Boa forma'),
(69778, 2507, 19, 'Boa forma para Jogar'),
(69779, 2508, 19, 'Fixar datas para encontro - qualquer encontro'),
(69780, 2509, 19, 'Consertar'),
(69781, 2511, 19, 'Flatulência'),
(69782, 2512, 19, 'Fluxo'),
(69783, 2516, 19, 'Vacinação de Infuenza'),
(69784, 2517, 19, 'Fluido e problema de eletrólito'),
(69785, 2518, 19, 'FMS'),
(69786, 2520, 19, 'Siga Manualmente'),
(69787, 2522, 19, 'Seguimento'),
(69788, 2524, 19, 'Razão do Seguimento'),
(69789, 2531, 19, 'Intolerância da Comida'),
(69790, 2532, 19, 'Pé'),
(69791, 2533, 19, 'Problemas no Pé'),
(69792, 2534, 19, 'Pé:'),
(69793, 2535, 19, 'Lesões de Futebol'),
(69794, 2537, 19, 'Relatório de Lesões de Futebol'),
(69795, 2538, 19, 'Tipo de Calçado'),
(69796, 2539, 19, 'para'),
(69797, 2540, 19, 'Para'),
(69798, 2543, 19, 'Queixas para a consulta'),
(69799, 2544, 19, 'Por exemplo:'),
(69800, 2552, 19, 'Referido por Organização/ por Clinico'),
(69801, 2555, 19, 'para:'),
(69802, 2559, 19, 'Antebraço'),
(69803, 2560, 19, 'Forma'),
(69804, 2561, 19, 'forma'),
(69805, 2564, 19, 'Formato'),
(69806, 2565, 19, 'formato'),
(69807, 2567, 19, 'Formato incorreto para NDC'),
(69808, 2571, 19, 'Ex-fumador'),
(69809, 2572, 19, 'Formulários'),
(69810, 2573, 19, 'Administração de Formulários'),
(69811, 2576, 19, 'Encaminhar páginas via Fax'),
(69812, 2577, 19, 'Encaminhado'),
(69813, 2579, 19, 'Quarto'),
(69814, 2581, 19, 'Fractura'),
(69815, 2582, 19, 'Fractura na Navicula'),
(69816, 2583, 19, 'Fractura lateral malleolus'),
(69817, 2584, 19, 'Fractura medial malleolus'),
(69818, 2585, 19, 'Fractura, Base do quinto metatarsal'),
(69819, 2587, 19, 'Francês'),
(69820, 2590, 19, 'Frequência'),
(69821, 2591, 19, 'Constipações Frequêntes'),
(69822, 2592, 19, 'Doença Frequente'),
(69823, 2593, 19, 'Sex'),
(69824, 2594, 19, 'Sexta'),
(69825, 2595, 19, 'De'),
(69826, 2596, 19, 'DE'),
(69827, 2597, 19, 'de'),
(69828, 2598, 19, 'Data De não pode ser superior à data Para.'),
(69829, 2599, 19, 'De:'),
(69830, 2600, 19, 'De: '),
(69831, 2601, 19, 'DE_CIDADE'),
(69832, 2603, 19, 'DE_FNOME'),
(69833, 2604, 19, 'DE_LNOME'),
(69834, 2605, 19, 'DE_MNOME'),
(69835, 2607, 19, 'DE_TELEFONEmovel'),
(69836, 2608, 19, 'DE_POSTAL'),
(69837, 2609, 19, 'DE_ESTADO'),
(69838, 2610, 19, 'DE_RUA'),
(69839, 2611, 19, 'DE_TÍTULO'),
(69840, 2612, 19, 'DE_VALEDICTORY'),
(69841, 2613, 19, 'Recepção'),
(69842, 2614, 19, 'Recibos da Recepção'),
(69843, 2615, 19, 'Relatório das Receitas da recepção'),
(69844, 2616, 19, 'Recpção Rec'),
(69845, 2617, 19, 'Frontal Direita:'),
(69846, 2619, 19, 'Nome Completo'),
(69847, 2620, 19, 'Caminho completo dos executáveis MySQL'),
(69848, 2621, 19, 'Caminho completo dos executáveis Perl'),
(69849, 2622, 19, 'Caminho completo da cópia de segurança do registo de eventos.'),
(69850, 2623, 19, 'Caminho completo dos ficheiros temporários.'),
(69851, 2624, 19, 'Jogo Completo'),
(69852, 2625, 19, 'Formação Completa'),
(69853, 2626, 19, 'Completamente Pago'),
(69854, 2633, 19, 'G'),
(69855, 2636, 19, 'Vesícula Biliar Condição'),
(69856, 2637, 19, 'Pedras na vesícula'),
(69857, 2638, 19, 'Período do Jogo'),
(69858, 2639, 19, 'Jogos'),
(69859, 2640, 19, 'Jogos Perdidos'),
(69860, 2641, 19, 'jogos/Eventos'),
(69861, 2642, 19, 'jogos/Eventos Perdidos'),
(69862, 2644, 19, 'Gastrites'),
(69863, 2645, 19, 'Dor de Gastro'),
(69864, 2646, 19, 'Gastrointestinal'),
(69865, 2647, 19, 'Relatório de Estatisticas GCAC'),
(69866, 2649, 19, 'Está perdendo a forma de visita GCAC'),
(69867, 2650, 19, 'Sexo'),
(69868, 2651, 19, 'Sexo '),
(69869, 2652, 19, 'Geral'),
(69870, 2655, 19, 'Serviço Geral de Categoria'),
(69871, 2657, 19, 'Criar e descarregar 1500 pedidos CMS'),
(69872, 2658, 19, 'Criar e descarregar 1500 pedidos HCFA'),
(69873, 2659, 19, 'Criar e descarregar X12'),
(69874, 2664, 19, 'Criar 1500 CMS'),
(69875, 2665, 19, 'Criar 1500 PDF CMS'),
(69876, 2667, 19, 'HCFA Geral'),
(69877, 2669, 19, 'Criar Carta'),
(69878, 2670, 19, 'Criar Carta a respeito de '),
(69879, 2677, 19, 'Criar Relatório'),
(69880, 2679, 19, 'Criar X12'),
(69881, 2680, 19, 'Criar Consulta X12'),
(69882, 2682, 19, 'Criado em'),
(69883, 2683, 19, 'Criado'),
(69884, 2684, 19, 'Genitourinary'),
(69885, 2687, 19, 'Alemão'),
(69886, 2691, 19, 'Obter HL7'),
(69887, 2692, 19, 'Glaucoma'),
(69888, 2693, 19, 'História Glaucoma da Familia'),
(69889, 2694, 19, 'Global'),
(69890, 2696, 19, 'ID Global'),
(69891, 2697, 19, 'Definições Gerais'),
(69892, 2698, 19, 'Gerais'),
(69893, 2700, 19, 'ir'),
(69894, 2701, 19, 'Ir'),
(69895, 2704, 19, 'Ir para'),
(69896, 2705, 19, 'Ir para a próxima semana'),
(69897, 2706, 19, 'Ir para Hoje'),
(69898, 2711, 19, 'Grau da Lesão'),
(69899, 2712, 19, 'Grau:'),
(69900, 2713, 19, 'gramas'),
(69901, 2714, 19, 'Total Principal'),
(69902, 2715, 19, 'Total Principal'),
(69903, 2722, 19, 'Grego'),
(69904, 2724, 19, 'Grupo'),
(69905, 2725, 19, 'Nome do Grupo'),
(69906, 2726, 19, 'Nomes do grupo não pode estár em branco'),
(69907, 2727, 19, 'Nomes do grupo não pode iniciar com números ou'),
(69908, 2728, 19, 'Nomes do grupo não pode iniciar com números'),
(69909, 2729, 19, 'Número do Grupo'),
(69910, 2731, 19, 'Grupo:'),
(69911, 2732, 19, 'Nome do Grupo'),
(69912, 2733, 19, 'Grupos e Controlo de Accesso'),
(69913, 2734, 19, 'Carta de Crescimento'),
(69914, 2735, 19, 'Carta de Crescimento'),
(69915, 2736, 19, 'gtts(gotas)'),
(69916, 2739, 19, 'Nome do Guardião'),
(69917, 2741, 19, 'Exame Ginecológico'),
(69918, 2742, 19, 'h'),
(69919, 2743, 19, 'h.s.'),
(69920, 2744, 19, 'Hepatite H/O'),
(69921, 2745, 19, 'Eliminado com sucesso. As subcategorias foram movidas abaixo'),
(69922, 2746, 19, 'Hematoma/ferida'),
(69923, 2747, 19, 'Estado de HAI'),
(69924, 2750, 19, 'Mão + Dedos'),
(69925, 2751, 19, 'Problema das Maõs'),
(69926, 2753, 19, 'w/ de Sofrimento'),
(69927, 2754, 19, 'foi anexo à visita'),
(69928, 2755, 19, 'expirou'),
(69929, 2761, 19, 'Actividades Perigosas'),
(69930, 2762, 19, 'Actividades perigosas'),
(69931, 2763, 19, 'HCFA deixou margens em pontos'),
(69932, 2764, 19, 'HCFA Margens'),
(69933, 2765, 19, 'HCFA tampam margens em pontos'),
(69934, 2767, 19, 'ele CaléndarioPostal '),
(69935, 2768, 19, 'Cabeça'),
(69936, 2769, 19, 'Circ Da Cabeça'),
(69937, 2770, 19, 'Circunferência da Cabeça'),
(69938, 2771, 19, 'Dor de Cabeça'),
(69939, 2772, 19, 'Dores de Cabeça'),
(69940, 2775, 19, 'Centro de saúde/clinica'),
(69941, 2776, 19, 'Organização de Manutenção da Saúde'),
(69942, 2777, 19, 'Organização de Manutenção da Saúde (HMO) Sistema de Saúde'),
(69943, 2778, 19, 'Perda da Audição'),
(69944, 2779, 19, 'Ataque Cardiaco'),
(69945, 2780, 19, 'Doença do Coração'),
(69946, 2781, 19, 'Insuficiência Cardíaca'),
(69947, 2782, 19, 'Problema do Coração'),
(69948, 2783, 19, 'Problemas do Coração'),
(69949, 2784, 19, 'Cirúrgia no Coração'),
(69950, 2785, 19, 'Transplante do Coração'),
(69951, 2786, 19, 'CORAÇÃO:'),
(69952, 2787, 19, 'Azia'),
(69953, 2788, 19, 'Calor ou Frio'),
(69954, 2789, 19, 'Calor Ou Frio'),
(69955, 2791, 19, 'Hebreu'),
(69956, 2793, 19, 'HEENT'),
(69957, 2794, 19, 'Altura'),
(69958, 2796, 19, 'Ajuda'),
(69959, 2797, 19, 'ajuda'),
(69960, 2798, 19, 'Hemattmesis'),
(69961, 2799, 19, 'Hematochezia'),
(69962, 2800, 19, 'Hematologic'),
(69963, 2801, 19, 'Hematúria'),
(69964, 2802, 19, 'Hemoglobina'),
(69965, 2804, 19, 'Hemoptysis'),
(69966, 2805, 19, 'Hepatites'),
(69967, 2806, 19, 'Hepatite A 1'),
(69968, 2807, 19, 'Hepatite A 2'),
(69969, 2808, 19, 'Hepatite B 1'),
(69970, 2809, 19, 'Hepatite B 2'),
(69971, 2810, 19, 'Hepatite B 3'),
(69972, 2811, 19, 'aqui'),
(69973, 2813, 19, 'Conserto da Hérnia'),
(69974, 2814, 19, 'Disco Herniado'),
(69975, 2815, 19, 'Herpes'),
(69976, 2816, 19, 'Hesitação'),
(69977, 2817, 19, 'heyyo.voçê esteve aqui para '),
(69978, 2818, 19, 'Hib 1'),
(69979, 2819, 19, 'Hib 2'),
(69980, 2820, 19, 'Hib 3'),
(69981, 2821, 19, 'Hib 4'),
(69982, 2822, 19, 'Esconder'),
(69983, 2823, 19, 'Administração de Eventos Escondidos'),
(69984, 2824, 19, 'Ocultar'),
(69985, 2825, 19, 'Ocultar detalhes'),
(69986, 2831, 19, 'Ocutar/Mostrar Colunas'),
(69987, 2833, 19, 'Alto'),
(69988, 2834, 19, 'Hipertensão'),
(69989, 2836, 19, 'Anca + virilha'),
(69990, 2837, 19, 'Anca e virilha'),
(69991, 2838, 19, 'Problemas de anca'),
(69992, 2839, 19, 'Substituição de anca'),
(69993, 2840, 19, 'Recebeu a Notícia HIPAA'),
(69994, 2842, 19, 'Hirsutismo / Estrias'),
(69995, 2843, 19, 'Hispânico'),
(69996, 2847, 19, 'Histórico'),
(69997, 2848, 19, 'Dados do Histórico'),
(69998, 2849, 19, 'Data do Histórico'),
(69999, 2851, 19, 'História de Murmúrio'),
(70000, 2852, 19, 'Histórico não autorizado'),
(70001, 2853, 19, 'História de Murmúrio do Coração'),
(70002, 2854, 19, 'Resultados'),
(70003, 2855, 19, 'VIH'),
(70004, 2858, 19, 'Visualizador HL7'),
(70005, 2862, 19, 'Pressione [Ctrl] para seleccionar vários itens'),
(70006, 2863, 19, 'Pressione Ctrl para seleccionar vários itens'),
(70007, 2864, 19, 'Pressione Ctrl para seleccionar múltiplas esquadras'),
(70008, 2865, 19, 'Início'),
(70009, 2866, 19, 'Telefone de Casa'),
(70010, 2867, 19, 'Número de Telefone de Casa'),
(70011, 2868, 19, 'Sem-abrigo ou similar?'),
(70012, 2869, 19, 'Sem-abrigo, etc'),
(70013, 2870, 19, 'Sem-abrigo, etc.'),
(70014, 2872, 19, 'Host Name'),
(70015, 2873, 19, 'Host Name cannot be empty'),
(70016, 2876, 19, 'Horas'),
(70017, 2878, 19, 'Como a Lesão Ocorreu?:'),
(70018, 2879, 19, 'Como a Lesão Ocorreu?:'),
(70019, 2881, 19, 'Quantos meses à frente para consultar os próximos eventos?'),
(70020, 2882, 19, 'HPI:'),
(70021, 2883, 19, 'HT'),
(70022, 2884, 19, 'HTML'),
(70023, 2892, 19, 'Hiperactive'),
(70024, 2893, 19, 'Hipertensão'),
(70025, 2896, 19, 'Hypertiroidismo'),
(70026, 2897, 19, 'Hipotiroidismo'),
(70027, 2898, 19, 'Histerectomia'),
(70028, 2899, 19, 'Eu'),
(70029, 2900, 19, 'Ocupado neste período'),
(70030, 2901, 19, 'Não tem Permissão para ler '),
(70031, 2902, 19, 'ICD'),
(70032, 2905, 19, 'ICD9'),
(70033, 2909, 19, 'ID'),
(70034, 2910, 19, 'Id'),
(70035, 2911, 19, 'ID não pode ficar em branco'),
(70036, 2913, 19, 'Idias'),
(70037, 2914, 19, 'identificado como'),
(70038, 2915, 19, 'Identificar(uma palavra)'),
(70039, 2919, 19, 'Se todos os dados para todas as colunas estão completas para esta forma'),
(70040, 2922, 19, 'Se nome, qualquer parte do último nome ou'),
(70041, 2923, 19, 'Se pagar por'),
(70042, 2927, 19, 'Se desempregado clique estudane'),
(70043, 2931, 19, 'Se você tiver escolhido para carregar as remessas eletrônicas, em seguida, a janela de pesquisa redisplays com as faturas correspondentes a partir do arquivo X12. Você pode clicar em qualquer um destes números de fatura (como descrito abaixo) se você deseja fazer as correções antes do envio de informações é aplicada. Para aplicar as alterações, clique no botão Arquivo Processo ERA, na parte inferior da página. Isto produzirá uma nova janela com um relatório detalhado.'),
(70044, 2932, 19, 'Se você digitou uma data de pagamento na página de pesquisa, esta irá substituir a data de lançamento de pagamentos e ajustes que são de outra tiradas do arquivo X12. Isso pode ser útil para fins de notificação, se você quiser que o seu relatório de receitas para usar a sua data de lançamento, em vez de a companhia de seguros da data de processamento. Note que isso vai afetar também as datas de pagamentos, antes e ajustes que são postos em créditos secundário.'),
(70045, 2933, 19, 'Se quiser mudar tipos de dados, acrescentar linhas ou colunas'),
(70046, 2937, 19, 'Doença'),
(70047, 2938, 19, 'IM'),
(70048, 2941, 19, 'Imagiologia'),
(70049, 2942, 19, 'Imunização'),
(70050, 2947, 19, 'Imunização: Lote No'),
(70051, 2948, 19, 'Imunização: Fabricante'),
(70052, 2951, 19, 'Imunização: Serviço'),
(70053, 2953, 19, 'Imunizações'),
(70054, 2954, 19, 'Imunize'),
(70055, 2955, 19, 'Imunológico'),
(70056, 2956, 19, 'Implantes'),
(70057, 2957, 19, 'Importar'),
(70058, 2961, 19, 'Importar certificado p/ o browser.'),
(70059, 2962, 19, 'Importe Configuração'),
(70060, 2964, 19, 'Importar Utente'),
(70061, 2965, 19, 'Importar Demografia do Utente'),
(70062, 2969, 19, 'Importado apartir da Contabilidade'),
(70063, 2972, 19, 'Melhorado'),
(70064, 2973, 19, 'em'),
(70065, 2974, 19, 'Em'),
(70066, 2975, 19, 'Em cada olho'),
(70067, 2976, 19, 'no olho esquerdo'),
(70068, 2977, 19, 'na narina'),
(70069, 2978, 19, 'Disponível'),
(70070, 2979, 19, 'no olho direto'),
(70071, 2980, 19, 'interno'),
(70072, 2981, 19, 'Inativo'),
(70073, 2982, 19, 'Dias Inactivos'),
(70074, 2986, 19, 'Incluir Checksum'),
(70075, 2987, 19, 'Inclusão Completa'),
(70076, 2988, 19, 'Incluir utilizadores inactivos'),
(70077, 2989, 19, 'Incluir não classificados'),
(70078, 2991, 19, 'Incluir dados vitais'),
(70079, 2992, 19, 'Incluir dados vitais?'),
(70080, 2994, 19, 'Rendimentos'),
(70081, 2996, 19, 'Imcompleto'),
(70082, 2997, 19, 'Aborto Terapeutico Incompleto'),
(70083, 2998, 19, 'Incontinênçia'),
(70084, 3001, 19, 'aumentado:'),
(70085, 3002, 19, 'Seguro contra dados'),
(70086, 3003, 19, 'Indeterminado'),
(70087, 3005, 19, 'Indica anormalidade'),
(70088, 3006, 19, 'Indicando se este assunto ativo corretamente'),
(70089, 3009, 19, 'Utentes Indigentes'),
(70090, 3010, 19, 'Relatório de Utente Indigente'),
(70091, 3011, 19, 'Indigentes'),
(70092, 3014, 19, 'Aborto Provocado'),
(70093, 3017, 19, 'Infecção / Abcesso'),
(70094, 3018, 19, 'Infecções'),
(70095, 3019, 19, 'Infert Acons'),
(70096, 3020, 19, 'Infertilidade'),
(70097, 3021, 19, 'Gripe 1'),
(70098, 3022, 19, 'Gripe 2'),
(70099, 3026, 19, 'Informação'),
(70100, 3027, 19, 'Info teste 1'),
(70101, 3028, 19, 'Info teste 2'),
(70102, 3029, 19, 'Info teste 3'),
(70103, 3030, 19, 'Info teste 4'),
(70104, 3031, 19, 'Info teste 5'),
(70105, 3032, 19, 'Info teste 6'),
(70106, 3034, 19, 'Inalações'),
(70107, 3035, 19, 'Inalações'),
(70108, 3037, 19, 'Utilizador Inicial'),
(70109, 3039, 19, 'Injetáveis'),
(70110, 3040, 19, 'Injecção'),
(70111, 3041, 19, 'Parte do Corpo Lesionada'),
(70112, 3042, 19, 'Dano fora'),
(70113, 3043, 19, 'Lesão'),
(70114, 3044, 19, 'Mecanismo de Lesão'),
(70115, 3045, 19, 'Relatório de Avaliação de Lesão'),
(70116, 3046, 19, 'Vigilância de Lesões'),
(70117, 3047, 19, 'Tipo de lesão'),
(70118, 3048, 19, 'Relac. c/ doença/lesão'),
(70119, 3051, 19, 'Campos de Entrada'),
(70120, 3056, 19, 'Ins ajustar'),
(70121, 3057, 19, 'Ins agregação'),
(70122, 3063, 19, 'Restituição Ins'),
(70123, 3064, 19, 'Ins Resumo'),
(70124, 3065, 19, 'Ins1'),
(70125, 3066, 19, 'Ins2'),
(70126, 3067, 19, 'Ins3'),
(70127, 3069, 19, 'Inserir falhou: '),
(70128, 3070, 19, 'Inserir eventos antigos em tabelas'),
(70129, 3072, 19, 'Insónia'),
(70130, 3074, 19, 'Inspeção'),
(70131, 3075, 19, 'Instabilidade /'),
(70132, 3079, 19, 'Instalar DB'),
(70133, 3081, 19, 'Instruido'),
(70134, 3082, 19, 'Instrução'),
(70135, 3084, 19, 'Instruções:'),
(70136, 3086, 19, 'Diabetes insulino dependente'),
(70137, 3087, 19, 'Subsistema'),
(70138, 3088, 19, 'subsistema'),
(70139, 3094, 19, 'Companias de Seguro'),
(70140, 3095, 19, 'Compania de Seguro'),
(70141, 3096, 19, 'Procurar/Acrescentar Compania de Seguro'),
(70142, 3098, 19, 'Data de Seguro'),
(70143, 3100, 19, 'Número do Seguro'),
(70144, 3103, 19, 'Entidade'),
(70145, 3107, 19, 'Conclusão de Entrada'),
(70146, 3108, 19, 'Data de Entrada'),
(70147, 3109, 19, 'Declínio Intelectual'),
(70148, 3113, 19, 'Erro Interno - Nenhuma página foi selecionada!'),
(70149, 3114, 19, 'Erro Interno - ID do Utente não foi inserido!'),
(70150, 3115, 19, 'Erro interno que acessa arquivos transferidos!'),
(70151, 3116, 19, 'Erro Interno!'),
(70152, 3117, 19, 'Erro Interno,não há ID de droga especificada!'),
(70153, 3119, 19, 'Erro Interno: Reivindicação '),
(70154, 3120, 19, 'Erro Interno: Encontro'''),
(70155, 3121, 19, 'Erro Interno: pid ou está perdendo o encontro.'),
(70156, 3123, 19, 'Interno Identificou (pid)'),
(70157, 3126, 19, 'Indicações Internas'),
(70158, 3128, 19, 'Dever Internacional'),
(70159, 3129, 19, 'Intérprete'),
(70160, 3130, 19, 'Precisou de Intérprete?'),
(70161, 3131, 19, 'Doenças Pulmonar Interstical'),
(70162, 3132, 19, 'Intervalo'),
(70163, 3137, 19, 'Intolerância'),
(70164, 3139, 19, 'Intramuscular'),
(70165, 3140, 19, 'Intravenously'),
(70166, 3141, 19, 'Introdução'),
(70167, 3149, 19, 'Inválido ou pagador em falta par código em falta '),
(70168, 3151, 19, 'Inválido Código de Servico'),
(70169, 3152, 19, 'Desegnação de fonte inválida'),
(70170, 3154, 19, 'InvAmt'),
(70171, 3155, 19, 'Inventário'),
(70172, 3159, 19, 'Inventário ntá disponivel nesta ordem.'),
(70173, 3160, 19, 'Inventário não está disponivel para esta ordem.'),
(70174, 3162, 19, 'Lista de Inventário'),
(70175, 3163, 19, 'Fatura'),
(70176, 3166, 19, 'Data da Fatura'),
(70177, 3167, 19, 'Fatura não tem nenhuma data!'),
(70178, 3173, 19, 'Fatura:'),
(70179, 3177, 19, 'IPPF SRH Data para'),
(70180, 3178, 19, 'IPPF Relatório de Estatística'),
(70181, 3180, 19, 'IPV 1'),
(70182, 3181, 19, 'IPV 2'),
(70183, 3182, 19, 'IPV 3'),
(70184, 3183, 19, 'IPV 4'),
(70185, 3185, 19, 'Batimento Cárdiaco Irregular'),
(70186, 3186, 19, 'Irritabilidade'),
(70187, 3187, 19, 'Irritação'),
(70188, 3191, 19, 'È um field exigido.'),
(70189, 3192, 19, 'È um nodo de raiz e não pode ser apagado.'),
(70190, 3197, 19, 'Não é valido (frações decimais são OK).'),
(70191, 3198, 19, 'PHP está usando o modo seguro?'),
(70192, 3216, 19, 'Assunto'),
(70193, 3217, 19, 'assunto'),
(70194, 3223, 19, 'Assuntos'),
(70195, 3224, 19, 'Questões (Lesões/Médicas/Alergias)'),
(70196, 3225, 19, 'Questões (Lesões/Médicas/Alergias):'),
(70197, 3226, 19, 'Assuntos e Encontros'),
(70198, 3227, 19, 'Assuntos e Encontros para'),
(70199, 3228, 19, 'Assuntos não autorizados'),
(70200, 3229, 19, 'Secção de Assuntos'),
(70201, 3231, 19, 'Carga'),
(70202, 3232, 19, 'carga'),
(70203, 3234, 19, 'Carga de artigo falhou'),
(70204, 3236, 19, 'IUD'),
(70205, 3237, 19, 'IV'),
(70206, 3238, 19, 'Jan'),
(70207, 3239, 19, 'Janeiro'),
(70208, 3241, 19, 'Icterícia'),
(70209, 3243, 19, 'Descrição de Trabalho'),
(70210, 3244, 19, 'ID do Trabalho'),
(70211, 3245, 19, 'Deslocação em comum'),
(70212, 3246, 19, 'Dor em Comum'),
(70213, 3247, 19, 'Deslocamentos em comum'),
(70214, 3248, 19, 'Jul'),
(70215, 3249, 19, 'Julho'),
(70216, 3250, 19, 'Jun'),
(70217, 3251, 19, 'Junho'),
(70218, 3252, 19, 'Só debaixo da informação verificada uma área azul'),
(70219, 3253, 19, 'Só as Minhas'),
(70220, 3255, 19, 'Justifique'),
(70221, 3256, 19, 'Justifique/Salvar'),
(70222, 3258, 19, 'k, aqui é o resto'),
(70223, 3265, 19, 'Palavras chaves'),
(70224, 3266, 19, 'kg'),
(70225, 3267, 19, 'kg/m^2'),
(70226, 3269, 19, 'Cancro do Rim'),
(70227, 3270, 19, 'Insuficiência Renal'),
(70228, 3271, 19, 'Infecções nos rins'),
(70229, 3272, 19, 'Pedras no Rim'),
(70230, 3273, 19, 'Transplante dos Rins'),
(70231, 3277, 19, 'Joelho'),
(70232, 3278, 19, 'Problemas no Joelho'),
(70233, 3279, 19, 'Substituição no Joelho'),
(70234, 3286, 19, 'Lab'),
(70235, 3295, 19, 'Relatório de Lab'),
(70236, 3303, 19, 'Etiqueta'),
(70237, 3304, 19, 'A etiqueta não pode estar em branco'),
(70238, 3307, 19, 'LabelCols deve ser um número entre 1 e 999'),
(70239, 3308, 19, 'Etiquetas'),
(70240, 3311, 19, 'Labs'),
(70241, 3312, 19, 'Dilaceração / condição da Pele'),
(70242, 3313, 19, 'Dilaceração/abrasão'),
(70243, 3316, 19, 'Idioma'),
(70244, 3317, 19, 'Código do Idioma'),
(70245, 3318, 19, 'Definição do Idioma acrescentado'),
(70246, 3320, 19, 'Lista de Idiomas (escrever, addonly opcional)'),
(70247, 3321, 19, 'Nome do Idioma'),
(70248, 3322, 19, 'Idioma:'),
(70249, 3325, 19, 'Último'),
(70250, 3326, 19, 'Data da Ùltima Atividade'),
(70251, 3328, 19, 'Data da Ùltima Conta'),
(70252, 3333, 19, 'Última Encontro'),
(70253, 3344, 19, 'Último Nome'),
(70254, 3345, 19, 'Último Nome'),
(70255, 3346, 19, 'Último Nome:'),
(70256, 3352, 19, 'Últimos Salvados'),
(70257, 3356, 19, 'Última actualização por'),
(70258, 3358, 19, 'Ùltima Visita'),
(70259, 3360, 19, 'Retorno Tarde (2-12 Mo)'),
(70260, 3361, 19, 'Malleolus Lateral'),
(70261, 3362, 19, 'Malleolus Lateral:'),
(70262, 3365, 19, 'Deslocou Lateral'),
(70263, 3373, 19, 'Baseado no Esquema'),
(70264, 3374, 19, 'Editar Esquema'),
(70265, 3375, 19, 'Grupos de Esquemas'),
(70266, 3376, 19, 'Estilo de Esquemas'),
(70267, 3378, 19, 'Formulários de Visita Baseados em Esquemas'),
(70268, 3379, 19, 'Esquemas'),
(70269, 3380, 19, 'lb'),
(70270, 3381, 19, 'Lbs'),
(70271, 3382, 19, 'LDL'),
(70272, 3383, 19, 'Deixa em branco se continuar ativo'),
(70273, 3385, 19, 'Deixe em branco para manter a senha inalterada.'),
(70274, 3386, 19, 'Deixa Mensagem com'),
(70275, 3387, 19, 'Deixa a Forma'),
(70276, 3390, 19, 'Esquerdo'),
(70277, 3391, 19, 'Ouvido Esquerdo'),
(70278, 3392, 19, 'ouvido esquerdo'),
(70279, 3394, 19, 'Esquerdo:'),
(70280, 3395, 19, 'Esquerdo: '),
(70281, 3396, 19, 'Dor da perna/Grampeado'),
(70282, 3397, 19, 'Legal'),
(70283, 3400, 19, 'Legenda:'),
(70284, 3401, 19, 'Comprimento'),
(70285, 3405, 19, 'Menos-informação privada (escrever,addonly opcional)'),
(70286, 3406, 19, 'Carta'),
(70287, 3407, 19, 'Gerador de Cartas'),
(70288, 3411, 19, 'Nível de urgência'),
(70289, 3412, 19, 'Responsabilidade'),
(70290, 3413, 19, 'Exame médico de Responsabilidade'),
(70291, 3414, 19, 'BI'),
(70292, 3423, 19, 'Estilo de vida'),
(70293, 3425, 19, 'Lágrima de Ligamento ou entorse'),
(70294, 3428, 19, 'Limites de Eventos'),
(70295, 3438, 19, 'Lista'),
(70296, 3439, 19, 'Caixa de Lista'),
(70297, 3440, 19, 'caixa de lista'),
(70298, 3441, 19, 'caixa de lista w/ add'),
(70299, 3442, 19, 'caixa de lista w/add'),
(70300, 3443, 19, 'Liste o Editor'),
(70301, 3445, 19, 'Lista de grupos'),
(70302, 3446, 19, 'Listar Companhias de Seguro'),
(70303, 3448, 19, 'Aliste artigos que não podem começar com um número.'),
(70304, 3449, 19, 'Aliste artigos que contém caracter(s) ilegal.'),
(70305, 3451, 19, 'Listas de lista'),
(70306, 3452, 19, 'Nomeda Lista'),
(70307, 3453, 19, 'Nome da Lista não pode começar com números.'),
(70308, 3454, 19, 'Lista de Receitas'),
(70309, 3458, 19, 'Listas'),
(70310, 3461, 19, 'LLL:'),
(70311, 3462, 19, 'LMP'),
(70312, 3464, 19, 'Carregue Definições'),
(70313, 3470, 19, 'A CARREGAR'),
(70314, 3472, 19, 'LOC'),
(70315, 3473, 19, 'Local'),
(70316, 3476, 19, 'Definições Regionais'),
(70317, 3477, 19, 'Localidade'),
(70318, 3478, 19, 'Localização'),
(70319, 3480, 19, 'Localização deste lote'),
(70320, 3481, 19, 'Localização não especificada'),
(70321, 3484, 19, 'Localização:'),
(70322, 3495, 19, 'Sessão'),
(70323, 3496, 19, 'Sessão iniciada como'),
(70324, 3497, 19, 'Sessão iniciada como: '),
(70325, 3498, 19, 'Sessão terminada.'),
(70326, 3500, 19, 'Entrar'),
(70327, 3501, 19, 'entrar'),
(70328, 3505, 19, 'Sair'),
(70329, 3506, 19, 'sair'),
(70330, 3507, 19, 'Eventos'),
(70331, 3508, 19, 'Visualizador de Eventos'),
(70332, 3510, 19, 'Procurar'),
(70333, 3511, 19, 'Lote'),
(70334, 3512, 19, 'Lote ID em falta!'),
(70335, 3513, 19, 'Número de Lote'),
(70336, 3514, 19, 'Baixo'),
(70337, 3516, 19, 'Perna mais baixa'),
(70338, 3519, 19, 'Espinha Lombar'),
(70339, 3520, 19, 'ALMOÇO'),
(70340, 3521, 19, 'Almoço'),
(70341, 3522, 19, 'Cancro do Pulmão'),
(70342, 3523, 19, 'Cirurgia de Cancro do Pulmão'),
(70343, 3524, 19, 'PULMÕES:'),
(70344, 3525, 19, 'pulmões:'),
(70345, 3526, 19, 'Lúpus'),
(70346, 3528, 19, 'S'),
(70347, 3529, 19, 'Categoria MA'),
(70348, 3535, 19, 'Endereço Principal'),
(70349, 3536, 19, 'Parte Superior do Ecrã'),
(70350, 3540, 19, 'Faça modificações para categorias recentes'),
(70351, 3542, 19, 'Tenha Certeza'),
(70352, 3545, 19, 'Mal-estar'),
(70353, 3548, 19, 'Masculino'),
(70354, 3549, 19, 'Preservativos Masculinos'),
(70355, 3550, 19, 'VSC Masculinas'),
(70356, 3552, 19, 'Mamograma'),
(70357, 3553, 19, 'Gerir'),
(70358, 3556, 19, 'Gerir Traduções'),
(70359, 3557, 19, 'Administração'),
(70360, 3561, 19, 'Manual'),
(70361, 3562, 19, 'Manual Postado'),
(70362, 3563, 19, 'Fabricante'),
(70363, 3565, 19, 'Mar'),
(70364, 3568, 19, 'Março'),
(70365, 3569, 19, 'Estado Civil'),
(70366, 3571, 19, 'Marque como faturado mas salta faturamento'),
(70367, 3572, 19, 'Marque como Clareado'),
(70368, 3573, 19, 'Marque como não faturou'),
(70369, 3575, 19, 'Marque como clareado'),
(70370, 3576, 19, 'Casado(a)'),
(70371, 3594, 19, 'Maxilar Direto:'),
(70372, 3603, 19, 'Maio'),
(70373, 3604, 19, 'MC'),
(70374, 3605, 19, 'mcg'),
(70375, 3612, 19, 'Malleolus mediano'),
(70376, 3613, 19, 'Exame médico'),
(70377, 3614, 19, 'Médico'),
(70378, 3615, 19, 'Aborto Médico'),
(70379, 3620, 19, 'problemas Médicos'),
(70380, 3623, 19, 'Problemas Médicos'),
(70381, 3624, 19, 'Registo Médico'),
(70382, 3625, 19, 'Registo Médico #'),
(70383, 3626, 19, 'Registos Médicos'),
(70384, 3632, 19, 'Médico/História (escrever,addonly opcional)'),
(70385, 3633, 19, 'Medicare Part B'),
(70386, 3635, 19, 'Medicamento'),
(70387, 3640, 19, 'Medicamentos'),
(70388, 3641, 19, 'Medicamentos:'),
(70389, 3642, 19, 'Unidades de medicinas'),
(70390, 3643, 19, 'Médio'),
(70391, 3645, 19, 'Relatório de Estatísticas da Associação de Membro'),
(70392, 3646, 19, 'Problemas de Memória'),
(70393, 3647, 19, 'Homem'),
(70394, 3648, 19, 'Homem e Mulher'),
(70395, 3649, 19, 'Só Homens'),
(70396, 3650, 19, 'Menarche'),
(70397, 3651, 19, 'Menopausa'),
(70398, 3652, 19, 'Fluxo Mestrual'),
(70399, 3653, 19, 'Frequência mestrual'),
(70400, 3654, 19, 'Doença mental'),
(70401, 3661, 19, 'Mensagen'),
(70402, 3666, 19, 'Estado da Mensagem'),
(70403, 3670, 19, 'MENSAGEN'),
(70404, 3671, 19, 'Mensagens'),
(70405, 3673, 19, 'Método'),
(70406, 3676, 19, 'Método de Destruição'),
(70407, 3679, 19, 'mg'),
(70408, 3680, 19, 'mg/1cc'),
(70409, 3681, 19, 'mg/2cc'),
(70410, 3682, 19, 'mg/3cc'),
(70411, 3683, 19, 'mg/4cc'),
(70412, 3684, 19, 'mg/5cc'),
(70413, 3685, 19, 'MG/DL'),
(70414, 3686, 19, 'Meio'),
(70415, 3687, 19, 'Nome do Meio'),
(70416, 3688, 19, 'Nome do meio'),
(70417, 3696, 19, 'Migrante ou trabalhador sazonal?'),
(70418, 3697, 19, 'Migrante/Sazonal'),
(70419, 3698, 19, 'Mil/CU.MM'),
(70420, 3702, 19, 'Mimique Tipo'),
(70421, 3704, 19, 'min'),
(70422, 3706, 19, 'pequenas articulações dolorosas+/- Sinovite'),
(70423, 3709, 19, 'minutos'),
(70424, 3710, 19, 'Minutos'),
(70425, 3712, 19, 'Outros'),
(70426, 3713, 19, 'Opções de facturação'),
(70427, 3714, 19, 'Opções de facturação para HCFA-1500'),
(70428, 3715, 19, 'Opções de Facturação para HCFA'),
(70429, 3716, 19, 'Diversos'),
(70430, 3717, 19, 'Perdido'),
(70431, 3719, 19, 'Campo obrigatório em falta'),
(70432, 3720, 19, 'Taxa Perdida'),
(70433, 3722, 19, 'Em Falta ou Inválido'),
(70434, 3723, 19, 'PID Perdida'),
(70435, 3725, 19, 'Golpe perdido depois de pagador em fonte para código '),
(70436, 3726, 19, 'Misturado'),
(70437, 3727, 19, 'ml'),
(70438, 3728, 19, 'MM/DD/AAAA'),
(70439, 3729, 19, 'mm/hg'),
(70440, 3731, 19, 'MMR 1'),
(70441, 3732, 19, 'MMR 2'),
(70442, 3733, 19, 'Telemóvel'),
(70443, 3734, 19, 'Telemóvel'),
(70444, 3735, 19, 'Mod'),
(70445, 3741, 19, 'Modificador'),
(70446, 3753, 19, 'Seg'),
(70447, 3754, 19, 'Seg a Sex'),
(70448, 3755, 19, 'Seg, Qua &amp; Sex'),
(70449, 3756, 19, 'Segunda'),
(70450, 3758, 19, 'Mês'),
(70451, 3759, 19, 'mês'),
(70452, 3760, 19, 'Mês'),
(70453, 3761, 19, 'Mes(es)'),
(70454, 3762, 19, 'Rendimento Mensal'),
(70455, 3763, 19, 'Meses'),
(70456, 3765, 19, 'Mais de 100 registos. Por favor restrinja os critérios.'),
(70457, 3766, 19, 'Mais de 50 resultados, por favor seja mais específico.'),
(70458, 3768, 19, 'Mais recente desde'),
(70459, 3771, 19, 'Mãe'),
(70460, 3772, 19, 'Nome da Mãe'),
(70461, 3774, 19, 'Boca'),
(70462, 3775, 19, 'Mover'),
(70463, 3776, 19, 'Mover Documento para a Categoria:'),
(70464, 3777, 19, 'Mover para Baixo'),
(70465, 3779, 19, 'Mover para Utente'),
(70466, 3780, 19, 'Mover para...'),
(70467, 3781, 19, 'Mover para Cima'),
(70468, 3783, 19, 'Sr.'),
(70469, 3785, 19, 'Sra.'),
(70470, 3786, 19, 'Srta.'),
(70471, 3796, 19, 'Ferramenta Multi-Idioma'),
(70472, 3797, 19, 'Áreas múltiplas'),
(70473, 3799, 19, 'Lotes múltiplos'),
(70474, 3802, 19, 'Multiracial'),
(70475, 3803, 19, 'Murmúrio:'),
(70476, 3804, 19, 'Dor Muscular'),
(70477, 3805, 19, 'Dores Musculares'),
(70478, 3806, 19, 'Vermelhidão Muscular'),
(70479, 3807, 19, 'Rigidez Muscular'),
(70480, 3808, 19, 'Inchaço Muscular'),
(70481, 3809, 19, 'Morno Musc'),
(70482, 3810, 19, 'Músculo'),
(70483, 3811, 19, 'Lesão Muscular'),
(70484, 3812, 19, 'Muscoesquelético'),
(70485, 3814, 19, 'Mutualmente Definido'),
(70486, 3815, 19, 'MVA'),
(70487, 3821, 19, 'N/D'),
(70488, 3822, 19, 'n/d'),
(70489, 3823, 19, 'Nome'),
(70490, 3825, 19, 'Nome (ver mais)'),
(70491, 3826, 19, 'Nome 1'),
(70492, 3827, 19, 'Nome 2'),
(70493, 3828, 19, 'Nome e Título de Administrador de Imunização'),
(70494, 3832, 19, 'Nome de companhia de seguros'),
(70495, 3833, 19, 'Nome do Clínico'),
(70496, 3835, 19, 'Nomeie Tradução'),
(70497, 3836, 19, 'Name/Value'),
(70498, 3837, 19, 'Nome:'),
(70499, 3838, 19, 'NARES:'),
(70500, 3839, 19, 'NARES: Direito normal'),
(70501, 3840, 19, 'Cor-de-rosa de mucosa nasal, midline de septum,'),
(70502, 3844, 19, 'Nacionalidade'),
(70503, 3852, 19, 'Náusea'),
(70504, 3854, 19, 'Navegação'),
(70505, 3862, 19, 'NDC'),
(70506, 3864, 19, 'Número NDC'),
(70507, 3866, 19, 'Pescoço'),
(70508, 3867, 19, 'Problemas no pescoço'),
(70509, 3868, 19, 'Pescoço movel'),
(70510, 3869, 19, 'Precise entrar em uma descrição'),
(70511, 3870, 19, 'Precise entrar em um Valor de Retorno'),
(70512, 3871, 19, 'Precise entrar em identificador'),
(70513, 3872, 19, 'Precise entrar em título'),
(70514, 3873, 19, 'Necessidades Auth'),
(70515, 3874, 19, 'Necessidades Justificam'),
(70516, 3875, 19, 'Necessidades faturamento secundário'),
(70517, 3876, 19, 'Negativo'),
(70518, 3877, 19, 'Negativos'),
(70519, 3880, 19, 'Dano de nervo'),
(70520, 3881, 19, 'Condição neural / dano de nervo'),
(70521, 3882, 19, 'Entorpecimento de Neuro'),
(70522, 3883, 19, 'Fraqueza de Neuro'),
(70523, 3884, 19, 'Neurologico'),
(70524, 3885, 19, 'Nunca'),
(70525, 3888, 19, 'Novo'),
(70526, 3889, 19, 'Novo =>'),
(70527, 3890, 19, 'Aceitantes novos'),
(70528, 3892, 19, 'Alergia nova'),
(70529, 3894, 19, 'Nova Marcação'),
(70530, 3895, 19, 'Categorias novas'),
(70531, 3896, 19, 'Categoria nova'),
(70532, 3897, 19, 'Clientes novos'),
(70533, 3898, 19, 'Consulta nova'),
(70534, 3900, 19, 'Jogo de Definição novo somou'),
(70535, 3901, 19, 'Documento novo'),
(70536, 3906, 19, 'Forma de Encontro nova'),
(70537, 3907, 19, 'Encontros novos não autorizaram'),
(70538, 3908, 19, 'Enctr novo'),
(70539, 3909, 19, 'Nova Clínica'),
(70540, 3912, 19, 'Grupo novo'),
(70541, 3913, 19, 'Informação de Grupo nova'),
(70542, 3916, 19, 'Limite novo de Eventos'),
(70543, 3917, 19, 'Lista nova'),
(70544, 3921, 19, 'Novo Utente'),
(70545, 3922, 19, 'NOVO UTENTE'),
(70546, 3923, 19, 'Consulta de Novo Utente'),
(70547, 3924, 19, 'Formulário de Novo Utente'),
(70548, 3925, 19, 'ID Novo Utente'),
(70549, 3926, 19, 'Novo Pagamento'),
(70550, 3928, 19, 'Pt novo'),
(70551, 3931, 19, 'Submissões novas'),
(70552, 3932, 19, 'Novo Utilizador'),
(70553, 3934, 19, 'Nova Visita'),
(70554, 3935, 19, 'Novo/Procura'),
(70555, 3961, 19, 'Jornal'),
(70556, 3962, 19, 'Próximo'),
(70557, 3964, 19, 'Próximo Dia'),
(70558, 3965, 19, 'Próximo Mês'),
(70559, 3966, 19, 'Próximo Mês (menu)'),
(70560, 3968, 19, 'Próxima Semana'),
(70561, 3969, 19, 'Próxima Semana (menu)'),
(70562, 3971, 19, 'Alcunha'),
(70563, 3973, 19, 'Suores Noturnos'),
(70564, 3974, 19, 'Nl ext genitália, mucosa de vag, cerviz,'),
(70565, 3975, 19, 'Não'),
(70566, 3976, 19, 'NÃO'),
(70567, 3977, 19, 'Sem acesso'),
(70568, 3978, 19, 'Não há lembretes'),
(70569, 3979, 19, 'Nenhum adenopathy (2 áreas requereram)'),
(70570, 3981, 19, 'Nenhum tenderness/masses anexo'),
(70571, 3985, 19, 'Nenhum sistema de faturamento é atualmente ativo'),
(70572, 3987, 19, 'Nenhuma Conta Achou para Incluir em OFX Export <br>'),
(70573, 3989, 19, 'Nenhum código foi especificado!'),
(70574, 3992, 19, 'Nenhuma Diagnose'),
(70575, 3995, 19, 'Nenhuma data de fim'),
(70576, 3996, 19, 'Nenhuma entrada achou, use a forma abaixo somar uma entrada.'),
(70577, 3997, 19, 'Sem erros'),
(70578, 3998, 19, 'Sem Eventos'),
(70579, 4001, 19, 'Nenhum grupo selecionado'),
(70580, 4002, 19, 'Sem hérnia'),
(70581, 4005, 19, 'Sem lesão/doença'),
(70582, 4006, 19, 'Nenhuma Companhia de Seguros'),
(70583, 4010, 19, 'Nenhum artigo foi selecionado!'),
(70584, 4027, 19, 'Nenhuma massa, ternura,'),
(70585, 4033, 19, 'Nenhum resultado'),
(70586, 4034, 19, 'Sem notas'),
(70587, 4035, 19, 'Nenhum ogrganomegoly'),
(70588, 4036, 19, 'Nenhuma abertura foi achada durante este período.'),
(70589, 4039, 19, 'Sem Sócio Achou'),
(70590, 4042, 19, 'Nenhum edema periférico'),
(70591, 4043, 19, 'Nenhuma Farmácia Encontrada'),
(70592, 4044, 19, 'Nenhuma Prescrição Encontrada'),
(70593, 4045, 19, 'Nenhum illness/injury apresentando'),
(70594, 4051, 19, 'Nenhum Clínico Encontrado'),
(70595, 4052, 19, 'Nenhuma lesão apressada ou anormal'),
(70596, 4053, 19, 'Nenhum registo encontrado'),
(70597, 4055, 19, 'Nenhum registro achou. Por favor amplie seus critério de pesquisa.'),
(70598, 4058, 19, 'Sem Resultados'),
(70599, 4060, 19, 'Sem Resultados'),
(70600, 4062, 19, 'Sem resultado, por favor tente novamente.'),
(70601, 4063, 19, 'Sem resultados, por favor tente novamente.'),
(70602, 4065, 19, 'Faltou'),
(70603, 4067, 19, 'Sem dor sinusal'),
(70604, 4068, 19, 'Sem ''pele de laranja'', nem nódulos mamários'),
(70605, 4071, 19, 'Sem dor, nem massas testiculares'),
(70606, 4072, 19, 'Sem roncos, nem sibilos'),
(70607, 4075, 19, 'Sem visita'),
(70608, 4076, 19, 'Não há registos'),
(70609, 4077, 19, 'Não, Cancelar'),
(70610, 4079, 19, 'Não:'),
(70611, 4080, 19, 'Nicturia'),
(70612, 4083, 19, 'Lesão inespecífica'),
(70613, 4085, 19, 'Diabetes não-insulino-dependente'),
(70614, 4087, 19, 'Exame médico de Non-SRH'),
(70615, 4088, 19, 'Non-SRH Non-Medical'),
(70616, 4089, 19, 'Nenhum'),
(70617, 4090, 19, 'nenhum'),
(70618, 4092, 19, 'Nenhum documentado'),
(70619, 4093, 19, 'Nenhuma das anteriores'),
(70620, 4095, 19, 'Diabetes não-insulino-dependente'),
(70621, 4096, 19, 'Nem'),
(70622, 4097, 19, 'Normal'),
(70623, 4098, 19, 'BL normal'),
(70624, 4099, 19, 'Exame Cardíaco normal:'),
(70625, 4100, 19, 'Exame Cardíaco normal: '),
(70626, 4101, 19, 'Exame Pulmonar normal:'),
(70627, 4102, 19, 'Exame Pulmonar normal: '),
(70628, 4103, 19, 'Consulta normal'),
(70629, 4104, 19, 'Orofaringe normal:'),
(70630, 4105, 19, 'Direito normal'),
(70631, 4106, 19, 'Direito normal:'),
(70632, 4107, 19, 'Visão normal'),
(70633, 4108, 19, 'normal:'),
(70634, 4112, 19, 'Norueguês'),
(70635, 4115, 19, 'Nariz'),
(70636, 4116, 19, 'Epistaxis'),
(70637, 4117, 19, 'nem letra nem numero'),
(70638, 4119, 19, 'Nem todos os campos são obrigatórios para todos os códigos ou tipos.'),
(70639, 4120, 19, 'Não Permitido'),
(70640, 4121, 19, 'Não é permitido apagar o grupo de Administradores'),
(70641, 4122, 19, 'Não Pode Editar'),
(70642, 4123, 19, 'Não é permitida a desativação de todos os objetos de segurança'),
(70643, 4124, 19, 'Não é permitido inactivar nada dos ''Administradores ACL'''),
(70644, 4125, 19, 'Não permitido remover o utilizador ''admin'' do grupo de Administradores'),
(70645, 4128, 19, 'Não está autorizado a acesseder o módulo ''PostCalendar'''),
(70646, 4129, 19, 'Não autorizado'),
(70647, 4132, 19, 'Não autorizado para esta equipa.'),
(70648, 4135, 19, 'Não Disponível'),
(70649, 4137, 19, 'Não facturado'),
(70650, 4139, 19, 'Não verificado'),
(70651, 4143, 19, 'Não Examinado'),
(70652, 4144, 19, 'Não Examinado:'),
(70653, 4145, 19, 'Não Examinado: '),
(70654, 4146, 19, 'não encontrado'),
(70655, 4148, 19, 'não encontrado!'),
(70656, 4152, 19, 'Não visto desde'),
(70657, 4157, 19, 'Nota'),
(70658, 4162, 19, 'Tipo de nota'),
(70659, 4168, 19, 'Nota: Este código não foi inserido por um utilizador autorizado. Apenas códigos autorizados podem ser enviados para a Rede de Facturação para processamento. Se deseja enviar códigos, selecione aqui um utilizador autorizado.'),
(70660, 4170, 19, 'NOTE: Ficheiros com nomes duplicados serão automaticamente remarcados (por ex., file.jpg will become file.1.jpg). Os nomes de ficheiros são considerados únicos por doente, não por categoria.'),
(70661, 4171, 19, 'NOTA: Arquivos transferindo com nomes duplicados causarão os arquivos a ser renomeados automaticamente. Por exemplo ''<i>file.jpg </ i> '' se tornará ''<i>file.jpg.1 </ i> ''. Filenames são considerados sem igual por doente, não por categoria.'),
(70662, 4172, 19, 'Notas'),
(70663, 4173, 19, 'Notas - qualquer consulta (escrita,addonly opcional)'),
(70664, 4174, 19, 'Notas - minhas consultas (write,addonly opcional)'),
(70665, 4175, 19, 'Notas não autorizadas'),
(70666, 4177, 19, 'Sem Registo'),
(70667, 4179, 19, 'Nenhuma alergia a importar'),
(70668, 4180, 19, 'Nenhuma prescrição a importar'),
(70669, 4182, 19, 'Nada foi seleccionado'),
(70670, 4184, 19, 'NOTE:: PostCalendar Submission/Modification'),
(70671, 4185, 19, 'Notificação'),
(70672, 4188, 19, 'Notificações'),
(70673, 4189, 19, 'Notifique Admin Sobre Evento Submission/Modification?'),
(70674, 4190, 19, 'Nov'),
(70675, 4191, 19, 'Novembro'),
(70676, 4192, 19, 'A enviar para:'),
(70677, 4193, 19, 'A imprimir'),
(70678, 4194, 19, 'Imprimindo agora declarações $stmt_count; os encontros serão atualizados.');
INSERT INTO `lang_definitions` VALUES
(70679, 4195, 19, 'Imprimindo agora declarações $stmt_count; as faturas serão atualizadas.'),
(70680, 4196, 19, 'Imprimindo agora declarações $stmt_count; os encontros não serão atualizados.'),
(70681, 4197, 19, 'Imprimindo agora declarações $stmt_count; as faturas não serão atualizadas.'),
(70682, 4198, 19, 'NPI'),
(70683, 4200, 19, 'Número'),
(70684, 4204, 19, 'Número de colunas em visão anual.'),
(70685, 4215, 19, 'Número de jogos ou eventos perdidos (se algum)'),
(70686, 4223, 19, 'Dormência'),
(70687, 4225, 19, 'Ordem de listagem numérica'),
(70688, 4229, 19, 'O.A.F.V.'),
(70689, 4230, 19, 'Sat O2'),
(70690, 4231, 19, 'Obesidade I'),
(70691, 4232, 19, 'Obesidade II'),
(70692, 4233, 19, 'Obesidade III'),
(70693, 4234, 19, 'Objetivo'),
(70694, 4237, 19, 'Ocupação'),
(70695, 4239, 19, 'Ocorrência'),
(70696, 4240, 19, 'Out'),
(70697, 4241, 19, 'Outubro'),
(70698, 4242, 19, 'OD'),
(70699, 4244, 19, 'de quantidade'),
(70700, 4245, 19, 'de comprimidos'),
(70701, 4246, 19, 'do mês todo'),
(70702, 4247, 19, 'Mensg Int'),
(70703, 4249, 19, 'Mensagens Internas'),
(70704, 4250, 19, 'Consulta'),
(70705, 4263, 19, 'Descendência'),
(70706, 4265, 19, 'pomada'),
(70707, 4267, 19, 'OK'),
(70708, 4269, 19, 'OK para unir o assunto de GCAC datado'),
(70709, 4270, 19, 'Velho(s)'),
(70710, 4272, 19, 'Clientes velhos'),
(70711, 4273, 19, 'Fractura velha não ou mal unida'),
(70712, 4283, 19, 'Omitir os utulizadores internos?'),
(70713, 4285, 19, 'omitir a autoassign'),
(70714, 4286, 19, 'no'),
(70715, 4288, 19, 'Disponível'),
(70716, 4289, 19, 'Encomenda'),
(70717, 4292, 19, 'Sempre que mudar a password tem de fazer Logout seguido de Login'),
(70718, 4297, 19, 'Apoio on-line'),
(70719, 4299, 19, 'Só Ativo'),
(70720, 4302, 19, 'só se faturando local'),
(70721, 4303, 19, 'Só Inativo'),
(70722, 4304, 19, 'Só Mina'),
(70723, 4310, 19, 'Início da Doença:'),
(70724, 4311, 19, 'Início da Doença: '),
(70725, 4312, 19, 'Início de Inchaço:'),
(70726, 4313, 19, 'Início/Internamento'),
(70727, 4316, 19, 'Aberto'),
(70728, 4324, 19, 'Base de Dados Actualizada'),
(70729, 4328, 19, 'LibreEHR exige para Javascript que execute autenticação de usuário.'),
(70730, 4329, 19, 'Utilizadores do LibreEHR'),
(70731, 4333, 19, 'Opção'),
(70732, 4336, 19, 'Opcional'),
(70733, 4343, 19, 'Nome de droga opcional, use% como um curinga'),
(70734, 4345, 19, 'Informação opcional sobre este evento'),
(70735, 4346, 19, 'Número de lote opcional, use% como um curinga'),
(70736, 4347, 19, 'ID numérico do utente opcional'),
(70737, 4348, 19, 'Código de procedimento opcional'),
(70738, 4351, 19, 'Or'),
(70739, 4352, 19, 'Oculus Uterque (bdz)'),
(70740, 4353, 19, 'ou escolhe'),
(70741, 4356, 19, 'Ou Fora Para'),
(70742, 4359, 19, 'Ou transfere arquivo de ERA:'),
(70743, 4360, 19, 'Oral'),
(70744, 4361, 19, 'Cor-de-rosa de mucosa oral, garganta claro'),
(70745, 4362, 19, 'Ordem'),
(70746, 4369, 19, 'Ordem deve ser um número entre 1 e 999'),
(70747, 4386, 19, 'Dano de órgão'),
(70748, 4387, 19, 'Organização'),
(70749, 4390, 19, 'Organizações'),
(70750, 4391, 19, 'X 3 orientado'),
(70751, 4392, 19, 'Original'),
(70752, 4396, 19, 'OROPHARYNX: '),
(70753, 4397, 19, 'Orthopnea'),
(70754, 4398, 19, 'OS'),
(70755, 4399, 19, 'Osetoarthritis'),
(70756, 4402, 19, 'Outro'),
(70757, 4403, 19, 'outro'),
(70758, 4404, 19, 'Outro (especifique)'),
(70759, 4406, 19, 'Outro Programa Federal'),
(70760, 4407, 19, 'Outro HCFA'),
(70761, 4408, 19, 'Outro dano especificou não em outro lugar'),
(70762, 4410, 19, 'outro mês'),
(70763, 4411, 19, 'Outros Programas Non-federais'),
(70764, 4412, 19, 'Outras Notas'),
(70765, 4413, 19, 'Outros Sintomas Pertinentes'),
(70766, 4414, 19, 'Outros Sintomas Pertinentes:'),
(70767, 4416, 19, 'Outro stress/Over usam dano'),
(70768, 4417, 19, 'Outro Cirúrgico'),
(70769, 4418, 19, 'Other/Generic Abortion-Related'),
(70770, 4421, 19, 'caso contrário você destruirá to/from de referências dados existentes.'),
(70771, 4422, 19, 'Ottawa Tornozelo Regras'),
(70772, 4423, 19, 'OU'),
(70773, 4424, 19, 'FORA'),
(70774, 4425, 19, 'Ausente'),
(70775, 4427, 19, 'Resultado'),
(70776, 4428, 19, 'Perspectiva'),
(70777, 4432, 19, 'Overuse'),
(70778, 4434, 19, 'Sobrepeso'),
(70779, 4435, 19, 'Escreva elaboradamente escolha de HIPAA'),
(70780, 4437, 19, 'Saturação de oxigênio'),
(70781, 4439, 19, 'P'),
(70782, 4440, 19, 'p.c.'),
(70783, 4441, 19, 'da tarde'),
(70784, 4442, 19, 'p.r.n.'),
(70785, 4444, 19, 'Paedeatric'),
(70786, 4445, 19, 'Página'),
(70787, 4446, 19, 'Páginas'),
(70788, 4447, 19, 'Pago'),
(70789, 4448, 19, 'Quantia pagada que você alocará'),
(70790, 4450, 19, 'Pagado Por'),
(70791, 4451, 19, 'Dor'),
(70792, 4453, 19, 'Palpitação'),
(70793, 4455, 19, 'Sujeira de papinha'),
(70794, 4458, 19, 'Paralisia'),
(70795, 4461, 19, 'Analise gramaticalmente HL7'),
(70796, 4463, 19, 'Sócio'),
(70797, 4472, 19, 'Senha'),
(70798, 4473, 19, 'Alterar Senha'),
(70799, 4475, 19, 'Senha Alterada.'),
(70800, 4480, 19, 'Password para Portal de SMS'),
(70801, 4481, 19, 'Password para Portal de SMS.'),
(70802, 4486, 19, 'Senha:'),
(70803, 4490, 19, 'Expirado'),
(70804, 4491, 19, 'Expirado'),
(70805, 4494, 19, 'Lista Consultas Anteriores'),
(70806, 4495, 19, 'Consultas Anteriores'),
(70807, 4496, 19, 'Consultas Anteriores e Documentos'),
(70808, 4498, 19, 'Colar Dados HL7'),
(70809, 4499, 19, 'Cole os dados para importar na área de texto abaixo:'),
(70810, 4502, 19, 'Remendo'),
(70811, 4514, 19, 'Utente'),
(70812, 4515, 19, 'utente'),
(70813, 4516, 19, 'UTENTE'),
(70814, 4521, 19, 'Alergias do utente'),
(70815, 4522, 19, 'Alergias do Utente'),
(70816, 4523, 19, 'Marcação Utente'),
(70817, 4528, 19, 'Processo doente ID'),
(70818, 4529, 19, 'Alta Utente'),
(70819, 4530, 19, 'Saída doente para '),
(70820, 4533, 19, 'Comunicação do Utente enviada'),
(70821, 4534, 19, 'Comunicação do Utente Enviada'),
(70822, 4539, 19, 'Dados Utente'),
(70823, 4544, 19, 'Documento Utente'),
(70824, 4547, 19, 'Consulta Utente'),
(70825, 4548, 19, 'Formulário Consulta Utente'),
(70826, 4549, 19, 'Consultas Utente'),
(70827, 4550, 19, 'Procura de Utentes'),
(70828, 4561, 19, 'Histórico do Utente'),
(70829, 4562, 19, 'Histórico do Utente / Estilo de vida'),
(70830, 4564, 19, 'ID Utente'),
(70831, 4566, 19, 'Cartão ID Utente'),
(70832, 4568, 19, 'Imunização do Utente'),
(70833, 4569, 19, 'Informação do Utente'),
(70834, 4570, 19, 'Instruções do Utente'),
(70835, 4571, 19, 'Distribuição de Seguro doente'),
(70836, 4572, 19, 'Relatório de Distribuição de Seguro doente'),
(70837, 4573, 19, 'Assuntos utente'),
(70838, 4581, 19, 'Lista de utentes'),
(70839, 4587, 19, 'Problemas Médicos do Utente'),
(70840, 4588, 19, 'Medicação do Utente'),
(70841, 4589, 19, 'Nome do Utente'),
(70842, 4590, 19, 'Nome e Endereço do Utente'),
(70843, 4595, 19, 'Nota do Utente'),
(70844, 4596, 19, 'Tipos de Nota do Utente'),
(70845, 4597, 19, 'Notas do Utente'),
(70846, 4598, 19, 'Notas do Utente (escrita opcional)'),
(70847, 4599, 19, 'Número do Utente'),
(70848, 4600, 19, 'Pagamento do Utente'),
(70849, 4608, 19, 'Relatório Impresso do Utente'),
(70850, 4609, 19, 'Relatório Registo do Utente'),
(70851, 4610, 19, 'Pedido de Acesso ao Registo do Utente'),
(70852, 4619, 19, 'Lembretes do Utente'),
(70853, 4620, 19, 'Relatório do Utente'),
(70854, 4621, 19, 'Pedidos do Utente'),
(70855, 4623, 19, 'Resultados do Utente'),
(70856, 4625, 19, 'Ecrã Procura/Criar Utente'),
(70857, 4629, 19, 'Resumo do Utente'),
(70858, 4630, 19, 'Transações do Utente'),
(70859, 4632, 19, 'doente(s) no banco de dados que partida a informação demográfica na que você entrou.'),
(70860, 4633, 19, 'Utente/Cliente'),
(70861, 4634, 19, 'Utente:'),
(70862, 4635, 19, 'IDUtente'),
(70863, 4636, 19, 'Utentes'),
(70864, 4638, 19, 'Pagamento'),
(70865, 4639, 19, 'Preste atenção para o "Terminado com" checkboxes. Depois que os seguros sejam marcados complete então nós começaremos pedindo para o doente que pagasse o equilíbrio restante; se você não marca tudo dos seguros complete então a quantia restante não será colecionada! Também se há um equilíbrio que o doente deveria pagar, então fixe a data de vencimento adequadamente, como isto afetará o idioma que se aparece em declarações pacientes.'),
(70866, 4640, 19, 'Pague Data:'),
(70867, 4643, 19, 'Pagador'),
(70868, 4644, 19, 'Tipo de pagador'),
(70869, 4645, 19, 'Pagando'),
(70870, 4647, 19, 'Pagamento'),
(70871, 4648, 19, 'pagamento'),
(70872, 4654, 19, 'Data de pagamento'),
(70873, 4655, 19, 'pagamento entrou em'),
(70874, 4660, 19, 'Método de pagamento'),
(70875, 4664, 19, 'Valor de pagamento para código '),
(70876, 4665, 19, 'Pagamentos'),
(70877, 4669, 19, 'PDF'),
(70878, 4672, 19, 'Pélvis e nádega'),
(70879, 4673, 19, 'Pemphigus'),
(70880, 4674, 19, 'Pendente'),
(70881, 4677, 19, 'Followup pendente'),
(70882, 4684, 19, 'Pennington LibreEHR v Firme'),
(70883, 4685, 19, 'Úlcera péptica'),
(70884, 4687, 19, 'por minuto'),
(70885, 4688, 19, 'Por Narina'),
(70886, 4689, 19, 'por narina'),
(70887, 4690, 19, 'Por Oris'),
(70888, 4691, 19, 'por oris'),
(70889, 4692, 19, 'Por Reto'),
(70890, 4693, 19, 'por reto'),
(70891, 4694, 19, 'Percentagem'),
(70892, 4697, 19, 'Per-centil'),
(70893, 4698, 19, 'Direito perfurado:'),
(70894, 4699, 19, 'Procurar'),
(70895, 4700, 19, 'Executar'),
(70896, 4705, 19, 'Período'),
(70897, 4708, 19, 'Periférico'),
(70898, 4712, 19, 'Pessoa'),
(70899, 4717, 19, 'Farmácias'),
(70900, 4718, 19, 'Farmácia'),
(70901, 4719, 19, 'Dispensário de farmácia'),
(70902, 4720, 19, 'Pheumothorax'),
(70903, 4729, 19, 'Telefone'),
(70904, 4730, 19, 'Lista de telefonemas'),
(70905, 4738, 19, 'Número de telefone'),
(70906, 4740, 19, 'Photophobia'),
(70907, 4741, 19, 'Fotos'),
(70908, 4742, 19, 'comprimido por PHP'),
(70909, 4744, 19, 'extraído por PHP'),
(70910, 4745, 19, 'controles de acesso de php-GACL são virados fora'),
(70911, 4746, 19, 'PHP-gacl não é instalado'),
(70912, 4747, 19, 'Exame físico'),
(70913, 4749, 19, 'Médico Request'),
(70914, 4750, 19, 'Assinatura do Médico'),
(70915, 4752, 19, 'Médicos'),
(70916, 4753, 19, 'usar'),
(70917, 4754, 19, 'Usar'),
(70918, 4755, 19, 'Escolha um tema CSS'),
(70919, 4756, 19, 'PID'),
(70920, 4757, 19, 'PID (Doença Inflamatória Pélvica)'),
(70921, 4758, 19, 'Tamanho de pílula'),
(70922, 4759, 19, 'Pílulas'),
(70923, 4765, 19, 'Placeholder'),
(70924, 4766, 19, 'Placeholder (Mantém ACLs vazio)'),
(70925, 4767, 19, 'Texto Simples'),
(70926, 4768, 19, 'Plano'),
(70927, 4771, 19, 'Nome de Plano'),
(70928, 4779, 19, 'Plano:'),
(70929, 4784, 19, 'Jogador'),
(70930, 4785, 19, 'Posição do Jogador'),
(70931, 4787, 19, 'Por favor altere a senha.'),
(70932, 4788, 19, 'Por favor escolha um ficheiro'),
(70933, 4789, 19, 'Por favor escolha um utente'),
(70934, 4790, 19, 'Por favor escolha uma seleção válida da lista.'),
(70935, 4791, 19, 'Por favor escolha uma seleção válida.'),
(70936, 4792, 19, 'Por favor escolha um valor para'),
(70937, 4797, 19, 'Por favor feche esta janela.'),
(70938, 4798, 19, 'Por favor compare o nome novo'),
(70939, 4802, 19, 'Por favor não aceite esta prescrição a menos que fosse recebido por facimile.'),
(70940, 4804, 19, 'Por favor não use seus browsers param ou botão de recarga enquanto esta página está correndo que a menos que mais de 10 atas decorressem, isto não fará o processo parar no servidor e consumirá recursos de uneccesary.'),
(70941, 4813, 19, 'Por favor entre em uma quantia monetária que usa só números e um ponto decimal.'),
(70942, 4815, 19, 'Por favor introduza um título!'),
(70943, 4823, 19, 'Por favor introduza a senha'),
(70944, 4826, 19, 'Por favor introduza a data'),
(70945, 4837, 19, 'Por favor note que isto pode levar um tempo muito longo, até várias atas, que seu browser de teia pode não se aparecer muito ativo durante este tempo mas gerando uma conta é um processo complicado e seu browser de teia somente está esperando por mais informação.'),
(70946, 4838, 19, 'Por favor Note: constantes são caso sensível e qualquer fio é permitido.'),
(70947, 4839, 19, 'Use somente carateres alfabéticos'),
(70948, 4840, 19, 'Use somente carateres alfabéticos sem espaços'),
(70949, 4841, 19, 'Por favor pague esta quantia'),
(70950, 4844, 19, 'Por favor redefina a senha.'),
(70951, 4849, 19, 'Por favor seleccione um idioma'),
(70952, 4850, 19, 'Seleccione Um Utente'),
(70953, 4858, 19, 'Por favor selecione uma razão de ajuste para código '),
(70954, 4859, 19, 'Por favor selecione um evento'),
(70955, 4865, 19, 'Por favor selecione as páginas desejadas para copiar ou remeter:'),
(70956, 4882, 19, 'PM'),
(70957, 4884, 19, 'Método de Pmt'),
(70958, 4885, 19, 'PND'),
(70959, 4886, 19, 'Pneumococcal Conjugate 1'),
(70960, 4887, 19, 'Pneumococcal Conjugate 2'),
(70961, 4888, 19, 'Pneumococcal Conjugate 3'),
(70962, 4889, 19, 'Pneumococcal Conjugate 4'),
(70963, 4891, 19, 'Vacinação de pneumonia'),
(70964, 4896, 19, 'Ponto de Serviço (POS)'),
(70965, 4897, 19, 'Política'),
(70966, 4899, 19, 'Número de política'),
(70967, 4901, 19, 'Polydypsia'),
(70968, 4902, 19, 'Pólipos'),
(70969, 4903, 19, 'Polyuria'),
(70970, 4904, 19, 'Falta de Apetite'),
(70971, 4905, 19, 'insuficiência circulatória'),
(70972, 4906, 19, 'Baixa Audição'),
(70973, 4908, 19, 'Antecedentes Pessoais'),
(70974, 4909, 19, 'Popups'),
(70975, 4918, 19, 'Português (brasileiro)'),
(70976, 4919, 19, 'Português (europeu)'),
(70977, 4920, 19, 'POS Code'),
(70978, 4926, 19, 'Poste Goteira Nasal'),
(70979, 4928, 19, 'Poste cirúrgico'),
(70980, 4929, 19, 'Poste a contabilidade e marque como faturado'),
(70981, 4933, 19, 'Cuidado de Post-Aborto'),
(70982, 4934, 19, 'Contracepção de Post-Aborto'),
(70983, 4935, 19, 'Post-Aborto Aconselhando'),
(70984, 4936, 19, 'Post-Aborto Followup'),
(70985, 4937, 19, 'Postal'),
(70986, 4938, 19, 'Código postal'),
(70987, 4939, 19, 'Código postal'),
(70988, 4941, 19, 'PostCalendar'),
(70989, 4942, 19, 'Administração de PostCalendar'),
(70990, 4943, 19, 'PostCalendar Categoria Colocações'),
(70991, 4944, 19, 'PostCalendar Colocações Globais'),
(70992, 4945, 19, 'Postado em'),
(70993, 4946, 19, 'Data postando'),
(70994, 4953, 19, 'Prática'),
(70995, 4955, 19, 'Pratique Colocações'),
(70996, 4956, 19, 'Médico'),
(70997, 4960, 19, 'Consulta de Pre-aborto'),
(70998, 4961, 19, 'Pre-aborto Aconselhando'),
(70999, 4962, 19, 'Categoria de Preferência'),
(71000, 4964, 19, 'Preferências'),
(71001, 4965, 19, 'Categoria de Evento preferida'),
(71002, 4966, 19, 'Idioma Preferido'),
(71003, 4967, 19, 'Farmácia Preferida'),
(71004, 4968, 19, 'Provedor Organization preferida (PPO)'),
(71005, 4969, 19, 'Preg Test'),
(71006, 4970, 19, 'Preliminar'),
(71007, 4972, 19, 'Pague'),
(71008, 4973, 19, 'Prescrição'),
(71009, 4977, 19, 'Rótulo de prescrição'),
(71010, 4978, 19, 'Relatório de Prescrição'),
(71011, 4979, 19, 'Prescrições'),
(71012, 4980, 19, 'Prescrições e Dispensações'),
(71013, 4981, 19, 'Prescrições e outras indicações'),
(71014, 4982, 19, 'Indicações de and/or de prescrições por especialista'),
(71015, 4983, 19, 'Prescrições Informam'),
(71016, 4984, 19, 'Prescriptions/Referrals'),
(71017, 4985, 19, 'Presente'),
(71018, 4986, 19, 'Reclamação apresentando'),
(71019, 4988, 19, 'Pressione Continuar'),
(71020, 4989, 19, 'Diagnose presumida'),
(71021, 4990, 19, 'Diagnose presumida por especialista'),
(71022, 4991, 19, 'Prev'),
(71023, 4998, 19, 'Preveja Evento'),
(71024, 5001, 19, 'Previamente'),
(71025, 5002, 19, 'Consultas prévias'),
(71026, 5003, 19, 'Dia prévio'),
(71027, 5004, 19, 'History/Screening prévio'),
(71028, 5005, 19, 'Mês prévio'),
(71029, 5006, 19, 'Semana prévia'),
(71030, 5007, 19, 'Preço'),
(71031, 5008, 19, 'Preço Descontando'),
(71032, 5009, 19, 'Nível de preços'),
(71033, 5010, 19, 'Nível de preços:'),
(71034, 5011, 19, 'Preços'),
(71035, 5012, 19, 'Primário'),
(71036, 5022, 19, 'Ins primário'),
(71037, 5023, 19, 'Seguro primário'),
(71038, 5024, 19, 'Dados de Seguro primários'),
(71039, 5025, 19, 'Provedor de Seguro primário'),
(71040, 5026, 19, 'Provedor primário'),
(71041, 5027, 19, 'Impressão'),
(71042, 5032, 19, 'Imprima Forma de Indicação Em branco'),
(71043, 5039, 19, 'Imprima Formato'),
(71044, 5040, 19, 'Imprima Quatro Painel'),
(71045, 5043, 19, 'Imprima Múltiplo'),
(71046, 5044, 19, 'Imprima Múltiplo para Enviar fax'),
(71047, 5047, 19, 'Imprima Página 1'),
(71048, 5048, 19, 'Imprima Página 2'),
(71049, 5052, 19, 'Imprima Registro'),
(71050, 5054, 19, 'Imprima Registro Atirado'),
(71051, 5057, 19, 'Imprima esta nota'),
(71052, 5058, 19, 'Imprima Esta Nota'),
(71053, 5060, 19, 'Imprima para Enviar fax'),
(71054, 5061, 19, 'Imprima Visão'),
(71055, 5062, 19, 'imprimível'),
(71056, 5063, 19, 'Versão imprimível'),
(71057, 5064, 19, 'Impresso'),
(71058, 5066, 19, 'Resultados imprimindo:'),
(71059, 5068, 19, 'Imprimindo saltaram; veja teste produzido dentro '),
(71060, 5069, 19, 'Auth anterior'),
(71061, 5070, 19, 'Forma de Autorização anterior'),
(71062, 5073, 19, 'Prioridade '),
(71063, 5074, 19, 'Privado'),
(71064, 5075, 19, 'Problema'),
(71065, 5077, 19, 'Lista de problema'),
(71066, 5079, 19, 'Problemas/Questões'),
(71067, 5086, 19, 'Procedimento'),
(71068, 5114, 19, 'Procedimentos'),
(71069, 5115, 19, 'Processo'),
(71070, 5125, 19, 'Processando'),
(71071, 5132, 19, 'Produtos'),
(71072, 5134, 19, 'Prof.'),
(71073, 5136, 19, 'Câncer prostático'),
(71074, 5138, 19, 'Exame prostático'),
(71075, 5139, 19, 'Problemas prostáticos'),
(71076, 5140, 19, 'Enlrgmt de w/o prostático, nódulos, oferta,'),
(71077, 5152, 19, 'Clínico'),
(71078, 5159, 19, 'Número do Clínico'),
(71079, 5162, 19, 'Clínico:'),
(71080, 5163, 19, 'Clínicos'),
(71081, 5164, 19, 'NPI dos Clínicos'),
(71082, 5165, 19, 'Clínicos Vêem Todo Calendário'),
(71083, 5166, 19, 'Prv'),
(71084, 5167, 19, 'PSA'),
(71085, 5168, 19, 'Psoríase'),
(71086, 5169, 19, 'Intimide psicologicamente Diagnose'),
(71087, 5170, 19, 'Intimide psicologicamente Medicamento'),
(71088, 5171, 19, 'Psiquiátrico'),
(71089, 5172, 19, 'Carta Breve psiquiátrica'),
(71090, 5173, 19, 'Diagnose psiquiátrica'),
(71091, 5174, 19, 'Exame psiquiátrico'),
(71092, 5175, 19, 'História psiquiátrica'),
(71093, 5176, 19, 'Entrada psiquiátrica'),
(71094, 5177, 19, 'Medicamento psiquiátrico'),
(71095, 5178, 19, 'Pt%'),
(71096, 5179, 19, 'Notas Ut.'),
(71097, 5180, 19, 'Notas Ut./Aut'),
(71098, 5181, 19, 'Overpaid de Pt'),
(71099, 5182, 19, 'Pt Paid'),
(71100, 5184, 19, 'Pt reembolsam'),
(71101, 5185, 19, 'Pt libertou'),
(71102, 5186, 19, 'Pt Report'),
(71103, 5187, 19, 'Estudante de PT, ou deixa espaço em branco'),
(71104, 5189, 19, 'PT_DOB'),
(71105, 5191, 19, 'PT_FNAME'),
(71106, 5192, 19, 'PT_LNAME'),
(71107, 5193, 19, 'PT_MNAME'),
(71108, 5201, 19, 'Público'),
(71109, 5205, 19, 'Pulmonar'),
(71110, 5206, 19, 'Pulso'),
(71111, 5213, 19, 'q.3h'),
(71112, 5214, 19, 'q.4h'),
(71113, 5215, 19, 'q.5h'),
(71114, 5216, 19, 'q.6h'),
(71115, 5217, 19, 'q.8h'),
(71116, 5218, 19, 'q.d.'),
(71117, 5219, 19, 'q.i.d.'),
(71118, 5220, 19, 'QOH'),
(71119, 5222, 19, 'Qty'),
(71120, 5223, 19, 'QTY'),
(71121, 5224, 19, 'Qualidade'),
(71122, 5226, 19, 'Quantidade'),
(71123, 5227, 19, 'Quantidade para NDC'),
(71124, 5228, 19, 'Quantidade Disponível'),
(71125, 5232, 19, 'Fila para processamento em lote de HCFA'),
(71126, 5233, 19, 'Fila para processamento em lote de HCFA e imprimindo'),
(71127, 5234, 19, 'Fila para processamento em lote de UB-92'),
(71128, 5235, 19, 'Fila para processamento em lote de UB-92 e imprimindo'),
(71129, 5236, 19, 'Feito fila'),
(71130, 5237, 19, 'Administração de Eventos feita fila'),
(71131, 5238, 19, 'Feito fila para'),
(71132, 5240, 19, 'Administração de Submissões feita fila'),
(71133, 5243, 19, 'R'),
(71134, 5245, 19, 'Raça'),
(71135, 5247, 19, 'Raça/Etnia'),
(71136, 5248, 19, 'Rádio'),
(71137, 5249, 19, 'Botões de rádio'),
(71138, 5252, 19, 'Erupções cutâneas'),
(71139, 5253, 19, 'Taxa'),
(71140, 5261, 19, 'Re-aberto'),
(71141, 5262, 19, 'Re-aberto'),
(71142, 5264, 19, 'Reações'),
(71143, 5265, 19, 'Ler'),
(71144, 5268, 19, 'Nome Profissional'),
(71145, 5270, 19, 'Motivo'),
(71146, 5271, 19, 'Causa do Óbito'),
(71147, 5272, 19, 'Causa do Óbito'),
(71148, 5274, 19, 'Razão para indicação'),
(71149, 5275, 19, 'Argumente para Visita'),
(71150, 5276, 19, 'Motivo/Formulário'),
(71151, 5277, 19, 'Recibo'),
(71152, 5278, 19, 'Recibo para Pagamento'),
(71153, 5279, 19, 'Recibo Gerou'),
(71154, 5280, 19, 'Recibos através de Relatório de Método de Pagamento'),
(71155, 5281, 19, 'Resumo de recibos'),
(71156, 5282, 19, 'Recebido'),
(71157, 5283, 19, 'Recebido Por'),
(71158, 5284, 19, 'Fac-símiles recebidos'),
(71159, 5287, 19, 'Receptor'),
(71160, 5288, 19, 'Administrador ID'),
(71161, 5300, 19, 'Recomendações'),
(71162, 5301, 19, 'Recomendações e tratamento'),
(71163, 5302, 19, 'Recomendações por especialista'),
(71164, 5314, 19, 'Registre Pagamento'),
(71165, 5317, 19, 'Registos'),
(71166, 5318, 19, 'registos encontrados'),
(71167, 5319, 19, 'registos encontrados.'),
(71168, 5322, 19, 'Retal'),
(71169, 5323, 19, 'Exame retal'),
(71170, 5324, 19, 'rectally'),
(71171, 5326, 19, 'Vermelhidão'),
(71172, 5327, 19, 'reduzido:'),
(71173, 5328, 19, 'Se refira'),
(71174, 5329, 19, 'Se refira Por'),
(71175, 5330, 19, 'Se refira Data'),
(71176, 5331, 19, 'Se refira'),
(71177, 5332, 19, 'Classificação de referência (nível de risco)'),
(71178, 5334, 19, 'Razão de referência'),
(71179, 5336, 19, 'Nome de Referer e assinatura'),
(71180, 5337, 19, 'Indicação'),
(71181, 5338, 19, 'Indicação Por'),
(71182, 5339, 19, 'Cartão de indicação'),
(71183, 5340, 19, 'Data de indicação'),
(71184, 5341, 19, 'Forma de indicação'),
(71185, 5342, 19, 'FORMA DE INDICAÇÃO'),
(71186, 5345, 19, 'Fonte de indicação'),
(71187, 5347, 19, 'Indicação Para'),
(71188, 5348, 19, 'Indicações'),
(71189, 5349, 19, 'Indicações Informam'),
(71190, 5350, 19, 'Se referido por'),
(71191, 5351, 19, 'Se referido Por'),
(71192, 5352, 19, 'Se referido'),
(71193, 5353, 19, 'Referrer'),
(71194, 5355, 19, 'Diagnose de Referrer'),
(71195, 5356, 19, 'Diagnose de Referrer'),
(71196, 5357, 19, 'O médico se referindo e prática'),
(71197, 5358, 19, 'Provedor se referindo'),
(71198, 5360, 19, 'Recargas'),
(71199, 5361, 19, 'recargas'),
(71200, 5362, 19, 'Reflexos normais'),
(71201, 5363, 19, 'Atualizar'),
(71202, 5369, 19, 'reg_re'),
(71203, 5370, 19, 'registro'),
(71204, 5372, 19, 'Registrado'),
(71205, 5373, 19, 'registrado'),
(71206, 5375, 19, 'Data de inscrição'),
(71207, 5376, 19, 'Forma de inscrição'),
(71208, 5377, 19, 'Reabilitação'),
(71209, 5381, 19, 'Relacionado com'),
(71210, 5382, 19, 'Relacionado'),
(71211, 5385, 19, 'Relation(s) / as Crianças'),
(71212, 5386, 19, 'Relações'),
(71213, 5387, 19, 'Relação'),
(71214, 5389, 19, 'Parentes'),
(71215, 5399, 19, 'Retransmita credenciais de Saúde estão perdendo desta conta do usuário.'),
(71216, 5400, 19, 'Retransmita ID para Saúde'),
(71217, 5403, 19, 'Religião'),
(71218, 5406, 19, 'Relogin'),
(71219, 5407, 19, 'Lembrete'),
(71220, 5408, 19, 'Recordar Clínica Seleccionada'),
(71221, 5416, 19, 'Remover'),
(71222, 5419, 19, 'Remover Grupo'),
(71223, 5420, 19, 'Remova Forma de Grupo'),
(71224, 5426, 19, 'Pedras renais'),
(71225, 5428, 19, 'Renomeie Grupo'),
(71226, 5429, 19, 'Fazendo'),
(71227, 5430, 19, 'Provedor fazendo'),
(71228, 5431, 19, 'Provedor Number fazendo'),
(71229, 5432, 19, 'Reordenar'),
(71230, 5433, 19, 'Reordene A'),
(71231, 5439, 19, 'Info repetindo:'),
(71232, 5440, 19, 'Repetições'),
(71233, 5444, 19, 'Data de resposta'),
(71234, 5445, 19, 'Responda De'),
(71235, 5446, 19, 'Relatório'),
(71236, 5449, 19, 'Informe por'),
(71237, 5458, 19, 'Totais de relatório'),
(71238, 5463, 19, 'Relatórios'),
(71239, 5467, 19, 'Pedido ignorou - processo de reivindicações já é corrente!'),
(71240, 5474, 19, 'Serviço pedido'),
(71241, 5477, 19, 'Obrigatório'),
(71242, 5479, 19, 'Campo Obrigatório em falta: Escolha o ficheiro EDI-271 para carregar'),
(71243, 5485, 19, 'RESERVADO'),
(71244, 5486, 19, 'Reservado'),
(71245, 5487, 19, 'Reservado para uso para definir Tempo de Férias Marcado'),
(71246, 5488, 19, 'Reservou para definir quando um provedor pode não ter compromissos disponíveis depois.'),
(71247, 5489, 19, 'Reservou para definir quando um evento não aconteceu como especificado.'),
(71248, 5490, 19, 'Todefine reservado quando um provedor pode compromissos de haveavailable depois.'),
(71249, 5496, 19, 'Solucionado'),
(71250, 5497, 19, 'Respiração'),
(71251, 5498, 19, 'Unlabored de esforço de respirador'),
(71252, 5499, 19, 'Respiratório'),
(71253, 5502, 19, 'Restringir Utilizadores a Clínicas'),
(71254, 5503, 19, 'Formação Restricta'),
(71255, 5504, 19, 'Resultado'),
(71256, 5506, 19, 'Estado do Resultado'),
(71257, 5510, 19, 'Resultados e'),
(71258, 5511, 19, 'Resultados encontrados Para a Pesquisa'),
(71259, 5515, 19, 'Resultados por página'),
(71260, 5517, 19, 'Exame de Retinal'),
(71261, 5518, 19, 'Direito retratado:'),
(71262, 5519, 19, 'Retorno'),
(71263, 5521, 19, 'Voltar ao calendário'),
(71264, 5527, 19, 'Valor de retorno'),
(71265, 5528, 19, 'Visita de retorno'),
(71266, 5529, 19, 'Devolvido para Jogar'),
(71267, 5534, 19, 'Revisão de PMH:'),
(71268, 5535, 19, 'Revisão de Sistemas'),
(71269, 5536, 19, 'Lista de Revisão de Sistemas'),
(71270, 5537, 19, 'Revisto'),
(71271, 5538, 19, 'Revisão'),
(71272, 5540, 19, 'Artrite de Rheumotoid'),
(71273, 5541, 19, 'Direito'),
(71274, 5542, 19, 'Orelha Direita'),
(71275, 5543, 19, 'orelha direita'),
(71276, 5545, 19, 'Direito:'),
(71277, 5546, 19, 'Zumbidos nos ouvidos'),
(71278, 5547, 19, 'Zumbidos nos ouvidos'),
(71279, 5549, 19, 'Factores de risco'),
(71280, 5550, 19, 'Nível de risco'),
(71281, 5551, 19, 'RLL:'),
(71282, 5552, 19, 'ROM'),
(71283, 5560, 19, 'Lista'),
(71284, 5561, 19, 'Via'),
(71285, 5562, 19, 'Via de administração, se aplicável'),
(71286, 5564, 19, 'Linhas'),
(71287, 5565, 19, 'RRR sem MOR'),
(71288, 5566, 19, 'Esfrega:'),
(71289, 5567, 19, 'Esfregas:'),
(71290, 5581, 19, 'Comando corrente: '),
(71291, 5582, 19, 'Ruptura'),
(71292, 5583, 19, 'Russo'),
(71293, 5584, 19, 'Rx'),
(71294, 5585, 19, 'RX'),
(71295, 5600, 19, 'S'),
(71296, 5601, 19, 'N. Utente'),
(71297, 5602, 19, 'S3:'),
(71298, 5603, 19, 'S4:'),
(71299, 5604, 19, 'SÁ * * por favor ler a licença lida o docs/license.txt ou visita * http://www.gnu.org/copyleft/gpl.html * * / / / == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == == = / / '),
(71300, 5605, 19, 'Venda'),
(71301, 5606, 19, 'Vendas'),
(71302, 5607, 19, 'Vendas por Artigo'),
(71303, 5608, 19, 'Vendas por Relatório de Produto'),
(71304, 5609, 19, 'Saliva'),
(71305, 5610, 19, 'Mesmo Dia'),
(71306, 5611, 19, 'Samoano'),
(71307, 5612, 19, 'Amostra'),
(71308, 5613, 19, 'Tipo de Sanção'),
(71309, 5617, 19, 'Sáb'),
(71310, 5618, 19, 'Sáb &amp; Dom'),
(71311, 5619, 19, 'Sábado'),
(71312, 5620, 19, 'Guardar'),
(71313, 5624, 19, 'Guardar e dispensar'),
(71314, 5626, 19, 'Guardar como Nova'),
(71315, 5627, 19, 'Guardar como nova nota'),
(71316, 5628, 19, 'Guardar Definições de Certificado'),
(71317, 5629, 19, 'Guardar Alterações'),
(71318, 5630, 19, 'Guardar Formulário'),
(71319, 5631, 19, 'Guardar Imunização'),
(71320, 5632, 19, 'Guardar Campo'),
(71321, 5633, 19, 'Guardar Grupo'),
(71322, 5634, 19, 'Guardar Lista'),
(71323, 5635, 19, 'Guardar Modelo'),
(71324, 5637, 19, 'Guardar Estatísticas do Utente'),
(71325, 5638, 19, 'Guardado com sucesso para o quadro de ID'),
(71326, 5639, 19, 'Guardar Operação'),
(71327, 5641, 19, 'Digitalizado'),
(71328, 5642, 19, 'Nota de Encontro digitalizada'),
(71329, 5644, 19, 'Escâner Em'),
(71330, 5645, 19, 'Horário'),
(71331, 5646, 19, 'Agenda da Clínica:'),
(71332, 5647, 19, 'NOTA ESCOLAR'),
(71333, 5648, 19, 'Escoliose'),
(71334, 5651, 19, 'SE'),
(71335, 5652, 19, 'SE Address'),
(71336, 5653, 19, 'Cidade de SE'),
(71337, 5654, 19, 'País de SE'),
(71338, 5655, 19, 'Localidade de SE'),
(71339, 5656, 19, 'SE Código Postal'),
(71340, 5657, 19, 'SE State'),
(71341, 5658, 19, 'Cep de SE'),
(71342, 5659, 19, 'Procurar'),
(71343, 5661, 19, 'procurar'),
(71344, 5662, 19, 'procurar novamente'),
(71345, 5664, 19, 'Procurar por:'),
(71346, 5665, 19, 'Procurar por'),
(71347, 5666, 19, 'Procurar por:'),
(71348, 5669, 19, 'Procurar ou Criar Utente'),
(71349, 5670, 19, 'Procurar Pagamento'),
(71350, 5672, 19, 'Procurar Resultados:'),
(71351, 5673, 19, 'Procurar Seleccionados'),
(71352, 5674, 19, 'O termo de procura não tem correspondência na base de dados'),
(71353, 5675, 19, 'Termo de procura deve ter pelo menos três carateres'),
(71354, 5677, 19, 'Procurar Eventos'),
(71355, 5678, 19, 'Procurar/Criar'),
(71356, 5679, 19, 'Procurar/Criar Entidade'),
(71357, 5680, 19, 'A procurar marcações'),
(71358, 5681, 19, 'A procurar...'),
(71359, 5682, 19, 'Uso de cinto de segurança'),
(71360, 5683, 19, 'Uso de cinto de segurança'),
(71361, 5684, 19, 'Segundo'),
(71362, 5687, 19, 'Secundário'),
(71363, 5688, 19, 'Seguro secundário'),
(71364, 5689, 19, 'Dados de Seguro secundários'),
(71365, 5690, 19, 'Provedor de Seguro secundário'),
(71366, 5698, 19, 'Segurança'),
(71367, 5699, 19, 'Ver Tudo'),
(71368, 5700, 19, 'Ver Autorizações'),
(71369, 5701, 19, 'Ver Quador-Crescimento'),
(71370, 5702, 19, 'Veja mensagens do último fixado de reivindicações geradas'),
(71371, 5704, 19, 'Visto desde então'),
(71372, 5707, 19, 'Ataques apopléticos'),
(71373, 5708, 19, 'Sel'),
(71374, 5709, 19, 'Seleccionar'),
(71375, 5710, 19, 'seleccionar'),
(71376, 5716, 19, 'Seleccionar Tudo'),
(71377, 5727, 19, 'Seleccionar data'),
(71378, 5729, 19, 'Seleccionar Diagnóstico'),
(71379, 5731, 19, 'Seleccionar Droga'),
(71380, 5732, 19, 'Seleccionar Drogas'),
(71381, 5736, 19, 'Campo seleccionado'),
(71382, 5737, 19, 'Campos Seleccionados'),
(71383, 5738, 19, 'Seleccione para imprimir'),
(71384, 5739, 19, 'Seleccione Imunizações'),
(71385, 5742, 19, 'Assunto seleto'),
(71386, 5744, 19, 'Seleccione Idioma'),
(71387, 5754, 19, 'Selecione os artigos de configuração para exportar'),
(71388, 5759, 19, 'Selecionar Utilizador'),
(71389, 5760, 19, 'Selecionar Utilizador da Lista'),
(71390, 5762, 19, 'Selecione Sim para confirmar apagamento de grupo'),
(71391, 5765, 19, 'Seleccionado'),
(71392, 5768, 19, 'Ego'),
(71393, 5769, 19, 'Pagamento de ego'),
(71394, 5771, 19, 'Enviar'),
(71395, 5774, 19, 'Envio em progresso'),
(71396, 5775, 19, 'Enviar mensagem'),
(71397, 5779, 19, 'Enviar este ficheiro'),
(71398, 5788, 19, 'Remetente'),
(71399, 5789, 19, 'Remetente ID'),
(71400, 5794, 19, 'Sensibilidades'),
(71401, 5795, 19, 'Sensibilidade:'),
(71402, 5796, 19, 'Normal de exame sensório'),
(71403, 5804, 19, 'Enviado prosperamente'),
(71404, 5807, 19, 'enviado para a impressora.'),
(71405, 5812, 19, 'Set'),
(71406, 5813, 19, 'Separado(a)'),
(71407, 5814, 19, 'Setembro'),
(71408, 5816, 19, 'Sequência'),
(71409, 5821, 19, 'Serviço'),
(71410, 5822, 19, 'Categoria Serviço'),
(71411, 5823, 19, 'Código Serviço'),
(71412, 5825, 19, 'Códigos Serviço'),
(71413, 5826, 19, 'Data de Serviço'),
(71414, 5827, 19, 'Data de Serviço:'),
(71415, 5829, 19, 'Localização do Serviço'),
(71416, 5831, 19, 'Serviço efectuado pelo especialista'),
(71417, 5834, 19, 'Serviços'),
(71418, 5835, 19, 'Serviços por Categoria'),
(71419, 5836, 19, 'Serviços efectuados'),
(71420, 5837, 19, 'Serviços Efectuados'),
(71421, 5838, 19, 'Serviços/Produtos'),
(71422, 5839, 19, 'Tipo de Sessão'),
(71423, 5840, 19, 'Define'),
(71424, 5846, 19, 'Define Como'),
(71425, 5847, 19, 'Define como Padrão'),
(71426, 5849, 19, 'Definições'),
(71427, 5851, 19, 'Enxaqueca severa'),
(71428, 5853, 19, 'Intensidade da Dor'),
(71429, 5854, 19, 'Intensidade da Dor:'),
(71430, 5855, 19, 'Sexo'),
(71431, 5856, 19, 'Doença Sexualmente Transmitida'),
(71432, 5859, 19, 'A Partilhar'),
(71433, 5864, 19, 'Falta de ar'),
(71434, 5865, 19, 'Falta De Ar'),
(71435, 5866, 19, 'Falta De Ar 2'),
(71436, 5867, 19, 'Registro de tiro'),
(71437, 5868, 19, 'Registro de tiro a partir de:'),
(71438, 5870, 19, 'deveria estar como nnnnn-nnnn-nn'),
(71439, 5871, 19, 'Deve ter duas letras'),
(71440, 5874, 19, 'Ombro'),
(71441, 5875, 19, 'Ombro + clavícula'),
(71442, 5876, 19, 'Problemas no ombro'),
(71443, 5877, 19, 'Ver'),
(71444, 5883, 19, 'Mostrar Todas as Transacções'),
(71445, 5884, 19, 'Ver como Ocupado'),
(71446, 5885, 19, 'Mostrar só as Autorizadas'),
(71447, 5886, 19, 'Ver Períodos Disponíveis'),
(71448, 5887, 19, 'Mostrar medidas US e métricas (defeito: métricas)'),
(71449, 5888, 19, 'Mostrar medidas US e métricas (defeito: US)'),
(71450, 5889, 19, 'Ver Detalhes'),
(71451, 5891, 19, 'Ver Gráfico'),
(71452, 5892, 19, 'Espetáculo que paira texto de evento mouseover aceso?'),
(71453, 5893, 19, 'Espetáculo quantos eventos páginas de admin acesas?'),
(71454, 5897, 19, 'Só mostrar métricas'),
(71455, 5898, 19, 'Mostrar Notas'),
(71456, 5901, 19, 'Mostrar Notas do Utetnes'),
(71457, 5906, 19, 'Relatório de espetáculo'),
(71458, 5907, 19, 'Ligações de search/submit de espetáculo em bloco?'),
(71459, 5913, 19, 'Mostre Unbilled Only'),
(71460, 5914, 19, 'Só mostrar US'),
(71461, 5920, 19, 'Irmãos'),
(71462, 5921, 19, 'Sickle Cell'),
(71463, 5922, 19, 'Sig'),
(71464, 5923, 19, 'Sigmoid/Colonoscopy'),
(71465, 5927, 19, 'Assinatura'),
(71466, 5929, 19, 'Assinatura:'),
(71467, 5932, 19, 'Inchação significante:'),
(71468, 5937, 19, 'Desde então'),
(71469, 5938, 19, 'Cordialmente,'),
(71470, 5940, 19, 'Solteiro(a)'),
(71471, 5941, 19, 'Lista de selecção única'),
(71472, 5942, 19, 'Lista de selecção única com possibilidade de adicionar'),
(71473, 5946, 19, 'sinusite'),
(71474, 5947, 19, 'Cirurgia de seio'),
(71475, 5948, 19, 'bombeamento do SEIO:'),
(71476, 5949, 19, 'Sinusite'),
(71477, 5956, 19, 'Tamanho'),
(71478, 5957, 19, 'Tamanho deve ser um número entre 1 e 999'),
(71479, 5958, 19, 'Size/List'),
(71480, 5959, 19, 'Pele'),
(71481, 5960, 19, 'carcinoma da pele'),
(71482, 5961, 19, 'Doença de pele'),
(71483, 5962, 19, 'Pele Outro'),
(71484, 5967, 19, 'Padrões de Sono'),
(71485, 5968, 19, 'Padrões de sono'),
(71486, 5969, 19, 'Dormindo'),
(71487, 5970, 19, 'Eslovaco'),
(71488, 5972, 19, 'Sm dívida w/o'),
(71489, 5973, 19, 'Esconderijo de Smarty foi clareado'),
(71490, 5974, 19, 'Fumador, estado actual desconhecido'),
(71491, 5976, 19, 'Fumador'),
(71492, 5978, 19, 'Portal de SMS'),
(71493, 5979, 19, 'Portal de SMS chave de API'),
(71494, 5983, 19, 'Notificação de SMS'),
(71495, 5985, 19, 'SMS enviam antes'),
(71496, 5987, 19, 'Texto de SMS, Etiqueta Utilizável,: * * * NOME * * *, * * * o PROVEDOR * * *, * * * DATA * * *, * * * STARTTIME * * *, * * * ENDTIME***<br> i.e. Querido * * * NOME * * *'),
(71497, 5988, 19, 'SMS/Email Alert Colocações'),
(71498, 6004, 19, 'Ronco'),
(71499, 6005, 19, 'SOAP'),
(71500, 6006, 19, 'Dificuldades sociais'),
(71501, 6009, 19, 'História social:'),
(71502, 6010, 19, 'Número de previdência social'),
(71503, 6011, 19, 'solução'),
(71504, 6013, 19, 'Contexto somático'),
(71505, 6014, 19, 'Algumas autorizações não foram exibidas. Faça tique-taque aqui para ver tudo'),
(71506, 6015, 19, 'Alguns códigos não foram exibidos.'),
(71507, 6016, 19, 'Alguns encontros não foram exibidos. Faça tique-taque aqui para ver tudo.'),
(71508, 6018, 19, 'Algumas notas não foram exibidas.'),
(71509, 6020, 19, 'algumas palavras'),
(71510, 6026, 19, 'Dor de garganta'),
(71511, 6028, 19, 'Erro ao carregar o ficheiro'),
(71512, 6029, 19, 'Ordenar por'),
(71513, 6030, 19, 'Ordenar Por'),
(71514, 6031, 19, 'Ordenar por Checksum'),
(71515, 6032, 19, 'Ordenar por Comentários'),
(71516, 6033, 19, 'Ordenar por Critério'),
(71517, 6034, 19, 'Ordenar por data'),
(71518, 6035, 19, 'Ordenar por data/hora'),
(71519, 6036, 19, 'Ordenar por Evento'),
(71520, 6037, 19, 'Ordenar por Grupo'),
(71521, 6040, 19, 'Ordenar por ID Utente'),
(71522, 6041, 19, 'Ordenar por Sucesso'),
(71523, 6043, 19, 'Ordenar por Utilizador'),
(71524, 6044, 19, 'Ordenar por vacina'),
(71525, 6045, 19, 'Ordem Descendente'),
(71526, 6046, 19, 'Ordenar Resultado por'),
(71527, 6047, 19, 'Ordem Ascendente'),
(71528, 6048, 19, 'Fonte'),
(71529, 6049, 19, 'Ficheiro Fonte'),
(71530, 6051, 19, 'Fonte está perdendo para código '),
(71531, 6057, 19, 'Fonte:'),
(71532, 6060, 19, 'Espaço'),
(71533, 6062, 19, 'Espanhol'),
(71534, 6068, 19, 'Especialista'),
(71535, 6069, 19, 'Nome do especialista e assinatura'),
(71536, 6071, 19, 'Especialidade'),
(71537, 6072, 19, 'Sistemas de especialidade'),
(71538, 6073, 19, 'Especialidade:'),
(71539, 6074, 19, 'Específico'),
(71540, 6078, 19, 'Serviço específico'),
(71541, 6092, 19, 'Notas'),
(71542, 6093, 19, 'Espermicidas'),
(71543, 6094, 19, 'Splenectomy'),
(71544, 6095, 19, 'Cônjuge'),
(71545, 6097, 19, 'Cuspe'),
(71546, 6098, 19, 'Cuspe:'),
(71547, 6099, 19, 'SQ'),
(71548, 6102, 19, 'Esquadra'),
(71549, 6103, 19, 'Sociedade de esquadra'),
(71550, 6104, 19, 'Esquadras'),
(71551, 6105, 19, 'SRH'),
(71552, 6106, 19, 'SRH - Controle de natalidade'),
(71553, 6107, 19, 'SRH Non Controle de natalidade'),
(71554, 6108, 19, 'Indicações de SRH'),
(71555, 6109, 19, 'SRH Visit Forma'),
(71556, 6111, 19, 'N. Ut.'),
(71557, 6113, 19, 'SSN'),
(71558, 6114, 19, 'Estabilidade'),
(71559, 6116, 19, 'Defeito'),
(71560, 6117, 19, 'Código de Defeito'),
(71561, 6122, 19, 'Nome de Defeito'),
(71562, 6124, 19, 'Início'),
(71563, 6125, 19, 'Início (aaaa-mm-dd): '),
(71564, 6128, 19, 'Data de Início'),
(71565, 6129, 19, 'Data de Início Nesta Clínica'),
(71566, 6130, 19, 'Data de início deve ser maior que a Data de Fim'),
(71567, 6131, 19, 'Data de início:'),
(71568, 6132, 19, 'Data de Início:'),
(71569, 6133, 19, 'Hora de Início'),
(71570, 6134, 19, 'Data de Início'),
(71571, 6135, 19, 'estd'),
(71572, 6136, 19, 'Distrito'),
(71573, 6141, 19, 'Lista estatal (write,addonly opcional)'),
(71574, 6144, 19, 'State/Locality'),
(71575, 6145, 19, 'State/Parish'),
(71576, 6151, 19, 'Demografia'),
(71577, 6152, 19, 'Estatísticas'),
(71578, 6153, 19, 'Estado'),
(71579, 6156, 19, 'Status quo'),
(71580, 6158, 19, 'STD/AIDS Couns'),
(71581, 6159, 19, 'Stength e Condicionando'),
(71582, 6169, 19, 'articulações duras'),
(71583, 6170, 19, 'Dureza'),
(71584, 6172, 19, 'Dores de estômago'),
(71585, 6175, 19, 'rigidez muscular'),
(71586, 6176, 19, 'Fluxo'),
(71587, 6177, 19, 'Rua'),
(71588, 6178, 19, 'Endereço'),
(71589, 6179, 19, 'Rua e Número'),
(71590, 6180, 19, 'Força'),
(71591, 6182, 19, 'amigdalite streptococica'),
(71592, 6183, 19, 'Fratura de tensão'),
(71593, 6184, 19, 'Teste de stress'),
(71594, 6185, 19, 'Golpe'),
(71595, 6186, 19, 'Uma senha forte tem pelo menos 8 caracteres e pelo três de: uma letra minúscula, uma maiúscula, um caractere especial'),
(71596, 6189, 19, 'Sub-categoria'),
(71597, 6190, 19, 'Sub-Total'),
(71598, 6191, 19, 'Subcategoria'),
(71599, 6192, 19, 'Subcategoria'),
(71600, 6193, 19, 'subcutâneo'),
(71601, 6195, 19, 'Subjetivo'),
(71602, 6196, 19, 'Sublingual'),
(71603, 6197, 19, 'sublingual'),
(71604, 6198, 19, 'Submeter'),
(71605, 6199, 19, 'submeter'),
(71606, 6200, 19, 'Submeter Tudo'),
(71607, 6202, 19, 'Submeter Evento'),
(71608, 6203, 19, 'submeter formulário'),
(71609, 6204, 19, 'Submeter Conteúdo Seleccionado'),
(71610, 6205, 19, 'submetido'),
(71611, 6206, 19, 'Submetido por'),
(71612, 6208, 19, 'Subscritor'),
(71613, 6209, 19, 'Endereço de subscritor'),
(71614, 6213, 19, 'Empregador de subscritor'),
(71615, 6214, 19, 'Empregador de subscritor (SE)'),
(71616, 6215, 19, 'Subscritor Empregador Address'),
(71617, 6216, 19, 'Subscritor Empregador City'),
(71618, 6217, 19, 'Subscritor Empregador Country'),
(71619, 6218, 19, 'Subscritor Empregador State'),
(71620, 6221, 19, 'Subscritor Empregador Cep'),
(71621, 6225, 19, 'Telefone de subscritor'),
(71622, 6226, 19, 'Relação de subscritor'),
(71623, 6227, 19, 'Relação de subscritor não é ego mas nome é o mesmo! Este realmente é o OK?'),
(71624, 6228, 19, 'Relação de subscritor não é ego mas número de SS é o mesmo!'),
(71625, 6229, 19, 'Relação de subscritor é ego mas nome é diferente! Este realmente é o OK?'),
(71626, 6230, 19, 'Relação de subscritor é ego mas número de SS é diferente!'),
(71627, 6231, 19, 'Sexo de subscritor'),
(71628, 6237, 19, 'Substituição'),
(71629, 6238, 19, 'substituição permitida'),
(71630, 6240, 19, 'Sucesso'),
(71631, 6241, 19, 'sucesso'),
(71632, 6247, 19, 'prosperamente acrescentado a categoria,'),
(71633, 6256, 19, 'prosperamente armazenado.'),
(71634, 6259, 19, 'prosperamente.'),
(71635, 6260, 19, 'Suicídio'),
(71636, 6261, 19, 'Resumo'),
(71637, 6262, 19, 'Resumo de'),
(71638, 6265, 19, 'Dom'),
(71639, 6267, 19, 'Domingo'),
(71640, 6268, 19, 'Superbill'),
(71641, 6269, 19, 'Superbill Codes'),
(71642, 6270, 19, 'Superbill Codes Administração'),
(71643, 6271, 19, 'Superbill Report'),
(71644, 6274, 19, 'Superbills, às vezes chamado Formas de Encontro ou Deslizes Derrotando, são uma parte essencial da maioria das práticas médicas.'),
(71645, 6275, 19, 'Superutilizador'),
(71646, 6276, 19, 'Supervisionando'),
(71647, 6289, 19, 'Tipo de superfície'),
(71648, 6290, 19, 'Cirurgias'),
(71649, 6291, 19, 'Cirurgia'),
(71650, 6293, 19, 'Suspenso'),
(71651, 6294, 19, 'suspensão'),
(71652, 6295, 19, 'Svc Date'),
(71653, 6296, 19, 'Svc Date:'),
(71654, 6299, 19, 'Transpiração:'),
(71655, 6300, 19, 'Sueco'),
(71656, 6301, 19, 'Inchaço'),
(71657, 6302, 19, 'Direito inchando'),
(71658, 6303, 19, 'articulações inchadas'),
(71659, 6304, 19, 'Ganglios linfáticos aumentados'),
(71660, 6307, 19, 'Sintomas'),
(71661, 6308, 19, 'Sincronizar'),
(71662, 6313, 19, 'Síncope'),
(71663, 6317, 19, 'Synovitis, intrusão, bursite,'),
(71664, 6318, 19, 'Sistema'),
(71665, 6322, 19, 'T'),
(71666, 6323, 19, 't.i.d.'),
(71667, 6324, 19, 'T.V.'),
(71668, 6327, 19, 'Erro ao criar a tabela'),
(71669, 6328, 19, 'Erro ao actualizar a tabela'),
(71670, 6330, 19, 'comprimido'),
(71671, 6335, 19, 'Levar'),
(71672, 6339, 19, 'Objetos pegados muito tempo'),
(71673, 6355, 19, 'Taxa de imposição'),
(71674, 6356, 19, 'Impostos'),
(71675, 6357, 19, 'Taxonomia'),
(71676, 6358, 19, 'Td'),
(71677, 6359, 19, 'Emparelhe Avaliação de Dano'),
(71678, 6360, 19, 'Emparelhe Lista'),
(71679, 6361, 19, 'Emparelhe Visão de Lista'),
(71680, 6363, 19, 'Tel'),
(71681, 6364, 19, 'Código do País'),
(71682, 6366, 19, 'Temp'),
(71683, 6367, 19, 'Localização Temp'),
(71684, 6368, 19, 'Método temporário'),
(71685, 6369, 19, 'Temperatura'),
(71686, 6370, 19, 'Modelo'),
(71687, 6371, 19, 'Nome de modelo'),
(71688, 6372, 19, 'Nomes de modelo não podem começar com números.'),
(71689, 6373, 19, 'Modelo:'),
(71690, 6374, 19, 'Modelos'),
(71691, 6375, 19, 'Artéria temporal'),
(71692, 6376, 19, 'Dano de tendão'),
(71693, 6377, 19, 'Tendinite / osis / bursite'),
(71694, 6379, 19, 'Terciário'),
(71695, 6380, 19, 'Seguro terciário'),
(71696, 6381, 19, 'Dados de Seguro terciários'),
(71697, 6382, 19, 'Provedor de Seguro terciário'),
(71698, 6383, 19, 'Programação de teste'),
(71699, 6384, 19, 'Sistema de teste'),
(71700, 6387, 19, 'Campo de Texto'),
(71701, 6393, 19, 'Data'),
(71702, 6394, 19, 'data'),
(71703, 6395, 19, 'Área de Texto'),
(71704, 6396, 19, 'área de texto'),
(71705, 6397, 19, 'Caixa de Texto'),
(71706, 6398, 19, 'caixa de texto'),
(71707, 6399, 19, 'Lista caixa de texto'),
(71708, 6400, 19, 'Lista caixa de texto'),
(71709, 6401, 19, 'Tailandês'),
(71710, 6402, 19, 'Obrigado'),
(71711, 6403, 19, 'Obrigado pela preferência'),
(71712, 6408, 19, 'O arquivo de reivindicação: '),
(71713, 6413, 19, 'o Código de Negação é'),
(71714, 6415, 19, 'O formulário de destino foi fechado'),
(71715, 6416, 19, 'A forma de destino estava fechada; Eu não posso agir em sua seleção.'),
(71716, 6422, 19, 'O evento(s) foi aprovado.'),
(71717, 6423, 19, 'O evento(s) foi escondido.'),
(71718, 6424, 19, 'O dados exportado se aparece na área de texto abaixo. Você pode copiar e pode colar isto em um e-mail ou para qualquer outro destino desejado.'),
(71719, 6426, 19, 'O dados exportado se aparece na área de texto abaixo. Você pode copiar e pode colar isto em um e-mail ou para qualquer outro destino desejado.'),
(71720, 6434, 19, 'O evento de calendário seguinte foi somado:'),
(71721, 6435, 19, 'O evento de calendário seguinte foi modifed:'),
(71722, 6441, 19, 'Os erros seguintes aconteceram'),
(71723, 6450, 19, 'A janela inicial é a página de procura de fatura. Ao topo você pode entrar em uma fonte (por exemplo confira número), pague data e confira quantia. A razão para a fonte e data de pagamento está de forma que você dom ''t têm que entrar neles inúmeras vezes para cada reivindicação. A quantia na que você entra será diminuída para cada fatura que é determinada parte do pagamento, e esperançosamente terminará a zero quando você for terminado.'),
(71724, 6456, 19, 'O rótulo que se aparece ao usuário na forma'),
(71725, 6460, 19, 'A nova categoria será uma subcategoria de '),
(71726, 6475, 19, 'A informação restante debaixo de só aplica se você está postando manualmente, ou se você está fazendo correções manuais.'),
(71727, 6477, 19, 'O documento pedido não está presente no local esperado no filesystem ou não há permissões suficientes para acessar isto.'),
(71728, 6480, 19, 'São copiadas a Fonte e colunas de Data da primeira página, tão normalmente você não precisará tocar esses. Você pode pôr uma quantia de pagamento na coluna de Pagamento, uma quantia de ajuste no Ajuste coluna, ou ambos. Você também pode clicar à direita o "W" para computar um valor de ajuste que escreve fora o resto do custo para aquele artigo de linha automaticamente.'),
(71729, 6485, 19, 'O rótulo traduzido que se aparecerá na forma em idioma atual'),
(71730, 6486, 19, 'O Título traduzido que se aparecerá em idioma atual'),
(71731, 6487, 19, 'A tradução de descrição em idioma atual'),
(71732, 6491, 19, 'O X12 arquiva como também a HTML resultante produziu são arquivados relatórios no subdiretório de "era" do LibreEHR instalação diretório principal. Você quererá recorrer de vez em quando a estes arquivos. A URL é'),
(71733, 6493, 19, 'Tema'),
(71734, 6495, 19, 'Injeções terapêuticas'),
(71735, 6496, 19, 'Há'),
(71736, 6497, 19, 'Não há prescrição'),
(71737, 6498, 19, 'Há erros com sua submissão. Estes são esboçados abaixo.'),
(71738, 6501, 19, 'Não há informações para este utente.'),
(71739, 6502, 19, 'Não há nenhuma Submissão Nova'),
(71740, 6503, 19, 'Não há notas para este utente.'),
(71741, 6504, 19, 'Não há transações para este utente.'),
(71742, 6505, 19, 'Houve um erro de correio que envia'),
(71743, 6510, 19, 'Não há nenhuma entrada de COA para conta de AR '),
(71744, 6511, 19, 'Não há nenhuma entrada de COA para conta de caixa '),
(71745, 6512, 19, 'Não há nenhuma entrada de COA para conta de renda '),
(71746, 6513, 19, 'Não há utente activo'),
(71747, 6515, 19, 'Não há nenhuma partida para id de fatura'),
(71748, 6516, 19, 'Não há nenhuma partida para id de fatura = '),
(71749, 6517, 19, 'Não há nenhuma entrada de partes para serviços ID '),
(71750, 6520, 19, 'Havia um erro enquanto processando seu pedido.'),
(71751, 6523, 19, 'Direito engrossado:'),
(71752, 6524, 19, 'Coxa'),
(71753, 6525, 19, 'Coxa + paralise'),
(71754, 6527, 19, 'Coisas que o escritório pode ler e pode entrar mas não pode modificar'),
(71755, 6528, 19, 'Coisas que o escritório pode ler e pode modificar'),
(71756, 6531, 19, 'Coisas que os clínicos podem ler e podem entrar mas não podem modificar'),
(71757, 6532, 19, 'Coisas que os clínicos podem ler e podem modificar'),
(71758, 6535, 19, 'Coisas que escritório dianteiro pode ler e pode entrar mas não pode modificar'),
(71759, 6536, 19, 'Coisas que escritório dianteiro pode ler e pode modificar'),
(71760, 6539, 19, 'Coisas que os médicos podem ler e podem entrar mas não podem modificar'),
(71761, 6540, 19, 'Coisas que os médicos podem ler e podem modificar'),
(71762, 6542, 19, 'Terceiro'),
(71763, 6544, 19, 'Esta ação não pode ser desfeita.'),
(71764, 6545, 19, 'Esta ação não pode ser desfeita.'),
(71765, 6547, 19, 'A acção vai ser registada'),
(71766, 6556, 19, 'Este tipo de código não aceita relações.'),
(71767, 6561, 19, 'Esta Consulta'),
(71768, 6566, 19, 'Este número de fatura foi mudado '),
(71769, 6575, 19, 'Este módulo está em modo de teste. O banco de dados não será mudado.'),
(71770, 6576, 19, 'Este módulo promove entrada eficiente de dados de EOB.'),
(71771, 6577, 19, 'Este mês até à data'),
(71772, 6581, 19, 'Esta página vai inline incluem a página de login, de forma que nós não têm clicar relogin toda vez.'),
(71773, 6582, 19, 'Este doente não tem nenhuma atividade.'),
(71774, 6583, 19, 'Este ID de doente já está a ser usada!'),
(71775, 6592, 19, 'Este utilizador não pertence a qualquer grupo'),
(71776, 6595, 19, 'Esta visita começa uso anticoncepcional novo'),
(71777, 6598, 19, 'Esta semana até à data'),
(71778, 6606, 19, 'Isto criará um auxílio em formato de piche e então envia isto a seu browser de teia assim você pode salvar isto'),
(71779, 6622, 19, 'Espinha torácica'),
(71780, 6625, 19, 'Garganta'),
(71781, 6626, 19, 'Câncer de garganta'),
(71782, 6627, 19, 'Cirurgia de Câncer de garganta'),
(71783, 6628, 19, 'Thrombosis/Stroke'),
(71784, 6629, 19, 'Qui'),
(71785, 6630, 19, 'Quinta'),
(71786, 6631, 19, 'Quinta'),
(71787, 6632, 19, 'Normal tiróide'),
(71788, 6633, 19, 'Problemas tiróides'),
(71789, 6634, 19, 'TIA'),
(71790, 6638, 19, 'Hora'),
(71791, 6639, 19, 'Formato da Hora'),
(71792, 6640, 19, 'Incremento de tempo para Some (atas 1-60)'),
(71793, 6647, 19, 'Evento cronometrado'),
(71794, 6648, 19, 'Tempos formam (N/A)'),
(71795, 6649, 19, 'Timestamp e Texto'),
(71796, 6650, 19, 'LATA'),
(71797, 6651, 19, 'Tinido'),
(71798, 6652, 19, 'Título'),
(71799, 6653, 19, 'Título V'),
(71800, 6654, 19, 'TitleCols deve ser um número entre 1 e 999'),
(71801, 6655, 19, 'Títulos'),
(71802, 6656, 19, 'TM ''S:'),
(71803, 6657, 19, 'TMs/EAMs/EE, nariz de ext,'),
(71804, 6658, 19, 'Para'),
(71805, 6659, 19, 'PARA'),
(71806, 6660, 19, 'para'),
(71807, 6662, 19, 'Adicione notas aqui '),
(71808, 6663, 19, 'Adicione notas aqui'),
(71809, 6664, 19, 'Para Área Afetada'),
(71810, 6665, 19, 'para área afetada'),
(71811, 6667, 19, 'Para Faturar Visão'),
(71812, 6668, 19, 'para categoria'),
(71813, 6669, 19, 'Para Visão Clínica'),
(71814, 6670, 19, 'Para copay'),
(71815, 6672, 19, 'Para ded''ble'),
(71816, 6673, 19, 'Para Dems'),
(71817, 6679, 19, 'Para Enctr'),
(71818, 6680, 19, 'Filtrar através de sexo'),
(71819, 6681, 19, 'Para História'),
(71820, 6682, 19, 'Para Assuntos'),
(71821, 6684, 19, 'Unir este encounter/consult a um assunto existente, clique o assunto desejado acima realçar isto e então clicar [Economize]. Sujeite [Ctrl] botão para selecionar assuntos múltiplos.'),
(71822, 6685, 19, 'para login novamente'),
(71823, 6686, 19, 'Para registar informação, carregue'),
(71824, 6687, 19, 'para executar'),
(71825, 6689, 19, 'Esfolar'),
(71826, 6690, 19, 'esfolar'),
(71827, 6691, 19, 'para esta visita?'),
(71828, 6693, 19, 'Para:'),
(71829, 6694, 19, 'Para: '),
(71830, 6695, 19, 'TO_CITY'),
(71831, 6696, 19, 'TO_FAX'),
(71832, 6697, 19, 'TO_FNAME'),
(71833, 6698, 19, 'TO_LNAME'),
(71834, 6699, 19, 'TO_MNAME'),
(71835, 6700, 19, 'TO_ORGANIZATION'),
(71836, 6703, 19, 'TO_POSTAL'),
(71837, 6704, 19, 'TO_STATE'),
(71838, 6705, 19, 'TO_STREET'),
(71839, 6706, 19, 'TO_TITLE'),
(71840, 6707, 19, 'TO_VALEDICTORY'),
(71841, 6708, 19, 'Tabaco'),
(71842, 6712, 19, 'Uso de tabaco'),
(71843, 6715, 19, 'Hoje'),
(71844, 6720, 19, 'Hoje ''Data de s'),
(71845, 6721, 19, 'Hoje ''Eventos de s'),
(71846, 6726, 19, 'Amigdalectomia'),
(71847, 6728, 19, 'Topo'),
(71848, 6730, 19, 'Tópico'),
(71849, 6731, 19, 'Total'),
(71850, 6732, 19, 'total'),
(71851, 6737, 19, 'Total Devido'),
(71852, 6738, 19, 'Total Pago'),
(71853, 6741, 19, 'Total Custos');
INSERT INTO `lang_definitions` VALUES
(71854, 6742, 19, 'Total Clientes'),
(71855, 6743, 19, 'Custo Total'),
(71856, 6748, 19, 'Total para'),
(71857, 6749, 19, 'Total para '),
(71858, 6750, 19, 'Total para categoria'),
(71859, 6758, 19, 'Num. Total Utentes'),
(71860, 6765, 19, 'Total SRH & Planeamento Familiar'),
(71861, 6776, 19, 'Totais'),
(71862, 6777, 19, 'Totais para'),
(71863, 6778, 19, 'Totais para '),
(71864, 6785, 19, 'Tipo de Formação'),
(71865, 6786, 19, 'Transação'),
(71866, 6787, 19, 'Transação'),
(71867, 6788, 19, 'transação'),
(71868, 6791, 19, 'Tipo de transação'),
(71869, 6793, 19, 'Transações'),
(71870, 6794, 19, 'Transações (opcional)'),
(71871, 6795, 19, 'Transações/Referenciadas'),
(71872, 6813, 19, 'traduza isto'),
(71873, 6814, 19, 'Tradução'),
(71874, 6815, 19, 'Traduções'),
(71875, 6819, 19, 'Trauma'),
(71876, 6822, 19, 'Tratamento: Objectivos'),
(71877, 6823, 19, 'Tratamento: Plano'),
(71878, 6826, 19, 'Tratamento:'),
(71879, 6827, 19, 'Tratamento: '),
(71880, 6829, 19, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000))); $month_value'),
(71881, 6830, 19, 'Ponto de gatilho / síndroma compartimental / DOMS / câimbra'),
(71882, 6831, 19, 'Trimaleolar'),
(71883, 6832, 19, 'Tronco e abdómen'),
(71884, 6837, 19, 'tsp'),
(71885, 6839, 19, 'TTS'),
(71886, 6840, 19, 'Tuberculose'),
(71887, 6841, 19, 'Ter'),
(71888, 6842, 19, 'Ter &amp; Qui'),
(71889, 6843, 19, 'Terça'),
(71890, 6844, 19, 'Tumor'),
(71891, 6845, 19, 'Turco'),
(71892, 6848, 19, 'duas vezes ao dia'),
(71893, 6850, 19, 'Membrana timpânica'),
(71894, 6851, 19, 'Tipo'),
(71895, 6857, 19, 'Tipo ou esquadrinha o identificador paciente aqui'),
(71896, 6864, 19, 'Códigos de UCSMC providos pela Universidade de Calgary Centro de Medicina De esporte'),
(71897, 6866, 19, 'Ulcerações'),
(71898, 6867, 19, 'Colites ulcerativas'),
(71899, 6868, 19, 'Úlceras:'),
(71900, 6877, 19, 'Sem registo'),
(71901, 6880, 19, 'Acesso sem autorização.'),
(71902, 6884, 19, 'debaixo de língua'),
(71903, 6885, 19, 'De peso inferior ao normal'),
(71904, 6886, 19, 'Undiagnosed'),
(71905, 6890, 19, 'Desfaça Saída'),
(71906, 6892, 19, 'Clientes sem igual'),
(71907, 6894, 19, 'Clientes Novos sem igual'),
(71908, 6896, 19, 'Pacientes Vistos sem igual'),
(71909, 6897, 19, 'Relatório de Pacientes Visto sem igual'),
(71910, 6898, 19, 'SP sem igual'),
(71911, 6899, 19, 'Unidade'),
(71912, 6900, 19, 'Unidades'),
(71913, 6901, 19, 'unidades'),
(71914, 6903, 19, 'Unidades dos Formulários'),
(71915, 6904, 19, 'Unidades devem ser um número'),
(71916, 6907, 19, 'Desconhecido'),
(71917, 6911, 19, 'Desconhecido ou N/A'),
(71918, 6914, 19, 'Companhia de seguros não mencionada'),
(71919, 6915, 19, 'Não registrado'),
(71920, 6918, 19, 'Unselect Tudo'),
(71921, 6919, 19, 'Unselected'),
(71922, 6920, 19, 'Não especificado'),
(71923, 6924, 19, 'até'),
(71924, 6925, 19, 'Intempestivamente arquivamento'),
(71925, 6926, 19, 'Não Utilizado'),
(71926, 6927, 19, 'UOR'),
(71927, 6928, 19, 'Até'),
(71928, 6929, 19, 'Próximas Marcações'),
(71929, 6930, 19, 'Eventos a chegar'),
(71930, 6931, 19, 'Atualizar'),
(71931, 6932, 19, 'actualizar'),
(71932, 6934, 19, 'Actualizar ficheiros'),
(71933, 6935, 19, 'Actualizar Informação'),
(71934, 6942, 19, 'Atualizando demographics não é autorizado.'),
(71935, 6950, 19, 'Cédula Profissional'),
(71936, 6951, 19, 'Carga'),
(71937, 6954, 19, 'Transfera dados de configuração'),
(71938, 6955, 19, 'Transfera Documento'),
(71939, 6956, 19, 'Carga falhou!'),
(71940, 6958, 19, 'Transfera arquivo de importação:'),
(71941, 6961, 19, 'Transfera Relatório'),
(71942, 6963, 19, 'Transfera este arquivo:'),
(71943, 6964, 19, 'Ao clicar um número de fatura a janela postando" manual" se aparece. Aqui você pode mudar a data de vencimento e notas para a fatura, selecione a festa para quem você está postando, e seleciona foram recebidos os seguros para os quais tudo esperaram paymants. Importantemente, para cada código de faturamento pelo qual uma quantia foi cobrada, você pode entrar em pagamento e informação de ajuste.'),
(71944, 6965, 19, 'Ao o procurar é apresentado com uma lista de faturas. Você pode clicar aceso dos números de fatura abrir uma segunda janela que é a página de entrada de dados por manual postar. Você também pode fazer tique-taque em um nome paciente se você quiser entrar em uma nota que o pessoal de escritório dianteiro verá quando os cheques pacientes em, e você pode selecionar faturas para se aparecer em declarações pacientes e imprimir essas declarações.'),
(71945, 6966, 19, 'Braço superior'),
(71946, 6968, 19, 'Urgência'),
(71947, 6971, 19, 'Urina Pingando'),
(71948, 6972, 19, 'Freqüência de urina'),
(71949, 6973, 19, 'Hesitação de urina'),
(71950, 6975, 19, 'Fluxo de urina'),
(71951, 6976, 19, 'Urgência de urina'),
(71952, 6977, 19, 'URL'),
(71953, 6988, 19, 'Use 24 formato de tempo de hora?'),
(71954, 7000, 19, 'Faltas de uso'),
(71955, 7002, 19, 'Use estilo de data internacional?'),
(71956, 7005, 19, 'Só use esta característica com locais recentemente instalados, '),
(71957, 7006, 19, 'Use tópicos?'),
(71958, 7007, 19, 'Utilizador'),
(71959, 7009, 19, 'Utilizador / Grupos'),
(71960, 7010, 19, 'Administração de usuário'),
(71961, 7011, 19, 'Administração de Utilizadores e Instalações'),
(71962, 7012, 19, 'Administração de Utilizadores e Grupos'),
(71963, 7014, 19, 'Autenticação de Utilizadores por Certificado está desabilitado'),
(71964, 7015, 19, 'Personalizado'),
(71965, 7016, 19, 'Área Personalizada 11'),
(71966, 7017, 19, 'Área Personalizada 12'),
(71967, 7018, 19, 'Campo Personalizado'),
(71968, 7019, 19, 'Lista Personalizada 1'),
(71969, 7020, 19, 'Lista Personalizada 2'),
(71970, 7021, 19, 'Lista Personalizada 3'),
(71971, 7022, 19, 'Lista Personalizada 4'),
(71972, 7023, 19, 'Lista Personalizada 5'),
(71973, 7024, 19, 'Lista Personalizada 6'),
(71974, 7025, 19, 'Lista Personalizada 7'),
(71975, 7026, 19, 'Texto Personalizado 1'),
(71976, 7027, 19, 'Texto Personalizado 2'),
(71977, 7028, 19, 'Texto Personalizado 3'),
(71978, 7029, 19, 'Texto Personalizado 4'),
(71979, 7030, 19, 'Texto Personalizado 5'),
(71980, 7031, 19, 'Texto Personalizado 6'),
(71981, 7032, 19, 'Texto Personalizado 7'),
(71982, 7033, 19, 'Texto Personalizado 8'),
(71983, 7039, 19, 'Manual do Utilizador'),
(71984, 7040, 19, 'Grupos do Utilizador'),
(71985, 7049, 19, 'Utilizador'),
(71986, 7052, 19, 'Utilizador para a Gateway de SMS'),
(71987, 7053, 19, 'Utilizador para a Gateway de SMS.'),
(71988, 7055, 19, 'Utilizador:'),
(71989, 7056, 19, 'Utilizadores'),
(71990, 7057, 19, 'Administração Utilizadores/Grupos/Registos'),
(71991, 7058, 19, 'usa <a php href=""http://php.net/strftime""> strftime </ a> formato'),
(71992, 7059, 19, 'UTIs'),
(71993, 7062, 19, 'FÉRIAS'),
(71994, 7063, 19, 'Férias'),
(71995, 7064, 19, 'Vacina'),
(71996, 7065, 19, 'Anel vaginal'),
(71997, 7066, 19, 'Valedictory'),
(71998, 7068, 19, 'Valor'),
(71999, 7069, 19, 'Valor 1'),
(72000, 7070, 19, 'Valor 2'),
(72001, 7072, 19, 'Valor deve ser numérico'),
(72002, 7073, 19, 'Var1'),
(72003, 7074, 19, 'Var2'),
(72004, 7076, 19, 'Varicela 1'),
(72005, 7077, 19, 'Varicela 2'),
(72006, 7078, 19, 'Veias varicosas'),
(72007, 7079, 19, 'Condição vascular'),
(72008, 7080, 19, 'Dano vascular'),
(72009, 7081, 19, 'Cirurgia vascular'),
(72010, 7083, 19, 'Fornecedor'),
(72011, 7084, 19, 'Versão'),
(72012, 7085, 19, 'Vertigem'),
(72013, 7087, 19, 'Plano Veterans Administration'),
(72014, 7090, 19, 'ver'),
(72015, 7091, 19, 'Ver'),
(72016, 7092, 19, 'Ver Alergias'),
(72017, 7097, 19, 'Ver reg. detalhado do paciente'),
(72018, 7100, 19, 'Ver documento'),
(72019, 7101, 19, 'Ver consulta'),
(72020, 7103, 19, 'Ver eventos numa janela?'),
(72021, 7108, 19, 'Veja pág 1'),
(72022, 7109, 19, 'Veja pág 2'),
(72023, 7111, 19, 'Ver Doente'),
(72024, 7116, 19, 'Ver consultas relacionadas'),
(72025, 7121, 19, 'Ver/Editar Alergias'),
(72026, 7124, 19, 'Ver:'),
(72027, 7125, 19, 'VISTO'),
(72028, 7126, 19, 'VISA/MC/AMEX/Dis'),
(72029, 7127, 19, 'Visceral: dano/trauma/cirurgia'),
(72030, 7133, 19, 'Visita: Categoria'),
(72031, 7134, 19, 'Visita: Data'),
(72032, 7137, 19, 'Visita: Formulários'),
(72033, 7138, 19, 'Histórico'),
(72034, 7140, 19, 'Visitas'),
(72035, 7141, 19, 'Visitas de'),
(72036, 7142, 19, 'Sinais Vitais'),
(72037, 7143, 19, 'Exame Físico Geral'),
(72038, 7144, 19, 'Vitals (Métrico) CHANGEME'),
(72039, 7146, 19, 'Voz'),
(72040, 7149, 19, 'Vômitos'),
(72041, 7151, 19, 'Q'),
(72042, 7152, 19, 'Cintura'),
(72043, 7153, 19, 'Cintura: circunferência'),
(72044, 7154, 19, 'Esperando'),
(72045, 7155, 19, 'Directos'),
(72046, 7157, 19, 'Walt Pennington'),
(72047, 7158, 19, 'Armazén'),
(72048, 7161, 19, 'Armazéns'),
(72049, 7162, 19, 'Quente'),
(72050, 7164, 19, 'AVISO'),
(72051, 7168, 19, 'Atenção: hoje foi já criada uma visita para este paciente!'),
(72052, 7170, 19, 'Advertindo: identificação paciente não é única!'),
(72053, 7171, 19, 'AVISO: Isto irá substituir as informações de configuração com os dados do arquivo enviado!'),
(72054, 7177, 19, 'Agradecemos o pagamento imediato do valor devido'),
(72055, 7178, 19, 'observámos o paciente acima identificado, na nossa clínica psiquiátrica ambulatoria. Gratos pela preferência.'),
(72056, 7179, 19, 'Fraqueza'),
(72057, 7182, 19, 'Website'),
(72058, 7184, 19, 'Qua'),
(72059, 7185, 19, 'Quarta'),
(72060, 7186, 19, 'Semana'),
(72061, 7187, 19, 'semana'),
(72062, 7188, 19, 'Semana'),
(72063, 7189, 19, 'Semana (s)'),
(72064, 7190, 19, 'Exposições Semanais'),
(72065, 7192, 19, 'Semanas'),
(72066, 7193, 19, 'Peso'),
(72067, 7196, 19, 'Mudança de peso'),
(72068, 7197, 19, 'Perda de peso'),
(72069, 7199, 19, 'Bemvindo'),
(72070, 7202, 19, 'Quem contactar?'),
(72071, 7203, 19, 'Sibilos:'),
(72072, 7204, 19, 'Sibilante'),
(72073, 7205, 19, 'Sibilante:'),
(72074, 7208, 19, 'Onde estão os registos (papel ou digitais) relacionados?'),
(72075, 7211, 19, 'Chicotada'),
(72076, 7213, 19, 'Quem'),
(72077, 7214, 19, 'Quem respondeu?'),
(72078, 7215, 19, 'Viúvo(a)'),
(72079, 7221, 19, 'Com selecionado:'),
(72080, 7222, 19, 'com o nome antigo'),
(72081, 7224, 19, 'A quem podemos deixar mensagem?'),
(72082, 7226, 19, 'dentro de horas'),
(72083, 7227, 19, 'dentro de horas:'),
(72084, 7228, 19, 'dentro de minutos'),
(72085, 7229, 19, 'dentro de minutos:'),
(72086, 7232, 19, 'Sem actualização'),
(72087, 7233, 19, 'Testemunha'),
(72088, 7234, 19, 'sm'),
(72089, 7235, 19, 'WNL'),
(72090, 7237, 19, 'Mulheres'),
(72091, 7238, 19, 'Só Mulheres'),
(72092, 7240, 19, 'Trabalho'),
(72093, 7241, 19, 'NOTA DE TRABALHO'),
(72094, 7242, 19, 'Telefone trabalho'),
(72095, 7243, 19, 'Nº Telefone trabalho'),
(72096, 7244, 19, 'Relacionado c/ trabalho?'),
(72097, 7245, 19, 'Trabalho/Educação/Passatempos'),
(72098, 7246, 19, 'Trabalho / Nota Escolar'),
(72099, 7247, 19, 'dia útil'),
(72100, 7249, 19, 'SubSistema de Saúde do trabalhador'),
(72101, 7252, 19, 'Pior'),
(72102, 7264, 19, 'Punho'),
(72103, 7265, 19, 'Punho e mão'),
(72104, 7266, 19, 'Problemas no punho'),
(72105, 7267, 19, 'escrever'),
(72106, 7268, 19, 'excluir'),
(72107, 7270, 19, 'wsome'),
(72108, 7271, 19, 'WT'),
(72109, 7273, 19, 'x Cancelado'),
(72110, 7274, 19, 'x Cancelado'),
(72111, 7275, 19, 'RX'),
(72112, 7276, 19, 'RX (interpretação):'),
(72113, 7277, 19, 'RX (interpretação):'),
(72114, 7278, 19, 'X12 só: Substituição de Pedido '),
(72115, 7279, 19, 'X12 Parceiro'),
(72116, 7280, 19, 'X12 Parceiros'),
(72117, 7284, 19, 'Y'),
(72118, 7285, 19, 'Ano'),
(72119, 7286, 19, 'ano'),
(72120, 7287, 19, 'Ver Ano'),
(72121, 7288, 19, 'Ano(s)'),
(72122, 7292, 19, 'SIM'),
(72123, 7293, 19, 'Sim'),
(72124, 7294, 19, 'sim'),
(72125, 7295, 19, 'SIM!'),
(72126, 7296, 19, 'Apagar e Registar'),
(72127, 7298, 19, 'Sim/Não'),
(72128, 7299, 19, 'Sim:'),
(72129, 7303, 19, 'Está prestes a substituir permanentemente o modelo existente. Tem certeza de que deseja continuar?'),
(72130, 7304, 19, 'Mude a password antes de'),
(72131, 7305, 19, 'Não tem permissão para eliminar este evento'),
(72132, 7306, 19, 'Não tem permissão para editar este evento'),
(72133, 7307, 19, 'Não tem permissão para isto.'),
(72134, 7308, 19, 'Não tem permissão para aceder a esta area.'),
(72135, 7309, 19, 'Não tem permissão para adicionar / editar questões'),
(72136, 7311, 19, 'Não tem permissão para ver este encontro.'),
(72137, 7313, 19, 'Não pode aceder a esta função directamente.'),
(72138, 7314, 19, 'Não pode aceder a esta página directamente.'),
(72139, 7315, 19, 'Não pode adicionar um valor em branco para essa categoria'),
(72140, 7316, 19, 'Não pode adicionar um valor em branco para essa subcategoria'),
(72141, 7317, 19, 'Não pode adicionar um valor em branco para um item'),
(72142, 7319, 19, 'Não escolheu nenhuma ação.'),
(72143, 7320, 19, 'Não tem permissão para ver/editar esta nota'),
(72144, 7321, 19, 'Tentou alterar conteudos trancados. Para destrancar remova linha ''/*lock::*/'''),
(72145, 7329, 19, 'Deve primeiro selecionar ou adicionar um paciente.'),
(72146, 7330, 19, 'Deve primeiro selecionar ou criar um encontro.'),
(72147, 7332, 19, 'Deve selecionar uma categoria de visita'),
(72148, 7333, 19, 'Deve selecionar alguns campos para continuar.'),
(72149, 7334, 19, 'Você deveria estar fazendo este teste se esta reivindicação parecesse gerar prosperamente mas o arquivo de reivindicação atual não contém qualquer dados ou só uma porção inacabada da quantia de dados é suposto que contém. É óbvio com reivindicações de HCFA porque eles são humanos legível, com reivindicações de X12 é um processo mais difícil para determinar se a reivindicação for corretamente complete.'),
(72150, 7339, 19, 'data final inválida'),
(72151, 7340, 19, 'Evento eliminado.'),
(72152, 7341, 19, 'Evento modificado.'),
(72153, 7342, 19, 'Evento submetido.'),
(72154, 7343, 19, 'O ficheiro é muito grande'),
(72155, 7345, 19, 'O nome da sua lista foi alterado em conformidade com as regras.'),
(72156, 7347, 19, 'Nome para esta categoria, procedimento ou resultado'),
(72157, 7349, 19, 'Password desactualizada. Mude a password.'),
(72158, 7350, 19, 'Password válida até'),
(72159, 7351, 19, 'Password termina hoje. Mude a Password.'),
(72160, 7353, 19, 'A configuração de PostCalendar foi alterada p/ valores padrão.'),
(72161, 7354, 19, 'Configuração de PostCalendar foi atualizada.'),
(72162, 7355, 19, 'Sua freqüência repetindo deve ser uma inteireza.'),
(72163, 7356, 19, 'Sua freqüência repetindo deve ser pelo menos 1.'),
(72164, 7357, 19, 'Sua data de começo é maior que sua data de fim'),
(72165, 7358, 19, 'Sua data de começo é inválida'),
(72166, 7359, 19, 'Sua submissão falhou.'),
(72167, 7360, 19, 'aaaa-mm-dd'),
(72168, 7362, 19, 'aaaa-mm-dd data associado a este documento'),
(72169, 7363, 19, 'aaaa-mm-dd data destruído'),
(72170, 7364, 19, 'aaaa-mm-dd data de nascimento'),
(72171, 7365, 19, 'aaaa-mm-dd Data de Nascimento'),
(72172, 7366, 19, 'aaaa-mm-dd data de morte'),
(72173, 7367, 19, 'aaaa-mm-dd Data de início ou internamento'),
(72174, 7368, 19, 'aaaa-mm-dd data de início, cirurgia ou início da medicação'),
(72175, 7369, 19, 'aaaa-mm-dd data de compra ou transferencia'),
(72176, 7370, 19, 'aaaa-mm-dd data de recuperação ou no final de medicação'),
(72177, 7371, 19, 'aaaa-mm-dd Data de voltar a jogar'),
(72178, 7372, 19, 'aaaa-mm-dd Data de serviço'),
(72179, 7373, 19, 'aaaa-mm-dd data desta carta'),
(72180, 7374, 19, 'aaaa-mm-dd data voltou a jogar'),
(72181, 7375, 19, 'aaaa-mm-dd data do documento'),
(72182, 7376, 19, 'aaaa-mm-dd ocorrencia ou data de início'),
(72183, 7383, 19, 'aaaa-mm-dd última data deste evento'),
(72184, 7387, 19, 'Zero'),
(72185, 7389, 19, 'C. Postal'),
(72186, 7390, 19, 'C. Postal'),
(72187, 7391, 19, 'C. Postal/País:'),
(72188, 7393, 19, ' mas era '),
(72189, 7394, 19, ' não pôde ser acedido.'),
(72190, 7395, 19, 'Deseja realmente eliminar'),
(72191, 7396, 19, 'Droga'),
(72192, 7397, 19, 'emails não enviados'),
(72193, 7398, 19, 'de'),
(72194, 7399, 19, 'foi criado. '),
(72195, 7400, 19, 'foi re-aberto.'),
(72196, 7401, 19, 'Historial'),
(72197, 7402, 19, 'não é um número'),
(72198, 7403, 19, 'está pronto para re-faturar.'),
(72199, 7404, 19, 'LLL:'),
(72200, 7405, 19, 'Lote'),
(72201, 7406, 19, 'Medicaid Referência Original Não. '),
(72202, 7407, 19, 'min'),
(72203, 7408, 19, 'não encontrado!'),
(72204, 7409, 19, 'Peculiaridades em muitos browsers pode querer dizer que a produção debaixo de entra em sua tela em puxões súbitos e que há longo pausa de vários segundos onde se aparece como se coisas podem ter batido. Isso não é o caso, você verá produção que sai de linha através de linha eventualmente. Pode haver números seqüentes que se aparecem abaixo, este é indicar que embora nada mais possa estar exibindo há atividade que vai em. Estes números serão entremeados com o conteúdo do faturamento e isso é normal.'),
(72205, 7410, 19, 'prescrição alcançou seu limite de'),
(72206, 7411, 19, 'até'),
(72207, 7412, 19, 'Actualização falhou, ausente da base de dados?'),
(72208, 7413, 19, 'marcado como facturado.'),
(72209, 7414, 19, 'adicionado à lista.'),
(72210, 7415, 19, '! Desistiu'),
(72211, 7416, 19, 'para código _x005F_x000D_ é CONFERIDO em Colocações de PostCalendar!'),
(72212, 7417, 19, '" SELECIONADO em configs PostCalendar!'),
(72213, 7418, 19, '# Ins / questão fin'),
(72214, 7419, 19, 'N. de comprimidos:'),
(72215, 7420, 19, '$'),
(72216, 7421, 19, '$ Codificado'),
(72217, 7422, 19, '$rótulo (aaaa-mm-dd): '),
(72218, 7423, 19, '%'),
(72219, 7424, 19, '% Cancelado <24h'),
(72220, 7425, 19, '% Cancelado <24h '),
(72221, 7426, 19, 'deveria existir mas não existe.'),
(72222, 7427, 19, '(% partidas qualquer fio, _ emparelha qualquer caráter)'),
(72223, 7429, 19, '(Retroceder)'),
(72224, 7430, 19, '(Editar)'),
(72225, 7432, 19, '(Mais)'),
(72226, 7433, 19, '(Novo Utente)'),
(72227, 7434, 19, '(Notas e Autorizações)'),
(72228, 7435, 19, '(Notas Utentes)'),
(72229, 7436, 19, '(Selecione um destes, ou digite seu próprio título)'),
(72230, 7438, 19, '* Lembrança feita'),
(72231, 7439, 19, '* * Por favor mova cirurgias a Assuntos!'),
(72232, 7440, 19, '* Exigido'),
(72233, 7442, 19, '- Nenhum'),
(72234, 7445, 19, '.'),
(72235, 7446, 19, '0'),
(72236, 7447, 19, '0-10'),
(72237, 7448, 19, '0-24'),
(72238, 7451, 19, '1'),
(72239, 7457, 19, '1.Descanso 2. Gelo durante dois dias 3. Compressão, mantém ligadura a menos que o pé fique hipostésico ou pálido. 4. Elevar pé e perna'),
(72240, 7458, 19, '11-14'),
(72241, 7459, 19, '12 hr'),
(72242, 7460, 19, '15-19'),
(72243, 7462, 19, '2'),
(72244, 7468, 19, '20-24'),
(72245, 7477, 19, '2111-13'),
(72246, 7478, 19, '24 hr'),
(72247, 7479, 19, '25'),
(72248, 7480, 19, '25-29'),
(72249, 7481, 19, '2º'),
(72250, 7483, 19, '3 meses'),
(72251, 7485, 19, '3 vezes ao dia'),
(72252, 7487, 19, '30-34'),
(72253, 7488, 19, '35-39'),
(72254, 7489, 19, '3º'),
(72255, 7491, 19, '4 meses'),
(72256, 7493, 19, '4 vezes ao dia'),
(72257, 7495, 19, '40-44'),
(72258, 7496, 19, '45'),
(72259, 7497, 19, '465.9, URI,'),
(72260, 7498, 19, '466.0, Bronquite aguda SOE'),
(72261, 7499, 19, '486.0, Pneumonia aguda'),
(72262, 7500, 19, '491.21, Exacerbação de DPCO'),
(72263, 7501, 19, '491.8, Bronquite crônica'),
(72264, 7502, 19, '493.92, Asma Aguda EXAC.'),
(72265, 7503, 19, '496.0, a DPCO'),
(72266, 7504, 19, '4º'),
(72267, 7508, 19, '519.7, Broncoespasmo'),
(72268, 7509, 19, '5º'),
(72269, 7511, 19, '6 meses'),
(72270, 7514, 19, '6º'),
(72271, 7517, 19, '824.0 fratura, malleolus mediano, fechado,'),
(72272, 7518, 19, '824.2 fratura, malleolus lateral, fechado,'),
(72273, 7519, 19, '824.6 fractura, Trimalleolar, fechado,'),
(72274, 7520, 19, '825.32 fractura, de Navicular (tornozelo)'),
(72275, 7521, 19, '825.35 fractura, Base de quinto (5º) Metatarsal'),
(72276, 7522, 19, '845.00 deslocamento de tornozelo NOS'),
(72277, 7523, 19, '845.01 deslocamento Mediano (Deltoid) Lig.'),
(72278, 7524, 19, '845.02 deslocamento, fibular de Calcaneal,'),
(72279, 7526, 19, '99212 estabelecido - Não complicado'),
(72280, 7527, 19, '99213 estabelecido - Baixa Complexidade'),
(72281, 7528, 19, '< Em consulta'),
(72282, 7529, 19, '> Saiu'),
(72283, 7531, 19, '? Faltou'),
(72284, 7532, 19, '@ Chegou'),
(72285, 7533, 19, '[Alterar Vista]'),
(72286, 7534, 19, '[Data da última consulta]'),
(72287, 7535, 19, '[Dias desde a última consulta]'),
(72288, 7536, 19, '[EOBs]'),
(72289, 7537, 19, '[Exporta OFX]'),
(72290, 7538, 19, '[não recomendado]'),
(72291, 7539, 19, '[Num. Encontros]'),
(72292, 7540, 19, '[Relatórios]'),
(72293, 7541, 19, '[Selecione Tudo]'),
(72294, 7542, 19, '[SQL-Ledger]'),
(72295, 7543, 19, '[Começa lote]'),
(72296, 7544, 19, '[Ver o reg]'),
(72297, 7545, 19, '[Ver Relatório Imprimível]'),
(72298, 7546, 19, '_PC_DUR_HOURS'),
(72299, 7547, 19, '_PC_DUR_MINUTES'),
(72300, 7548, 19, '_PC_LOCALE'),
(72301, 7549, 19, '~ Chegou atrasado'),
(72302, 1, 20, 'Um'),
(72303, 2, 20, 'Um número do cheque ou do crédito para identificar o pagamento'),
(72304, 3, 20, 'Um certificado cliente para o usuário administrador'),
(72305, 4, 20, 'Um documento clínico está anexado.'),
(72306, 5, 20, 'Um documento clínico está anexado.'),
(72307, 7, 20, 'Um distribuidor é necessário'),
(72308, 8, 20, 'Um formulário GCAC deve ser acrescentado a esta visita.'),
(72309, 9, 20, 'Um número de lote é necessário'),
(72310, 10, 20, 'Um número de lote é necessário!'),
(72311, 11, 20, 'Uma letra minúscula'),
(72312, 12, 20, 'Um número'),
(72313, 14, 20, 'Já existe um paciente com está identificação.'),
(72314, 15, 20, 'Já existe um paciente com este nome.'),
(72315, 16, 20, 'Um paciente com este CPF já existe.'),
(72316, 17, 20, 'Um número positivo vai mostrar que muitos agendamentos anteriores no Aplicativo na tela de Resumo do Paciente (um número negativo irá mostrar os últimos compromissos em ordem decrescente).'),
(72317, 18, 20, 'Um número positivo vai mostrar que muitos agendamentos anteriores no Aplicativo na tela de Resumo do Paciente.'),
(72318, 19, 20, 'Uma fonte de referência pode ser especificada para cada visita.'),
(72319, 20, 20, 'Um código IPPF relacionado é necessário!'),
(72320, 21, 20, 'Um caractere especial'),
(72321, 22, 20, 'Um valor único para identificar este campo, não visível para o usuário'),
(72322, 23, 20, 'Uma visita já existe para este paciente hoje. Clique em Cancelar para abri-lo, ou OK para prosseguir com a criação de um novo.'),
(72323, 24, 20, 'c.a.'),
(72324, 25, 20, 'da tarde'),
(72325, 26, 20, 'A/F Nível Direita:'),
(72326, 27, 20, 'Agenda'),
(72327, 28, 20, 'Abreviatura'),
(72328, 29, 20, 'Abcesso:'),
(72329, 30, 20, 'Abdominal'),
(72330, 31, 20, 'Capaz de suportar o peso por quatro (4) passos:'),
(72331, 32, 20, 'ABN'),
(72332, 33, 20, 'ABN1'),
(72333, 34, 20, 'Anormal'),
(72334, 35, 20, 'Teste de Sangue Anormal'),
(72335, 36, 20, 'Crescimento anormal dos cabelos'),
(72336, 37, 20, 'Mamografia anormal'),
(72337, 39, 20, 'Aborto'),
(72338, 40, 20, 'Questões do Aborto'),
(72339, 41, 20, 'O método do aborto'),
(72340, 42, 20, 'Categorias Relacionadas ao Aborto'),
(72341, 43, 20, 'Abortos'),
(72342, 44, 20, 'Sobre o calendário'),
(72343, 46, 20, 'Ausências por Diagnóstico'),
(72344, 47, 20, 'Aceitar Tarefa'),
(72345, 48, 20, 'Aceitar Pagamento para'),
(72346, 49, 20, 'Aceitar Pagamento para'),
(72347, 50, 20, 'Aceitar Tarefa'),
(72348, 51, 20, 'Controle de Acesso'),
(72349, 52, 20, 'Controle de Acesso da Lista de Administração'),
(72350, 53, 20, 'Data de acesso'),
(72351, 54, 20, 'Acesso não permitido'),
(72352, 55, 20, 'Acesso Não Autorizado'),
(72353, 56, 20, 'Acesse o Portal do Paciente'),
(72354, 57, 20, 'Acidente'),
(72355, 59, 20, 'Nome da Conta'),
(72356, 62, 20, 'Contabilidade'),
(72357, 64, 20, 'Dores'),
(72358, 65, 20, 'Solicitação de Requisição (ISA14)'),
(72359, 66, 20, 'Reconhecimentos, Licenciamento e Certificação'),
(72360, 67, 20, 'Acesso'),
(72361, 68, 20, 'Administração de Acesso'),
(72362, 69, 20, 'Administração de Acesso Não Autorizada'),
(72363, 70, 20, 'ACL atualizado com sucesso'),
(72364, 71, 20, 'Acne'),
(72365, 72, 20, 'Procedimento'),
(72366, 73, 20, 'Data do Procedimento'),
(72367, 74, 20, 'Ação'),
(72368, 75, 20, 'Ações'),
(72369, 77, 20, 'Ativar Relatórios CCR/CCD'),
(72370, 78, 20, 'Ativo'),
(72371, 79, 20, 'Alerta Ativo'),
(72372, 80, 20, 'Regras de Alerta Ativo'),
(72373, 81, 20, 'Alertas Ativos/Lembretes'),
(72374, 82, 20, 'Consulta Ativa'),
(72375, 84, 20, 'Listas ativas'),
(72376, 85, 20, 'Paciente Ativo'),
(72377, 86, 20, 'Planos Ativos'),
(72378, 87, 20, 'Atividade'),
(72379, 88, 20, 'Tipo de Atividade'),
(72380, 90, 20, 'Intoxicação Aguda/Isolamento'),
(72381, 91, 20, 'Manifestação aguda de uma condição crônica'),
(72382, 92, 20, 'Aguda sobre crônica'),
(72383, 93, 20, 'adicionar'),
(72384, 94, 20, 'Adicionar'),
(72385, 95, 20, 'ADICIONAR'),
(72386, 96, 20, 'Adicionar uma Empresa'),
(72387, 98, 20, 'Adicionar uma Farmácia'),
(72388, 100, 20, 'adicionar um evento para '),
(72389, 101, 20, 'Adicionar como uma nova nota'),
(72390, 102, 20, 'Adicionar como Novo'),
(72391, 104, 20, 'Adicionar Botões'),
(72392, 105, 20, 'Adicionar Botões para Caracteres especiais, Textos para serem exibidos no topo do editor para inclusão do texto em um Clique'),
(72393, 106, 20, 'Adicionar Categoria'),
(72394, 107, 20, 'Adicionar Constante'),
(72395, 108, 20, 'Adicionar Contexto'),
(72396, 109, 20, 'Adicionar Co-Pagamento'),
(72397, 110, 20, 'Adicionar Critério'),
(72398, 111, 20, 'Adicionar Botão Customizado'),
(72399, 112, 20, 'Adicionar Diagnóstico'),
(72400, 113, 20, 'Adicionar Medicamento'),
(72401, 114, 20, 'Adicionar Consulta'),
(72402, 115, 20, 'Adicionar Consulta/Notas'),
(72403, 116, 20, 'Adicionar Clínica'),
(72404, 117, 20, 'Adicionar Campo'),
(72405, 118, 20, 'Adicionar estas linhas ao arquivo de configuração do Servidor Web (Apache)'),
(72406, 119, 20, 'Adicionar Grupo'),
(72407, 120, 20, 'Adicionar Código CID'),
(72408, 121, 20, 'Adicionar Imunização'),
(72409, 122, 20, 'Não está autorizado adicionar!'),
(72410, 123, 20, 'Adicionar Ocorrência'),
(72411, 124, 20, 'Adicionar item para localizar'),
(72412, 125, 20, 'Adicionar Idioma'),
(72413, 126, 20, 'Adicionar Novo'),
(72414, 127, 20, 'Adicionar novo'),
(72415, 128, 20, 'Adicionar nova categoria: '),
(72416, 129, 20, 'Adicione certificados novos ao arquivo de configuração do Servidor Web (Apache)'),
(72417, 130, 20, 'Adicionar novo componente'),
(72418, 131, 20, 'Adicionar novos componentes'),
(72419, 132, 20, 'Adicionar Novo Grupo'),
(72420, 134, 20, 'Adicionar novo lote e transação'),
(72421, 135, 20, 'Adicionar Nova Observação'),
(72422, 136, 20, 'Adicionar nova observação'),
(72423, 137, 20, 'Adicionar Novo Parceiro'),
(72424, 138, 20, 'Adicionar Novo Paciente'),
(72425, 140, 20, 'Adicionar Observação'),
(72426, 141, 20, 'Adicionar Registro de Paciente'),
(72427, 142, 20, 'Adicionar Receita'),
(72428, 143, 20, 'Adicionar Procedimento'),
(72429, 144, 20, 'Adicionar o número da operadora.'),
(72430, 145, 20, 'Adicionar Reabilitação'),
(72431, 146, 20, 'Adicionar Regra'),
(72432, 147, 20, 'Adicionar a'),
(72433, 148, 20, 'Adicionar a Lista de Medicamentos'),
(72434, 149, 20, 'Adicionar nível superior'),
(72435, 150, 20, 'Adicionar Transação'),
(72436, 151, 20, 'Adicionar Usuário'),
(72437, 152, 20, 'Adicionar Usuário ao Grupo'),
(72438, 153, 20, 'Adicionar/Editar eRx'),
(72439, 154, 20, 'Adicionar/Editar Transação de Paciente'),
(72440, 155, 20, 'adicionado'),
(72441, 156, 20, 'Não esta autorizado adicionar dados cadastrais.'),
(72442, 157, 20, 'Adicionar item para controlar falhou'),
(72443, 158, 20, 'Síndrome de Addison'),
(72444, 159, 20, 'Síndrome de Addison'),
(72445, 160, 20, 'Características adicionais'),
(72446, 161, 20, 'Diagnósticos Adicionais:'),
(72447, 162, 20, 'Histórico Adicional'),
(72448, 163, 20, 'Observação adicionais do histórico'),
(72449, 164, 20, 'Informações Adicionais'),
(72450, 165, 20, 'Laboratórios Complementares'),
(72451, 166, 20, 'Observações Adicionais'),
(72452, 167, 20, 'Observações ou recomendação adicionais para este resultado'),
(72453, 168, 20, 'Observações Adicionais:'),
(72454, 169, 20, 'Observações Adicionais: '),
(72455, 170, 20, 'Observações Adicionais do Raio-X:'),
(72456, 171, 20, 'Adicionalmente, o correspondente pacote de extensão US Snomed pode ser importado separadamente após a instalação do Snomed Internacional liberado (Versão em Inglês).'),
(72457, 172, 20, 'somente adicionar'),
(72458, 173, 20, 'Agenda'),
(72459, 174, 20, 'Agenda'),
(72460, 175, 20, 'Endereço'),
(72461, 178, 20, 'Lista de Endereços'),
(72462, 179, 20, 'Cadastro de empresa que realiza este procedimento'),
(72463, 180, 20, 'Cadastro do distribuidor'),
(72464, 181, 20, 'Cadastro do vendedor'),
(72465, 182, 20, 'Tipos de Cadastros'),
(72466, 183, 20, 'Etiqueta de endereço'),
(72467, 187, 20, 'Endereço1'),
(72468, 188, 20, 'Endereço2'),
(72469, 189, 20, 'DESTINATÁRIO'),
(72470, 190, 20, 'Ajt'),
(72471, 191, 20, 'Ajt Quant'),
(72472, 192, 20, 'Ajuste'),
(72473, 193, 20, 'Correção'),
(72474, 194, 20, 'Valor de Correção'),
(72475, 195, 20, 'Razões da Correção'),
(72476, 196, 20, 'Correção para o código '),
(72477, 197, 20, 'Correções'),
(72478, 198, 20, 'Adm Correção'),
(72479, 199, 20, 'Admin'),
(72480, 200, 20, 'E-mail do Administrador'),
(72481, 201, 20, 'Administrar Por'),
(72482, 202, 20, 'Administrado'),
(72483, 203, 20, 'Administrado Por'),
(72484, 204, 20, 'Data de administraçao'),
(72485, 205, 20, 'Site Administrado'),
(72486, 206, 20, 'Administração'),
(72487, 207, 20, 'Adminstração do Site'),
(72488, 208, 20, 'Administradores'),
(72489, 209, 20, 'Administradores podem fazer qualquer operação'),
(72490, 210, 20, 'Data da Admissão'),
(72491, 212, 20, 'Peso Adulto de Triagem e Acompanhamento'),
(72492, 213, 20, 'Peso Adulto de Triagem e Acompanhamento (CQM)'),
(72493, 214, 20, 'Diretiva Avançada'),
(72494, 215, 20, 'Diretivas Avançadas'),
(72495, 216, 20, 'Aviso de Diretivas Avançadas'),
(72496, 218, 20, 'Avançado'),
(72497, 219, 20, 'Recomendação'),
(72498, 220, 20, 'Longe'),
(72499, 221, 20, 'Afetado normal'),
(72500, 223, 20, 'Chamadas após hrs'),
(72501, 224, 20, 'Após a migração dos mecanismos senha antiga, onde as senhas são armazenados na tabela de usuários sem sal é completa, esta flag deve ser definida para falça para que apenas a autenticação pelo novo método seja possível.'),
(72502, 225, 20, 'Após aplicar as configurações acima, importe o certificado cliente do administrador para o Browser e reinicie o Servidor Apache (Senha em Branco)'),
(72503, 226, 20, 'Após salvar o PDF, clique em [Visualizar Log] para verificar erros.'),
(72504, 227, 20, 'Depois de salvar o(s) arquivo(s) em Texto, clique sob [Visualizar Log] para verificar por erros'),
(72505, 228, 20, 'Após salvar o seu lote, clique em [Visualizar Log] para verificar erros'),
(72506, 230, 20, 'Após inserir corretamente os dados, clique no botão Salvar.'),
(72507, 232, 20, 'Planejamento de Pós-tratamento'),
(72508, 233, 20, 'Novamente'),
(72509, 234, 20, 'Idade'),
(72510, 235, 20, 'Por idade'),
(72511, 236, 20, 'Idade Categoria'),
(72512, 237, 20, 'Dados da idade está fora do intervalo.'),
(72513, 238, 20, 'Formato de Exibição da Idade'),
(72514, 239, 20, 'Formato da Idade "" DE "" não é válido'),
(72515, 240, 20, 'Formato da Idade "" ATÉ "" não é válido'),
(72516, 241, 20, 'De Idade'),
(72517, 242, 20, 'Idade em Anos para Alterar Formato de Exibição'),
(72518, 243, 20, 'Idade máxima'),
(72519, 244, 20, 'Idade mínima'),
(72520, 245, 20, 'Intervalo de Idade'),
(72521, 247, 20, 'Colunas Envelhecimento:'),
(72522, 249, 20, 'Albanês'),
(72523, 250, 20, 'Álcool'),
(72524, 251, 20, 'Consumo de álcool'),
(72525, 252, 20, 'Uso de álcool'),
(72526, 253, 20, 'Número de alertas'),
(72527, 255, 20, 'Alertas'),
(72528, 258, 20, 'Aleútes(Comunidade Indígena)'),
(72529, 259, 20, 'Todos'),
(72530, 260, 20, 'TODOS'),
(72531, 261, 20, 'Todos (Comparado Formato A)'),
(72532, 262, 20, 'Todos (Comparado Formato B)'),
(72533, 263, 20, 'Todos (Acumulativo)'),
(72534, 265, 20, 'Todos Cálculos de Medida Automatizados (CMA)'),
(72535, 266, 20, 'Todas as Categorias'),
(72536, 267, 20, 'Todas Medidas de Qualidade Clínica (MQC)'),
(72537, 268, 20, 'Todos os códigos'),
(72538, 269, 20, 'O Dia Inteiro'),
(72539, 270, 20, 'Evento durante o dia inteiro'),
(72540, 271, 20, 'Todos os campos demográficos, com pesquisa e dupla verificação'),
(72541, 272, 20, 'Todas as Clínicas'),
(72542, 273, 20, 'Todas as Feridas/Problemas/Assuntos'),
(72543, 274, 20, 'Todas as Linguagens são Permitidas'),
(72544, 276, 20, 'Parte ou todo primeiro nome'),
(72545, 277, 20, 'Parte ou todo sobrenome'),
(72546, 278, 20, 'Todos ou parte da organização'),
(72547, 280, 20, 'Todos os Produtos'),
(72548, 281, 20, 'Todos os Médicos'),
(72549, 282, 20, 'Todos Opinião e negativos:'),
(72550, 283, 20, 'Todos os Tópicos'),
(72551, 284, 20, 'Todos os Médicos'),
(72552, 285, 20, 'Alérgica'),
(72553, 286, 20, 'Alergias'),
(72554, 287, 20, 'Alergias:'),
(72555, 288, 20, 'Alergia'),
(72556, 289, 20, 'Importação de Alergias completadas com sucesso'),
(72557, 290, 20, 'Lista de Questões de Alergia'),
(72558, 291, 20, 'Reação alérgica'),
(72559, 294, 20, 'Alocar'),
(72560, 295, 20, 'Permitir'),
(72561, 296, 20, 'Permitir todas as línguas disponíveis como escolha no menu do login'),
(72562, 297, 20, 'Permitir a criação de pedidos contendo diagnósticos, mas não os procedimentos ou encargos financeiros. A maioria das clínicas não usa esta opção.'),
(72563, 298, 20, 'Permitir Língua de Depuração'),
(72564, 299, 20, 'Permitir Mala Direta'),
(72565, 300, 20, 'Permitir mensagens de e-mail?'),
(72566, 301, 20, 'Permitir Mala Direta?'),
(72567, 302, 20, 'Permitir Consultas devida Reclamações'),
(72568, 303, 20, 'Permitir Troca de Informações de Saúde.'),
(72569, 304, 20, 'Permitir Compartilhamento de Informações de Imunização'),
(72570, 305, 20, 'Permitir Uso de Registros de Imunização'),
(72571, 306, 20, 'Permitir Mensagem de e-mail'),
(72572, 308, 20, 'Permitir acesso ao portal do paciente'),
(72573, 309, 20, 'Permitir SMS'),
(72574, 310, 20, 'Permitir mensagens SMS (texto)?'),
(72575, 311, 20, 'Permitir que os eventos submetidos a ser feito ativo imediatamente?'),
(72576, 312, 20, 'Permitir mensagens de telefone?'),
(72577, 313, 20, 'Permitir que os usuários publiquem Eventos globais'),
(72578, 314, 20, 'Permitir que os usuários publiquem calendários pessoais'),
(72579, 315, 20, 'Permitir Correio de Voz'),
(72580, 316, 20, 'Permitido'),
(72581, 317, 20, 'Idiomas Permitidos'),
(72582, 318, 20, 'Permitido'),
(72583, 323, 20, 'Já existe.'),
(72584, 324, 20, 'Já existe.'),
(72585, 325, 20, 'Já utilizados, escolha outro identificador'),
(72586, 326, 20, 'Já usado, escolher um outro título'),
(72587, 327, 20, 'Alt Endereço'),
(72588, 328, 20, 'alterar'),
(72589, 329, 20, 'Alternativamente, você pode utilizar a página de pesquisa para enviar uma remessa eletrônica (X12 835 arquivos) que você tenha obtido a partir do seu autor ou câmara de compensação. Você pode fazer isso clicando no botão Procurar e selecionar o arquivo para upload, e depois clique em Procurar para realizar o upload e mostrar as faturas correspondentes. Neste caso, os outros parâmetros mencionados acima não se aplicam e serão ignorados. Uploading salva o arquivo, mas não ainda processo seu conteúdo - que é feito separadamente, como descrito abaixo.'),
(72590, 330, 20, 'AM'),
(72591, 331, 20, 'Programa AM'),
(72592, 332, 20, 'AMC'),
(72593, 333, 20, 'Rastreamento AMC'),
(72594, 338, 20, 'Alterar a nota existente'),
(72595, 339, 20, 'Alterado a partir de'),
(72596, 340, 20, 'Alteração de Status'),
(72597, 341, 20, 'Alterações'),
(72598, 342, 20, 'Alterações de'),
(72599, 343, 20, 'Índio Americano'),
(72600, 344, 20, 'Índio Americano ou nativo do Alaska'),
(72601, 345, 20, 'AMEX'),
(72602, 346, 20, 'Amárico'),
(72603, 347, 20, 'Valor'),
(72604, 348, 20, 'Valor Administrado'),
(72605, 349, 20, 'Total de valores'),
(72606, 350, 20, 'Quantidade de passadas de balanço'),
(72607, 351, 20, 'Montante para esta consulta'),
(72608, 352, 20, 'Valor pago'),
(72609, 353, 20, 'Valor:'),
(72610, 354, 20, 'Valor Faturado'),
(72611, 355, 20, 'Uma data de término posterior a data de início é necessário para eventos repetidos!'),
(72612, 356, 20, 'Ocorreu um erro assinar o formulário'),
(72613, 357, 20, 'Ocorreu um erro enquanto se limpava a árvore de diretórios Web do LibreEHR.'),
(72614, 358, 20, 'Ocorreu um erro enquanto se limpava a árvore de diretórios Web do phpGACL.'),
(72615, 359, 20, 'Ocorreu um erro enquanto se limpava a árvore de diretórios Web do SQL-Ledger.'),
(72616, 360, 20, 'Uma questão GCAC incompleta foi criado e vinculado. Alguém terá de concluí-lo mais tarde.'),
(72617, 362, 20, 'Um erro inesperado ocorreu.'),
(72618, 363, 20, 'Um erro inesperado ocorreu.'),
(72619, 365, 20, 'E'),
(72620, 366, 20, 'E'),
(72621, 367, 20, 'e'),
(72622, 368, 20, 'e '),
(72623, 369, 20, 'e todos os dados referentes à ele? Esta ação será registrada'),
(72624, 370, 20, 'e modificado'),
(72625, 371, 20, 'e processado'),
(72626, 372, 20, 'e reinicie o servidor Apache'),
(72627, 373, 20, 'e o Motivo é'),
(72628, 374, 20, 'Anemia'),
(72629, 375, 20, 'Tornozelo'),
(72630, 376, 20, 'Tornozelo + calcanhar'),
(72631, 377, 20, 'Tornozelo Formulário de Avaliação'),
(72632, 378, 20, 'Problemas do Tornozelo'),
(72633, 379, 20, 'Espondilite Sondlilitis'),
(72634, 380, 20, 'Espondilite Spondlilitis'),
(72635, 381, 20, 'Anorexia'),
(72636, 382, 20, 'Outra coisa que você pode fazer na janela de postagem é de faturamento pedido secundário. Se você selecionar esta opção antes de salvar, em seguida, o pedido inicial será re-aberto e em fila na página de faturamento, e será processada durante a execução do próximo pagamento.'),
(72637, 383, 20, 'ante'),
(72638, 384, 20, 'Nl ânus, sem ternura retal / massa'),
(72639, 385, 20, 'Ansiedade'),
(72640, 386, 20, 'Tds'),
(72641, 387, 20, 'Qualquer Categoria'),
(72642, 388, 20, 'Qualquer parte do código desejado ou sua descrição'),
(72643, 389, 20, 'Qualquer parte da especialidade pretendida'),
(72644, 390, 20, 'Qualquer parte do código ou nome do remédio'),
(72645, 391, 20, 'Qualquer parte do código ou nome da imunização'),
(72646, 392, 20, 'Qualquer parte do nome do paciente, ou ""último, primeiro "" ou ""XY ""'),
(72647, 393, 20, 'Qualquer outra Informação Relevante'),
(72648, 394, 20, 'Chave API para SMS Gateway'),
(72649, 395, 20, 'Apnéia'),
(72650, 396, 20, 'Aparência'),
(72651, 397, 20, 'Aparência:'),
(72652, 398, 20, 'Anexar esta nota'),
(72653, 399, 20, 'Anexar à nota existente'),
(72654, 400, 20, 'Acrescentar a esta nota'),
(72655, 401, 20, 'Acrescentar a esta nota'),
(72656, 402, 20, 'Apendicectomia'),
(72657, 404, 20, 'Pacientes Aplicáveis'),
(72658, 405, 20, 'Aplicação'),
(72659, 406, 20, 'Nome da aplicação para a página de login e título da janela principal'),
(72660, 407, 20, 'Código Aplicação Receptor (GS03 - se branco ISA08 será usado)'),
(72661, 408, 20, 'Código de Envio da Aplicação(GS02)'),
(72662, 409, 20, 'Título da Aplicação'),
(72663, 410, 20, 'Aplicar ao formulário Vital e Gráfico de Crescimento.'),
(72664, 411, 20, 'Aplicar ao formulário Vital'),
(72665, 412, 20, 'Aplicar as mudanças apenas aos eventos atuais, para esta e futuras ocorrencias, ou para todas as ocorrencias?'),
(72666, 413, 20, 'Aplicar a zona afetada'),
(72667, 414, 20, 'Aplicar na pele'),
(72668, 415, 20, 'Aplicando'),
(72669, 416, 20, 'Aplicando Correção ao site'),
(72670, 417, 20, 'Consulta'),
(72671, 418, 20, 'Data da Consulta'),
(72672, 419, 20, 'Estilo de Apresentação das Consultas'),
(72673, 420, 20, 'Regras de Lembrete de Consulta'),
(72674, 421, 20, 'Status da Consulta'),
(72675, 422, 20, 'Status das Consultas'),
(72676, 423, 20, 'Consulta dentro de'),
(72677, 424, 20, 'Consulta/Cor do Evento'),
(72678, 425, 20, 'Consultas'),
(72679, 426, 20, 'Consultas (escrever opcional)'),
(72680, 427, 20, 'Consultas (escrever opcional)'),
(72681, 430, 20, 'Consultas e Visitas'),
(72682, 431, 20, 'Relatório de Consultas'),
(72683, 432, 20, 'Relatório de Consultas e Visitas'),
(72684, 434, 20, 'Aprovar'),
(72685, 436, 20, 'Aprovado'),
(72686, 437, 20, 'Aprovado Eventos Administração'),
(72687, 440, 20, 'Consulta'),
(72688, 441, 20, 'Consultas'),
(72689, 442, 20, 'Abr.'),
(72690, 443, 20, 'Abril'),
(72691, 444, 20, 'Árabe'),
(72692, 446, 20, 'Arquivar'),
(72693, 447, 20, 'Os nomes dos grupos de controle de acesso devem ser traduzidos?'),
(72694, 448, 20, 'Os nomes das categorias de consulta devem ser traduzidos?'),
(72695, 449, 20, 'Os nomes das categorias dos documentos devem ser traduzidos?'),
(72696, 450, 20, 'É adicionada alguma cobrança para este tipo?'),
(72697, 451, 20, 'É necessário traduzir o título das notas do paciente?'),
(72698, 452, 20, 'Os códigos armazenados das tabelas sql externas são (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(72699, 453, 20, 'Você está preparado para completar um problema GCAC novo para essa visita?'),
(72700, 454, 20, 'Tem certeza que deseja postar para hoje?'),
(72701, 455, 20, 'Tem certeza que deseja aprovar esses eventos?'),
(72702, 457, 20, 'Você tem certeza que quer remover completamente este formulário?'),
(72703, 458, 20, 'Você tem certeza que quer excluir?'),
(72704, 459, 20, 'Você tem certeza que quer remover esta divulgação'),
(72705, 460, 20, 'Tem certeza de que deseja excluir este evento?'),
(72706, 461, 20, 'Você tem certeza de que deseja deletar esse item do banco de dados?'),
(72707, 462, 20, 'Tem certeza de que deseja excluir esta nota?'),
(72708, 464, 20, 'Tem certeza que deseja editar estes eventos?'),
(72709, 465, 20, 'Tem certeza que deseja ocultar estes eventos?'),
(72710, 466, 20, 'Você está certo de que quer transmiti-la novamente?'),
(72711, 467, 20, 'Você tem certeza que quer ver estes eventos?'),
(72712, 468, 20, 'Tem certeza de que deseja apagar todo o grupo denominado'),
(72713, 469, 20, 'Tem certeza de que deseja apagar toda a lista'),
(72714, 470, 20, 'Tem certeza de que deseja excluir o campo em'),
(72715, 471, 20, 'Tem certeza de que deseja apagar os campos selecionados?'),
(72716, 472, 20, 'Tem certeza de que deseja continuar com estas ações?'),
(72717, 473, 20, 'Área não especificada'),
(72718, 474, 20, 'braço'),
(72719, 475, 20, 'Armênio'),
(72720, 477, 20, 'Arritmia'),
(72721, 478, 20, 'Artrite'),
(72722, 479, 20, 'Artrite / Doenças Degenerativas conjunta'),
(72723, 480, 20, 'Artrite / doença articular Degenerativa'),
(72724, 481, 20, 'como'),
(72725, 482, 20, 'Como De'),
(72726, 483, 20, 'ASC'),
(72727, 484, 20, 'Asiático'),
(72728, 487, 20, 'EFE'),
(72729, 488, 20, 'Atribuído a'),
(72730, 489, 20, 'Assistente'),
(72731, 490, 20, 'Asma'),
(72732, 491, 20, 'em'),
(72733, 492, 20, 'Pelo menos um parâmetro de procura é necessário se você selecionar Todos.'),
(72734, 493, 20, 'No navicular'),
(72735, 494, 20, 'At the navicular:'),
(72736, 495, 20, 'Time Atletico'),
(72737, 496, 20, 'Time Atletico'),
(72738, 497, 20, 'Atlético / Prejuízo'),
(72739, 498, 20, 'Certificado CA auditado ATNA'),
(72740, 499, 20, 'Convidado de Auditoria ATNA'),
(72741, 500, 20, 'Certificado local de Auditoria ATNA'),
(72742, 501, 20, 'Porta de Auditoria ATNA'),
(72743, 503, 20, 'Atenção'),
(72744, 504, 20, 'À atenção de'),
(72745, 506, 20, 'Auditar Motor de Consultas CDR'),
(72746, 507, 20, 'Registro de auditoria adulterado'),
(72747, 509, 20, 'Auditar Registros de Backups'),
(72748, 510, 20, 'Auditar Registros Diversos'),
(72749, 511, 20, 'Auditar Registros de Pagamentos'),
(72750, 512, 20, 'Auditar Registros de Prontuários'),
(72751, 513, 20, 'Auditar Registros de Agendamento'),
(72752, 514, 20, 'Auditar Registros de Administração de Segurança'),
(72753, 515, 20, 'Auditar Registros de Consultas "SELECT"'),
(72754, 516, 20, 'Ago.'),
(72755, 517, 20, 'Agosto'),
(72756, 519, 20, 'Aut.'),
(72757, 520, 20, 'Aut. / notas'),
(72758, 523, 20, 'Grupo de Autorização'),
(72759, 524, 20, 'Status de Autorização'),
(72760, 525, 20, 'Autorizações'),
(72761, 526, 20, 'Autorizar'),
(72762, 527, 20, 'Autorizar - quaisquer Consultas'),
(72763, 528, 20, 'Autorizar - minhas Consultas'),
(72764, 529, 20, 'Autorizar.net'),
(72765, 530, 20, 'Autorizado'),
(72766, 531, 20, 'Autorizado Apenas'),
(72767, 532, 20, 'Auto Enviar'),
(72768, 535, 20, 'Criação automática de novos encontros.'),
(72769, 536, 20, 'Auto-gerar'),
(72770, 537, 20, 'Cálculo Automático de Medida (CAM)'),
(72771, 538, 20, 'Cálculo Automático de Medida (CAM) - 2011'),
(72772, 539, 20, 'Cálculo Automático de Medida (CAM) - 2014'),
(72773, 542, 20, 'Rastreamento Cálculo Automático de Medida (CAM)'),
(72774, 543, 20, 'Medidas Automáticas'),
(72775, 544, 20, 'Automático'),
(72776, 546, 20, 'automaticamente cria um novo encontro quando o estado do anterior é "@" (chegado)'),
(72777, 549, 20, 'Automóvel Médico'),
(72778, 550, 20, 'salvar automático'),
(72779, 551, 20, 'Categorias disponíveis'),
(72780, 552, 20, 'Horário Disponível'),
(72781, 553, 20, 'Faixas disponíveis'),
(72782, 555, 20, 'há muitos tipos de entiqueta para imprimir entiquetas para pacientes e notificaçoes na aba de navegaçao à esquerda'),
(72783, 557, 20, 'Média Mensal'),
(72784, 558, 20, 'A fratura por avulsão /'),
(72785, 559, 20, 'Avulsão do maléolo lateral'),
(72786, 560, 20, 'Avulsão do maléolo medial '),
(72787, 561, 20, 'Conscientização-Based'),
(72788, 562, 20, 'Axilar'),
(72789, 565, 20, 'b.i.d.'),
(72790, 566, 20, 'Voltar'),
(72791, 567, 20, 'voltar'),
(72792, 568, 20, 'Voltar oito visitas'),
(72793, 569, 20, 'Voltar onze visitas'),
(72794, 570, 20, 'Voltar cinco visitas'),
(72795, 571, 20, 'Voltar quatro visitas'),
(72796, 572, 20, 'Voltar nove visitas'),
(72797, 573, 20, 'Voltar uma visita'),
(72798, 574, 20, 'Dor nas Costas'),
(72799, 575, 20, 'Problemas nas costas'),
(72800, 576, 20, 'Voltar sete visitas'),
(72801, 577, 20, 'Voltar seis visitas'),
(72802, 578, 20, 'Voltar Cirurgia'),
(72803, 579, 20, 'Voltar dez visitas'),
(72804, 580, 20, 'Voltar três visitas'),
(72805, 581, 20, 'Voltar a Pág. Administração'),
(72806, 582, 20, 'Voltar para encontrar'),
(72807, 583, 20, 'Voltar ao Paciente'),
(72808, 584, 20, 'Voltar ao Paciente'),
(72809, 585, 20, 'Voltar a Usuários'),
(72810, 586, 20, 'Voltar à modo Visualização'),
(72811, 587, 20, 'Voltar doze visitas'),
(72812, 588, 20, 'Voltar duas visitas'),
(72813, 589, 20, 'Serviços de fundo'),
(72814, 590, 20, 'Backup'),
(72815, 591, 20, 'O arquivo de backup foi criado. Agora enviará o download.'),
(72816, 592, 20, 'Lista de backup'),
(72817, 593, 20, 'Backup feito com sucesso em'),
(72818, 594, 20, 'Cheque ruim'),
(72819, 595, 20, 'Dívida incobrável'),
(72820, 596, 20, 'Bahasa Indonésia'),
(72821, 597, 20, 'Sal'),
(72822, 598, 20, 'Saldo'),
(72823, 599, 20, 'equilíbrio'),
(72824, 600, 20, 'Valor do Saldo'),
(72825, 601, 20, 'Saldo devedor'),
(72826, 603, 20, 'Banco de Rascunhos'),
(72827, 604, 20, 'Código de barras'),
(72828, 605, 20, 'Tipo de código de barras'),
(72829, 607, 20, 'Base de quinta (5) Metarsal'),
(72830, 608, 20, 'Base de quinta (5) Metarsal:'),
(72831, 611, 20, 'Reivindicação em lote'),
(72832, 612, 20, 'Lote Ferramenta de Comunicação'),
(72833, 613, 20, 'Processamento em lote das entradas de pagamento'),
(72834, 614, 20, 'Pagamentos em lote'),
(72835, 615, 20, 'Processamento em lote iniciado, o que pode demorar um pouco.'),
(72836, 616, 20, 'Resultados do Processamento em Lote.'),
(72837, 617, 20, 'BatchCom'),
(72838, 618, 20, 'Seja paciente, alguns arquivos podem demorar alguns minutos para processar!'),
(72839, 619, 20, 'porque esse id não existe.'),
(72840, 620, 20, 'Começo'),
(72841, 621, 20, 'Data inicial'),
(72842, 623, 20, 'Data de início do serviço aaaa-mm-dd'),
(72843, 624, 20, 'Hora de início de eventos na agenda'),
(72844, 626, 20, 'Arroto'),
(72845, 628, 20, 'Bengali'),
(72846, 630, 20, 'entre'),
(72847, 631, 20, 'Bidirecional'),
(72848, 633, 20, 'Bilateral'),
(72849, 634, 20, 'Bilateral:'),
(72850, 636, 20, 'Data da Conta:'),
(72851, 637, 20, 'Conta / Recolher'),
(72852, 638, 20, 'Faturado'),
(72853, 640, 20, 'Faturamento'),
(72854, 641, 20, 'Faturamento (escrever opcional)'),
(72855, 642, 20, 'À atenção de faturamento'),
(72856, 644, 20, 'Código de faturamento para os serviços solicitados'),
(72857, 645, 20, 'Códigos de faturamento'),
(72858, 646, 20, 'Informações para Cobrança.'),
(72859, 647, 20, 'Faturamento do Departamento'),
(72860, 648, 20, 'Faturamento das Instalações'),
(72861, 649, 20, 'Informações de faturamento'),
(72862, 650, 20, 'Faturamento Localização'),
(72863, 655, 20, 'Gerente de Cobranças'),
(72864, 656, 20, 'Nota de faturamento'),
(72865, 657, 20, 'Nota de faturamento para '),
(72866, 658, 20, 'Nota de faturamento'),
(72867, 659, 20, 'Fila resultados de faturamento'),
(72868, 660, 20, 'Relatório de faturamento'),
(72869, 661, 20, 'Status de faturamento'),
(72870, 662, 20, 'Status de Cobrança = Não Faturado'),
(72871, 663, 20, 'faturamento para '),
(72872, 665, 20, 'Biópsia'),
(72873, 666, 20, 'Data de Nascimento'),
(72874, 667, 20, 'Nascimento - 24 meses'),
(72875, 669, 20, 'Preto'),
(72876, 670, 20, 'Antracose'),
(72877, 671, 20, 'Negro ou Afro-Americano'),
(72878, 672, 20, 'Cancro da bexiga'),
(72879, 673, 20, 'As infecções da bexiga'),
(72880, 674, 20, 'Formulários em branco'),
(72881, 675, 20, 'Problemas de sangramento'),
(72882, 676, 20, 'Pontos cegos'),
(72883, 677, 20, 'Inchação'),
(72884, 678, 20, 'Bloqueados'),
(72885, 679, 20, 'Sangue'),
(72886, 680, 20, 'Pressão Arterial'),
(72887, 681, 20, 'A pressão arterial'),
(72888, 682, 20, 'Nariz Ensang.'),
(72889, 683, 20, 'Blue Cross Blue Shield'),
(72890, 684, 20, 'As linhas azuis neste relatório são informativos. Linhas pretas mostram informações previamente existentes. Linhas verdes mostram as alterações que foram aplicadas com êxito. As linhas vermelhas indicam erros ou alterações que não foram aplicadas, estas deverão ser processadas manualmente. Atualmente, negou as acusações e reversões de pagamento não é feito automaticamente e assim que aparecem em vermelho.'),
(72891, 685, 20, 'Visão turva'),
(72892, 686, 20, 'IMC'),
(72893, 687, 20, 'IMC Status'),
(72894, 689, 20, 'Corpo Região'),
(72895, 690, 20, 'Lado do corpo'),
(72896, 691, 20, 'lado do corpo , se aplicavel'),
(72897, 692, 20, 'Ternura Bone:'),
(72898, 693, 20, 'Bone Ternura: do maléolo medial'),
(72899, 694, 20, 'Boolean'),
(72900, 696, 20, 'Inf.'),
(72901, 697, 20, 'Ambas as orelhas'),
(72902, 698, 20, 'ambas as orelhas'),
(72903, 699, 20, 'Fundo'),
(72904, 700, 20, 'Margem inferior (px)'),
(72905, 701, 20, 'BOX Emprego A. 10 relacionados '),
(72906, 702, 20, 'BOX 10 B. Auto Accident '),
(72907, 703, 20, 'BOX 10 C. Outros Acidentes '),
(72908, 706, 20, 'BOX 15. Data de doença igual ou semelhante (aaaa-mm-dd):'),
(72909, 708, 20, 'BOX 16. Data incapaz de trabalhar a partir de (aaaa-mm-dd):'),
(72910, 709, 20, 'BOX 16. Data incapaz de trabalhar a (aaaa-mm-dd):'),
(72911, 710, 20, 'BOX 18. Data de Internação (aaaa-mm-dd): '),
(72912, 711, 20, 'BOX 18. Data de Internação (aaaa-mm-dd): '),
(72913, 712, 20, 'BOX 20. Fora do laboratório é utilizado?'),
(72914, 713, 20, 'BOX 22. Medicaid Reapresentação Código (CID-9) '),
(72915, 714, 20, 'BOX 23. º Autorização prévia '),
(72916, 715, 20, 'PA'),
(72917, 716, 20, 'PA diastólica'),
(72918, 717, 20, 'PA sistólica'),
(72919, 719, 20, 'Bpd'),
(72920, 721, 20, 'Bps'),
(72921, 722, 20, 'Português do Brasil'),
(72922, 723, 20, 'Mama'),
(72923, 724, 20, 'Biópsia de mama'),
(72924, 725, 20, 'Quitação de mama');
INSERT INTO `lang_definitions` VALUES
(72925, 726, 20, 'Doença da Mama'),
(72926, 727, 20, 'Exame de Mama'),
(72927, 728, 20, 'Massa de mama'),
(72928, 730, 20, 'Respiração:'),
(72929, 731, 20, 'Bretão'),
(72930, 732, 20, 'Fratura Osséa'),
(72931, 733, 20, 'Formulário quebrado'),
(72932, 734, 20, 'Bronquite Forma'),
(72933, 735, 20, 'Navegue'),
(72934, 736, 20, 'Navegue até à ficha'),
(72935, 737, 20, 'Contusão / hematoma'),
(72936, 738, 20, 'Búlgaro'),
(72937, 739, 20, 'Abaulamento Direita:'),
(72938, 740, 20, 'Birmanês'),
(72939, 741, 20, 'Ardor ao urinar'),
(72940, 742, 20, 'Ardor ao urinar'),
(72941, 743, 20, 'Telefone comercial'),
(72942, 744, 20, 'Ocupado'),
(72943, 745, 20, 'mas não ainda processado.'),
(72944, 746, 20, 'Nádega'),
(72945, 747, 20, 'Nádega + S.I.'),
(72946, 748, 20, 'por'),
(72947, 749, 20, 'Por'),
(72948, 750, 20, 'pela boca'),
(72949, 751, 20, 'Por / Fonte'),
(72950, 752, 20, 'Por:'),
(72951, 753, 20, 'C'),
(72952, 754, 20, 'Certificado CA para verificação via Servidor de Syslog RFC 5425 TLS'),
(72953, 755, 20, 'Cache Lifetime (em segundos)'),
(72954, 756, 20, 'Cache modelo de produção?'),
(72955, 757, 20, 'O consumo de cafeína'),
(72956, 758, 20, 'Calendário'),
(72957, 759, 20, 'Horário de final do Calendário'),
(72958, 760, 20, 'Intervalo do Calendário'),
(72959, 761, 20, 'Tela do Calendário'),
(72960, 762, 20, 'Definições do calendário'),
(72961, 763, 20, 'Hora de Inicio do Calendário'),
(72962, 764, 20, 'Calendário UI'),
(72963, 765, 20, 'Ver Calendário'),
(72964, 766, 20, 'Chamar a atenção para addForm () vai aqui. <br>'),
(72965, 767, 20, 'Calorias'),
(72966, 768, 20, 'Cambogiano'),
(72968, 774, 20, 'Cancelar'),
(72969, 775, 20, 'Calcelar Alterações'),
(72970, 776, 20, 'Cancelado'),
(72971, 777, 20, 'Câncer'),
(72972, 778, 20, 'Investigação de malignidade: Cólon'),
(72973, 779, 20, 'Investigação de malignidade: Mamografia'),
(72974, 780, 20, 'Investigação de malignidade: Papanicolau'),
(72975, 781, 20, 'Investigação de malignidade: Próstata'),
(72976, 782, 20, 'Não é possível adicionar esta entrada, porque já existe!'),
(72977, 783, 20, 'Não é possível adicionar / actualizar esta entrada, porque já existe um duplicado!'),
(72978, 784, 20, 'não pode ser arquivado, ignorado'),
(72979, 785, 20, 'não pode ser convertido para JPEG. Talvez ImageMagick não está instalado?'),
(72980, 786, 20, 'não pode ser deletado, ignorado'),
(72981, 787, 20, 'não pode ser exibido inline porque seu tipo não é suportado pelo navegador.'),
(72982, 788, 20, 'não pode ser exibido inline porque seu tipo não é suportado pelo browser'),
(72983, 789, 20, 'não pode ser exibido inline porque seu tipo não é suportado pelo navegador.'),
(72984, 790, 20, 'Não é possível criar'),
(72985, 791, 20, 'Não é possível criar arquivo'),
(72986, 792, 20, 'Não é possível excluir arquivo (a partir de SFTP server)'),
(72987, 793, 20, 'Não é possível excluir arquivo'),
(72988, 794, 20, 'Não é possível determinar um nome de arquivo de destino'),
(72989, 795, 20, 'Não é possível localizar '),
(72990, 796, 20, 'Não é possível encontrar o nome do arquivo de destino'),
(72991, 799, 20, 'Não é possível encontrar pacientes de SQL-Ledger ID do cliente'),
(72992, 800, 20, 'Não é possível encontrar referência do documento em PostScript '),
(72993, 801, 20, 'Não é possível encontrar fornecedor de SQL-Ledger empregado = '),
(72994, 802, 20, 'Não é possível modificar Pagamentos.'),
(72995, 803, 20, 'Não é possível abrir '),
(72996, 804, 20, 'Não é possível emitir a Operadora. O pagamento selecionado é Paciente.'),
(72997, 805, 20, 'Não é possível emitir ao Paciente. O pagamento selecionado é Operadora.'),
(72998, 806, 20, 'Não é possível emitir Pagamentos.'),
(72999, 807, 20, 'Não é possível ler'),
(73000, 808, 20, 'Não é possível ler pasta'),
(73001, 809, 20, 'Não é possível atualizar porque você não está editando uma entrada existente!'),
(73002, 810, 20, 'Capitalizar'),
(73003, 811, 20, 'Capitalizar tudo'),
(73004, 812, 20, 'cápsula'),
(73005, 813, 20, 'Cartão'),
(73006, 814, 20, 'Cateterismo Cardíaco'),
(73007, 815, 20, 'Remédio Cardíaco'),
(73008, 816, 20, 'Cardiovascular'),
(73009, 821, 20, 'Danos na cartilagem / condral / disco'),
(73010, 822, 20, 'Lesão da cartilagem'),
(73011, 823, 20, 'Pulsações Cartoid nl, nl dos pulsos'),
(73012, 824, 20, 'dinheiro'),
(73013, 825, 20, 'Dinheiro'),
(73014, 826, 20, 'Dinheiro Rec'),
(73015, 827, 20, 'Pagamentos Recebidos pela Operadora'),
(73016, 828, 20, 'Catalão Valenciana'),
(73017, 829, 20, 'Cirurgia de Catarata'),
(73018, 830, 20, 'Catarata'),
(73019, 831, 20, 'Categorias'),
(73020, 832, 20, 'Categorias por'),
(73021, 833, 20, 'Categoria'),
(73022, 834, 20, 'categoria'),
(73023, 835, 20, 'Categoria '),
(73024, 836, 20, 'Categoria Detalhes'),
(73025, 837, 20, 'Limites de Categoria'),
(73026, 838, 20, 'Nome da Categoria'),
(73027, 839, 20, 'Nome da Categoria está vazia'),
(73028, 840, 20, 'Categoria/Título'),
(73029, 841, 20, 'Caucasiano'),
(73030, 842, 20, 'Recibos de casos pra imprimir encontrados/fornecer informação primária'),
(73031, 846, 20, 'CCR Aprovado'),
(73032, 847, 20, 'Avaliação Paciente CCR'),
(73033, 848, 20, 'CCR Aprovado'),
(73034, 850, 20, 'CDR'),
(73035, 851, 20, 'CDR Relatórios de Processamento'),
(73036, 852, 20, 'Celular'),
(73037, 853, 20, 'Telefone Celular'),
(73038, 854, 20, 'Numero de telefone celular'),
(73039, 855, 20, 'Número de Telefone Celular'),
(73040, 856, 20, 'Central de Certificação'),
(73041, 857, 20, 'Central/America do Sul'),
(73042, 858, 20, 'Local do arquivo CRT da certificadora não pode estar vazio'),
(73043, 859, 20, 'Local do arquivo CHAVE da certificadora não pode estar vazio'),
(73044, 860, 20, 'Certificado para enviar a RFC 5425 servidor syslog TLS.'),
(73045, 861, 20, 'Usuário Certificado'),
(73046, 862, 20, 'Certificados'),
(73047, 864, 20, 'Mastigação'),
(73048, 865, 20, 'ChampUSVA'),
(73049, 866, 20, 'alterar'),
(73050, 867, 20, 'Alterar'),
(73051, 868, 20, 'Mudança de Atividade'),
(73052, 869, 20, 'A Alteração falhou! Erro de conecção CouchDB?'),
(73053, 870, 20, 'Mudança na visão'),
(73054, 871, 20, 'Mudança na visão'),
(73055, 872, 20, 'Alterar Senha'),
(73056, 874, 20, 'Mudado'),
(73057, 875, 20, 'Mudança Intestinal'),
(73058, 876, 20, 'Mudando paciente ID para documento'),
(73059, 877, 20, 'Características'),
(73060, 878, 20, 'Caracteres Restantes'),
(73061, 879, 20, 'Carregar'),
(73062, 880, 20, 'Ajuste de despesas'),
(73063, 881, 20, 'Encargo codificado'),
(73064, 882, 20, 'Despesa'),
(73065, 883, 20, 'Gráfico'),
(73066, 884, 20, 'Gráfico de Atividade'),
(73067, 885, 20, 'Gráfico Check-in/out Relatório de Atividade'),
(73068, 886, 20, 'Gráfico ID'),
(73069, 887, 20, 'Gráfico ID:'),
(73070, 888, 20, 'Etiqueta de gráfico'),
(73071, 889, 20, 'Gráfico Atividade Local'),
(73072, 890, 20, 'Gráfico Observação'),
(73073, 891, 20, 'Gráfico Número'),
(73074, 892, 20, 'Gráfico Local de armazenamento'),
(73075, 893, 20, 'Gráfico Tracker'),
(73076, 894, 20, 'Gráfico Trk'),
(73077, 895, 20, 'Gráficos Check-out'),
(73078, 896, 20, 'Gráficos Out'),
(73079, 897, 20, 'Checheno'),
(73080, 898, 20, 'Verificar'),
(73081, 899, 20, 'verificar'),
(73082, 900, 20, 'Verificar Todos'),
(73083, 902, 20, 'Verificar Quantia'),
(73084, 903, 20, 'Verificar Data'),
(73085, 904, 20, 'Busque por diferenças nas traduções com a tabela de idiomas personalizada.'),
(73086, 906, 20, 'Check-in Para'),
(73087, 907, 20, 'Verificar dados de entrada'),
(73088, 908, 20, 'Verifique itens para representar graficamente'),
(73089, 909, 20, 'Verificar Resultado Laboratório'),
(73090, 910, 20, 'Marca de verificação indica revisado'),
(73091, 911, 20, 'Verificar Nº'),
(73092, 912, 20, 'Verificar Número'),
(73093, 915, 20, 'Verificar Pagamento'),
(73094, 916, 20, 'Marque a caixa se este é um arquivo criptografado'),
(73095, 917, 20, 'Marque esta opção se você quiser ver todos os prestadores e não apenas o seu próprio.'),
(73096, 918, 20, 'Marque para cadastrar um problema a partir desse diagnóstico'),
(73097, 919, 20, 'Verificar / EOB Data:'),
(73098, 920, 20, 'Verificar / EOB No.:'),
(73099, 921, 20, 'Verificar / Número de Referência'),
(73100, 922, 20, 'Verificar / Número de Referência'),
(73101, 923, 20, 'Lista Checkbox'),
(73102, 924, 20, 'lista de seleção'),
(73103, 925, 20, 'w caixa / texto'),
(73104, 926, 20, 'Checkbox w / texto'),
(73105, 927, 20, 'As caixas de seleção acima indicam se você deseja rejeitar e excluir o arquivo HL7.'),
(73106, 928, 20, 'Marcado'),
(73107, 929, 20, 'Checked caixa = sim, em branco = não'),
(73108, 931, 20, 'Verificando a caixa de bloqueio que impedirá quaisquer edições futuras sobre quaisquer formas neste encontro.'),
(73109, 932, 20, 'Saída'),
(73110, 934, 20, 'Peito'),
(73111, 935, 20, 'Tórax CTAB'),
(73112, 936, 20, 'Dor Torácica'),
(73113, 937, 20, 'Dor no peito:'),
(73114, 938, 20, 'Dores no peito'),
(73115, 940, 20, 'Var'),
(73116, 942, 20, 'Queixa principal'),
(73117, 943, 20, 'Criança'),
(73118, 945, 20, 'Status Vacinação infantil (SVI)'),
(73119, 946, 20, 'Calafrios'),
(73120, 947, 20, 'Chinês'),
(73121, 948, 20, 'Chinês (Simplificado)'),
(73122, 949, 20, 'Chinês (Tradicional)'),
(73123, 950, 20, 'Quiroprática'),
(73124, 951, 20, 'Escolhas'),
(73125, 952, 20, 'Colecistectomia'),
(73126, 953, 20, 'Colecistectomia'),
(73127, 954, 20, 'Colecistectomia'),
(73128, 955, 20, 'Escolher'),
(73129, 956, 20, 'Escolha uma seção e clique em um item dentro dela e, depois, em outra seção você verá os itens relacionados em destaque, e você pode clicar nesse ponto para adicionar e excluir relacionamentos.'),
(73130, 957, 20, 'Escolher Critérios'),
(73131, 958, 20, 'Escolha o download ou mostre-me as opçoes'),
(73132, 959, 20, 'Escolha Arquivo'),
(73133, 960, 20, 'Escolha da lista'),
(73134, 961, 20, 'Escolha direção do layout'),
(73135, 962, 20, 'Escolha lista'),
(73136, 963, 20, 'Escolha Tamanho do Papel'),
(73137, 964, 20, 'Escolha linguagem Preferência do PDF'),
(73138, 965, 20, 'Escolha o formato de impressão para esse relatório'),
(73139, 967, 20, 'Bronquite crônica'),
(73140, 968, 20, 'Dor Crônica na Articulação'),
(73141, 969, 20, 'Doença Renal Crônica (DRC)'),
(73142, 970, 20, 'Sinovite crônica / derrame / dor nas articulações / gota'),
(73143, 971, 20, 'Crônica / recorrente'),
(73144, 972, 20, 'Chuvache'),
(73145, 973, 20, 'Cirrose do fígado'),
(73146, 974, 20, 'A cirrose hepática'),
(73147, 975, 20, 'Cidade'),
(73148, 976, 20, 'Nome Cidade'),
(73149, 977, 20, 'Cidade, Estado'),
(73150, 978, 20, 'Cidade, Estado CEP'),
(73151, 979, 20, 'Cidade / Estado'),
(73152, 980, 20, 'Reclamar'),
(73153, 981, 20, 'Reclamar '),
(73154, 982, 20, 'Situação da reclamação'),
(73155, 983, 20, 'Reivindicação de teste estiver concluído'),
(73156, 984, 20, 'Tipo de reclamação'),
(73157, 985, 20, 'Reivindicação foi gerada para arquivo'),
(73158, 986, 20, 'Reivindicação foi gerada para arquivo '),
(73159, 987, 20, 'Reclamações'),
(73160, 988, 20, 'Classificação'),
(73161, 989, 20, 'Apagar'),
(73162, 990, 20, 'APAGAR PACIENTE ATIVO'),
(73163, 991, 20, 'Apagar Tudo'),
(73164, 992, 20, 'Limpar dados HL7'),
(73165, 993, 20, 'Limpar Justificação'),
(73166, 994, 20, 'Limpar Smarty Cache'),
(73167, 995, 20, 'Limpando Informação casa necessária para criação do lote EDI 270'),
(73168, 996, 20, 'Número de CLIA'),
(73169, 997, 20, 'Clique'),
(73170, 998, 20, 'Clique em ''exportar'' para exportar sua Categoria, Subcategoria, ponto, os dados de conteúdo para um arquivo de texto. Qualquer semelhança desse arquivo para um arquivo XML é mera coincidência. Os abertura e fechamento deve estar na mesma linha, eles devem estar em letras minúsculas, sem espaços. Para importar, procure um arquivo e clique em ''importação''. Se os dados é completamente diferente, ele irá fundir-se com os seus dados existentes. Se houver nomes de itens semelhantes, a antiga será mantido e o novo salvo com um número adicionado ao final.'),
(73171, 999, 20, 'Clique em um ponto no gráfico para adicionar uma nova anotação, clique novamente para removê-lo'),
(73172, 1000, 20, 'Clique em "Download de Certificado" para fazer o download em arquivo do ssl.zip'),
(73173, 1001, 20, 'clique para saber mais'),
(73174, 1002, 20, 'Clique para maiores detalhes'),
(73175, 1003, 20, 'Clique para resumo do pedido'),
(73176, 1004, 20, 'Clique para obter os resultados'),
(73177, 1005, 20, 'Clique aqui'),
(73178, 1006, 20, 'Clique aqui para adicionar um novo paciente'),
(73179, 1007, 20, 'Clique aqui para adicionar novo status de modificação lesão e editar atividade diária'),
(73180, 1008, 20, 'Clique aqui para escolher uma data'),
(73181, 1009, 20, 'Clique aqui para escolher uma data e horário'),
(73182, 1010, 20, 'Clique aqui para escolher uma data de início'),
(73183, 1011, 20, 'Clique aqui para escolher data e hora'),
(73184, 1012, 20, 'Clique aqui para escolher data e hora de'),
(73185, 1013, 20, 'Clique aqui para escolher a data e hora para'),
(73186, 1014, 20, 'Clique aqui para configurar Este módulo'),
(73187, 1016, 20, 'Clique Aqui Para Desativar Esse Módulo'),
(73188, 1018, 20, 'Clique aqui para ativar este módulo'),
(73189, 1019, 20, 'Clique aqui para instalar este módulo'),
(73190, 1020, 20, 'Clique aqui para procurar'),
(73191, 1021, 20, 'clique aqui para atualizar prioridade, a categoria e o apelido configurações'),
(73192, 1022, 20, 'Clique aqui para ver todos.'),
(73193, 1023, 20, 'Clique aqui para visualização e gráfico'),
(73194, 1024, 20, 'Clique aqui para ver o gráfico e todos os dados de laboratório.'),
(73195, 1025, 20, 'Clique aqui para visualização e gráfico das informações vitais'),
(73196, 1026, 20, 'Clique aqui para visualizar detalhes do paciente'),
(73197, 1027, 20, 'Clique aqui para ver todos eles.'),
(73198, 1028, 20, 'Clique aqui para visualizar/editar detalhes'),
(73199, 1029, 20, 'Clique no botão de Instalar para instalar a base de dados com edição na seguinte data'),
(73200, 1030, 20, 'Clique em qualquer uma das seções temporais para a aumentar'),
(73201, 1031, 20, 'Clique Nome do paciente para abrir o arquivo do paciente'),
(73202, 1032, 20, 'Clique Atualizar para ver todos os resultados, ou então, por favor dê entrada ao critério de pesquisa acima para ver resultados específicos.'),
(73203, 1033, 20, 'Clique para adicionar um diagnóstico'),
(73204, 1034, 20, 'Clique para adicionar novos componentes'),
(73205, 1035, 20, 'Clique para adicionar nova consulta'),
(73206, 1036, 20, 'Click aqui para escolher diagnósticos para justificar.'),
(73207, 1037, 20, 'Clique para fazer download'),
(73208, 1038, 20, 'Clique para editar'),
(73209, 1039, 20, 'Clique para editar descrição'),
(73210, 1040, 20, 'Clique para editar este evento'),
(73211, 1041, 20, 'Clique para gerar o relatório'),
(73212, 1042, 20, 'Clique para corresponder paciente'),
(73213, 1043, 20, 'Clique para imprimir'),
(73214, 1044, 20, 'Clique para receber (add) novo lote'),
(73215, 1045, 20, 'Clique para selecionar'),
(73216, 1046, 20, 'Clique para Selecionar'),
(73217, 1047, 20, 'Clique para selecionar o código padrão da indústria para este procedimento'),
(73218, 1048, 20, 'Clique para selecionar o código de procedimento opcional'),
(73219, 1049, 20, 'Clique para selecionar ou mudar a codificação'),
(73220, 1050, 20, 'Clique para selecionar ou alterar o código CVX'),
(73221, 1051, 20, 'Clique para selecionar ou alterar diagnósticos'),
(73222, 1052, 20, 'Clique para selecionar ou alterar códigos de serviço'),
(73223, 1053, 20, 'Clique para selecionar pacientes'),
(73224, 1054, 20, 'Clique para selecionar o código relacionado'),
(73225, 1055, 20, 'Clique para selecionar serviços a executar em caso de resultado anormal'),
(73226, 1056, 20, 'Clique para selecionar procedimento desejado'),
(73227, 1057, 20, 'Clique para ordenar'),
(73228, 1058, 20, 'Clique para ver'),
(73229, 1059, 20, 'Clique aqui para visualizar ou editar'),
(73230, 1060, 20, 'Clique para ver/editar'),
(73231, 1061, 20, 'Clique no botão Atualizar para atualizar o banco de dados de liberação a partir do seguinte data'),
(73232, 1062, 20, 'Clique onde indicado acima, para coincidir com o paciente.'),
(73233, 1063, 20, 'Clique em:'),
(73234, 1064, 20, 'Certificado do cliente expira em Dias'),
(73235, 1065, 20, 'Período de validação do certificado do cliente'),
(73236, 1066, 20, 'Vigência do certificado do cliente deve ser um número válido.'),
(73237, 1067, 20, 'Cópia do Paciente'),
(73238, 1069, 20, 'Resumo do histórico médico do paciente'),
(73239, 1070, 20, 'Nome do Paciente'),
(73240, 1071, 20, 'Número do Paciente'),
(73241, 1072, 20, 'Perfil do Paciente - Novos Pacientes'),
(73242, 1073, 20, 'Perfil do Paciente - Pacientes Únicos'),
(73243, 1074, 20, 'Pacientes'),
(73244, 1075, 20, 'Clínica'),
(73245, 1076, 20, 'Cópia da Clínica'),
(73246, 1077, 20, 'Anotação Diária da Clínica'),
(73247, 1078, 20, 'Clínica ID'),
(73248, 1079, 20, 'Clínico'),
(73249, 1080, 20, 'Gerenciador de regras de decisão clínica'),
(73250, 1081, 20, 'Histórico Clínico'),
(73251, 1083, 20, 'Plano Clínico'),
(73252, 1084, 20, 'Avaliador de Qualidade Clínica (AQC)'),
(73253, 1085, 20, 'Avaliador de Qualidade Clínica (AQC) - 2011'),
(73254, 1086, 20, 'Avaliador de Qualidade Clínica (AQC) - 2014'),
(73255, 1087, 20, 'Lembrete Clínico'),
(73256, 1088, 20, 'Relatório Clínico'),
(73257, 1089, 20, 'Regra Clínica - Categoria'),
(73258, 1090, 20, 'Regra Clínica - Ítem'),
(73259, 1091, 20, 'Regra Clínica - Método de Filtro'),
(73260, 1092, 20, 'Regra Clínica - Método Alvo'),
(73261, 1093, 20, 'Regra Clínica'),
(73262, 1094, 20, 'Regra Clínica - Intervalo de Idade'),
(73263, 1095, 20, 'Regra Clínica - Comparação'),
(73264, 1096, 20, 'Regra Clínica - Tipos de Consultas'),
(73265, 1097, 20, 'Regra Clínica - Motivo de Finalização'),
(73266, 1098, 20, 'Regra Clínica - Motivo de Inativação'),
(73267, 1099, 20, 'Regra Clínica - Intervalo de Lembrete'),
(73268, 1100, 20, 'Regra Clínica - Método de Lembrete'),
(73269, 1101, 20, 'Regra Clínica - Alvo do Intervalo'),
(73270, 1102, 20, 'Objetivos Clínicos'),
(73271, 1103, 20, 'Termo Clínico'),
(73272, 1104, 20, 'Código de Termo Clínico'),
(73273, 1106, 20, 'Clínicos'),
(73274, 1107, 20, 'Clonar'),
(73275, 1108, 20, 'Clonar Visita Anterior'),
(73276, 1109, 20, 'Fechar'),
(73277, 1110, 20, 'Fechar a janela'),
(73278, 1111, 20, 'Fechar a janela'),
(73279, 1112, 20, 'Fechado'),
(73280, 1113, 20, 'cm'),
(73281, 1114, 20, 'CMS 1500 Margins'),
(73282, 1115, 20, 'CMS 1500 Formato papel'),
(73283, 1118, 20, 'CMS ID'),
(73284, 1122, 20, 'CMS Portal não habilitado!'),
(73285, 1123, 20, 'CMS Portal Senha'),
(73286, 1124, 20, 'CMS Portal Solicitado'),
(73287, 1126, 20, 'CMS Portal Nome de usuário'),
(73288, 1127, 20, 'CN2-12 intactas'),
(73289, 1128, 20, 'CoPagamento'),
(73290, 1129, 20, 'CoPagamento Pago'),
(73291, 1130, 20, 'CoPagamento'),
(73292, 1131, 20, 'Código'),
(73293, 1132, 20, 'código'),
(73294, 1133, 20, 'Localizador de Código'),
(73295, 1134, 20, 'Código devem ser dois letra minúscula'),
(73296, 1135, 20, 'Símbolo Monetário'),
(73297, 1136, 20, 'Texto do Código'),
(73298, 1137, 20, 'tipo de código'),
(73299, 1138, 20, 'digite o código'),
(73300, 1139, 20, 'Tipo de código não reconhecido'),
(73301, 1140, 20, 'Tipo de código ainda não definido'),
(73302, 1141, 20, 'Tipos de código'),
(73303, 1142, 20, 'Código(s)'),
(73304, 1143, 20, 'Codificado'),
(73305, 1144, 20, 'Códigos'),
(73306, 1145, 20, 'Codificação'),
(73307, 1147, 20, 'Codificação - quaisquer Consultas (escrever, wsome opcional)'),
(73308, 1148, 20, 'Codificação - minhas Consultas (escrever, wsome opcional)'),
(73309, 1149, 20, 'Codificação não autorizada'),
(73310, 1150, 20, 'Café'),
(73311, 1151, 20, 'Cafe usado'),
(73312, 1152, 20, 'cosseguro'),
(73313, 1153, 20, 'Coll w/o'),
(73314, 1154, 20, 'Recolher'),
(73315, 1155, 20, 'recolher'),
(73316, 1156, 20, 'Recolher Tudo'),
(73317, 1157, 20, 'Recolher tudo'),
(73318, 1158, 20, 'recolher tudo'),
(73319, 1160, 20, 'Coleção Data'),
(73320, 1161, 20, 'Coleções'),
(73321, 1162, 20, 'Relatório de Coleções'),
(73322, 1163, 20, 'Câncer do cólon'),
(73323, 1164, 20, 'Rastreio do cancro do cólon'),
(73324, 1165, 20, 'Cirurgia de Câncer do Cólon'),
(73325, 1166, 20, 'Colonoscopia'),
(73326, 1167, 20, 'colonoscopia'),
(73327, 1168, 20, 'Cor'),
(73328, 1170, 20, 'Coluna'),
(73329, 1171, 20, 'Colunas'),
(73330, 1172, 20, 'Combinando Lotes'),
(73331, 1173, 20, 'Vírgula'),
(73332, 1174, 20, 'Comentário'),
(73333, 1175, 20, 'Comentários'),
(73334, 1176, 20, 'Comentários ou recomendações para este resultado'),
(73335, 1177, 20, 'Empresa de Seguro Comercial'),
(73336, 1178, 20, 'Gravar Alterações'),
(73337, 1179, 20, 'Comunicação'),
(73338, 1180, 20, 'Comunicações'),
(73339, 1182, 20, 'Empresa'),
(73340, 1183, 20, 'Nome da Empresa'),
(73341, 1184, 20, 'Completar'),
(73342, 1186, 20, 'Concluído'),
(73343, 1188, 20, 'Concluído?'),
(73344, 1190, 20, 'Complicações pelo Provedor de Serviço'),
(73345, 1191, 20, 'Complicações do Aborto'),
(73346, 1192, 20, 'Componentes'),
(73347, 1193, 20, 'Sistema de Pedidos Médicos - Computer Aided'),
(73348, 1194, 20, 'Conclusões'),
(73349, 1198, 20, 'Configuração'),
(73350, 1199, 20, 'Configuração'),
(73351, 1200, 20, 'Configuração Exportar/Importar'),
(73352, 1201, 20, 'Configuração salva com sucesso'),
(73353, 1202, 20, 'Configure Servidor Web (Apache) e LibreEHR para uso de certificado SSL pelo clíente.'),
(73354, 1203, 20, 'Configure Servidor Web (Apache) para uso de certificado SSL pelo clíente.'),
(73355, 1204, 20, 'Configure Servidor Web (Apache) para uso HTTPS.'),
(73356, 1205, 20, 'Configure LibreEHR para uso de certificado SSL pelo clíente.'),
(73357, 1206, 20, 'Configurar trilhas'),
(73358, 1207, 20, 'Configurar Trilhas'),
(73359, 1208, 20, 'Confirmar Criação de Novo Paciente'),
(73360, 1209, 20, 'Confirmar Nova Senha'),
(73361, 1210, 20, 'Confirmar Pagamento'),
(73362, 1214, 20, 'Congênita'),
(73363, 1215, 20, 'Conjuntiva, pupilas'),
(73364, 1216, 20, 'Erro de conexão'),
(73365, 1217, 20, 'Conectores'),
(73366, 1218, 20, 'Constante'),
(73367, 1219, 20, 'nome da constante'),
(73368, 1220, 20, 'Nome da constante está em branco'),
(73369, 1221, 20, 'Constantes'),
(73370, 1222, 20, 'Constipação'),
(73371, 1223, 20, 'Constitucional'),
(73372, 1226, 20, 'Breve Descrição da Consulta'),
(73373, 1227, 20, 'Contato'),
(73374, 1228, 20, 'Email para Contato'),
(73375, 1229, 20, 'Endereço de Email para Contato'),
(73376, 1231, 20, 'Informações de contato'),
(73377, 1232, 20, 'Lentes de Contato'),
(73378, 1236, 20, 'Nome de contato'),
(73379, 1237, 20, 'Pessoa de Contato'),
(73380, 1239, 20, 'Número de telefone'),
(73381, 1243, 20, 'Conteúdo'),
(73382, 1244, 20, 'conteúdo'),
(73383, 1247, 20, 'Continue'),
(73384, 1250, 20, 'Contra clientes'),
(73385, 1251, 20, 'Contracepção'),
(73386, 1252, 20, 'Questões Contracepção'),
(73387, 1253, 20, 'Anticoncepcionais Complicação (especificar)'),
(73388, 1254, 20, 'Método Anticoncepcional'),
(73389, 1255, 20, 'Produtos Contraceptivos'),
(73390, 1256, 20, 'Serviços de contracepção já iniciados'),
(73391, 1257, 20, 'Iniciar Contraceptivos'),
(73392, 1258, 20, 'ID de Controle'),
(73393, 1259, 20, 'Nº de Controle'),
(73394, 1262, 20, 'CoPagamento'),
(73395, 1263, 20, 'CoPagamento'),
(73396, 1264, 20, 'CoPagamento não positivo'),
(73397, 1266, 20, 'CoPagamentos'),
(73398, 1267, 20, 'DPOC'),
(73399, 1268, 20, 'Copiar páginas para Paciente Gráfico'),
(73400, 1269, 20, 'Copiar Valores'),
(73401, 1270, 20, 'Copiando Arquivo da Base de Dados. Isto pode levar algum tempo...'),
(73402, 1271, 20, 'Nota de Direitos Autorais'),
(73403, 1273, 20, 'Artéria Coronária Bypass'),
(73404, 1275, 20, 'Conectado'),
(73405, 1277, 20, 'CouchDB'),
(73406, 1278, 20, 'CouchDB conexão falhou.'),
(73407, 1279, 20, 'CouchDB - Banco de Dados'),
(73408, 1280, 20, 'CouchDB - Nome do Banco de Dados'),
(73409, 1281, 20, 'CouchDB - Host'),
(73410, 1282, 20, 'CouchDB - Nome do Host'),
(73411, 1283, 20, 'CouchDB - Ativar Log'),
(73412, 1284, 20, 'CouchDB - Senha'),
(73413, 1285, 20, 'CouchDB - Porta'),
(73414, 1286, 20, 'CouchDB - Porta'),
(73415, 1288, 20, 'CouchDB - Nome do Usuário'),
(73416, 1289, 20, 'Tosse'),
(73417, 1290, 20, 'Tosse:'),
(73418, 1294, 20, 'Não foi possível ler o arquivo'),
(73419, 1296, 20, 'Não foi possível enviar e-mail devido a um problema de servidor, '),
(73420, 1297, 20, 'Não foi possível enviar e-mail devido a um problema de servidor. '),
(73421, 1298, 20, 'Não foi possível criar pasta de Backup:'),
(73422, 1299, 20, 'Não foi possível excluir pasta:'),
(73423, 1300, 20, 'Não foi possível excluir arquivo antigo de backup:'),
(73424, 1301, 20, 'Não foi possível excluir arquivo antigo exportado:'),
(73425, 1303, 20, 'Aconselhamento por Método'),
(73426, 1304, 20, 'Aconselhamento'),
(73427, 1305, 20, 'Atividades de aconselhamento'),
(73428, 1306, 20, 'CONTADOR NO FORMULÁRIO'),
(73429, 1307, 20, 'Contra-referência'),
(73430, 1308, 20, 'País'),
(73431, 1309, 20, 'País - Tipo de dados'),
(73432, 1310, 20, 'País - Lista'),
(73433, 1311, 20, 'Lista de Países (escrever, adicionar somente opcional)'),
(73434, 1312, 20, 'Nome do País deve ser representado por duas letras (Ex: Brasil = BR)'),
(73435, 1313, 20, 'país'),
(73436, 1315, 20, 'Cupom'),
(73437, 1318, 20, 'CPT'),
(73438, 1319, 20, 'Código CPT'),
(73439, 1320, 20, 'Códigos de CPT'),
(73440, 1324, 20, 'Crepitações:'),
(73441, 1325, 20, 'creme'),
(73442, 1326, 20, 'Crie um certificado SSL do lado do cliente para cada usuário ou máquina cliente.'),
(73443, 1327, 20, 'Crie um certificado SSL do lado do cliente para um usuário ou um nome de host cliente.'),
(73444, 1329, 20, 'Criar um Evento'),
(73445, 1330, 20, 'Criar e fazer download de um backup completo'),
(73446, 1332, 20, 'Criar backup'),
(73447, 1333, 20, 'Criar lote'),
(73448, 1334, 20, 'Criar Certificado de Cliente'),
(73449, 1335, 20, 'Criar certificados SSL do lado do cliente'),
(73450, 1336, 20, 'Criar Duplicado'),
(73451, 1338, 20, 'Criar backup de log de eventos'),
(73452, 1339, 20, 'Criar uma nova questão'),
(73453, 1340, 20, 'Criar novo paciente'),
(73454, 1342, 20, 'Criar Portal Credenciais Offsite'),
(73455, 1343, 20, 'Criar Portal Credenciais Onsite'),
(73456, 1344, 20, 'Criar Observação do Paciente'),
(73457, 1345, 20, 'Criar o Certificado SSL e certificados de servidor.'),
(73458, 1346, 20, 'Nova Consulta'),
(73459, 1347, 20, 'Criado'),
(73460, 1348, 20, 'Criando arquivo de exportação'),
(73461, 1350, 20, 'A criação deste arquivo no host remoto falhou'),
(73462, 1351, 20, 'Criador'),
(73463, 1352, 20, 'crédito'),
(73464, 1353, 20, 'Cartão de Crédito'),
(73465, 1354, 20, 'Créditos'),
(73466, 1356, 20, 'Critérios'),
(73467, 1358, 20, 'Doença de Crohn'),
(73468, 1359, 20, 'Doença de Crohn'),
(73469, 1360, 20, 'Exportar CSV'),
(73470, 1361, 20, 'Arquivo CSV'),
(73471, 1362, 20, 'Tabelas CSV'),
(73472, 1363, 20, 'CU.MM'),
(73473, 1364, 20, 'Cubano'),
(73474, 1365, 20, 'Moeda - Casas Decimais'),
(73475, 1366, 20, 'Moeda - Separador Decimal'),
(73476, 1367, 20, 'Moeda - Símbolos Monetário'),
(73477, 1368, 20, 'Moeda - Separador Milhar'),
(73478, 1369, 20, 'Atual'),
(73479, 1370, 20, 'Atual - Etilismo'),
(73480, 1371, 20, 'Atual - Consulta'),
(73481, 1372, 20, 'Atual - Critérios'),
(73482, 1373, 20, 'Atual - Pigmetação Cutânea'),
(73483, 1374, 20, 'Atual - Fumante Diário'),
(73484, 1375, 20, 'Nome do arquivo atual foi alterado para'),
(73485, 1377, 20, 'Atual - Localização'),
(73486, 1378, 20, 'Atual - Medicamentos'),
(73487, 1379, 20, 'Atual - Senha'),
(73488, 1380, 20, 'Atual - Paciente'),
(73489, 1382, 20, 'Atual - Drogas recreativas'),
(73490, 1383, 20, 'Atual - Fumante Esporádico'),
(73491, 1386, 20, 'Atualmente Ativo'),
(73492, 1389, 20, 'Síndrome de Cushing'),
(73493, 1390, 20, 'Síndrome de Cushing'),
(73494, 1392, 20, 'Personalizado'),
(73495, 1393, 20, 'Entrada Personalizada?'),
(73496, 1394, 20, 'Tabela Personalizada'),
(73497, 1396, 20, 'Código CVX'),
(73498, 1397, 20, 'Mapeamento de Código CVX'),
(73499, 1398, 20, 'Imunização CVX'),
(73500, 1399, 20, 'Período'),
(73501, 1400, 20, 'CYP'),
(73502, 1401, 20, 'Fator CYP'),
(73503, 1402, 20, 'Relatório CYP'),
(73504, 1403, 20, 'Tcheco'),
(73505, 1404, 20, 'D'),
(73506, 1405, 20, 'D & C'),
(73507, 1406, 20, 'D & E'),
(73508, 1407, 20, 'Data Nascimento'),
(73509, 1408, 20, 'diário'),
(73510, 1409, 20, 'Registro diário'),
(73511, 1410, 20, 'Dinamarquês'),
(73512, 1411, 20, 'Dados idênticos já estão no banco de dados, altere o código e/ou descrição'),
(73513, 1412, 20, 'Dados idênticos já estão no banco de dados, altere o nome da constante'),
(73514, 1413, 20, 'Dados Cols'),
(73515, 1416, 20, 'Erro de Dados'),
(73516, 1420, 20, 'Tipo de Dados'),
(73517, 1421, 20, 'Banco de Dados'),
(73518, 1422, 20, 'Banco de dados não está instalado.'),
(73519, 1423, 20, 'Patch do Banco de Dados'),
(73520, 1424, 20, 'Relatório de Banco de Dados'),
(73521, 1425, 20, 'Atualização do banco de dados concluída.'),
(73522, 1426, 20, 'DataCols deve ser um número entre 1 e 999'),
(73523, 1427, 20, 'Data'),
(73524, 1428, 20, 'DATA'),
(73525, 1429, 20, 'Data & Hora Administrado'),
(73526, 1431, 20, 'Data Administrado'),
(73527, 1432, 20, 'Data e hora da coleta de amostras'),
(73528, 1433, 20, 'Data e hora da observação'),
(73529, 1435, 20, 'Data e hora em que a amostra foi coletada'),
(73530, 1436, 20, 'A data não pode ser maior do que hoje'),
(73531, 1437, 20, 'Data de serviços contraceptivos inicialmente previsto'),
(73532, 1438, 20, 'Data de Criação'),
(73533, 1439, 20, 'Data de Falecimento'),
(73534, 1440, 20, 'Data destruído'),
(73535, 1441, 20, 'Formato Data'),
(73536, 1442, 20, 'Formato de data para ""end nomeação "" não é válido'),
(73537, 1443, 20, 'Formato de data para ""start nomeação "" não é válido'),
(73538, 1444, 20, 'Formato de data para ""próximo compromisso "" não é válido'),
(73539, 1445, 20, 'Formato de data para ""não visto desde "" não é válido'),
(73540, 1446, 20, 'Formato de data para ""visita uma vez que "" não é válido'),
(73541, 1447, 20, 'Demonstrações Data de Vacinação informações fornecidas'),
(73542, 1448, 20, 'Data está faltando para o código '),
(73543, 1449, 20, 'Critérios de Dados Padrão'),
(73544, 1450, 20, 'Data de depósito bancário aaaa-mm-dd'),
(73545, 1451, 20, 'Data da Fatura'),
(73546, 1452, 20, 'Data de Nascimento'),
(73547, 1453, 20, 'Data de nascimento'),
(73548, 1454, 20, 'Data de Nascimento'),
(73549, 1455, 20, 'Data do Registro'),
(73550, 1456, 20, 'Data de Lesão'),
(73551, 1458, 20, 'Data de pagamento aaaa-mm-dd'),
(73552, 1459, 20, 'Data de envio'),
(73553, 1460, 20, 'Data da Resposta'),
(73554, 1461, 20, 'Data do Relatório'),
(73555, 1462, 20, 'Data do Serviço'),
(73556, 1463, 20, 'Data do Serviço'),
(73557, 1464, 20, 'Data do Serviço = hoje'),
(73558, 1465, 20, 'Data do Serviço mm/dd/aaaa'),
(73559, 1466, 20, 'Data do Serviço:'),
(73560, 1467, 20, 'Data de Assinatura'),
(73561, 1468, 20, 'Data da Mudança de Status'),
(73562, 1469, 20, 'Data deste pedido'),
(73563, 1470, 20, 'Data deste relatório'),
(73564, 1471, 20, 'Data da Declaração VIS'),
(73565, 1472, 20, 'Data do Pedido'),
(73566, 1475, 20, 'Seletor de Data'),
(73567, 1476, 20, 'Data de Envio'),
(73568, 1477, 20, 'Data que a mensagem foi enviada'),
(73569, 1479, 20, 'O valor de data não pode ficar em branco.'),
(73570, 1480, 20, 'Data / Appt'),
(73571, 1481, 20, 'Data do Exame / Comentários'),
(73572, 1482, 20, 'Data / Notas de Última'),
(73573, 1483, 20, 'Data/Hora'),
(73574, 1484, 20, 'Data:'),
(73575, 1485, 20, 'Log de Mensagem datada'),
(73576, 1486, 20, 'Dia'),
(73577, 1487, 20, 'dia'),
(73578, 1489, 20, 'Ver dia'),
(73579, 1490, 20, 'Dia(s)'),
(73580, 1491, 20, 'Dia (s) M-F'),
(73581, 1492, 20, 'dias'),
(73582, 1493, 20, 'Dias'),
(73583, 1494, 20, 'dias atrás'),
(73584, 1495, 20, 'Dias e Jogos Perdidos'),
(73585, 1496, 20, 'Dias da última Consulta'),
(73586, 1497, 20, 'Dias Perdidos'),
(73587, 1498, 20, 'Dias por coluna:'),
(73588, 1500, 20, 'Dias/Colunas:'),
(73589, 1501, 20, 'DB instalado'),
(73590, 1502, 20, 'DD/MM/AAAA'),
(73591, 1509, 20, 'DEA'),
(73592, 1512, 20, 'Informações de Depuração'),
(73593, 1514, 20, 'Depurando'),
(73594, 1515, 20, 'Dec'),
(73595, 1516, 20, 'FALECIDO'),
(73596, 1517, 20, 'Dezembro'),
(73597, 1518, 20, 'Decimais em libras e onças devem ser separados por # (por exemplo, 5#4)'),
(73598, 1519, 20, 'Recusou A Especificar'),
(73599, 1520, 20, 'Deduzível'),
(73600, 1521, 20, 'Met Deduzível'),
(73601, 1522, 20, 'Padrão'),
(73602, 1523, 20, 'Ver Calendário (Padrão)'),
(73603, 1526, 20, 'Clínica (Padrão)'),
(73604, 1527, 20, 'Idioma (Padrão)'),
(73605, 1528, 20, 'Idioma padrão caso nenhuma outra for permitida ou escolhida (Padrão).'),
(73606, 1529, 20, 'Lista (Padrão) (escrever, adicionar opcional)'),
(73607, 1530, 20, 'Método (Padrão)'),
(73608, 1531, 20, 'Período que Expira Senha (Padrão)'),
(73609, 1532, 20, 'Período que Expira Senha (Padrão). 0 significa desativar este recurso.'),
(73610, 1533, 20, 'País do Paciente (Padrão)'),
(73611, 1535, 20, 'Prioridade (Padrão)'),
(73612, 1536, 20, 'Provedor (Padrão)'),
(73613, 1537, 20, 'Intervalo (Padrão)'),
(73614, 1538, 20, 'Motivo da Visita (Padrão)'),
(73615, 1540, 20, 'Configuração (Padrão)'),
(73616, 1542, 20, 'Modelo Padrão'),
(73617, 1546, 20, 'Unidades (Padrão)'),
(73618, 1547, 20, 'Valor (Padrão)'),
(73619, 1549, 20, 'Padrão X12 Partner'),
(73620, 1550, 20, 'Padrão/Global'),
(73621, 1551, 20, 'Apagar'),
(73622, 1552, 20, 'apagar'),
(73623, 1553, 20, 'Atraso da Recorrência (> 12 Mo)'),
(73624, 1554, 20, 'Excluir'),
(73625, 1555, 20, 'excluir'),
(73626, 1556, 20, 'Excluir categorias com ID(s): '),
(73627, 1557, 20, 'Excluir Categoria'),
(73628, 1559, 20, 'Falha ao excluir!'),
(73629, 1560, 20, 'Excluir Grupo'),
(73630, 1561, 20, 'Excluir Lista'),
(73631, 1562, 20, 'Excluir Páginas'),
(73632, 1563, 20, 'Excluir Paciente, Consulta, Forma, edição, documentos, pagamento, cobrança ou transação'),
(73633, 1565, 20, 'Ecluir Linha'),
(73634, 1566, 20, 'Excluir Itens Selecionados'),
(73635, 1567, 20, 'Excluir Solicitações Selecionadas'),
(73636, 1568, 20, 'Exclusão efetuada com sucesso.'),
(73637, 1569, 20, 'Excluir este documento'),
(73638, 1570, 20, 'Excluir este formulário'),
(73639, 1571, 20, 'Excluir este lembrete'),
(73640, 1573, 20, 'Excluído com Sucesso'),
(73641, 1574, 20, 'Excluindo'),
(73642, 1575, 20, 'Exclusão desse evento não pode ser revertida. Tem certeza que quer excluir esse evento?'),
(73643, 1576, 20, 'Entrega Confirmada'),
(73644, 1577, 20, 'Entrega não autorizada para o Endereço especificado'),
(73645, 1578, 20, 'Entrega náo permitida para o Endereço especificado.'),
(73646, 1580, 20, 'Entrega do documento clínico anexado solicitada pelo paciente.'),
(73647, 1581, 20, 'Demência'),
(73648, 1582, 20, 'Informações'),
(73649, 1583, 20, 'Informações (escrever, adicionar opcional)'),
(73650, 1585, 20, 'Informações - Critério de filtro'),
(73651, 1586, 20, 'Informações não autorizadas'),
(73652, 1587, 20, 'Informações não autorizadas.'),
(73653, 1588, 20, 'Negado'),
(73654, 1590, 20, 'Dental'),
(73655, 1591, 20, 'Lista de problemas dentários'),
(73656, 1592, 20, 'Problemas dentários'),
(73657, 1593, 20, 'Módulos de dependência'),
(73658, 1594, 20, 'Problemas de dependência'),
(73659, 1595, 20, 'Dependendo do tipo de conta que você está testando você vai ver HCFA como a saída em uma página em branco para HCFA contas, você vai ver várias linhas de texto um tanto truncado e as informações se você está testando uma reivindicação X12. Esse texto ilegível é o X12 EDI 4010 formato. Ocasionalmente você vai ver caracteres estranhos que parecem dominós ou squiglies, estes são caracteres de controle como de alimentos e são normais.'),
(73660, 1596, 20, 'Data de Depósito'),
(73661, 1597, 20, 'Data de Depósito não pode ser maior do que Hoje'),
(73662, 1598, 20, 'Data de Depósito:'),
(73663, 1599, 20, 'Deprimido'),
(73664, 1600, 20, 'Depressão'),
(73665, 1602, 20, 'Descrição'),
(73666, 1603, 20, 'Descrição'),
(73667, 1604, 20, 'Descrição é o texto padrão'),
(73668, 1605, 20, 'Descrição da Divulgação'),
(73669, 1606, 20, 'Descrição desse código de procedimento ou resultado'),
(73670, 1607, 20, 'Tradução Descrição'),
(73671, 1608, 20, 'Arquivo desejado'),
(73672, 1609, 20, 'Destino'),
(73673, 1610, 20, 'Arquivo de Destino'),
(73674, 1611, 20, 'Destruir Lote'),
(73675, 1612, 20, 'Destruir...'),
(73676, 1613, 20, 'Destruído'),
(73677, 1614, 20, 'Drogas Destruídas'),
(73678, 1615, 20, 'Relatório de Drogas Destruídas'),
(73679, 1616, 20, 'Detalhe'),
(73680, 1617, 20, 'Detalhes'),
(73681, 1619, 20, 'Anormalidade Desenvolvida'),
(73682, 1620, 20, 'Diabetes'),
(73683, 1621, 20, 'Diabetes Mellitus'),
(73684, 1622, 20, 'Diabetes: Controle da Pressão Arterial (CQM)'),
(73685, 1623, 20, 'Diabetes: Exame Oftalmológico'),
(73686, 1624, 20, 'Diabetes: Exame Oftalmológico (CQM)'),
(73687, 1625, 20, 'Diabetes: Exame do Pé'),
(73688, 1626, 20, 'Diabetes: Exame do Pé(CQM)'),
(73689, 1628, 20, 'Diabete: hemoglobina A1C'),
(73690, 1629, 20, 'Diabete: Controle e Gerenciamento de LDL (CQM)'),
(73691, 1631, 20, 'Diag'),
(73692, 1632, 20, 'Diagnósticos'),
(73693, 1633, 20, 'Diagnóstico'),
(73694, 1634, 20, 'Código do Diagnóstico'),
(73695, 1635, 20, 'Código dos Diagnósticos'),
(73696, 1636, 20, 'Data do Diagnóstico'),
(73697, 1637, 20, 'O diagnóstico deve ser codificado em uma consulta'),
(73698, 1638, 20, 'Diagnóstico - Nome'),
(73699, 1639, 20, 'Diagnóstico - Relatório'),
(73700, 1640, 20, 'Diagnóstico - Relatório'),
(73701, 1641, 20, 'Diagnóstico - Somente Relatório'),
(73702, 1642, 20, 'Diagnóstico - Título'),
(73703, 1643, 20, 'Diagnóstico:'),
(73704, 1644, 20, 'Diagnóstico: '),
(73705, 1645, 20, 'Testes de Diagnóstico:'),
(73706, 1647, 20, 'Diafragmas'),
(73707, 1648, 20, 'Diarréia'),
(73708, 1650, 20, 'Ditado'),
(73709, 1651, 20, 'Ditado: '),
(73710, 1652, 20, 'Você recebeu uma cópia da comunicação HIPAA?'),
(73711, 1653, 20, 'Difuso:'),
(73712, 1654, 20, 'Assinado Digitalmente'),
(73713, 1657, 20, 'Correio Direto'),
(73714, 1658, 20, 'Log de Mensagem Direta'),
(73715, 1659, 20, 'Mensagem Direta Recebida.'),
(73716, 1660, 20, 'Mensagem Direta está indisponível no momento.'),
(73717, 1661, 20, 'Falha no Envio de Mensagem Direta.'),
(73718, 1663, 20, 'Nome do Diretor'),
(73719, 1664, 20, 'Falha ao excluir diretório; continuando.'),
(73720, 1665, 20, 'Deficiência'),
(73721, 1666, 20, 'Desabilitar'),
(73722, 1667, 20, 'Desabilitar Calendário'),
(73723, 1669, 20, 'Desabilitar Imunizações'),
(73724, 1670, 20, 'Desabilitar Antiga Métrica de Formas Vitais'),
(73725, 1672, 20, 'Desabilitar phpMyAdmin'),
(73726, 1673, 20, 'Desabilitar Prescrições'),
(73727, 1674, 20, 'Desabilitar Grupos de Usuários'),
(73728, 1675, 20, 'inválido'),
(73729, 1676, 20, 'Inválido'),
(73730, 1678, 20, 'DISC'),
(73731, 1679, 20, 'Descartar'),
(73732, 1680, 20, 'Descartado'),
(73733, 1681, 20, 'Quitação'),
(73734, 1682, 20, 'Quitação da uretra'),
(73735, 1684, 20, 'Direito de Quitação'),
(73736, 1685, 20, 'Direito de Quitação:'),
(73737, 1688, 20, 'Pago'),
(73738, 1689, 20, 'Revelar de Informação'),
(73739, 1690, 20, 'Tipo de Divulgação'),
(73740, 1691, 20, 'Tipos de Divulgação'),
(73741, 1692, 20, 'Divulgações'),
(73742, 1694, 20, 'Desconto'),
(73743, 1695, 20, 'Valor do desconto'),
(73744, 1696, 20, 'Nível de desconto'),
(73745, 1697, 20, 'Percentual de Desconto'),
(73746, 1698, 20, 'Descontos como Quantias Monetárias'),
(73747, 1701, 20, 'Doença'),
(73748, 1702, 20, 'Luxação'),
(73749, 1703, 20, 'Disp #'),
(73750, 1704, 20, 'Expedição'),
(73751, 1705, 20, 'Expedição do Documento Recebido'),
(73752, 1706, 20, 'Dispensada'),
(73753, 1708, 20, 'Mostrar Documentos'),
(73754, 1709, 20, 'Exibir datas de eventos em bloco?'),
(73755, 1710, 20, 'Exibir Medidas para Formato US'),
(73756, 1711, 20, 'Exibir quantos eventos?'),
(73757, 1713, 20, 'Exibir localização em bloco?'),
(73758, 1714, 20, 'Nome de Exibição'),
(73759, 1715, 20, 'Exibir calendário?'),
(73760, 1718, 20, 'Exibir eventos de hoje em bloco?'),
(73761, 1719, 20, 'Exibir tópico em bloco?'),
(73762, 1720, 20, 'Exibir eventos programados em bloco?'),
(73763, 1721, 20, 'Exibir Colunas'),
(73764, 1723, 20, 'Exibindo o seguinte número de notas recentes'),
(73765, 1724, 20, 'Exibindo o seguinte número de notas recentes:'),
(73766, 1725, 20, 'Distribuição'),
(73767, 1726, 20, 'Distribuições'),
(73768, 1727, 20, 'Distribuidor'),
(73769, 1729, 20, 'Diverticulite'),
(73770, 1730, 20, 'Diverticulite Cirurgia'),
(73771, 1731, 20, 'Divirticulitis'),
(73772, 1732, 20, 'Divirticulitis Cirurgia'),
(73773, 1733, 20, 'Divorciado'),
(73774, 1734, 20, 'Tonturas:'),
(73775, 1735, 20, 'Não Mude'),
(73776, 1742, 20, 'Não exibir calendário.'),
(73777, 1744, 20, 'Não inventariar e vender qualquer produto'),
(73778, 1745, 20, 'Não requerer autorização para anotações do paciente'),
(73779, 1747, 20, 'não salvar'),
(73780, 1748, 20, 'não substituir'),
(73781, 1749, 20, 'nada a fazer'),
(73782, 1751, 20, 'Realmente deseja excluir'),
(73783, 1752, 20, 'Realmente deseja excluir os itens selecionados?'),
(73784, 1753, 20, 'Realmente deseja excluir o grupo'),
(73785, 1755, 20, 'Quer continuar?'),
(73786, 1756, 20, 'Quer excluir?'),
(73787, 1757, 20, 'Quer excluir?'),
(73788, 1758, 20, 'Quer remover esse registro?'),
(73789, 1759, 20, 'Deseja continuar a adicionar este novo paciente?'),
(73790, 1760, 20, 'Deseja continuar com o novo nome?'),
(73791, 1761, 20, 'Deseja excluir PERMANENTEMENTE este registro de imunizações?'),
(73792, 1762, 20, 'Data de nascimento'),
(73793, 1763, 20, 'Data de nascimento está faltando, informe se possível'),
(73794, 1764, 20, 'Médicos'),
(73795, 1765, 20, 'Médico'),
(73796, 1766, 20, 'Médico:'),
(73797, 1767, 20, 'Nome do médico e assinatura'),
(73798, 1768, 20, 'Documento'),
(73799, 1769, 20, 'documento'),
(73800, 1770, 20, 'Documento Categorias'),
(73801, 1775, 20, 'O documento não poderia ser transferido para identificação do paciente'),
(73802, 1777, 20, 'Data do documento'),
(73803, 1778, 20, 'Documento data de emissão e atualizado com sucesso'),
(73804, 1780, 20, 'Documento transferido para nova categoria'),
(73805, 1781, 20, 'Documento transferido para identificação do paciente'),
(73806, 1783, 20, 'Documento aprovado no teste de integridade.'),
(73807, 1784, 20, 'Método de Armazenamento de Documento'),
(73808, 1785, 20, 'Documento renomeado com sucesso.'),
(73809, 1789, 20, 'Documento(s)'),
(73810, 1790, 20, 'Documento / Imagem Armazenada'),
(73811, 1791, 20, 'Documentos'),
(73812, 1792, 20, 'Documentos (escrever, adicionar opcional)'),
(73813, 1794, 20, 'DOE'),
(73814, 1797, 20, 'Não parece válido'),
(73815, 1799, 20, 'Relação Estável'),
(73816, 1800, 20, 'Não salvar'),
(73817, 1801, 20, 'Não salvar'),
(73818, 1802, 20, 'Não salvar as alterações'),
(73819, 1803, 20, 'Feito'),
(73820, 1804, 20, 'Feito com:'),
(73821, 1805, 20, 'Feito. Agora enviará o download.'),
(73822, 1806, 20, 'DOS'),
(73823, 1807, 20, 'Dosagem'),
(73824, 1809, 20, 'duplo clique para editar'),
(73825, 1810, 20, 'Visão Dupla'),
(73826, 1811, 20, 'Baixar'),
(73827, 1814, 20, 'Baixar mesmo assim'),
(73828, 1815, 20, 'Download de arquivos de faturamento, posto à contabilidade e marca como faturado'),
(73829, 1817, 20, 'Baixar certificados'),
(73830, 1818, 20, 'Transferir dados de configuração'),
(73831, 1828, 20, 'Dr Check'),
(73832, 1829, 20, 'Dr Visite'),
(73833, 1830, 20, 'Dr.'),
(73834, 1831, 20, 'Arraste para mover'),
(73835, 1832, 20, 'Dribbling'),
(73836, 1833, 20, 'Carteira de Motorista ou de Estado-ID'),
(73837, 1834, 20, 'Drogas'),
(73838, 1836, 20, 'Formas de drogas'),
(73839, 1837, 20, 'Drogas ID faltando!'),
(73840, 1838, 20, 'Intervalos de drogas'),
(73841, 1839, 20, 'Inventário de drogas'),
(73842, 1840, 20, 'Nome da droga'),
(73843, 1841, 20, 'Drogas Rotas'),
(73844, 1845, 20, 'Unidades de drogas'),
(73845, 1846, 20, 'Drogas'),
(73846, 1847, 20, 'Drogas e Produtos'),
(73847, 1848, 20, 'Boca seca'),
(73848, 1850, 20, 'DT 1'),
(73849, 1851, 20, 'DT 2'),
(73850, 1852, 20, 'DT 3'),
(73851, 1853, 20, 'DT 4'),
(73852, 1854, 20, 'DT 5'),
(73853, 1855, 20, 'DTaP 1'),
(73854, 1856, 20, 'DTaP 2'),
(73855, 1857, 20, 'DTaP 3'),
(73856, 1858, 20, 'DTaP 4'),
(73857, 1859, 20, 'DTaP 5'),
(73858, 1861, 20, 'Data de Vencimento'),
(73859, 1862, 20, 'Milímetro Vencimento / dd / aaaa ou aaaa-mm-dd'),
(73860, 1863, 20, 'Data de Vencimento:'),
(73861, 1864, 20, 'Ins Devido'),
(73862, 1865, 20, 'Devido Pt'),
(73863, 1869, 20, 'Dumping banco LibreEHR'),
(73864, 1870, 20, 'Dumping LibreEHR árvore de diretórios web'),
(73865, 1871, 20, 'Dumping banco phpgacl'),
(73866, 1872, 20, 'Dumping árvore de diretórios phpgacl web'),
(73867, 1873, 20, 'Dumping banco de dados SQL-Ledger'),
(73868, 1874, 20, 'Dumping SQL-Ledger árvore de diretórios web'),
(73869, 1878, 20, 'AVISO DUPLICAÇÃO'),
(73870, 1880, 20, 'Duração'),
(73871, 1881, 20, 'Duração'),
(73872, 1882, 20, 'Holandês'),
(73873, 1884, 20, 'Disfagia'),
(73874, 1885, 20, 'Dispnéia:'),
(73875, 1886, 20, 'Disúria'),
(73876, 1894, 20, 'A recidiva precoce (<2 Mo)'),
(73877, 1895, 20, 'Orelhas'),
(73878, 1896, 20, 'ECG'),
(73879, 1898, 20, 'Edema'),
(73880, 1904, 20, 'Editar'),
(73881, 1906, 20, 'Editar Alergias'),
(73882, 1907, 20, 'Editar categorias'),
(73883, 1909, 20, 'Editar definições'),
(73884, 1910, 20, 'Editar Diagnósticos para'),
(73885, 1912, 20, 'Editar Clínicas'),
(73886, 1914, 20, 'Editar Informações da Clínica'),
(73887, 1917, 20, 'Formulário Editar'),
(73888, 1920, 20, 'Editar layout'),
(73889, 1921, 20, 'Editar lista'),
(73890, 1923, 20, 'Editar Estrutura'),
(73891, 1928, 20, 'Educação'),
(73892, 1929, 20, 'Data da Educação'),
(73893, 1931, 20, 'ee a GNU General Public License para mais detalhes. * Você deve ter recebido uma cópia da Licença Pública Geral GNU * junto com este programa, se não, escreva para a Free '),
(73894, 1932, 20, 'Data Efetiva'),
(73895, 1934, 20, 'Eficácia'),
(73896, 1936, 20, 'Ejaculações'),
(73897, 1937, 20, 'Elbow'),
(73898, 1938, 20, 'Elbow Problemas'),
(73899, 1942, 20, 'Eletrônica da competência'),
(73900, 1949, 20, 'Email'),
(73901, 1957, 20, 'E-mail de Batchcom'),
(73902, 1958, 20, 'Email Notificação'),
(73903, 1961, 20, 'Enviar e-mail antes'),
(73904, 1962, 20, 'Email Enviar'),
(73905, 1965, 20, 'E-mail Assunto'),
(73906, 1966, 20, 'E-mail de texto, Útil Tag: *** NOME ***, ou seja, Caro *** NOME ***'),
(73907, 1971, 20, 'Contato de emergência'),
(73908, 1972, 20, 'Contato de Emergência'),
(73909, 1973, 20, 'Número de telefone de emergência'),
(73910, 1974, 20, 'Contracepção de Emergência'),
(73911, 1980, 20, 'Telefone de emergência'),
(73912, 1982, 20, 'Enfisema'),
(73913, 1983, 20, 'Empregado'),
(73914, 1984, 20, 'Empresa'),
(73915, 1985, 20, 'Endereço da Empresa'),
(73916, 1986, 20, 'Admissão da Empresa'),
(73917, 1987, 20, 'Nome da Empresa'),
(73918, 1989, 20, 'Vazio'),
(73919, 1991, 20, 'Valor vazio em ""Horas-mail ""'),
(73920, 1992, 20, 'Valor vazio em ""Email Sender ""'),
(73921, 1993, 20, 'Valor vazio em ""Assunto do Email ""'),
(73922, 1994, 20, 'Valor vazio em ""E-mail Texto ""'),
(73923, 1995, 20, 'Valor vazio em ""Nome do Provedor ""'),
(73924, 1996, 20, 'Valor vazio em ""Password ""'),
(73925, 1997, 20, 'Valor vazio em ""Horas SMS ""'),
(73926, 1998, 20, 'Valor vazio em ""de texto SMS ""'),
(73927, 1999, 20, 'Valor vazio em ""Nome ""'),
(73928, 2068, 20, 'habilitado'),
(73929, 2071, 20, 'Enc'),
(73930, 2073, 20, 'Consulta'),
(73931, 2074, 20, 'Consulta'),
(73932, 2075, 20, 'Consulta '),
(73933, 2086, 20, 'Consulta Formulários'),
(73934, 2091, 20, 'Número Consulta'),
(73935, 2110, 20, 'Consulta foi codificada'),
(73936, 2111, 20, 'Consulta:'),
(73937, 2113, 20, 'Consultas'),
(73938, 2114, 20, 'Consultas & Formulários'),
(73939, 2115, 20, 'Consultas & Formulários'),
(73940, 2116, 20, 'Consultas não autorizado'),
(73941, 2117, 20, 'Consultas Relatório'),
(73942, 2118, 20, 'Consultas Seção'),
(73943, 2121, 20, 'Fim'),
(73944, 2122, 20, 'Fim (aaaa-mm-dd): '),
(73945, 2123, 20, 'Data final'),
(73946, 2124, 20, 'Com data final'),
(73947, 2127, 20, 'Data final:'),
(73948, 2131, 20, 'End Time'),
(73949, 2133, 20, 'Data de término do serviço aaaa-mm-dd'),
(73950, 2134, 20, 'Ending milímetros DOS / dd / yyyy se deseja introduzir um intervalo'),
(73951, 2136, 20, 'Endo sanguíneos anormais'),
(73952, 2137, 20, 'Endócrino'),
(73953, 2138, 20, 'Endoscopia'),
(73954, 2141, 20, 'Inglês'),
(73955, 2142, 20, 'Inglês '),
(73956, 2143, 20, 'Inglês (indiana)'),
(73957, 2144, 20, 'Inglês (Standard)'),
(73958, 2146, 20, 'Assegurar LibreEHR tem privilégios de gravação para o diretório'),
(73959, 2147, 20, 'ENT Quitação'),
(73960, 2148, 20, 'ENT Pain'),
(73961, 2149, 20, 'Digite um código de diagnóstico para excluir todas as faturas que não contenham a'),
(73962, 2151, 20, 'Entrar no corpo da carta aqui'),
(73963, 2161, 20, 'Entrar novo Estado'),
(73964, 2165, 20, 'Digite seu critério de pesquisa acima'),
(73965, 2168, 20, 'Ambiental'),
(73966, 2169, 20, 'EOB de entrada de dados'),
(73967, 2170, 20, 'EOB Destacamento - Electronic Remessas'),
(73968, 2171, 20, 'EOB Posting - Instruções'),
(73969, 2172, 20, 'EOB Destacamento - Invoice'),
(73970, 2173, 20, 'EOB Destacamento - Paciente Nota'),
(73971, 2174, 20, 'EOB Destacamento - Busca'),
(73972, 2176, 20, 'Epilepsia'),
(73973, 2181, 20, 'Erase'),
(73974, 2182, 20, 'Ereções'),
(73975, 2183, 20, 'Erro'),
(73976, 2188, 20, 'Erro na ""Sexo "" seleção'),
(73977, 2189, 20, 'Erro na ""HIPAA "" seleção'),
(73978, 2190, 20, 'Erro na ""Processo "" seleção'),
(73979, 2191, 20, 'Erro na ""SMS Gateway "" seleção'),
(73980, 2192, 20, 'Erro na ""Ordenar por "" seleção'),
(73981, 2194, 20, 'Erro na opção SIM ou NÃO'),
(73982, 2205, 20, 'erro ao registrar formulário!'),
(73983, 2206, 20, 'Erro ao salvar o arquivo'),
(73984, 2208, 20, 'Erro ao gravar no arquivo'),
(73985, 2211, 20, 'Erro, incapaz de coletar dados de servidor'),
(73986, 2219, 20, 'ERRO: não pôde abrir table.sql, forma quebrado?'),
(73987, 2225, 20, 'Erro: Senha inválida. Verifique sua digitação.'),
(73988, 2235, 20, 'Erros'),
(73989, 2242, 20, 'Eritema:'),
(73990, 2247, 20, 'Paciente Antigo'),
(73991, 2250, 20, 'Etnia ou raça'),
(73992, 2251, 20, 'Étnico-Lista Raça (escrever, adicionar opcional)'),
(73993, 2252, 20, 'Etin'),
(73994, 2253, 20, 'Evento'),
(73995, 2254, 20, 'Evento começa'),
(73996, 2255, 20, 'Categoria do evento'),
(73997, 2256, 20, 'Data do Evento'),
(73998, 2257, 20, 'Descrição do evento'),
(73999, 2258, 20, 'Detalhes do evento'),
(74000, 2259, 20, 'Evento não se repete'),
(74001, 2260, 20, 'Duração do evento'),
(74002, 2261, 20, 'Evento duração em minutos'),
(74003, 2262, 20, 'Taxa de Eventos'),
(74004, 2263, 20, 'Local do evento'),
(74005, 2264, 20, 'Evento se repete'),
(74006, 2265, 20, 'Evento se repete no'),
(74007, 2266, 20, 'Evento hora de início'),
(74008, 2267, 20, 'Título do evento'),
(74009, 2268, 20, 'Título do Evento'),
(74010, 2269, 20, 'Website do evento'),
(74011, 2270, 20, 'Eventos'),
(74012, 2271, 20, 'Eventos para'),
(74013, 2272, 20, 'Eventos abrir em uma nova janela'),
(74014, 2273, 20, 'cada um'),
(74015, 2274, 20, 'Cada um'),
(74016, 2275, 20, 'a cada 3 horas'),
(74017, 2276, 20, 'a cada 4 horas'),
(74018, 2277, 20, 'a cada 5 horas'),
(74019, 2278, 20, 'a cada 6 horas'),
(74020, 2279, 20, 'a cada 8 horas'),
(74021, 2280, 20, 'Toda Quarta'),
(74022, 2281, 20, 'Todos os outros'),
(74023, 2282, 20, 'Cada Terceiro');
INSERT INTO `lang_definitions` VALUES
(74024, 2283, 20, 'Todos os dias, todas as outras, a cada 3, etc'),
(74025, 2285, 20, 'Os resultados dos exames e teste'),
(74026, 2286, 20, 'Os resultados dos exames'),
(74027, 2290, 20, 'Data Exame'),
(74028, 2293, 20, 'Exames / Testes'),
(74029, 2295, 20, 'Lacrimejamento excessivo'),
(74030, 2298, 20, 'Exclusive Provider Organization (EPO)'),
(74031, 2301, 20, 'Padrões de exercício'),
(74032, 2302, 20, 'Padrões de exercício'),
(74033, 2304, 20, 'Sair do Administração'),
(74034, 2305, 20, 'Exp'),
(74035, 2311, 20, 'Visualização Expandida'),
(74036, 2312, 20, 'Form_encounter.pid Esperado ser '),
(74037, 2313, 20, 'Expiração'),
(74038, 2314, 20, 'Data de Expiração'),
(74039, 2315, 20, 'Expira'),
(74040, 2317, 20, 'Exportação'),
(74041, 2318, 20, 'Exportar como CSV'),
(74042, 2319, 20, 'Exportar configuração'),
(74043, 2322, 20, 'Exportar Informações do Paciente'),
(74044, 2325, 20, 'Exportar como CSV Selecionados'),
(74045, 2326, 20, 'Coleções selecionadas para exportação'),
(74046, 2327, 20, 'Exportar para CSV'),
(74047, 2328, 20, 'Exportar para o sistema de faturamento externo'),
(74048, 2329, 20, 'A exposição ao Estrangeiro'),
(74049, 2330, 20, 'Exposição ao Estrangeiro'),
(74050, 2332, 20, 'Externo'),
(74051, 2336, 20, 'N# Cadastro'),
(74052, 2338, 20, 'Identificador externo'),
(74053, 2339, 20, 'Somente Externo'),
(74054, 2342, 20, 'Consulta externa'),
(74055, 2343, 20, 'Consulta Externa Followups'),
(74056, 2344, 20, 'Externos de referência?'),
(74057, 2345, 20, 'Referências externas'),
(74058, 2348, 20, 'Exsudato:'),
(74059, 2349, 20, 'Irritação dos olhos'),
(74060, 2350, 20, 'Dor ocular'),
(74061, 2351, 20, 'Vermelhidão dos olhos'),
(74062, 2352, 20, 'Olhos'),
(74063, 2353, 20, 'F'),
(74064, 2354, 20, 'F / H problemas do sangue'),
(74065, 2355, 20, 'F / H Feminino Hirsutismo / Estrias'),
(74066, 2356, 20, 'Clínicas'),
(74067, 2357, 20, 'Clínica'),
(74068, 2358, 20, 'Motor'),
(74069, 2359, 20, 'Clínica de Administração'),
(74070, 2361, 20, 'Clínica Código'),
(74071, 2365, 20, 'CNPJ da Clínica'),
(74072, 2372, 20, 'Clínica:'),
(74073, 2375, 20, 'Falha'),
(74074, 2383, 20, 'falha'),
(74075, 2390, 20, 'Histórico da Família'),
(74076, 2391, 20, 'Histórico familiar de glaucoma'),
(74077, 2392, 20, 'Histórico da Família:'),
(74078, 2395, 20, 'Tamanho Família'),
(74079, 2396, 20, 'Fancy'),
(74080, 2400, 20, 'Pai'),
(74081, 2402, 20, 'Fadiga'),
(74082, 2403, 20, 'Fatigado'),
(74083, 2404, 20, 'Fax'),
(74084, 2406, 20, 'Fax'),
(74085, 2408, 20, 'Fax / Digitalização'),
(74086, 2409, 20, 'Faxes no'),
(74087, 2410, 20, 'Faxes Out'),
(74088, 2413, 20, 'Fevereiro'),
(74089, 2414, 20, 'FECA'),
(74090, 2415, 20, 'Estado do CRM'),
(74091, 2416, 20, 'CRM'),
(74092, 2417, 20, 'CRM'),
(74093, 2418, 20, 'Honorários'),
(74094, 2419, 20, 'honorários'),
(74095, 2420, 20, 'Taxa não é permitido'),
(74096, 2421, 20, 'Taxa Folha'),
(74097, 2422, 20, 'Taxa Folha Opções'),
(74098, 2423, 20, 'Taxas'),
(74099, 2424, 20, 'Feminino'),
(74100, 2425, 20, 'Feminino AP'),
(74101, 2426, 20, 'Preservativos Femininos'),
(74102, 2427, 20, 'Mulher G'),
(74103, 2428, 20, 'Feminino LC'),
(74104, 2429, 20, 'P Feminino'),
(74105, 2430, 20, 'Feminino Sintomas'),
(74106, 2431, 20, 'Feminino VSC'),
(74107, 2434, 20, 'Febre'),
(74108, 2435, 20, 'Febre:'),
(74109, 2436, 20, 'FH problemas do sangue'),
(74110, 2437, 20, 'Fibromiomas'),
(74111, 2447, 20, 'Arquivo'),
(74112, 2455, 20, 'Arquivo do quarto'),
(74113, 2456, 20, 'Arquivo para upload'),
(74114, 2458, 20, 'Arquivo com mesmo nome já existe no local:'),
(74115, 2459, 20, 'Nome do Arquivo'),
(74116, 2461, 20, 'Arquivos'),
(74117, 2462, 20, 'Filipino'),
(74118, 2463, 20, 'Preencha qualquer uma das linhas abaixo.'),
(74119, 2464, 20, 'Preencha somente para envio de notificação de e-mail aos pacientes'),
(74120, 2465, 20, 'Preencha os valores abaixo'),
(74121, 2467, 20, 'Preencha a Linha.'),
(74122, 2468, 20, 'Filtro'),
(74123, 2469, 20, 'Filtro para Constantes'),
(74124, 2470, 20, 'Filtro para Definições'),
(74125, 2471, 20, 'Filtro para'),
(74126, 2472, 20, 'filtros'),
(74127, 2473, 20, 'Filtros'),
(74128, 2474, 20, 'Final'),
(74129, 2475, 20, 'Diagnóstico Final'),
(74130, 2476, 20, 'O diagnóstico final pelo especialista'),
(74131, 2478, 20, 'Financeiro'),
(74132, 2479, 20, 'Data de fechamento financeiro (aaaa-mm-dd)'),
(74133, 2480, 20, 'Relato Financeiro - nada'),
(74134, 2481, 20, 'Relato Financeiro - minhas Consultas'),
(74135, 2482, 20, 'Financeiro Revisão Data'),
(74136, 2483, 20, 'Resumo Financeiro por código de serviço'),
(74137, 2484, 20, 'Pesq.'),
(74138, 2485, 20, 'Procurar Disponível'),
(74139, 2486, 20, 'Procurar Marcações Disponíveis'),
(74140, 2487, 20, 'Pesquisar Paciente'),
(74141, 2488, 20, 'Encontre Materiais Informativo do Paciente'),
(74142, 2489, 20, 'Apreciação'),
(74143, 2490, 20, 'Descobertas por um especialista'),
(74144, 2491, 20, 'Agradável'),
(74145, 2492, 20, 'Concluir Pagamentos'),
(74146, 2493, 20, 'Concluído'),
(74147, 2495, 20, 'Primeiro'),
(74148, 2497, 20, 'Primeiro dia da semana'),
(74149, 2498, 20, 'Nome'),
(74150, 2499, 20, 'Nome'),
(74151, 2500, 20, 'Nome:'),
(74152, 2503, 20, 'Fitness'),
(74153, 2504, 20, 'Fitness: Nível'),
(74154, 2507, 20, 'Aptidão para jogar'),
(74155, 2508, 20, 'Corrigir datas de Consultas'),
(74156, 2509, 20, 'Corrigir este'),
(74157, 2510, 20, 'FL'),
(74158, 2511, 20, 'Flatulência'),
(74159, 2512, 20, 'Fluxo'),
(74160, 2516, 20, 'Vacinação contra a gripe'),
(74161, 2517, 20, 'Problema de líquidos e eletrólitos'),
(74162, 2518, 20, 'FMS'),
(74163, 2520, 20, 'Siga manualmente'),
(74164, 2531, 20, 'Intolerância Alimentar'),
(74165, 2532, 20, 'Pé'),
(74166, 2533, 20, 'Problemas do Pé'),
(74167, 2534, 20, 'Pé:'),
(74168, 2535, 20, 'Football Injuries'),
(74169, 2537, 20, 'Futebol Injury Report'),
(74170, 2538, 20, 'Tipo de calçado'),
(74171, 2539, 20, 'para'),
(74172, 2555, 20, 'para:'),
(74173, 2559, 20, 'Antebraço'),
(74174, 2560, 20, 'Forma'),
(74175, 2561, 20, 'forma'),
(74176, 2564, 20, 'Formato'),
(74177, 2565, 20, 'formato'),
(74178, 2567, 20, 'Formato incorreto para NDC'),
(74179, 2572, 20, 'Formulários'),
(74180, 2573, 20, 'Formas de administração'),
(74181, 2576, 20, 'Páginas transmitir via Fax'),
(74182, 2579, 20, 'Quarta'),
(74183, 2581, 20, 'Fratura'),
(74184, 2582, 20, 'Fratura no Navicula'),
(74185, 2583, 20, 'Fratura do maléolo lateral'),
(74186, 2584, 20, 'A fratura do maléolo medial'),
(74187, 2585, 20, 'Fracture, da Base de quinta (5) Metatarsal'),
(74188, 2587, 20, 'Francês'),
(74189, 2590, 20, 'Freqüência'),
(74190, 2591, 20, 'Resfriados freqüentes'),
(74191, 2592, 20, 'Doenças frequentes'),
(74192, 2593, 20, 'Sex'),
(74193, 2594, 20, 'Sexta-feira'),
(74194, 2595, 20, 'De'),
(74195, 2596, 20, 'DA'),
(74196, 2599, 20, 'De:'),
(74197, 2600, 20, 'De: '),
(74198, 2601, 20, 'FROM_CITY'),
(74199, 2603, 20, 'FROM_FNAME'),
(74200, 2604, 20, 'FROM_LNAME'),
(74201, 2605, 20, 'FROM_MNAME'),
(74202, 2607, 20, 'FROM_PHONECELL'),
(74203, 2608, 20, 'FROM_POSTAL'),
(74204, 2609, 20, 'FROM_STATE'),
(74205, 2610, 20, 'FROM_STREET'),
(74206, 2611, 20, 'FROM_TITLE'),
(74207, 2612, 20, 'FROM_VALEDICTORY'),
(74208, 2613, 20, 'Recepção'),
(74209, 2614, 20, 'Arquivos da Recepção'),
(74210, 2615, 20, 'Relatório de Arquivos da Recepção Relatório'),
(74211, 2616, 20, 'Front Rec'),
(74212, 2617, 20, 'Frontal Direita:'),
(74213, 2619, 20, 'Nome Completo'),
(74214, 2624, 20, 'Completamente Tocar'),
(74215, 2625, 20, 'Full Training'),
(74216, 2633, 20, 'G'),
(74217, 2636, 20, 'Vesícula Biliar Condição'),
(74218, 2637, 20, 'Gall Stones'),
(74219, 2638, 20, 'Jogo Período'),
(74220, 2639, 20, 'Jogos'),
(74221, 2641, 20, 'jogos / eventos'),
(74222, 2642, 20, 'Jogos / Eventos Missed'),
(74223, 2644, 20, 'Gastrite'),
(74224, 2645, 20, 'Gastro Pain'),
(74225, 2646, 20, 'Gastrointestinais'),
(74226, 2647, 20, 'GCAC Statistics Report'),
(74227, 2649, 20, 'GCAC formulário visita está faltando'),
(74228, 2650, 20, 'Gênero'),
(74229, 2651, 20, 'Gênero '),
(74230, 2652, 20, 'Filtro'),
(74231, 2655, 20, 'Categoria de Serviços Gerais'),
(74232, 2658, 20, 'Gerar e transferir créditos HCFA 1500 papel'),
(74233, 2659, 20, 'Gerar e lote X12 download'),
(74234, 2667, 20, 'Gerar HCFA'),
(74235, 2669, 20, 'Gerar Carta'),
(74236, 2670, 20, 'Gerar carta a respeito '),
(74237, 2677, 20, 'Gerar relatório'),
(74238, 2679, 20, 'Gerar X12'),
(74239, 2682, 20, 'Geração de'),
(74240, 2683, 20, 'Gera'),
(74241, 2684, 20, 'Geniturinário'),
(74242, 2687, 20, 'Alemão'),
(74243, 2692, 20, 'Glaucoma'),
(74244, 2693, 20, 'Glaucoma na Família'),
(74245, 2694, 20, 'Global'),
(74246, 2696, 20, 'Global ID'),
(74247, 2700, 20, 'ir'),
(74248, 2701, 20, 'Ir'),
(74249, 2704, 20, 'Ir para'),
(74250, 2705, 20, 'Ir para a semana de'),
(74251, 2712, 20, 'Votação:'),
(74252, 2713, 20, 'gramas'),
(74253, 2714, 20, 'Total Geral'),
(74254, 2715, 20, 'Totais Gerais'),
(74255, 2722, 20, 'Grego'),
(74256, 2724, 20, 'Grupo'),
(74257, 2725, 20, 'Nome do Grupo'),
(74258, 2726, 20, 'Os nomes dos grupos não pode estar em branco'),
(74259, 2727, 20, 'Os nomes dos grupos não pode começar com números ou espaços.'),
(74260, 2728, 20, 'Os nomes dos grupos não pode começar com números.'),
(74261, 2729, 20, 'Produto'),
(74262, 2731, 20, 'Grupo:'),
(74263, 2732, 20, 'Nome do Grupo'),
(74264, 2733, 20, 'Grupos e Controles de Acesso'),
(74265, 2734, 20, 'Growth Chart'),
(74266, 2735, 20, 'Growth-chart'),
(74267, 2736, 20, 'Gotas'),
(74268, 2741, 20, 'Exame ginecológico'),
(74269, 2742, 20, 'h'),
(74270, 2743, 20, 'H.S.'),
(74271, 2744, 20, 'H / O Hepatite'),
(74272, 2745, 20, 'tinha sido excluído com sucesso. Qualquer sub-categorias se apresentam foram movidos abaixo'),
(74273, 2746, 20, 'Hematoma / contusão'),
(74274, 2747, 20, 'HAI Status'),
(74275, 2750, 20, 'Mão + dedos'),
(74276, 2751, 20, 'Mão Problemas'),
(74277, 2753, 20, 'Hardship w / o'),
(74278, 2754, 20, 'tem sido associada a visitar'),
(74279, 2761, 20, 'Atividades perigosas'),
(74280, 2762, 20, 'Atividades perigosas'),
(74281, 2763, 20, 'HCFA margem esquerda em pontos'),
(74282, 2764, 20, 'Margens HCFA'),
(74283, 2765, 20, 'HCFA margem superior nos pontos'),
(74284, 2767, 20, 'ele PostCalendar '),
(74285, 2768, 20, 'Cabeça'),
(74286, 2769, 20, 'Chefe Circ'),
(74287, 2770, 20, 'Perímetro cefálico'),
(74288, 2771, 20, 'Dor de cabeça'),
(74289, 2772, 20, 'Dores de cabeça'),
(74290, 2775, 20, 'Centro de saúde / clínica'),
(74291, 2776, 20, 'Organização em Defesa da Saúde'),
(74292, 2777, 20, 'Organização em Defesa da Saúde (HMO) Medicare Risk'),
(74293, 2778, 20, 'Perda de Audição'),
(74294, 2779, 20, 'Ataque do Coração'),
(74295, 2780, 20, 'Doenças do Coração'),
(74296, 2781, 20, 'Insuficiência Cardíaca'),
(74297, 2782, 20, 'Problema cardíaco'),
(74298, 2783, 20, 'Problemas cardíacos'),
(74299, 2784, 20, 'Cirurgia de Coração'),
(74300, 2785, 20, 'Transplante de Coração'),
(74301, 2786, 20, 'CORAÇÃO:'),
(74302, 2787, 20, 'Azia'),
(74303, 2788, 20, 'Quente ou Frio'),
(74304, 2789, 20, 'Quente ou Frio'),
(74305, 2791, 20, 'Hebraico'),
(74306, 2793, 20, 'HEENT'),
(74307, 2794, 20, 'Altura'),
(74308, 2796, 20, 'Ajuda'),
(74309, 2797, 20, 'ajuda'),
(74310, 2798, 20, 'Hematêmese'),
(74311, 2799, 20, 'Hematoquezia'),
(74312, 2800, 20, 'Hematológico'),
(74313, 2801, 20, 'Hematuria'),
(74314, 2802, 20, 'Hemoglobina'),
(74315, 2804, 20, 'Hemoptise'),
(74316, 2805, 20, 'Hepatite'),
(74317, 2806, 20, 'Hepatite A 1'),
(74318, 2807, 20, 'Hepatite A 2'),
(74319, 2808, 20, 'Hepatite B 1'),
(74320, 2809, 20, 'Hepatite B 2'),
(74321, 2810, 20, 'Hepatite B 3'),
(74322, 2811, 20, 'aqui'),
(74323, 2813, 20, 'Hernia Repair'),
(74324, 2814, 20, 'Hérnia de disco'),
(74325, 2815, 20, 'Herpes'),
(74326, 2816, 20, 'Hesitação'),
(74327, 2817, 20, 'Olá. Você está por aqui há '),
(74328, 2818, 20, 'Hib 1'),
(74329, 2819, 20, 'Hib 2'),
(74330, 2820, 20, 'Hib 3'),
(74331, 2821, 20, 'Hib 4'),
(74332, 2822, 20, 'Oculto'),
(74333, 2823, 20, 'Administração de Eventos Ocultos'),
(74334, 2824, 20, 'Ocultar'),
(74335, 2825, 20, 'Ocultar Detalhes'),
(74336, 2833, 20, 'Alto'),
(74337, 2834, 20, 'Alta Pressão Sanguínea'),
(74338, 2836, 20, 'anca + virilha'),
(74339, 2837, 20, 'anca e virilha'),
(74340, 2838, 20, 'Problemas no anca'),
(74341, 2839, 20, 'anca Replacement'),
(74342, 2840, 20, 'HIPAA Aviso Recebido'),
(74343, 2842, 20, 'Hirsutismo / Estrias'),
(74344, 2843, 20, 'Hispânico'),
(74345, 2847, 20, 'Histórico'),
(74346, 2848, 20, 'Dados Históricos'),
(74347, 2851, 20, 'História Murmur'),
(74348, 2853, 20, 'History of Heart Murmur'),
(74349, 2855, 20, 'HIV'),
(74350, 2858, 20, 'HL7 Viewer'),
(74351, 2862, 20, 'Segure a tecla [Ctrl] para seleção múltipla ou desfazer seleção'),
(74352, 2863, 20, 'Segue a tecla [Ctrl] para selecionar múltiplos itens'),
(74353, 2864, 20, 'Segure a tecla [Ctrl] para selecionar vários esquadrões'),
(74354, 2865, 20, 'Início'),
(74355, 2866, 20, 'Telefone Residencial'),
(74356, 2867, 20, 'Número de telefone residencial'),
(74357, 2868, 20, 'Sem-teto ou similar?'),
(74358, 2869, 20, 'Sem-teto, etc'),
(74359, 2870, 20, 'Sem-teto, etc.'),
(74360, 2876, 20, 'Horas'),
(74361, 2878, 20, 'Como a Lesão Ocorreu?'),
(74362, 2879, 20, 'Como a Lesão Ocorreu?:'),
(74363, 2881, 20, 'Quantos meses à frente para consultar os próximos eventos?'),
(74364, 2882, 20, 'HPI:'),
(74365, 2884, 20, 'HTML'),
(74366, 2892, 20, 'Hiperatividade'),
(74367, 2893, 20, 'Hipertensão'),
(74368, 2896, 20, 'Hipertireoidismo'),
(74369, 2897, 20, 'Hipotireoidismo'),
(74370, 2898, 20, 'Histerectomia'),
(74371, 2899, 20, 'I'),
(74372, 2900, 20, 'Estou ocupado durante esse tempo.'),
(74373, 2901, 20, 'Eu não tenho permissão para ler '),
(74374, 2902, 20, 'CID'),
(74375, 2905, 20, 'CID9'),
(74376, 2909, 20, 'RG'),
(74377, 2911, 20, 'Identificação não pode estar em branco'),
(74378, 2913, 20, 'IDays'),
(74379, 2914, 20, 'logado como'),
(74380, 2915, 20, '(Identificador de uma palavra)'),
(74381, 2919, 20, 'Se todos os dados para todas as colunas são completos para este formulário'),
(74382, 2922, 20, 'Se o nome, qualquer parte do apelido, ou sobrenome, nome'),
(74383, 2923, 20, 'Se pagar por'),
(74384, 2927, 20, 'Se desempregado entra Estudante'),
(74385, 2931, 20, 'Se você tiver escolhido para carregar as remessas eletrônicas, em seguida, a janela de pesquisa redisplays com as faturas correspondentes a partir do arquivo X12. Você pode clicar em qualquer um destes números de fatura (como descrito abaixo) se você deseja fazer as correções antes do envio de informações é aplicada. Para aplicar as alterações, clique no botão Arquivo Processo ERA, na parte inferior da página. Isto produzirá uma nova janela com um relatório detalhado.'),
(74386, 2932, 20, 'Se você digitou uma data de pagamento na página de pesquisa, esta irá substituir a data de lançamento de pagamentos e ajustes que são de outra tiradas do arquivo X12. Isso pode ser útil para fins de notificação, se você quiser que o seu relatório de receitas para usar a sua data de lançamento, em vez de a companhia de seguros da data de processamento. Note que isso vai afetar também as datas de pagamentos, antes e ajustes que são postos em créditos secundário.'),
(74387, 2933, 20, 'Se pretender alterar os tipos de dados, ou adicionar linhas ou colunas'),
(74388, 2937, 20, 'Doença'),
(74389, 2938, 20, 'IM'),
(74390, 2942, 20, 'Vacinação'),
(74391, 2947, 20, 'Lote Número da Vacina'),
(74392, 2948, 20, 'Fabricante da Vacina'),
(74393, 2953, 20, 'Vacinas'),
(74394, 2954, 20, 'Vacinar'),
(74395, 2955, 20, 'Imunológicos'),
(74396, 2956, 20, 'Implantes'),
(74397, 2957, 20, 'Importar'),
(74398, 2961, 20, 'Importar certificado p/ o browser.'),
(74399, 2962, 20, 'Importar configuração'),
(74400, 2964, 20, 'Paciente de Importação'),
(74401, 2965, 20, 'Importar Informações do Paciente'),
(74402, 2969, 20, 'Importado da Contabilidade'),
(74403, 2972, 20, 'Melhoria'),
(74404, 2973, 20, 'em'),
(74405, 2974, 20, 'EM'),
(74406, 2975, 20, 'em cada olho'),
(74407, 2976, 20, 'no olho esquerdo'),
(74408, 2977, 20, 'na narina'),
(74409, 2978, 20, 'Na Clínica - Disponível'),
(74410, 2979, 20, 'no olho direito'),
(74411, 2980, 20, 'em casa'),
(74412, 2981, 20, 'Inativo'),
(74413, 2982, 20, 'Inativo Dias'),
(74414, 2988, 20, 'Incluir os usuários inativos'),
(74415, 2989, 20, 'Incluir Uncategorized'),
(74416, 2991, 20, 'Incluir dados vitais'),
(74417, 2992, 20, 'Incluir dados vitais?'),
(74418, 2994, 20, 'Renda'),
(74419, 2997, 20, 'Aborto incompleto Tratamento'),
(74420, 2998, 20, 'Incontinência'),
(74421, 3001, 20, 'aumentou:'),
(74422, 3002, 20, 'Seguro de Indenização'),
(74423, 3003, 20, 'Indeterminado'),
(74424, 3005, 20, 'Indica anormalidade'),
(74425, 3006, 20, 'Indica se este problema está atualmente ativo'),
(74426, 3010, 20, 'Indigentes pacientes relatam'),
(74427, 3011, 20, 'Indigentes'),
(74428, 3014, 20, 'Aborto induzido'),
(74429, 3017, 20, 'Infecção / Abscesso'),
(74430, 3018, 20, 'Infecções'),
(74431, 3019, 20, 'Infertil Couns'),
(74432, 3020, 20, 'Infertilidade'),
(74433, 3021, 20, 'Influenza 1'),
(74434, 3022, 20, 'Influenza 2'),
(74435, 3026, 20, 'Info'),
(74436, 3027, 20, 'Info teste 1'),
(74437, 3028, 20, 'Info teste 2'),
(74438, 3029, 20, 'Info teste 3'),
(74439, 3030, 20, 'Info teste 4'),
(74440, 3031, 20, 'Info teste 5'),
(74441, 3032, 20, 'Info teste 6'),
(74442, 3034, 20, 'inalações'),
(74443, 3035, 20, 'inhilations'),
(74444, 3037, 20, 'Usuário inicial'),
(74445, 3039, 20, 'Injetáveis'),
(74446, 3040, 20, 'Injeção'),
(74447, 3042, 20, 'Feridos Out'),
(74448, 3043, 20, 'Lesão'),
(74449, 3044, 20, 'Mecanismo de lesão'),
(74450, 3045, 20, 'Lesão relatório geral'),
(74451, 3046, 20, 'Vigilância de Lesões'),
(74452, 3047, 20, 'Tipo de lesão'),
(74453, 3051, 20, 'Input Fields'),
(74454, 3056, 20, 'Ins ajustar'),
(74455, 3057, 20, 'Ins agregação'),
(74456, 3061, 20, 'Ins excesso'),
(74457, 3063, 20, 'Restituição Ins'),
(74458, 3064, 20, 'Ins Resumo'),
(74459, 3065, 20, 'Ins1'),
(74460, 3066, 20, 'Ins2'),
(74461, 3067, 20, 'Ins3'),
(74462, 3069, 20, 'Inserir falhou: '),
(74463, 3070, 20, 'Inserir eventos antigos em tabelas'),
(74464, 3072, 20, 'Insonia'),
(74465, 3074, 20, 'Inspeção'),
(74466, 3075, 20, 'Instabilidade / subluxação'),
(74467, 3079, 20, 'instalar DB'),
(74468, 3081, 20, 'Instruída'),
(74469, 3084, 20, 'Instruções:'),
(74470, 3086, 20, 'Insulino-dependente'),
(74471, 3087, 20, 'Seguros'),
(74472, 3088, 20, 'seguro'),
(74473, 3094, 20, 'Seguradoras'),
(74474, 3095, 20, 'Companhia de Seguros'),
(74475, 3096, 20, 'Companhia de Seguros de Pesquisa / Adicionar'),
(74476, 3098, 20, 'Dados Seguros'),
(74477, 3100, 20, 'Seguros Números'),
(74478, 3103, 20, 'Operadora de Seguros'),
(74479, 3107, 20, 'Ingestão de Conclusão'),
(74480, 3108, 20, 'Data de admissão'),
(74481, 3109, 20, 'Declínio Intelectual'),
(74482, 3113, 20, 'Erro interno - sem páginas foram selecionados!'),
(74483, 3114, 20, 'Erro interno - identificação do paciente não foi fornecida!'),
(74484, 3115, 20, 'Interno erro ao aceder ao ficheiro uploaded!'),
(74485, 3116, 20, 'Erro interno!'),
(74486, 3117, 20, 'Erro interno, nenhuma droga ID especificado!'),
(74487, 3119, 20, 'Erro interno: reclamação '),
(74488, 3120, 20, 'Erro interno: consulta '''),
(74489, 3121, 20, 'Erro interno: PID ou Consulta está faltando.'),
(74490, 3123, 20, 'Interno Identifier (PID)'),
(74491, 3126, 20, 'Interno Referências'),
(74492, 3128, 20, 'Direito Internacional'),
(74493, 3129, 20, 'Intérprete'),
(74494, 3130, 20, 'Interpreter needed?'),
(74495, 3131, 20, 'Interstitial Lung Disease'),
(74496, 3132, 20, 'Intervalo'),
(74497, 3137, 20, 'Intolerância'),
(74498, 3139, 20, 'intramuscular'),
(74499, 3140, 20, 'intravenosa'),
(74500, 3141, 20, 'Introdução'),
(74501, 3149, 20, 'Inválido ou faltando ordenante na fonte para o código '),
(74502, 3151, 20, 'Invalid Service Códigos'),
(74503, 3152, 20, 'Invalid denominação de origem ""'),
(74504, 3154, 20, 'InvAmt'),
(74505, 3155, 20, 'Inventário'),
(74506, 3159, 20, 'Inventário não está disponível para este fim.'),
(74507, 3160, 20, 'Inventário'),
(74508, 3162, 20, 'Fatura'),
(74509, 3163, 20, 'fatura'),
(74510, 3166, 20, 'Data da fatura'),
(74511, 3167, 20, 'Fatura não tem data!'),
(74512, 3173, 20, 'Fatura:'),
(74513, 3177, 20, 'IPPF SRH dados para'),
(74514, 3178, 20, 'IPPF Relatório de Estatísticas'),
(74515, 3180, 20, 'VPI 1'),
(74516, 3181, 20, 'VPI 2'),
(74517, 3182, 20, 'VPI 3'),
(74518, 3183, 20, 'VPI 4'),
(74519, 3185, 20, 'Batimento cardíaco irregular'),
(74520, 3186, 20, 'Irritabilidade'),
(74521, 3187, 20, 'Irritação'),
(74522, 3191, 20, 'é um campo obrigatório.'),
(74523, 3192, 20, 'é um nó raiz e não pode ser excluído.'),
(74524, 3197, 20, 'não é válida (frações decimais são OK).'),
(74525, 3198, 20, 'PHP é utilizando o modo de segurança?'),
(74526, 3216, 20, 'Problema'),
(74527, 3217, 20, 'problema'),
(74528, 3223, 20, 'Questões'),
(74529, 3225, 20, 'Ocorrências (Lesões / Medical / Alergia):'),
(74530, 3226, 20, 'Questões e Consultas'),
(74531, 3227, 20, 'Questões e Consultas para'),
(74532, 3228, 20, 'Questões não autorizado'),
(74533, 3229, 20, 'A seção'),
(74534, 3231, 20, 'Item'),
(74535, 3232, 20, 'item'),
(74536, 3234, 20, 'Carregar itens não'),
(74537, 3236, 20, 'DIU'),
(74538, 3237, 20, 'IV'),
(74539, 3239, 20, 'Janeiro'),
(74540, 3241, 20, 'Icterícia'),
(74541, 3243, 20, 'Especialidade'),
(74542, 3244, 20, 'Job ID'),
(74543, 3245, 20, 'Luxações articulares'),
(74544, 3246, 20, 'Dor nas Articulações'),
(74545, 3247, 20, 'Entorses Comum'),
(74546, 3249, 20, 'Julho'),
(74547, 3251, 20, 'Junho'),
(74548, 3252, 20, 'Logo abaixo as informações de seleção é uma área azul onde você colocou em seus parâmetros de busca. Você pode pesquisar por nome do paciente, número de registro, número ou a data da Consulta de serviço, ou qualquer combinação destes. Você também pode selecionar se você quiser ver todas as notas fiscais, faturas em aberto, ou que são apenas faturas devidas (pelo paciente). Clique no botão Procurar para executar a pesquisa.'),
(74549, 3253, 20, 'Somente Minhas'),
(74550, 3255, 20, 'Justificar'),
(74551, 3256, 20, 'Justificar / Save'),
(74552, 3258, 20, 'ok, aqui está o resto'),
(74553, 3265, 20, 'Palavras-chave'),
(74554, 3266, 20, 'kg'),
(74555, 3267, 20, 'kg / m ^ 2'),
(74556, 3269, 20, 'Kidney Cancer'),
(74557, 3270, 20, 'Insuficiência Renal'),
(74558, 3271, 20, 'Infecções do Rim'),
(74559, 3272, 20, 'Pedras nos rins'),
(74560, 3273, 20, 'Transplante renal'),
(74561, 3277, 20, 'Joelho'),
(74562, 3278, 20, 'Problemas do Joelho'),
(74563, 3279, 20, 'Recolocação do joelho'),
(74564, 3286, 20, 'Lab'),
(74565, 3295, 20, 'Lab Report'),
(74566, 3303, 20, 'Rótulo'),
(74567, 3304, 20, 'Rótulo não pode estar em branco'),
(74568, 3305, 20, 'Label Cols'),
(74569, 3307, 20, 'LabelCols deve ser um número entre 1 e 999'),
(74570, 3308, 20, 'Labels'),
(74571, 3311, 20, 'Labs'),
(74572, 3312, 20, 'Laceração condição de pele /'),
(74573, 3313, 20, 'Laceração / abrasão'),
(74574, 3316, 20, 'Linguagem'),
(74575, 3317, 20, 'Código de idioma'),
(74576, 3318, 20, 'Definição de linguagem acrescentado'),
(74577, 3319, 20, 'Language Interface Tool'),
(74578, 3320, 20, 'Lista de Língua (escrever, adicionar opcional)'),
(74579, 3321, 20, 'Nome Language'),
(74580, 3322, 20, 'Idioma:'),
(74581, 3325, 20, 'Último'),
(74582, 3326, 20, 'Data Última'),
(74583, 3328, 20, 'Data da última fatura:'),
(74584, 3333, 20, 'Última Consulta'),
(74585, 3344, 20, 'Sobrenome'),
(74586, 3345, 20, 'Sobrenome'),
(74587, 3346, 20, 'Sobrenome'),
(74588, 3352, 20, 'Last Saved'),
(74589, 3356, 20, 'Última atualização por'),
(74590, 3358, 20, 'Sua última visita'),
(74591, 3360, 20, 'A recorrência tardia (2-12 Mo)'),
(74592, 3361, 20, 'Do maléolo lateral'),
(74593, 3362, 20, 'Maléolo lateral:'),
(74594, 3365, 20, 'deslocada lateralmente PMI:'),
(74595, 3373, 20, 'Layout Baseado'),
(74596, 3374, 20, 'Editor de Layout'),
(74597, 3375, 20, 'Grupos Layout'),
(74598, 3378, 20, 'Layout baseado Visite Formulários'),
(74599, 3379, 20, 'Layouts'),
(74600, 3380, 20, 'lb'),
(74601, 3381, 20, 'lbs'),
(74602, 3382, 20, 'LDL'),
(74603, 3383, 20, 'deixe em branco se ainda está ativo'),
(74604, 3385, 20, 'Deixe em branco para manter inalterada a senha.'),
(74605, 3386, 20, 'Deixar recado com'),
(74606, 3387, 20, 'Deixe o formulário'),
(74607, 3390, 20, 'Esquerdo'),
(74608, 3391, 20, 'Orelha Esquerda'),
(74609, 3392, 20, 'orelha esquerda'),
(74610, 3394, 20, 'Esquerda:'),
(74611, 3395, 20, 'Esquerda: '),
(74612, 3396, 20, 'Dor na Perna / cólicas'),
(74613, 3397, 20, 'Legal'),
(74614, 3400, 20, 'Legenda:'),
(74615, 3401, 20, 'Comprimento'),
(74616, 3405, 20, 'Menos de informações privado (escrever, adicionar opcional)'),
(74617, 3406, 20, 'Carta'),
(74618, 3407, 20, 'Letter Generator'),
(74619, 3411, 20, 'Nível de urgência'),
(74620, 3412, 20, 'Responsabilidade'),
(74621, 3413, 20, 'Responsabilidade Médica'),
(74622, 3414, 20, 'RG'),
(74623, 3423, 20, 'Hábitos'),
(74624, 3425, 20, 'Ligamento lágrima ou entorse'),
(74625, 3428, 20, 'Limite de Eventos'),
(74626, 3438, 20, 'Lista'),
(74627, 3439, 20, 'Caixa de lista'),
(74628, 3440, 20, 'caixa de lista'),
(74629, 3441, 20, 'w caixa de lista / add'),
(74630, 3442, 20, 'W Lista de caixa / add'),
(74631, 3443, 20, 'List Editor'),
(74632, 3445, 20, 'Lista de grupos'),
(74633, 3446, 20, 'Seguradoras Lista'),
(74634, 3448, 20, 'Os itens da lista não pode começar com um número.'),
(74635, 3449, 20, 'Os itens da lista contém caracteres ilegais (s).'),
(74636, 3451, 20, 'Lista de listas'),
(74637, 3452, 20, 'Nome da lista'),
(74638, 3453, 20, 'Lista de nomes não podem começar com números.'),
(74639, 3454, 20, 'Prescrição List'),
(74640, 3458, 20, 'Listas'),
(74641, 3461, 20, 'LLL:'),
(74642, 3462, 20, 'LMP'),
(74643, 3464, 20, 'Definições de carga'),
(74644, 3470, 20, 'CARGA'),
(74645, 3472, 20, 'LOC'),
(74646, 3473, 20, 'Local'),
(74647, 3477, 20, 'Estado'),
(74648, 3478, 20, 'Local'),
(74649, 3481, 20, 'Localização não especificada'),
(74650, 3484, 20, 'Localização:'),
(74651, 3495, 20, 'Logado'),
(74652, 3496, 20, 'Logado como'),
(74653, 3497, 20, 'Logado como: '),
(74654, 3498, 20, 'Desconectado.'),
(74655, 3500, 20, 'Login'),
(74656, 3501, 20, 'login'),
(74657, 3505, 20, 'Sair'),
(74658, 3506, 20, 'sair'),
(74659, 3507, 20, 'Históricos'),
(74660, 3508, 20, 'Históricos Viewer'),
(74661, 3510, 20, 'Look Up'),
(74662, 3511, 20, 'Lote'),
(74663, 3512, 20, 'Lote ID faltando!'),
(74664, 3513, 20, 'Número de lote'),
(74665, 3514, 20, 'Baixo'),
(74666, 3516, 20, 'Perna'),
(74667, 3519, 20, 'Coluna lombar'),
(74668, 3520, 20, 'Horário de Almoço'),
(74669, 3521, 20, 'Horário de Almoço'),
(74670, 3522, 20, 'Câncer de Pulmão'),
(74671, 3523, 20, 'Cirurgia de Câncer de Pulmão'),
(74672, 3524, 20, 'Pulmões:'),
(74673, 3525, 20, 'Pulmões:'),
(74674, 3526, 20, 'Lupus'),
(74675, 3528, 20, 'M'),
(74676, 3529, 20, 'MA Categoria'),
(74677, 3535, 20, 'Endereço principal'),
(74678, 3540, 20, 'Faça modificações categorias atuais.'),
(74679, 3542, 20, 'Certifique-se de ""'),
(74680, 3545, 20, 'Mal-estar:'),
(74681, 3548, 20, 'Masculino'),
(74682, 3549, 20, 'Preservativos Masculinos'),
(74683, 3550, 20, 'Masculino VSC'),
(74684, 3552, 20, 'Mamografia'),
(74685, 3557, 20, 'Gerenciamento'),
(74686, 3562, 20, 'Lançamento manual'),
(74687, 3563, 20, 'Fabricante'),
(74688, 3568, 20, 'Março'),
(74689, 3569, 20, 'Estado Civil'),
(74690, 3571, 20, 'Marcar como bico, mas pular de faturamento'),
(74691, 3572, 20, 'Marcar como Cleared'),
(74692, 3573, 20, 'Marcar como não faturado'),
(74693, 3575, 20, 'Marcado como apuradas'),
(74694, 3576, 20, 'Casado'),
(74695, 3594, 20, 'Maxilar direito:'),
(74696, 3603, 20, 'Maio'),
(74697, 3604, 20, 'MC'),
(74698, 3605, 20, 'mcg'),
(74699, 3612, 20, 'Maléolo medial:'),
(74700, 3613, 20, 'Medicaid'),
(74701, 3614, 20, 'Medicina'),
(74702, 3615, 20, 'Aborto Medicinal'),
(74703, 3620, 20, 'Problema médico'),
(74704, 3623, 20, 'Anotações do Paciente'),
(74705, 3624, 20, 'Histórico'),
(74706, 3625, 20, 'Histórico #'),
(74707, 3626, 20, 'Registros Médicos'),
(74708, 3632, 20, 'Medicina / História (escrever, adicionar opcional)'),
(74709, 3633, 20, 'Medicare Part B'),
(74710, 3635, 20, 'Medicação'),
(74711, 3640, 20, 'Medicações'),
(74712, 3641, 20, 'Medicamentos:'),
(74713, 3642, 20, 'Unidades de Medicina'),
(74714, 3643, 20, 'Médio'),
(74715, 3645, 20, 'Membro da Associação Relatório de Estatísticas'),
(74716, 3646, 20, 'Problemas de memória'),
(74717, 3647, 20, 'Homens'),
(74718, 3648, 20, 'Homens e Mulheres'),
(74719, 3649, 20, 'Men Only'),
(74720, 3650, 20, 'Menarca'),
(74721, 3651, 20, 'Menopausa'),
(74722, 3652, 20, 'Fluxo menstrual'),
(74723, 3653, 20, 'Menstrual Freqüência'),
(74724, 3654, 20, 'Doença Mental'),
(74725, 3661, 20, 'Mensagem'),
(74726, 3670, 20, 'MENSAGEM:'),
(74727, 3671, 20, 'Mensagens'),
(74728, 3673, 20, 'Método'),
(74729, 3676, 20, 'Método de Destruição'),
(74730, 3679, 20, 'mg'),
(74731, 3680, 20, 'mg/1cc'),
(74732, 3681, 20, 'mg/2cc'),
(74733, 3682, 20, 'mg/3cc'),
(74734, 3683, 20, 'mg/4cc'),
(74735, 3684, 20, 'mg/5cc'),
(74736, 3686, 20, 'Médio'),
(74737, 3687, 20, 'Nome do Meio'),
(74738, 3688, 20, 'Nome do meio'),
(74739, 3696, 20, 'Migrantes ou sazonal?'),
(74740, 3697, 20, 'Migrantes / Seasonal'),
(74741, 3702, 20, 'MimeType'),
(74742, 3704, 20, 'min'),
(74743, 3706, 20, 'Menor tensão comum + / - sinovite'),
(74744, 3709, 20, 'minutos'),
(74745, 3710, 20, 'Minutos'),
(74746, 3712, 20, 'Misc'),
(74747, 3713, 20, 'Opções de Pagamento Misc'),
(74748, 3714, 20, 'Opções de Faturamento Misc para HCFA-1500'),
(74749, 3715, 20, 'Faturamento Misc Opções HCFA'),
(74750, 3716, 20, 'Diversos'),
(74751, 3717, 20, 'Missed'),
(74752, 3720, 20, 'Missing Fee'),
(74753, 3723, 20, 'Missing PID.'),
(74754, 3725, 20, 'Missing barra depois ordenante na origem para o código '),
(74755, 3726, 20, 'Mixed'),
(74756, 3727, 20, 'ml'),
(74757, 3729, 20, 'mm / Hg'),
(74758, 3731, 20, 'VASPR 1'),
(74759, 3732, 20, 'MMR 2'),
(74760, 3733, 20, 'Móvel'),
(74761, 3734, 20, 'Telefone Celular'),
(74762, 3735, 20, 'Mod'),
(74763, 3741, 20, 'Modifier'),
(74764, 3753, 20, 'Seg'),
(74765, 3754, 20, 'Seg à Sex'),
(74766, 3755, 20, 'Seg, Qua e Sex'),
(74767, 3756, 20, 'Segunda-feira'),
(74768, 3758, 20, 'Mês'),
(74769, 3759, 20, 'mês'),
(74770, 3760, 20, 'Ver mês'),
(74771, 3761, 20, 'Mês (s)'),
(74772, 3762, 20, 'Renda Mensal'),
(74773, 3765, 20, 'Mais de 100 registros encontrados. Restrinja a sua pesquisa.'),
(74774, 3766, 20, 'Mais de 50 resultados, por favor faça sua busca mais específica.'),
(74775, 3771, 20, 'Mãe'),
(74776, 3774, 20, 'Boca'),
(74777, 3775, 20, 'Mover'),
(74778, 3776, 20, 'Mover documento para a categoria:'),
(74779, 3777, 20, 'Mover para baixo'),
(74780, 3779, 20, 'Mover-se para Paciente'),
(74781, 3780, 20, 'Mover para...'),
(74782, 3781, 20, 'Mover para cima'),
(74783, 3783, 20, 'Sr.'),
(74784, 3785, 20, 'Sra.'),
(74785, 3786, 20, 'Srta.'),
(74786, 3796, 20, 'Ferramenta Multi Linguagens'),
(74787, 3797, 20, 'Várias áreas'),
(74788, 3803, 20, 'Murmur:'),
(74789, 3804, 20, 'Musc Dor'),
(74790, 3805, 20, 'Musc Dores'),
(74791, 3806, 20, 'Vermelhidão Musc'),
(74792, 3807, 20, 'Musc Rigidez'),
(74793, 3808, 20, 'Musc Inchaço'),
(74794, 3809, 20, 'Warm Musc'),
(74795, 3810, 20, 'Músculo'),
(74796, 3811, 20, 'Lesão muscular'),
(74797, 3812, 20, 'Musculosqueléticas'),
(74798, 3814, 20, 'Definido mutuamente'),
(74799, 3815, 20, 'MVA'),
(74800, 3821, 20, 'N/A'),
(74801, 3822, 20, 'n/a'),
(74802, 3823, 20, 'Nome'),
(74803, 3825, 20, 'Nome (mais)'),
(74804, 3826, 20, 'Nome 1'),
(74805, 3827, 20, 'Nome 2'),
(74806, 3828, 20, 'Gerenciamento de Vacinas'),
(74807, 3831, 20, 'Nome de Eventos'),
(74808, 3832, 20, 'Nome da seguradora'),
(74809, 3833, 20, 'Nome da Operadora'),
(74810, 3835, 20, 'Tradução Nome'),
(74811, 3836, 20, 'Nome/Valor'),
(74812, 3837, 20, 'Nome:'),
(74813, 3838, 20, 'NARES:'),
(74814, 3839, 20, 'NARES: Direito Normal'),
(74815, 3840, 20, 'Mucosa nasal rosa, linha mediana de septo'),
(74816, 3844, 20, 'Nacionalidade'),
(74817, 3852, 20, 'Nauseas'),
(74818, 3854, 20, 'Navegação'),
(74819, 3862, 20, 'NDC'),
(74820, 3864, 20, 'Número do NDC'),
(74821, 3866, 20, 'Pescoço'),
(74822, 3867, 20, 'Problemas no pescoço'),
(74823, 3868, 20, 'Pescoço flexível'),
(74824, 3869, 20, 'Necessidade de introduzir uma descrição'),
(74825, 3870, 20, 'Necessidade de introduzir um valor de retorno'),
(74826, 3871, 20, 'Necessidade de introduzir identificador'),
(74827, 3872, 20, 'Necessidade de introduzir o título'),
(74828, 3873, 20, 'Necessidades Auth'),
(74829, 3874, 20, 'Necessidades Justify'),
(74830, 3875, 20, 'Necessidades de faturamento secundário'),
(74831, 3880, 20, 'A lesão nervosa'),
(74832, 3881, 20, 'Condição Neural / dano nervoso'),
(74833, 3882, 20, 'Neuro Dormência'),
(74834, 3883, 20, 'Fraqueza Neuro'),
(74835, 3884, 20, 'Neurológicas'),
(74836, 3888, 20, 'Novo'),
(74837, 3889, 20, 'Novo =>'),
(74838, 3890, 20, 'Nova Aceitadores'),
(74839, 3892, 20, 'Nova Alergia'),
(74840, 3894, 20, 'Nova Consulta'),
(74841, 3895, 20, 'Novas Categorias'),
(74842, 3896, 20, 'Nova Categoria'),
(74843, 3897, 20, 'Novos pacientes'),
(74844, 3898, 20, 'Nova Consulta'),
(74845, 3900, 20, 'Novo conjunto de definições adicionados'),
(74846, 3901, 20, 'Novo Documento'),
(74847, 3906, 20, 'Formulário de nova consulta'),
(74848, 3907, 20, 'Nova consulta não autorizada'),
(74849, 3908, 20, 'Nova Consulta'),
(74850, 3909, 20, 'Informações da Nova Clínica'),
(74851, 3912, 20, 'Novo Grupo'),
(74852, 3913, 20, 'Novo Grupo de Informação'),
(74853, 3916, 20, 'New Limit de Eventos'),
(74854, 3917, 20, 'Nova Lista'),
(74855, 3921, 20, 'Novo Paciente'),
(74856, 3922, 20, 'NOVO PACIENTE'),
(74857, 3923, 20, 'Novo Paciente - Consulta'),
(74858, 3924, 20, 'Novo Paciente - Formulário'),
(74859, 3925, 20, 'Novo Paciente - ID'),
(74860, 3926, 20, 'Novo Pagamento'),
(74861, 3928, 20, 'Novo Pt'),
(74862, 3930, 20, 'Nova Busca'),
(74863, 3931, 20, 'Nova Submissão'),
(74864, 3932, 20, 'Novo Usuário'),
(74865, 3934, 20, 'Nova Visita'),
(74866, 3935, 20, 'Novo/Buscar'),
(74867, 3961, 20, 'Jornal'),
(74868, 3962, 20, 'Próximo'),
(74869, 3964, 20, 'Próximo Dia'),
(74870, 3965, 20, 'Próximo Mês'),
(74871, 3966, 20, 'Próximo mês (pressione para o menu)'),
(74872, 3968, 20, 'Próxima Semana'),
(74873, 3969, 20, 'Próximo ano (pressione para o menu)'),
(74874, 3971, 20, 'Apelido'),
(74875, 3973, 20, 'Suores noturnos'),
(74876, 3974, 20, 'Genitais ext Nl, vag mucosa, colo do útero'),
(74877, 3975, 20, 'Não'),
(74878, 3976, 20, 'NÃO'),
(74879, 3977, 20, 'Sem acesso'),
(74880, 3978, 20, 'Nenhum lembrete ativo de pacientes.'),
(74881, 3979, 20, 'Sem adenopatia (2 áreas necessárias)'),
(74882, 3983, 20, 'Sem Compromissos'),
(74883, 3985, 20, 'Sistema de faturamento está atualmente inativo'),
(74884, 3986, 20, 'Nenhuma Cobrança Encontrada para Incluir no OFX Export'),
(74885, 3987, 20, 'Nenhuma Cobrança Encontrada para Incluir no OFX Export<br>'),
(74886, 3989, 20, 'Nenhum código foi especificado!'),
(74887, 3992, 20, 'Nenhum diagnóstico'),
(74888, 3993, 20, 'Nenhum Documento Encontrado'),
(74889, 3994, 20, 'Nenhuma Consulta pôde ser criada'),
(74890, 3995, 20, 'Sem data final'),
(74891, 3996, 20, 'Não foram encontradas entradas, use o formulário abaixo para adicionar uma entrada.'),
(74892, 3997, 20, 'Não foi encontrado erros'),
(74893, 3998, 20, 'Não há eventos'),
(74894, 4001, 20, 'Nenhum grupo foi selecionado'),
(74895, 4002, 20, 'Sem hérnia'),
(74896, 4006, 20, 'Seguradoras Não Encontradas'),
(74897, 4007, 20, 'Sem Problemas'),
(74898, 4008, 20, 'Sem problemas nessa consulta.'),
(74899, 4009, 20, 'Sem itens sob categoria selecionada'),
(74900, 4010, 20, 'Nenhum item foi selecionado!'),
(74901, 4029, 20, 'Nenhum resultado encontrado. Tente nova busca.'),
(74902, 4030, 20, 'Nenhum resultado encontrado.'),
(74903, 4031, 20, 'Nenhum resultado encontrado. Cadastrar novo paciente?'),
(74904, 4033, 20, 'Nenhum novo resultado encontrado'),
(74905, 4034, 20, 'Sem notas'),
(74906, 4036, 20, 'Não foram encontradas vagas para este período.'),
(74907, 4039, 20, 'Nenhum Parceiro Encontrado'),
(74908, 4042, 20, 'Não havia edema periférico'),
(74909, 4043, 20, 'Nenhuma Farmácias'),
(74910, 4044, 20, 'Nenhuma Prescrição'),
(74911, 4045, 20, 'Nenhuma doença que apresenta / lesão'),
(74912, 4051, 20, 'Sem Indicação'),
(74913, 4052, 20, 'Ausência de lesões cutânea ou anormal'),
(74914, 4055, 20, 'Não foram encontrados registos. Por favor, expandir os seus critérios de busca.'),
(74915, 4058, 20, 'Nenhum resultado'),
(74916, 4060, 20, 'Nenhum resultados de busca'),
(74917, 4062, 20, 'Não há resultados, por favor bandeja novamente.'),
(74918, 4063, 20, 'Não há resultados, por favor, tente novamente.'),
(74919, 4065, 20, 'Não Compareceu'),
(74920, 4067, 20, 'No Tenderness Sinus:'),
(74921, 4068, 20, 'Nódulos no ondear da pele ou da mama'),
(74922, 4071, 20, 'No ternura testicular, massas'),
(74923, 4072, 20, 'No emoções ou heaves'),
(74924, 4075, 20, 'Nenhuma visita'),
(74925, 4077, 20, 'Não, Cancelar'),
(74926, 4079, 20, 'Não:'),
(74927, 4080, 20, 'Noctúria'),
(74928, 4083, 20, 'Non lesão específica'),
(74929, 4085, 20, 'Não-insulino-dependente'),
(74930, 4087, 20, 'Non-SRH Médica'),
(74931, 4088, 20, 'Non-SRH não-médicos'),
(74932, 4089, 20, 'Nenhum'),
(74933, 4090, 20, 'nenhum'),
(74934, 4093, 20, 'Nenhuma das anteriores'),
(74935, 4095, 20, 'Noninsulin Dependent Diabetes'),
(74936, 4096, 20, 'Nem'),
(74937, 4097, 20, 'Normal'),
(74938, 4098, 20, 'Normal BL'),
(74939, 4099, 20, 'Exame cardíaco normal:'),
(74940, 4100, 20, 'Exame cardíaco normal: '),
(74941, 4101, 20, 'Exame Pulmonar Normal:'),
(74942, 4102, 20, 'Exame Pulmonar Normal: '),
(74943, 4103, 20, 'Normal Office Visite'),
(74944, 4104, 20, 'Orofaringe normal:'),
(74945, 4105, 20, 'Normal Direito'),
(74946, 4106, 20, 'Normal Direito:'),
(74947, 4107, 20, 'Normal View'),
(74948, 4108, 20, 'normal:'),
(74949, 4112, 20, 'Norueguês'),
(74950, 4115, 20, 'Nariz'),
(74951, 4116, 20, 'Epistaxis'),
(74952, 4117, 20, 'nem letra nem numero'),
(74953, 4119, 20, 'Nem todos os campos são obrigatórios para todos os códigos ou tipos.'),
(74954, 4120, 20, 'Não Desejados'),
(74955, 4121, 20, 'Não é permitida a exclusão do grupo de administradores'),
(74956, 4123, 20, 'Não é permitida a desativação de todos os objetos de segurança'),
(74957, 4124, 20, 'Não permitido para inativar qualquer coisa da Segurança dos Administradores'),
(74958, 4125, 20, 'Não é permitido remover o usuário Administrador do grupo Administradores'),
(74959, 4128, 20, 'Não autorizadas a ter acesso módulo PostCalendar'),
(74960, 4129, 20, 'Não autorizado'),
(74961, 4132, 20, 'Não autorizado para este plantel.'),
(74962, 4135, 20, 'Não Disponível'),
(74963, 4137, 20, 'Não faturado'),
(74964, 4139, 20, 'Não verificado'),
(74965, 4143, 20, 'Não examinados'),
(74966, 4144, 20, 'Não examinados:'),
(74967, 4145, 20, 'Não examinados: '),
(74968, 4146, 20, 'não encontrado'),
(74969, 4148, 20, 'não encontrado!'),
(74970, 4152, 20, 'Não visto desde'),
(74971, 4157, 20, 'Nota'),
(74972, 4162, 20, 'Tipo de nota'),
(74973, 4168, 20, 'Nota: Este código não foi inserido por um usuário autorizado. Apenas códigos autorizados podem ser enviados para o médico do faturamento de uma rede aberta para processamento. Se você deseja enviar esses códigos, selecione um usuário autorizado aqui.'),
(74974, 4170, 20, 'NOTE: Ficheiros com nomes duplicados serão automaticamente remarcados (por ex., file.jpg will become file.1.jpg). Os nomes de ficheiros são considerados únicos por doente, não por categoria.'),
(74975, 4171, 20, 'NOTA: Envio de arquivos com nomes duplicados fará com que os arquivos a serem renomeados automaticamente. Por exemplo, file.jpg se tornará file.jpg.1 . Nomes de arquivos são considerados únicos por paciente e não por categoria.'),
(74976, 4172, 20, 'Notas'),
(74977, 4173, 20, 'Notas - quaisquer encontros (escrever, adicionar opcional)'),
(74978, 4174, 20, 'Notas - meus encontros (escrever, adicionar opcional)'),
(74979, 4175, 20, 'Notas não autorizadas'),
(74980, 4182, 20, 'Nada foi selecionado'),
(74981, 4184, 20, 'AVISO: PostCalendar Submission / Modificação'),
(74982, 4185, 20, 'Notificação'),
(74983, 4189, 20, 'Informe-Admin Sobre o Evento Apresentação / modificação?'),
(74984, 4191, 20, 'Novembro'),
(74985, 4192, 20, 'Agora enviar para:'),
(74986, 4193, 20, 'A imprimir'),
(74987, 4194, 20, 'Agora impressão declarações $ stmt_count e encontros de atualização.'),
(74988, 4195, 20, 'Agora impressão declarações $ stmt_count e faturas de atualização.'),
(74989, 4196, 20, 'Agora impressão declarações $ stmt_count; encontros não serão atualizados.'),
(74990, 4197, 20, 'Agora impressão declarações $ stmt_count; facturas não serão atualizados.'),
(74991, 4198, 20, 'RG'),
(74992, 4200, 20, 'Número'),
(74993, 4204, 20, 'Número de colunas, tendo em conta o ano.'),
(74994, 4215, 20, 'Número de jogos ou eventos perdidos, se houver'),
(74995, 4223, 20, 'Dormência'),
(74996, 4229, 20, 'O.A.F.V.'),
(74997, 4230, 20, 'Sat O2'),
(74998, 4231, 20, 'Obesidade I'),
(74999, 4232, 20, 'Obesidade II'),
(75000, 4233, 20, 'Obesidade III'),
(75001, 4234, 20, 'HMA'),
(75002, 4237, 20, 'Ocupação'),
(75003, 4239, 20, 'Ocorrência'),
(75004, 4240, 20, 'Out'),
(75005, 4241, 20, 'Outubro'),
(75006, 4242, 20, 'OD'),
(75007, 4244, 20, 'de quantidade'),
(75008, 4245, 20, 'de comprimidos'),
(75009, 4246, 20, 'de cada mês'),
(75010, 4247, 20, 'Mensagens'),
(75011, 4249, 20, 'Mensagens Internas'),
(75012, 4250, 20, 'Consulta'),
(75013, 4263, 20, 'Filhos'),
(75014, 4265, 20, 'pomada'),
(75015, 4267, 20, 'OK'),
(75016, 4269, 20, 'OK relacionar a questão GCAC datado'),
(75017, 4272, 20, 'Pacientes antigos'),
(75018, 4273, 20, 'Old não fratura / malunion'),
(75019, 4283, 20, 'Omitir os usuários internos?'),
(75020, 4285, 20, 'omitir a autoassign'),
(75021, 4286, 20, 'ligado'),
(75022, 4288, 20, 'On Hand'),
(75023, 4289, 20, 'Em Ordem'),
(75024, 4292, 20, 'Uma vez que você alterar sua senha, você terá que re-login.'),
(75025, 4297, 20, 'Suporte On-line'),
(75026, 4299, 20, 'Apenas Ativo'),
(75027, 4302, 20, 'apenas se a localização de faturamento'),
(75028, 4303, 20, 'Apenas inativos'),
(75029, 4304, 20, 'Somente Próprias'),
(75030, 4310, 20, 'Início da doença:'),
(75031, 4311, 20, 'O início da Ilness: '),
(75032, 4312, 20, 'Aparecimento de edema:'),
(75033, 4313, 20, 'Onset / hosp. Data:'),
(75034, 4316, 20, 'Abrir'),
(75035, 4328, 20, 'LibreEHR requer que o Javascript para realizar a autenticação do usuário.'),
(75036, 4329, 20, 'Usuários LibreEHR'),
(75037, 4333, 20, 'Opção'),
(75038, 4336, 20, 'Opcional'),
(75039, 4343, 20, 'Nome do medicamento opcional, use% como curinga'),
(75040, 4345, 20, 'Opcional informações sobre este evento'),
(75041, 4346, 20, 'Número de lote, opcional, use% como curinga'),
(75042, 4347, 20, 'Paciente numérico opcional ID'),
(75043, 4348, 20, 'Código Procedimento'),
(75044, 4351, 20, 'Ou'),
(75045, 4352, 20, 'Ou'),
(75046, 4353, 20, 'ou escolha'),
(75047, 4356, 20, 'Ou para fora ao'),
(75048, 4359, 20, 'ERA ou o arquivo de upload:'),
(75049, 4360, 20, 'Oral'),
(75050, 4361, 20, 'Mucosa Oral-de-rosa, a garganta clara'),
(75051, 4362, 20, 'Pedido'),
(75052, 4369, 20, 'Ordem deve ser um número entre 1 e 999'),
(75053, 4386, 20, 'Lesões de órgãos'),
(75054, 4387, 20, 'Pessoa Jurídica'),
(75055, 4390, 20, 'Pessoas Jurídicas'),
(75056, 4391, 20, 'Orientado x 3'),
(75057, 4392, 20, 'Original'),
(75058, 4396, 20, 'Orofaringe: '),
(75059, 4397, 20, 'Ortopnéia'),
(75060, 4398, 20, 'OS'),
(75061, 4399, 20, 'Osetoarthritis'),
(75062, 4402, 20, 'Outro'),
(75063, 4403, 20, 'outro'),
(75064, 4404, 20, 'Outro (especificar)'),
(75065, 4406, 20, 'Outros Programas Governamentais'),
(75066, 4407, 20, 'HCFA Outros'),
(75067, 4408, 20, 'Outros danos não especificados'),
(75068, 4410, 20, 'outro mês'),
(75069, 4411, 20, 'Outros Programas não Governamentais'),
(75070, 4412, 20, 'Outras Notas'),
(75071, 4413, 20, 'Outros sintomas Pertinente'),
(75072, 4414, 20, 'Outros sintomas pertinentes:'),
(75073, 4416, 20, 'Outros stress / Mais de utilização de prejuízo'),
(75074, 4417, 20, 'Cirúrgicos Outros'),
(75075, 4418, 20, 'Outros / Generic relacionadas ao aborto'),
(75076, 4421, 20, 'caso contrário, você irá destruir as referências para / de dados existentes.'),
(75077, 4422, 20, 'Otava Ankle Regras'),
(75078, 4423, 20, 'OU'),
(75079, 4424, 20, 'OUT'),
(75080, 4425, 20, 'Out Of Office'),
(75081, 4427, 20, 'Resultado'),
(75082, 4428, 20, 'Outlook'),
(75083, 4432, 20, 'O uso excessivo'),
(75084, 4434, 20, 'Sobrepeso'),
(75085, 4435, 20, 'Substituir escolha HIPAA'),
(75086, 4437, 20, 'Saturação de Oxigênio'),
(75087, 4439, 20, 'P'),
(75088, 4440, 20, 'P.C.'),
(75089, 4441, 20, 'p.m.'),
(75090, 4442, 20, 'P.R.N.'),
(75091, 4444, 20, 'Pediátricos'),
(75092, 4445, 20, 'Página'),
(75093, 4446, 20, 'Páginas'),
(75094, 4447, 20, 'Pago'),
(75095, 4448, 20, 'Montante pago que você vai alocar'),
(75096, 4450, 20, 'Via Paid'),
(75097, 4451, 20, 'Dor'),
(75098, 4453, 20, 'Palpitações'),
(75099, 4455, 20, 'Papanicolau'),
(75100, 4458, 20, 'Paralisia'),
(75101, 4461, 20, 'Parse HL7'),
(75102, 4463, 20, 'Partner'),
(75103, 4472, 20, 'Senha'),
(75104, 4473, 20, 'Alterar Senha'),
(75105, 4475, 20, 'Mudança de senha bem sucedida.'),
(75106, 4480, 20, 'Senha para o SMS Gateway'),
(75107, 4486, 20, 'Senha:'),
(75108, 4490, 20, 'Vencido'),
(75109, 4491, 20, 'Vencido'),
(75110, 4492, 20, 'Intervalo de Vencimento - Lembrete Clínico'),
(75111, 4493, 20, 'Intervalo de Vencimento - Lembrete Paciente'),
(75112, 4495, 20, 'Consultas passadas'),
(75113, 4496, 20, 'Consultas Passadas e Documentos'),
(75114, 4498, 20, 'Colar HL7 Dados'),
(75115, 4499, 20, 'Cole os dados da importação para a área de texto abaixo:'),
(75116, 4502, 20, 'Patch'),
(75117, 4514, 20, 'Paciente'),
(75118, 4515, 20, 'paciente'),
(75119, 4516, 20, 'PACIENTE'),
(75120, 4521, 20, 'Paciente alergias'),
(75121, 4522, 20, 'Paciente Alergias'),
(75122, 4523, 20, 'Nomeação do Paciente'),
(75123, 4528, 20, 'Prontuário ID'),
(75124, 4529, 20, 'Paciente Checkout'),
(75125, 4530, 20, 'Paciente Checkout '),
(75126, 4533, 20, 'Paciente Comunicação enviado'),
(75127, 4534, 20, 'Paciente Comunication Enviados'),
(75128, 4539, 20, 'Dados do paciente'),
(75129, 4544, 20, 'Documento do paciente'),
(75130, 4547, 20, 'Patient Encounter'),
(75131, 4548, 20, 'Patient Encounter Forma'),
(75132, 4549, 20, 'Paciente Encounters'),
(75133, 4550, 20, 'Paciente Encontrado'),
(75134, 4561, 20, 'Histórico do Paciente'),
(75135, 4562, 20, 'Histórico do Paciente / Hábitos'),
(75136, 4564, 20, 'ID do Paciente'),
(75137, 4566, 20, 'Paciente cartão de identificação'),
(75138, 4568, 20, 'Paciente de Vacinação'),
(75139, 4569, 20, 'Informação do Paciente'),
(75140, 4571, 20, 'A distribuição dos pacientes de Seguros'),
(75141, 4572, 20, 'A distribuição dos pacientes Insurance Report'),
(75142, 4573, 20, 'Paciente Questões'),
(75143, 4581, 20, 'Lista de pacientes'),
(75144, 4587, 20, 'Anotações do Paciente'),
(75145, 4588, 20, 'Paciente Medications'),
(75146, 4590, 20, 'Nome e endereço do paciente'),
(75147, 4596, 20, 'Paciente Nota Tipos'),
(75148, 4597, 20, 'Anotações do Paciente'),
(75149, 4598, 20, 'Anotações do Paciente (escrever, adicionar opcional)'),
(75150, 4599, 20, 'Número de doentes'),
(75151, 4608, 20, 'Paciente Relatório Impresso'),
(75152, 4609, 20, 'Registrar Relatório do Paciente'),
(75153, 4620, 20, 'Relatório do paciente'),
(75154, 4621, 20, 'Paciente Pedido'),
(75155, 4629, 20, 'Resumo do paciente'),
(75156, 4630, 20, 'Transações do Paciente'),
(75157, 4632, 20, 'paciente (s) no banco de dados que correspondem às informações demográficas que você entrou.'),
(75158, 4633, 20, 'Paciente'),
(75159, 4634, 20, 'Paciente:'),
(75160, 4636, 20, 'Pacientes'),
(75161, 4638, 20, 'Pago'),
(75162, 4639, 20, 'Preste atenção ao ""Feito com "" caixas. Depois que os seguros são marcadas completa, então vamos começar a pedir o doente para o pagamento do saldo remanescente, se você deixar de marcar todos os seguros, em seguida, completar o valor restante não será coletado! Além disso, se há um equilíbrio que o paciente deve pagar, em seguida, defina a data de vencimento de forma adequada, como isso vai afetar o idioma que aparece sobre as declarações do paciente.'),
(75163, 4640, 20, 'Data de pagamento:'),
(75164, 4643, 20, 'Pagamento'),
(75165, 4644, 20, 'Tipo de Pagamento'),
(75166, 4645, 20, 'Pagar'),
(75167, 4647, 20, 'Pagamento'),
(75168, 4648, 20, 'pagamento'),
(75169, 4654, 20, 'Data de Pagamento'),
(75170, 4655, 20, 'pagamento inscritas no'),
(75171, 4660, 20, 'Método de Pagamento'),
(75172, 4664, 20, 'Valor do pagamento para o código '),
(75173, 4665, 20, 'Pagamentos'),
(75174, 4669, 20, 'PDF'),
(75175, 4672, 20, 'Pelve e nádega'),
(75176, 4673, 20, 'Pênfigo'),
(75177, 4674, 20, 'Pendente'),
(75178, 4677, 20, 'Followup Pending'),
(75179, 4684, 20, 'Empresa Pennington LibreEHR v'),
(75180, 4685, 20, 'Úlcera Péptica Doença'),
(75181, 4687, 20, 'por minuto'),
(75182, 4688, 20, 'Por Narina'),
(75183, 4689, 20, 'por narina'),
(75184, 4690, 20, 'Por Oris'),
(75185, 4691, 20, 'por oris'),
(75186, 4692, 20, 'Por Reto'),
(75187, 4693, 20, 'por reto'),
(75188, 4698, 20, 'Perfurado Direita:'),
(75189, 4699, 20, 'Execute Busca'),
(75190, 4700, 20, 'Realizar esta ação'),
(75191, 4708, 20, 'Periférico'),
(75192, 4712, 20, 'Pessoa'),
(75193, 4717, 20, 'Farmácias'),
(75194, 4718, 20, 'Farmácia'),
(75195, 4719, 20, 'Farmácia Dispensário'),
(75196, 4720, 20, 'Pheumothorax'),
(75197, 4729, 20, 'Telefone'),
(75198, 4730, 20, 'Telefone lista de chamadas'),
(75199, 4738, 20, 'Telefone'),
(75200, 4740, 20, 'Fotofobia'),
(75201, 4742, 20, 'PHP comprimido'),
(75202, 4744, 20, 'PHP extraída'),
(75203, 4745, 20, 'php controles de acesso GACL são desligados'),
(75204, 4746, 20, 'PHP-GACL não está instalado'),
(75205, 4747, 20, 'Exame Físico'),
(75206, 4749, 20, 'Pedido médico'),
(75207, 4750, 20, 'Assinatura do Médico'),
(75208, 4752, 20, 'Médicos'),
(75209, 4753, 20, 'cores'),
(75210, 4756, 20, 'PID'),
(75211, 4757, 20, 'PID (Doença Inflamatória Pélvica)'),
(75212, 4758, 20, 'Tamanho Comprimido'),
(75213, 4759, 20, 'Pills'),
(75214, 4765, 20, 'Espaço reservado'),
(75215, 4766, 20, 'Espaço reservado (Mantém vazio ACLs)'),
(75216, 4767, 20, 'Plain Text'),
(75217, 4768, 20, 'Conduta'),
(75218, 4771, 20, 'Nome do Plano'),
(75219, 4779, 20, 'Plano:'),
(75220, 4784, 20, 'Jogador'),
(75221, 4785, 20, 'Jogando Posição'),
(75222, 4790, 20, 'Por favor, escolha uma selecção válida a partir da lista.'),
(75223, 4791, 20, 'Por favor, escolha uma selecção válida.'),
(75224, 4792, 20, 'Por favor, escolha um valor para'),
(75225, 4797, 20, 'Por favor, feche esta janela.'),
(75226, 4798, 20, 'Por favor, compare o novo nome'),
(75227, 4802, 20, 'Por favor, não aceitamos essa receita que não tenha sido recebido através facimile.'),
(75228, 4804, 20, 'Por favor, não use o seu navegador ou parar botão Recarregar enquanto esta página está em execução a menos que mais de 10 minutos se passaram, isso não fará com que o processo parar no servidor e vai consumir recursos uneccesary.'),
(75229, 4813, 20, 'Por favor, indique um valor monetário usando apenas números e um ponto decimal.'),
(75230, 4815, 20, 'Por favor, indique uma descrição!'),
(75231, 4837, 20, 'Por favor, note que isso pode levar um tempo muito longo, até vários minutos, o seu navegador pode não aparecer muito ativo durante este tempo, mas gerando um projeto de lei é um processo complicado e seu navegador está apenas à espera de mais informações.'),
(75232, 4838, 20, 'Atenção: as constantes são caso sensível e qualquer seqüência de caracteres é permitida.');
INSERT INTO `lang_definitions` VALUES
(75233, 4839, 20, 'Por favor, utilize apenas caracteres alfabéticos'),
(75234, 4840, 20, 'Por favor, utilize apenas caracteres alfabéticos sem espaços'),
(75235, 4841, 20, 'Por favor, o pagamento deste montante'),
(75236, 4858, 20, 'Por favor selecione uma razão de ajuste para o código '),
(75237, 4859, 20, 'Por favor selecione um evento'),
(75238, 4865, 20, 'Por favor, selecione as páginas desejadas para copiar ou para a frente:'),
(75239, 4882, 20, 'PM'),
(75240, 4884, 20, 'PMT Método'),
(75241, 4885, 20, 'PND'),
(75242, 4886, 20, 'Pneumocócica conjugada 1'),
(75243, 4887, 20, 'Pneumocócica conjugada 2'),
(75244, 4888, 20, 'Pneumocócica conjugada 3'),
(75245, 4889, 20, 'Pneumocócica conjugada 4'),
(75246, 4891, 20, 'Pneumonia Vacinação'),
(75247, 4896, 20, 'Point of Service (POS)'),
(75248, 4897, 20, 'Política'),
(75249, 4899, 20, 'Número da apólice'),
(75250, 4901, 20, 'Polidipsia'),
(75251, 4902, 20, 'Pólipos'),
(75252, 4903, 20, 'Poliúria'),
(75253, 4904, 20, 'Falta de Apetite'),
(75254, 4905, 20, 'Baixa Circulação'),
(75255, 4906, 20, 'Baixa Audição'),
(75256, 4908, 20, 'Preencher a visão anos com eventos?'),
(75257, 4909, 20, 'Popups'),
(75258, 4918, 20, 'Português (Brasil)'),
(75259, 4919, 20, 'Português (Europeu)'),
(75260, 4920, 20, 'POS Código'),
(75261, 4926, 20, 'Post Nasal Drip'),
(75262, 4928, 20, 'Pós cirúrgico'),
(75263, 4929, 20, 'Post a contabilidade e marcar como faturado'),
(75264, 4933, 20, 'Post-Abortion Care'),
(75265, 4934, 20, 'A contracepção pós-aborto'),
(75266, 4935, 20, 'Aconselhamento pós-aborto'),
(75267, 4936, 20, 'Pós-aborto Followup'),
(75268, 4937, 20, 'Postal'),
(75269, 4938, 20, 'CEP'),
(75270, 4939, 20, 'CEP'),
(75271, 4941, 20, 'PostCalendar'),
(75272, 4942, 20, 'PostCalendar Administração'),
(75273, 4943, 20, 'PostCalendar Categoria Definições'),
(75274, 4944, 20, 'PostCalendar Global Settings'),
(75275, 4945, 20, 'Postado em'),
(75276, 4946, 20, 'Data de lançamento'),
(75277, 4953, 20, 'Clínica'),
(75278, 4955, 20, 'Definições da Clínica'),
(75279, 4956, 20, 'Profissional'),
(75280, 4960, 20, 'Consulta pré-aborto'),
(75281, 4961, 20, 'Aconselhamento pré-aborto'),
(75282, 4962, 20, 'Pref Cat'),
(75283, 4965, 20, 'Preferidos Categoria do evento'),
(75284, 4966, 20, 'Idioma preferido'),
(75285, 4967, 20, 'Preferidos Farmácia'),
(75286, 4968, 20, 'Preferred Provider Organization (PPO)'),
(75287, 4969, 20, 'Teste de gravidez'),
(75288, 4972, 20, 'Pagamento antecipado'),
(75289, 4973, 20, 'Prescrição'),
(75290, 4977, 20, 'Prescrição Label'),
(75291, 4979, 20, 'Prescrição'),
(75292, 4980, 20, 'Prescrição e dispensas'),
(75293, 4981, 20, 'Prescrições e outras referências'),
(75294, 4982, 20, 'Prescrições e / ou referências do especialista'),
(75295, 4983, 20, 'Prescrição Relatório'),
(75296, 4984, 20, 'Prescrição / Registo'),
(75297, 4986, 20, 'Apresentar Queixa'),
(75298, 4988, 20, 'Pressione Continuar para prosseguir'),
(75299, 4989, 20, 'Presume-Diagnóstico'),
(75300, 4990, 20, 'Diagnóstico presumido por especialista'),
(75301, 4991, 20, 'Anterior'),
(75302, 4998, 20, 'Preview Event'),
(75303, 5001, 20, 'Anterior'),
(75304, 5002, 20, 'Consultas anteriores'),
(75305, 5003, 20, 'Dia Anterior'),
(75306, 5004, 20, 'História Anterior / Screening'),
(75307, 5005, 20, 'Mês anterior'),
(75308, 5006, 20, 'Semana anterior'),
(75309, 5007, 20, 'Preço'),
(75310, 5008, 20, 'Valor Desconto'),
(75311, 5009, 20, 'Nível de Preços'),
(75312, 5010, 20, 'Nível de Preços:'),
(75313, 5011, 20, 'Preços'),
(75314, 5012, 20, 'Primário'),
(75315, 5022, 20, 'Ins Primário'),
(75316, 5023, 20, 'Seguro Primário'),
(75317, 5024, 20, 'Primária de Seguro de Dados'),
(75318, 5025, 20, 'Primeiro Convênio'),
(75319, 5026, 20, 'Provedor primário'),
(75320, 5027, 20, 'Imprimir'),
(75321, 5032, 20, 'Print Blank Referral Forma'),
(75322, 5039, 20, 'Formato de Impressão'),
(75323, 5040, 20, 'Imprimir Quatro Painel'),
(75324, 5043, 20, 'Imprimir múltiplas'),
(75325, 5044, 20, 'Para imprimir várias Fax'),
(75326, 5047, 20, 'Imprimir Página 1'),
(75327, 5048, 20, 'Imprimir página 2'),
(75328, 5052, 20, 'Imprimir Anotação'),
(75329, 5054, 20, 'Imprimir Shot Record'),
(75330, 5057, 20, 'Imprimir esta nota'),
(75331, 5058, 20, 'Imprimir esta nota'),
(75332, 5060, 20, 'Imprimir para Fax'),
(75333, 5061, 20, 'Versão para impressão'),
(75334, 5062, 20, 'Imprimir Proposta'),
(75335, 5063, 20, 'Printable Version'),
(75336, 5064, 20, 'Impresso'),
(75337, 5066, 20, 'Impressão de resultados:'),
(75338, 5068, 20, 'Imprensa ignorado; ver a saída de teste em '),
(75339, 5069, 20, 'Antes Auth'),
(75340, 5070, 20, 'Formulário de Autorização Prévia'),
(75341, 5073, 20, 'Prioridade '),
(75342, 5074, 20, 'Privado'),
(75343, 5075, 20, 'Problema'),
(75344, 5077, 20, 'Lista Problema'),
(75345, 5079, 20, 'Problemas / Questões'),
(75346, 5086, 20, 'Processo'),
(75347, 5114, 20, 'Procedimentos'),
(75348, 5115, 20, 'Processo'),
(75349, 5125, 20, 'Processamento'),
(75350, 5132, 20, 'Produtos'),
(75351, 5134, 20, 'Prof'),
(75352, 5136, 20, 'Câncer de Próstata'),
(75353, 5138, 20, 'Exame de próstata'),
(75354, 5139, 20, 'Problemas da Próstata'),
(75355, 5140, 20, 'Próstata w / o enlrgmt, nódulos, concurso'),
(75356, 5152, 20, 'Médico'),
(75357, 5159, 20, 'Número do Médico'),
(75358, 5162, 20, 'Operadora:'),
(75359, 5163, 20, 'Médicos'),
(75360, 5164, 20, 'RG dos Médicos'),
(75361, 5166, 20, 'Prv'),
(75362, 5167, 20, 'PSA'),
(75363, 5168, 20, 'Psoríase'),
(75364, 5169, 20, 'Psych Diagnóstico'),
(75365, 5170, 20, 'Psych Medication'),
(75366, 5171, 20, 'Psychiatric'),
(75367, 5172, 20, 'Psiquiátrica Breve Carta'),
(75368, 5173, 20, 'Diagnóstico psiquiátrico'),
(75369, 5174, 20, 'Exame psiquiátrico'),
(75370, 5175, 20, 'Histórico psiquiátrico'),
(75371, 5176, 20, 'Psiquiátrica Intake'),
(75372, 5177, 20, 'Medicação Psiquiátrica'),
(75373, 5178, 20, '% Pt'),
(75374, 5179, 20, 'Pt Notas'),
(75375, 5180, 20, 'Pt Notas / Auth'),
(75376, 5181, 20, 'Pt excesso'),
(75377, 5182, 20, 'Pt Paid'),
(75378, 5184, 20, 'Restituição Pt'),
(75379, 5185, 20, 'Pt liberado'),
(75380, 5186, 20, 'Pt Relatório'),
(75381, 5187, 20, 'PT Estudante, ou deixar em branco'),
(75382, 5189, 20, 'PT_DOB'),
(75383, 5191, 20, 'PT_FNAME'),
(75384, 5192, 20, 'PT_LNAME'),
(75385, 5193, 20, 'PT_MNAME'),
(75386, 5201, 20, 'Público'),
(75387, 5205, 20, 'Pulmonar'),
(75388, 5206, 20, 'Pulse'),
(75389, 5213, 20, 'q.3h'),
(75390, 5214, 20, 'q.4h'),
(75391, 5215, 20, 'q.5h'),
(75392, 5216, 20, 'q.6h'),
(75393, 5217, 20, 'q.8h'),
(75394, 5218, 20, 'q.d.'),
(75395, 5219, 20, 'q.i.d.'),
(75396, 5220, 20, 'Ecl'),
(75397, 5222, 20, 'Qtde'),
(75398, 5223, 20, 'QTD'),
(75399, 5224, 20, 'Qualidade'),
(75400, 5226, 20, 'Quantidade'),
(75401, 5227, 20, 'Quantidade de NDC'),
(75402, 5228, 20, 'Quantidade On Hand'),
(75403, 5232, 20, 'HCFA fila para processamento em lote'),
(75404, 5233, 20, 'HCFA fila para processamento em lote e impressão'),
(75405, 5234, 20, 'Fila para o UB-92 lotes de processamento'),
(75406, 5235, 20, 'Fila para o UB-92 lotes de processamento e impressão'),
(75407, 5236, 20, 'Enfileirado'),
(75408, 5237, 20, 'Em fila de espera de eventos Administração'),
(75409, 5238, 20, 'Em fila de espera para'),
(75410, 5240, 20, 'Submissões fila Administração'),
(75411, 5243, 20, 'R'),
(75412, 5245, 20, 'Raça'),
(75413, 5247, 20, 'Raça / Etnia'),
(75414, 5248, 20, 'Rádio'),
(75415, 5249, 20, 'Radio buttons'),
(75416, 5252, 20, 'Pruridos'),
(75417, 5253, 20, 'Categoria'),
(75418, 5261, 20, 'Reaberto'),
(75419, 5262, 20, 'Reaberto'),
(75420, 5264, 20, 'Reações'),
(75421, 5268, 20, 'Nome real'),
(75422, 5270, 20, 'Motivo'),
(75423, 5274, 20, 'Motivo do encaminhamento'),
(75424, 5275, 20, 'Motivo da visita'),
(75425, 5276, 20, 'Motivo / Forma'),
(75426, 5277, 20, 'Recibo'),
(75427, 5278, 20, 'Recibo de pagamento'),
(75428, 5279, 20, 'Recibo Gerado'),
(75429, 5280, 20, 'Recibos de Pagamento Relatório'),
(75430, 5281, 20, 'Recibos Resumo'),
(75431, 5282, 20, 'Recebido'),
(75432, 5283, 20, 'Recebido Por'),
(75433, 5284, 20, 'Os faxes recebidos'),
(75434, 5287, 20, 'Receptor'),
(75435, 5288, 20, 'Identificação do receptor'),
(75436, 5300, 20, 'Recomendações'),
(75437, 5301, 20, 'Recomendações e tratamento'),
(75438, 5302, 20, 'Recomendações do especialista'),
(75439, 5314, 20, 'Registro de Pagamento'),
(75440, 5319, 20, 'registros encontrados.'),
(75441, 5322, 20, 'Retal'),
(75442, 5323, 20, 'Exame Retal'),
(75443, 5324, 20, 'retal'),
(75444, 5326, 20, 'Vermelhidão'),
(75445, 5327, 20, 'reduzido:'),
(75446, 5328, 20, 'Consulte'),
(75447, 5329, 20, 'Ao se referir'),
(75448, 5330, 20, 'Data Consulte'),
(75449, 5331, 20, 'Consulte'),
(75450, 5332, 20, 'Referência classificação (nível de risco)'),
(75451, 5334, 20, 'Referência Reason'),
(75452, 5336, 20, 'Atribuir nome e assinatura'),
(75453, 5337, 20, 'Atribuir'),
(75454, 5338, 20, 'Por remessa'),
(75455, 5339, 20, 'Atribuir Cartão'),
(75456, 5340, 20, 'Data de remessa'),
(75457, 5341, 20, 'Consulta Formulário'),
(75458, 5342, 20, 'FORMA DE REMESSA'),
(75459, 5345, 20, 'Fonte de referência'),
(75460, 5347, 20, 'Consulta de'),
(75461, 5348, 20, 'Diagnósticos'),
(75462, 5349, 20, 'Relatório de Diagnósticos'),
(75463, 5350, 20, 'Diagnosticado por'),
(75464, 5351, 20, 'Diagnosticados por'),
(75465, 5352, 20, 'Diagnosticado'),
(75466, 5353, 20, 'Médico'),
(75467, 5355, 20, 'Diagnóstico do médico'),
(75468, 5356, 20, 'Diagnóstico Referido'),
(75469, 5357, 20, 'Referindo-se médico e clínica'),
(75470, 5358, 20, 'Referindo-Médico'),
(75471, 5360, 20, 'Recargas'),
(75472, 5361, 20, 'recargas'),
(75473, 5362, 20, 'Reflexos normais'),
(75474, 5363, 20, 'Atualizar'),
(75475, 5369, 20, 'reg_re'),
(75476, 5370, 20, 'Registre-se'),
(75477, 5372, 20, 'Registado'),
(75478, 5373, 20, 'registada'),
(75479, 5375, 20, 'Data de Registro'),
(75480, 5376, 20, 'Formulário de Inscrição'),
(75481, 5377, 20, 'Reabilitação'),
(75482, 5381, 20, 'Relate To'),
(75483, 5382, 20, 'Relacionados'),
(75484, 5385, 20, 'Relação (s) / Crianças'),
(75485, 5387, 20, 'Parentesco'),
(75486, 5389, 20, 'Parentes'),
(75487, 5399, 20, 'Credenciais Relay Saúde estão em falta a partir desta conta de usuário.'),
(75488, 5400, 20, 'Relay Saúde ID'),
(75489, 5403, 20, 'Religião'),
(75490, 5406, 20, 'Relogin'),
(75491, 5416, 20, 'Remover'),
(75492, 5419, 20, 'Remover Grupo'),
(75493, 5420, 20, 'Remover Grupo Forma'),
(75494, 5426, 20, 'Renal Stones'),
(75495, 5428, 20, 'Renomear Grupo'),
(75496, 5429, 20, 'Rendering'),
(75497, 5430, 20, 'Rendering Provider'),
(75498, 5431, 20, 'Rendering Provider Number'),
(75499, 5433, 20, 'Ao reordenar'),
(75500, 5439, 20, 'Info Repetindo:'),
(75501, 5440, 20, 'Repete'),
(75502, 5444, 20, 'Data Responder'),
(75503, 5445, 20, 'De Responder'),
(75504, 5446, 20, 'Relatório'),
(75505, 5449, 20, 'Relatório'),
(75506, 5458, 20, 'Totals Report'),
(75507, 5463, 20, 'Relatórios'),
(75508, 5467, 20, 'Pedido ignorado - tratamento dos pedidos já está em execução!'),
(75509, 5474, 20, 'Serviço solicitado'),
(75510, 5477, 20, 'Necessário'),
(75511, 5485, 20, 'RESERVADO'),
(75512, 5486, 20, 'Reservado'),
(75513, 5487, 20, 'Reservado para uso para definir o tempo de férias agendadas'),
(75514, 5488, 20, 'Reservado para definir quando um fornecedor pode não ter disponível após a nomeação.'),
(75515, 5489, 20, 'Reservado para definir quando um evento não ocorreu, conforme especificado.'),
(75516, 5490, 20, 'Tempo disponível na clínica.'),
(75517, 5496, 20, 'Resolvidas'),
(75518, 5497, 20, 'Respiração'),
(75519, 5498, 20, 'Esforço Respirador unlabored'),
(75520, 5499, 20, 'Respiratory'),
(75521, 5503, 20, 'Restrita Formação'),
(75522, 5504, 20, 'Resultado'),
(75523, 5511, 20, 'Resultados encontrados para pesquisa'),
(75524, 5517, 20, 'Exame da retina'),
(75525, 5518, 20, 'Retraído Direita:'),
(75526, 5519, 20, 'Retorno'),
(75527, 5521, 20, 'Voltar à agenda'),
(75528, 5527, 20, 'Valor de retorno'),
(75529, 5528, 20, 'Visite Retorno'),
(75530, 5529, 20, 'Voltou a jogar'),
(75531, 5534, 20, 'Revisão do PMH'),
(75532, 5535, 20, 'Revisão dos sistemas'),
(75533, 5536, 20, 'Antecedentes Pessoais'),
(75534, 5538, 20, 'Revisão'),
(75535, 5540, 20, 'Rheumotoid Arthritis'),
(75536, 5541, 20, 'Direito'),
(75537, 5542, 20, 'Orelha Direita'),
(75538, 5543, 20, 'orelha direita'),
(75539, 5545, 20, 'Direita:'),
(75540, 5546, 20, 'Zumbidos nos ouvidos'),
(75541, 5547, 20, 'Zumbidos nos ouvidos'),
(75542, 5549, 20, 'Fatores de Risco'),
(75543, 5550, 20, 'Nível de Risco'),
(75544, 5551, 20, 'RLL:'),
(75545, 5552, 20, 'ROM'),
(75546, 5560, 20, 'Plantel'),
(75547, 5561, 20, 'Rota'),
(75548, 5564, 20, 'Filas'),
(75549, 5565, 20, 'RRR sem MOR'),
(75550, 5566, 20, 'Rub:'),
(75551, 5567, 20, 'Rubs:'),
(75552, 5581, 20, 'Comando de duração: '),
(75553, 5582, 20, 'Ruptura'),
(75554, 5583, 20, 'Russo'),
(75555, 5584, 20, 'Rx'),
(75556, 5585, 20, 'RX'),
(75557, 5600, 20, 'S'),
(75558, 5601, 20, 'CPF'),
(75559, 5602, 20, 'S3:'),
(75560, 5603, 20, 'S4:'),
(75561, 5604, 20, 'SA * * Para ler a licença, por favor leia o docs / license.txt ou visite http://www.gnu.org/copyleft/gpl.html * * * / //============ ================================================== =========== / / '),
(75562, 5606, 20, 'Vendas'),
(75563, 5607, 20, 'Vendas por Item'),
(75564, 5608, 20, 'Relatório de vendas por produto'),
(75565, 5610, 20, 'Mesmo dia'),
(75566, 5612, 20, 'Amostra'),
(75567, 5613, 20, 'Sanção Tipo'),
(75568, 5617, 20, 'Sáb'),
(75569, 5618, 20, 'Sáb & Dom'),
(75570, 5619, 20, 'Sábado'),
(75571, 5620, 20, 'Salvar'),
(75572, 5624, 20, 'Salvar e Dispense'),
(75573, 5626, 20, 'Salvar como nova'),
(75574, 5629, 20, 'Salvar alterações'),
(75575, 5630, 20, 'Salvar Form'),
(75576, 5631, 20, 'Salvar Vacinação'),
(75577, 5632, 20, 'Salvar Novo Campo'),
(75578, 5633, 20, 'Salvar Novo Grupo'),
(75579, 5634, 20, 'Salvar Lista'),
(75580, 5635, 20, 'Salvar novo modelo'),
(75581, 5637, 20, 'Salvar Informações do Paciente'),
(75582, 5638, 20, 'Guarde bem sucedido para gráfico ID'),
(75583, 5639, 20, 'Salvar Operação'),
(75584, 5641, 20, 'Digitalizada'),
(75585, 5642, 20, 'Scanned Nota Encounter'),
(75586, 5644, 20, 'Em Scanner'),
(75587, 5645, 20, 'Cronograma'),
(75588, 5646, 20, 'Agenda da Clínica:'),
(75589, 5647, 20, 'NOTA ESCOLA'),
(75590, 5648, 20, 'Escoliose'),
(75591, 5651, 20, 'SE'),
(75592, 5652, 20, 'SE Endereço'),
(75593, 5653, 20, 'SE Cidade'),
(75594, 5654, 20, 'SE País'),
(75595, 5655, 20, 'SE Bairro'),
(75596, 5656, 20, 'SE CEP'),
(75597, 5657, 20, 'SE Estado'),
(75598, 5658, 20, 'SE CEP'),
(75599, 5659, 20, 'Pesquisa'),
(75600, 5661, 20, 'pesquisa'),
(75601, 5662, 20, 'busca novamente'),
(75602, 5663, 20, 'Buscar todas as Colunas'),
(75603, 5664, 20, 'Busca por:'),
(75604, 5665, 20, 'Busca por:'),
(75605, 5666, 20, 'Busca por:'),
(75606, 5667, 20, 'Procurar em'),
(75607, 5668, 20, 'Procurar em'),
(75608, 5669, 20, 'Procurar ou Adicionar Paciente'),
(75609, 5672, 20, 'Resultados da Pesquisa:'),
(75610, 5674, 20, 'O termo de procura não tem correspondência na base de dados'),
(75611, 5675, 20, 'Termo de procura deve ter pelo menos três carateres'),
(75612, 5677, 20, 'Pesquisa de Eventos'),
(75613, 5679, 20, 'Buscar / Adicionar Seguradora'),
(75614, 5680, 20, 'Procurando nomeações'),
(75615, 5681, 20, 'Pesquisando ...'),
(75616, 5682, 20, 'Use cinto de segurança'),
(75617, 5683, 20, 'Uso do cinto'),
(75618, 5684, 20, 'Segunda'),
(75619, 5687, 20, 'Segundo'),
(75620, 5688, 20, 'Segundo Convênio'),
(75621, 5689, 20, 'Dados do Segundo Convênio'),
(75622, 5690, 20, 'Segundo Convênio'),
(75623, 5693, 20, 'ID'),
(75624, 5694, 20, 'ID e Nome Não podem estar vazios'),
(75625, 5695, 20, 'Nome'),
(75626, 5696, 20, 'Seção salva com sucesso'),
(75627, 5698, 20, 'Segurança'),
(75628, 5699, 20, 'Todos Médicos'),
(75629, 5700, 20, 'Veja Autorizações'),
(75630, 5701, 20, 'Veja Growth-chart'),
(75631, 5702, 20, 'Veja mensagens do último conjunto de créditos gerados'),
(75632, 5704, 20, 'Atividade desde'),
(75633, 5707, 20, 'Apreensões'),
(75634, 5708, 20, 'Sel'),
(75635, 5709, 20, 'Selecione'),
(75636, 5710, 20, 'Selecionar'),
(75637, 5711, 20, 'Selecionar um Componente'),
(75638, 5712, 20, 'Selecionar um Contexto'),
(75639, 5715, 20, 'Selecionar Usuario'),
(75640, 5716, 20, 'Selecionar Tudo'),
(75641, 5720, 20, 'Selecionar Categoria'),
(75642, 5721, 20, 'Selecionar preferencias de Comunicação'),
(75643, 5722, 20, 'Selecionar checkboxes para deletar'),
(75644, 5724, 20, 'Selecionar Tabela CSV'),
(75645, 5736, 20, 'Selecionar campo'),
(75646, 5737, 20, 'Selecione Campo'),
(75647, 5738, 20, 'Selecionar para impressão'),
(75648, 5742, 20, 'Emissão Selecione'),
(75649, 5754, 20, 'Selecione os itens de configuração para exportação'),
(75650, 5762, 20, 'Selecione Sim para confirmar a exclusão do grupo'),
(75651, 5768, 20, 'Self'),
(75652, 5769, 20, 'Pagamento Self'),
(75653, 5774, 20, 'Enviar em andamento'),
(75654, 5788, 20, 'Remetente'),
(75655, 5789, 20, 'Remetente ID'),
(75656, 5794, 20, 'Sensibilidades'),
(75657, 5795, 20, 'Sensibilidade:'),
(75658, 5796, 20, 'Sensorial exame normal'),
(75659, 5804, 20, 'Enviada com sucesso!'),
(75660, 5807, 20, 'enviadas para a impressora.'),
(75661, 5813, 20, 'Separado'),
(75662, 5814, 20, 'Setembro'),
(75663, 5822, 20, 'Categoria de Serviço'),
(75664, 5826, 20, 'Data Serviço'),
(75665, 5827, 20, 'Data Serviço:'),
(75666, 5829, 20, 'Localização'),
(75667, 5831, 20, 'Serviço prestado pelo especialista'),
(75668, 5834, 20, 'Serviços'),
(75669, 5835, 20, 'Serviços por Categoria'),
(75670, 5836, 20, 'Serviços prestados'),
(75671, 5837, 20, 'Serviços Prestados'),
(75672, 5849, 20, 'Definições'),
(75673, 5851, 20, 'Severe Migraine'),
(75674, 5853, 20, 'Severidade da dor'),
(75675, 5854, 20, 'Severidade da dor:'),
(75676, 5855, 20, 'Sexo'),
(75677, 5856, 20, 'Doenças Sexualmente Transmissíveis'),
(75678, 5859, 20, 'Compartilhamento'),
(75679, 5864, 20, 'Falta de ar'),
(75680, 5865, 20, 'Shortness de respiração'),
(75681, 5866, 20, 'Shortness de respiração 2'),
(75682, 5867, 20, 'Shot Record'),
(75683, 5868, 20, 'Shot Record a partir de:'),
(75684, 5870, 20, 'deve ser como nnnnn nnnn-nn'),
(75685, 5874, 20, 'Ombro'),
(75686, 5875, 20, 'Ombro + clavícula'),
(75687, 5876, 20, 'Problemas de ombro'),
(75688, 5877, 20, 'Mostrar'),
(75689, 5884, 20, 'Mostrar como Ocupado'),
(75690, 5885, 20, 'Mostrar apenas autorizado'),
(75691, 5889, 20, 'Mostrar Detalhes'),
(75692, 5892, 20, 'Mostrar texto de eventos que paira sobre mouseover?'),
(75693, 5893, 20, 'Mostrar eventos como muitas páginas de administração?'),
(75694, 5906, 20, 'Mostrar Relatório'),
(75695, 5907, 20, 'Mostrar / Buscar - apresentar links em bloco?'),
(75696, 5913, 20, 'Mostrar só não faturada'),
(75697, 5920, 20, 'Irmãos'),
(75698, 5921, 20, 'Sickle Cell'),
(75699, 5922, 20, 'Sig'),
(75700, 5923, 20, 'Sigmóide / Colonoscopia'),
(75701, 5927, 20, 'Assinatura'),
(75702, 5929, 20, 'Assinatura:'),
(75703, 5932, 20, 'Inchaço significativo:'),
(75704, 5937, 20, 'Desde'),
(75705, 5940, 20, 'Solteiro'),
(75706, 5946, 20, 'Problemas do seio'),
(75707, 5947, 20, 'Sinus Cirurgia'),
(75708, 5948, 20, 'SINUS ternura:'),
(75709, 5949, 20, 'Sinusite'),
(75710, 5956, 20, 'Tamanho'),
(75711, 5957, 20, 'Tamanho deve ser um número entre 1 e 999'),
(75712, 5958, 20, 'Tamanho / Lista'),
(75713, 5959, 20, 'Pele'),
(75714, 5960, 20, 'Câncer de Pele'),
(75715, 5961, 20, 'Doença de pele'),
(75716, 5962, 20, 'De pele Outros'),
(75717, 5967, 20, 'Os padrões de sono'),
(75718, 5968, 20, 'Os padrões de sono'),
(75719, 5969, 20, 'Sono'),
(75720, 5970, 20, 'Eslovaco'),
(75721, 5972, 20, 'Sm dívida w / o'),
(75722, 5973, 20, 'Smarty Cache foi limpo'),
(75723, 5978, 20, 'SMS Gateway'),
(75724, 5979, 20, 'SMS Gateway API chave'),
(75725, 5983, 20, 'Notificação de SMS'),
(75726, 5985, 20, 'Antes de enviar SMS'),
(75727, 5987, 20, 'Texto SMS, Usable Tag: *** NOME ***, *** Médico ***, *** DATA ***, *** STARTTIME ***, *** *** ENDTIME <br> ou seja, Dear *** NOME ***'),
(75728, 5988, 20, 'SMS / Email configurações de alerta'),
(75729, 6004, 20, 'Ronco'),
(75730, 6005, 20, 'Anamnese'),
(75731, 6006, 20, 'Dificuldades Social'),
(75732, 6009, 20, 'Histórico Social:'),
(75733, 6010, 20, 'Social Security Number'),
(75734, 6011, 20, 'solução'),
(75735, 6013, 20, 'Somatic Contexto'),
(75736, 6014, 20, 'Algumas autorizações não foram exibidos. Clique aqui para ver todos'),
(75737, 6015, 20, 'Alguns códigos não eram exibidas.'),
(75738, 6016, 20, 'Alguns encontros não foram exibidos. Clique aqui para ver todos.'),
(75739, 6018, 20, 'Algumas notas não eram exibidas.'),
(75740, 6020, 20, 'algumas palavras'),
(75741, 6026, 20, 'Sore Throat'),
(75742, 6029, 20, 'Ordenar por'),
(75743, 6032, 20, 'Ordenar por Comentários'),
(75744, 6034, 20, 'Classificar por data'),
(75745, 6035, 20, 'Classificar por data / hora'),
(75746, 6036, 20, 'Ordenar por evento'),
(75747, 6037, 20, 'Classificar por grupo'),
(75748, 6043, 20, 'Ordenar por Usuário'),
(75749, 6044, 20, 'Ordenar por vacinas'),
(75750, 6048, 20, 'Fonte'),
(75751, 6051, 20, 'Fonte está faltando para o código '),
(75752, 6057, 20, 'Fonte:'),
(75753, 6062, 20, 'Espanhol'),
(75754, 6069, 20, 'Especialista em nome e assinatura'),
(75755, 6071, 20, 'Especialidade'),
(75756, 6072, 20, 'Especialidade Systems'),
(75757, 6073, 20, 'Especialidade:'),
(75758, 6074, 20, 'Específicos'),
(75759, 6078, 20, 'Específica'),
(75760, 6092, 20, 'Ditado Speech'),
(75761, 6093, 20, 'Espermicidas'),
(75762, 6094, 20, 'Esplenectomia'),
(75763, 6095, 20, 'Cônjuge'),
(75764, 6097, 20, 'Escarro'),
(75765, 6098, 20, 'Escarro:'),
(75766, 6099, 20, 'SQ'),
(75767, 6102, 20, 'Plantel'),
(75768, 6103, 20, 'Squad Sócio'),
(75769, 6104, 20, 'Esquadrões'),
(75770, 6105, 20, 'SRH'),
(75771, 6106, 20, 'SRH - Planejamento Familiar'),
(75772, 6107, 20, 'SRH Non Planejamento Familiar'),
(75773, 6108, 20, 'SRH Referências'),
(75774, 6109, 20, 'SRH Ficha de Visita'),
(75775, 6111, 20, 'CPF'),
(75776, 6113, 20, 'CPF'),
(75777, 6114, 20, 'Estabilidade'),
(75778, 6116, 20, 'Normal'),
(75779, 6124, 20, 'Iniciar'),
(75780, 6125, 20, 'Start (aaaa-mm-dd): '),
(75781, 6128, 20, 'Data de Início'),
(75782, 6129, 20, 'Data de início na clínica'),
(75783, 6131, 20, 'Data de início:'),
(75784, 6132, 20, 'Data de início:'),
(75785, 6133, 20, 'Data de Início'),
(75786, 6134, 20, 'Data de início'),
(75787, 6135, 20, 'Estado'),
(75788, 6136, 20, 'Estado'),
(75789, 6141, 20, 'Lista Estado (escrever, adicionar opcional)'),
(75790, 6144, 20, 'Estado / Local'),
(75791, 6145, 20, 'Estado / Parish'),
(75792, 6151, 20, 'Estatísticas'),
(75793, 6152, 20, 'Stats'),
(75794, 6153, 20, 'Status'),
(75795, 6156, 20, 'Status quo'),
(75796, 6158, 20, 'DST / AIDS Couns'),
(75797, 6159, 20, 'Stength e Condicionamento'),
(75798, 6169, 20, 'Stiff Articulações'),
(75799, 6170, 20, 'Rigidez'),
(75800, 6172, 20, 'Dores de estômago'),
(75801, 6175, 20, 'Tensão do músculo'),
(75802, 6176, 20, 'Fluxo'),
(75803, 6177, 20, 'Rua'),
(75804, 6179, 20, 'Rua e número'),
(75805, 6180, 20, 'Força'),
(75806, 6182, 20, 'Strep Throat'),
(75807, 6183, 20, 'Fratura de estresse'),
(75808, 6184, 20, 'Teste de Stress'),
(75809, 6185, 20, 'Enfarte'),
(75810, 6189, 20, 'Sub-categoria'),
(75811, 6190, 20, 'Sub-Total'),
(75812, 6191, 20, 'Subcategoria'),
(75813, 6192, 20, 'subcategoria'),
(75814, 6193, 20, 'subcutânea'),
(75815, 6195, 20, 'QeD'),
(75816, 6196, 20, 'Sublingual'),
(75817, 6197, 20, 'sublingual'),
(75818, 6198, 20, 'Enviar'),
(75819, 6202, 20, 'Submeter evento'),
(75820, 6203, 20, 'enviar o formulário'),
(75821, 6206, 20, 'Enviado por'),
(75822, 6208, 20, 'Titular'),
(75823, 6209, 20, 'Endereço do Titular'),
(75824, 6213, 20, 'Empresa Titular'),
(75825, 6214, 20, 'Empresa Titular(SE)'),
(75826, 6215, 20, 'Endereço da Empresa Titular'),
(75827, 6216, 20, 'Cidade da Empresa Titular'),
(75828, 6217, 20, 'País da Empresa Titular'),
(75829, 6218, 20, 'Estado da Empresa Titular'),
(75830, 6221, 20, 'CEP da Empresa Titular'),
(75831, 6225, 20, 'Telefone Titular'),
(75832, 6226, 20, 'Titular Parentesco'),
(75833, 6227, 20, 'Titular Parentesco não é auto mas o nome é o mesmo! Is this OK?'),
(75834, 6228, 20, 'Titular Parentesco não é auto-SS, mas o número é o mesmo!'),
(75835, 6229, 20, 'Relação de Titular é auto mas o nome é diferente! Is this OK?'),
(75836, 6230, 20, 'Relação de Titular é auto, mas número de SS é diferente!'),
(75837, 6231, 20, 'Sexo do Titular'),
(75838, 6237, 20, 'Substituição'),
(75839, 6238, 20, 'substituição permitiu'),
(75840, 6241, 20, 'sucesso'),
(75841, 6247, 20, 'adicionado com êxito para a categoria,'),
(75842, 6256, 20, 'armazenados com êxito.'),
(75843, 6259, 20, 'com êxito.'),
(75844, 6260, 20, 'Suicídio'),
(75845, 6261, 20, 'Resumo'),
(75846, 6265, 20, 'Dom'),
(75847, 6267, 20, 'Domingo'),
(75848, 6268, 20, 'Superbill'),
(75849, 6269, 20, 'Superbill Códigos'),
(75850, 6270, 20, 'Superbill Códigos Administração'),
(75851, 6271, 20, 'Superbill Relatório'),
(75852, 6274, 20, 'Superbills, às vezes chamado de Encontro Forms ou deslizamentos de roteamento, são uma parte essencial da maioria das práticas médicas.'),
(75853, 6275, 20, 'Superusuário'),
(75854, 6276, 20, 'Supervisão'),
(75855, 6289, 20, 'Tipo de superfície'),
(75856, 6290, 20, 'Cirurgias'),
(75857, 6291, 20, 'Cirurgia'),
(75858, 6293, 20, 'Suspenso'),
(75859, 6294, 20, 'suspensão'),
(75860, 6295, 20, 'Data Svc'),
(75861, 6296, 20, 'Data Svc:'),
(75862, 6299, 20, 'Transpiração:'),
(75863, 6300, 20, 'Sueco'),
(75864, 6301, 20, 'Inchaço'),
(75865, 6302, 20, 'Inchaço Direito'),
(75866, 6303, 20, 'Articulações inchadas'),
(75867, 6304, 20, 'Linfonodos inchados'),
(75868, 6307, 20, 'Sintomas'),
(75869, 6313, 20, 'Síncope'),
(75870, 6317, 20, 'Sinovite, choque, bursite'),
(75871, 6318, 20, 'Sistema'),
(75872, 6322, 20, 'T'),
(75873, 6323, 20, 't.i.d.'),
(75874, 6324, 20, 'T.V.'),
(75875, 6327, 20, 'Criação da tabela falhou'),
(75876, 6328, 20, 'Tabela de atualização falhou'),
(75877, 6330, 20, 'comprimido'),
(75878, 6335, 20, 'Pegar'),
(75879, 6339, 20, 'Leva tempo'),
(75880, 6355, 20, 'Taxa de imposto'),
(75881, 6356, 20, 'Impostos'),
(75882, 6357, 20, 'Taxonomia'),
(75883, 6358, 20, 'Td'),
(75884, 6359, 20, 'Team Injury Visão'),
(75885, 6360, 20, 'Team Ordem de Serviço'),
(75886, 6361, 20, 'Team Ordem de Serviço Ver'),
(75887, 6363, 20, 'Tel'),
(75888, 6367, 20, 'Temp Localização'),
(75889, 6368, 20, 'Temp Método'),
(75890, 6369, 20, 'Temperatura'),
(75891, 6370, 20, 'Template'),
(75892, 6371, 20, 'Nome do Modelo'),
(75893, 6372, 20, 'Template nomes não podem começar com números.'),
(75894, 6373, 20, 'Modelo:'),
(75895, 6374, 20, 'Modelos'),
(75896, 6375, 20, 'Têmpora'),
(75897, 6376, 20, 'Lesão no tendão'),
(75898, 6377, 20, 'Tendinite / osis / bursite'),
(75899, 6379, 20, 'Terceiro'),
(75900, 6380, 20, 'Terceiro Convênio'),
(75901, 6381, 20, 'Dados do Terceiro Convênio'),
(75902, 6382, 20, 'Terceiro Convênio'),
(75903, 6383, 20, 'Programação de Teste'),
(75904, 6384, 20, 'Test System'),
(75905, 6393, 20, 'Text-data'),
(75906, 6394, 20, 'text-data'),
(75907, 6395, 20, 'Textarea'),
(75908, 6396, 20, 'textarea'),
(75909, 6397, 20, 'Textbox'),
(75910, 6398, 20, 'textbox'),
(75911, 6399, 20, 'Lista Textbox'),
(75912, 6400, 20, 'lista de texto'),
(75913, 6402, 20, 'Obrigado'),
(75914, 6408, 20, 'A alegação de arquivo: '),
(75915, 6416, 20, 'O formulário de destino foi fechado, não posso agir em sua seleção.'),
(75916, 6422, 20, 'O evento (s) foram aprovados.'),
(75917, 6423, 20, 'O evento (s) foram escondidos.'),
(75918, 6424, 20, 'Os dados exportados aparece na área de texto abaixo. Você pode copiar e colar as informações em um e-mail ou para qualquer outro destino desejado.'),
(75919, 6426, 20, 'Os dados exportados aparece na área de texto abaixo. Você pode copiar e colar as informações em um e-mail ou para qualquer outro destino desejado.'),
(75920, 6434, 20, 'O calendário de eventos a seguir foi adicionado:'),
(75921, 6435, 20, 'O calendário de eventos que se segue foi modifed:'),
(75922, 6441, 20, 'Os seguintes erros ocorreram'),
(75923, 6450, 20, 'A janela inicial é a página de pesquisa na factura. No topo você pode inserir um código (número do cheque, por exemplo), pagamento de data e quantidade de seleção. A razão para isto é não ter que inseri-las uma e outra vez de cada pedido. A quantidade que você inserir será reduzida para cada nota fiscal que é dado parte do pagamento, e esperamos que vai terminar em zero quando você está feito.'),
(75924, 6456, 20, 'O rótulo que aparece para o usuário sobre a forma'),
(75925, 6460, 20, 'A nova categoria será uma sub-categoria de '),
(75926, 6475, 20, 'As demais informações a seguir só se aplica se você está postando manualmente, ou se você está fazendo correções manuais.'),
(75927, 6477, 20, 'O documento solicitado não está presente no local previsto no sistema de arquivos ou não existem permissões suficientes para acessá-lo.'),
(75928, 6480, 20, 'As colunas de origem e data são copiados da primeira página, assim que normalmente você não vai precisar tocar essas. Você pode colocar um valor de pagamento na coluna Pay, um ajuste no montante de Ajuste de coluna, ou ambos. Você também pode clicar no ""W "" sobre o direito de computar automaticamente um valor de ajuste que escreve fora do restante da carga para esse item.'),
(75929, 6485, 20, 'O rótulo traduzido que irá aparecer no formulário em linguagem corrente'),
(75930, 6486, 20, 'O título traduzido que aparecerá na linguagem corrente'),
(75931, 6487, 20, 'A tradução da descrição em linguagem corrente'),
(75932, 6491, 20, 'O X12 arquivos, bem como os relatórios resultantes de saída HTML são arquivados na pasta ""era "" subdiretório do diretório principal LibreEHR instalação. Você vai querer referir-se a estes arquivos de vez em quando. O URL é'),
(75933, 6493, 20, 'Theme'),
(75934, 6495, 20, 'Injeções terapêuticas'),
(75935, 6496, 20, 'Há'),
(75936, 6498, 20, 'Há erros com a sua apresentação. Estes são descritos abaixo.'),
(75937, 6502, 20, 'Não existem argumentos Novos'),
(75938, 6505, 20, 'Houve um erro de envio de email para'),
(75939, 6510, 20, 'Não há entrada para o COA AR conta '),
(75940, 6511, 20, 'Não há entrada de dinheiro por conta COA '),
(75941, 6512, 20, 'Não há entrada do COA de balança de rendimentos '),
(75942, 6515, 20, 'Não há correspondência para id fatura'),
(75943, 6516, 20, 'Não há correspondência para fatura id = '),
(75944, 6517, 20, 'Não há entrada de peças para os serviços de identificação '),
(75945, 6520, 20, 'Houve um erro ao processar seu pedido.'),
(75946, 6523, 20, 'Engrossado Direita:'),
(75947, 6524, 20, 'Coxa'),
(75948, 6525, 20, 'Coxa + tendão'),
(75949, 6527, 20, 'Coisas que a administração pode ler e digitar, mas não modificar'),
(75950, 6528, 20, 'Coisas que a administração pode ler e modificar'),
(75951, 6531, 20, 'Coisas que os clínicos podem ler e entrar, mas não modificar'),
(75952, 6532, 20, 'Coisas que os clínicos podem ler e modificar'),
(75953, 6535, 20, 'Coisas que o escritório da frente pode ler e digitar, mas não modificar'),
(75954, 6536, 20, 'Coisas que o escritório da frente pode ler e modificar'),
(75955, 6539, 20, 'Coisas que os médicos podem ler e entrar, mas não modificar'),
(75956, 6540, 20, 'Coisas que os médicos podem ler e modificar'),
(75957, 6542, 20, 'Terceira'),
(75958, 6544, 20, 'Essa ação não pode ser desfeita.'),
(75959, 6545, 20, 'Essa ação não pode ser desfeita.'),
(75960, 6556, 20, 'Este tipo de código não aceita as relações.'),
(75961, 6561, 20, 'Este Encontro'),
(75962, 6566, 20, 'Este número da fatura foi alterado para '),
(75963, 6575, 20, 'Este módulo está em modo de teste. O banco de dados não serão alterados.'),
(75964, 6576, 20, 'Este módulo promove a entrada eficiente de dados EOB.'),
(75965, 6581, 20, 'Esta página irá incluir inline na página de login, de modo que não temos a relogin clique de cada vez.'),
(75966, 6582, 20, 'Este paciente não tem atividade.'),
(75967, 6583, 20, 'Este paciente ID já está em uso!'),
(75968, 6592, 20, 'Este usuário não é um membro de qualquer grupo'),
(75969, 6595, 20, 'Esta visita começa o uso de anticoncepcionais novo'),
(75970, 6606, 20, 'Isto irá criar um backup no formato tar e depois enviá-lo para seu navegador para que você possa salvá-lo'),
(75971, 6622, 20, 'A coluna torácica'),
(75972, 6625, 20, 'Garganta'),
(75973, 6626, 20, 'Cancro da garganta'),
(75974, 6627, 20, 'Cirurgia de Câncer de Garganta'),
(75975, 6628, 20, 'Trombose / Curso'),
(75976, 6629, 20, 'Qui'),
(75977, 6630, 20, 'Quinta'),
(75978, 6631, 20, 'Quinta-feira'),
(75979, 6632, 20, 'Tiróide normal'),
(75980, 6633, 20, 'Problemas do Tiróide'),
(75981, 6634, 20, 'TIA'),
(75982, 6638, 20, 'Horário'),
(75983, 6640, 20, 'Incremento de tempo para Add (minutos 1-60)'),
(75984, 6647, 20, 'Evento Temporário'),
(75985, 6648, 20, 'Matriz Times (N / A)'),
(75986, 6649, 20, 'Timestamp e Texto'),
(75987, 6650, 20, 'TIN'),
(75988, 6651, 20, 'Zumbido'),
(75989, 6652, 20, 'Queixa'),
(75990, 6653, 20, 'Título V'),
(75991, 6654, 20, 'TitleCols deve ser um número entre 1 e 999'),
(75992, 6655, 20, 'Queixas'),
(75993, 6656, 20, 'TMs / AEM / EE, ext nariz'),
(75994, 6657, 20, 'TMs'),
(75995, 6658, 20, 'Para'),
(75996, 6659, 20, 'TO'),
(75997, 6660, 20, 'para'),
(75998, 6664, 20, 'A área afetada'),
(75999, 6665, 20, 'a área afetada'),
(76000, 6667, 20, 'Para Ver Faturamento'),
(76001, 6668, 20, 'a categoria'),
(76002, 6669, 20, 'Ver a Clínica'),
(76003, 6670, 20, 'Para copay'),
(76004, 6672, 20, 'Para DED'),
(76005, 6673, 20, 'Para Dems'),
(76006, 6679, 20, 'Para Enctr'),
(76007, 6680, 20, 'Para filtrar por sexo'),
(76008, 6681, 20, 'Acrescentar/Consultar Histórico'),
(76009, 6682, 20, 'Para Questões'),
(76010, 6684, 20, 'Para vincular este encontro / consulta a um problema existente, clique na edição desejada acima para destacá-lo e, em seguida, clique em [Salvar]. Mantenha pressionada a tecla [Ctrl] para seleccionar várias questões.'),
(76011, 6685, 20, 'Para fazer o login novamente'),
(76012, 6689, 20, 'To Skin'),
(76013, 6690, 20, 'para a pele'),
(76014, 6691, 20, 'a esta visita?'),
(76015, 6693, 20, 'Para:'),
(76016, 6694, 20, 'Para: '),
(76017, 6695, 20, 'To_city'),
(76018, 6696, 20, 'TO_FAX'),
(76019, 6697, 20, 'TO_FNAME'),
(76020, 6698, 20, 'TO_LNAME'),
(76021, 6699, 20, 'TO_MNAME'),
(76022, 6700, 20, 'TO_ORGANIZATION'),
(76023, 6703, 20, 'TO_POSTAL'),
(76024, 6704, 20, 'TO_STATE'),
(76025, 6705, 20, 'TO_STREET'),
(76026, 6706, 20, 'TO_TITLE'),
(76027, 6707, 20, 'TO_VALEDICTORY'),
(76028, 6708, 20, 'Tabaco'),
(76029, 6712, 20, 'O uso do tabaco'),
(76030, 6715, 20, 'Hoje'),
(76031, 6720, 20, 'Data de Hoje'),
(76032, 6721, 20, 'Eventos de Hoje'),
(76033, 6726, 20, 'Amigdalectomia'),
(76034, 6728, 20, 'Sup.'),
(76035, 6730, 20, 'Tópico'),
(76036, 6731, 20, 'Consultas'),
(76037, 6732, 20, 'total'),
(76038, 6738, 20, 'Valor Total Pago'),
(76039, 6741, 20, 'Total de despesas'),
(76040, 6742, 20, 'Total de pacientes'),
(76041, 6748, 20, 'Total de'),
(76042, 6749, 20, 'Total de '),
(76043, 6750, 20, 'Total por categoria'),
(76044, 6758, 20, 'Número total de pacientes'),
(76045, 6765, 20, 'Total SRH & Planeamento Familiar'),
(76046, 6776, 20, 'Totais'),
(76047, 6777, 20, 'Total para'),
(76048, 6778, 20, 'Total para '),
(76049, 6785, 20, 'Tipo de Formação'),
(76050, 6786, 20, 'Transact'),
(76051, 6787, 20, 'Transação'),
(76052, 6788, 20, 'transação'),
(76053, 6791, 20, 'Tipo de Transação'),
(76054, 6793, 20, 'Transações'),
(76055, 6794, 20, 'Transações (escrever opcional)'),
(76056, 6795, 20, 'Transações / Registo'),
(76057, 6804, 20, 'Transferências'),
(76058, 6813, 20, 'traduzir este'),
(76059, 6814, 20, 'Tradução'),
(76060, 6815, 20, 'Traduções'),
(76061, 6819, 20, 'Trauma'),
(76062, 6820, 20, 'Tratamento'),
(76063, 6822, 20, 'Tratamento Gols'),
(76064, 6823, 20, 'Plano de Tratamento'),
(76065, 6826, 20, 'Tratamento:'),
(76066, 6827, 20, 'Tratamento: '),
(76067, 6829, 20, 'trftime ($ month_format, mktime (0, 0, 0, $ i, 1, 2000))); $ month_value'),
(76068, 6830, 20, 'Trigger Point / síndrome de compartimento / DOM / grampo'),
(76069, 6831, 20, 'Trimalleolar'),
(76070, 6832, 20, 'Tronco e abdome'),
(76071, 6837, 20, 'Colher(es) de chá'),
(76072, 6839, 20, 'TTS'),
(76073, 6840, 20, 'Tuberculose'),
(76074, 6841, 20, 'Ter'),
(76075, 6842, 20, 'Ter & Qui'),
(76076, 6843, 20, 'Terça-feira'),
(76077, 6844, 20, 'Tumor'),
(76078, 6848, 20, 'duas vezes por dia'),
(76079, 6850, 20, 'Via Auricular'),
(76080, 6851, 20, 'Tipo'),
(76081, 6857, 20, 'Tipo de digitalização ou o identificador do paciente aqui'),
(76082, 6864, 20, 'UCSMC códigos fornecidos pela Universidade de Calgary Centro de Medicina Esportiva'),
(76083, 6866, 20, 'Ulcerações'),
(76084, 6867, 20, 'Colite ulcerosa'),
(76085, 6868, 20, 'Úlceras:'),
(76086, 6876, 20, 'Não aplicado'),
(76087, 6877, 20, 'Selecione'),
(76088, 6880, 20, 'O acesso não autorizado.'),
(76089, 6884, 20, 'debaixo da língua'),
(76090, 6885, 20, 'Debaixo de'),
(76091, 6886, 20, 'Undiagnosed'),
(76092, 6888, 20, 'Não distribuído'),
(76093, 6890, 20, 'Undo Checkout'),
(76094, 6892, 20, 'Pacientes Únicos'),
(76095, 6894, 20, 'Pacientes Únicos Novos'),
(76096, 6896, 20, 'Única atividade Pacientes'),
(76097, 6897, 20, 'Única atividade pacientes relatam'),
(76098, 6898, 20, 'Unique SP'),
(76099, 6899, 20, 'Unidade'),
(76100, 6900, 20, 'Unidades'),
(76101, 6901, 20, 'unidades'),
(76102, 6904, 20, 'Unidades deve ser um número'),
(76103, 6907, 20, 'Desconhecido'),
(76104, 6910, 20, 'Não se sabe se fumou alguma vez'),
(76105, 6911, 20, 'Desconhecido ou N / A'),
(76106, 6914, 20, 'Companhia de seguros Unnamed'),
(76107, 6915, 20, 'Unregistered'),
(76108, 6918, 20, 'Desmarcar Todos'),
(76109, 6919, 20, 'Não Selecionado'),
(76110, 6920, 20, 'Não especificado'),
(76111, 6921, 20, 'Não estruturado'),
(76112, 6924, 20, 'até'),
(76113, 6925, 20, 'Prematura de arquivamento'),
(76114, 6926, 20, 'Não Usado'),
(76115, 6927, 20, 'UOR'),
(76116, 6928, 20, 'Até'),
(76117, 6929, 20, 'Próximos Eventos'),
(76118, 6930, 20, 'Próximos Eventos'),
(76119, 6931, 20, 'actualizar'),
(76120, 6932, 20, 'actualizar'),
(76121, 6934, 20, 'Os arquivos de atualização'),
(76122, 6935, 20, 'Update Info'),
(76123, 6942, 20, 'Atualizando a informações não está autorizada.'),
(76124, 6950, 20, 'CPF'),
(76125, 6951, 20, 'Upload'),
(76126, 6954, 20, 'Upload de dados de configuração'),
(76127, 6955, 20, 'Carregar Documento'),
(76128, 6956, 20, 'Upload falhou!'),
(76129, 6957, 20, 'Enviar imagem para'),
(76130, 6958, 20, 'Arquivo de importação de Upload:'),
(76131, 6961, 20, 'Upload Relatório'),
(76132, 6963, 20, 'Carregar arquivo isto:'),
(76133, 6964, 20, 'Ao clicar em um número da factura a ""janela de lançamento manual "" aparece. Aqui você pode mudar a data de vencimento e as notas para a factura, selecione o partido para o qual você está postando, e selecione os seguros para a qual todos os paymants esperados foram recebidos. Mais importante ainda, para cada código de faturamento para as quais foi cobrada uma quantia, você pode inserir informações de pagamento e de ajustamento.'),
(76134, 6965, 20, 'Após a pesquisa que você é apresentado com uma lista de faturas. Você pode clicar em um dos números de factura para abrir uma segunda janela, que é a página de entrada de dados para lançamento manual. Você também pode clicar no nome do paciente, se você deseja inserir uma nota que o pessoal do escritório da frente vai ver quando as verificações no paciente, e você pode selecionar as facturas para aparecer em declarações paciente e imprimir essas declarações.'),
(76135, 6966, 20, 'Braço'),
(76136, 6968, 20, 'Urgência'),
(76137, 6971, 20, 'Urina Dribbling'),
(76138, 6972, 20, 'Urina de Freqüência'),
(76139, 6973, 20, 'Urina Hesitação'),
(76140, 6975, 20, 'Urina Stream'),
(76141, 6976, 20, 'Urina Urgência'),
(76142, 6977, 20, 'URL'),
(76143, 6988, 20, 'Use 24 formato de hora a hora?'),
(76144, 7000, 20, 'Usar Padrões'),
(76145, 7002, 20, 'Use estilo de data internacional?'),
(76146, 7005, 20, 'Use este recurso apenas com sites recém-instalado, '),
(76147, 7006, 20, 'Use tópicos?'),
(76148, 7007, 20, 'Usuário'),
(76149, 7010, 20, 'Administração de Usuários'),
(76150, 7011, 20, 'Usuário de Clínica e Administração'),
(76151, 7012, 20, 'Usuário e Grupo de Administração'),
(76152, 7015, 20, 'Filiação'),
(76153, 7016, 20, 'Definido pelo usuário Área 11'),
(76154, 7017, 20, 'Definido pelo usuário Area 12'),
(76155, 7018, 20, 'Campo definido pelo usuário'),
(76156, 7019, 20, 'Manual de lista definida 1'),
(76157, 7020, 20, 'Manual de lista definida 2'),
(76158, 7021, 20, 'Manual de lista definida 3'),
(76159, 7022, 20, 'Manual de lista definida 4'),
(76160, 7023, 20, 'Manual de lista definida 5'),
(76161, 7024, 20, 'Manual de lista definida 6'),
(76162, 7025, 20, 'Manual de lista definida 7'),
(76163, 7026, 20, 'Texto Definido pelo Usuário 1'),
(76164, 7027, 20, 'Texto Definido pelo Usuário 2'),
(76165, 7028, 20, 'Texto Definido pelo Usuário 3'),
(76166, 7029, 20, 'Texto Definido pelo Usuário 4'),
(76167, 7030, 20, 'Texto Definido pelo Usuário 5'),
(76168, 7031, 20, 'Texto Definido pelo Usuário 6'),
(76169, 7032, 20, 'Texto Definido pelo Usuário 7'),
(76170, 7033, 20, 'Texto Definido pelo Usuário 8'),
(76171, 7039, 20, 'Manual do Usuário'),
(76172, 7040, 20, 'Associações de'),
(76173, 7041, 20, 'Nome do usuário'),
(76174, 7049, 20, 'Nome de Usuário'),
(76175, 7052, 20, 'Nome de usuário para o SMS Gateway'),
(76176, 7055, 20, 'Nome de usuário:'),
(76177, 7056, 20, 'Usuários'),
(76178, 7057, 20, 'Usuários / Grupos / Logs Administração'),
(76179, 7058, 20, 'usa <a php href=""http://php.net/strftime""> strftime </ a> formato'),
(76180, 7059, 20, 'UTIs'),
(76181, 7062, 20, 'FÉRIAS'),
(76182, 7063, 20, 'Férias'),
(76183, 7064, 20, 'Vacina'),
(76184, 7065, 20, 'Anel Vaginal'),
(76185, 7066, 20, 'Despedida'),
(76186, 7067, 20, 'Validar'),
(76187, 7068, 20, 'Valor'),
(76188, 7069, 20, 'Valor 1'),
(76189, 7070, 20, 'Valor 2'),
(76190, 7073, 20, 'Var1'),
(76191, 7074, 20, 'Var2'),
(76192, 7076, 20, 'Varicela 1'),
(76193, 7077, 20, 'Varicela 2'),
(76194, 7078, 20, 'Varizes'),
(76195, 7079, 20, 'Condição Vascular'),
(76196, 7080, 20, 'A lesão vascular'),
(76197, 7081, 20, 'Cirurgia Vascular'),
(76198, 7083, 20, 'Vendedor'),
(76199, 7084, 20, 'Versão'),
(76200, 7085, 20, 'Vertigo'),
(76201, 7087, 20, 'Veterans Administration Plan'),
(76202, 7090, 20, 'visualizar'),
(76203, 7091, 20, 'Visualizar'),
(76204, 7092, 20, 'Ver Alergias'),
(76205, 7097, 20, 'Ver Relatório detalhado do paciente'),
(76206, 7100, 20, 'Ver documento'),
(76207, 7101, 20, 'Exibir encontro'),
(76208, 7103, 20, 'Ver eventos em uma janela popup?'),
(76209, 7108, 20, 'Ver página 1'),
(76210, 7109, 20, 'Ver página 2'),
(76211, 7111, 20, 'Ver paciente'),
(76212, 7116, 20, 'Encontros Ver relacionados'),
(76213, 7121, 20, 'Ver/Editar Alergias'),
(76214, 7123, 20, 'Ver/Imprimir'),
(76215, 7124, 20, 'Ver:'),
(76216, 7125, 20, 'VISA'),
(76217, 7126, 20, 'VISA/MC/AMEX/Dis'),
(76218, 7127, 20, 'Danos Visceral / trauma / cirurgia'),
(76219, 7133, 20, 'Visite Categoria:'),
(76220, 7134, 20, 'Data da visita'),
(76221, 7137, 20, 'Visite Formulários'),
(76222, 7138, 20, 'Histórico de visitas'),
(76223, 7140, 20, 'Consultas'),
(76224, 7141, 20, 'Total De'),
(76225, 7142, 20, 'Sinais vitais'),
(76226, 7143, 20, 'Exame Físico Geral'),
(76227, 7144, 20, 'Exame Físico Geral (Metrico)'),
(76228, 7146, 20, 'Voz'),
(76229, 7149, 20, 'Vômitos'),
(76230, 7151, 20, 'W'),
(76231, 7152, 20, 'Circ'),
(76232, 7153, 20, 'Circunferência da cintura'),
(76233, 7154, 20, 'Esperando'),
(76234, 7155, 20, 'Walk-in'),
(76235, 7157, 20, 'Walt Pennington'),
(76236, 7162, 20, 'Quente'),
(76237, 7164, 20, 'AVISO'),
(76238, 7168, 20, 'Atenção: A visita foi já criado para este paciente hoje!'),
(76239, 7170, 20, 'Atenção: identificação do paciente não é único!'),
(76240, 7171, 20, 'AVISO: Isto irá substituir as informações de configuração com os dados do arquivo enviado!'),
(76241, 7173, 20, 'Alertas'),
(76242, 7176, 20, 'não foi encontrado'),
(76243, 7178, 20, 'vimos acima do seu paciente para avaliação e tratamento em nossa clínica psiquiátrica ambulatorial. Obrigado por esta referência.'),
(76244, 7179, 20, 'Fraqueza'),
(76245, 7181, 20, 'Busca Online'),
(76246, 7184, 20, 'Qua'),
(76247, 7185, 20, 'Quarta-feira'),
(76248, 7186, 20, 'Semana'),
(76249, 7187, 20, 'semana'),
(76250, 7188, 20, 'Ver semana'),
(76251, 7189, 20, 'Semana(s)'),
(76252, 7191, 20, 'semanas'),
(76253, 7192, 20, 'Semanas'),
(76254, 7193, 20, 'Peso'),
(76255, 7196, 20, 'Alteração de peso'),
(76256, 7197, 20, 'Perda de peso'),
(76257, 7198, 20, 'Perda de peso clínico'),
(76258, 7199, 20, 'Bem-vindo'),
(76259, 7202, 20, 'O que deve ser contado?'),
(76260, 7203, 20, 'Sibilos:'),
(76261, 7204, 20, 'Chiado'),
(76262, 7205, 20, 'Chiado:'),
(76263, 7208, 20, 'Onde pode relacionados digitalizados ou documentos em papel pode ser encontrado?'),
(76264, 7211, 20, 'Whiplash'),
(76265, 7212, 20, 'Branco'),
(76266, 7213, 20, 'Quem'),
(76267, 7214, 20, 'Quem respondeu?'),
(76268, 7215, 20, 'Viúvo'),
(76269, 7216, 20, 'Largura'),
(76270, 7217, 20, 'Largura em pixels do frame de navegação à esquerda.'),
(76271, 7221, 20, 'Com selecionado:'),
(76272, 7222, 20, 'com o nome antigo'),
(76273, 7224, 20, 'Com quem podemos deixar uma mensagem?'),
(76274, 7226, 20, 'em horas'),
(76275, 7227, 20, 'em horas:'),
(76276, 7228, 20, 'dentro de minutos'),
(76277, 7229, 20, 'em minutos:'),
(76278, 7232, 20, 'Sem atualização'),
(76279, 7233, 20, 'Testemunha'),
(76280, 7237, 20, 'Mulheres'),
(76281, 7238, 20, 'Mulheres Somente'),
(76282, 7240, 20, 'Trabalho'),
(76283, 7241, 20, 'NOTA DE TRABALHO'),
(76284, 7242, 20, 'Telefone Comercial'),
(76285, 7243, 20, 'Número de Telefone Comercial'),
(76286, 7244, 20, 'Trabalho relacionado?'),
(76287, 7245, 20, 'Trabalho/ Educação/ Lazer'),
(76288, 7246, 20, 'Nota de Trabalho/Escola'),
(76289, 7247, 20, 'dia útil'),
(76290, 7248, 20, 'Compensação do Trabalhador'),
(76291, 7249, 20, 'Compensação do Trabalhador (Plano de Saúde)'),
(76292, 7251, 20, 'Trabalhando... isso pode levar alguns minutos.'),
(76293, 7252, 20, 'Pior'),
(76294, 7258, 20, 'Você gostaria de deletar pagamentos?'),
(76295, 7259, 20, 'Você gostaria de modificar e Finalizar os Pagamentos?'),
(76296, 7260, 20, 'Você gostaria de modificar pagamentos?'),
(76297, 7261, 20, 'Você gostaria de postar e finalizar os pagamentos?'),
(76298, 7262, 20, 'Você gostaria de postar os pagamentos?'),
(76299, 7263, 20, 'Você gostaria de salvar?'),
(76300, 7264, 20, 'Punho'),
(76301, 7265, 20, 'Punho e mão'),
(76302, 7266, 20, 'Problemas no punho'),
(76303, 7267, 20, 'escrever'),
(76304, 7273, 20, 'x Cancelado'),
(76305, 7274, 20, 'x Cancelado'),
(76306, 7275, 20, 'Raio-X'),
(76307, 7276, 20, 'Interpretação do RAIO-X:'),
(76308, 7277, 20, 'Interpretação do Raio-X:'),
(76309, 7278, 20, 'X12 apenas: Reclamação Substituta '),
(76310, 7279, 20, 'X12 Parceiro'),
(76311, 7280, 20, 'X12 Parceiros'),
(76312, 7281, 20, 'x12 Texto'),
(76313, 7284, 20, 'Y'),
(76314, 7285, 20, 'Ano'),
(76315, 7286, 20, 'ano'),
(76316, 7287, 20, 'Ver Ano'),
(76317, 7288, 20, 'Ano(s)'),
(76318, 7289, 20, 'Anos'),
(76319, 7290, 20, 'Anos e meses'),
(76320, 7291, 20, 'Anos, meses e dias'),
(76321, 7292, 20, 'SIM'),
(76322, 7293, 20, 'Sim'),
(76323, 7294, 20, 'sim'),
(76324, 7295, 20, 'SIM!'),
(76325, 7296, 20, 'Sim, Excluir e Log'),
(76326, 7298, 20, 'Sim/Não'),
(76327, 7299, 20, 'Sim:'),
(76328, 7300, 20, 'Yiddish'),
(76329, 7303, 20, 'Você está prestes a substituir permanentemente o modelo existente. Tem certeza de que deseja continuar?'),
(76330, 7304, 20, 'Troque a senha antes de'),
(76331, 7305, 20, 'Você não tem permissão para excluir este evento'),
(76332, 7306, 20, 'Você não tem permissão para editar este evento'),
(76333, 7307, 20, 'Você não está autorizado para isso.'),
(76334, 7308, 20, 'Você não está autorizado a acessar este quadro.'),
(76335, 7309, 20, 'Você não está autorizado a adicionar/editar problemas'),
(76336, 7310, 20, 'Você não está autorizado a agendar compromissos.'),
(76337, 7311, 20, 'Você não está autorizado a ver essa consulta.'),
(76338, 7312, 20, 'Você está postando em uma consulta antiga?'),
(76339, 7313, 20, 'Você não pode acessar esta função diretamente.'),
(76340, 7314, 20, 'Você não pode acessar a página diretamente.'),
(76341, 7315, 20, 'Você não pode adicionar um valor em branco para uma categoria!'),
(76342, 7316, 20, 'Você não pode adicionar um valor em branco para uma subcategoria!'),
(76343, 7317, 20, 'Você não pode adicionar um valor em branco para um item!'),
(76344, 7318, 20, 'Você não pode escolher uma data future com todos os valores SIM.'),
(76345, 7319, 20, 'Você não escolheu nenhuma ação.'),
(76346, 7320, 20, 'Você não tem permissão para acessar/editar esta nota'),
(76347, 7321, 20, 'Você tentou alterar conteudos bloqueados. Para desbloquear, remova linha ''/*lock::*/'''),
(76348, 7322, 20, 'Você foi desconectado com sucesso.'),
(76349, 7323, 20, 'Você só pode carregar arquivos .txt'),
(76350, 7324, 20, 'Você pode, opcionalmente, carregar os resultados HL7 a partir de um arquivo'),
(76351, 7326, 20, 'Você deve informar uma frase secreta para encriptar o documento'),
(76352, 7327, 20, 'Você deve inserir sua senha para trocar a senhas dos demais usuários. Deixe em branco para não alterar a senha.'),
(76353, 7329, 20, 'Você deve primeiro selecionar ou adicionar um paciente.'),
(76354, 7330, 20, 'Você deve primeiro selecionar ou criar uma consulta.'),
(76355, 7331, 20, 'Você deve selecionar uma categoria de visita'),
(76356, 7332, 20, 'Você deve selecionar uma categoria de visita.'),
(76357, 7333, 20, 'Você deve selecionar alguns campos para continuar.'),
(76358, 7334, 20, 'Você deve estar executando esse teste, se essa reivindicação surgiu para gerar com êxito, mas o pedido real arquivo não contém quaisquer dados ou apenas uma parte inacabada da quantidade de dados que é suposto que contêm. É óbvio com reivindicações HCFA porque são legível, com X12 afirma que é um processo mais difícil de determinar se o pedido está devidamente completo.'),
(76359, 7335, 20, 'Você deve selecionar ao menos um contexto'),
(76360, 7336, 20, 'Você deve selecionar ao menos um Provedor'),
(76361, 7339, 20, 'Sua data final é inválida'),
(76362, 7340, 20, 'Seu evento foi eliminado.'),
(76363, 7341, 20, 'Seu evento foi modificado.'),
(76364, 7342, 20, 'Seu evento foi submetido.'),
(76365, 7343, 20, 'O arquivo é muito grande'),
(76366, 7345, 20, 'Seu nome na lista foi alterado para atender aos requisitos.'),
(76367, 7346, 20, 'Sua mensagem foi submatida à entrega para'),
(76368, 7347, 20, 'Nome para esta categoria, procedimento ou resultado'),
(76369, 7348, 20, 'Sua Senha'),
(76370, 7349, 20, 'Senha expirada. Por favor troque sua senha.'),
(76371, 7350, 20, 'Sua senha expira em'),
(76372, 7351, 20, 'Sua senha expira hoje, favor realizar a troca.'),
(76373, 7353, 20, 'Sua configuração de PostCalendar foi redefinida para o padrão.'),
(76374, 7354, 20, 'Sua configuração de PostCalendar foi atualizada.'),
(76375, 7355, 20, 'Sua frequência de repetição deve ser um número inteiro.'),
(76376, 7356, 20, 'Sua frequência de repetição deve ser pelo menos 1.'),
(76377, 7357, 20, 'Sua data de início é maior do que a data de término'),
(76378, 7358, 20, 'Sua data de início é inválida'),
(76379, 7359, 20, 'Sua submissão falhou.'),
(76380, 7360, 20, 'aaaa-mm-dd'),
(76381, 7361, 20, 'AAAA-MM-DD'),
(76382, 7362, 20, 'aaaa-mm-dd data associada a este documento'),
(76383, 7363, 20, 'aaaa-mm-dd data de destruição');
INSERT INTO `lang_definitions` VALUES
(76384, 7364, 20, 'aaaa-mm-dd data de nascimento'),
(76385, 7365, 20, 'aaaa-mm-dd Data de Nascimento'),
(76386, 7366, 20, 'aaaa-mm-dd data de expiração'),
(76387, 7367, 20, 'aaaa-mm-dd Data de início ou internação'),
(76388, 7368, 20, 'aaaa-mm-dd data de início, cirurgia ou início da medicação'),
(76389, 7369, 20, 'aaaa-mm-dd data de compra ou transferência'),
(76390, 7370, 20, 'aaaa-mm-dd data de recuperação ou fim de medicação'),
(76391, 7371, 20, 'aaaa-mm-dd Data para voltar a jogar'),
(76392, 7372, 20, 'aaaa-mm-dd Data de serviço'),
(76393, 7373, 20, 'aaaa-mm-dd data da presente carta'),
(76394, 7374, 20, 'aaaa-mm-dd data que voltou a jogar'),
(76395, 7375, 20, 'aaaa-mm-dd data do documento'),
(76396, 7376, 20, 'aaaa-mm-dd data do evento ou data de início'),
(76397, 7377, 20, 'aaaa-mm-dd data final'),
(76398, 7378, 20, 'aaaa-mm-dd data final'),
(76399, 7379, 20, 'aaaa-mm-dd data inicial'),
(76400, 7380, 20, 'aaaa-mm-dd data inicial'),
(76401, 7381, 20, 'aaaa-mm-dd hh:mm:ss'),
(76402, 7382, 20, 'aaaa-mm-dd Horas(24):minutos'),
(76403, 7383, 20, 'aaaa-mm-dd última data deste evento'),
(76404, 7386, 20, 'Modulo Zend'),
(76405, 7387, 20, 'Zero'),
(76406, 7389, 20, 'CEP'),
(76407, 7390, 20, 'CEP'),
(76408, 7391, 20, 'CEP/País:'),
(76409, 7392, 20, 'Zulu'),
(76410, 7393, 20, ' mas foi '),
(76411, 7394, 20, ' não pôde ser acessado.'),
(76412, 7395, 20, 'Você realmente deseja apagar'),
(76413, 7396, 20, 'Droga'),
(76414, 7397, 20, 'e-mails não enviados'),
(76415, 7398, 20, 'de'),
(76416, 7399, 20, 'foi criado. '),
(76417, 7400, 20, 'foi reaberto.'),
(76418, 7401, 20, 'Histórico'),
(76419, 7402, 20, 'não é um número'),
(76420, 7403, 20, 'está pronto para re-faturamento.'),
(76421, 7404, 20, 'LLL:'),
(76422, 7405, 20, 'Lote'),
(76423, 7406, 20, 'Medicaid Original Reference No. '),
(76424, 7407, 20, 'min'),
(76425, 7408, 20, 'não encontrado!'),
(76426, 7409, 20, 'Peculiaridades em vários navegadores pode significar que a saída abaixo entra em sua tela em empurrões súbita e que há longas pausas de vários segundos, onde parece que as coisas podem ter deixado de funcionar. Isso não é o caso, você acabará por ver a saída que sai de linha por linha. Pode haver números seqüenciais que aparecem abaixo, é para indicar que, mesmo que nada mais pode estar exibindo há uma atividade em curso. Estes números serão intercaladas com o conteúdo do faturamento e que é normal.'),
(76427, 7410, 20, 'receita atingiu seu limite de'),
(76428, 7411, 20, 'até'),
(76429, 7412, 20, 'Falha na atualização, não no banco de dados?'),
(76430, 7413, 20, 'foi marcado como faturado apenas.'),
(76431, 7414, 20, 'enfileirado com sucesso.'),
(76432, 7415, 20, '! Saiu, visita w/o'),
(76433, 7416, 20, '" para código'),
(76434, 7417, 20, '" está MARCADO em configurações de PostCalendar!'),
(76435, 7418, 20, '# Ins / questão fin'),
(76436, 7419, 20, 'Nº de comprimidos:'),
(76437, 7420, 20, '$'),
(76438, 7421, 20, '$ Codificação feita'),
(76439, 7422, 20, '$formato (aaaa-mm-dd): '),
(76440, 7423, 20, '%'),
(76441, 7424, 20, '% Cancelado < 24h'),
(76442, 7425, 20, '% Cancelado < 24h '),
(76443, 7426, 20, 'deve existir, mas não.'),
(76444, 7427, 20, '(% Corresponde a qualquer cadeia _ corresponde a qualquer caractere)'),
(76445, 7428, 20, '([ctrl] + clique para selecionar múltiplos recipientes)'),
(76446, 7429, 20, '(Voltar)'),
(76447, 7430, 20, '(Clique para editar)'),
(76448, 7431, 20, '( A entrega de E-mail é imediata, enquanto VOIP automatizado é enviado para o provedor de serviços para posterior processamento. )'),
(76449, 7432, 20, '(Mais)'),
(76450, 7433, 20, '(Paciente Novo)'),
(76451, 7434, 20, '(Notas e Autorizações)'),
(76452, 7435, 20, '(Notas do Paciente)'),
(76453, 7436, 20, '(Escolha um, ou escreve seu próprio título)'),
(76454, 7437, 20, '(Shift-)Clique ou arraste para alterar o valor'),
(76455, 7438, 20, '* Lembrete feito'),
(76456, 7439, 20, '** Por favor mover cirurgias para Problemas!'),
(76457, 7440, 20, '*Obrigatório'),
(76458, 7441, 20, '+ Chart pulled'),
(76459, 7442, 20, '- Nenhum'),
(76460, 7443, 20, '-- Todos --'),
(76461, 7444, 20, '--Selecione Perfil--'),
(76462, 7445, 20, '.'),
(76463, 7446, 20, '0'),
(76464, 7447, 20, '0-10'),
(76465, 7448, 20, '0-24'),
(76466, 7451, 20, '1'),
(76467, 7452, 20, '55 = Brasil. Acesse http://www.wtng.info/ para a lista completa de códigos dos países.'),
(76468, 7453, 20, '1 dia a contar de hoje'),
(76469, 7454, 20, '1 mês a contar de hoje'),
(76470, 7455, 20, '1 semana a contar de hoje'),
(76471, 7456, 20, '1 ano a contar de hoje'),
(76472, 7457, 20, '1.Descansar 2. Gelo durante dois dias 3. Compressão, deixar o curativo no local a menos que o pé se desenvolve dormência ou cor pálida 4. Elevar o pé e perna'),
(76473, 7458, 20, '11-14'),
(76474, 7459, 20, '12 hs'),
(76475, 7460, 20, '15-19'),
(76476, 7462, 20, '2'),
(76477, 7463, 20, '2 dias a contar de hoje'),
(76478, 7464, 20, '2 meses a contar de hoje'),
(76479, 7465, 20, '2 semanas a contar de hoje'),
(76480, 7466, 20, '2 anos a contar de hoje'),
(76481, 7467, 20, '2-20 anos'),
(76482, 7468, 20, '20-24'),
(76483, 7475, 20, '2014 Medida de qualidade clínica'),
(76484, 7476, 20, '2014 Medida de qualidade clínica (CQM) Grupo de Medidas'),
(76485, 7477, 20, '2111-13'),
(76486, 7478, 20, '24 hs'),
(76487, 7479, 20, '25+'),
(76488, 7480, 20, '25-29'),
(76489, 7481, 20, '2º'),
(76490, 7482, 20, '3 dias a contar de hoje'),
(76491, 7483, 20, '3 meses'),
(76492, 7484, 20, '3 meses a partir de agora'),
(76493, 7485, 20, '3 vezes ao dia'),
(76494, 7486, 20, '3 semanas a contar de hoje'),
(76495, 7487, 20, '30-34'),
(76496, 7488, 20, '35-39'),
(76497, 7489, 20, '3º'),
(76498, 7490, 20, '4 dias a contar de hoje'),
(76499, 7491, 20, '4 meses'),
(76500, 7492, 20, '4 meses a contar de hoje'),
(76501, 7493, 20, '4 vezes ao dia'),
(76502, 7494, 20, '4 semanas a contar de hoje'),
(76503, 7495, 20, '40-44'),
(76504, 7496, 20, '45+'),
(76505, 7497, 20, '465,9, URI'),
(76506, 7498, 20, '466,0, Bronquite aguda SOE'),
(76507, 7499, 20, '486,0, Pneumonia aguda'),
(76508, 7500, 20, '491,21, exacerbação de DPOC'),
(76509, 7501, 20, '491,8, Bronquite crônica'),
(76510, 7502, 20, '493,92, Asma Aguda EXAC.'),
(76511, 7503, 20, '496,0, a DPOC'),
(76512, 7504, 20, '4º'),
(76513, 7505, 20, '5 dias a contar de hoje'),
(76514, 7506, 20, '5 meses a partir de agora'),
(76515, 7507, 20, '5 semanas a contar de hoje'),
(76516, 7508, 20, '519,7, broncoespasmo'),
(76517, 7509, 20, '5º'),
(76518, 7510, 20, '6 dias a contar de hoje'),
(76519, 7511, 20, '6 meses'),
(76520, 7512, 20, '6 meses a partir de agora'),
(76521, 7513, 20, '6 semanas a partir de agora'),
(76522, 7514, 20, '6º'),
(76523, 7515, 20, '7 meses a partir de agora'),
(76524, 7516, 20, '8 meses a partir de agora'),
(76525, 7517, 20, '824,0 Fratura do maléolo medial, fechado'),
(76526, 7518, 20, '824,2 Fracture, maléolo lateral, fechado'),
(76527, 7519, 20, '824,6 Fracture, Trimalleolar, fechado'),
(76528, 7520, 20, '825,32 Fracture, do navicular (tornozelo)'),
(76529, 7521, 20, '825,35 Fracture, Base de quinta (5) Metatarsal'),
(76530, 7522, 20, '845,00 NOS entorse de tornozelo'),
(76531, 7523, 20, '845,01 Entorse medial (deltóide) Lig.'),
(76532, 7524, 20, '845,02 entorse, calcâneo fibular'),
(76533, 7525, 20, '9 meses a partir de agora'),
(76534, 7526, 20, '99212 Estabelecido - Descomplicado'),
(76535, 7527, 20, '99213 Estabelecido - Baixa Complexidade'),
(76536, 7528, 20, '< Na sala de exame'),
(76537, 7529, 20, '> Check out'),
(76538, 7530, 20, '?'),
(76539, 7531, 20, '? Não Compareceu'),
(76540, 7532, 20, '@ Chegou'),
(76541, 7533, 20, '[Alterar Visualização]'),
(76542, 7534, 20, '[Data da Última Consulta]'),
(76543, 7535, 20, '[Dias Desde a Última Consulta]'),
(76544, 7536, 20, '[EOBs]'),
(76545, 7537, 20, '[Exportar OFX]'),
(76546, 7538, 20, '[não recomendado]'),
(76547, 7539, 20, '[Número de encontros]'),
(76548, 7540, 20, '[Relatórios]'),
(76549, 7541, 20, '[Selecionar Todos]'),
(76550, 7542, 20, '[SQL-Ledger]'),
(76551, 7543, 20, '[Iniciar Processamento Batch]'),
(76552, 7544, 20, '[Ver log]'),
(76553, 7545, 20, '[Ver Relatório para Impressão]'),
(76554, 7546, 20, '_PC_DUR_HOURS'),
(76555, 7547, 20, '_PC_DUR_MINUTES'),
(76556, 7548, 20, '_PC_LOCALE'),
(76557, 7549, 20, '~ Chegou atrasado'),
(76558, 1, 21, 'ا'),
(76559, 2, 21, 'رقم الإيصال أو المطالبة للتعريف بالدفع'),
(76560, 3, 21, 'شهادة عميل للمستخدم المشرف'),
(76561, 4, 21, 'تم إرفاق وثيقة طبية'),
(76562, 5, 21, 'تم إرفاق وثيقة طبية.'),
(76563, 7, 21, 'مطلوب موزع'),
(76564, 8, 21, 'ينبغي اضافة استمارة الزيارة لهذه الزيارة'),
(76565, 9, 21, 'رقم الشحنة مطلوب'),
(76566, 10, 21, 'رقم الشحنة مطلوب'),
(76567, 11, 21, 'حرف صغير من الأبجدية الانجليزية'),
(76568, 12, 21, 'رقم'),
(76569, 14, 21, 'هوية التعريف لهذا المريض موجودة مسبقاً'),
(76570, 15, 21, 'اسم هذا المريض موجود مسبقاً'),
(76571, 16, 21, 'رقم الضمان الاجتماعي لهذا المريض موجود مسبقاً'),
(76572, 18, 21, 'يعرض الرقم الموجب عدة مواعيد سابقة على أداة في شاشة ملخص المريض.'),
(76573, 19, 21, 'يمكن تحديد مصدر الإحالة عن كل زيارة'),
(76574, 20, 21, 'يطلب الرمز IPPF  ذو الصلة'),
(76575, 21, 21, 'حرف خاص'),
(76576, 22, 21, 'قيمة لامثيل لها للتعريف بهذا الحقل ,غير مرئية للمستخدم'),
(76577, 23, 21, 'الزيارة مفتوحه لهذا المريض اليوم. اضغط إلغاء لفتحها أو موافق لإنشاء زيارة جديدة'),
(76578, 24, 21, 'قبل الطعام'),
(76579, 25, 21, 'بعد الطعام'),
(76580, 26, 21, 'الرجفان الأذيني يمين المستوى'),
(76581, 27, 21, 'اب'),
(76582, 28, 21, 'اختصارات'),
(76583, 29, 21, 'خراج'),
(76584, 30, 21, 'بطني'),
(76585, 31, 21, 'قادر على حمل الوزن أربع خطوات'),
(76586, 32, 21, 'غير طبيعي'),
(76587, 33, 21, 'إشعار ميديكير المتقدم 1'),
(76588, 34, 21, 'غير عادي'),
(76589, 35, 21, 'فحص دم غير عادي'),
(76590, 36, 21, 'نمو شعر غير عادي'),
(76591, 37, 21, 'تصوير ثدي غير عادي'),
(76592, 39, 21, 'اجهاض'),
(76593, 40, 21, 'قضايا الإجهاض'),
(76594, 41, 21, 'طريقة الإجهاض'),
(76595, 42, 21, 'الفئات المتعلقة بالإجهاض'),
(76596, 43, 21, 'اجهاضات'),
(76597, 44, 21, 'عن المفكرة'),
(76598, 46, 21, 'غياب التشخيص'),
(76599, 47, 21, 'قبول المهمة'),
(76600, 48, 21, 'قبول الدفع ل'),
(76601, 49, 21, 'قبول الدفع ل'),
(76602, 50, 21, 'قبول المهمة'),
(76603, 51, 21, 'تحكم  بالوصول'),
(76604, 52, 21, 'ادارة قائمة التحكم بالوصول'),
(76605, 53, 21, 'تاريخ الوصول'),
(76606, 54, 21, ' الوصول غير مسموح'),
(76607, 55, 21, 'الوصول غير مرخص به'),
(76608, 56, 21, 'الوصول إلى بوابة مريضكم'),
(76609, 57, 21, 'حادث'),
(76610, 59, 21, 'اسم الحساب'),
(76611, 62, 21, 'المحاسبة'),
(76612, 64, 21, 'آلام'),
(76613, 65, 21, 'إشعار بإلاستلام  (ISA14)'),
(76614, 66, 21, 'الاشعارات والترخيص والتصديق'),
(76615, 67, 21, 'قائمة التحكم بالوصول'),
(76616, 68, 21, 'ادارة قائمة التحكم بالوصول'),
(76617, 69, 21, 'المستخدم ليس له صلاحية في ادارة قائمة التحكم بالوصول'),
(76618, 70, 21, 'تم تحديث ادارة قائمة التحكم بالوصول'),
(76619, 71, 21, 'حب الشباب'),
(76620, 72, 21, 'الحدث'),
(76621, 73, 21, 'تاريخ الحدوث'),
(76622, 74, 21, 'الحدث'),
(76623, 75, 21, 'الاحداث'),
(76624, 77, 21, 'تفعيل تقارير  CCR / CCD'),
(76625, 78, 21, 'تنبيه نشط'),
(76626, 79, 21, 'تنبيه فعال'),
(76627, 80, 21, 'قواعد التنبيه الفعال'),
(76628, 81, 21, 'تنبيهات/تذكيرات فعالة'),
(76629, 82, 21, 'الموعد الفعال'),
(76630, 84, 21, 'القوائم الفعالة'),
(76631, 85, 21, 'المريض الفعال'),
(76632, 86, 21, 'خطط فعالة'),
(76633, 87, 21, 'فعالية'),
(76634, 88, 21, 'النوع الفعال'),
(76635, 90, 21, 'تسمم حاد/إنسحاب'),
(76636, 91, 21, 'عارض حاد لمرض مزمن'),
(76637, 92, 21, 'حاد أو مزمن'),
(76638, 93, 21, 'إضافة'),
(76639, 94, 21, 'إضافة'),
(76640, 95, 21, 'أضف'),
(76641, 96, 21, 'إضافة شركة'),
(76642, 98, 21, 'إضافة صيدلية'),
(76643, 100, 21, 'إضافة حدث ل'),
(76644, 101, 21, 'إضافة كملاحظة جديدة'),
(76645, 102, 21, 'إضافة جديد'),
(76646, 104, 21, 'أضف أزرار'),
(76647, 105, 21, 'إضافة ازار للحروف والرموز الخاصة يتم عرضها أعلى محرر النصوص ويتم ادراجها ضمن النص عند الضغط عليها'),
(76648, 106, 21, 'إضافة فئة'),
(76649, 107, 21, 'إضافة ثابت'),
(76650, 108, 21, 'اضافة حالة'),
(76651, 109, 21, 'إضافة تحمل'),
(76652, 110, 21, 'أضف حالة'),
(76653, 111, 21, 'إضافة زر مخصص'),
(76654, 112, 21, 'أضف تشخيص'),
(76655, 113, 21, 'إضافة دواء'),
(76656, 114, 21, 'إضافة موعد'),
(76657, 115, 21, 'إضافة زيارة / ملاحظات'),
(76658, 116, 21, 'إضافة مرفق'),
(76659, 117, 21, 'إضافة حقل'),
(76660, 118, 21, 'إضافة  الأسطر التالية إلى تكوين ملف اباتشي'),
(76661, 119, 21, 'إضافة مجموعة'),
(76662, 120, 21, 'إضافة  رمز التصنيفات الإحصائية الدولية للأمراض'),
(76663, 121, 21, 'إضافة لقاح'),
(76664, 122, 21, 'الإضافة غير مسموحة'),
(76665, 123, 21, 'إضافة مسألة'),
(76666, 124, 21, 'إضافة بند للمتابعة'),
(76667, 125, 21, 'إضافة لغة'),
(76668, 126, 21, 'إضافة عنصر جديد'),
(76669, 127, 21, 'إضافة عنصر جديد'),
(76670, 128, 21, 'إضافة فئة جديدة '),
(76671, 129, 21, 'إضافة شهادات جديدة لتكوين ملف اباتشي'),
(76672, 130, 21, 'إضافة مكوّن جديد'),
(76673, 131, 21, 'إضافة مكوّنات جديدة'),
(76674, 132, 21, 'إضافة مجموعة جديدة'),
(76675, 133, 21, 'إضافة مشكلة جديدة'),
(76676, 134, 21, 'إضافة شحنة و معاملة جديدة'),
(76677, 135, 21, 'إضافة ملاحظة جديدة'),
(76678, 136, 21, 'إضافة ملاحظة جديدة'),
(76679, 137, 21, 'إضافة شريك جديد'),
(76680, 138, 21, 'إضافة مريض جديد'),
(76681, 140, 21, 'إضافة ملاحظة'),
(76682, 141, 21, 'إضافة سجل مريض'),
(76683, 142, 21, 'إضافة وصفة'),
(76684, 143, 21, 'إضافة إجراء'),
(76685, 144, 21, 'إضافة رقم المزود'),
(76686, 145, 21, 'إضافة إعادة التأهيل'),
(76687, 146, 21, 'أضف امر'),
(76688, 147, 21, 'إضافة الى'),
(76689, 148, 21, 'إضافة الى قائمة الأدوية'),
(76690, 149, 21, 'إضافة المستوى الأعلى'),
(76691, 150, 21, 'إضافة تحويل'),
(76692, 151, 21, 'إضافة مستخدم'),
(76693, 152, 21, 'إضافة مستخدم الى مجموعة'),
(76694, 153, 21, 'أضف/عدل الوصفات الطبية الالكترونية اي آر اكس'),
(76695, 154, 21, 'إضافة / أو تعديل اجراء للمريض'),
(76696, 155, 21, 'مضاف'),
(76697, 156, 21, 'إضافة معلومات ديموغرافية غير مسموح'),
(76698, 157, 21, 'لقد فشلت إضافه بند للمتابعة'),
(76699, 158, 21, 'متلازمة أديسون'),
(76700, 159, 21, 'متلازمة أديسون'),
(76701, 160, 21, 'سمات اضافية'),
(76702, 161, 21, 'تشخيص اضافي'),
(76703, 162, 21, 'تاريخ مرضي اضافي'),
(76704, 163, 21, 'ملاحظات في التاريخ المرضي اضافية'),
(76705, 164, 21, 'معلومات اضافية'),
(76706, 165, 21, 'تحاليل مخبرية اضافية'),
(76707, 166, 21, 'ملاحظات اضافية'),
(76708, 167, 21, 'توصيات او ملاحظات اضافية للنتيجة'),
(76709, 168, 21, 'ملاحظات اضافية'),
(76710, 169, 21, 'ملاحظات اضافية '),
(76711, 170, 21, 'ملاحظات شعاعية اضافية'),
(76712, 171, 21, 'إضافيا, يمكن استيراد طرد Snomed للولايات المتحدة بعد الطراز العالمي منها'),
(76713, 172, 21, 'إضافة محددة'),
(76714, 173, 21, 'دفتر العناوين'),
(76715, 174, 21, 'دفتر العناوين'),
(76716, 175, 21, 'العنوان'),
(76717, 178, 21, 'دفتر العناوين'),
(76718, 179, 21, 'مدخلات دفتر العناوين الخاصة بالشركة التي تقوم بهذه اﻹجراءات'),
(76719, 180, 21, 'ادخال دفتر العناوين للموزع'),
(76720, 181, 21, 'ادخال دفتر العناوين للبائع'),
(76721, 182, 21, 'أنواع دفتر العناوين'),
(76722, 183, 21, 'ملصق العنوان'),
(76723, 187, 21, 'العنوان 1'),
(76724, 188, 21, 'العنوان 2'),
(76725, 189, 21, 'مخاطب'),
(76726, 190, 21, 'تعديل'),
(76727, 191, 21, 'مقدار التعديل'),
(76728, 192, 21, 'عدّل'),
(76729, 193, 21, 'تعديل'),
(76730, 194, 21, 'كمية التعديل'),
(76731, 195, 21, 'أسباب التعديل'),
(76732, 196, 21, 'القيمة المعدلة للرمز '),
(76733, 197, 21, 'تعديلات'),
(76734, 198, 21, 'تعديلات المدير'),
(76735, 199, 21, 'المدير'),
(76736, 200, 21, 'العنوان الإلكتروني للمدير'),
(76737, 201, 21, 'ادير/ قدم من'),
(76738, 202, 21, 'ادار/قدم'),
(76739, 203, 21, 'ادارة عن طريق'),
(76740, 204, 21, 'تاريخ مُدار'),
(76741, 205, 21, 'موقع مُدار'),
(76742, 206, 21, 'الإدارة'),
(76743, 207, 21, 'موقع الإدارة'),
(76744, 208, 21, 'المدراء'),
(76745, 209, 21, 'المدراء لهم كافة الصلاحيات'),
(76746, 210, 21, 'تاريخ الدخول'),
(76747, 212, 21, 'فحص الوزن والمتابعة للبالغين'),
(76748, 213, 21, 'فحص الوزن والمتابعة للبالغين (CQM)'),
(76749, 214, 21, 'التوجيه مقدما'),
(76750, 215, 21, 'توجيهات متقدمة'),
(76751, 216, 21, 'توجيهات تحذيرية متقدمة'),
(76752, 218, 21, 'متقدم'),
(76753, 219, 21, 'نصيحة'),
(76754, 220, 21, 'بعيد'),
(76755, 221, 21, 'يؤثر طبيعياً'),
(76756, 222, 21, 'جنوب افريقي أبيض'),
(76757, 223, 21, 'مكالمة بعد ساعات'),
(76758, 224, 21, 'بعد التحول من آلية كلمة السر القديمة , يجب تعيين علامة سالبة بحيث تكون المصاقة ممكنة من خلال طريقة جديدة'),
(76759, 225, 21, 'بعد القيام باﻹعدادات اعلاه، قم باستصدار شهادة إدراة النظام الزبون الى المتصفح ومن ثم قم بإعادة تشغيل خادم الويب (أباتشي)(كلمة سر فارغة)'),
(76760, 226, 21, 'بعد حفظ الملف بصيغة بدف اضغط مشاهدة السجل للتأكد من عدم وجود أخطاء'),
(76761, 227, 21, 'بعد حفظ الملف نصي بدف اضغط مشاهدة السجل للتأكد من عدم وجود أخطاء'),
(76762, 228, 21, 'بعد حفظ تعديلك اضغط مشاهدة السجل للتأكد من عدم وجود أخطاء'),
(76763, 230, 21, 'بعد ادخال المعلومات بشكل صحيح اضغط زر الحفظ'),
(76764, 232, 21, 'التخطيط للرعاية اللاحقة'),
(76765, 233, 21, 'مرة اخرى'),
(76766, 234, 21, 'العمر'),
(76767, 235, 21, 'العمر ب'),
(76768, 236, 21, 'الفئة العمرية'),
(76769, 237, 21, 'بيانات العمر خارج المجال'),
(76770, 238, 21, 'نمط عرض العمر'),
(76771, 239, 21, 'نمط ادخال العمر ل (العمر من ) غير صحيح'),
(76772, 240, 21, 'نمط ادخال العمر ل (العمر الى) غير صحيح'),
(76773, 241, 21, 'العمر من'),
(76774, 242, 21, 'العمر بالسنوات للتغير في صيغة العرض'),
(76775, 243, 21, 'اكبر عمر'),
(76776, 244, 21, 'اصغر عمر'),
(76777, 245, 21, 'مدى العمر'),
(76778, 247, 21, 'أعمدة العمر'),
(76779, 248, 21, 'لغه ساحل العاج و غانا'),
(76780, 249, 21, 'ألباني'),
(76781, 250, 21, 'الكحول'),
(76782, 251, 21, 'استهلاك الكحول'),
(76783, 252, 21, 'إستعمال الكحول'),
(76784, 253, 21, 'عدد التحذير'),
(76785, 255, 21, 'تحذيرات'),
(76786, 258, 21, 'الألوشية'),
(76787, 259, 21, 'الكل'),
(76788, 260, 21, 'الكل'),
(76789, 261, 21, 'الكل(نموذج أ)'),
(76790, 262, 21, 'الكل (نموذج ب)'),
(76791, 263, 21, 'الكل (متراكم)'),
(76792, 265, 21, 'كل الحسابات اتوماتيكية (AMC)'),
(76793, 266, 21, 'كل الفئات'),
(76794, 267, 21, 'كل مقاييس النوعية الاكلينيكيه (CQM)'),
(76795, 268, 21, 'كل الرموز'),
(76796, 269, 21, 'كل الأيام'),
(76797, 270, 21, 'كل أحداث اليوم'),
(76798, 271, 21, 'كل الحقول الديموغرافية التي لها فحص للبحث والتكرار'),
(76799, 272, 21, 'كل الهيئات'),
(76800, 273, 21, 'كل اﻹصابات/المشاكل/القضايا'),
(76801, 274, 21, 'كل اللغات المسموحة'),
(76802, 276, 21, 'كل أو جزء من الإسم الأول'),
(76803, 277, 21, 'كل أو جزء من الإسم الأخير'),
(76804, 278, 21, 'كل أو جزء من المنظومة'),
(76805, 279, 21, 'كل المرضي'),
(76806, 280, 21, 'كل المنتجات'),
(76807, 281, 21, 'كل المزودين'),
(76808, 282, 21, 'الكل تمت مراجعته وسلبي'),
(76809, 283, 21, 'كافة المواضيع'),
(76810, 284, 21, 'كافة المستخدمين'),
(76811, 285, 21, 'تحسسي'),
(76812, 286, 21, 'المحسسات'),
(76813, 287, 21, 'المحسسات:'),
(76814, 288, 21, 'الحساسية'),
(76815, 289, 21, 'تم إستيراد سجلات الحساسية بنجاح'),
(76816, 290, 21, 'قائمة مشاكل الحساسية'),
(76817, 291, 21, 'ارتكاس حساسية'),
(76818, 294, 21, 'تخصيص'),
(76819, 295, 21, 'اسمح'),
(76820, 296, 21, 'جعل كل اللغات المثبتة متاحة عند الدخول إلى النظام'),
(76821, 297, 21, 'إسمح بإضافة مطالبات محتوية على تشخيصات ولكن لا تحتوي على إجراءات أو اسعار. معظم المستوصفات والعيادات لا تفضل هذا.'),
(76822, 298, 21, 'السماح بلغة التصحيح'),
(76823, 299, 21, 'السماح بالبريد الإلكتروني'),
(76824, 300, 21, 'السماح برسائل البريد الإلكتروني'),
(76825, 301, 21, 'السماح بالبريد الإلكتروني ؟'),
(76826, 302, 21, 'السماح بمطالبات المراجعة'),
(76827, 303, 21, 'السماح بتبادل المعلومات الصحية'),
(76828, 304, 21, 'السماح بمشاركة معلومات التحصينات'),
(76829, 305, 21, 'السماح باستخدام سجل التحصينات'),
(76830, 306, 21, 'السماح برسالة بريدية'),
(76831, 308, 21, 'السماح بالبوابة اﻹلكترونية للمرضى'),
(76832, 309, 21, 'السماح برسالة نصية'),
(76833, 310, 21, 'السماح برسالة نصية ؟'),
(76834, 311, 21, 'السماح بالأحداث المدخلة لتصبح فعالة بسرعة؟'),
(76835, 312, 21, 'السماح بالرسائل الهاتفية'),
(76836, 313, 21, 'السماح للمستخدمين بنشر الأحداث العامة'),
(76837, 314, 21, 'السماح للمستخدمين بنشر المواعيد الشخصية'),
(76838, 315, 21, 'السماح بالرسائل الصوتية'),
(76839, 316, 21, 'مسموح'),
(76840, 317, 21, 'اللغات المسموح بها'),
(76841, 318, 21, 'مسموح (c)'),
(76842, 319, 21, 'السماح بالتوقيع الرقمي علي كل الزيارة'),
(76843, 320, 21, 'السماح بالتوقيع الرقمي كل علي حدة'),
(76844, 321, 21, 'السماح للبريد'),
(76845, 322, 21, 'السماح للرسائل الصوتية'),
(76846, 323, 21, 'موجود'),
(76847, 324, 21, 'متواجد حالياً'),
(76848, 325, 21, 'مستخدم حالياً ,الرجاء اختيار تعريف آخر'),
(76849, 326, 21, 'مستخدم حالياً,الرجاء اختيار تعريف آخر'),
(76850, 327, 21, 'عنوان بديل'),
(76851, 328, 21, 'تبدل'),
(76852, 329, 21, 'بشكل بديل, يمكنك استخدام صفحة البحث لتحميل الملف التحويلات المالية الإلكترونية الذي كنت قد تم الحصول عليها من دافع أو تبادل المعلومات الخاصة بك. يمكنك القيام بذلك عن طريق النقر على زر تصفح واختيار ملف للتحميل ، ثم انقر فوق بحث لأداء وتحميل وعرض الفواتير المناظرة. في هذه الحالة المعلمات الأخرى المذكورة أعلاه لا تنطبق وسيتم تجاهلها. تحميل يحفظ الملف لكنها لا عملية محتوياته ، والتي تتم بصورة منفصلة على النحو المبين أدناه.'),
(76853, 330, 21, 'صباحاً'),
(76854, 331, 21, 'البرنامج الصباحي'),
(76855, 332, 21, 'حسابات القياس اﻵلي'),
(76856, 333, 21, 'متابعة حسابات القياس اﻵلي'),
(76857, 338, 21, 'تغيير ملاحظة موجودة'),
(76858, 339, 21, 'طلب تعديل أو إضافة'),
(76859, 340, 21, 'حالة التعديل أو الإضافة'),
(76860, 341, 21, 'تعديلات أو إضافات'),
(76861, 342, 21, 'تعديلات أو إضافات ل'),
(76862, 343, 21, 'هندي أمريكي'),
(76863, 344, 21, 'هندي أمريكي أو من اﻷسكا'),
(76864, 345, 21, 'بطاقة اميريكان اكسبرس'),
(76865, 346, 21, 'اللغة الأمهرية'),
(76866, 347, 21, 'كمية'),
(76867, 348, 21, 'الكمية المُدخلة'),
(76868, 349, 21, 'تكاليف الكمية'),
(76869, 350, 21, 'كمية التوازن الماضي'),
(76870, 351, 21, 'مقدار هذه الزيارة'),
(76871, 352, 21, 'المقدار المدفوع'),
(76872, 353, 21, 'الكمية'),
(76873, 354, 21, 'قيمة الفاتورة'),
(76874, 355, 21, 'تاريخ نهاية بعد تاريخ البداية مطلوب للأحداث المتكررة'),
(76875, 357, 21, 'LibreEHR حدث خطأ أثناء إلقاء دليل الويب شجرة ل'),
(76876, 358, 21, 'phpGACL حدث خطأ أثناء إلقاء دليل الويب شجرة ل'),
(76877, 359, 21, 'SQL-Ledger حدث خطأ أثناء إلقاء دليل الويب شجرة ل'),
(76878, 360, 21, 'القضية غير مكتملة تم إنشاؤها وربطها. شخص ما يجب حاجة لاستكماله في وقت لاحق'),
(76879, 362, 21, 'حدث خطأ غير متوقع'),
(76880, 363, 21, 'حرف'),
(76881, 365, 21, 'و'),
(76882, 366, 21, 'و'),
(76883, 367, 21, 'و'),
(76884, 368, 21, 'و '),
(76885, 369, 21, 'وجميع معلومات المرؤسين؟ سيتم تسجيل هذه العملية في النظام'),
(76886, 370, 21, 'و المُعدل'),
(76887, 371, 21, 'و تمت معالجته'),
(76888, 372, 21, 'اعادة تشغيل سيرفر الـ‘أباتشي‘'),
(76889, 373, 21, 'و السبب هو'),
(76890, 374, 21, 'فقر الدم'),
(76891, 375, 21, 'الكاحل'),
(76892, 376, 21, 'الكاحل + العقب'),
(76893, 377, 21, 'نموذج تقييم الكاحل'),
(76894, 378, 21, 'مشاكل الكاحل'),
(76895, 379, 21, 'التهاب الفقار اللاصق'),
(76896, 380, 21, 'التهاب الفقار اللاصق'),
(76897, 381, 21, 'فقدان الشهية'),
(76898, 382, 21, 'شيء آخر يمكنك القيام به في نافذة الطلب هو طلب الفواتير الثانوية. إذا قمت بتحديد صندوق الاختيار هذا قبل الحفظ، سيتم إعادة فتح المطالبة الأصلية وتوضع على قائمة الانتظار في صفحة الفواتير، وسيتم معالجتها خلال عملية الفوترة القادمة.'),
(76899, 383, 21, 'قبل'),
(76900, 384, 21, 'فحص اشرج سوي, لا كتل أو مضض في المستقيم'),
(76901, 385, 21, 'قلق'),
(76902, 386, 21, 'أي منها'),
(76903, 387, 21, 'أي فئة'),
(76904, 388, 21, 'اي جزء من الرمز المطلوب او وصفه'),
(76905, 389, 21, 'أي جزء من الإختصاص المطلوب'),
(76906, 390, 21, 'أي جزء من رقم أو إسم الدواء'),
(76907, 391, 21, 'أي جزء من رقم أو إسم اللقاح'),
(76908, 392, 21, 'أي جزء من اسم المريض'),
(76909, 393, 21, 'هل من معلومات أخرى؟'),
(76910, 394, 21, 'مفتاح الكود البرمجي لبوابة رسائل الجوال'),
(76911, 395, 21, 'توقف تنفس'),
(76912, 396, 21, 'المظهر'),
(76913, 397, 21, 'المظهر:'),
(76914, 398, 21, 'ارفاق هذه الملاحظة'),
(76915, 399, 21, 'إضافة الى الملاحظة الموجودة'),
(76916, 400, 21, 'إضافة الى هذه الملاحظة'),
(76917, 401, 21, 'إضافة الى هذه الملاحظة'),
(76918, 402, 21, 'استئصال الزائدة'),
(76919, 404, 21, 'المرضى المعنيين'),
(76920, 405, 21, 'استمارة'),
(76921, 406, 21, 'إسم تطبيق صفجة الدخول و عنوان النافذة الرئيسية'),
(76922, 407, 21, 'رمز مستقبل الطلب'),
(76923, 408, 21, '(GS02) رمز التطبيق المرسل'),
(76924, 409, 21, 'عنوان الطلب'),
(76925, 410, 21, 'ينطبق على نموذج العلامات الحيوية و مخطط النمو'),
(76926, 411, 21, 'أضف التغيرات للحدث الحالي فقط'),
(76927, 412, 21, 'تطبيق التغييرات على الحدث الحالي وما يليه أو جميع اﻷحداث؟'),
(76928, 413, 21, 'تطبيق على المنطقة المصابة'),
(76929, 414, 21, 'تطبيق على الجلد'),
(76930, 415, 21, 'تطبيق'),
(76931, 416, 21, 'تحديث الموقع'),
(76932, 417, 21, 'موعد'),
(76933, 418, 21, 'تاريخ الموعد'),
(76934, 419, 21, 'طريقة عرض الموعد'),
(76935, 420, 21, 'قواعد التذكير بالموعد'),
(76936, 421, 21, 'حالة الموعد'),
(76937, 422, 21, 'حالات الموعد'),
(76938, 423, 21, 'الموعد خلال'),
(76939, 424, 21, 'لون الموعد أو الحدث'),
(76940, 425, 21, 'المواعيد'),
(76941, 426, 21, 'المواعيد (الكتابة اختيارية)'),
(76942, 427, 21, 'المواعيد (الكتابة اختيارية)'),
(76943, 430, 21, 'المواعيد والمقابلات'),
(76944, 431, 21, 'تقرير بالمواعيد'),
(76945, 432, 21, 'تقرير بالمواعيد والمقابلات'),
(76946, 434, 21, 'موافق'),
(76947, 436, 21, 'الموافقة'),
(76948, 437, 21, 'ادارة الأحداث الموافقة'),
(76949, 438, 21, 'تمت الموافقة بنجاح'),
(76950, 440, 21, 'المواعيد والمقابلات'),
(76951, 441, 21, 'المواعيد'),
(76952, 442, 21, 'أبريل/نيسان'),
(76953, 443, 21, 'أبريل/نيسان'),
(76954, 444, 21, 'العربية'),
(76955, 446, 21, 'الارشيف'),
(76956, 447, 21, 'ترجمة أسماء مجموعة التحكم؟'),
(76957, 448, 21, 'ترجمة أسماء فئة المواعبد؟'),
(76958, 449, 21, 'ترجمة أسماء فئة المستند؟'),
(76959, 450, 21, 'هل تم حساب فاتورة لهذا النمط؟'),
(76960, 451, 21, 'هل سيتم ترجمة عناوين ملاحظات المرضى'),
(76961, 452, 21, 'هل اﻷكواد التالية محفوظة في قاعدة بيانات خارجية (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2) )'),
(76962, 453, 21, 'هل أنت مستعد ﻹكمال عملية GCAC لهذه الزيارة؟'),
(76963, 454, 21, 'هل أنت متأكد من أنك تريد الإرسال لهذا اليوم؟'),
(76964, 455, 21, 'هل أنت متأكد أنك تريد الموافقة على هذه الأحداث؟'),
(76965, 457, 21, 'هل أنت متأكد أنك تريد إزالة هذه من النموذج بشكل كامل؟'),
(76966, 459, 21, 'هل أنت متأكد من أنك تريد حذف هذا الكشف؟'),
(76967, 460, 21, 'هل أنت متأكد أنك تريد حذف هذا الحدث؟'),
(76968, 461, 21, 'هل أنت متأكد أنك تريد هذا البند من قاعدة البيانات؟'),
(76969, 462, 21, 'هل أنت متأكد أنك تريد حذف هذه الملاحظة؟'),
(76970, 464, 21, 'هل أنت متأكد أنك تريد تحرير هذه الأحداث؟'),
(76971, 465, 21, 'هل أنت متأكد أنك تريد إخفاء هذه الأحداث؟'),
(76972, 466, 21, 'هل أنت متأكد أنك تريد الإرسال مجددا؟'),
(76973, 467, 21, 'هل أنت متأكد أنك تريد عرض هذه الأحداث؟'),
(76974, 468, 21, 'هل أنت متأكد أنك تريد حذف هذه المجموعة؟'),
(76975, 469, 21, 'هل أنت متأكد أنك تريد حذف هذه القائمة؟'),
(76976, 470, 21, 'هل أنت متأكد أنك تريد حذف هذا الحقل؟'),
(76977, 471, 21, 'هل أنت متأكد أنك تريد حذف الحقول المختارة؟'),
(76978, 472, 21, 'هل أنت متأكد أنك تريد الاستمرار في هذه الأفعال؟'),
(76979, 473, 21, 'ناحية غير محددة'),
(76980, 474, 21, 'ساعد'),
(76981, 475, 21, 'أرمني'),
(76982, 477, 21, 'لا نظمية'),
(76983, 478, 21, 'التهاب المفصل'),
(76984, 479, 21, 'التهاب المفصل/ الداء المفصلي التنكسي'),
(76985, 480, 21, 'التهاب المفصل/ الداء المفصلي التنكسي'),
(76986, 481, 21, 'مثل'),
(76987, 482, 21, 'مثلما'),
(76988, 484, 21, 'آسيوي'),
(76989, 487, 21, 'التقييم'),
(76990, 488, 21, 'موكل إلى'),
(76991, 489, 21, 'المساعد'),
(76992, 490, 21, 'الربو'),
(76993, 491, 21, 'في'),
(76994, 492, 21, 'تحتاج إلى عنصر بحث واحد على الأقل إذا خترت الكل'),
(76995, 493, 21, 'في مستوى القاربي'),
(76996, 494, 21, 'في مستوى القاربي'),
(76997, 495, 21, 'الفريق الرياضي'),
(76998, 496, 21, 'الفريق الرياضي'),
(76999, 497, 21, 'الرياضي/ إصابة'),
(77000, 498, 21, 'شهادة مراجعة ومصادقة الحسابات'),
(77001, 499, 21, 'مضيف عملية تدقيق ومصادقة الحسابات'),
(77002, 500, 21, 'شهادة تدقيق و مصادقة الحسابت الداخلية'),
(77003, 501, 21, 'منفذ تدقيق ومصادقة الحسابات'),
(77004, 503, 21, 'انتباه'),
(77005, 504, 21, 'عناية'),
(77006, 506, 21, 'تدقيق محرك إستفهامات CDR'),
(77007, 509, 21, 'تدقيق التقارير اﻹحتياطية'),
(77008, 510, 21, 'تدقيق التقارير النثرية'),
(77009, 511, 21, 'تدقيق تقارير اﻷوامر'),
(77010, 512, 21, 'تدقيق سجل تقارير المرضى'),
(77011, 513, 21, 'تدقيق سجل المواعيد'),
(77012, 514, 21, 'تدقيق سجل إدارة اﻷمن'),
(77013, 515, 21, 'تدقيق سجل طلبات البحث في قاعدة المعلومات'),
(77014, 516, 21, 'اغسطس/آب'),
(77015, 517, 21, 'اغسطس/آب'),
(77016, 519, 21, 'تفويض'),
(77017, 520, 21, 'تفويض/ملاحظات'),
(77018, 523, 21, 'مجموعة التفويض'),
(77019, 524, 21, 'حالة التفويض'),
(77020, 525, 21, 'التفويض'),
(77021, 526, 21, 'يفوّض'),
(77022, 527, 21, 'تفويض - أي مراجعة'),
(77023, 528, 21, 'تفويض - مراجعيي'),
(77024, 529, 21, 'Authorize.net'),
(77025, 530, 21, 'تم التفويض'),
(77026, 531, 21, 'المفوض فقط'),
(77027, 532, 21, 'إرسال ذاتي'),
(77028, 535, 21, 'إنشاء ذاتي'),
(77029, 536, 21, 'إنشاء ذاتي'),
(77030, 537, 21, 'حسابات القياس اﻵلي (AMC)'),
(77031, 542, 21, 'مراجعة حسابات القياس اﻵلي (AMC)'),
(77032, 543, 21, 'القياس اﻵلي'),
(77033, 544, 21, 'آلي'),
(77034, 546, 21, 'إضافة مراجعة آليا عندما تكون حالة الموعد "@" (وصل)'),
(77035, 549, 21, 'طبي متحرك'),
(77036, 550, 21, 'حفظ ذاتي'),
(77037, 551, 21, 'التصنيفات المتوفرة'),
(77038, 552, 21, 'الأوقات المتوفرة'),
(77039, 557, 21, 'المعدل الشهري'),
(77040, 558, 21, 'قلع / كسر قلعي'),
(77041, 559, 21, 'كسر عظم الشظية'),
(77042, 560, 21, 'كسر عظم الظنبوب '),
(77043, 561, 21, 'معتمد على الوعي'),
(77044, 562, 21, 'إبطي'),
(77045, 565, 21, 'مرتان في اليوم'),
(77046, 566, 21, 'الظهر'),
(77047, 567, 21, 'الخلف'),
(77048, 568, 21, 'الرجوع ثماني زيارات'),
(77049, 569, 21, 'الرجوع أحد عشر زيارة'),
(77050, 570, 21, 'الرجوع خمس زيارات'),
(77051, 571, 21, 'الرجوع أربع زبارات'),
(77052, 572, 21, 'الرجوع تسع زيارات'),
(77053, 573, 21, 'الرجوع زيارة واحدة'),
(77054, 574, 21, 'ألم الظهر'),
(77055, 575, 21, 'مشاكل الظهر'),
(77056, 576, 21, 'الرجوع سبع زيارات'),
(77057, 577, 21, 'الرجوع ست زيارات'),
(77058, 578, 21, 'جراحة الظهر'),
(77059, 579, 21, 'الرجوع عشر زيارات'),
(77060, 580, 21, 'الرجوع ثلاث زيارات'),
(77061, 581, 21, 'الرجوع إلى صفحة اﻹدارة'),
(77062, 584, 21, 'الرجوع إلى المريض'),
(77063, 585, 21, 'الرجوع إلى المستخدمين'),
(77064, 586, 21, 'الرجوع إلى الصفحة'),
(77065, 587, 21, 'الرجوع اثنا عشر زيارة'),
(77066, 588, 21, 'الرجوع زيارتان'),
(77067, 589, 21, 'خدمات مساندة'),
(77068, 590, 21, 'نسخة احتياطية'),
(77069, 591, 21, 'تم إنشاء النسخة الاحتياطية، جارِ التحميل'),
(77070, 593, 21, 'تم أخذ نسخة إحتياطية بنجاح'),
(77071, 594, 21, 'شيك مصرفي سيء'),
(77072, 595, 21, 'قصة ائتمان سيء'),
(77073, 596, 21, 'باهاسا إندونيسيا'),
(77074, 597, 21, 'الرصيد'),
(77075, 598, 21, 'التوازن'),
(77076, 599, 21, 'التوازن'),
(77077, 600, 21, 'كمية التوازن'),
(77078, 601, 21, 'المبلغ المطلوب'),
(77079, 603, 21, 'شيك مصرفي'),
(77080, 607, 21, 'قاعدة السنع الخامس'),
(77081, 608, 21, 'قاعدة السنع الخامس'),
(77082, 611, 21, 'مطالبات مجتمعة'),
(77083, 612, 21, 'أداة اﻹتصال الجماعية'),
(77084, 613, 21, 'إدخال الدفعات'),
(77085, 614, 21, 'دفعات'),
(77086, 615, 21, 'جاري معالجة رزمة - قد يستغرق هذا بعض الوقت'),
(77087, 616, 21, 'مجموعة النتائج'),
(77088, 617, 21, 'BatchCom'),
(77089, 619, 21, 'لإن هذا الرقم غير موجود'),
(77090, 620, 21, 'تاريخ البدء'),
(77091, 621, 21, 'تاريخ البدء'),
(77092, 623, 21, 'تاريخ بدء الخدمة'),
(77093, 624, 21, 'ساعة بداية اليوم للمواعيد'),
(77094, 626, 21, 'التجشؤ'),
(77095, 628, 21, 'بنغالي'),
(77096, 630, 21, 'بين'),
(77097, 633, 21, 'ثنائي الجانب'),
(77098, 634, 21, 'ثنائي الجانب'),
(77099, 636, 21, 'تاريخ الفاتورة:'),
(77100, 637, 21, 'الفاتورة/ التحصيل'),
(77101, 638, 21, 'الفاتورة مرسلة'),
(77102, 640, 21, 'الفاتورة'),
(77103, 641, 21, 'الفاتورة اختياري'),
(77104, 642, 21, 'الفاتورة إلى'),
(77105, 644, 21, 'رمز الفاتورة للخدمات المطلوبة'),
(77106, 645, 21, 'رموز الفواتير'),
(77107, 646, 21, 'بيانات المحاسبه'),
(77108, 647, 21, 'قسم المحاسبة'),
(77109, 648, 21, 'المحاسبة'),
(77110, 649, 21, 'معلومات المحاسبة و الأجور'),
(77111, 650, 21, 'مكان المحاسبة'),
(77112, 655, 21, 'مدير المحاسبة'),
(77113, 656, 21, 'ملاحظات المحاسبة'),
(77114, 657, 21, 'ملاحظات المحاسبة ل '),
(77115, 658, 21, 'ملاحظات المحاسبة'),
(77116, 659, 21, 'نتائج المحاسبة'),
(77117, 660, 21, 'تقرير المحاسبة'),
(77118, 661, 21, 'حالة الفوترة'),
(77119, 662, 21, 'حالة الفوترة - لم يتم إصدار الفاتورة'),
(77120, 663, 21, 'إرسال الفاتورة إلى '),
(77121, 665, 21, 'خزعة'),
(77122, 666, 21, 'تاريخ الولادة'),
(77123, 667, 21, 'الولادة - 24 شهر'),
(77124, 669, 21, 'أسود إفريقي'),
(77125, 670, 21, 'رئة سوداء'),
(77126, 671, 21, 'أسود او افريقى امريكي'),
(77127, 672, 21, 'سرطان المثانة'),
(77128, 673, 21, 'أخماج المثانة'),
(77129, 674, 21, 'استمارات فارغة'),
(77130, 675, 21, 'مشاكل نزفية'),
(77131, 676, 21, 'بقع عمياء'),
(77132, 677, 21, 'حس انتفاخ'),
(77133, 678, 21, 'محجوب- مغلق'),
(77134, 679, 21, 'الدم'),
(77135, 680, 21, 'ضغط الدم'),
(77136, 681, 21, 'ضغط الدم'),
(77137, 682, 21, 'نزف الأنف'),
(77138, 683, 21, 'مؤسسة الصليب اﻻزرق الدرع اﻻزرق للتأمين'),
(77139, 684, 21, 'الخطوط الزرقاء في هذا التقرير هي للمعلومات. الخطوط السوداء تظهر المعلومات السابقة. الخطوط الخضراء تظهر التطبيق الناجح للتغيرات. الخطوط الحمراء تظهر وجود خطأ، أو إن التغيرات لم تطبق، لابد من تطبيقها يدوياً'),
(77140, 685, 21, 'رؤية مشوشة'),
(77141, 686, 21, 'مشعر كتلة الجسم'),
(77142, 687, 21, 'حالة مشعر كتلة الجسم'),
(77143, 689, 21, 'منطقة الجسم التشريحية'),
(77144, 690, 21, 'الموقع التشريحي'),
(77145, 691, 21, 'الموقع التشريحي، عند الضرورة'),
(77146, 692, 21, 'مضض العظام'),
(77147, 693, 21, 'مضض مفصل الكاحل'),
(77148, 694, 21, 'رقمي'),
(77149, 696, 21, 'السفلي'),
(77150, 697, 21, 'كلا الأذنين'),
(77151, 698, 21, 'كلا الأذنين'),
(77152, 699, 21, 'الأسفل'),
(77153, 701, 21, 'الصندوق رقم 10 أ : إصابة عمل '),
(77154, 702, 21, 'الصندوق رقم 10 ب : حادث سيارة '),
(77155, 703, 21, 'الصندوق رقم 10 ج: حوادث اخرى '),
(77156, 706, 21, 'الصندوق رقم 15 : تاريخ نفس المرض أو مشابه (بهذة الصيغة : 12-05-1990)'),
(77157, 708, 21, 'الصندوق رقم 16 :تاريخ بداية العجز عن العمل (بهذة الصيغة : 12-05-1990)'),
(77158, 709, 21, 'الصندوق رقم 16 :تاريخ نهاية العجز عن العمل (بهذة الصيغة : 12-05-1990)'),
(77159, 710, 21, 'الصندوق رقم 18 :تاريخ بداية التنويم (بهذة الصيغة : 12-05-1990) '),
(77160, 711, 21, 'الصندوق رقم 18 :تاريخ نهاية التنويم (بهذة الصيغة : 12-05-1990) '),
(77161, 712, 21, 'الصندوق رقم 20 : هل تم إستخدام مختبر خارجي؟'),
(77162, 713, 21, 'الصندوق رقم 22 : رمز إعادة التسليم الطبي (ICD-9) '),
(77163, 714, 21, 'الصندوق رقم 23 : رقم التفويض السابق '),
(77164, 715, 21, 'ضغط الدم'),
(77165, 716, 21, 'ضغط الدم اﻹنبساطي'),
(77166, 717, 21, 'ضغط الدم اﻹنقباضي'),
(77167, 719, 21, 'ضغط الدم اﻹنبساطي'),
(77168, 721, 21, 'ضغط الدم اﻹنقباضي'),
(77169, 722, 21, 'برازيلي برتغالي'),
(77170, 723, 21, 'الثدي'),
(77171, 724, 21, 'خزعة الثدي'),
(77172, 725, 21, 'مفرزات الثدي'),
(77173, 726, 21, 'مرض الثدي'),
(77174, 727, 21, 'فحص الثدي'),
(77175, 728, 21, 'كتلة الثدي'),
(77176, 730, 21, 'أصوات التنفس:'),
(77177, 732, 21, 'عظام مكسورة'),
(77178, 734, 21, 'استمارة التهاب القصبات'),
(77179, 735, 21, 'تصفح'),
(77180, 736, 21, 'تصفح السجل'),
(77181, 737, 21, 'تكدم/ ورم دموي'),
(77182, 739, 21, 'بروز ايمن'),
(77183, 741, 21, 'حرقة أثناء التبول'),
(77184, 742, 21, 'حرقة أثناء التبول'),
(77185, 744, 21, 'مشغول'),
(77186, 745, 21, 'لكن لم تتم معالجتة بعد'),
(77187, 746, 21, 'ردف'),
(77188, 747, 21, 'ردف'),
(77189, 748, 21, 'بواسطة'),
(77190, 749, 21, 'بواسطة'),
(77191, 750, 21, 'عن طريق الفم'),
(77192, 751, 21, 'بواسطة/ المصدر'),
(77193, 752, 21, 'من قبل:'),
(77194, 753, 21, 'ج'),
(77195, 754, 21, 'CA Certificate for verifying the RFC 5425 TLS syslog server.'),
(77196, 755, 21, 'حياة الذاكرة الوسيطة (بالثواني)'),
(77197, 756, 21, 'خرج قالب الذاكرة الوسيطة؟'),
(77198, 757, 21, 'استهلاك القهوة'),
(77199, 758, 21, 'التقويم'),
(77200, 759, 21, 'ساعة نهاية التقويم'),
(77201, 760, 21, 'فترة التقويم'),
(77202, 761, 21, 'شاشة التقويم'),
(77203, 762, 21, 'إعدادات التقويم'),
(77204, 763, 21, 'ساعة بداية التقويم'),
(77205, 764, 21, 'واجهة التقويم'),
(77206, 765, 21, 'مشاهدة التقويم'),
(77207, 766, 21, 'شفرة إضافة نموذج (addForm()) تأتي هنا <br>'),
(77208, 767, 21, 'الحريرات'),
(77209, 768, 21, 'كمبودي'),
(77211, 774, 21, 'إلغاء'),
(77212, 775, 21, 'الغاء التغييرات'),
(77213, 776, 21, 'ألغي'),
(77214, 777, 21, 'السرطان'),
(77215, 778, 21, 'تقصي السرطان: تقصي سرطان الكولون'),
(77216, 779, 21, 'تقصي السرطان: صورة الثدي'),
(77217, 780, 21, 'تقصي السرطان: مسحة باب نيكولاو'),
(77218, 781, 21, 'تقصي السرطان: تقصي سرطان البروستات'),
(77219, 782, 21, 'لايمكن إضافة هذا لأنه موجود سابقاَ'),
(77220, 783, 21, 'لايمكن إضافة/تحديث هذا لأنه موجود سابقاَ'),
(77221, 784, 21, 'لا يمكن الحفظ'),
(77222, 785, 21, 'لايمكن تحويله إلى ملف صورة - تحتاج تنصيب برنامج'),
(77223, 786, 21, 'لا يمكن الحذف'),
(77224, 787, 21, 'لا يمكن عرض البيانات ﻷن المتصفح لا يدعم هذا النوع.'),
(77225, 788, 21, 'لا يمكن عرض البيانات ﻷن المتصفح لا يدعم هذا النوع.'),
(77226, 789, 21, 'لا يمكن عرض البيانات ﻷن المتصفح لا يدعم هذا النوع.'),
(77227, 790, 21, 'لا يمكن اﻹضافة'),
(77228, 795, 21, 'لا يمكن ايجاده '),
(77229, 796, 21, 'لا يمكن ايجاد ملف بهذا اﻹسم'),
(77230, 799, 21, 'لا يمكن إيجاد المريض في قاعدة معلومات الزبائن'),
(77231, 800, 21, 'لا يمكن العثور علي دليل ملف ال postscript '),
(77232, 801, 21, 'لا يمكن العثور من SQL-Ledger employee '),
(77233, 802, 21, 'لا يمكن تغيير الدفوعات. المقدار الغير موزع بالسالب'),
(77234, 803, 21, 'غير قابل للفتح '),
(77235, 804, 21, 'لا يمكن المطالبةبالدفع من التأمين. الجهة المختارة هى مريض'),
(77236, 805, 21, 'لا يمكن المطالبة بالدفع من المريض. الجهة المختارة هي شركة تأمين.'),
(77237, 806, 21, 'لا يمكن المطالبة بالدفع. القيمة الغير موزعة بالسالب'),
(77238, 807, 21, 'لا يمكن القراءة'),
(77239, 808, 21, 'لا يمكن قراءة المجلد'),
(77240, 809, 21, 'لا يمكن التحديث لأن السجل غير موجود!'),
(77241, 810, 21, 'اﻹستفادة'),
(77242, 812, 21, 'كبسولة'),
(77243, 813, 21, 'بطاقة'),
(77244, 814, 21, 'القسطرة القلبية'),
(77245, 815, 21, 'تصوير صدى القلب'),
(77246, 816, 21, 'قلبي وعائي'),
(77247, 821, 21, 'الغضروف / الغضروفي / تأذي القرص'),
(77248, 822, 21, 'إصابة الغضروف'),
(77249, 823, 21, 'نبض الشريان السباتي: سوي، نبض شريان ظهر القدم: سوي'),
(77250, 824, 21, 'نقداَ'),
(77251, 825, 21, 'نقداَ'),
(77252, 826, 21, 'إيصال الدفع نقداَ'),
(77253, 827, 21, 'جراحة الساد'),
(77254, 829, 21, 'الساد'),
(77255, 830, 21, 'المجموعات'),
(77256, 831, 21, 'المجموعة'),
(77257, 832, 21, 'أصناف ال'),
(77258, 833, 21, 'المجموعة'),
(77259, 834, 21, 'المجموعة'),
(77260, 835, 21, 'تفاصيل المجموعة '),
(77261, 836, 21, 'محددات المجموعة'),
(77262, 837, 21, 'اسم المجموعة'),
(77263, 838, 21, 'قوقازي /أبيض'),
(77264, 839, 21, 'اسم الصنف فارغ'),
(77265, 840, 21, 'الصنف / العنوان'),
(77266, 841, 21, 'الهاتف الخليوي'),
(77267, 842, 21, 'يجعل الإيصالات تطبع معلومات الزيارة/المزود الأولي'),
(77268, 850, 21, 'لجنة تسجيل السّكر'),
(77269, 851, 21, 'أولوية تشغيل تقارير لجنة تسجيل السّكر'),
(77270, 852, 21, 'خلية'),
(77271, 853, 21, 'الهاتف النقال'),
(77272, 855, 21, 'رقم الهاتف النقال'),
(77273, 856, 21, 'ترخيص مركزي'),
(77274, 857, 21, 'امريكي جنوبي'),
(77275, 858, 21, 'crt لملف شهادة السلطة لا يمكن أن يكون خاليا'),
(77276, 859, 21, 'مفتاح ملف شهادة السلطة لا يمكن أن يكون خاليا'),
(77277, 860, 21, 'الشهادات التي سيتم إرسالها الي RFC 5425 TLS syslog server'),
(77278, 861, 21, 'شهادة المستخدم'),
(77279, 862, 21, 'شهادات'),
(77280, 864, 21, 'تريكير برنامج صحي للجنود'),
(77281, 865, 21, 'تريكير برنامج صحي للجنود'),
(77282, 866, 21, 'غير'),
(77283, 867, 21, 'غير'),
(77284, 868, 21, 'تغيرات النشاط'),
(77285, 869, 21, 'Change failed! CouchDB connect error?'),
(77286, 870, 21, 'تغيرات الرؤية'),
(77287, 871, 21, 'تغيرات الرؤية'),
(77288, 872, 21, 'تغيير كلمة السر'),
(77289, 874, 21, 'تغير'),
(77290, 875, 21, 'تغيرت عادات التبرز'),
(77291, 876, 21, 'تغيير هوية المريض'),
(77292, 877, 21, 'مواصفات'),
(77293, 878, 21, 'أحرف متبقية');
INSERT INTO `lang_definitions` VALUES
(77294, 879, 21, 'تكلفة'),
(77295, 880, 21, 'تعديل التكلفة'),
(77296, 881, 21, 'تكلفة برمز'),
(77297, 882, 21, 'تكاليف'),
(77298, 883, 21, 'ملف المريض'),
(77299, 884, 21, 'حركة ملف المريض'),
(77300, 885, 21, 'تقرير الدخول / الخروج لملف المريض'),
(77301, 886, 21, 'هوية الملف'),
(77302, 887, 21, 'هوية الملف:'),
(77303, 889, 21, 'حركة موقع الملف'),
(77304, 890, 21, 'الملاحظات'),
(77305, 891, 21, 'رقم الملف'),
(77306, 892, 21, 'مواقع ملفات المرضى'),
(77307, 893, 21, 'متتّبع المخططات'),
(77308, 894, 21, 'متتّبع المخططات'),
(77309, 895, 21, 'تم اخراج مخططات المريض'),
(77310, 896, 21, 'تم اخراج مخططات المريض'),
(77311, 898, 21, 'فحص'),
(77312, 899, 21, 'فحص'),
(77313, 900, 21, 'فحص شامل'),
(77314, 902, 21, 'كمية الفحوص'),
(77315, 903, 21, 'تاريخ الفحص'),
(77316, 904, 21, 'فحص اﻹختلافات في الترجمة في ملف اللغة لمعدل'),
(77317, 906, 21, 'فحص في و إلى'),
(77318, 907, 21, 'فحص البيانات المدخلة'),
(77319, 909, 21, 'فحص نتائج المختبر'),
(77320, 910, 21, 'علامة الاختيار تعني تمت المراجعة'),
(77321, 911, 21, 'رقم الإختيار'),
(77322, 912, 21, 'فحص الرقم'),
(77323, 915, 21, 'فحص الدفعة'),
(77324, 916, 21, 'اختر إذا كان هذا ملف مشفر'),
(77325, 917, 21, 'اختر هذا إذا كنت تريد الطبيب أن يرى كل المواعيد وليس فقط مواعيده.'),
(77326, 918, 21, 'اختر لكتابة مشكلة من التشخيص'),
(77327, 919, 21, 'اختر / تاريخ نهاية العمل'),
(77328, 920, 21, 'اختر / رقم نهاية العمل'),
(77329, 921, 21, 'اختر / الرقم المرجعي'),
(77330, 922, 21, 'اختر / الرقم المرجعي'),
(77331, 923, 21, 'قائمة صندوق اﻹختيارات'),
(77332, 924, 21, 'قائمة صندوق اﻹختيارات'),
(77333, 925, 21, 'صندوق اختيار بنص'),
(77334, 926, 21, 'صندوق اختيار بنص'),
(77335, 928, 21, 'تم اختياره'),
(77336, 929, 21, 'صندوق اختيار = نعم ، فارغ = لا.'),
(77337, 932, 21, 'خروج'),
(77338, 933, 21, 'Checksum'),
(77339, 934, 21, 'الصدر'),
(77340, 935, 21, 'الصدر خالي من الأصوات المرضّية'),
(77341, 936, 21, 'الم الصدر'),
(77342, 937, 21, 'الم الصدر:'),
(77343, 938, 21, 'الام الصدر'),
(77344, 940, 21, 'تكلفة'),
(77345, 942, 21, 'الشكاية الأساسية'),
(77346, 943, 21, 'الطفل'),
(77347, 945, 21, 'حالة تحصينات سن الطفولة'),
(77348, 946, 21, 'عرواءات'),
(77349, 947, 21, 'صيني- اللغة'),
(77350, 948, 21, 'اللغة الصينية المبسطة'),
(77351, 949, 21, 'الغة الصينية التقليدية'),
(77352, 951, 21, 'اختيارات'),
(77353, 952, 21, 'استئصل المرارة'),
(77354, 954, 21, 'استئصال المرارة'),
(77355, 955, 21, 'اختر'),
(77356, 956, 21, 'اختر القسم و انقر على عنصر ضمنه، العناصر المتعلقة محددة'),
(77357, 957, 21, 'اختر المعايير'),
(77358, 959, 21, 'اختر ملف'),
(77359, 960, 21, 'اختر من القائمة'),
(77360, 962, 21, 'اختر من القائمة'),
(77361, 965, 21, 'اختر شكل طباعة هذا التقرير'),
(77362, 967, 21, 'التهاب القصبات المزمن'),
(77363, 968, 21, 'الألم المفصلي المزمن'),
(77364, 969, 21, 'مرض الكلى المزمن'),
(77365, 970, 21, 'التهاب الغشاء الزليلي المزمن/الانصباب/ألم المفصل/ النقرس'),
(77366, 971, 21, 'مزمن/متكرر/ناكس'),
(77367, 973, 21, 'تشمع الكبد'),
(77368, 974, 21, 'تشمع الكبد'),
(77369, 975, 21, 'المدينة'),
(77370, 976, 21, 'اسم المدينة'),
(77371, 977, 21, 'المدينة ، المحلفظة'),
(77372, 978, 21, 'المدينة ، المحلفظة ، الرمز'),
(77373, 979, 21, 'المدينة/المحافظة'),
(77374, 980, 21, 'دعوى'),
(77375, 981, 21, 'الدعوى '),
(77376, 982, 21, 'حالة الدعوى'),
(77377, 983, 21, 'انهى إختبار المطالبة العمل'),
(77378, 984, 21, 'نوع المطالبة'),
(77379, 985, 21, 'تم إضافة المطالبة إلى ملف'),
(77380, 986, 21, 'تم إضافة المطالبة إلى ملف '),
(77381, 987, 21, 'مطالبات'),
(77382, 988, 21, 'التصنيف'),
(77383, 989, 21, 'امسح'),
(77384, 990, 21, 'مسح'),
(77385, 991, 21, 'امسح الكل'),
(77386, 992, 21, 'بيانات HL7 واضحة'),
(77387, 993, 21, 'مبرر واضح'),
(77388, 994, 21, 'مسح الذاكرة'),
(77389, 995, 21, 'Clearing house info required for EDI 270 batch creation.'),
(77390, 996, 21, 'رقم المحتبرات السريرية'),
(77391, 997, 21, 'انقر'),
(77392, 998, 21, 'انقر "تصدير" لتصدير صنف، عنصر، محتوى'),
(77393, 999, 21, 'إضغط على نقطة في الرسم ﻹضافة ملاحظة، واضغط مرة اخرى ﻹزالتها'),
(77394, 1000, 21, 'انقر تنزيل الشهادة'),
(77395, 1001, 21, 'انقر'),
(77396, 1002, 21, 'انقر لمزيد من التفاصيل'),
(77397, 1003, 21, 'انقر لطلب مخلص'),
(77398, 1004, 21, 'انقر لمشاهدة النتائج'),
(77399, 1005, 21, 'انقر هنا'),
(77400, 1006, 21, 'انقر ﻹضافة مريض'),
(77401, 1007, 21, 'انقر ﻹضافة إصابة ، تعديل الحالة أو تحرير المهام اليومية'),
(77402, 1008, 21, 'انقر هنا لاختيار التاريخ'),
(77403, 1009, 21, 'انقر هنا لاختيار التاريخ والوقت'),
(77404, 1010, 21, 'انقر هنا ﻹختيار تاريخ البدء'),
(77405, 1020, 21, 'انقر هنا للبحث'),
(77406, 1021, 21, 'انقر هنا لتحديث إعدادات الأولوية، التصنيف، الاسم'),
(77407, 1022, 21, 'انقر هنا لمشاهدة الكل'),
(77408, 1023, 21, 'انقر هنا للإستعراض والرسم'),
(77409, 1025, 21, 'انقر هنا ﻹستعراض ورسم كل العلامات الحيوية'),
(77410, 1026, 21, 'انقر هنا ﻹستعراض بيانات المريض'),
(77411, 1027, 21, 'انقر هنا ﻹستعراض الكل'),
(77412, 1028, 21, 'انقر هنا لمشاهدة /تعديل تفاصيل أكثر'),
(77413, 1029, 21, 'انقر تثبيت لتثبيت قاعدة المعلومات من التاريخ التالي'),
(77414, 1030, 21, 'انقر على اي من أجزاء الوقت لزيادته'),
(77415, 1031, 21, 'انقر على إسم المريض لفتح ملفه'),
(77416, 1032, 21, 'انقر تحديث ﻹستعراض كل النتائج أو قم بإدخال معايير البحث ﻹستعراض بيانات معينة'),
(77417, 1033, 21, 'انقر لإضافة تشخيص'),
(77418, 1034, 21, 'انقر ﻹضافة مكونات إضافية'),
(77419, 1035, 21, 'انقر ﻹضافة إستشارة جديدة'),
(77420, 1037, 21, 'انقر للتنزيل'),
(77421, 1038, 21, 'انقر للتحرير'),
(77422, 1039, 21, 'انقر لتحرير الوصف'),
(77423, 1040, 21, 'انقر لتحرير هذه الحدث'),
(77424, 1041, 21, 'انقر لأنشاء التقرير'),
(77425, 1043, 21, 'انقر للطباعة'),
(77426, 1044, 21, 'انقر لاستقبال أو إضافة جديد'),
(77427, 1045, 21, 'انقر للاختيار'),
(77428, 1046, 21, 'انقر للاختيار'),
(77429, 1047, 21, 'انقر ﻹختيار رمز مقياس-صناعي لهذه اﻹجراءات'),
(77430, 1048, 21, 'انقر ﻹختيار رمز اختياري لهذه اﻹجراءات'),
(77431, 1050, 21, 'انقر ﻹختيار أو تغيير رمز CVX'),
(77432, 1051, 21, 'انقر لاختيار إو تغيير التشخيص'),
(77433, 1052, 21, 'انقر ﻹختيار أو تغيير رمز الخدمة'),
(77434, 1053, 21, 'انقر لاختيار المريض'),
(77435, 1054, 21, 'انقر لاختيار الرمز'),
(77436, 1055, 21, 'انقر ﻹختيار الخدمات التي تقدم في حال كانت النتيجة غير طبيعية'),
(77437, 1056, 21, 'انقر ﻹختيار اﻹجراءات المطلوبة'),
(77438, 1057, 21, 'انقر للترتيب'),
(77439, 1058, 21, 'انقر للمشاهدة'),
(77440, 1059, 21, 'انقر للمشاهدة أو التحرير'),
(77441, 1060, 21, 'انقر للمشاهدة/التحرير'),
(77442, 1061, 21, 'انقر زر ترقية لترقية إصدار قاعدة المعلومات من التاريخ التالي'),
(77443, 1063, 21, 'انقر:'),
(77444, 1064, 21, 'أيام أنتهاء صلاحية شهادة العميل'),
(77445, 1065, 21, 'فترة صلاحية شهادة العميل'),
(77446, 1066, 21, 'صلاحية شهادة العميل يجب أن يكون رقم صالح.'),
(77447, 1067, 21, 'نسخة العميل'),
(77448, 1069, 21, 'ملخص القصة المرضية'),
(77449, 1070, 21, 'اسم المريض'),
(77450, 1071, 21, 'رقم المريض'),
(77451, 1072, 21, 'إضبارة المريض - المرضى الجدد'),
(77452, 1073, 21, 'إضبارة المريض - المرضى المميزون'),
(77453, 1074, 21, 'المرضى'),
(77454, 1075, 21, 'العيادة'),
(77455, 1076, 21, 'نسخة العيادة'),
(77456, 1077, 21, 'السجل اليومي للعيادة'),
(77457, 1078, 21, 'رقم العيادة'),
(77458, 1079, 21, 'سريري'),
(77459, 1080, 21, 'مدير تنبيه قواعد القرارات السريرية'),
(77460, 1081, 21, 'القصة المرضية'),
(77461, 1083, 21, 'خطط سريرية'),
(77462, 1084, 21, 'مقاييس الجودة السريرية'),
(77463, 1087, 21, 'التذكيرات السريرية'),
(77464, 1088, 21, 'التقارير السريرية'),
(77465, 1089, 21, 'فئة عمل القاعدة السريرية'),
(77466, 1090, 21, 'بند عمل القاعدة السريرية'),
(77467, 1091, 21, 'طرق تصفية القاعدة السريرية'),
(77468, 1092, 21, 'الطرق المستهدفة للقاعدة السريرية'),
(77469, 1093, 21, 'القواعد السريرية'),
(77470, 1094, 21, 'المراحل العمرية للقواعد السريرية'),
(77471, 1095, 21, 'مقارنات القواعد السريرية'),
(77472, 1096, 21, 'أنواع المراجعات للقواعد السريرية'),
(77473, 1097, 21, 'خيارات التذكير للقواعد السريرية'),
(77474, 1098, 21, 'الخيارات التفاعلية للتذكير بالقواعد السريرية'),
(77475, 1099, 21, 'فترات التذكير للقواعد السريرية'),
(77476, 1100, 21, 'طرق التذكير للقواعد السريرية'),
(77477, 1101, 21, 'الفترات المستهدفة للقواعد السريرية'),
(77478, 1102, 21, 'اﻷهداف السريرية'),
(77479, 1103, 21, 'العبارة السريرية'),
(77480, 1104, 21, 'رمز المصطلح السريري'),
(77481, 1106, 21, 'الأطباء'),
(77482, 1107, 21, 'الاستنساخ'),
(77483, 1108, 21, 'استنساخ الزيارة السابقة'),
(77484, 1109, 21, 'إغلاق'),
(77485, 1111, 21, 'إغلاق النافذة'),
(77486, 1112, 21, 'مغلق'),
(77487, 1113, 21, 'سم'),
(77488, 1114, 21, 'CMS 1500 Margins'),
(77489, 1118, 21, 'CMS ID'),
(77490, 1127, 21, 'الأعصاب القحفية من الثاني- الثاني عشر: سليمة'),
(77491, 1128, 21, 'الدفع المشترك'),
(77492, 1129, 21, 'الدفع المشترك-مدفوع'),
(77493, 1130, 21, 'الدفع المشترك'),
(77494, 1131, 21, 'الرمز'),
(77495, 1132, 21, 'الرمز'),
(77496, 1133, 21, 'إيجاد الرمز'),
(77497, 1134, 21, 'يجب أن يكون الرمز من حرفيين'),
(77498, 1135, 21, 'الرمز أو العينة لتوضيح العملة'),
(77499, 1136, 21, 'نص الرمز'),
(77500, 1138, 21, 'نمط الرمز'),
(77501, 1141, 21, 'انماط الرمز'),
(77502, 1142, 21, 'الرمز'),
(77503, 1143, 21, 'مشفر'),
(77504, 1144, 21, 'الرموز'),
(77505, 1145, 21, 'نظام التصنيف'),
(77506, 1147, 21, 'ترميز أي مراجعة'),
(77507, 1148, 21, 'ترميز مراجعاتي فقط'),
(77508, 1149, 21, 'الترميز غير مصرح'),
(77509, 1150, 21, 'القهوة'),
(77510, 1152, 21, 'التأمين المشترك'),
(77511, 1153, 21, 'إنهيار بدون'),
(77512, 1154, 21, 'إنهيار'),
(77513, 1155, 21, 'إنهيار'),
(77514, 1156, 21, 'إخفاء جميع القوائم'),
(77515, 1157, 21, 'إخفاء جميع القوائم'),
(77516, 1158, 21, 'إخفاء جميع القوائم'),
(77517, 1160, 21, 'تاريخ الجمع'),
(77518, 1161, 21, 'تجميعات'),
(77519, 1162, 21, 'تقرير التجميعات'),
(77520, 1163, 21, 'سرطان الكولون'),
(77521, 1164, 21, 'فحص سرطان القولون'),
(77522, 1165, 21, 'جراحة سرطان الكولون'),
(77523, 1166, 21, 'تنظير الكولون'),
(77524, 1167, 21, 'تنظير الكولون'),
(77525, 1168, 21, 'اللون'),
(77526, 1169, 21, 'إختصار اللون'),
(77527, 1170, 21, 'عمود'),
(77528, 1171, 21, 'الأعمدة'),
(77529, 1172, 21, 'الطبخات المجمعة'),
(77530, 1173, 21, 'فاصلة'),
(77531, 1174, 21, 'ملاحظة / تعليق'),
(77532, 1175, 21, 'التعليقات'),
(77533, 1176, 21, 'التعليق على هذه النتيجة أو التوصيات'),
(77534, 1177, 21, 'شركة التأمين'),
(77535, 1178, 21, 'حفظ التغييرات'),
(77536, 1180, 21, 'الاتصالات'),
(77537, 1182, 21, 'الشركة'),
(77538, 1183, 21, 'إسم الشركة'),
(77539, 1184, 21, 'كامل'),
(77540, 1186, 21, 'مكتمل'),
(77541, 1188, 21, 'مكتمل؟'),
(77542, 1190, 21, 'التعيقدات من مزود الخدمة'),
(77543, 1191, 21, 'اختلاطات الإجهاض'),
(77544, 1192, 21, 'المكونات'),
(77545, 1193, 21, 'نظام الأوامر الطبية بمساعدة الكومبيوتر'),
(77546, 1194, 21, 'الاستنتاجات'),
(77547, 1199, 21, 'اﻹعدادات'),
(77548, 1200, 21, 'تصدير / إستيراد اﻹعدادات'),
(77549, 1202, 21, 'هيئ الأباتشى و البرنامج لإستخدام شهادات SSL التابعة للعميل'),
(77550, 1203, 21, 'هيئ الأباتشى لإستخدام شهادات SSL التابعة للعميل'),
(77551, 1204, 21, 'هيئ الأباتشى لإستخدام HTTPS'),
(77552, 1205, 21, 'هيئ البرنامج لإستخدام شهادات SSL التابعة للعميل'),
(77553, 1208, 21, 'تأكيد إضافة مريض جديد'),
(77554, 1209, 21, 'تأكيد كلمة المرور الجديدة'),
(77555, 1210, 21, 'تأكيد الدفع'),
(77556, 1214, 21, 'الخلقي'),
(77557, 1215, 21, 'الملتحمة ، الحدقات'),
(77558, 1217, 21, 'الموصلات'),
(77559, 1218, 21, 'ثابت'),
(77560, 1219, 21, 'إسم الثابت'),
(77561, 1220, 21, 'إسم الثابت فارغ'),
(77562, 1221, 21, 'الثوابت'),
(77563, 1222, 21, 'الإمساك'),
(77564, 1223, 21, 'أعراض جهازية عامة'),
(77565, 1226, 21, 'وصف مختصر لسبب زيارة المريض'),
(77566, 1227, 21, 'المعلومات حول شخص قريب أو مرافق'),
(77567, 1228, 21, 'البريد الإلكتروني'),
(77568, 1229, 21, 'البريد الإلكتروني'),
(77569, 1230, 21, 'تواصل مع EMRمباشرة للإشتراك فى خدمة phiMail للمراسلة المباشرة'),
(77570, 1231, 21, 'المعلومات حول شخص قريب أو مرافق'),
(77571, 1232, 21, 'العدسات اللاصقة'),
(77572, 1233, 21, 'تواصل مع دمج المعلومات الطبيّة لخدمة تبادل المعمل http://mi-squared.com'),
(77573, 1234, 21, 'تواصل مع دمج المعلومات الطبيّة http://mi-squared.com او ZH Healthcare at http://zhservices.com'),
(77574, 1236, 21, 'اسم شخص قريب أو مرافق'),
(77575, 1237, 21, 'شخص قريب أو مرافق'),
(77576, 1239, 21, 'هاتف الشخص القريب أو المرافق'),
(77577, 1240, 21, 'تواصل مع (zmghealth@gmail.com) for subscribing the eRx service'),
(77578, 1241, 21, 'تحتوي على اﻷقل على ثلاثة من أربعة من البنود التالية'),
(77579, 1242, 21, 'إسم محتوى المجموعة'),
(77580, 1243, 21, 'المحتوى'),
(77581, 1244, 21, 'المحتوى'),
(77582, 1245, 21, 'السياق'),
(77583, 1246, 21, 'اسم السياق لا يمكن أن يكون فارغا'),
(77584, 1247, 21, 'الاستمرار'),
(77585, 1248, 21, 'استمرارية وثيقة الرعاية'),
(77586, 1249, 21, 'استمرارية سجل الرعاية'),
(77587, 1250, 21, 'ضد العملاء'),
(77588, 1251, 21, 'منع الحمل'),
(77589, 1252, 21, 'مسائل منع الحمل'),
(77590, 1253, 21, 'التأثيرات الجانبية لموانع الحمل - اذكرها'),
(77591, 1254, 21, 'أسلوب منع الحمل'),
(77592, 1255, 21, 'منتجات منع الحمل'),
(77593, 1256, 21, 'خدمات منع الحمل السابقة'),
(77594, 1257, 21, 'بدء موانع الحمل'),
(77595, 1258, 21, 'معرف التحكم'),
(77596, 1259, 21, 'رقم التحكم'),
(77597, 1261, 21, 'الدفع المشترك'),
(77598, 1262, 21, 'الدفع المشترك'),
(77599, 1263, 21, 'الدفع المشترك'),
(77600, 1264, 21, 'الدفع المشترك غير موجب'),
(77601, 1266, 21, 'الدفوع المشتركة'),
(77602, 1267, 21, 'المرض الرئوي الانسدادي المزمن'),
(77603, 1268, 21, 'نسخ الصفحات إلى إضبارة المريض'),
(77604, 1269, 21, 'قيم النسخ'),
(77605, 1270, 21, 'جاري نسخ ملف قاعدة المعلومات - قد يستغرق ذلك بعض الوقت'),
(77606, 1271, 21, 'حول حفظ الحقوق'),
(77607, 1273, 21, 'مجازة الشرايين التاجية'),
(77608, 1274, 21, 'مجازة الشرايين التاجية'),
(77609, 1275, 21, 'صحح'),
(77610, 1277, 21, 'CouchDB'),
(77611, 1278, 21, 'فشل الإتصال CouchDB'),
(77612, 1279, 21, 'قاعدة البيانات CouchDB'),
(77613, 1280, 21, 'إسم قاعدة البيانات CouchDB'),
(77614, 1281, 21, 'مستضيف CouchDB'),
(77615, 1282, 21, 'إسم مستضيف CouchDB'),
(77616, 1283, 21, 'فعّل تسجيل احداث CouchDB'),
(77617, 1284, 21, 'كلمة سّر CouchDB'),
(77618, 1285, 21, 'مدخل CouchDB'),
(77619, 1286, 21, 'مدخل CouchDB'),
(77620, 1288, 21, 'إسم مستخدم CouchDB'),
(77621, 1289, 21, 'السعال'),
(77622, 1290, 21, 'السعال:'),
(77623, 1294, 21, 'تعذر قراءة الملف'),
(77624, 1296, 21, 'فشل إرسال رسللة إلكترونية لعطل في الشبكة '),
(77625, 1297, 21, 'تعذر إرسال البريد اﻹلكتروني بسبب مشكلة في الخادم '),
(77626, 1298, 21, 'فشل إنشاء النسخة الاحتياطية'),
(77627, 1299, 21, 'تعذر حذف المجلد'),
(77628, 1300, 21, 'تعذر حذف ملف النسخ اﻹحتياطي السابق'),
(77629, 1301, 21, 'تعذر حذف ملف التصدير السابق'),
(77630, 1302, 21, 'تدبير المعالجة بمميعات الدم- مراقبة INR'),
(77631, 1303, 21, 'الإستشارة بالنوع'),
(77632, 1304, 21, 'جلسات التوعية'),
(77633, 1305, 21, 'نشاطات التوعية'),
(77634, 1306, 21, 'نموذج اﻹحالة'),
(77635, 1307, 21, 'تعدد الاحالة'),
(77636, 1308, 21, 'الدولة'),
(77637, 1309, 21, 'نوع بيانات الدول'),
(77638, 1310, 21, 'قائمة الدول'),
(77639, 1311, 21, 'قائمة الدول'),
(77640, 1312, 21, 'اسم الدولة لا بد أن يتم تمثيله ب حرفين (مثلا : السعودية :SA)'),
(77641, 1313, 21, 'المحافظة'),
(77642, 1315, 21, 'القسيمة'),
(77643, 1318, 21, 'قائمة الإجراءات الطبية'),
(77644, 1319, 21, 'رمز CPT4'),
(77645, 1320, 21, 'تصانيف الإجراءات الطبية'),
(77646, 1321, 21, 'إجراءات / خدمة CPT4'),
(77647, 1322, 21, 'قياسات اداء CPTII'),
(77648, 1323, 21, 'CQM'),
(77649, 1324, 21, 'أصوات تنفسية فرقعية:'),
(77650, 1325, 21, 'كريم'),
(77651, 1326, 21, 'إنشاء شهادة SSL من جانب العميل لكل مستخدم أو جهاز العميل.'),
(77652, 1327, 21, 'إنشاء شهادة SSL من جانب العميل سواء لمستخدم أو لمضيف العميل.'),
(77653, 1329, 21, 'إنشاء حدث جديد'),
(77654, 1330, 21, 'إنشاء وتنريل نسخة احتياطية كاملة'),
(77655, 1332, 21, 'إنشاء نسخة احتياطية'),
(77656, 1333, 21, 'إنشاء حزمة'),
(77657, 1334, 21, 'إنشاء شهادة الزبون'),
(77658, 1335, 21, 'إنشاء شهادة أمن المتصفح'),
(77659, 1336, 21, 'إنشاء نسخة مكررة'),
(77660, 1338, 21, 'إنشاء نسخة إحتياطية من سجل اﻷحداث'),
(77661, 1339, 21, 'إنشاء قضية جديدة'),
(77662, 1340, 21, 'إنشاء ملف جديد للمريض'),
(77663, 1342, 21, 'Create Offsite Portal Credentials'),
(77664, 1343, 21, 'Create Onsite Portal Credentials'),
(77665, 1344, 21, 'إنشاء تقرير عن المريض'),
(77666, 1345, 21, 'Create the SSL Certificate Authority and Server certificates.'),
(77667, 1346, 21, 'إنشاء زيارة'),
(77668, 1347, 21, 'تم'),
(77669, 1348, 21, 'جارِ إنشاء ملف للتصدير'),
(77670, 1350, 21, 'فشل إنشاء الملف'),
(77671, 1351, 21, 'المنشيء'),
(77672, 1352, 21, 'إئتمان'),
(77673, 1353, 21, 'بطاقة الائتمان'),
(77674, 1354, 21, 'اﻹعتمادات'),
(77675, 1356, 21, 'المعايير'),
(77676, 1358, 21, 'داء كرون'),
(77677, 1359, 21, 'داء كرون'),
(77678, 1360, 21, 'تصدير الى ملف CSV'),
(77679, 1361, 21, 'ملف CSV'),
(77680, 1362, 21, 'جداول CSV'),
(77681, 1363, 21, 'مم مكعب'),
(77682, 1364, 21, 'كوبي'),
(77683, 1365, 21, 'اماكن الفاصلة العشرية للعملة'),
(77684, 1366, 21, 'الفاصلة العشرية للعملة'),
(77685, 1367, 21, 'رمز العملة'),
(77686, 1368, 21, 'فاصل الالاف في العملة'),
(77687, 1369, 21, 'الحالي'),
(77688, 1370, 21, 'الكحول الحالي'),
(77689, 1371, 21, 'الاستشارة الحالية'),
(77690, 1372, 21, 'المعايير الحالية'),
(77691, 1373, 21, 'لون التوضيح لليوم الحالي'),
(77692, 1374, 21, 'مدخن يومي'),
(77693, 1375, 21, 'الموقع الحالي'),
(77694, 1376, 21, 'الفاصل الحالي'),
(77695, 1377, 21, 'تغير اسم الملف الحالي إلى'),
(77696, 1378, 21, 'اﻷدوية الحالية'),
(77697, 1379, 21, 'كلمة السر الحالية'),
(77698, 1380, 21, 'المريض الحالي'),
(77699, 1382, 21, 'اﻷدوية الترويحية الحالية'),
(77700, 1383, 21, 'مدخن متقطع'),
(77701, 1386, 21, 'النشط حالياَ'),
(77702, 1387, 21, 'المشغل حالياً'),
(77703, 1388, 21, 'لا توجد مراكز حالياً'),
(77704, 1389, 21, 'متلازمة كوشينغ'),
(77705, 1390, 21, 'متلازمة كوشينغ'),
(77706, 1392, 21, 'عرف'),
(77707, 1393, 21, 'مدخل مخصص؟'),
(77708, 1394, 21, 'جدول مخصص'),
(77709, 1396, 21, 'كود CVX'),
(77710, 1397, 21, 'تخطيط كود CVX'),
(77711, 1398, 21, 'تطعيم CVX'),
(77712, 1399, 21, 'دورة'),
(77713, 1400, 21, 'سيتوكروم بي'),
(77714, 1401, 21, 'معامل سيتوكروم بي'),
(77715, 1402, 21, 'تقرير سيتوكروم بي'),
(77716, 1403, 21, 'تشيكي'),
(77717, 1404, 21, 'د'),
(77718, 1405, 21, 'التوسيع و التجريف'),
(77719, 1406, 21, 'التوسيع و التفريغ'),
(77720, 1407, 21, 'تاريخ الولادة'),
(77721, 1408, 21, 'يومياَ'),
(77722, 1409, 21, 'السجل اليومي'),
(77723, 1410, 21, 'دانماركي'),
(77724, 1411, 21, 'معلومات مشابهة موجودة مسبقا. قم بتغيير المز و/أو الوصف'),
(77725, 1412, 21, 'معلومات مشابهة موجودة مسبقا. قم بتغيير إسم الثابت'),
(77726, 1413, 21, 'أعمدة البيانات'),
(77727, 1416, 21, 'خطأ في البيانات'),
(77728, 1420, 21, 'نوع البيانات'),
(77729, 1421, 21, 'قاعدة البيانات'),
(77730, 1422, 21, 'قاعدة المعلومات غير مثبتة'),
(77731, 1423, 21, 'رقعة برمجية لقاعدة المعلومات'),
(77732, 1424, 21, 'تقرير قاعدة المعلومات'),
(77733, 1425, 21, 'تحيث قاعدة البيانات تم'),
(77734, 1426, 21, 'أعمدة البيانات يجب أن يكون رقم بين 1 و 999'),
(77735, 1427, 21, 'التاريخ'),
(77736, 1428, 21, 'التاريخ'),
(77737, 1429, 21, 'التاريخ و الوقت'),
(77738, 1431, 21, 'تاريخ البدء'),
(77739, 1432, 21, 'تاريخ و وقت جمع العينة'),
(77740, 1433, 21, 'تاريخ و وقت هذه الملاحظة'),
(77741, 1435, 21, 'التاريخ والوقت الذي جمعت فيه العينة'),
(77742, 1436, 21, 'التاريخ لا يمكن ان يتجاوز تاريخ اليوم'),
(77743, 1437, 21, 'تاريخ تقديم خدمة منع الحمل ﻷول بداية'),
(77744, 1438, 21, 'تاريخ اﻹضافة'),
(77745, 1439, 21, 'تاريخ الوفاة'),
(77746, 1440, 21, 'تاريخ اﻹتلاف'),
(77747, 1441, 21, 'طريقة عرض التاريخ'),
(77748, 1442, 21, 'طريقة عرض التاريخ ل "نهاية الموعد" غير صالحة'),
(77749, 1443, 21, 'طريقة عرض التاريخ ل "بداية الموعد" غير صالحة'),
(77750, 1444, 21, 'طريقة عرض التاريخ ل " الموعد القادم" غير صالحة'),
(77751, 1445, 21, 'طريقة عرض التاريخ ل "لم يًشاهد سابقا" غير صالحة'),
(77752, 1446, 21, 'طريقة عرض التاريخ ل "شوهد سابقا" غير صالحة'),
(77753, 1447, 21, 'تاريخ المعلومات الخاصة باللقاحات'),
(77754, 1448, 21, 'غياب تاريخ الرمز '),
(77755, 1449, 21, 'معايير التاريخ الرئيسية'),
(77756, 1450, 21, 'تاريخ الإيداع المصرفي سنة-شهر-يوم'),
(77757, 1451, 21, 'تاريخ الفاتورة'),
(77758, 1452, 21, 'تاريخ الولادة'),
(77759, 1453, 21, 'تاريخ الولادة'),
(77760, 1454, 21, 'تاريخ الميلاد'),
(77761, 1455, 21, 'تاريخ الدخول'),
(77762, 1456, 21, 'تاريخ الأذية'),
(77763, 1458, 21, 'تاريخ الدفع سنة-شهر-يوم'),
(77764, 1459, 21, 'تاريخ الإحالة'),
(77765, 1460, 21, 'تاريخ الرد'),
(77766, 1461, 21, 'تاريخ التقرير'),
(77767, 1462, 21, 'تاريخ الخدمة'),
(77768, 1463, 21, 'تاريخ الخدمة'),
(77769, 1464, 21, 'تاريخ الخدمة = اليوم'),
(77770, 1465, 21, 'تاريخ الخدمة سنة-شهر-يوم'),
(77771, 1466, 21, 'تاريخ الخدمة'),
(77772, 1467, 21, 'تاريخ التوقيع'),
(77773, 1468, 21, 'تاريخ تغيير الحالة'),
(77774, 1469, 21, 'تاريخ هذا اﻷمر'),
(77775, 1470, 21, 'تاريخ هذا التقرير'),
(77776, 1471, 21, 'تاريخ عبارة الزيارة'),
(77777, 1472, 21, 'تاريخ اﻷمر'),
(77778, 1475, 21, 'مختار التاريخ'),
(77779, 1476, 21, 'تاريخ اﻹرسال'),
(77780, 1477, 21, 'تاريخ إرسال الرسالة'),
(77781, 1479, 21, 'قيمة التاريخ لا يمكن ان تكون فارغة'),
(77782, 1480, 21, 'التاريخ/الموعد'),
(77783, 1481, 21, 'التاريخ/الملاحظات'),
(77784, 1482, 21, 'تاريخ/ملاحظات اﻵخر'),
(77785, 1483, 21, 'التاريخ/الوقت'),
(77786, 1484, 21, 'التاريخ'),
(77787, 1485, 21, 'سجل الرسائل المؤرخ'),
(77788, 1486, 21, 'اليوم'),
(77789, 1487, 21, 'يوم'),
(77790, 1489, 21, 'طريقة عرض اليوم'),
(77791, 1490, 21, 'اليوم (الأيام)'),
(77792, 1491, 21, 'اﻷيام (من الأحد إلى الخميس)'),
(77793, 1492, 21, 'الأيام'),
(77794, 1493, 21, 'الأيام'),
(77795, 1494, 21, 'يوما مضى'),
(77796, 1495, 21, 'أيام الغياب'),
(77797, 1496, 21, 'عدد اﻷيام من اخر مراجعة'),
(77798, 1497, 21, 'أيام الغياب'),
(77799, 1498, 21, 'عدد اﻷيام في العمود'),
(77800, 1500, 21, 'أيام في العمود'),
(77801, 1501, 21, 'تنصيب قاعدة البيانات'),
(77802, 1502, 21, 'ي ي/ش ش/س س س س'),
(77803, 1503, 21, 'تعريف'),
(77804, 1504, 21, 'معالجة التعريف انتهت'),
(77805, 1505, 21, 'معالجة التعريف مستمرة'),
(77806, 1506, 21, 'معالجة التعريف بدأت وجاري العمل عليها'),
(77807, 1507, 21, 'تعريف البيانات غير مكتمل'),
(77808, 1508, 21, 'تم حفظ التعريف'),
(77809, 1509, 21, 'رقم وكالة مكافحة المخدرات'),
(77810, 1511, 21, 'أصم'),
(77811, 1512, 21, 'معلومات كشف اﻷخطاء'),
(77812, 1514, 21, 'تصحيح'),
(77813, 1515, 21, 'كانون الأول (ديسمبر)'),
(77814, 1516, 21, 'متوفى'),
(77815, 1517, 21, 'كانون الأول'),
(77816, 1518, 21, 'رقم الرطل و الأونصة'),
(77817, 1520, 21, 'قابل للمراعاة'),
(77818, 1521, 21, 'الأصل'),
(77819, 1522, 21, 'الأصل'),
(77820, 1523, 21, 'الطريقة الأصل لعرض المفكرة'),
(77821, 1524, 21, 'رقم نموذج المراجعة اﻹفتراضي'),
(77822, 1526, 21, 'المؤسسة الأصل'),
(77823, 1527, 21, 'اللغة اﻹفتراضية'),
(77824, 1528, 21, 'اللغة اﻹفتراضية في حال عدم وجود أو عدم اختيار لغة اخرى'),
(77825, 1529, 21, 'القائمة الأصل (كتابة، الإضافة فقط)'),
(77826, 1530, 21, 'الطريقة الأصل'),
(77827, 1531, 21, 'عدد أيام انتهاء صلاحية كلمة السر'),
(77828, 1532, 21, 'فترة إنتهاء فترة صلاحية كلمة السر. 0 يعني ان هذه الميزة غير مفعلة'),
(77829, 1533, 21, 'دولة المريض اﻹفتراضية'),
(77830, 1535, 21, 'الأولوية'),
(77831, 1536, 21, 'المزود اﻹفتراضي'),
(77832, 1537, 21, 'المدى اﻹفتراضي'),
(77833, 1538, 21, 'سبب المراجعة اﻹفتراضي'),
(77834, 1540, 21, 'اﻹعدادات اﻹفتراضية'),
(77835, 1541, 21, 'حالة صندق اﻹختيار اﻹفتراضية في النافذة الجديدة في قائمة المرضى'),
(77836, 1542, 21, 'القالب الأساسي'),
(77837, 1546, 21, 'الوحدات اﻹفتراضية'),
(77838, 1547, 21, 'القيمة اﻹفتراضية'),
(77839, 1548, 21, 'المستودع اﻹفتراضي'),
(77840, 1549, 21, 'شريك X12 اﻹفتراضي'),
(77841, 1550, 21, 'الأساسي/العالمي'),
(77842, 1551, 21, 'حذف'),
(77843, 1552, 21, 'حذف'),
(77844, 1553, 21, 'النكس المتأخر أكثر من اثنتي عشرة شهرا'),
(77845, 1554, 21, 'حذف'),
(77846, 1555, 21, 'حذف'),
(77847, 1556, 21, 'حذف المجموعات ذات الأرقام التالية '),
(77848, 1557, 21, 'حذف الصنف'),
(77849, 1559, 21, 'فشل الحذف'),
(77850, 1560, 21, 'حذف المجموعة'),
(77851, 1561, 21, 'حذف القائمة'),
(77852, 1562, 21, 'حذف الصفحات'),
(77853, 1563, 21, 'حذف المريض، المراجعة، الاستمارة، المشكلة، المستند، الدفع، الفاتورة، التحويل'),
(77854, 1565, 21, 'حذف صف'),
(77855, 1566, 21, 'حذف العنلصر المختارة'),
(77856, 1568, 21, 'حذف ناجح!'),
(77857, 1569, 21, 'حذف هذا المستند'),
(77858, 1570, 21, 'حذف هذه الاستمارة'),
(77859, 1571, 21, 'حذف هذه الملاحظة'),
(77860, 1573, 21, 'تم الحذف بنجاح'),
(77861, 1574, 21, 'جارٍ الحذف'),
(77862, 1575, 21, 'حذف هذا الحدث لا يمكن إسترجاعه. هل أنت متأكد من أنك تريد الحذف؟'),
(77863, 1576, 21, 'تم الإرسال والتسليم'),
(77864, 1578, 21, 'لا يسمح التسليم في الوقت الحالي إلى العنوان المباشر المحدد.'),
(77865, 1580, 21, 'تم طلب توصيل المستند الطبي المرفق من قبل المريض.'),
(77866, 1581, 21, 'العته'),
(77867, 1582, 21, 'المعلومات الشخصية'),
(77868, 1583, 21, 'المعلومات الشخصية'),
(77869, 1585, 21, 'معايير تصفية المعلومات الديموغرافية'),
(77870, 1586, 21, 'المعلومات الشخصية غير متاحة'),
(77871, 1587, 21, 'المعلومات الشخصية غير متاحة'),
(77872, 1588, 21, 'مرفوض'),
(77873, 1589, 21, 'البسط'),
(77874, 1590, 21, 'سني'),
(77875, 1591, 21, 'قائمة مشاكل الأسنان'),
(77876, 1592, 21, 'مشاكل الأسنان'),
(77877, 1595, 21, 'عند إختبار ملف X12 سوف يظهر لك خرج HCFA و الذي يتكون من أسطر عديدة من اللغة المختلطة. لا تقلق فهذة صيغة X12 EDI 4010A.'),
(77878, 1596, 21, 'تاريخ اﻹيداع'),
(77879, 1597, 21, 'تاريخ اﻹيداع لا يمكن أن يكون بعد تاريخ اليوم'),
(77880, 1598, 21, 'تاريخ الإيداع'),
(77881, 1599, 21, 'مكتئب'),
(77882, 1600, 21, 'اكتئاب'),
(77883, 1602, 21, 'الوصف'),
(77884, 1603, 21, 'الوصف'),
(77885, 1605, 21, 'وصف اﻹفصاح'),
(77886, 1606, 21, 'وصف هذه اﻹجراءات أو رمز النتيجة'),
(77887, 1607, 21, 'ترجمة الوصف'),
(77888, 1609, 21, 'الوجهة'),
(77889, 1610, 21, 'إسم الملف الجهة'),
(77890, 1611, 21, 'إتلاف الطرد'),
(77891, 1612, 21, 'متلف'),
(77892, 1613, 21, 'أتلف'),
(77893, 1614, 21, 'متلف'),
(77894, 1615, 21, 'الأدوية التالفة'),
(77895, 1616, 21, 'التفاصيل'),
(77896, 1617, 21, 'التفاصيل'),
(77897, 1619, 21, 'خلل التكون'),
(77898, 1620, 21, 'الداء السكري'),
(77899, 1621, 21, 'الداء السكري'),
(77900, 1622, 21, 'الداء السكري: ضبط ضغط الدم'),
(77901, 1623, 21, 'الداء السكري: فحص العين'),
(77902, 1624, 21, 'الداء السكري: فحص العين'),
(77903, 1625, 21, 'الداء السكري: فحص القدم'),
(77904, 1626, 21, 'الداء السكري: فحص القدم'),
(77905, 1627, 21, 'الداء السكري: ضبط سيئ للخضاب الغلوكوزي'),
(77906, 1628, 21, 'الداء السكري: الخضاب الغلوكوزي'),
(77907, 1629, 21, 'الداء السكري: ضبط الكوليستيرول'),
(77908, 1630, 21, 'الداء السكري: مستوى الألبومين في البول'),
(77909, 1631, 21, 'التشخيص'),
(77910, 1632, 21, 'التشخيص'),
(77911, 1633, 21, 'التشخيص'),
(77912, 1634, 21, 'رمز التشخيص'),
(77913, 1636, 21, 'تاريخ التشخيص'),
(77914, 1637, 21, 'يجب ترميز التشخيص في المراجعة'),
(77915, 1638, 21, 'اسم التشخيص'),
(77916, 1639, 21, 'تقرير التشخيص'),
(77917, 1640, 21, 'اﻹبلاغ عن التشخيص'),
(77918, 1641, 21, 'اﻹبلاغ عن التشخيص فقط'),
(77919, 1642, 21, 'عنوان التشخيص'),
(77920, 1643, 21, 'التشخيص:'),
(77921, 1644, 21, 'التشخيص: '),
(77922, 1645, 21, 'الاختبارات التشخيصية:'),
(77923, 1646, 21, 'جلسات الديال'),
(77924, 1647, 21, 'حجاب / قلنسوة'),
(77925, 1648, 21, 'الإسهال'),
(77926, 1650, 21, 'الإملاء'),
(77927, 1651, 21, 'الإملاء: '),
(77928, 1652, 21, 'هل وصلك نسخة من المؤسسة المسوؤلة عن الصحة والتأمينات'),
(77929, 1653, 21, 'توزيع:'),
(77930, 1654, 21, 'وقع إلكترونياً'),
(77931, 1657, 21, 'بريد مباشر'),
(77932, 1658, 21, 'سجل الرسائل المباشرة'),
(77933, 1659, 21, 'تم استقبال الرسالة المباشرة'),
(77934, 1660, 21, 'الرسالة المباشره غير متوفرة حاليا'),
(77935, 1661, 21, 'تعذر ارسال الرسالة المباشرة'),
(77936, 1663, 21, 'اسم المشرف'),
(77937, 1664, 21, 'تعذر مسح الدليل ; استمرار'),
(77938, 1665, 21, 'الإعاقة'),
(77939, 1667, 21, 'إيقاف التقويم'),
(77940, 1668, 21, 'إيقاف متابعة الملف'),
(77941, 1669, 21, 'إيقاف اللقاحات'),
(77942, 1670, 21, 'إيقاف استمارة العلامات الحياتية المترية القديمة'),
(77943, 1672, 21, 'إيقاف phpMyAdmin'),
(77944, 1673, 21, 'إيقاف الوصفات'),
(77945, 1674, 21, 'إيقاف المجموعات'),
(77946, 1675, 21, 'مُعطّل'),
(77947, 1676, 21, 'مُعطّل'),
(77948, 1677, 21, 'تعطيل المستفيدين لاعمار اقل من ٦٥ سنة'),
(77949, 1678, 21, 'بطاقة ديسكفري اﻹئتمانية'),
(77950, 1681, 21, 'خروج'),
(77951, 1682, 21, 'مفرزات الإحليل'),
(77952, 1684, 21, 'حق الخروج'),
(77953, 1685, 21, 'حق الخروج'),
(77954, 1688, 21, 'تخريج المريض'),
(77955, 1689, 21, 'إفشاء المعلومات'),
(77956, 1690, 21, 'نوع إفشاء المعلومات'),
(77957, 1691, 21, 'أنواع إفشاء المعلومات'),
(77958, 1692, 21, 'الإفصاحات'),
(77959, 1694, 21, 'الحسم'),
(77960, 1695, 21, 'مقدار الحسم'),
(77961, 1696, 21, 'مستوى الحسم'),
(77962, 1697, 21, 'نسبة الحسم'),
(77963, 1698, 21, 'نسبة الحسم النقدي'),
(77964, 1699, 21, 'الحسم النقدي عند الخروج مقابل النسبة المئوية'),
(77965, 1700, 21, 'نتيجة سرية'),
(77966, 1701, 21, 'المرض'),
(77967, 1702, 21, 'الخلع'),
(77968, 1703, 21, 'اصرف #'),
(77969, 1704, 21, 'وزع الوثيقة المتلقية'),
(77970, 1705, 21, 'إرسال المستند المستلم'),
(77971, 1706, 21, 'المصروف'),
(77972, 1707, 21, 'إعرض المجلدت المتقدمة فى صفحة الديمجرافيا'),
(77973, 1709, 21, 'عرض احداث البيانات'),
(77974, 1710, 21, 'عرض تنسيق الاوازن'),
(77975, 1711, 21, 'عرض كم عدد الحدث'),
(77976, 1713, 21, 'عرض المنطقة'),
(77977, 1714, 21, 'عرض الاسم'),
(77978, 1715, 21, 'عرض التاريخ'),
(77979, 1718, 21, 'عرض احداث اليوم'),
(77980, 1719, 21, 'عرض العناوين'),
(77981, 1720, 21, 'عرض الاحداث القادمة'),
(77982, 1721, 21, 'الأعمدة المعروضة'),
(77983, 1722, 21, 'يتم عرض العدد التالي من إفشائات السرية اﻷحدث'),
(77984, 1723, 21, 'يتم عرض العدد التالي من الملاحظات اﻷحدث'),
(77985, 1724, 21, 'يتم عرض العدد التالي من الملاحظات اﻷحدث'),
(77986, 1725, 21, 'التوزع'),
(77987, 1726, 21, 'التوزيعات'),
(77988, 1727, 21, 'موزع'),
(77989, 1729, 21, 'التهاب الرتوج'),
(77990, 1730, 21, 'جراحة الرتوج'),
(77991, 1731, 21, 'التهاب الرتوج'),
(77992, 1732, 21, 'جراحة الرتوج'),
(77993, 1733, 21, 'مطلق'),
(77994, 1734, 21, 'الدوخة:'),
(77995, 1735, 21, 'لا تغير'),
(77996, 1737, 21, 'لاتعرض الحساسية المرفعة ال NewCrop'),
(77997, 1739, 21, 'لاتعرض الأدوية المرفعة ال NewCrop'),
(77998, 1742, 21, 'لاتعرض التاريخ'),
(77999, 1744, 21, 'لا جرد وبيع أي منتجات'),
(78000, 1745, 21, 'لا تستلزم مﻻحظات المريض للإعتماد'),
(78001, 1746, 21, 'توصية آمرة: لاتقم بالإنعاش'),
(78002, 1747, 21, 'لا تحفظ'),
(78003, 1748, 21, 'لا تستبدل الأدوية - اصرف الدواء حسب ما هو مكتوب حرفيا'),
(78004, 1749, 21, 'لا تفعل أي شيئ'),
(78005, 1751, 21, 'هل تريد الحذف؟'),
(78006, 1752, 21, 'هل تريد الحذف؟'),
(78007, 1753, 21, 'هل تريد حذف هذه المجموعة؟'),
(78008, 1755, 21, 'هل تريد أن تستمر؟'),
(78009, 1756, 21, 'هل تريد أن تحذف هذا؟'),
(78010, 1757, 21, 'هل تريد أن تحذف؟'),
(78011, 1758, 21, 'هل تريد أن تزيل هذا السجل؟'),
(78012, 1759, 21, 'هل تريد الاستمرار في إضافة هذا المريض الجديد؟'),
(78013, 1760, 21, 'هل تريد الاستمرار في الاسم الجديد؟'),
(78014, 1761, 21, 'هل تريد الحذف النهائي لهذا السجل الخاص باللقاحات؟'),
(78015, 1762, 21, 'تاريخ الولادة'),
(78016, 1763, 21, 'تاريخ الولادة مفقود، الرجاء إدخاله'),
(78017, 1764, 21, 'المستندات'),
(78018, 1765, 21, 'الطبيب'),
(78019, 1766, 21, 'الطبيب الدكتور'),
(78020, 1767, 21, 'اسم وتوقيع الطبيب'),
(78021, 1768, 21, 'المستند'),
(78022, 1769, 21, 'المستند'),
(78023, 1770, 21, 'مجموعات المستندات'),
(78024, 1775, 21, 'لم يتم نقل المستند إلى ملف المريض'),
(78025, 1777, 21, 'تاريخ المستند'),
(78026, 1778, 21, 'تم تحديث التاريخ و المشكلة'),
(78027, 1779, 21, 'رقم المستند'),
(78028, 1780, 21, 'تم نقل المستند إلى مجموعة جديدة'),
(78029, 1781, 21, 'تم نقل المستند إلى ملف المريض'),
(78030, 1783, 21, 'المستند سليم'),
(78031, 1784, 21, 'طرق تخزين الوثائق'),
(78032, 1785, 21, 'إعادة التسمية ناجحة'),
(78033, 1790, 21, 'مستودع المستندات/الصور'),
(78034, 1791, 21, 'المستدات (كتابة) اختيارية'),
(78035, 1792, 21, 'وثائق (كتابة , )'),
(78036, 1794, 21, 'ضيق النفس الجهدي'),
(78037, 1796, 21, 'لا يطابق رقم الزيارة PV1'),
(78038, 1797, 21, 'لا تبدو صالحة'),
(78039, 1798, 21, 'هل هذا النوع يسمح بالرموز المقاربة؟'),
(78040, 1799, 21, 'شريك في العيش'),
(78041, 1800, 21, 'لا تحفظ'),
(78042, 1801, 21, 'لا تحفظ'),
(78043, 1802, 21, 'لا تحفظ التغييرات'),
(78044, 1803, 21, 'تم'),
(78045, 1804, 21, 'تم بواسطة'),
(78046, 1805, 21, 'تم، سيتم الإرسال'),
(78047, 1806, 21, 'تاريخ بداية الخدمة'),
(78048, 1807, 21, 'الجرعات'),
(78049, 1809, 21, 'انقر لمرتين لبدء التحرير'),
(78050, 1810, 21, 'رؤية مزدوجة'),
(78051, 1811, 21, 'تنزيل'),
(78052, 1814, 21, 'قم بالتنزيل'),
(78053, 1815, 21, 'يت تنزيل ملف الفوترة, ضع فى الحسابات و علّم كمفوتر'),
(78054, 1817, 21, 'تنزيل الترخيص'),
(78055, 1818, 21, 'تنزيل بيانات التكوين'),
(78056, 1820, 21, 'تنزيل ملف مشفر'),
(78057, 1825, 21, 'تنزيل ملف'),
(78058, 1827, 21, 'تنزيل المختارات'),
(78059, 1828, 21, 'شوهد من قبل الطبيب'),
(78060, 1829, 21, 'زيارة الطبيب'),
(78061, 1830, 21, 'الطبيب'),
(78062, 1831, 21, 'اسحب للتحريك'),
(78063, 1832, 21, 'تنقيط البول'),
(78064, 1833, 21, 'إجازة قيادة السيارة/الهوية الوطنية'),
(78065, 1834, 21, 'الدواء'),
(78066, 1835, 21, 'إيجاد الدواء'),
(78067, 1836, 21, 'الأشكال الصيدلانية للدواء'),
(78068, 1837, 21, 'رقم الدواء مفقود'),
(78069, 1838, 21, 'تواتر الدواء'),
(78070, 1839, 21, 'مستودع الأدوية'),
(78071, 1840, 21, 'اسم الدواء'),
(78072, 1841, 21, 'طريقة أخذ الدواء'),
(78073, 1845, 21, 'عيار الدوء'),
(78074, 1846, 21, 'الأدوية'),
(78075, 1847, 21, 'الأدوية والمنتجات الطبية'),
(78076, 1848, 21, 'الفم الجاف'),
(78077, 1849, 21, 'التشخيص حسب " الدليل التشخيصي و الإحصائي-النسخة الرابعة"'),
(78078, 1850, 21, 'الجرعة الأولى للقاح الديفتريا و الكزاز'),
(78079, 1851, 21, 'الجرعة الثانية للقاح الديفتريا و الكزاز'),
(78080, 1852, 21, 'الجرعة الثالثة للقاح الديفتريا و الكزاز'),
(78081, 1853, 21, 'الجرعة الرابعة للقاح الديفتريا و الكزاز'),
(78082, 1854, 21, 'الجرعة الخامسة للقاح الديفتريا و الكزاز'),
(78083, 1855, 21, 'الجرعة الأولى للقاح الديفتريا و الكزاز و السعال الديكي'),
(78084, 1856, 21, 'الجرعة الثانية للقاح الديفتريا و الكزاز و السعال الديكي'),
(78085, 1857, 21, 'الجرعة الثالثة للقاح الديفتريا و الكزاز و السعال الديكي'),
(78086, 1858, 21, 'الجرعة الرابعة للقاح الديفتريا و الكزاز و السعال الديكي'),
(78087, 1859, 21, 'الجرعة الخامسة للقاح الديفتريا و الكزاز و السعال الديكي'),
(78088, 1860, 21, 'المستحق'),
(78089, 1861, 21, 'التاريخ المستحق'),
(78090, 1862, 21, 'التاريخ المستحق ش ش/ي ي/س س س س أو س س س س-ش ش-- ي ي'),
(78091, 1863, 21, 'التاريخ المستحق:'),
(78092, 1864, 21, 'مدخولات مستحقة'),
(78093, 1865, 21, 'مريض مستحق'),
(78094, 1866, 21, 'يستحق قريباَ'),
(78095, 1867, 21, 'حالة الإستحقاق'),
(78096, 1868, 21, 'تحديث حالة الإستحقاق'),
(78097, 1869, 21, 'تفريغ قاعدة بيانات البرنامج'),
(78098, 1870, 21, 'تفريغ شجرة مجلد الأنترنت للبرنامج'),
(78099, 1871, 21, 'تفريغ قاعدة بيانات phpGACL'),
(78100, 1872, 21, 'تفريغ شجرة مجلد الأنترنت لphpGACL'),
(78101, 1873, 21, 'تفريغ قاعدة بيانات SQL-Ledger'),
(78102, 1874, 21, 'تفريغ شجرة مجلد الأنترنت لSQL-Ledger'),
(78103, 1875, 21, 'التأكّد من التفريغ'),
(78104, 1876, 21, 'الهوية مكررة في هذا السطر'),
(78105, 1877, 21, 'الإسم مكرر في هذا السطر'),
(78106, 1878, 21, 'تحذير التكرار'),
(78107, 1879, 21, 'السلطة الممتدة للمحامي'),
(78108, 1880, 21, 'المدة'),
(78109, 1881, 21, 'المدة'),
(78110, 1882, 21, 'هولندي'),
(78111, 1883, 21, 'مندوب مبيعات اﻷدوية'),
(78112, 1884, 21, 'صعوبة البلع'),
(78113, 1885, 21, 'ضيق النفس'),
(78114, 1886, 21, 'عسرة التبول'),
(78115, 1888, 21, 'صرف الوصفة الإلكتروني'),
(78116, 1889, 21, 'التقارير الإلكترونية'),
(78117, 1890, 21, 'صرف الوصفة الإلكتروني'),
(78118, 1892, 21, 'تجديد صرف الوصفة الإلكتروني'),
(78119, 1893, 21, 'كل مستفيد يجب ان يعّلم رسالته الخاصة به كمكتمله'),
(78120, 1894, 21, 'النكس الباكر (في أقل من شهرين'),
(78121, 1895, 21, 'الأذن'),
(78122, 1896, 21, 'تخطيط كهربائية القلب'),
(78123, 1897, 21, 'المطالبات الإلكترونية'),
(78124, 1898, 21, 'الوذمة'),
(78125, 1899, 21, 'تاريخ تبادل المعلومات الإلكتروني'),
(78126, 1900, 21, 'تاريخ تبادل المعلومات الإلكتروني'),
(78127, 1901, 21, 'تاريخ تبادل المعلومات الإلكتروني (لقاء رسوم) لتخزين و تفسير ملفات التأمين'),
(78128, 1902, 21, 'تحميل ملف EDI-271'),
(78129, 1903, 21, 'تحميل ملف تفاعل EDI-271'),
(78130, 1904, 21, 'التحرير'),
(78131, 1905, 21, 'التحرير'),
(78132, 1906, 21, 'تحرير الحساسية'),
(78133, 1907, 21, 'تحرير المجموعات'),
(78134, 1908, 21, 'تحرير التعاريف'),
(78135, 1909, 21, 'تحرير التعاريف'),
(78136, 1910, 21, 'تحرير التشخيص ل'),
(78137, 1911, 21, 'تحرير إفشاء المعلومات'),
(78138, 1912, 21, 'تحرير المراكز الطبية'),
(78139, 1913, 21, 'تحرير المركز الطبي'),
(78140, 1914, 21, 'تحرير معلومات المركز الطبي'),
(78141, 1915, 21, 'تحرير معلومات المستخدم الخاص فى المنشأة'),
(78142, 1916, 21, 'تحرير الملف في'),
(78143, 1917, 21, 'تحرير الاستمارة'),
(78144, 1918, 21, 'تحرير الإعدادات الأساسية'),
(78145, 1919, 21, ' تحرير المحتوى غير مسموح  '),
(78146, 1920, 21, 'تحرير طريقة العرض'),
(78147, 1921, 21, 'تحرير القائمة'),
(78148, 1922, 21, 'تحرير عملية الدفع'),
(78149, 1923, 21, 'تحرير التركيب'),
(78150, 1924, 21, 'تحرير مستخدم'),
(78151, 1925, 21, 'تحرير إعدادات المستخدم'),
(78152, 1928, 21, 'التعليم/ التوعية'),
(78153, 1929, 21, 'تاريخ التعليم'),
(78154, 1931, 21, 'ee the * GNU General Public License for more details. * * You should have received a copy of the GNU General Public License * along with this program; if not, write to the Free '),
(78155, 1932, 21, 'التاريخ المؤكد'),
(78156, 1934, 21, 'الفعالية'),
(78157, 1935, 21, 'رقم هوية الموظف'),
(78158, 1936, 21, 'الدفقات'),
(78159, 1937, 21, 'المرفق'),
(78160, 1938, 21, 'مشاكل المرفق'),
(78161, 1939, 21, 'إلكتروني'),
(78162, 1942, 21, 'إحالة إلكترونية'),
(78163, 1943, 21, 'تقرير إلكتروني'),
(78164, 1944, 21, 'أهليّة'),
(78165, 1945, 21, '270 Inquiry Batch أهليّة'),
(78166, 1946, 21, 'رّد الأهليّة'),
(78167, 1947, 21, 'حالة الأهلية للحصول على لقاح الأطفال المتوفر'),
(78168, 1948, 21, 'مسموح له'),
(78169, 1949, 21, 'البريد الإلكتروني / إيميل'),
(78170, 1951, 21, 'البريد الإلكتروني / إيميل'),
(78171, 1953, 21, 'إيميل المرسل لتذكيرات المرضي و الذي سيتلقى الردود أيضا. من المهم ان يكون الإيميل نابعا من موقع المنشأة لتفدي ذهاب التذكيرات لملف المهملات فى ايميل المتلقي'),
(78172, 1954, 21, 'البريد الإلكتروني / إيميل لإستلام تنبيهات الإدارة'),
(78173, 1955, 21, 'البريد الإلكتروني / إيميل لإستلام رسائل تفعيل ولوج المستخدمين الطارئة'),
(78174, 1956, 21, 'سلطة الإيميل'),
(78175, 1957, 21, 'إيميل Batchcom'),
(78176, 1958, 21, 'اخطار بالبريد الالكتروني'),
(78177, 1959, 21, 'البريد الإلكتروني الإخطار ساعات'),
(78178, 1960, 21, 'تقرير بااخطار البريد الالكتروني'),
(78179, 1961, 21, 'البريد الإلكتروني المرسلة من قبل');
INSERT INTO `lang_definitions` VALUES
(78180, 1962, 21, 'مُرسل البريد'),
(78181, 1963, 21, 'تم الإرسال'),
(78182, 1964, 21, 'تم إرسال البريد الى'),
(78183, 1965, 21, 'عنوان البريد'),
(78184, 1966, 21, 'Email Text, Usable Tag: ***NAME*** , i.e. Dear ***NAME***'),
(78185, 1967, 21, 'Email Text, Usable Tag: ***NAME*** , i.e. Dear ***NAME***{{Do Not translate the ***NAME*** elements of this constant.}}'),
(78186, 1968, 21, 'طريقة نقل الإيميل'),
(78187, 1969, 21, 'تم إرسال البريد إلى العنوان التالي'),
(78188, 1971, 21, 'الشخص القريب عند الحالات الطارئة'),
(78189, 1972, 21, 'اسم الشخص في الحالات الطارئة'),
(78190, 1973, 21, 'رقم الهاتف في الحالات الطارئة'),
(78191, 1974, 21, 'منع الحمل السريع'),
(78192, 1975, 21, 'الدخول الطارئ في النظام'),
(78193, 1976, 21, 'Emergency Login ACL is chosen. The user is still in active state, please de-activate the user and activate the same when required during emergency situations. Visit Administration->Users for activation or de-activation.'),
(78194, 1977, 21, 'Emergency Login activation email will be circulated only if following settings in the interface/globals.php file are configured:'),
(78195, 1978, 21, 'البريد في الحالات الطارئة'),
(78196, 1979, 21, 'الدخول الطارئ كامل الصلاحية'),
(78197, 1980, 21, 'الهاتف في حالة طارئة'),
(78198, 1981, 21, 'عاطفي/حالات و مضاعفات سلوكية'),
(78199, 1982, 21, 'النفاخ الرئوي'),
(78200, 1983, 21, 'الموظف'),
(78201, 1984, 21, 'رب العمل'),
(78202, 1985, 21, 'عنوان العمل'),
(78203, 1986, 21, 'معلومات العمل'),
(78204, 1987, 21, 'اسم صاحب العمل'),
(78205, 1988, 21, 'فارغ'),
(78206, 1989, 21, 'فارغ'),
(78207, 1990, 21, 'حقل الرقم السري لايمكن ان يكون فارغ'),
(78208, 1991, 21, '"فارغة" ساعات البريد'),
(78209, 1992, 21, '"فارغة" المرسل'),
(78210, 1993, 21, '"فارغة " الموضوع'),
(78211, 1994, 21, '"فارغة" النص'),
(78212, 1995, 21, '"فارغة" اسم المؤسسة'),
(78213, 1996, 21, '"فارغة" الرقم السري'),
(78214, 1997, 21, 'قيمة فارغة في "ساعات SMS"'),
(78215, 1998, 21, 'قيمة فارغة في "نص SMS"'),
(78216, 1999, 21, 'قيمة فارغة في "اسم المستخدم"'),
(78217, 2006, 21, 'فعّل تحفيز AMC'),
(78218, 2008, 21, 'فعّل تقرير AMC'),
(78219, 2009, 21, 'فعّل تتبع AMC'),
(78220, 2011, 21, 'فعّل تدقيق ATNA'),
(78221, 2013, 21, 'فعّل ولوج التدقيق'),
(78222, 2014, 21, 'فعّل تتبع التدقيق و صلاحية العقدة (ATNA)'),
(78223, 2015, 21, 'فعّل تقرير قياس الحسابات الألي (AMC)'),
(78224, 2016, 21, 'فعّل عميل SLL'),
(78225, 2017, 21, 'فعّل توثيق شهادة عميل SLL'),
(78226, 2019, 21, 'فعّل قواعد القرارات الإكلينكية'),
(78227, 2022, 21, 'فعّل تقرير مقياس النوعية الإكلينكية'),
(78228, 2023, 21, 'فعّل نافذة منبثقة للتذكير الإكلينكي'),
(78229, 2024, 21, 'فعّل اداة للتذكير الإكلينكي'),
(78230, 2027, 21, 'فعّل تقرير CQM'),
(78231, 2028, 21, 'فعّل تاريخ EDI في القائمة اليسري'),
(78232, 2030, 21, 'فعّل المصاريف في القائمة اليسري'),
(78233, 2031, 21, 'فعّل دعم Hylafax'),
(78234, 2033, 21, 'فعّل حالة الإستيراد NewCrop erx'),
(78235, 2037, 21, 'فعّل تبادل المعمل'),
(78236, 2039, 21, 'فعّل السجل لترفيع او تنزيل الوثائق الي'),
(78237, 2040, 21, 'فعّل الولوج لكل استفهامات SQL SELECT'),
(78238, 2041, 21, 'فعّل الولوج للنشاطات المتعلقة بالنسخ الإحتياطي'),
(78239, 2042, 21, 'فعّل الولوج لكل استفهامات CDR Engine'),
(78240, 2043, 21, 'فعّل الولوج للنشاطات المتفرقة'),
(78241, 2044, 21, 'فعّل الولوج لنشاطات الطلب'),
(78242, 2045, 21, 'فعّل الولوج لتعديلات سجل المريض'),
(78243, 2046, 21, 'فعّل الولوج لنشاطات جدولة المواعيد'),
(78244, 2047, 21, 'فعّل الولوج لنشاطات الحماية و الإدارة'),
(78245, 2049, 21, 'فعّل خدمة NewCrop eRx'),
(78246, 2051, 21, 'فعّل بوابة المريض خارج الموقع'),
(78247, 2052, 21, 'فعّل بوابة المريض خارج الموقع'),
(78248, 2053, 21, 'فعّل بوابة المريض داخل الموقع'),
(78249, 2055, 21, 'فعّل بوابة المريض داخل الموقع'),
(78250, 2056, 21, 'فعّل اداة تذكير المريض'),
(78251, 2057, 21, 'فعّل خدمة phiMail للإرسال المباشر'),
(78252, 2058, 21, 'فعّل تحفيز البيانات المطلوبة لقياس الحسابات الألي (AMC)'),
(78253, 2060, 21, 'فعّل التقرير لتتبع اليوم لقياس الحسابات الألي (AMC)'),
(78254, 2061, 21, 'فعّل دعم الماسح الضوئي'),
(78255, 2064, 21, 'فعّل دمج المعلومات الطبية, خدمة تبادل المعمل LLC'),
(78256, 2065, 21, 'فعّل دعم البرنامج لخدمة تبادل المعمل LLC'),
(78257, 2066, 21, 'فعّل تفقد صلاحية شهادة المستخدم'),
(78258, 2067, 21, 'فعّل ZMG, LLC eRx service'),
(78259, 2068, 21, 'مُفعّل'),
(78260, 2070, 21, 'يفعّل لوحة التكاليف القديمة لإدخال رموز الفوترة و الدفعات. لا ينصح به, استخدم شريحة الاجور بدلا'),
(78261, 2071, 21, 'الزيارة'),
(78262, 2072, 21, 'الزيارة'),
(78263, 2073, 21, 'الزيارة'),
(78264, 2074, 21, 'الزيارة'),
(78265, 2075, 21, 'الزيارة '),
(78266, 2076, 21, 'الزيارة الحرجة لمريض داخلي او قسم الطوارئ'),
(78267, 2081, 21, 'تاريخ الزيارة'),
(78268, 2084, 21, 'سجل تبادل المعلومات الإلكتروني للزيارة'),
(78269, 2086, 21, 'استمارات الزيارة'),
(78270, 2087, 21, 'التقييم الصحي و السلوكي للزبارة'),
(78271, 2088, 21, 'التاريخ المرضي'),
(78272, 2089, 21, 'رقم معرف الزيارة'),
(78273, 2090, 21, 'زيارة انفلونزا'),
(78274, 2091, 21, 'رقم الزيارة'),
(78275, 2093, 21, 'الخروج من زيارة التمريض'),
(78276, 2094, 21, 'زيارة منشأة التمريض'),
(78277, 2095, 21, 'زيارة العلاج الوظيفي'),
(78278, 2096, 21, 'زيارة العيادة'),
(78279, 2097, 21, 'زيارة العيادات الخارجية'),
(78280, 2098, 21, 'زيارة العيادات الخارجية لطب اﻷسرة او النساء و الولادة'),
(78281, 2099, 21, 'حجم صفحة الزيارة'),
(78282, 2100, 21, 'المستحقات المالية للزيارة'),
(78283, 2101, 21, 'زيارة حمل'),
(78284, 2102, 21, 'زيارة الطب الوقائي - استشاره فرديه'),
(78285, 2103, 21, 'زيارة الطب الوقائي - ٤٠ سنه فمافوق'),
(78286, 2104, 21, 'زيارة الطب الوقائي - استشاره جماعيه'),
(78287, 2105, 21, 'زيارة الطب الوقائي - خدمات اخري'),
(78288, 2106, 21, 'زيارة الطب الوقائي - ١٨ سنه فمافوق'),
(78289, 2107, 21, 'زيارة الطب النفسي'),
(78290, 2108, 21, 'إحصائيات الزيارة'),
(78291, 2109, 21, 'ملخص الزيارة'),
(78292, 2110, 21, 'تم حفظ الزيارة'),
(78293, 2111, 21, 'الزيارة:'),
(78294, 2112, 21, 'الزيارة: زيارة لحالة غير حرجة داخلي , خارجي او عيون'),
(78295, 2113, 21, 'الزيارات'),
(78296, 2114, 21, 'الزيارات و الاستمارات'),
(78297, 2115, 21, 'الزيارات و الاستمارات'),
(78298, 2116, 21, 'الزيارة عير مصرح بها'),
(78299, 2117, 21, 'تقرير الزيارة'),
(78300, 2118, 21, 'قسم الزيارة'),
(78301, 2120, 21, 'التشفير'),
(78302, 2121, 21, 'نهاية'),
(78303, 2122, 21, 'تاريخ اﻹنتهاء: (سنة-شهر-يوم) '),
(78304, 2123, 21, 'تاريخ اﻹنتهاء'),
(78305, 2124, 21, 'تاريخ اﻹنتهاء'),
(78306, 2126, 21, 'تاريخ اﻹنتهاء يجب أن يكون أبعد من تاريخ البدء'),
(78307, 2127, 21, 'تاريخ اﻹنتهاء:'),
(78308, 2131, 21, 'وقت اﻹنتهاء'),
(78309, 2132, 21, 'مستفيد MCP بخطة تأمينيه جماعية فى المراحل اﻷخيرة من الفشل الكلوي'),
(78310, 2133, 21, 'تاريخ انتهاء الخدمة سنة-شهر-يوم'),
(78311, 2134, 21, 'إنهاء موجه الاوامر شهر/يوم/سنة إذا كنت ترغب في إدخال نطاق'),
(78312, 2135, 21, 'أخر ساعة عمل يومي لأحداث الروزنامة'),
(78313, 2136, 21, 'وجود دم غير طبيعي بالتنظير'),
(78314, 2137, 21, 'الغدد الصماء'),
(78315, 2138, 21, 'التنظير'),
(78316, 2141, 21, 'الإنجليزية'),
(78317, 2142, 21, 'الإنجليزية '),
(78318, 2143, 21, 'الإنجليزية الهند'),
(78319, 2144, 21, 'الإنجليزية'),
(78320, 2145, 21, 'أمر Enscript مستخدم بواسطة Hylafax'),
(78321, 2146, 21, 'تأكد من أن البرنامج يملك صلاحية الكتابة للمجلد'),
(78322, 2147, 21, 'إفرازات في الأذن, الأنف. الحنجرة'),
(78323, 2148, 21, 'ألم في الأذن, الأنف, الحنجرة'),
(78324, 2149, 21, 'ادخل رمز التشخيص لإستبعاد كل الفواتير التي لا تحتويه'),
(78325, 2151, 21, 'أدخل جسد الرسالة هنا'),
(78326, 2152, 21, 'أدخل كلمة سر الجذر لقاعدة البيانات'),
(78327, 2153, 21, 'أدخل إسم المستخدم الجذر لقاعدة البيانات'),
(78328, 2154, 21, 'أدخل التشخيص'),
(78329, 2155, 21, 'أدخل الأدوية'),
(78330, 2156, 21, 'أدخل الزيارة'),
(78331, 2157, 21, 'أدخل رقم الزيارة'),
(78332, 2158, 21, 'أدخل التطعيمات'),
(78333, 2159, 21, 'زر الإدخال'),
(78334, 2161, 21, 'ادخل حالة جديدة'),
(78335, 2162, 21, 'أدخل عنوان المستلم المباشر'),
(78336, 2164, 21, 'أدخل رمز إعادة التعريف'),
(78337, 2165, 21, 'أدخل معايير البحث أعلاه'),
(78338, 2166, 21, 'تم الإدخال بالخطأ'),
(78339, 2167, 21, 'تدوينات'),
(78340, 2168, 21, 'بيئي'),
(78341, 2169, 21, 'إدخال بيانات وثيقة شرح الإستفادة التأمينية'),
(78342, 2170, 21, 'التحويلات البنكية الإلكترونية - وثيقة شرح الإستفادة التأمينية'),
(78343, 2171, 21, 'التعليمات - وثيقة شرح الإستفادة التأمينية'),
(78344, 2172, 21, 'الإيصال - وثيقة شرح الإستفادة التأمينية'),
(78345, 2173, 21, 'ملاحظة المريض - وثيقة شرح الإستفادة التأمينية'),
(78346, 2174, 21, 'البحث - وثيقة شرح الإستفادة التأمينية'),
(78347, 2176, 21, 'صرع'),
(78348, 2178, 21, 'التقاعد المبكّر'),
(78349, 2179, 21, 'ملفات التقاعد المبكّر'),
(78350, 2180, 21, 'إعلام التقاعد المبكّر'),
(78351, 2181, 21, 'مسح'),
(78352, 2182, 21, 'إنتصابات'),
(78353, 2183, 21, 'خطأ'),
(78354, 2185, 21, 'خطأ في تأكيد إستلام نتائج المختبر'),
(78355, 2187, 21, 'خطأ في إستلام نتائج المختبر من شبكة تبادل المختبر'),
(78356, 2188, 21, 'خطأ في إختيار "نوع الجنس"'),
(78357, 2189, 21, 'خطأ في إختيار "HIPPA"'),
(78358, 2190, 21, 'خطأ في إختيار "الإجراء"'),
(78359, 2191, 21, 'خطأ في اختيار "بوابة الرسائل النصية القصيرة"'),
(78360, 2192, 21, 'خطأ في اختيار "الفرز حسب"'),
(78361, 2193, 21, 'خطأ في عملية ضغط الملف: '),
(78362, 2194, 21, 'خطأ في إختيار نعم أو لا'),
(78363, 2195, 21, 'خطأ في فتح الملف المحمل للقراءة'),
(78364, 2196, 21, 'خطأ في معالجة الملف'),
(78365, 2197, 21, 'خطأ في تحميل الملف'),
(78366, 2198, 21, 'خطأ في ازالة الرسالة'),
(78367, 2199, 21, 'خطأ  في استرجاع النتائج من شبكة المختبر'),
(78368, 2200, 21, 'خطأ في استرجاع القيم'),
(78369, 2202, 21, 'خطأ فى إعطاء صلاحيات الملفات للمستخدم'),
(78370, 2205, 21, 'خطأ خلال قت تسجيل النموذج!'),
(78371, 2206, 21, 'خطأ خلال مرحلة حفظ الملف'),
(78372, 2208, 21, 'خطأ خلال مرحلة الكتابة في الملف'),
(78373, 2209, 21, 'خطأ او أخطاء ناتجة من النتائج الجديدة'),
(78374, 2210, 21, 'خطأ, الملف غير موجود'),
(78375, 2211, 21, 'خطأ, غير قادرعلى جمع البيانات من الخادم'),
(78376, 2212, 21, 'خطأ، غير قادر علي إنشاء شهادة للعميل'),
(78377, 2213, 21, 'خطأ، غير قادر علي إنشاء شهادة admin.p12'),
(78378, 2214, 21, 'خطأ، غير قادر علي إنشاء شهادة لشهادة السلطة'),
(78379, 2215, 21, 'خطأ، غير قادر علي إنشاء شهادة للخادم'),
(78380, 2216, 21, 'خطأ, لايمكن فتح الملف'),
(78381, 2217, 21, 'خطأ, التأكد من شهادة المستخدم غير مفعّل فى البرنامج'),
(78382, 2218, 21, 'خطأ, يجب أن تثّبت جزء Archive/Tar.php php'),
(78383, 2219, 21, 'خطأ, لايمكن فتح table.sql, الطلب معطوب؟'),
(78384, 2220, 21, 'خطأ, رقم هوية مكررة'),
(78385, 2221, 21, 'خطأ, أسم مكرر في نفس الخط'),
(78386, 2222, 21, 'خطأ: حقل'),
(78387, 2223, 21, 'خطأ, ملف ZipArchive PHP Module غير موجود'),
(78388, 2224, 21, 'خطأ: مجلد إستيراد ICD غير موجود'),
(78389, 2225, 21, 'خطأ: الإرقام السرية غير مطابقة. فضلاً تأكد من الكتابة'),
(78390, 2226, 21, 'خطأ: الإرقام السرية غير مطابقة. فضلاً تأكد من الكتابة'),
(78391, 2227, 21, 'خطأ: الملف غير موجود'),
(78392, 2228, 21, 'خطأ: المتغيرات التالية تحتوي على رموز خاطئة'),
(78393, 2229, 21, 'خطأ: غير قادر على نسخ الملف'),
(78394, 2230, 21, 'خطأ: غير قادر على تكوين الملف القابل للتنزيل'),
(78395, 2231, 21, 'خطأ: غير قادر على تكوين الملف المضغوط'),
(78396, 2232, 21, 'خطأ: غير قادر على استخراج الملف'),
(78397, 2233, 21, 'خطأ: غير قادر على تحميل الملف على قاعدة البيانات'),
(78398, 2234, 21, 'خطأ: غير قادر على وضع رقم الأصدار'),
(78399, 2235, 21, 'أخطاء'),
(78400, 2236, 21, 'حالة حساب الوصف الإلكتروني'),
(78401, 2237, 21, 'سجل الوصف الإلكتروني'),
(78402, 2238, 21, 'إسم الوصفة الإلكترونية'),
(78403, 2239, 21, 'كلمة سر الوصفة الإلكترونية'),
(78404, 2240, 21, 'دور الوصفة الإلكترونية'),
(78405, 2241, 21, 'مستخدم الوصفة الإلكترونية'),
(78406, 2242, 21, 'احمرار'),
(78407, 2245, 21, 'الاسكيمو'),
(78408, 2247, 21, 'مريض دائم'),
(78409, 2248, 21, 'إستوني'),
(78410, 2249, 21, 'العرقية'),
(78411, 2250, 21, 'العرقية'),
(78412, 2251, 21, 'قائمة العرقية (اكتب, الإضافة اختيارية)'),
(78413, 2252, 21, 'رقم هوية دافع الضرائب الإلكتروني'),
(78414, 2253, 21, 'الحدث'),
(78415, 2254, 21, 'بدء الحدث'),
(78416, 2255, 21, 'مجموعة الحدث'),
(78417, 2256, 21, 'تاريخ الحدث'),
(78418, 2257, 21, 'وصف الحدث'),
(78419, 2258, 21, 'تفاصيل الحدث'),
(78420, 2259, 21, 'الحدث لا يتكرر'),
(78421, 2260, 21, 'مدة الحدث'),
(78422, 2261, 21, 'مدة الحدث بالدقائق'),
(78423, 2262, 21, 'كلفة الحدث'),
(78424, 2263, 21, 'مكان الحدث'),
(78425, 2264, 21, 'الحدث يتكرر كل'),
(78426, 2265, 21, 'الحدث يتكرر في'),
(78427, 2266, 21, 'الحدث بدأ الساعة'),
(78428, 2267, 21, 'عنوان الحدث'),
(78429, 2268, 21, 'عنوان الحدث'),
(78430, 2269, 21, 'موقع الحدث'),
(78431, 2270, 21, 'الأحداث'),
(78432, 2271, 21, 'الأحداث ل'),
(78433, 2272, 21, 'إفتح الأحداث فى نافذة جديدة'),
(78434, 2273, 21, 'كل'),
(78435, 2274, 21, 'كل'),
(78436, 2275, 21, 'كل 3 ساعات'),
(78437, 2276, 21, 'كل 4 ساعات'),
(78438, 2277, 21, 'كل 5 ساعات'),
(78439, 2278, 21, 'كل 6 ساعات'),
(78440, 2279, 21, 'كل 8 ساعات'),
(78441, 2280, 21, 'كل رابع'),
(78442, 2281, 21, 'كل تالِ'),
(78443, 2282, 21, 'كل ثالث'),
(78444, 2283, 21, 'كل، كل يوم آخر'),
(78445, 2285, 21, 'نتائج الفحص و التحاليل'),
(78446, 2286, 21, 'نتائج التحاليل'),
(78447, 2289, 21, 'الفحص'),
(78448, 2290, 21, 'تاريخ الفحص'),
(78449, 2291, 21, 'مثال'),
(78450, 2292, 21, 'أمثلة'),
(78451, 2293, 21, 'الفحص/الاختبارات'),
(78452, 2294, 21, 'ماعدا'),
(78453, 2295, 21, 'تمزق شديد'),
(78454, 2296, 21, 'المرضى الاستثناء'),
(78455, 2297, 21, 'الاستثناء'),
(78456, 2298, 21, 'منظمة مزودة حصرية'),
(78457, 2299, 21, 'حجم الورق التنفيذي'),
(78458, 2300, 21, 'التمرين'),
(78459, 2301, 21, 'نماذج التمرين'),
(78460, 2302, 21, 'نماذج التمرين'),
(78461, 2303, 21, 'الخروج'),
(78462, 2304, 21, 'الخروج من الإدارة'),
(78463, 2305, 21, 'مد'),
(78464, 2306, 21, 'مد'),
(78465, 2307, 21, 'مد'),
(78466, 2308, 21, 'مد الكل'),
(78467, 2311, 21, 'مشاهدة موسعة'),
(78468, 2312, 21, 'Expected form_encounter.pid to be '),
(78469, 2313, 21, 'إنتهاء الأجل'),
(78470, 2314, 21, 'تاريخ الإنتهاء'),
(78471, 2315, 21, 'ينتهي'),
(78472, 2316, 21, 'ينتهي في'),
(78473, 2317, 21, 'تصدير'),
(78474, 2318, 21, 'تصدير بصيغة  CSV'),
(78475, 2319, 21, 'هيئة التصدير'),
(78476, 2322, 21, 'تصدير بيانات المريض الديموغرافية'),
(78477, 2323, 21, 'تصدير تقريرPQRI'),
(78478, 2325, 21, 'تصدير المقتطفات'),
(78479, 2326, 21, 'تصدير الاختيارات الى التحصيل'),
(78480, 2327, 21, 'تصدير الى CSV'),
(78481, 2328, 21, 'تصدير الى نظام الفواتير الخارجي'),
(78482, 2329, 21, 'زيارة بلدان أخرى'),
(78483, 2330, 21, 'زيارة بلدان أخرى'),
(78484, 2331, 21, 'تم جمع وقت Ext'),
(78485, 2332, 21, 'خارجي'),
(78486, 2334, 21, 'تحميل البيانات الخارجية'),
(78487, 2335, 21, 'أداة إستيراد قاعدة البيانات الخارجية'),
(78488, 2336, 21, 'هوية خارجية'),
(78489, 2337, 21, 'رقم خارجي'),
(78490, 2338, 21, 'هوية خارجية'),
(78491, 2339, 21, 'خارجي فقط'),
(78492, 2342, 21, 'إحالة خارجية'),
(78493, 2343, 21, 'متابعة الإحالة الخارجية'),
(78494, 2344, 21, 'إحالة خارجية؟'),
(78495, 2345, 21, 'الإحالات الخارجية'),
(78496, 2346, 21, 'فك الملف المضغوط'),
(78497, 2347, 21, 'فك الملف المضغوط، قد يأخذ بعض الوقت'),
(78498, 2348, 21, 'نتحة قيحية:'),
(78499, 2349, 21, 'إجهاد العين'),
(78500, 2350, 21, 'ألم العين'),
(78501, 2351, 21, 'احمرار العين'),
(78502, 2352, 21, 'العينين'),
(78503, 2353, 21, 'أنثى'),
(78504, 2354, 21, 'قصة عائلية: مشاكل دم'),
(78505, 2355, 21, 'قصة عائلية: شعرانية/فزر'),
(78506, 2356, 21, 'المنشآت'),
(78507, 2357, 21, 'المنشأة'),
(78508, 2358, 21, 'المنشأة'),
(78509, 2359, 21, 'إدارة المنشأة'),
(78510, 2360, 21, 'مدينة المنشأة'),
(78511, 2361, 21, 'رمز المنشأة'),
(78512, 2362, 21, 'رمز دولة المنشأة'),
(78513, 2363, 21, 'فاكس المنشأة'),
(78514, 2364, 21, 'إسم المنشأة'),
(78515, 2365, 21, 'رقم تعريف المنشأة الوطني'),
(78516, 2366, 21, 'هاتف المنشأة'),
(78517, 2367, 21, 'معلومات المستخدم الخاصة بالمنشأة'),
(78518, 2368, 21, 'ولاية المنشأة'),
(78519, 2369, 21, 'شارع المنشأة'),
(78520, 2370, 21, 'الرمز البريدي للمنشأة'),
(78521, 2372, 21, 'المنشأة:'),
(78522, 2373, 21, 'فشل'),
(78523, 2374, 21, 'فاشل'),
(78524, 2375, 21, 'فاشل'),
(78525, 2380, 21, 'فشل في إنشاء ملف مؤقت . CouchDB لن يعمل'),
(78526, 2382, 21, 'فشل'),
(78527, 2383, 21, 'فشل و قصور'),
(78528, 2390, 21, 'القصة العائلية'),
(78529, 2391, 21, 'القصة العائلية للجلوكوما'),
(78530, 2392, 21, 'القصة العائلية'),
(78531, 2394, 21, 'سداد العائلة'),
(78532, 2395, 21, 'حجم العائلة'),
(78533, 2396, 21, 'فاخر'),
(78534, 2398, 21, 'فارسى'),
(78535, 2400, 21, 'الأب'),
(78536, 2402, 21, 'الإرهاق'),
(78537, 2403, 21, 'مرهق'),
(78538, 2404, 21, 'الفاكس'),
(78539, 2405, 21, 'تعداد الفاكس'),
(78540, 2406, 21, 'رقم الفاكس'),
(78541, 2408, 21, 'الفاكس / المسح'),
(78542, 2409, 21, 'الفاكس الوارد'),
(78543, 2410, 21, 'الفاكس الصادر'),
(78544, 2411, 21, 'المميزات'),
(78545, 2412, 21, 'فبراير/شباط'),
(78546, 2413, 21, 'فبراير/شباط'),
(78547, 2414, 21, 'قانون تعويض الموظفين الفيدرالي'),
(78548, 2415, 21, 'رقم الدواء'),
(78549, 2416, 21, 'الرقم الحكومي التعريفي بالجهة الموظفة'),
(78550, 2417, 21, 'الرقم الضريبي'),
(78551, 2418, 21, 'التكلفة'),
(78552, 2419, 21, 'التكلفة'),
(78553, 2420, 21, 'التكلفة غير مسموح بها'),
(78554, 2421, 21, 'صفحة التكاليف'),
(78555, 2422, 21, 'خيارات صفحة التكاليف'),
(78556, 2423, 21, 'التكاليف'),
(78557, 2424, 21, 'أنثى'),
(78558, 2425, 21, 'مسحة باب غير طبيعية للإنثي'),
(78559, 2426, 21, 'واق نسائي'),
(78560, 2427, 21, 'تناسلية نسائية'),
(78561, 2428, 21, 'تاريخ اخر حمل'),
(78562, 2429, 21, 'حوضي نسائي'),
(78563, 2430, 21, 'أعراض نسائية'),
(78564, 2431, 21, 'منع الحمل الجراحي الطوعى للإنثي'),
(78565, 2434, 21, 'الحمى'),
(78566, 2435, 21, 'الحمى'),
(78567, 2436, 21, 'قصة عائلية لمرض دموي'),
(78568, 2437, 21, 'أورام ليفية سليمة'),
(78569, 2441, 21, 'نوع الحقل لإستخدامه لدولة الموظف فى الديموجرافيا'),
(78570, 2442, 21, 'نوع الحقل لإستخدامه لولاية الموظف فى الديموجرافيا'),
(78571, 2443, 21, 'يجب إكمال الحقول الفارغة!'),
(78572, 2447, 21, 'الملف'),
(78573, 2448, 21, 'file in the Documentation directory to learn how to automate the process of creating log backups'),
(78574, 2449, 21, 'موقع الملف'),
(78575, 2450, 21, 'أدارة الملفات'),
(78576, 2453, 21, 'صلاحيات الملف تعطى لمسخدم الملف الالكتروني'),
(78577, 2454, 21, 'فشل أسترجاع الملف من CouchDB'),
(78578, 2455, 21, 'غرفة الملفات'),
(78579, 2456, 21, 'الملف للتحميل'),
(78580, 2457, 21, 'الملف للتحميل'),
(78581, 2458, 21, 'يوجد ملف بالاسم نفسه في الموقع'),
(78582, 2459, 21, 'اسم الملف'),
(78583, 2461, 21, 'الملفات'),
(78584, 2462, 21, 'فليبني'),
(78585, 2463, 21, 'املأ الفراغ التالي'),
(78586, 2464, 21, 'املأ هنا عند إرسال رسالة للمرضى فقط'),
(78587, 2465, 21, 'املأ فيما يلي'),
(78588, 2467, 21, 'املأ فيما يلي'),
(78589, 2468, 21, 'تصفية'),
(78590, 2469, 21, 'التصفية'),
(78591, 2470, 21, 'ترتيبت حسب التعاريف'),
(78592, 2471, 21, 'مصفى من'),
(78593, 2472, 21, 'التصفية'),
(78594, 2473, 21, 'التصفية'),
(78595, 2474, 21, 'النهائي'),
(78596, 2475, 21, 'التشخيص النهائي'),
(78597, 2476, 21, 'التشخيص النهائي من قبل اختصاصي'),
(78598, 2478, 21, 'المالي'),
(78599, 2479, 21, 'نهاية العام المالي'),
(78600, 2480, 21, 'التقرير المالي'),
(78601, 2481, 21, 'التقرير المالي - الحالات الخاصة'),
(78602, 2482, 21, 'تاريخ مراجعة الحسابات'),
(78603, 2483, 21, 'الملخص المالي حسب رمز الخدمة'),
(78604, 2484, 21, 'البحث'),
(78605, 2485, 21, 'البحث عن المتوفر'),
(78606, 2486, 21, 'ابحث عن المواعيد المتوفرة'),
(78607, 2487, 21, 'ابحث عن مريض'),
(78608, 2488, 21, 'ابحث عن مواد توعية المريض'),
(78609, 2489, 21, 'الموجودات'),
(78610, 2490, 21, 'الموجودات من قبل اختصاصي'),
(78611, 2491, 21, 'ناعم'),
(78612, 2492, 21, 'السداد النهائي'),
(78613, 2493, 21, 'منتهي'),
(78614, 2495, 21, 'الأول'),
(78615, 2497, 21, 'اليوم الأول للأسبوع'),
(78616, 2498, 21, 'الاسم الأول'),
(78617, 2499, 21, 'الاسم الأول'),
(78618, 2500, 21, 'الاسم الأول'),
(78619, 2503, 21, 'اللياقة'),
(78620, 2504, 21, 'مستوى اللياقة'),
(78621, 2505, 21, 'مستوى اللياقة لهذا اللاعب في هذا اليوم'),
(78622, 2507, 21, 'اللياقة للعب'),
(78623, 2508, 21, 'تصحيح تاريخ الزيارات'),
(78624, 2509, 21, 'تصحيح.'),
(78625, 2510, 21, 'فلوريدا'),
(78626, 2511, 21, 'حس الانتفاخ'),
(78627, 2512, 21, 'الجريان'),
(78628, 2514, 21, 'فصل الإنفلونزا'),
(78629, 2515, 21, 'فصل الإنفلونزا'),
(78630, 2516, 21, 'لقاح الإنفلونزا'),
(78631, 2517, 21, 'مشكلة في السوائل و الشوارد'),
(78632, 2518, 21, 'أخصائي طب العائلة'),
(78633, 2519, 21, 'حجم ورقة الترتيب'),
(78634, 2520, 21, 'متابعة يدوية'),
(78635, 2521, 21, 'إتبع هذة التعليمات لتثبيت او ترقية قاعدة البيانات التالية'),
(78636, 2522, 21, 'المتابعة'),
(78637, 2524, 21, 'سبب المتابعة'),
(78638, 2525, 21, 'اﻷتي هو مصطلح جديد حسب الطلب:'),
(78639, 2526, 21, 'اﻷتي هو لغة جديدة حسب الطلب:'),
(78640, 2527, 21, 'اﻷتي هو تعريف جديد حسب الطلب (لغة, تعريف او مصطلح):'),
(78641, 2529, 21, 'خدمات المتابعة'),
(78642, 2530, 21, 'دواعي المتابعة'),
(78643, 2531, 21, 'عدم تحمل الغذاء'),
(78644, 2532, 21, 'القدم'),
(78645, 2533, 21, 'مشاكل القدم'),
(78646, 2534, 21, 'القدم'),
(78647, 2535, 21, 'الرضوض في كرة القدم'),
(78648, 2536, 21, 'رضه كره قدم'),
(78649, 2537, 21, 'التقرير الطبي'),
(78650, 2538, 21, 'نمط التمزق'),
(78651, 2539, 21, 'لـ'),
(78652, 2540, 21, 'لـ'),
(78653, 2541, 21, 'لـ رمز'),
(78654, 2543, 21, 'لـ دعاوى الزيارة'),
(78655, 2544, 21, 'كـ مثال'),
(78656, 2547, 21, 'لـ لفاتورة'),
(78657, 2548, 21, 'لميديكير فقط, يجبر المزوّد المحوّل ليكون هو نفسه المزوّد المؤدي'),
(78658, 2549, 21, 'لواضع رقم الطلب ل OBR'),
(78659, 2552, 21, 'لـ الجهة / الممارس المُحيل للمريض'),
(78660, 2553, 21, 'منذ'),
(78661, 2554, 21, 'للمتغيرات'),
(78662, 2555, 21, 'من أجل'),
(78663, 2556, 21, 'فتح اجباري - قائمه المدفوعات'),
(78664, 2557, 21, 'فتح اجباري - ملف مريض جديد'),
(78665, 2558, 21, 'إظهار اجباري'),
(78666, 2559, 21, 'الساعد'),
(78667, 2560, 21, 'الاستمارة'),
(78668, 2561, 21, 'الاستمارة'),
(78669, 2564, 21, 'الصيغة'),
(78670, 2565, 21, 'الصيغة'),
(78671, 2566, 21, 'صيغه عرض العمر'),
(78672, 2567, 21, 'الصيغة خاطئة لNDC'),
(78673, 2568, 21, 'الصيغة المستعملة لعرض التواريخ'),
(78674, 2569, 21, 'الصيغة المستعملة لعرض التواريخ'),
(78675, 2570, 21, 'التقرير'),
(78676, 2571, 21, 'مدخن سابق'),
(78677, 2572, 21, 'الاستمارات'),
(78678, 2573, 21, 'الاستمارات الإدارية'),
(78679, 2575, 21, 'اعاده ارسال'),
(78680, 2576, 21, 'إرسال الصفحات بالفاكس'),
(78681, 2577, 21, 'مرسل'),
(78682, 2579, 21, 'الرابع'),
(78683, 2581, 21, 'الكسر'),
(78684, 2582, 21, 'كسر الترقوة'),
(78685, 2583, 21, 'كسر الكعب الوحشي'),
(78686, 2584, 21, 'كسر الكعب الأنسي'),
(78687, 2585, 21, 'كسر قاعدة المشط الخامس'),
(78688, 2586, 21, 'مطلوب هيكل الدعم'),
(78689, 2587, 21, 'الفرنسية'),
(78690, 2588, 21, 'الفرنسية (الكندية)'),
(78691, 2589, 21, 'اللغة الفرنسية'),
(78692, 2590, 21, 'التواتر'),
(78693, 2591, 21, 'زكام متكرر'),
(78694, 2592, 21, 'أمراض متكررة'),
(78695, 2593, 21, 'الجمعة'),
(78696, 2594, 21, 'الحمعة'),
(78697, 2595, 21, 'من'),
(78698, 2596, 21, 'من'),
(78699, 2597, 21, 'من'),
(78700, 2598, 21, 'من تاريخه لايمكن أن يكون أكثر من الحالي'),
(78701, 2599, 21, 'من'),
(78702, 2600, 21, 'من '),
(78703, 2601, 21, 'من_مدينة'),
(78704, 2603, 21, 'من_الأسم_الأول'),
(78705, 2604, 21, 'من_الأسم_الأخير'),
(78706, 2605, 21, 'من_الأسم_الأوسط'),
(78707, 2607, 21, 'من_هاتف_الجوال'),
(78708, 2608, 21, 'كم_الرمز البريدي'),
(78709, 2609, 21, 'من_الولاية'),
(78710, 2610, 21, 'من_الشارع'),
(78711, 2611, 21, 'من_العنوان'),
(78712, 2612, 21, 'من ـ دليل القيمه'),
(78713, 2613, 21, 'مكتب الاستقبال'),
(78714, 2614, 21, 'إيصالات مكتب الأستقبال'),
(78715, 2615, 21, 'تقرير الاستقبال'),
(78716, 2616, 21, 'التسجيل الأمامي'),
(78717, 2617, 21, 'اليمنى الأمامية'),
(78718, 2619, 21, 'الاسم الكامل'),
(78719, 2620, 21, 'دليل مسار كامل متضمن اوامر قاعده البيانات MySQL قابل لتطبيق'),
(78720, 2621, 21, 'دليل مسار كامل متضمن اوامر البرمجه Perl قابل لتطبيق'),
(78721, 2622, 21, 'دليل مسار كامل من احتياطي سجل الاحداث السابقه log'),
(78722, 2623, 21, 'دليل مسار كامل للملفات المؤقته'),
(78723, 2624, 21, 'اللعب التام'),
(78724, 2625, 21, 'التدريب التام'),
(78725, 2626, 21, 'المدفوع التام'),
(78726, 2633, 21, 'غ'),
(78727, 2634, 21, 'غ/دل'),
(78728, 2636, 21, 'حالة حصيات المرارة'),
(78729, 2637, 21, 'حصيات المرارة'),
(78730, 2638, 21, 'فترة اللعب'),
(78731, 2639, 21, 'الألعاب'),
(78732, 2640, 21, 'الغياب'),
(78733, 2641, 21, 'الألعاب'),
(78734, 2642, 21, 'الغياب'),
(78735, 2644, 21, 'التهاب المعدة'),
(78736, 2645, 21, 'ألم المعدة'),
(78737, 2646, 21, 'الهضمي'),
(78738, 2647, 21, 'تقرير إحصائيات GCAC'),
(78739, 2648, 21, 'حالات GCAC'),
(78740, 2649, 21, 'طلب زيارة GCAC مفقود'),
(78741, 2650, 21, 'الجنس'),
(78742, 2651, 21, 'الجنس '),
(78743, 2652, 21, 'العام'),
(78744, 2653, 21, 'قائمة المشاكل العامة'),
(78745, 2655, 21, 'مجموعة الخدمة العامة'),
(78746, 2657, 21, 'كوّن ثم نزّل مطالبات CMS 1500 الورقية'),
(78747, 2658, 21, 'كوّن ثم نزّل مطالبات HCFA 1500 الورقية'),
(78748, 2659, 21, 'كوّن ثم نزّل جملة X12'),
(78749, 2660, 21, 'كوّن ثم نزّل جملة مطالبات الزيارة لX12'),
(78750, 2663, 21, 'كوّن ثم نزّل الوصفات المسموح بها الكترونيا'),
(78751, 2664, 21, 'كوّن CMS 1500'),
(78752, 2665, 21, 'كوّن CMS 1500 علي نسق الوثائق النقال'),
(78753, 2666, 21, 'كوّن CMS 1500 كملف خطي'),
(78754, 2667, 21, 'كوّن HCFA'),
(78755, 2668, 21, 'تكوين الفاتورة'),
(78756, 2669, 21, 'تكوين الخطاب'),
(78757, 2670, 21, 'تكوين خطاب بخصوص '),
(78758, 2671, 21, 'تكوين تقرير PQRI بطريقة A'),
(78759, 2673, 21, 'تكوين تقرير PQRI بطريقة E'),
(78760, 2677, 21, 'تكوين التقرير'),
(78761, 2678, 21, 'تكوين اسم مستخدم و كلمة سر'),
(78762, 2679, 21, 'تكوين X12'),
(78763, 2680, 21, 'تكوين مراجعة X12'),
(78764, 2682, 21, 'تم في'),
(78765, 2683, 21, 'كون'),
(78766, 2684, 21, 'البولي التناسلي'),
(78767, 2687, 21, 'الألمانية'),
(78768, 2691, 21, 'تكوين HL7'),
(78769, 2692, 21, 'الجلوكوما'),
(78770, 2693, 21, 'قصة عائلية للجلوكوما'),
(78771, 2694, 21, 'عالمي'),
(78772, 2696, 21, 'هوية عالمية'),
(78773, 2697, 21, 'الإعدادات العامة'),
(78774, 2698, 21, 'العموميات'),
(78775, 2699, 21, 'غرام/دل'),
(78776, 2700, 21, 'اذهب'),
(78777, 2701, 21, 'اذهب'),
(78778, 2704, 21, 'اذهب'),
(78779, 2705, 21, 'اذهب للإسبوع'),
(78780, 2706, 21, 'اذهب لليوم الحالي'),
(78781, 2707, 21, 'الهدف أ'),
(78782, 2708, 21, 'الهدف والطرق'),
(78783, 2709, 21, 'الهدف ب'),
(78784, 2710, 21, 'الهدف ج'),
(78785, 2711, 21, 'درجة الأذية'),
(78786, 2712, 21, 'الدرجة'),
(78787, 2713, 21, 'غرام/دل'),
(78788, 2714, 21, 'المجموع الإجمالي'),
(78789, 2715, 21, 'المجاميع الإجمالية'),
(78790, 2718, 21, 'امكانية عمل رسم بياني'),
(78791, 2720, 21, 'أكبر من'),
(78792, 2721, 21, 'أكبر من أو يساوي'),
(78793, 2722, 21, 'إغريقي'),
(78794, 2724, 21, 'مجموعة'),
(78795, 2725, 21, 'أسم المجموعة'),
(78796, 2726, 21, 'أسماء المجموعة لا يمكن أن تترك فارغة'),
(78797, 2727, 21, 'أسماء المجموعة لا يمكن ان تبدأ برقم او مسافة'),
(78798, 2728, 21, 'أسماء المجموعة لا يمكن أن تبدأ برقم'),
(78799, 2729, 21, 'رقم المجموعة'),
(78800, 2730, 21, 'اجمع المستحقات'),
(78801, 2731, 21, 'مجموعة'),
(78802, 2732, 21, 'اسم المجموعة'),
(78803, 2733, 21, 'المجموعات وضبط الوصول'),
(78804, 2734, 21, 'الرسم البياني للنمو'),
(78805, 2735, 21, 'الرسم البياني-للنمو'),
(78806, 2736, 21, 'قطرات'),
(78807, 2737, 21, 'مواطن غوامي'),
(78808, 2739, 21, 'اسم ولي الأمر'),
(78809, 2741, 21, 'كشف نسائي'),
(78810, 2742, 21, 'ساعة'),
(78811, 2743, 21, 'قبل النوم'),
(78812, 2744, 21, 'تاريخ مرضي التهاب الكبد'),
(78813, 2745, 21, 'تم الحذف بنجاح. أي من الفئات الفرعية قد تم نقلها إذا كانت موجوده أدناه'),
(78814, 2746, 21, 'ورم دموي - تكدم'),
(78815, 2747, 21, 'حالة العدوى المكتسبة من المستشفى'),
(78816, 2750, 21, 'يد + أصابع'),
(78817, 2751, 21, 'مشاكل اليد'),
(78818, 2752, 21, 'القرص الصلب'),
(78819, 2753, 21, 'ضائقة بدون'),
(78820, 2754, 21, 'تم ربطها بالزيارة'),
(78821, 2755, 21, 'انتهى'),
(78822, 2756, 21, 'خليط'),
(78823, 2757, 21, 'Hash did not exist for this file. A new hash was generated.'),
(78824, 2758, 21, 'Hash does not match. Data integrity has been compromised.'),
(78825, 2760, 21, 'من هاواي'),
(78826, 2761, 21, 'نشاطات خطرة'),
(78827, 2762, 21, 'نشاطات خطرة'),
(78828, 2763, 21, 'الحافة اليسرى ل HCFA بالنقاط'),
(78829, 2764, 21, 'حواف HCFA'),
(78830, 2765, 21, 'الحافة العليا ل HCFA بالنقاط'),
(78831, 2766, 21, 'خدمة/ عمليات HCPCS'),
(78832, 2767, 21, 'هو PostCalendar '),
(78833, 2768, 21, 'رأس'),
(78834, 2769, 21, 'محيط الرأس'),
(78835, 2770, 21, 'محيط الرأس'),
(78836, 2771, 21, 'وجع رأس'),
(78837, 2772, 21, 'وجع رأس'),
(78838, 2773, 21, 'عمليات الرعاية الصحية'),
(78839, 2774, 21, 'عمليات الرعاية الصحية'),
(78840, 2775, 21, 'مركز صحي / عيادة'),
(78841, 2776, 21, 'منظمه الحفاض علي الصحه'),
(78842, 2777, 21, 'مخاطرة ميديكير لمنظمه الحفاض علي الصحه'),
(78843, 2778, 21, 'فقدان السمع'),
(78844, 2779, 21, 'نوبة قلبية'),
(78845, 2780, 21, 'أمراض القلب'),
(78846, 2781, 21, 'سكتة قلبية'),
(78847, 2782, 21, 'مشاكل القلب'),
(78848, 2783, 21, 'مشاكل القلب'),
(78849, 2784, 21, 'جراحة قلب'),
(78850, 2785, 21, 'زراعة قلب'),
(78851, 2786, 21, 'القلب'),
(78852, 2787, 21, 'حرقة المعدة'),
(78853, 2788, 21, 'حار أو بارد'),
(78854, 2789, 21, 'حار أو بارد'),
(78855, 2790, 21, 'مدخن بشراهة'),
(78856, 2791, 21, 'العبرية'),
(78857, 2793, 21, 'الرأس, العيون, الأذان, الأنف, الحنجرة'),
(78858, 2794, 21, 'الإرتفاع'),
(78859, 2796, 21, 'مساعدة'),
(78860, 2797, 21, 'مساعدة'),
(78861, 2798, 21, 'قئ الدم'),
(78862, 2799, 21, 'التغوط المدمى'),
(78863, 2800, 21, 'دموي'),
(78864, 2801, 21, 'البول الدموي'),
(78865, 2802, 21, 'الهيموجلوبين'),
(78866, 2803, 21, 'الهيموجلوبين المسكر (الجليكوزيلاتي)'),
(78867, 2804, 21, 'بصق الدم'),
(78868, 2805, 21, 'إلتهاب الكبد الوبائي'),
(78869, 2806, 21, 'إلتهاب الكبد الوبائي A 1'),
(78870, 2807, 21, 'إلتهاب الكبد الوبائي A 2'),
(78871, 2808, 21, 'إلتهاب الكبد الوبائي B 1'),
(78872, 2809, 21, 'إلتهاب الكبد الوبائي B 2'),
(78873, 2810, 21, 'إلتهاب الكبد الوبائي B 3'),
(78874, 2811, 21, 'هنا'),
(78875, 2813, 21, 'إصلاح الفتاق'),
(78876, 2814, 21, 'فتاق النواة اللبّية'),
(78877, 2815, 21, 'الهربس'),
(78878, 2816, 21, 'تردد'),
(78879, 2817, 21, 'مرحبا. لماذا انت هنا '),
(78880, 2818, 21, 'تطعيم الإنفلونزا 1'),
(78881, 2819, 21, 'تطعيم الإنفلونزا 2'),
(78882, 2820, 21, 'تطعيم الإنفلونزا 3'),
(78883, 2821, 21, 'تطعيم الإنفلونزا 4'),
(78884, 2822, 21, 'مخفي'),
(78885, 2823, 21, 'احداث اداريه مخفيه'),
(78886, 2824, 21, 'أخفى'),
(78887, 2825, 21, 'أخفاء التفاصيل'),
(78888, 2827, 21, 'أخفاء خيار التشفير-فك التشفير في ادارة الوثائق'),
(78889, 2828, 21, 'أخفاء القائمة'),
(78890, 2830, 21, 'أخفاء التنبيهات'),
(78891, 2831, 21, 'أخفاء/إظهار الأعمدة'),
(78892, 2833, 21, 'مرتفع'),
(78893, 2834, 21, 'أرتفاع ضغط الدم'),
(78894, 2835, 21, 'هندي'),
(78895, 2836, 21, 'الورك + الأربية'),
(78896, 2837, 21, 'الورك و الأربية'),
(78897, 2838, 21, 'مشاكل الورك'),
(78898, 2839, 21, 'إستبدال مفصل الورك'),
(78899, 2840, 21, 'أستلام نسخة من قانون الخصوصية وسرية المعلومات HIPAA'),
(78900, 2842, 21, 'كثرة الشعر/حزوز'),
(78901, 2843, 21, 'أسباني'),
(78902, 2844, 21, 'أسباني- اخرى (مولود في الولايات المتحدة)'),
(78903, 2845, 21, 'أسباني- أخرى (مولود خارج الولايات المتحدة)'),
(78904, 2846, 21, 'أسباني او لاتيني'),
(78905, 2847, 21, 'التاريخ'),
(78906, 2848, 21, 'التاريخ'),
(78907, 2849, 21, 'التاريخ'),
(78908, 2851, 21, 'تاريخ النفخة القلبية'),
(78909, 2852, 21, 'التاريخ غير مصرح'),
(78910, 2853, 21, 'تاريخ طبي بالنفخة القلبية'),
(78911, 2854, 21, 'إرتطام'),
(78912, 2855, 21, 'فيروس نقص المناعة البشرية'),
(78913, 2858, 21, 'معاين المستوى السابع الصحي'),
(78914, 2860, 21, 'ميكرومول لكل ليتر'),
(78915, 2861, 21, 'همونق-الصين'),
(78916, 2862, 21, 'إضغط [Ctrl] بإستمرار لخيارات متعددة او لإلغاء التحديد'),
(78917, 2863, 21, 'إضغط [Ctrl] بإستمرار لتحديد عناصر متعددة'),
(78918, 2864, 21, 'إضغط [Ctrl] بإستمرار لتحديد مجموعات متعددة'),
(78919, 2865, 21, 'الصفحة الرئيسية'),
(78920, 2866, 21, 'تلفون المنزل'),
(78921, 2867, 21, 'رقم تلفون المنزل'),
(78922, 2868, 21, 'بلا مأوى او مماثل'),
(78923, 2869, 21, 'بلا مأوى, اخرى'),
(78924, 2870, 21, 'بلا مأوى, اخرى'),
(78925, 2872, 21, 'أسم المضيف'),
(78926, 2873, 21, 'أسم المضيف لايمكن ان يكون فارغ'),
(78927, 2875, 21, 'ساعة'),
(78928, 2876, 21, 'ساعات'),
(78929, 2878, 21, 'كيف حصلت الإصابة ؟'),
(78930, 2879, 21, 'كيف حصلت الإصابة؟:'),
(78931, 2880, 21, 'كيف سمعت عنا'),
(78932, 2881, 21, 'كم شهراَ مقدماَ للبحث عن اﻷحداث؟'),
(78933, 2882, 21, 'تفصيل قصة المرض الحالي:'),
(78934, 2883, 21, 'الطول'),
(78935, 2884, 21, 'لغة رقم النص الفائق (إتش تي أم إل)'),
(78936, 2885, 21, 'مخرجات لغة النص الفائق (إتش تي أم إال ) ؟'),
(78937, 2886, 21, 'رابط Https للبرنامج علي خدمة تبادل المعمل'),
(78938, 2887, 21, 'مجري- هنغاري'),
(78939, 2888, 21, 'مجلّد Hylafax'),
(78940, 2889, 21, 'أمر Hylafax'),
(78941, 2890, 21, 'خادم Hylafax'),
(78942, 2891, 21, 'إسم خادم Hylafax'),
(78943, 2892, 21, 'مفرط النشاط'),
(78944, 2893, 21, 'فرط ضغط الدم'),
(78945, 2894, 21, 'ضغط الدم: قياس ضغط الدم'),
(78946, 2895, 21, 'ضغط الدم: قياس ضغط الدم (CQM)'),
(78947, 2896, 21, 'فرط الدرقية'),
(78948, 2897, 21, 'قصور الدرقية'),
(78949, 2898, 21, 'إستئصال الرحم'),
(78950, 2900, 21, 'أنا مشغول في هذا الوقت'),
(78951, 2901, 21, 'ليس لدي صلاحية القراءة '),
(78952, 2902, 21, 'التصنيف الدولي للأمراض'),
(78953, 2903, 21, 'التصنيف الدولي العاشر للأمراض: التشخيص'),
(78954, 2904, 21, 'التصنيف الدولي العاشر للأمراض: الإجراءات- الخدمات'),
(78955, 2905, 21, 'التصنيف الدولي للأمراض - الطبعة التاسعة'),
(78956, 2906, 21, 'التصنيف الدولي التاسع للأمراض: التشخيص'),
(78957, 2907, 21, 'التصنيف الدولي التاسع للأمراض: الإجراءات-الخدمات'),
(78958, 2909, 21, 'رقم الهوية'),
(78959, 2910, 21, 'رقم الهوية'),
(78960, 2911, 21, 'رقم الهوية لا يمكن ان يكون فارغاُ'),
(78961, 2912, 21, 'بطاقة الهوية الوطنية'),
(78962, 2913, 21, 'IDays'),
(78963, 2914, 21, 'معرّف ك'),
(78964, 2915, 21, 'معرٍف (كلمة واحدة)'),
(78965, 2916, 21, 'رمز التعرفة'),
(78966, 2917, 21, 'إنتهاء وقت الجلسة بالثواني'),
(78967, 2919, 21, 'أذا كانت كل البيانات من كل الأعمدة مكتملة لهذا النموذج '),
(78968, 2920, 21, 'أدخل رمز التشخيص لو تم إستخدام تعليل للفوترة'),
(78969, 2921, 21, 'لو تم اﻹدخال, إختر أولئك الذين كانت عندهم الخدمة'),
(78970, 2922, 21, 'لو إسم, اذا اي جزء من اﻷسم سواء اﻷول,اﻷخير'),
(78971, 2923, 21, 'أذا كان الدفع عن طريق'),
(78972, 2924, 21, 'أذاكان الشخص متوفي, ادخل تاريخ الوفاة'),
(78973, 2925, 21, 'لو تم إستخدام SMTP, اسم الخادم او عنوان ال IP'),
(78974, 2926, 21, 'لو تم إستخدام SMTP, رقم فتحة الخادم (عادة رقم 25)'),
(78975, 2927, 21, 'أذاكان غير موظف ادخل طالب'),
(78976, 2928, 21, 'إختر العمر بالسنوات بدلا عن سنه شهر يوم'),
(78977, 2929, 21, 'إذا تم تغيير دور e-RX للوصفة الإلكترونية فإن ذلك سيؤثر على سير العمل, إتصل بندوبهم لمزيد من التفاصيل'),
(78978, 2931, 21, 'إذا كنت إخترت التحويلات المالية الإلكترونية إذا نافذة البحث ستستعرض الفواتير من الملف X12. بإمكانك تغيير اي من هذه الملفات بالضغط عليه قبل الشروع في التحويل'),
(78979, 2932, 21, 'لو أدخلت تاريخا للمرتب فى صفحة البحث فسوف يتفادي المعايير المأخودة من الملف X12 و المتعلقه بتواريخ الدفع. هذة الخاصية مفيدة لأغراض إنشاء التقارير. هذا الإختيار سوف يؤثر على تواريخ الدفوعات السابقه و المتعلقة بالمطالبات الثانوية'),
(78980, 2933, 21, 'إذا كنت تريد تغيير نوعية البيانات أو إضافة أصفف أو أعمدة'),
(78981, 2934, 21, 'إذا كنت تريد ترقية قاعدة البيانات فعليك وضع ملفها المضغوط فى المجلّد التالي'),
(78982, 2936, 21, 'تجاهل'),
(78983, 2937, 21, 'داء'),
(78984, 2938, 21, 'في العضل'),
(78985, 2941, 21, 'خدمات التصوير'),
(78986, 2942, 21, 'التطعيم'),
(78987, 2943, 21, 'رمز التطعيم'),
(78988, 2945, 21, 'تاريخ التطعيم'),
(78989, 2946, 21, 'تاريخ إنتهاء التطعيم'),
(78990, 2947, 21, 'الرقم المصنعي الخاص بالتطعيمة Lot Number'),
(78991, 2948, 21, 'مصنع التطعيمة'),
(78992, 2949, 21, 'سجل التطعيم'),
(78993, 2951, 21, 'خدمة التطعيم'),
(78994, 2952, 21, 'أسم التطعيم'),
(78995, 2953, 21, 'التطعيمات'),
(78996, 2954, 21, 'حصن'),
(78997, 2955, 21, 'مناعي'),
(78998, 2956, 21, 'زرع'),
(78999, 2957, 21, 'استورد'),
(79000, 2961, 21, 'إستورد الشهادة الي المتصفح'),
(79001, 2962, 21, 'إستورد الإعدادات'),
(79002, 2964, 21, 'إستورد المريض'),
(79003, 2965, 21, 'إستورد ديموجرافيا المريض'),
(79004, 2966, 21, 'رموز مهمة'),
(79005, 2967, 21, 'تحذير مهم: أداة الرفع هذه لرفع الملفات للمرضى الذين لم يتم تسجيلهم في النظام. ولرفع الملفات للمرضى الموجودين مسبقا في النظام, الرجاء استخدام رابط أداة الرفع الموجودة في نافذة المريض الموجزة.'),
(79006, 2969, 21, 'مستوردة من المحاسبة'),
(79007, 2972, 21, 'تحسن'),
(79008, 2973, 21, 'داخل'),
(79009, 2974, 21, 'داخل'),
(79010, 2975, 21, 'في كل عين'),
(79011, 2976, 21, 'في العين اليسرى'),
(79012, 2977, 21, 'فتحة الأنف'),
(79013, 2978, 21, 'في المكتب'),
(79014, 2979, 21, 'في العين اليمنى'),
(79015, 2980, 21, 'في المنزل'),
(79016, 2981, 21, 'خامل'),
(79017, 2982, 21, 'أيام خاملة'),
(79018, 2983, 21, 'الصندوق'),
(79019, 2986, 21, 'اشمل Checksum'),
(79020, 2987, 21, 'ادراج المكتمل'),
(79021, 2988, 21, 'ادراج المستخدمين الغير نشطيين'),
(79022, 2989, 21, 'ادراج الغير مصنف'),
(79023, 2990, 21, 'ادراج البيانات الغير منظمة'),
(79024, 2991, 21, 'ادراج العلامات الحيوية'),
(79025, 2992, 21, 'ادارج بيانات العلامات الحيوية؟'),
(79026, 2993, 21, 'إشتمال'),
(79027, 2994, 21, 'الدخل'),
(79028, 2996, 21, 'غير كامل'),
(79029, 2997, 21, 'علاج إجهاض غير مكتمل'),
(79030, 2998, 21, 'سلس البول'),
(79031, 2999, 21, 'ادمج نتائج التحاليل الطبية مع تقنية EHR المعتمدة كبيانات مؤسسة'),
(79032, 3000, 21, 'كلمة السر غير صحيحة!'),
(79033, 3001, 21, 'زيادة :'),
(79034, 3002, 21, 'تعويض التأمين'),
(79035, 3003, 21, 'غير معروف'),
(79036, 3004, 21, 'هندي'),
(79037, 3005, 21, 'يدل علي المرض/ العلّة'),
(79038, 3006, 21, 'نوه اذا كانت المشكلة حاليا نشطة'),
(79039, 3008, 21, 'مؤشر للإستخدام المتخصص'),
(79040, 3009, 21, 'مريض معوز'),
(79041, 3010, 21, 'تقارير المرضى المعوزين'),
(79042, 3011, 21, 'المعوزين'),
(79043, 3014, 21, 'إجهاض محرض'),
(79044, 3016, 21, 'غير مؤهل'),
(79045, 3017, 21, 'عدوى / خراج'),
(79046, 3018, 21, 'عدوى'),
(79047, 3019, 21, 'مشورات العقم'),
(79048, 3020, 21, 'العقم'),
(79049, 3021, 21, 'انفلونزا 1'),
(79050, 3022, 21, 'انفلونزا 2'),
(79051, 3023, 21, 'تطعييم انفلونزا للمرضي اكبر من او يساوي 50 عاما'),
(79052, 3024, 21, 'تطعييم انفلونزا للمرضي اكبر من او يساوي 50 عاما (CQM)'),
(79053, 3025, 21, 'لقاح الإنفلونزا'),
(79054, 3026, 21, 'معلومات'),
(79055, 3027, 21, 'إختبار المعلومه 1'),
(79056, 3028, 21, 'إختبار المعلومه 2'),
(79057, 3029, 21, 'إختبار المعلومه 3'),
(79058, 3030, 21, 'إختبار المعلومه 4'),
(79059, 3031, 21, 'إختبار المعلومه 5'),
(79060, 3032, 21, 'إختبار المعلومه 6'),
(79061, 3034, 21, 'إستنشاق'),
(79062, 3035, 21, 'إستنشاق'),
(79063, 3037, 21, 'المستخدم الأول'),
(79064, 3038, 21, 'تلقيح/ تأهيل'),
(79065, 3039, 21, 'الحقن'),
(79066, 3040, 21, 'حقنة'),
(79067, 3041, 21, 'اجزاء الجسم المصابة'),
(79068, 3042, 21, 'قسم الجروح الخارجي'),
(79069, 3043, 21, 'إصابة'),
(79070, 3044, 21, 'كيفية الإصابة'),
(79071, 3045, 21, 'تقرير موجز الإصابة'),
(79072, 3046, 21, 'مراقية الإصابات'),
(79073, 3047, 21, 'نوع الإصابة'),
(79074, 3048, 21, 'متعلق بالمرض/الإصابة'),
(79075, 3050, 21, 'الإدخال غير مبتدئ بمقطع MSH');
INSERT INTO `lang_definitions` VALUES
(79076, 3051, 21, 'حقول الإدخال'),
(79077, 3052, 21, 'إختبار تخثر الدم بناء علي وقت البروثرومبن'),
(79078, 3053, 21, 'تأمين 1'),
(79079, 3054, 21, 'تأمين 2 او تأمين 3'),
(79080, 3055, 21, 'عنوان التأمين'),
(79081, 3056, 21, 'تعديل التأمين'),
(79082, 3057, 21, 'تحزيم التأمين'),
(79083, 3058, 21, 'كود التأمين'),
(79084, 3059, 21, 'مجموعة التأمين'),
(79085, 3060, 21, 'إسم التأمين'),
(79086, 3061, 21, 'دفع زيادة التأمين'),
(79087, 3062, 21, 'بوليصه التأمين'),
(79088, 3063, 21, 'إرجاع التأمين'),
(79089, 3064, 21, 'ملخص التأمين'),
(79090, 3065, 21, 'تأمين 1'),
(79091, 3066, 21, 'تأمين 2'),
(79092, 3067, 21, 'تأمين 3'),
(79093, 3069, 21, 'فشلت الإضافة '),
(79094, 3070, 21, 'أضف الأحداث القديمة في جداول'),
(79095, 3072, 21, 'أرق'),
(79096, 3073, 21, 'فحص السجل'),
(79097, 3074, 21, 'تفتيش'),
(79098, 3075, 21, 'غير ثابت/ خلع جزئي'),
(79099, 3076, 21, 'تثبيت'),
(79100, 3077, 21, 'تثبيت'),
(79101, 3079, 21, 'تثبيت قاعدة البيانات'),
(79102, 3080, 21, 'النسخة المثبتة'),
(79103, 3081, 21, 'أرشد'),
(79104, 3082, 21, 'تعليمات'),
(79105, 3084, 21, 'تعليمات :'),
(79106, 3085, 21, 'بضاعة غير كافية للمنتج 1ا الهوية'),
(79107, 3086, 21, 'السكري المعتمد على الإنسولين'),
(79108, 3087, 21, 'تأمين'),
(79109, 3088, 21, 'تأمين'),
(79110, 3091, 21, 'رصيد حساب التأمين'),
(79111, 3092, 21, 'رصيد حساب التامين المستحق'),
(79112, 3093, 21, 'شركة التأمين'),
(79113, 3094, 21, 'شركات التأمين'),
(79114, 3095, 21, 'شركة التأمين'),
(79115, 3096, 21, 'بحث/ إضافة شركة تأمين'),
(79116, 3098, 21, 'تاريخ التأمين'),
(79117, 3099, 21, 'معلومات التأمين في الملف'),
(79118, 3100, 21, 'رقم التأمين'),
(79119, 3101, 21, 'مدفوعات التأمين'),
(79120, 3103, 21, 'شركة تأمين'),
(79121, 3106, 21, 'مؤمن'),
(79122, 3107, 21, 'مجمل التناول'),
(79123, 3108, 21, 'تاريخ التناول'),
(79124, 3109, 21, 'إنخفاض فكري'),
(79125, 3113, 21, 'خطأ داخلي - لم يتم تحديد الصفحات !'),
(79126, 3114, 21, 'خطأ داخلي - لم يتم توفير رقم المريض !'),
(79127, 3115, 21, 'خطأ داخلي في الوصول الى الملف المحمل !'),
(79128, 3116, 21, 'خطأ داخلي'),
(79129, 3117, 21, 'خطأ داخلي لم يتم تحديد رقم الدواء !'),
(79130, 3118, 21, 'خطأ داخلي: لم يعثر علي MSH-10'),
(79131, 3119, 21, 'خطأ داخلي: مطالبة '),
(79132, 3120, 21, 'خطأ داخلي: الزيارة'''),
(79133, 3121, 21, 'خطأ داخلي: الزيارة او المعرف داخلي مفقود'),
(79134, 3122, 21, 'خطأ داخلي: لا يبدو انك بداخل صفحة الزيارة'),
(79135, 3123, 21, 'معرف داخلي'),
(79136, 3126, 21, 'الإحالات الداخلية'),
(79137, 3127, 21, 'تم جمع الوقت الداخلي'),
(79138, 3128, 21, 'مهمة دولية'),
(79139, 3129, 21, 'مترجم'),
(79140, 3130, 21, 'هل تحتاج الى مترجم؟'),
(79141, 3131, 21, 'الأمراض الخلالية الرئوية'),
(79142, 3132, 21, 'فاصل زمني'),
(79143, 3133, 21, 'فاصل زمني (دقائق)'),
(79144, 3134, 21, 'فاصل زمني بين تفقد الرسائل (اذا كان علي 0 فالتفقد يدوى فقط)'),
(79145, 3135, 21, 'تدخل'),
(79146, 3136, 21, 'تم التدخل'),
(79147, 3137, 21, 'حساسية مفرطة'),
(79148, 3139, 21, 'العضل'),
(79149, 3140, 21, 'وريدي'),
(79150, 3141, 21, 'مقدمة'),
(79151, 3144, 21, 'حرف غير صالح في'),
(79152, 3147, 21, 'الطول غير صالح ل'),
(79153, 3148, 21, 'رمز غير رقمي في'),
(79154, 3149, 21, 'الدافع غير صالح او مفقود فى الكود الأساسي '),
(79155, 3150, 21, 'عنوان المتلقي غير صالح. حاول مجددا'),
(79156, 3151, 21, 'رموز خدمة غير صالحة'),
(79157, 3152, 21, 'التوصيف الأساسي غير صالح'),
(79158, 3153, 21, 'أسم المستخدم او الرقم السري غير صالح'),
(79159, 3154, 21, 'كمية المخزون'),
(79160, 3155, 21, 'بيان الجرد'),
(79161, 3156, 21, 'أنشطة الجرد'),
(79162, 3157, 21, 'تخزين و بيع كل البضائع كأدوية و غير أدوية'),
(79163, 3158, 21, 'تخزين و بيع البضائع الدوائية فقط'),
(79164, 3159, 21, 'الجرد غير متوفر لهذا الطلب'),
(79165, 3160, 21, 'قائمة الجرد'),
(79166, 3161, 21, 'تعاملات بيان الجرد'),
(79167, 3162, 21, 'فاتورة'),
(79168, 3163, 21, 'فاتورة'),
(79169, 3164, 21, 'فاتورة باقى الحساب'),
(79170, 3165, 21, 'لا يمكن عرض فاتورة باقى الحساب. الزيارة لم تنشأ بعد'),
(79171, 3166, 21, 'تاريخ الفاتورة'),
(79172, 3167, 21, 'الفاتورة لا تحتوي على تاريخ!'),
(79173, 3168, 21, 'رقم الفاتورة'),
(79174, 3169, 21, 'الرقم المرجعي للفاتورة'),
(79175, 3170, 21, 'جمع الرقم المرجعي للفواتير المستخدمه'),
(79176, 3171, 21, 'جمع الرقم المرجعي للفواتير'),
(79177, 3172, 21, 'مجمع ارقام الإيصالات'),
(79178, 3173, 21, 'فاتورة:'),
(79179, 3174, 21, 'الإتحاد الدولي لتنظيم الأسرة'),
(79180, 3175, 21, 'الإتحاد الدولي لتنظيم الأسرة - الإجهاض'),
(79181, 3176, 21, 'الإتحاد الدولي لتنظيم الأسرة - موانع الحمل'),
(79182, 3177, 21, 'بيانات الإتحاد الدولي لتنظيم الأسرة'),
(79183, 3178, 21, 'الإتحاد الدولي لتنظيم الأسرة - التقرير الإحصائي'),
(79184, 3179, 21, 'احصائيات الإتحاد الدولي لتنظيم الأسرة'),
(79185, 3180, 21, 'تطعيم فيروس البابيلوما 1'),
(79186, 3181, 21, 'تطعيم فيروس البابيلوما 2'),
(79187, 3182, 21, 'تطعيم فيروس البابيلوما 3'),
(79188, 3183, 21, 'تطعيم فيروس البابيلوما 4'),
(79189, 3185, 21, 'ضربات قلب غير منتظمة'),
(79190, 3186, 21, 'التهيج المفرط'),
(79191, 3187, 21, 'تهيج'),
(79192, 3188, 21, 'نسخه للغه مختلفه من قاعدت البيانات التاليه'),
(79193, 3189, 21, 'نسخه مختلفه من قاعدت البيانات التاليه'),
(79194, 3190, 21, 'اصدار احدث من قاعده البيانات التاليه'),
(79195, 3191, 21, 'خانه مطلوبه'),
(79196, 3192, 21, 'عقدة أساسية و لا يمكن مسحها'),
(79197, 3193, 21, 'امتداد لقاعده البيانات التاليه'),
(79198, 3195, 21, 'في غير موضعة او غير معروف'),
(79199, 3197, 21, 'غير صالح (الكسور العشرية مقبولة)'),
(79200, 3198, 21, 'هل يستخدم ال PHP الوضع الامن؟'),
(79201, 3200, 21, 'هل سيتم ترجمة النص من توزيعة الطلب؟'),
(79202, 3201, 21, 'هل سيتم ترجمة النص من القوائم؟'),
(79203, 3202, 21, 'هل الملف مشفر؟'),
(79204, 3203, 21, 'هل هذا رمز لمصطلح طبي؟'),
(79205, 3204, 21, 'هل هذا نوع التشخيص؟'),
(79206, 3205, 21, 'هل هذا نوع من ترميز المشاكل الطبية ؟'),
(79207, 3207, 21, 'هل هذا نوع عملية / خدمة ؟'),
(79208, 3208, 21, 'هل هذا نشط ؟'),
(79209, 3209, 21, 'هل نوع الترميز هذا نشط ؟'),
(79210, 3210, 21, 'هل هذا الرمز مستخدم فى المطالبات؟'),
(79211, 3212, 21, 'هل هذا النوع مخبأ فى صحيفة الرسوم؟'),
(79212, 3213, 21, 'هل يتم استخدام جداول sql خارجية؟ لو نعم اذا إختر الصيغة'),
(79213, 3214, 21, 'طويل للغاية'),
(79214, 3216, 21, 'مشكلة'),
(79215, 3217, 21, 'مشكلة'),
(79216, 3218, 21, 'تاريخ المشكلة'),
(79217, 3219, 21, 'رقم الإصدار'),
(79218, 3220, 21, 'أسم المشكلة'),
(79219, 3221, 21, 'نوع المشكلة'),
(79220, 3222, 21, 'أنواع المشاكل'),
(79221, 3223, 21, 'مشاكل'),
(79222, 3224, 21, 'مشاكل ( إصابات/ صحي/حساسية)'),
(79223, 3225, 21, 'مشاكل ( إصابات/ صحي/حساسية) :'),
(79224, 3226, 21, 'المشاكل والزيارات'),
(79225, 3227, 21, 'المشاكل والزيارات لــ'),
(79226, 3228, 21, 'المشاكل غير مصرح بها'),
(79227, 3229, 21, 'قسم المشاكل'),
(79228, 3230, 21, 'إيطالي'),
(79229, 3231, 21, 'بند'),
(79230, 3232, 21, 'بند'),
(79231, 3233, 21, 'بنود'),
(79232, 3234, 21, 'تعثر تحميل البنود'),
(79233, 3235, 21, 'وحدة دولية لكل ليتر'),
(79234, 3236, 21, 'الجهاز الواقي داخل الرحم'),
(79235, 3237, 21, 'العلاج عن طريق الوريد'),
(79236, 3238, 21, 'يناير/كانون الثاني'),
(79237, 3239, 21, 'يناير/كانون الثاني'),
(79238, 3240, 21, 'ياباني'),
(79239, 3241, 21, 'شعور الإشمئزاز'),
(79240, 3243, 21, 'وصف الوظيفة'),
(79241, 3244, 21, 'رقم الوظيفة'),
(79242, 3245, 21, 'خلع المفصل'),
(79243, 3246, 21, 'ألم المفصل'),
(79244, 3247, 21, 'خلع ناقص للمفصل'),
(79245, 3248, 21, 'يوليو/تموز'),
(79246, 3249, 21, 'يوليو/تموز'),
(79247, 3250, 21, 'يونيو/حزيران'),
(79248, 3251, 21, 'يونيو/حزيران'),
(79249, 3252, 21, 'أدخل كلمات البحث فى المنطقة الزرقاء ادناه. يمكنك البحث بإسم المريض, تاريخ الزيارة, رقم الإيصال او رقم المخطط'),
(79250, 3253, 21, 'خاص بي فقط'),
(79251, 3254, 21, 'مبررات الإدخالات'),
(79252, 3255, 21, 'يبرر'),
(79253, 3256, 21, 'برر/إحفظ'),
(79254, 3257, 21, 'J{{Justify Header}}'),
(79255, 3258, 21, 'حسناَ اليك البقية'),
(79256, 3264, 21, 'مفتاح'),
(79257, 3265, 21, 'مفردات الكلمات'),
(79258, 3266, 21, 'كجم'),
(79259, 3267, 21, 'كجم لكل متر مربع'),
(79260, 3269, 21, 'سرطان الكلية'),
(79261, 3270, 21, 'فشل كلوي'),
(79262, 3271, 21, 'إلتهاب كلوي'),
(79263, 3272, 21, 'حصوات الكلى'),
(79264, 3273, 21, 'زرع الكلى'),
(79265, 3277, 21, 'ركبة'),
(79266, 3278, 21, 'مشاكل الركبة'),
(79267, 3279, 21, 'إستبدال الركبة'),
(79268, 3282, 21, 'كوري'),
(79269, 3286, 21, 'مختبر'),
(79270, 3288, 21, 'عنوان موقع تبادل المعمل'),
(79271, 3289, 21, 'رقم هوية موقع تبادل المعمل'),
(79272, 3290, 21, 'عنوان علامة تبادل المعمل'),
(79273, 3294, 21, 'حالة إستعلام المختبر'),
(79274, 3295, 21, 'تقرير المختبر'),
(79275, 3296, 21, 'نتيجة المختبر'),
(79276, 3297, 21, 'نتائج المختبر'),
(79277, 3299, 21, 'تقرير نتائج المختبر'),
(79278, 3300, 21, 'خدمات المختبر'),
(79279, 3301, 21, 'نتائج التحليل'),
(79280, 3303, 21, 'ملصق'),
(79281, 3304, 21, 'الملصق لا يمكن أن يكون فارغاً'),
(79282, 3305, 21, 'عمدان الملصقات'),
(79283, 3306, 21, 'ملصق لهذا النوع'),
(79284, 3307, 21, 'عمدان الملصقات يجب أن تكون مابين 1 الي 999'),
(79285, 3308, 21, 'ملصقات'),
(79286, 3311, 21, 'مختبرات'),
(79287, 3312, 21, 'تمزق/ حالة جلدية'),
(79288, 3313, 21, 'تمزق/كشط'),
(79289, 3316, 21, 'لغة'),
(79290, 3317, 21, 'رقم اللغة'),
(79291, 3318, 21, 'تم إضافه تعريف اللغة'),
(79292, 3319, 21, 'أداة واجهة اللغة'),
(79293, 3320, 21, 'قائمة اللغات (اكتب,الزيادة اختيارية)'),
(79294, 3321, 21, 'أسم اللغة'),
(79295, 3322, 21, 'اللغة:'),
(79296, 3324, 21, 'لاوس'),
(79297, 3325, 21, 'آخر'),
(79298, 3326, 21, 'تاريخ أخر نشاط'),
(79299, 3328, 21, 'تاريخ اخر فاتورة:'),
(79300, 3330, 21, 'تقويم السنة الماضية'),
(79301, 3333, 21, 'اخر زيارة'),
(79302, 3340, 21, 'المستوي الإخير الذى تم اصدار فاتورة له'),
(79303, 3343, 21, 'الشهر الماضي'),
(79304, 3344, 21, 'اللقب'),
(79305, 3345, 21, 'اللقب'),
(79306, 3346, 21, 'اللقب:'),
(79307, 3350, 21, 'اخر مراجعة'),
(79308, 3351, 21, 'أخر تشغيلة بدأت من'),
(79309, 3352, 21, 'اخر حفظ'),
(79310, 3356, 21, 'اخر تحديث بواسطة'),
(79311, 3357, 21, 'اخر تحقق في'),
(79312, 3358, 21, 'اخر زيارة'),
(79313, 3360, 21, 'اخر تجدد حدوث العرض (شهرين الى 12 شهر)'),
(79314, 3361, 21, 'الكعب الوحشي'),
(79315, 3362, 21, 'الكعب الوحشي :'),
(79316, 3363, 21, 'التجانب'),
(79317, 3364, 21, 'تجانب هذة العملية, لو قابل للتطبيق'),
(79318, 3365, 21, 'تغير نقطة اقصي ضربات القلب'),
(79319, 3373, 21, 'معتمد علي التخطيط'),
(79320, 3374, 21, 'محرر التخطيط'),
(79321, 3375, 21, 'مجموعات التخطيط'),
(79322, 3376, 21, 'اسلوب التخطيط'),
(79323, 3378, 21, 'طلبات الزيارة المعتمدة على التخطيط'),
(79324, 3379, 21, 'المخططات'),
(79325, 3380, 21, 'رطل'),
(79326, 3381, 21, 'ارطال'),
(79327, 3382, 21, 'الكلستيرول قليل الكثافة'),
(79328, 3383, 21, 'اتركه فارغا لو كان نشطا'),
(79329, 3384, 21, 'اتركه فارغا لإستبقاء الإسم الأصلي'),
(79330, 3385, 21, 'اتركه فارغا لإستبقاء كلمة السر الأصلية'),
(79331, 3386, 21, 'اترك رسالة مع'),
(79332, 3387, 21, 'اترك النموذج'),
(79333, 3388, 21, 'ترك عبارة السر فارغة لن يشفر الوثيقة'),
(79334, 3390, 21, 'يسار'),
(79335, 3391, 21, 'الأذن اليسرى'),
(79336, 3392, 21, 'الأذن اليسرى'),
(79337, 3394, 21, 'يسار:'),
(79338, 3395, 21, 'يسار: '),
(79339, 3396, 21, 'ألم بالساق / تشنج'),
(79340, 3397, 21, 'قانوني'),
(79341, 3399, 21, 'حجم الورقة القانوني'),
(79342, 3400, 21, 'علامة فارقة:'),
(79343, 3401, 21, 'طول'),
(79344, 3402, 21, 'طول المُعدل, 0 لو لا يوجد'),
(79345, 3403, 21, 'أقل من'),
(79346, 3404, 21, 'أقل من أو يساوي'),
(79347, 3405, 21, 'معلومات قليلة الخصوصية (اكتب, الإضافه إختيارية)'),
(79348, 3406, 21, 'رسالة'),
(79349, 3407, 21, 'مكون الرسالة'),
(79350, 3408, 21, 'حجم ورقة الرسالة'),
(79351, 3409, 21, 'الرسالة التي يوقعها الطبيب'),
(79352, 3410, 21, 'الرسالة التي يوقعها المريض'),
(79353, 3411, 21, 'مستوي العجلة'),
(79354, 3412, 21, 'مسئولية'),
(79355, 3413, 21, 'مسئولية طبية'),
(79356, 3414, 21, 'الرخصة/الهوية'),
(79357, 3419, 21, 'الإسم الأخير للطبيب المرخص'),
(79358, 3420, 21, 'رقم الترخيص للطبيب المرخص'),
(79359, 3421, 21, 'رقم الترخيص العالمي للطبيب المرخص'),
(79360, 3423, 21, 'اسلوب الحياة'),
(79361, 3424, 21, 'حالة اسلوب الحياة'),
(79362, 3425, 21, 'تمزق او تهتك الرباط'),
(79363, 3426, 21, 'مدخن خفيف'),
(79364, 3428, 21, 'حدود الأحداث'),
(79365, 3429, 21, 'حدود'),
(79366, 3431, 21, 'وصلة'),
(79367, 3432, 21, 'وصلة للمريض'),
(79368, 3433, 21, 'تم التوصيل'),
(79369, 3434, 21, 'وثيقة موصولة'),
(79370, 3435, 21, 'طلب إجراء موصول'),
(79371, 3436, 21, 'تم التوصيل للوثيقة'),
(79372, 3437, 21, 'تم التوصيل لطلب الإجراء'),
(79373, 3438, 21, 'قائمة'),
(79374, 3439, 21, 'صندوق قائمة'),
(79375, 3440, 21, 'صندوق قائمة'),
(79376, 3441, 21, 'صندوق قائمة مع الزيادة'),
(79377, 3442, 21, 'صندوق قائمة مع الزيادة'),
(79378, 3443, 21, 'محرر القائمة'),
(79379, 3444, 21, 'زيارات القائمة'),
(79380, 3445, 21, 'مجموعات القائمة'),
(79381, 3446, 21, 'قائمة شركات التأمين'),
(79382, 3448, 21, 'قائمة البنود لا يمكن أن تبدأ برقم'),
(79383, 3449, 21, 'قائمة البنود تحتوي علي احرف غير قانونية'),
(79384, 3451, 21, 'قائمة القوائم'),
(79385, 3452, 21, 'قائمة الإسم'),
(79386, 3453, 21, 'لا يمكن أن تبدأ برقم'),
(79387, 3454, 21, 'قائمة الوصفات'),
(79388, 3455, 21, 'اختيار قائمة بيانات الدولة المستخدمة أعلاه'),
(79389, 3456, 21, 'اختيار قائمة بيانات الولاية المستخدمة أعلاه'),
(79390, 3457, 21, 'يتم الإستماع الى المنفذ RFC 5425 TLS'),
(79391, 3458, 21, 'قوائم'),
(79392, 3459, 21, 'لثواني'),
(79393, 3460, 21, 'حب الحياة'),
(79394, 3461, 21, 'LLL:'),
(79395, 3462, 21, 'اخر دورة شهرية'),
(79396, 3463, 21, 'حمّل الخلاصة'),
(79397, 3464, 21, 'حمّل التعريفات'),
(79398, 3465, 21, 'حمّل إعدادات المختير'),
(79399, 3466, 21, 'حمّل إختيارات الأسئلة OE'),
(79400, 3467, 21, 'حمّل تعريفات الأوامر'),
(79401, 3468, 21, 'حمّل أسئلة ترتيب الإدخال'),
(79402, 3470, 21, 'جاري التحميل'),
(79403, 3471, 21, 'جاري تحميل الملفات الي قاعدة البيانات. سيأخذ هذا بعض الوقت...'),
(79404, 3472, 21, 'الموقع'),
(79405, 3473, 21, 'محلي'),
(79406, 3476, 21, 'موضع'),
(79407, 3477, 21, 'بيئة'),
(79408, 3478, 21, 'الموقع'),
(79409, 3479, 21, 'موقع حاسوب البرنامج و يمكن أن تحتوي علي معلومات حساسة و لذلك ينصح بحذفها يدوياَ بعد الإستخدام'),
(79410, 3480, 21, 'موقع هذة البضاعة'),
(79411, 3481, 21, 'لم يتم تحيدي الموقع'),
(79412, 3482, 21, 'موقع تخزين Hylafax للفاكس'),
(79413, 3483, 21, 'موقع تخزين المسح الضوئي'),
(79414, 3484, 21, 'الموقع:'),
(79415, 3485, 21, 'قفل'),
(79416, 3492, 21, 'تسجيل الدخول'),
(79417, 3493, 21, 'تسجيل الدخول'),
(79418, 3494, 21, 'تسجيل خروج'),
(79419, 3495, 21, 'تم الدخول'),
(79420, 3496, 21, 'تسجيل الدخول كـ'),
(79421, 3497, 21, 'تسجيل الدخول كــ : '),
(79422, 3498, 21, 'تم الخروج'),
(79423, 3499, 21, 'يتم الدخول'),
(79424, 3500, 21, 'الولوج'),
(79425, 3501, 21, 'الولوج'),
(79426, 3503, 21, 'الولوج الي المستضيف القاصي'),
(79427, 3504, 21, 'فشل الولوج الي المستضيف القاصي'),
(79428, 3505, 21, 'الخروج'),
(79429, 3506, 21, 'الخروج'),
(79430, 3507, 21, 'السجلات'),
(79431, 3508, 21, 'متصفح السجلات'),
(79432, 3510, 21, 'البحث عن'),
(79433, 3511, 21, 'بضاعة بالجملة'),
(79434, 3512, 21, 'رقم هوية بضاعة بالجملة مفقود'),
(79435, 3513, 21, 'رقم بضاعة بالجملة'),
(79436, 3514, 21, 'منخفض'),
(79437, 3515, 21, 'ذا اهمية منخفضة'),
(79438, 3516, 21, 'الرجل السفلي'),
(79439, 3517, 21, 'اقل أهمية'),
(79440, 3519, 21, 'الفقرات القطنية'),
(79441, 3520, 21, 'وجبة الغداء'),
(79442, 3521, 21, 'وجبة الغداء'),
(79443, 3522, 21, 'سرطان الرئة'),
(79444, 3523, 21, 'جراحة لسرطان الرئة'),
(79445, 3524, 21, 'الرئتين:'),
(79446, 3525, 21, 'الرئتين:'),
(79447, 3526, 21, 'الذئبة'),
(79448, 3528, 21, 'م'),
(79449, 3529, 21, 'تصنيف الإجهاض الطبي'),
(79450, 3530, 21, 'عميل الإجهاض الطبي يقبل الإجهاض'),
(79451, 3531, 21, 'معطيات الإجهاض الطبي'),
(79452, 3533, 21, 'تم إرسال البريد'),
(79453, 3534, 21, 'رئيسي'),
(79454, 3535, 21, 'العنوان الرئيسي'),
(79455, 3536, 21, 'النافذة العلوية الرئيسية من الشاشة'),
(79456, 3537, 21, 'أبق على قائمة أدوية الحساسية قيد الإستعمال'),
(79457, 3538, 21, 'أبق على الأدوية قيد الإستعمال'),
(79458, 3539, 21, 'أبق على قائمة المشاكل للتشخيص الحالي النشط'),
(79459, 3540, 21, 'اضافة تعديلات على القوائم الحالية'),
(79460, 3541, 21, 'إجراء موعد جديد ل'),
(79461, 3542, 21, 'كن متأكداَ'),
(79462, 3543, 21, 'جارى تكوين مجموعة ملفات نصية للرفع الي شركة التأمين و سيتم تصنيفها كمفوترة'),
(79463, 3545, 21, 'وعكة-شعور بالضيق'),
(79464, 3548, 21, 'ذكر'),
(79465, 3549, 21, 'واقي ذكري'),
(79466, 3550, 21, 'عقم جراحي اختياري للذكور'),
(79467, 3552, 21, 'صورة شعاعية للثدي'),
(79468, 3553, 21, 'أدار'),
(79469, 3556, 21, 'ادارة الترجمة'),
(79470, 3557, 21, 'أدارة'),
(79471, 3558, 21, 'اجباري وحقول محددة'),
(79472, 3559, 21, 'اجباري او حقول محددة, اعادة تأكد بدون بحث'),
(79473, 3560, 21, 'اجباري او حقول محددة, بحث و اعادة تأكيد'),
(79474, 3561, 21, 'دليل الإستخدام'),
(79475, 3562, 21, 'إرسال يدوي'),
(79476, 3563, 21, 'مُصنّع'),
(79477, 3565, 21, 'مارس/اذار'),
(79478, 3568, 21, 'مارس/اذار'),
(79479, 3569, 21, 'الحالة الشخصية'),
(79480, 3571, 21, 'ضع علامة الفوترة لكن لا تفوتر'),
(79481, 3572, 21, 'ضع علامة كخالص'),
(79482, 3573, 21, 'ضع علامة كعدم مفوتر'),
(79483, 3574, 21, 'ضع علامة كمقروء على التقارير'),
(79484, 3575, 21, 'ضع علامة كخالص'),
(79485, 3576, 21, 'متزوج'),
(79486, 3578, 21, 'أخفي'),
(79487, 3579, 21, 'أخفي أرقام الإيصال'),
(79488, 3580, 21, 'أخفي رقم هوية المريض'),
(79489, 3581, 21, 'أخفي رقم هوية المنتج'),
(79490, 3582, 21, 'وفق'),
(79491, 3583, 21, 'وفق الحالة'),
(79492, 3591, 21, 'الأقصي'),
(79493, 3592, 21, 'تم التوصل الي أقصي حد للملفات - قم بإعادة الأسماء ادناه'),
(79494, 3594, 21, 'الفَكِّ العُلْوِيِّ‎ الأيمن'),
(79495, 3595, 21, 'الحد الأقصى للعمر'),
(79496, 3596, 21, 'الحد الأقصى للرموز'),
(79497, 3597, 21, 'وقت الخمول الأقصي المسموح به قبل الخروج.الحد الافتراضي هو 7200 (ساعتين)'),
(79498, 3600, 21, 'الحد الأقصي للجرد, 0 لو قابل للتطبيق'),
(79499, 3601, 21, 'المقاس الأقصى المسموح به'),
(79500, 3602, 21, 'المقاس الأقصى المسموح به (إدخال صفر سيسمح بأي مقاس)'),
(79501, 3603, 21, 'مايو/أيار'),
(79502, 3604, 21, 'ميكرو'),
(79503, 3605, 21, 'ميكروجرام'),
(79504, 3607, 21, 'يعني ان أياَ من كلمات السر الثلاثة السابقة غير مسموح بها'),
(79505, 3609, 21, 'قياس رمز المجموعة'),
(79506, 3611, 21, 'قياسات'),
(79507, 3612, 21, 'الكَعْبُ الإِنْسِيّ'),
(79508, 3613, 21, 'ميديكايد'),
(79509, 3614, 21, 'طبي'),
(79510, 3615, 21, 'إجهاض الطبي'),
(79511, 3616, 21, 'الأدارة الطبية'),
(79512, 3617, 21, 'التاريخ الطبي'),
(79513, 3618, 21, 'مشكلة طبية'),
(79514, 3619, 21, 'مشكلة طبية'),
(79515, 3620, 21, 'المشكلة المرضية'),
(79516, 3621, 21, 'المشكلة المرضية'),
(79517, 3622, 21, 'قائمة المشاكل الطبية'),
(79518, 3623, 21, 'المشاكل الطبية'),
(79519, 3624, 21, 'الملف الطبي'),
(79520, 3625, 21, 'رقم الملف الطبي'),
(79521, 3626, 21, 'الملفات الطبية'),
(79522, 3627, 21, 'تم إرسال الملفات الطبية'),
(79523, 3629, 21, 'تم إعطاء ملخص عن الحالة الطبية'),
(79524, 3630, 21, 'النظام الطبي'),
(79525, 3631, 21, 'النوع الطبي'),
(79526, 3632, 21, 'التاريخ/الطبي (اكتب، اﻹضافه اختيارية)'),
(79527, 3633, 21, 'ميديكير الجزء الثانى'),
(79528, 3634, 21, 'المحول لميديكير هو المخلص'),
(79529, 3635, 21, 'الأدوية'),
(79530, 3636, 21, 'قائمة الحساسية من الأدوية'),
(79531, 3637, 21, 'قائمة المشاكل من الأدوية'),
(79532, 3638, 21, 'قائمة الأدوية'),
(79533, 3639, 21, 'مراجعة الأدوية مع الأوامر العلاجية والمريض'),
(79534, 3640, 21, 'الأدوية'),
(79535, 3641, 21, 'الأدوية:'),
(79536, 3642, 21, 'وحدات الدواء'),
(79537, 3643, 21, 'متوسط'),
(79538, 3645, 21, 'تقرير إحصائى عن متعلقات العضو'),
(79539, 3646, 21, 'مشكلة في الذاكرة'),
(79540, 3647, 21, 'رجال'),
(79541, 3648, 21, 'رجال ونساء'),
(79542, 3649, 21, 'رجال فقط'),
(79543, 3650, 21, 'بَدْءُ الإِحَاضَة‎'),
(79544, 3651, 21, 'إنقطاع الطمث'),
(79545, 3652, 21, 'الدورة الشهرية'),
(79546, 3653, 21, 'تكرار الطمث'),
(79547, 3654, 21, 'اضْطِرابٌ نَفْسِي‎'),
(79548, 3657, 21, 'دمج'),
(79549, 3658, 21, 'إكتمال الدمج'),
(79550, 3659, 21, 'دمج المرضى'),
(79551, 3661, 21, 'رسالة-خطاب'),
(79552, 3662, 21, 'مركز الرسائل والتنبيهات'),
(79553, 3663, 21, 'محتويات الرسالة ليست خطيه بسيطة و لذلك تم تخزينها كوثيقة'),
(79554, 3665, 21, 'تم إرسال الرسالة'),
(79555, 3666, 21, 'حالة الرسالة'),
(79556, 3669, 21, 'نوعية الرسالة'),
(79557, 3670, 21, 'الرسالة:'),
(79558, 3671, 21, 'الرسائل'),
(79559, 3672, 21, 'الرسائل المرسلة اليوم'),
(79560, 3673, 21, 'الطريقة'),
(79561, 3674, 21, 'الطريقة ومنتج معين'),
(79562, 3675, 21, 'طريقة إرسال ايميل'),
(79563, 3676, 21, 'طريقة اﻻتلاف'),
(79564, 3677, 21, 'مكسيكي/ميكسيكي امريكى'),
(79565, 3679, 21, 'ملى جرام'),
(79566, 3680, 21, 'ملى جرام لكل 1 سى سى'),
(79567, 3681, 21, 'ملى جرام لكل 2 سى سى'),
(79568, 3682, 21, 'ملى جرام لكل 3 سى سى'),
(79569, 3683, 21, 'ملى جرام لكل 4 سى سى'),
(79570, 3684, 21, 'ملى جرام لكل 5 سى سى'),
(79571, 3685, 21, 'ملى جرام/ ديسى ليتر'),
(79572, 3686, 21, 'أوسط'),
(79573, 3687, 21, 'الأسم الأوسط'),
(79574, 3688, 21, 'الأسم الأوسط'),
(79575, 3690, 21, 'واصف دوائي مخدر متوسط المستوي'),
(79576, 3691, 21, 'الإسم الأول للواصف الدوائي متوسط المستوي'),
(79577, 3692, 21, 'الإسم الأخير للواصف الدوائي متوسط المستوي'),
(79578, 3693, 21, 'بادئة الواصف الدوائي متوسط المستوي'),
(79579, 3694, 21, 'رقم ممارسه المهنة العالمي للواصف الدوائي متوسط المستوي'),
(79580, 3695, 21, 'المظهر'),
(79581, 3696, 21, 'مهاجر او عامل موسمى؟'),
(79582, 3697, 21, 'مهاجر / موسمى'),
(79583, 3698, 21, 'مليون لكل مم مربع'),
(79584, 3702, 21, 'MimeType'),
(79585, 3703, 21, 'اﻻقل'),
(79586, 3704, 21, 'اﻻقل'),
(79587, 3705, 21, 'أقل سن'),
(79588, 3706, 21, 'اجهاد مفصل طفيف +/- التهاب زﻻلي'),
(79589, 3708, 21, 'دقيقة'),
(79590, 3709, 21, 'دقائق'),
(79591, 3710, 21, 'دقائق'),
(79592, 3712, 21, 'متنوع'),
(79593, 3713, 21, 'إختيارات فوترة متنوعة'),
(79594, 3714, 21, 'إختيارات فوترة متنوعة HCFA-1500'),
(79595, 3715, 21, 'إختيارات فوترة متنوعة HCFA'),
(79596, 3716, 21, 'متنوع'),
(79597, 3717, 21, 'لم يتم إدراكه'),
(79598, 3718, 21, 'مفقود'),
(79599, 3719, 21, 'حقل مطلوب ناقص'),
(79600, 3720, 21, 'مصروفات مفقودة'),
(79601, 3721, 21, 'مفقودى الإداريين فقط'),
(79602, 3722, 21, 'مفقود او غير صالح'),
(79603, 3723, 21, 'رقم الهوية الشخصية مفقود'),
(79604, 3724, 21, 'تاريخ التقرير مفقود'),
(79605, 3725, 21, 'رمز الشرطه مفقود بعد الدافع فى الكود الأصلي '),
(79606, 3726, 21, 'مخلط'),
(79607, 3727, 21, 'مل'),
(79608, 3728, 21, 'شهر/يوم/سنة'),
(79609, 3729, 21, 'مم من الزئبق'),
(79610, 3730, 21, 'مم زئبقي'),
(79611, 3731, 21, 'تطعيم الحصبة, الحصبة الألمانية و النكاف 1'),
(79612, 3732, 21, 'تطعيم الحصبة, الحصبة الألمانية و النكاف 2'),
(79613, 3733, 21, 'متحرك'),
(79614, 3734, 21, 'هاتف نقال'),
(79615, 3735, 21, 'مدير'),
(79616, 3738, 21, 'أهمية متوسطة'),
(79617, 3740, 21, 'أهمية متوسطة الي قليلة'),
(79618, 3741, 21, 'محّور'),
(79619, 3742, 21, 'محّورات'),
(79620, 3743, 21, 'يحّور'),
(79621, 3745, 21, 'يحّور المدفوعات'),
(79622, 3746, 21, 'ModLength'),
(79623, 3753, 21, 'الأثنين'),
(79624, 3754, 21, 'الأثنين الي الجمعه'),
(79625, 3755, 21, 'الأثنين الأربعاء و الجمعه'),
(79626, 3756, 21, 'الأثنين'),
(79627, 3758, 21, 'شهر'),
(79628, 3759, 21, 'شهر'),
(79629, 3760, 21, 'رؤية الشهر'),
(79630, 3761, 21, 'الأشهر'),
(79631, 3762, 21, 'الدخل الشهري'),
(79632, 3763, 21, 'اشهر'),
(79633, 3765, 21, 'تم العثور على اكثر من 100 ملف. الرجاء تحديد خصائص البحث اكثر'),
(79634, 3766, 21, 'تم العثور على اكثر من 50 ملف. الرجاء تحديد خصائص البحث اكثر'),
(79635, 3767, 21, 'معظم رؤوس الأعمدة يمكنك الظغط عليها لتغيير ترتيب العرض'),
(79636, 3768, 21, 'الأحدث من'),
(79637, 3770, 21, 'اخر تحديث للعلامات الحيوية من:'),
(79638, 3771, 21, 'الأم'),
(79639, 3772, 21, 'أسم الأم'),
(79640, 3774, 21, 'فم'),
(79641, 3775, 21, 'أنقل'),
(79642, 3776, 21, 'نقل الوثيقة الى القائمة'),
(79643, 3777, 21, 'أنقل الى الأسفل'),
(79644, 3778, 21, 'فشل النقل'),
(79645, 3779, 21, 'أنقل الى المريض'),
(79646, 3780, 21, 'أنقل الى'),
(79647, 3781, 21, 'أنقل الى اعلى'),
(79648, 3782, 21, 'يتم النقل'),
(79649, 3783, 21, 'السيد'),
(79650, 3784, 21, 'رقم السجّل الصحي'),
(79651, 3785, 21, 'السيدة'),
(79652, 3786, 21, 'اﻻنسة'),
(79653, 3787, 21, 'علوم الإدارة الصحية 11'),
(79654, 3788, 21, 'علوم الإدارة الصحية 3.1'),
(79655, 3789, 21, 'علوم الإدارة الصحية 4.1'),
(79656, 3790, 21, 'علوم الإدارة الصحية 5.1'),
(79657, 3791, 21, 'علوم الإدارة الصحية 6.1'),
(79658, 3794, 21, 'رمز خطة الرعاية الصحّية'),
(79659, 3795, 21, 'رمز إسترجاع تأمين خطة الرعاية الصحّية'),
(79660, 3796, 21, 'أداة متعددة اللغات'),
(79661, 3797, 21, 'عدة مناطق'),
(79662, 3798, 21, 'بإمكان ترفيع عدة ملفات بنفس الوقت وذلك بإختارهم مستخدما CTRL+Click او SHIFT+Click.'),
(79663, 3799, 21, 'بضاعة جمله متعددة'),
(79664, 3800, 21, 'بإمكانك الفصل بين أدوات التحوير بفواصل او مسافات, اربع علي اﻷكثر (M1:M2:M3:M4)'),
(79665, 3802, 21, 'متعدد الأعراق'),
(79666, 3803, 21, 'نَفْخَة:'),
(79667, 3804, 21, 'ألم العضلة'),
(79668, 3805, 21, 'ألام عضلية'),
(79669, 3806, 21, 'احمرار العضلة'),
(79670, 3807, 21, 'تصلب العضلة'),
(79671, 3808, 21, 'تورم العضلة'),
(79672, 3809, 21, 'سخونه العضلة'),
(79673, 3810, 21, 'عضلة'),
(79674, 3811, 21, 'إصابة عضلية'),
(79675, 3812, 21, 'عضلي هيكلي'),
(79676, 3813, 21, 'يجب ان يكون خاليا اذا لم تستخدم التأكد من SMTP'),
(79677, 3814, 21, 'معّرف بالإجماع'),
(79678, 3815, 21, 'اﻹجهاض بالشفط اليدوي'),
(79679, 3818, 21, 'أنا'),
(79680, 3821, 21, 'غير متاح'),
(79681, 3822, 21, 'غير متاح'),
(79682, 3823, 21, 'الأسم'),
(79683, 3825, 21, 'الأسم ( اضغط لرؤية المزيد )'),
(79684, 3826, 21, 'الأسم 1'),
(79685, 3827, 21, 'الأسم 2'),
(79686, 3828, 21, 'اسم و توصيف مدير التطعيمات'),
(79687, 3831, 21, 'أسماء الأحداث'),
(79688, 3832, 21, 'أسم شركة التأمين'),
(79689, 3833, 21, 'أسم مقدم الخدمة'),
(79690, 3834, 21, 'أسم مرسل التنبيهات للمريض'),
(79691, 3835, 21, 'ترجمة الأسم'),
(79692, 3836, 21, 'الأسم-القيمة'),
(79693, 3837, 21, 'الأسم :'),
(79694, 3838, 21, 'فتحة اﻷنف:'),
(79695, 3839, 21, 'فتحة اﻷنف: اليمني طبيعية'),
(79696, 3840, 21, 'الغشاء المخاطي للأنف وردي اللون و الحاجز فى المنتصف'),
(79697, 3841, 21, 'ملاحظات اﻷمة'),
(79698, 3842, 21, 'تهيئة ملاحظات اﻷمة'),
(79699, 3843, 21, 'إبدال أزرار ملاحظات اﻷمة'),
(79700, 3844, 21, 'الجنسية'),
(79701, 3845, 21, 'ملاحظات اﻷمة'),
(79702, 3847, 21, 'من هاواي او من سكان جزر المحيط الهادئ'),
(79703, 3852, 21, 'إشمئزاز'),
(79704, 3854, 21, 'إبحار'),
(79705, 3855, 21, 'منطقة الإبحار تشمل طلبات الزيارة'),
(79706, 3856, 21, 'منطقة الإبحار تستخدم الطول الكامل لهيكل الإطار'),
(79707, 3857, 21, 'منطقة إبحار طلبات الزيارة'),
(79708, 3858, 21, 'عرض منطقة الإبحار'),
(79709, 3859, 21, 'قائمة الإبحار تتكون من ازواج لأزرار الراديو'),
(79710, 3860, 21, 'قائمة الإبحار هي منظر شجري'),
(79711, 3861, 21, 'الإبحار يستخدم قائمة منزلقة'),
(79712, 3862, 21, 'رمز الدواء الوطني'),
(79713, 3863, 21, 'بيانات رمز الدواء الوطني'),
(79714, 3864, 21, 'رقم رمز الدواء الوطني'),
(79715, 3866, 21, 'رقبة'),
(79716, 3867, 21, 'مشاكل الرقبة'),
(79717, 3868, 21, 'ليونة الرقبة'),
(79718, 3869, 21, 'تحتاج لإدخال وصف'),
(79719, 3870, 21, 'تحتاج لإدخال قيمة رجعية'),
(79720, 3871, 21, 'تحتاج لإدخال معرّف'),
(79721, 3872, 21, 'تحتاج لإدخال عنوان'),
(79722, 3873, 21, 'تحتاج لتصريح'),
(79723, 3874, 21, 'تحتاج لتعديل الحواف'),
(79724, 3875, 21, 'تحتاج لفوترة ثانوية'),
(79725, 3876, 21, 'سلبي'),
(79726, 3877, 21, 'سلبيات'),
(79727, 3880, 21, 'إصابة عصب'),
(79728, 3881, 21, 'حالة عصبية / تلف عصبي'),
(79729, 3882, 21, 'تخدر الأعصاب'),
(79730, 3883, 21, 'وهن عصبي'),
(79731, 3884, 21, 'عصبي'),
(79732, 3885, 21, 'ابدا'),
(79733, 3886, 21, 'لم يشرب الكحول أبداٌ'),
(79734, 3887, 21, 'لم يدخن ابدا'),
(79735, 3888, 21, 'جديد'),
(79736, 3889, 21, 'جديد =>'),
(79737, 3890, 21, 'مستقبلين جدد'),
(79738, 3892, 21, 'حساسية جديدة'),
(79739, 3894, 21, 'موعد جديد'),
(79740, 3895, 21, 'اصناف جديدة'),
(79741, 3896, 21, 'صنف جديد'),
(79742, 3897, 21, 'عملاء جدد'),
(79743, 3898, 21, 'إستشارة جديدة'),
(79744, 3899, 21, 'حصاد جديد'),
(79745, 3900, 21, 'تمت إضافة مجموعة تعريف جديدة'),
(79746, 3901, 21, 'ملف جديد'),
(79747, 3902, 21, 'ملفات جدد'),
(79748, 3904, 21, 'زيارة جديدة'),
(79749, 3905, 21, 'تم تكوين زيارة جديدة برقم الهوية'),
(79750, 3906, 21, 'استمارة زيارة جديدة'),
(79751, 3907, 21, 'الزيارات الجديدة لم تعتمد'),
(79752, 3908, 21, 'زيارة جديدة'),
(79753, 3909, 21, 'معلومات منشأة جديدة'),
(79754, 3910, 21, 'ملف جديد'),
(79755, 3911, 21, 'ملفات جدد'),
(79756, 3912, 21, 'مجموعة جديدة'),
(79757, 3913, 21, 'معلومات مجموعة جديدة'),
(79758, 3914, 21, 'إصابة جديدة'),
(79759, 3916, 21, 'الحّد الجديد للأحداث'),
(79760, 3917, 21, 'قائمة جديدة'),
(79761, 3918, 21, 'أومر جديدة'),
(79762, 3919, 21, 'فقرة جديدة'),
(79763, 3920, 21, 'كلمة سر جديدة'),
(79764, 3921, 21, 'مريض جديد'),
(79765, 3922, 21, 'مريض جديد'),
(79766, 3923, 21, 'زيارة مريض جديدة'),
(79767, 3924, 21, 'نموذج جديد للمريض'),
(79768, 3925, 21, 'رقم مريض جديد'),
(79769, 3926, 21, 'دفعة جديدة'),
(79770, 3928, 21, 'مريض جديد'),
(79771, 3929, 21, 'نتائج جديدة من شبكة المختبرات لتبادل النتائج'),
(79772, 3930, 21, 'بحث جديد'),
(79773, 3931, 21, 'تسليمات جديدة'),
(79774, 3932, 21, 'مستخدم جديد'),
(79775, 3934, 21, 'زيارة جديدة'),
(79776, 3935, 21, 'جديد/ بحث'),
(79777, 3936, 21, 'حالة حساب NewCrop'),
(79778, 3937, 21, 'مدير NewCrop'),
(79779, 3938, 21, 'فشل استدعاء NewCrop'),
(79780, 3939, 21, 'طبيب NewCrop'),
(79781, 3944, 21, 'اسم NewCrop eRx'),
(79782, 3945, 21, 'اسم زميل NewCrop eRx'),
(79783, 3946, 21, 'كلمة سر NewCrop eRx'),
(79784, 3947, 21, 'دور NewCrop eRx'),
(79785, 3948, 21, 'دور NewCrop eRx'),
(79786, 3949, 21, 'عنوان موقع NewCrop eRx'),
(79787, 3954, 21, 'عنوان مساعدة الانترنت NewCrop eRx'),
(79788, 3955, 21, 'مدير NewCrop'),
(79789, 3956, 21, 'مدخل طبي NewCrop'),
(79790, 3957, 21, 'واصف متوسط المستوي NewCrop'),
(79791, 3958, 21, 'ممرضة NewCrop'),
(79792, 3959, 21, 'طبيب مشرف NewCrop'),
(79793, 3961, 21, 'صحيفة'),
(79794, 3962, 21, 'التالي'),
(79795, 3964, 21, 'اليوم التالي'),
(79796, 3965, 21, 'الشهر القادم'),
(79797, 3966, 21, 'الشهر القادم (انتظر للقائمة)'),
(79798, 3967, 21, 'التشغيل المؤقت التالي'),
(79799, 3968, 21, 'الأسبوع القادم'),
(79800, 3969, 21, 'العام القادم (انتظر للقائمة)'),
(79801, 3971, 21, 'أسم الدلع'),
(79802, 3973, 21, 'تعرق ليلي'),
(79803, 3974, 21, 'ضمن الحدود الطبيعية: الأعضاء التناسلية الخارجية, غشاء المهبل و عنق الرحم'),
(79804, 3975, 21, 'لا'),
(79805, 3976, 21, 'لا'),
(79806, 3977, 21, 'ممنوع الدخول'),
(79807, 3978, 21, 'لا يوجد تذكيرات نشطة للمريض'),
(79808, 3979, 21, 'لا تضخم للغدد (مطلوب منطقتين)'),
(79809, 3980, 21, 'لا يوجد سبب للتعديل'),
(79810, 3981, 21, 'لا الم او كتل متعلق بالمُلْحَقَات'),
(79811, 3983, 21, 'لا يوجد موعد'),
(79812, 3985, 21, 'لا يوجد نظام فوترة نشط'),
(79813, 3986, 21, 'لا توجد فواتير لتشمل فى تصدير OFX'),
(79814, 3987, 21, 'لا توجد فواتير لتشمل فى تصدير OFX'),
(79815, 3989, 21, 'لم يتم تعيين رمز!'),
(79816, 3992, 21, 'لا يوجد تشخيص'),
(79817, 3993, 21, 'لم يتم العثور علي الوثائق'),
(79818, 3994, 21, 'لم نستطع إنشاء زيارة جديدة'),
(79819, 3995, 21, 'لا يوجد تاريخ إنتهاء'),
(79820, 3996, 21, 'لم يتم العثور علي الإدخالات, إستخدم الطلب أدناة لإضافة إدخال'),
(79821, 3997, 21, 'لم يتم العثور على خطأ'),
(79822, 3998, 21, 'لا أحداث'),
(79823, 4000, 21, 'لا توجد ملفات للتثبيت'),
(79824, 4001, 21, 'لم يتم إختيار المجموعة'),
(79825, 4002, 21, 'لا يوجد فتاق'),
(79826, 4005, 21, 'لا يوجد إصابة /مرض'),
(79827, 4006, 21, 'لم يتم العثور عى شركة التأمين'),
(79828, 4007, 21, 'لا يوجد مشاكل'),
(79829, 4008, 21, 'لا يوجد مشاكل في هذه الزياة'),
(79830, 4009, 21, 'لا بنود تحت التصنيف المختار'),
(79831, 4010, 21, 'لم يتم اختيار بنود!'),
(79832, 4025, 21, 'لم يتم العثور عل ملف تسجيل لليوم المختار'),
(79833, 4027, 21, 'لا تكتلات او اﻻم'),
(79834, 4028, 21, 'لم يتم العثور علي مريض متطابق لرمز اعادة التعريف'),
(79835, 4029, 21, 'لم يتم العثور على تطايق,اعد البحث مرة اخرى'),
(79836, 4030, 21, 'لم يتم العثور علي نتائج متطابقة'),
(79837, 4031, 21, 'لم يتم العثور علي نتائج متطابقة. كوّن مريض جديد الان؟'),
(79838, 4032, 21, 'لم يتم العثور علي سجلات متطابقة'),
(79839, 4033, 21, 'لم يتم العثور على نتائج جديدة'),
(79840, 4034, 21, 'لا ملاحظات'),
(79841, 4035, 21, 'لا تضخم للأحشاء او الأعضاء الداخلية'),
(79842, 4036, 21, 'لا فرص مفتوحة لهذة الفترة.'),
(79843, 4037, 21, 'لا يوجد ارقام هاتف اخري مدرجه'),
(79844, 4039, 21, 'لم يتم العثور علي زملاء'),
(79845, 4040, 21, 'لم يتم العثور علي سجل للمريض للمعطيات المختارة'),
(79846, 4041, 21, 'لم يتم العثور علي مريض لرمز اعادة التعريف'),
(79847, 4042, 21, 'لا يوجد اِستِسقاء فى الأطراف'),
(79848, 4043, 21, 'لم يتم العثور على صيدليات'),
(79849, 4044, 21, 'لم يتم العثور على وصفات'),
(79850, 4045, 21, 'لا يوجد مرض حالي / إصابة'),
(79851, 4046, 21, 'لا يوجد مدخلات سابقة'),
(79852, 4047, 21, 'لم يتم إختيار منشأة العمل الرئيسية فى قائمة المنشأت'),
(79853, 4048, 21, 'لا يوجد زيارة سابقة'),
(79854, 4049, 21, 'لا يوجد عمليات في هذه الزيارة'),
(79855, 4051, 21, 'لم يتم العثور على مزودين'),
(79856, 4052, 21, 'لا يوجد طفح جلدي'),
(79857, 4053, 21, 'لك يتم العثور على الملف'),
(79858, 4055, 21, 'لك يتم العثور على الملف. الرجاء توسيع متطلبات البحث'),
(79859, 4056, 21, 'لا يوجد تذكيرات'),
(79860, 4057, 21, 'لم يتم العثور على نتائج لمتطلبات البحث أعلاة'),
(79861, 4058, 21, 'لا توجد نتائج'),
(79862, 4059, 21, 'لم يتم العثور على نتائج'),
(79863, 4060, 21, 'لم يتم العثور على نتائج للبحث'),
(79864, 4061, 21, 'لا يتم العثور على نتائج, الرجاء المحاولة مرة آخرى'),
(79865, 4062, 21, 'لا يوجد نتائج, الرجاء المحاولة مرة آخرى'),
(79866, 4063, 21, 'لا يوجد نتائج, الرجاء المحاولة مرة آخرى'),
(79867, 4065, 21, 'لم يحضر المريض للزيارة'),
(79868, 4067, 21, 'لا إيلامٌ فى الجيوب:'),
(79869, 4068, 21, 'لا تكّور فى الجلد او عقد فى الثدي'),
(79870, 4069, 21, 'لا يوجد مثل سياق الإسم هذا'),
(79871, 4070, 21, 'لم يتم أختيار جدول ! يرجى أختيار جدول.'),
(79872, 4071, 21, 'لا يوجد إيلام او تكتلات بالخصية'),
(79873, 4072, 21, 'لا توجد دبيبة او اهتزازات قلبية'),
(79874, 4075, 21, 'لا توجد زيارة'),
(79875, 4076, 21, 'لم يتم تسجيل اي مؤشرات حيوية'),
(79876, 4077, 21, 'لا, الغ العملية'),
(79877, 4078, 21, 'لا - خطأ تأميني متضمن اوتو هو الأولي'),
(79878, 4079, 21, 'لا:'),
(79879, 4080, 21, 'سلس ليلي'),
(79880, 4081, 21, 'غير مدفوع'),
(79881, 4082, 21, 'تقرير غير مقرر'),
(79882, 4083, 21, 'الإصابة غير محددة'),
(79883, 4084, 21, 'غير الكتروني'),
(79884, 4085, 21, 'النوع الثاني من السكري غير المعتمد علي الإنسولين'),
(79885, 4086, 21, 'غير مؤمن'),
(79886, 4087, 21, 'طبي ولكن غير صحي تناسلي او جنسي'),
(79887, 4088, 21, 'غير طبي و غير صحي تناسلي او جنسي'),
(79888, 4089, 21, 'ولا واحِد'),
(79889, 4090, 21, 'ولا واحِد'),
(79890, 4091, 21, 'ولا واحِد معرّف'),
(79891, 4092, 21, 'ولا واحِد موثق'),
(79892, 4093, 21, 'ولا واحِد مما سبق'),
(79893, 4094, 21, 'ولا واحِد من أسطر التوزيع العلويين يمكن أن يكون فارغا'),
(79894, 4095, 21, 'النوع الثاني من السكري غير المعتمد علي الإنسولين'),
(79895, 4096, 21, 'و لا حتي'),
(79896, 4097, 21, 'طبيعي'),
(79897, 4098, 21, 'طبيعي للجهتين'),
(79898, 4099, 21, 'فحص قلبي طبيعي:'),
(79899, 4100, 21, 'فحص قلبي طبيعي: '),
(79900, 4101, 21, 'فحص رئوي طبيعي:'),
(79901, 4102, 21, 'فحص رئوي طبيعي: '),
(79902, 4103, 21, 'زيارة عيادة طبيعية:'),
(79903, 4104, 21, 'فم و حنجرة طبيعيين:'),
(79904, 4105, 21, 'طبيعي يمينا'),
(79905, 4106, 21, 'طبيعي يمينا:'),
(79906, 4107, 21, 'منظر طبيعي'),
(79907, 4108, 21, 'طبيعي:'),
(79908, 4109, 21, 'من الطبيعي ان يفحص هذا. غير متعلق بتحكم الوصول.'),
(79909, 4112, 21, 'نرويجي'),
(79910, 4115, 21, 'أنف'),
(79911, 4116, 21, 'رُعاف'),
(79912, 4117, 21, 'ليس حرفا او رقما'),
(79913, 4119, 21, 'ليست كل الحقول مطلوبة لكل الرموز او انواعها'),
(79914, 4120, 21, 'غير مسموح'),
(79915, 4121, 21, 'غير مسموح بحذف مجموعة المدراء'),
(79916, 4122, 21, 'التعديل غير مسموح'),
(79917, 4123, 21, 'غير مسموح بتعطيل كل متعلقات الحماية'),
(79918, 4124, 21, 'غير مسموح بتعطيل اي شئ من ACL المدراء'),
(79919, 4125, 21, 'غير مسموح بحذف المستخدم المدير من مجموعة المدراء'),
(79920, 4126, 21, 'غير مسموح بحذف هذا المستخدم من مجموعة المدراء'),
(79921, 4127, 21, 'غير قابل للتطبيق'),
(79922, 4128, 21, 'غير مسموح بالعبور الي PostCalendar module'),
(79923, 4129, 21, 'غير مصّرح'),
(79924, 4130, 21, 'غير مصّرح'),
(79925, 4131, 21, 'غير مصّرح لهذه الفرقة!'),
(79926, 4132, 21, 'غير مصّرح لهذه الفرقة.'),
(79927, 4133, 21, 'غير مصّرح بالتحكم فى المستخدمين!'),
(79928, 4134, 21, 'غير مصّرح بالتوقيع علي النتائج'),
(79929, 4135, 21, 'غير متوفر'),
(79930, 4137, 21, 'غير مفوتر'),
(79931, 4138, 21, 'غير مدقق'),
(79932, 4139, 21, 'غير مخرج'),
(79933, 4140, 21, 'غير مرمّز'),
(79934, 4141, 21, 'غير مستحق'),
(79935, 4143, 21, 'لم يفحص بعد'),
(79936, 4144, 21, 'لم يفحص بعد:'),
(79937, 4145, 21, 'لم يفحص بعد: '),
(79938, 4146, 21, 'تعذر العثور'),
(79939, 4148, 21, 'تعذر العثور!'),
(79940, 4149, 21, 'غير أسباني او لاتيني'),
(79941, 4150, 21, 'غير مثبّت'),
(79942, 4152, 21, 'لم يُر منذ'),
(79943, 4153, 21, 'لم يتم إرسالة'),
(79944, 4154, 21, 'لم يتم إرسالة بعد'),
(79945, 4155, 21, 'غير محدّد'),
(79946, 4156, 21, 'غير محدّد'),
(79947, 4157, 21, 'ملاحظة'),
(79948, 4158, 21, 'رموز الملاحظات'),
(79949, 4159, 21, 'لاحظ انها سوف تستغرق 5-10 دقائق للتشغيل بعد ان تعطي الامر بالتثبيت'),
(79950, 4160, 21, 'لاحظ انها سوف تستغرق 5-10 دقائق للتشغيل بعد ان تعطي الامر بالتثبيت'),
(79951, 4161, 21, 'لاحظ ان ولوج التدقيق يجب ان يكون مفعلا اعلاه'),
(79952, 4162, 21, 'نوع الملاحظة'),
(79953, 4163, 21, 'ملاحظة: 12:00 ظهرا هي PM و ليست AM'),
(79954, 4164, 21, 'ملاحظة: إستيراد البيانات الخارجية قد يستغرق وقتا يفوق الساعة علي حسب قوة جهازك. بعض بيانات RxNorm يحتوي علي أكثر من 6 ملايين سطر.'),
(79955, 4165, 21, 'ملاحظة: إصدار Snomed النصف سنوي هو الوحيد المدعّم حاليا'),
(79956, 4166, 21, 'ملاحظة: إصدار RxNorm الشهري الكامل هو الوحيد المدعّم حاليا'),
(79957, 4168, 21, 'ملاحظة: هذا الرمز لم يتم ادخالة بواسطة مستخدم مصرح له. الرموز المصرح لها هي الوحيدة المفعّلة. اذا اردت استخدامها فإختر مستخدما مصرح له'),
(79958, 4170, 21, 'ملاحظة: ترفيع ملفات بأسماء مكررة سيؤدي الي حذفها تلقائيا. أسماء الوثائق تعتبر فريدة لكل مريض و ليس لك مجموعة'),
(79959, 4171, 21, 'ملاحظة: ترفيع ملفات بأسماء مكررة سيؤدي الي حذفها تلقائيا. أسماء الوثائق تعتبر فريدة لكل مريض و ليس لك مجموعة'),
(79960, 4172, 21, 'ملاحظات'),
(79961, 4173, 21, 'ملاحظات - اي زيارة (اكتب, الإضافة إختيارية)'),
(79962, 4174, 21, 'ملاحظات - زياراتي (اكتب, الإضافة إختيارية)'),
(79963, 4175, 21, 'الملاحظات غير مصرح لها'),
(79964, 4177, 21, 'لم يتم تسجيل اي شيئ'),
(79965, 4179, 21, 'لم يتم استيراد اي شيئ للحساسية'),
(79966, 4180, 21, 'لم يتم استيراد اي شيئ للوصفة'),
(79967, 4181, 21, 'لا شيئ ليعرض'),
(79968, 4182, 21, 'لم يتم إختيار اي شيئ'),
(79969, 4184, 21, 'مذكرّة:: ايداع/ تعديل PostCalendar'),
(79970, 4185, 21, 'إشْعار'),
(79971, 4186, 21, 'إيميل إلاشْعار'),
(79972, 4188, 21, 'إشْعارات'),
(79973, 4189, 21, 'أشعر المدير بخصوص ايداع/ تعديل؟'),
(79974, 4190, 21, 'نوفمبر/تشرين الثاني'),
(79975, 4191, 21, 'نوفمبر/تشرين الثاني'),
(79976, 4192, 21, 'الان يتم الاعلام ل:'),
(79977, 4193, 21, 'تتم الطباعة اﻵن');
INSERT INTO `lang_definitions` VALUES
(79978, 4194, 21, 'تتم الطباعة اﻵن $stmt_count statements and updating encounters.'),
(79979, 4195, 21, 'تتم الطباعة اﻵن $stmt_count statements and updating invoices.'),
(79980, 4196, 21, 'تتم الطباعة اﻵن $stmt_count statements; encounters will not be updated.'),
(79981, 4197, 21, 'تتم الطباعة اﻵن $stmt_count statements; invoices will not be updated.'),
(79982, 4198, 21, 'رقم المزوّد الوطني'),
(79983, 4199, 21, 'هيكل النوعية الوطنية'),
(79984, 4200, 21, 'عدد'),
(79985, 4201, 21, 'عدد المختبرات'),
(79986, 4204, 21, 'عدد اﻷعمدة في منظر السنة'),
(79987, 4211, 21, 'عدد اﻷيام لصلاحية شهادة العميل'),
(79988, 4213, 21, 'عدد اﻷرقام بعد الفاصلة العشرية, عادة 0 او 2'),
(79989, 4214, 21, 'عدد الزيارات المعروضة لكل صفحة'),
(79990, 4215, 21, 'عدد المباريات او الحداث المفقودة لو وجدت'),
(79991, 4216, 21, 'عدد الساعات لإرسال تنبيهات اﻹيميل مقدما'),
(79992, 4217, 21, 'عدد الساعات لإرسال تنبيهات الهاتف مقدما'),
(79993, 4218, 21, 'عدد الساعات لإرسال تنبيهات الرسائل النصية القصيرة مقدما'),
(79994, 4221, 21, 'عدد اعمدة التاريخ المرضي'),
(79995, 4222, 21, 'عدد عرض المرضي لكل صفحة فى قائمة المرضي'),
(79996, 4223, 21, 'خذل'),
(79997, 4224, 21, 'بسط الكسر'),
(79998, 4225, 21, 'ترتيب العرض العددي'),
(79999, 4227, 21, 'تغذية'),
(80000, 4229, 21, 'O.A.F.V.'),
(80001, 4230, 21, 'نسبة تشبع اﻷوكسجين'),
(80002, 4231, 21, 'البدانة 1'),
(80003, 4232, 21, 'البدانة 2'),
(80004, 4233, 21, 'البدانة 3'),
(80005, 4234, 21, 'موضوعي'),
(80006, 4237, 21, 'المهنة'),
(80007, 4239, 21, 'الحدوث'),
(80008, 4240, 21, 'اكتوبر/تشرين اﻷول'),
(80009, 4241, 21, 'اكتوبر/تشرين اﻷول'),
(80010, 4242, 21, 'العين اليمني'),
(80011, 4243, 21, 'ل'),
(80012, 4244, 21, 'للكمية'),
(80013, 4245, 21, 'للحبوب'),
(80014, 4246, 21, 'للشهر كل'),
(80015, 4247, 21, 'ملاحظات العيادة'),
(80016, 4248, 21, 'مغلق'),
(80017, 4249, 21, 'ملاحظات العيادة'),
(80018, 4250, 21, 'زيارة العيادة'),
(80019, 4251, 21, 'مجموعات قياس مقاييس النوعية الطبية الرسمية (CQM)'),
(80020, 4252, 21, 'رابط تصفح بوابة المرضي خارج الموقع'),
(80021, 4253, 21, 'رابط تصفح بوابة المرضي خارج الموقع (رابط المريض)'),
(80022, 4254, 21, 'كلمة سر بوابة المرضي خارج الموقع'),
(80023, 4255, 21, 'كلمة سر بوابة المرضي خارج الموقع (أبق فارغا لو المريض غير مسجل)'),
(80024, 4256, 21, 'رقم هوية مزود بوابة المرضي خارج الموقع'),
(80025, 4257, 21, 'رقم هوية مزود بوابة المرضي خارج الموقع (أبق فارغا لو غير مسجل)'),
(80026, 4258, 21, 'عنوان موقع بوابة المرضي خارج الموقع'),
(80027, 4259, 21, 'عنوان موقع بوابة المرضي خارج الموقع (رابط المريض)'),
(80028, 4260, 21, 'إسم المستخدم لبوابة المرضي خارج الموقع'),
(80029, 4261, 21, 'إسم المستخدم لبوابة المرضي خارج الموقع (أبق فارغا لو غير مسجل)'),
(80030, 4263, 21, 'ذرّية'),
(80031, 4265, 21, 'مرهم'),
(80032, 4267, 21, 'موافق'),
(80033, 4269, 21, 'موافق لربط موضوع مؤرخ GCAC'),
(80034, 4270, 21, 'قديم'),
(80035, 4272, 21, 'عملاء قدامى'),
(80036, 4273, 21, 'كسر قديم غير / التحام خاطئ'),
(80037, 4274, 21, 'اسلوب ترتيب قديم بدون قائمة يسري'),
(80038, 4275, 21, 'اسلوب قديم لطلب بدون قائمة بحث أو تصحيح المتكرارت'),
(80039, 4277, 21, 'إحذف'),
(80040, 4278, 21, 'إحذف المحيطات'),
(80041, 4279, 21, 'إحذف معلومات أرباب العمل في ديموجرافيا المريض'),
(80042, 4280, 21, 'إحذف أرباب العمل'),
(80043, 4281, 21, 'إحذف الهيئة, طريق الإعطاء و الفاصل الزمني لتصبح جزءا من الجرعة'),
(80044, 4282, 21, 'إحذف التأمين و بعض اﻷشياء أﻷخري من طلب الديموجرافيا'),
(80045, 4283, 21, 'إحذف المستخدمين الداخليين؟'),
(80046, 4284, 21, 'إحذف طريقة الدفع من واجهة الدفع المشترك'),
(80047, 4285, 21, 'إحذف الي الولوج التلقائي'),
(80048, 4286, 21, 'عند'),
(80049, 4287, 21, 'عند'),
(80050, 4288, 21, 'حاضر'),
(80051, 4289, 21, 'عند الطلب'),
(80052, 4290, 21, 'فى الموقع'),
(80053, 4291, 21, 'تعيين منشأة التأمين أﻷولي يجب ان لا يتغير لانه مرتبط بخدمة الوصفة الإكترونية من NewCrop ePrescription'),
(80054, 4292, 21, 'ما أن تقوم بتغيير كلمة سرك يجب عليك إعادة الولوج'),
(80055, 4297, 21, 'الدعم على الإنترنت'),
(80056, 4298, 21, 'رابط الدعم على الإنترنت'),
(80057, 4299, 21, 'نشط فقط'),
(80058, 4300, 21, 'مطبق فقط لو المزود مختار بالأعلي. اﻷولي سيختار المرضي الذين يزودهم المزود اﻷولي'),
(80059, 4302, 21, 'فقط لو مكان الفوترة'),
(80060, 4303, 21, 'خامل فقط'),
(80061, 4304, 21, 'تابع لي فقط'),
(80062, 4305, 21, 'اضهر رموز التشخيص فقط'),
(80063, 4306, 21, 'اضهر رموز الخدمة لقرير المالية فقط'),
(80064, 4307, 21, 'رفّع الوصفات النشطة فقط'),
(80065, 4310, 21, 'بداية المرض:'),
(80066, 4311, 21, 'بداية المرض: '),
(80067, 4312, 21, 'بداية التورم:'),
(80068, 4313, 21, 'تاريخ إدخال المستشفي:'),
(80069, 4314, 21, 'عنوان موقع بوباة المريض علي الإنترنت'),
(80070, 4315, 21, 'عفوا!'),
(80071, 4316, 21, 'فتح'),
(80072, 4318, 21, 'إفتح في نافذة جديدة'),
(80073, 4321, 21, 'فتح زيارة اليوم'),
(80074, 4322, 21, 'إعدادات شهادة السلطه للبرنامج مهيئة أصلا'),
(80075, 4323, 21, 'مجموعة تطبيقات البرنامج'),
(80076, 4324, 21, 'ترقية قاعدة بيانات البرنامج'),
(80077, 4325, 21, 'ترقية قاعدة بيانات البرنامج لمسح الهوية'),
(80078, 4326, 21, 'البرنامج لم يتعرّف علي الملف القادم فى مجلد contrib. This is most likely because you need to configure the release in the supported_external_dataloads table in the MySQL database.'),
(80079, 4327, 21, 'يجب علي البرنامج ان يهيئ لإستخدام الشهادات قبل ان يتمكن من اصدار شهادات للعميل'),
(80080, 4328, 21, 'البرنامج يحتاج اليJavascript ليقوم بالتأكد من المستخدم'),
(80081, 4329, 21, 'مستخدمي البرنامج'),
(80082, 4330, 21, 'افتتاحيات'),
(80083, 4332, 21, 'عيون'),
(80084, 4333, 21, 'خيار'),
(80085, 4334, 21, 'خيار لطريقة حفظ تخزين الوثيقة'),
(80086, 4335, 21, 'خيار لدعم المخزون و مبيعات المنتجات'),
(80087, 4336, 21, 'إختياري'),
(80088, 4337, 21, 'إسم المجموعة الإختيارية لبطاقة هوية المريض التي يمكن رؤيتها من صفحة ملخّص المريض'),
(80089, 4338, 21, 'إسم المجموعة الإختيارية للصور التي يمكن رؤيتها من صفحة ملخّص المريض'),
(80090, 4339, 21, 'إسم المجموعة الإختيارية للوثيقة التي يمكن ربطها من صفحة ملخّص المريض'),
(80091, 4340, 21, 'المجال الإفتراضي الإختياري للإدخال اليدوي للنتائج'),
(80092, 4341, 21, 'الوحدات الإفتراضية الإختيارية للإدخال اليدوي للنتائج'),
(80093, 4342, 21, 'إسم الوصول الإختياري'),
(80094, 4343, 21, 'إسم الدواء الإختياري, إستخدم % كرمز مبهم للبحث'),
(80095, 4345, 21, 'معلومات اختيارية عن هذا الحدث'),
(80096, 4346, 21, 'إسم الجملة الإختياري, إستخدم % كرمز مبهم للبحث'),
(80097, 4347, 21, 'رقم هوية المريض الإختياري'),
(80098, 4348, 21, 'رمز العملية الإختياري'),
(80099, 4349, 21, 'رمز العملية /الخدمة الإختياري'),
(80100, 4350, 21, 'خيارات'),
(80101, 4351, 21, 'أو'),
(80102, 4352, 21, 'أو'),
(80103, 4353, 21, 'أو أختار'),
(80104, 4354, 21, 'أو اضغط وأسحب لإختيار أسرع'),
(80105, 4356, 21, 'أو أخرج الي'),
(80106, 4358, 21, 'إضغط مع Shift للتصغير'),
(80107, 4359, 21, 'أو رفّع ملف ERA:'),
(80108, 4360, 21, 'فموي'),
(80109, 4361, 21, 'عشاء الفم وردي و البلعوم صافي'),
(80110, 4362, 21, 'طلب'),
(80111, 4363, 21, 'نوع الطلب والنتيجة'),
(80112, 4364, 21, 'دليل الطلب'),
(80113, 4365, 21, 'تاريخ الطلب'),
(80114, 4367, 21, 'إستمارة الطلب'),
(80115, 4368, 21, 'رقم الطلب'),
(80116, 4369, 21, 'رقم الطلب يجب ان يكون من 1 الي 999'),
(80117, 4370, 21, 'أسم الطلب'),
(80118, 4371, 21, 'أولوية الطلب'),
(80119, 4372, 21, 'معالج الطلب'),
(80120, 4373, 21, 'نتائج الطلب'),
(80121, 4374, 21, 'حالة الطلب'),
(80122, 4375, 21, 'حالة الطلب'),
(80123, 4376, 21, 'ملخص الطلب'),
(80124, 4378, 21, 'نوع الطلب'),
(80125, 4380, 21, 'نوع الطلب /النتيجة'),
(80126, 4381, 21, 'تم الطلب'),
(80127, 4382, 21, 'طلب بواسطة'),
(80128, 4383, 21, 'عملية تم طلبها'),
(80129, 4384, 21, 'المزود الطالب'),
(80130, 4385, 21, 'ممر الطلبات'),
(80131, 4386, 21, 'إصابة عضوية'),
(80132, 4387, 21, 'منظمة'),
(80133, 4388, 21, 'أسم المنظمة'),
(80134, 4389, 21, 'أسموحدة المنظمة'),
(80135, 4390, 21, 'المنظمات'),
(80136, 4391, 21, 'تم التعريف في 3'),
(80137, 4392, 21, 'اﻷصلي'),
(80138, 4396, 21, 'الفم و الحنجرة '),
(80139, 4397, 21, 'ضيق النفس الإضطجاعي'),
(80140, 4398, 21, 'اليسري'),
(80141, 4399, 21, 'التهاب العظام و المفاصل'),
(80142, 4402, 21, 'اﻵخر'),
(80143, 4403, 21, 'اﻵخر'),
(80144, 4404, 21, 'اﻵخر (حدّد)'),
(80145, 4405, 21, 'اﻵخر (محدّد)'),
(80146, 4406, 21, 'برامج فيدرالية آخرى'),
(80147, 4407, 21, 'اﻵخر HCFA'),
(80148, 4408, 21, 'الإصابه غير المحدّدة في مكان اخر'),
(80149, 4409, 21, 'التزام التأمين اﻵخر هو اﻷولي'),
(80150, 4410, 21, 'شهر آخر'),
(80151, 4411, 21, 'برامج آخرى غير فيدرالية'),
(80152, 4412, 21, 'ملاحظات اخري'),
(80153, 4413, 21, 'أعراض اخري متعلقة'),
(80154, 4414, 21, 'أعراض اخري متعلقة:'),
(80155, 4415, 21, 'اخري تنفسية'),
(80156, 4416, 21, 'إرهاق/زيادة استعمال اخري'),
(80157, 4417, 21, 'جراحية اخري'),
(80158, 4418, 21, 'اخري/ متعلقة بالإجهاض'),
(80159, 4420, 21, 'اخري'),
(80160, 4421, 21, 'و إلا ستفسد المراجع من و الي البيانات الحالية'),
(80161, 4422, 21, 'قواعد اتاوا لتصوير الكعب'),
(80162, 4423, 21, 'كلتا العينين'),
(80163, 4424, 21, 'خارجا'),
(80164, 4425, 21, 'خارج المكتب'),
(80165, 4426, 21, 'تحويل متجه الى الخارج'),
(80166, 4427, 21, 'نتيجة'),
(80167, 4428, 21, 'وُجهَة نَظَر'),
(80168, 4430, 21, 'حالة التسريح العامة'),
(80169, 4431, 21, 'متأخر'),
(80170, 4432, 21, 'زيادة استخدام'),
(80171, 4433, 21, 'نظرة عامة'),
(80172, 4434, 21, 'وزن زائد (سمنة)'),
(80173, 4435, 21, 'اكتب فوق اختيار'),
(80174, 4437, 21, 'تشبع بالأكسجين'),
(80175, 4438, 21, 'أونصة'),
(80176, 4440, 21, 'بعد الوجبات'),
(80177, 4441, 21, 'مساءاً'),
(80178, 4442, 21, 'عند اللزوم'),
(80179, 4443, 21, 'ساكن جزر المحيط الهادي'),
(80180, 4444, 21, 'الطفولة'),
(80181, 4445, 21, 'صفحة'),
(80182, 4446, 21, 'صفحات'),
(80183, 4447, 21, 'تم الدفع'),
(80184, 4448, 21, 'المبلغ المدفوع الذي حددتة'),
(80185, 4449, 21, 'المبلغ المدفوع'),
(80186, 4450, 21, 'دفع بواسطة'),
(80187, 4451, 21, 'ألم'),
(80188, 4453, 21, 'خفقان'),
(80189, 4455, 21, 'مسحة عنق الرحم'),
(80190, 4456, 21, 'ورق'),
(80191, 4457, 21, 'حجم الورق'),
(80192, 4458, 21, 'شلل'),
(80193, 4461, 21, 'تحليل HL7'),
(80194, 4463, 21, 'شريك'),
(80195, 4464, 21, 'أسم الشريك'),
(80196, 4467, 21, 'جملة السر'),
(80197, 4468, 21, 'جملة السر لفك تشفير الوثيقة'),
(80198, 4469, 21, 'المرضي المتوفيين'),
(80199, 4470, 21, 'تنبيه سلبي'),
(80200, 4471, 21, 'قواعد التنبيه السلبي'),
(80201, 4472, 21, 'كلمة السر'),
(80202, 4473, 21, 'تغيير كلمة السر'),
(80203, 4474, 21, 'تم تغيير كلمة السر بنجاح'),
(80204, 4475, 21, 'تم تغيير كلمة السر بنجاح.'),
(80205, 4476, 21, 'كلمة السر لا ترقي للحد اﻹدني و يجب ان تحتوي علي علي اﻷقل علي حرف كبير و اخر صغير و رقم و اي رمز خاص'),
(80206, 4477, 21, 'فترة السماح لكلمة السر المنتهية الصلاحية'),
(80207, 4479, 21, 'كلمة السر لبوابة الهاتف. خدمة VOIP المقدمة من http://signup.maviq.com'),
(80208, 4480, 21, 'كلمة السر لممر الرسائل النصية القصيرة'),
(80209, 4481, 21, 'كلمة السر لممر الرسائل النصية القصيرة'),
(80210, 4483, 21, 'نظام اﻷمان لكلمة السر تم ترقيته'),
(80211, 4484, 21, 'كلمة السر لالإتصال ب CouchDB'),
(80212, 4485, 21, 'كلمة السر قصيرة جداَ. مطلوب اكثر من 8 رموز.'),
(80213, 4486, 21, 'كلمة السر:'),
(80214, 4487, 21, 'كلمات السر غير متطابقة !'),
(80215, 4488, 21, 'المواعيد السابقة'),
(80216, 4489, 21, 'أداة عرض المواعيد السابقة'),
(80217, 4490, 21, 'مضى تاريخ استحقاقها'),
(80218, 4491, 21, 'مضى تاريخ استحقاقها'),
(80219, 4492, 21, 'فاصل مضى تاريخ اﻹستحقاق (تنبيهات طبية)'),
(80220, 4493, 21, 'فاصل مضى تاريخ اﻹستحقاق (تنبيهات المريض)'),
(80221, 4494, 21, 'قائمة الزيارات الآخيرة'),
(80222, 4495, 21, 'الزيارة السابقة'),
(80223, 4496, 21, 'الزيارة السابقة والملفات'),
(80224, 4497, 21, 'الزيارات السابقة ل'),
(80225, 4498, 21, 'الصق بيانات HL7'),
(80226, 4499, 21, 'الصق البيانات لتستورد فى مكان النص ادناه'),
(80227, 4500, 21, 'مريض'),
(80228, 4502, 21, 'رقعة'),
(80229, 4508, 21, 'طريق لاحتياط تسجيل الحدث'),
(80230, 4509, 21, 'طريق لملف شهادة ال CA'),
(80231, 4510, 21, 'طريق لمفتاح شهادة ال CA'),
(80232, 4511, 21, 'طريق لثنائيات MySQL'),
(80233, 4512, 21, 'طريق لثنائيات Perl'),
(80234, 4513, 21, 'طريق للملفات المؤقتة'),
(80235, 4514, 21, 'مريض'),
(80236, 4515, 21, 'مريض'),
(80237, 4516, 21, 'مريض'),
(80238, 4517, 21, 'عنوان المريض'),
(80239, 4518, 21, 'عنوان المريض مفقود'),
(80240, 4521, 21, 'حساسيات المريض'),
(80241, 4522, 21, 'حساسيات المريض'),
(80242, 4523, 21, 'موعد المريض'),
(80243, 4524, 21, 'باقي حساب المريض'),
(80244, 4525, 21, 'حساب المريض مستحق الدفع'),
(80245, 4528, 21, 'رقم هوية ملف المريض'),
(80246, 4529, 21, 'إنهاء اجراءات المريض'),
(80247, 4530, 21, 'إنهاء اجراءات المريض ل '),
(80248, 4531, 21, 'مدينة المريضة'),
(80249, 4532, 21, 'مدينة المريض مفقودة'),
(80250, 4533, 21, 'تم إرسال مراسلات المريض'),
(80251, 4534, 21, 'تم إرسال مراسلات المريض'),
(80252, 4535, 21, 'بلد المريض'),
(80253, 4536, 21, 'بلد المريض مفقودة. كم انك لم تعين بلد افتراضي فى الإعدادات العامة'),
(80254, 4537, 21, 'تغطية المريض التأمينية'),
(80255, 4539, 21, 'بيانات المريض'),
(80256, 4541, 21, 'تاريخ ميلاد المريض مفقود'),
(80257, 4542, 21, 'تفاصيل المريض'),
(80258, 4543, 21, 'تاريخ ميلاد المريض'),
(80259, 4544, 21, 'وثيقة المريض'),
(80260, 4545, 21, 'تعليم المريض'),
(80261, 4546, 21, 'وسائل تعليمية للمريض'),
(80262, 4547, 21, 'زيارة المريض'),
(80263, 4548, 21, 'طلب زيارة المريض'),
(80264, 4549, 21, 'زيارة المرضي'),
(80265, 4550, 21, 'الباحث عن المريض'),
(80266, 4551, 21, 'أسم المريض الأول'),
(80267, 4553, 21, 'أسم المريض الأول مفقود'),
(80268, 4558, 21, 'جنس المريض'),
(80269, 4559, 21, 'جنس المريض مفقود'),
(80270, 4560, 21, 'المريض لم يصرح لبوابة المريض'),
(80271, 4561, 21, 'التاريخ الطبي للمريض'),
(80272, 4562, 21, 'التاريخ الطبي / اسلوب حياة المريض'),
(80273, 4563, 21, 'رقم تلفون منزل المريض'),
(80274, 4564, 21, 'رقم هوية المريض'),
(80275, 4565, 21, 'رقم هوية المريض'),
(80276, 4566, 21, 'بطاقة رقم هوية المريض'),
(80277, 4567, 21, 'إسم مجموعة رقم هوية المريض'),
(80278, 4568, 21, 'تطعيمات المريض'),
(80279, 4569, 21, 'معلومات المريض'),
(80280, 4570, 21, 'تعليمات المريض'),
(80281, 4571, 21, 'توزيع تأمين المريض'),
(80282, 4572, 21, 'تقرير عن توزيع تأمين المريض'),
(80283, 4573, 21, 'مشاكل المريض'),
(80284, 4575, 21, 'لقب المريض'),
(80285, 4577, 21, 'لقب المريض مفقود'),
(80286, 4581, 21, 'قائمة المريض'),
(80287, 4582, 21, 'أعمدة قائمة المريض'),
(80288, 4584, 21, 'نافذة جديدة لقائمة المريض'),
(80289, 4585, 21, 'حجم صفحة قائمة المريض'),
(80290, 4586, 21, 'أخطاء فى البحث عن المريض'),
(80291, 4587, 21, 'مشاكل المريض الصحية'),
(80292, 4588, 21, 'أدوية المريض'),
(80293, 4589, 21, 'أسم المريض'),
(80294, 4590, 21, 'أسم المريض وعنوانه'),
(80295, 4593, 21, 'أسم المريض مطلوب'),
(80296, 4595, 21, 'مذكرة المريض'),
(80297, 4596, 21, 'انواع مذكرة المريض'),
(80298, 4597, 21, 'مذكرات المريض'),
(80299, 4598, 21, 'مذكرات المريض (اكتب, اﻹضافة اختيارية)'),
(80300, 4599, 21, 'رقم المريض'),
(80301, 4600, 21, 'مدفوعات المريض'),
(80302, 4602, 21, 'إسم مجموعة صورة المريض'),
(80303, 4603, 21, 'بوابة المريض'),
(80304, 4605, 21, 'بوابة المريض مغلقة'),
(80305, 4606, 21, 'الولوج الي بوابة المريض'),
(80306, 4607, 21, 'عنوان بوابة المريض على الإنترنت'),
(80307, 4608, 21, 'تقرير المريض المطبوع'),
(80308, 4609, 21, 'تقرير سجل المريض'),
(80309, 4610, 21, 'طلب تقرير المريض'),
(80310, 4611, 21, 'طلب سجل المريض'),
(80311, 4613, 21, 'تنبيه المريض'),
(80312, 4614, 21, 'عمل دفعات لتنبية المريض'),
(80313, 4615, 21, 'اولوية إنشاء تنبيه المريض'),
(80314, 4616, 21, 'قواعد تنبيه المريض'),
(80315, 4617, 21, 'ايميل مرسل تنبيه المريض'),
(80316, 4618, 21, 'اسم مرسل تنبيه المريض'),
(80317, 4619, 21, 'تنبيهات المريض'),
(80318, 4620, 21, 'تقرير المريض'),
(80319, 4621, 21, 'طلب المريض'),
(80320, 4622, 21, 'السجلات الطبية المطلوبة بواسطة المريض'),
(80321, 4623, 21, 'نتائج المريض'),
(80322, 4624, 21, 'تصميم البحث عن نتائج المريض'),
(80323, 4625, 21, 'البحث عن المريض/شاشة الإضافة'),
(80324, 4626, 21, 'إعدادات المريض'),
(80325, 4627, 21, 'ولاية المريض'),
(80326, 4629, 21, 'ملخص المريض'),
(80327, 4630, 21, 'تعاملات المريض المادية'),
(80328, 4631, 21, 'رمز المريض البريدي'),
(80329, 4632, 21, 'المرضي في قاعدة البيانات الذي تطابق معلوماتهم السكانية معايير بحثك'),
(80330, 4633, 21, 'المريض/العميل'),
(80331, 4634, 21, 'المريض :'),
(80332, 4635, 21, 'رقم هوية المريض'),
(80333, 4636, 21, 'المرضي'),
(80334, 4637, 21, 'المرضي المعالجين'),
(80335, 4638, 21, 'دفع'),
(80336, 4639, 21, 'اعط اهتماما لخانة تأشير المعلمة ب "تم مع". كل الدفعات التأمينية المتبقية علي المريض لن تحّصل اذا تم تجاهل هذا اﻹختيار.'),
(80337, 4640, 21, 'تاريخ الدفع :'),
(80338, 4641, 21, 'حالة الدفع'),
(80339, 4642, 21, 'اسم المدفوع له'),
(80340, 4643, 21, 'الدافع'),
(80341, 4644, 21, 'نوع الدافع'),
(80342, 4645, 21, 'جاري الدفع'),
(80343, 4646, 21, 'كيان دافع'),
(80344, 4647, 21, 'مدفوعة'),
(80345, 4648, 21, 'مدفوعة'),
(80346, 4649, 21, 'رمز تعديل المدفوعة'),
(80347, 4650, 21, 'المدفوع لأجل'),
(80348, 4651, 21, 'المبلغ المدفوع'),
(80349, 4652, 21, 'المبلغ المدفوع يجب ان يكون رقماَ'),
(80350, 4653, 21, 'صنف الدفع'),
(80351, 4654, 21, 'تاريخ الدفع'),
(80352, 4655, 21, 'تم إدخال الدفع بتاريخ'),
(80353, 4656, 21, 'تم الدفع من'),
(80354, 4657, 21, 'ممرات الدفع'),
(80355, 4658, 21, 'دفع التأمين'),
(80356, 4659, 21, 'قائمة الدفع'),
(80357, 4660, 21, 'طريقة الدفع'),
(80358, 4661, 21, 'إفرز الدفع بواسطة'),
(80359, 4662, 21, 'حالة الدفع'),
(80360, 4663, 21, 'نوع الدفع'),
(80361, 4664, 21, 'قيمة الدفع بالرمز '),
(80362, 4665, 21, 'مدفوعات'),
(80363, 4667, 21, 'طبيب الرعاية الأولية'),
(80364, 4668, 21, 'نسبة الصفوص'),
(80365, 4669, 21, 'ملف PDF'),
(80366, 4670, 21, 'نزل البيانات المختارة بصيغة PDF'),
(80367, 4672, 21, 'الحوض و المؤخرة'),
(80368, 4673, 21, 'شبيه الفقاع'),
(80369, 4674, 21, 'معلق'),
(80370, 4676, 21, 'متابعة معلقة'),
(80371, 4677, 21, 'متابعة معلقة'),
(80372, 4678, 21, 'متابعة معلقة من النتائج'),
(80373, 4679, 21, 'أوامر معلقة'),
(80374, 4680, 21, 'حجز معلّق'),
(80375, 4681, 21, 'مراجعة معلقة'),
(80376, 4682, 21, 'تعداد الوصفة معلق'),
(80377, 4684, 21, 'شركة بنينجتون'),
(80378, 4685, 21, 'قرحه المعدة'),
(80379, 4686, 21, 'لكل زيارة'),
(80380, 4687, 21, 'لكل دقيقة'),
(80381, 4688, 21, 'لكل فتحة انف'),
(80382, 4689, 21, 'لكل فتحة انف'),
(80383, 4690, 21, 'عن طريق الفم'),
(80384, 4691, 21, 'عن طريق الفم'),
(80385, 4692, 21, 'عن طريق الشرج'),
(80386, 4693, 21, 'عن طريق الشرج'),
(80387, 4694, 21, 'نسبة'),
(80388, 4697, 21, 'نسبوي'),
(80389, 4698, 21, 'مثقوب يمينا:'),
(80390, 4699, 21, 'أجر البحث'),
(80391, 4700, 21, 'أجر هذا الفعل'),
(80392, 4701, 21, 'نسبة الأداء'),
(80393, 4703, 21, 'منشأة المعمل المؤدي'),
(80394, 4705, 21, 'فتره زمنية'),
(80395, 4706, 21, 'المدة (باليوم) المسموح للمستخدم الدخول بكلمة سر منتهية الصلاحية'),
(80396, 4707, 21, 'العناية المتعلقة بالجراحة'),
(80397, 4708, 21, 'طرفي'),
(80398, 4709, 21, 'اسمح لكلمات السر السهلة'),
(80399, 4710, 21, 'فارسي'),
(80400, 4712, 21, 'شخص'),
(80401, 4713, 21, 'حسب الطلب'),
(80402, 4714, 21, 'ما بعد التخرّج'),
(80403, 4715, 21, 'دوائي'),
(80404, 4716, 21, 'تعداد أدوية الصيدلية'),
(80405, 4717, 21, 'صيدليات'),
(80406, 4718, 21, 'صيدلية'),
(80407, 4719, 21, 'صيدلية بائعة للدواء'),
(80408, 4720, 21, 'الاسترواح الصدري'),
(80409, 4723, 21, 'phiMail فاصل زمني بين جلب الرسائل'),
(80410, 4724, 21, 'phiMail مستخدم التنبيهات'),
(80411, 4725, 21, 'phiMail كلمة السر ل'),
(80412, 4726, 21, 'phiMail عنوان الخادم'),
(80413, 4727, 21, 'phiMail اسم المستخدم'),
(80414, 4729, 21, 'هاتف'),
(80415, 4730, 21, 'قائمة اتصال الهاتف'),
(80416, 4731, 21, 'تقرير قائمة اتصال الهاتف'),
(80417, 4733, 21, 'كلمة سر ممر الهاتف'),
(80418, 4734, 21, 'عنوان ممر الهاتف'),
(80419, 4735, 21, 'إسم مستخدم ممر الهاتف'),
(80420, 4737, 21, 'ساعة إعلام الهاتف'),
(80421, 4738, 21, 'رقم الهاتف'),
(80422, 4740, 21, 'رهاب الضوء'),
(80423, 4741, 21, 'صور'),
(80424, 4742, 21, 'PHP مضغوط'),
(80425, 4743, 21, 'PHP CURL يجب ان يكون مفعلا فى خادمك'),
(80426, 4744, 21, 'PHP تم فك الضغط عنه'),
(80427, 4745, 21, 'php-GACL تحكمات وسيلة الوصول مغلقة'),
(80428, 4746, 21, 'PHP-gacl غير مثبّت'),
(80429, 4747, 21, 'فحص جسدي'),
(80430, 4749, 21, 'طلب الطبيب'),
(80431, 4750, 21, 'توقيع الطبيب'),
(80432, 4752, 21, 'أطباء'),
(80433, 4753, 21, 'إنتقي'),
(80434, 4754, 21, 'إنتقي'),
(80435, 4755, 21, 'إنتقي تصميم ال CSS'),
(80436, 4756, 21, 'مَرَضٌ الْتِهابِيٌّ حَوضِيّ'),
(80437, 4757, 21, 'مَرَضٌ الْتِهابِيٌّ حَوضِيّ'),
(80438, 4758, 21, 'حجم حبة الدواء'),
(80439, 4759, 21, 'حبوب الدواء'),
(80440, 4760, 21, 'ضع ملف قاعدة البيانات المضغوط فى المجلد التالي اذا كنت تريد إختيار التثبيت'),
(80441, 4761, 21, 'ضع الملف المنزّل قاعدة بيانات ICD 10 المضغوط فى المجلد التالي'),
(80442, 4762, 21, 'ضع الملف المنزّل قاعدة بيانات ICD 9 المضغوط فى المجلد التالي'),
(80443, 4763, 21, 'ضع الملف المنزّل قاعدة بيانات RxNorm المضغوط فى المجلد التالي'),
(80444, 4764, 21, 'ضع الملف المنزّل قاعدة بيانات Snomed المضغوط فى المجلد التالي'),
(80445, 4765, 21, 'ماسك المكان'),
(80446, 4766, 21, 'ماسك المكان (يعتني بACLs فارغة)'),
(80447, 4767, 21, 'نص صِرف'),
(80448, 4768, 21, 'خطة'),
(80449, 4771, 21, 'إسم الخطة'),
(80450, 4775, 21, 'مخططات'),
(80451, 4779, 21, 'خطة:'),
(80452, 4782, 21, 'خطط'),
(80453, 4784, 21, 'لاعب'),
(80454, 4785, 21, 'موقع اللعب'),
(80455, 4786, 21, 'الرحاء اﻹتصال اذا كانت المعلومات أعلاه غير صحيحة'),
(80456, 4787, 21, 'الرجاء تغيير كلمة السر'),
(80457, 4788, 21, 'الرجاء إختر ملف'),
(80458, 4789, 21, 'الرجاء إختر مريض'),
(80459, 4790, 21, 'الرجاء إختر مختارات مقبولة من القائمة'),
(80460, 4791, 21, 'الرجاء إختر مختارات مقبولة'),
(80461, 4792, 21, 'الرجاء إختر قيمة ل'),
(80462, 4793, 21, 'الرجاء إختر مجال التاريخ أعلاه ثم اضغط على التنشيط لمشاهدة النتائج'),
(80463, 4794, 21, 'الرجاء إختر ملف EDI-271 معالج جيداَ'),
(80464, 4795, 21, 'اضغط زر التنزيل لتنزيل البيانات ممسوحة الهوية'),
(80465, 4796, 21, 'اضغط زر التنزيل لتنزيل البيانات معاده تعريف الهوية'),
(80466, 4797, 21, 'الرجاء إغلاق هذة النافذة.'),
(80467, 4798, 21, 'الرجاء مقارنة اﻹسم الجديد'),
(80468, 4801, 21, 'الرجاء إنشاء الملف التالي قبل المضي قدماَ'),
(80469, 4802, 21, 'الرجاء عدم قبول هذة الوصفة الا فى حال استلامها بالفاكس'),
(80470, 4803, 21, 'الرجاء عدم قبول هذة الوصفة الا فى حال استلامها بالفاكس'),
(80471, 4804, 21, 'الرجاء عدم إستخدام زر الإيقاف او إعادة التحميل بمتصفحك الا فى حالة التوقف أكثر من 10 دقائق'),
(80472, 4805, 21, 'الرجاء تمكين إضافة CURL'),
(80473, 4806, 21, 'الرجاء تمكين إضافة OPENSSL'),
(80474, 4807, 21, 'الرجاء تمكين إضافة SOAP'),
(80475, 4808, 21, 'الرجاء تمكين إضافة XML'),
(80476, 4809, 21, 'الرجاء إدخال تاريخ لاخر مراجعة'),
(80477, 4810, 21, 'الرجاء ادخال التاريخ'),
(80478, 4811, 21, 'الرجاء ادخال التاريخ المتوقع'),
(80479, 4812, 21, 'الرجاء ادخال الرسالة'),
(80480, 4813, 21, 'الرجاء ادخال القيمة المادية بإستخدام اﻷرقام و الفواصل فقط'),
(80481, 4814, 21, 'الرجاء ادخال كلمة سر جديدة'),
(80482, 4815, 21, 'الرجاء ادخال العنوان!'),
(80483, 4816, 21, 'الرجاء ادخال عنواناَ صالحاَ أعلاه'),
(80484, 4819, 21, 'الرجاء ادخال رمزاَ صالحاَ ﻹعادة التعريف'),
(80485, 4821, 21, 'الرجاء ادخال طلب بحث جديد'),
(80486, 4822, 21, 'الرجاء ادخال رمزاَ صالحاَ ﻹعادة التعريف'),
(80487, 4823, 21, 'الرجاء ادخال كلمة السر'),
(80488, 4824, 21, 'الرجاء إكمال رقم الشيك'),
(80489, 4825, 21, 'الرجاء إكمال رقم الشيك/المرجع'),
(80490, 4826, 21, 'الرجاء إكمال التاريخ'),
(80491, 4827, 21, 'الرجاء إكمال مبلغ الدفع'),
(80492, 4828, 21, 'الرجاء إكمال مجموعة الدفع'),
(80493, 4829, 21, 'الرجاء إكمال طلب الدفع'),
(80494, 4830, 21, 'الرجاء إكمال احجز ليوم'),
(80495, 4831, 21, 'الرجاء الإكمال قيل المضي قدماَ'),
(80496, 4832, 21, 'الرجاء إضافة سبب الزيارة'),
(80497, 4833, 21, 'الرجاء إضافة معايير البحث أعلاه ثم اضغط إرسال لبدء التقرير'),
(80498, 4834, 21, 'الرجاء إضافة معايير البحث أعلاه ثم اضغط إرسال لرؤية النتائج'),
(80499, 4835, 21, 'الرجاء إضافة معايير البحث أعلاه ثم اضغط إرسال لرؤية النتائج (سيتم عرض النتائج في نافذة جديدة)'),
(80500, 4836, 21, 'الرجاء الولوج ثانيا'),
(80501, 4837, 21, 'الرجاء الإنتباه إلي ان هذا قد يأخد وقتا طويلا بالدقائق و قد يبدو متصفحك غير مستجيب و لكن إنشاء الفواتير عملية معقدة'),
(80502, 4838, 21, 'الرجاء الإنتباه: الثوابت حساسة لحالة الحرف (مطبق علي الإنجليزية)'),
(80503, 4839, 21, 'الرجاء إستخدام اﻷحرف الكتابية فقط'),
(80504, 4840, 21, 'الرجاء إستخدام اﻷحرف الكتابية فقط بدون مسافات'),
(80505, 4841, 21, 'الرجاء دفع هذا المبلغ'),
(80506, 4842, 21, 'الرجاء ضع ملفات التثبيت في المجلد التالي'),
(80507, 4843, 21, 'الرجاء حول الي'),
(80508, 4844, 21, 'الرجاء تصفير كلمة السر'),
(80509, 4845, 21, 'الرجاء اعادة تشغيل خادم اﻷباتشي قبل تجربة الغاء الهوية'),
(80510, 4847, 21, 'الرجاء إختيار'),
(80511, 4849, 21, 'الرجاء إختيار اللغة'),
(80512, 4850, 21, 'الرجاء إختيار المريض'),
(80513, 4851, 21, 'الرجاء إختيار منشأة العمل الرئيسيه مع رقم هويه الضريبة لتعريفها كرمزك الضريبي ولكن ان كنت بمفردك (كعيادة) فإستخدم رقمك الضريبي الخاص'),
(80514, 4854, 21, 'الرجاء إختيار المريض'),
(80515, 4855, 21, 'الرجاء إختيار تاريخ البدء و الإنتهاء'),
(80516, 4856, 21, 'الرجاء إختيار مستفيد قيّم'),
(80517, 4858, 21, 'الرجاء إختيار سبب تغيير الرمز '),
(80518, 4859, 21, 'الرجاء إختيار الحدث'),
(80519, 4860, 21, 'الرجاء إختيار خيار للبحث'),
(80520, 4863, 21, 'الرجاء إختيار وصفة واحدة علي اﻷقل!'),
(80521, 4865, 21, 'الرجاء إختيار الصفحات المختارة للنسخ او التحويل:'),
(80522, 4866, 21, 'الرجاء إختيار طريقة الدفع'),
(80523, 4867, 21, 'الرجاء إختيار نوعية الدفع'),
(80524, 4869, 21, 'الرجاء إختيار شريك X12, المطلوب لتكوين جمله ال 270'),
(80525, 4870, 21, 'الرجاء ضبط'),
(80526, 4871, 21, 'الرجاء ضبط إعداد إلغاء الهوية الي الصفر ثانيا'),
(80527, 4873, 21, 'الرجاء البدء بعملية جديدة ﻹلغاء الهوية'),
(80528, 4874, 21, 'الرجاء ترقية قاعدة بيانات البرنامج لتشمل إجراءات إلغاء الهوية'),
(80529, 4875, 21, 'الرجاء الإطلاع علي تسجيل جدول الخطأ لإجراءات إلغاء الهوية'),
(80530, 4876, 21, 'الرجاء زيارة شاشة إجراءات إلغاء الهوية بعد بعض الوقت'),
(80531, 4877, 21, 'الرجاء زيارة شاشة إجراءات إعادة الهوية بعد بعض الوقت'),
(80532, 4878, 21, 'الرجاء زيارة الشاشة بعد بعض الوقت'),
(80533, 4881, 21, 'جمع'),
(80534, 4882, 21, 'مساءً'),
(80535, 4883, 21, 'البرنامج المسائي'),
(80536, 4884, 21, 'طريقة الدفع'),
(80537, 4885, 21, 'ضيقُ النَّفَسِ اللَّيلِيُّ الانْتِيابِيّ'),
(80538, 4886, 21, 'مترافق المُكَوَّاراتِ الرِّئَوِيَّة 1'),
(80539, 4887, 21, 'مترافق المُكَوَّاراتِ الرِّئَوِيَّة 2'),
(80540, 4888, 21, 'مترافق المُكَوَّاراتِ الرِّئَوِيَّة 3'),
(80541, 4889, 21, 'مترافق المُكَوَّاراتِ الرِّئَوِيَّة 4'),
(80542, 4890, 21, 'تطعيم المُكَوَّاراتِ الرِّئَوِيَّة'),
(80543, 4891, 21, 'تطعيم ذاتُ الرّئَة'),
(80544, 4892, 21, 'حالة تطعيم ذاتُ الرّئَة للبالغين'),
(80545, 4893, 21, 'حالة تطعيم ذاتُ الرّئَة للبالغين (CQM)'),
(80546, 4894, 21, 'طب اﻷقدام'),
(80547, 4896, 21, 'نقطة الخدمة'),
(80548, 4897, 21, 'بوليصة'),
(80549, 4898, 21, 'رقم البوليصة'),
(80550, 4899, 21, 'رقم البوليصة'),
(80551, 4900, 21, 'بولندي'),
(80552, 4901, 21, 'العطاش'),
(80553, 4902, 21, 'سَلاَئِلُ'),
(80554, 4903, 21, 'بُوال'),
(80555, 4904, 21, 'ضعف الشهية'),
(80556, 4905, 21, 'دورة ضعيفة'),
(80557, 4906, 21, 'سمع ضعيف'),
(80558, 4907, 21, 'خاصية النوافذ المنبثقة يجب ان تفعّل لرؤية هذة التقارير'),
(80559, 4908, 21, 'إملأ منظر السنة باﻷحداث؟'),
(80560, 4909, 21, 'النوافذ المنبثقة'),
(80561, 4910, 21, 'بوابة'),
(80562, 4911, 21, 'نشاط البوابة'),
(80563, 4917, 21, 'برتغالي'),
(80564, 4918, 21, 'برتغالي (برازيلي)'),
(80565, 4919, 21, 'برتغالي (اوروبي)'),
(80566, 4920, 21, 'رمز نقطة الخدمة'),
(80567, 4922, 21, 'إيجابي'),
(80568, 4923, 21, 'إيجابيات'),
(80569, 4925, 21, 'إعرض بدلا عن'),
(80570, 4926, 21, 'تدفق إفرازات الأنف إلى الخلف'),
(80571, 4927, 21, 'ما بعد المدفوعات'),
(80572, 4928, 21, 'ما بعد الجراحة'),
(80573, 4929, 21, 'أرسل الي المحاسبة و صنف كمفوتر'),
(80574, 4930, 21, 'أرسل الي التاريخ'),
(80575, 4931, 21, 'أرسل الي التاريخ لا يجوز ان يكون ابعد من اليوم'),
(80576, 4932, 21, 'أرسل الي التاريخ يجب ان يكون أكبر من تاريخ أغلاق المحاسبة'),
(80577, 4933, 21, 'عناية ما بعد اﻹجهاض'),
(80578, 4934, 21, 'منع حمل ما بعد اﻹجهاض'),
(80579, 4935, 21, 'إرشاد ما بعد اﻹجهاض'),
(80580, 4936, 21, 'متابعة ما بعد اﻹجهاض'),
(80581, 4937, 21, 'بريدي'),
(80582, 4938, 21, 'الرمز البريدي'),
(80583, 4939, 21, 'الرمز البريدي'),
(80584, 4941, 21, 'PostCalendar'),
(80585, 4942, 21, 'إدارة PostCalendar'),
(80586, 4943, 21, 'إعدادات تصنييف PostCalendar'),
(80587, 4944, 21, 'إعدادات العامة PostCalendar'),
(80588, 4945, 21, 'تم اﻹرسال بتاريخ'),
(80589, 4946, 21, 'تاريخ اﻹرسال'),
(80590, 4948, 21, 'مشغل ب'),
(80591, 4949, 21, 'معدات السلامة الشخصية + التاريخ المرضي الطبي و الجراحي'),
(80592, 4950, 21, 'مبادرة اﻹبلغ عن كفائة الطبيب'),
(80593, 4951, 21, 'رقم التسجيل لمبادرة اﻹبلاغ عن كفائة الطبيب'),
(80594, 4952, 21, 'إسم التسجيل لمبادرة اﻹبلاغ عن كفائة الطبيب'),
(80595, 4953, 21, 'ممارسة'),
(80596, 4954, 21, 'الإعدادت الإفتراضية للممارسة'),
(80597, 4955, 21, 'إعدادت الممارسة'),
(80598, 4956, 21, 'ممارس'),
(80599, 4958, 21, 'قبل الدفع'),
(80600, 4959, 21, 'قبل الدفعة'),
(80601, 4960, 21, 'إستشارة ما قبل اﻹجهاض'),
(80602, 4961, 21, 'إرشاد ما قبل اﻹجهاض'),
(80603, 4962, 21, 'المجموعة المفضّلة'),
(80604, 4964, 21, 'التفضيلات'),
(80605, 4965, 21, 'تصنيف الحدث المفضل'),
(80606, 4966, 21, 'اللغة المفضلة'),
(80607, 4967, 21, 'الصيدلية المفضلة'),
(80608, 4968, 21, 'المنظمة المزودة المفضلة'),
(80609, 4969, 21, 'إختبار الحمل'),
(80610, 4970, 21, 'مبدئي'),
(80611, 4971, 21, 'يتم التجهيز لإعداد التقرير'),
(80612, 4972, 21, 'مسبق الدفع'),
(80613, 4973, 21, 'وصفة دوائية'),
(80614, 4974, 21, 'الوصفة الدوائية وصلت الي حدود ال'),
(80615, 4975, 21, 'سرد تاريخ الوصفة الدوائية'),
(80616, 4976, 21, 'تم جلب تاريخ الوصفة الدوائية بنجاح'),
(80617, 4977, 21, 'علامة الوصفة الدوائية'),
(80618, 4978, 21, 'تقرير الوصفة الدوائية'),
(80619, 4979, 21, 'الوصفات الدوائية'),
(80620, 4980, 21, 'الوصفات الدوائية و الصرف الدوائي'),
(80621, 4981, 21, 'الوصفات الدوائية و التحويلات اﻷخري'),
(80622, 4982, 21, 'الوصفات الدوائية و/او التحويلات بواسطة اﻷخصائي'),
(80623, 4983, 21, 'تقرير الوصفات الدوائية'),
(80624, 4984, 21, 'الوصفات الدوائية / التحويلات'),
(80625, 4985, 21, 'الحاضر'),
(80626, 4986, 21, 'الشكوي الحالية'),
(80627, 4987, 21, 'المشاكل الحالية'),
(80628, 4988, 21, 'إضغط أكمل لتتابع'),
(80629, 4989, 21, 'التشخيص المفترض'),
(80630, 4990, 21, 'التشخيص المفترض بواسطة اﻷخصائي'),
(80631, 4991, 21, 'السابق'),
(80632, 4992, 21, 'التاريخ المرضي الطبي و الجراحي السابق'),
(80633, 4993, 21, 'الشهر السابق (إبق ضاغطا للقائمة)'),
(80634, 4994, 21, 'السنة السابقة (إبق ضاغطا للقائمة)'),
(80635, 4995, 21, 'الرعاية الوقائية'),
(80636, 4998, 21, 'إستعرض الحدث'),
(80637, 5000, 21, 'إستعراض ال'),
(80638, 5001, 21, 'السابق'),
(80639, 5002, 21, 'الإستشارات السابقة'),
(80640, 5003, 21, 'اليوم السابق'),
(80641, 5004, 21, 'التاريخ الطبي / المعاينة السابقة'),
(80642, 5005, 21, 'الشهر السابق'),
(80643, 5006, 21, 'الأسبوع الماضي'),
(80644, 5007, 21, 'السعر'),
(80645, 5008, 21, 'خصم السعر'),
(80646, 5009, 21, 'مستوى السعر'),
(80647, 5010, 21, 'مستوى السعر:'),
(80648, 5011, 21, 'السعار'),
(80649, 5012, 21, 'أولّي'),
(80650, 5013, 21, 'الكيان التجاري الأولي'),
(80651, 5014, 21, 'الرقم الضريبي للكيان التجاري الأولي سيستخدم كرقم حساب'),
(80652, 5022, 21, 'تأمين أولّي'),
(80653, 5023, 21, 'تأمين أولّي'),
(80654, 5024, 21, 'بيانات التأمين الأولّي'),
(80655, 5025, 21, 'مزوّد التأمين الأولّي'),
(80656, 5026, 21, 'المزوّد الأولّي'),
(80657, 5027, 21, 'إطبع'),
(80658, 5028, 21, 'إطبع (HTML)'),
(80659, 5029, 21, 'إطبع (PDF)'),
(80660, 5031, 21, 'إطبع اي زيارة'),
(80661, 5032, 21, 'إطبع طلب تحويل فارغ'),
(80662, 5033, 21, 'إطبع اﻷمر'),
(80663, 5034, 21, 'إطبع التاريخ'),
(80664, 5039, 21, 'إطبع التهيئة'),
(80665, 5040, 21, 'إطبع اربع واجهات'),
(80666, 5042, 21, 'إطبع الرسالة'),
(80667, 5043, 21, 'إطبع متعدد'),
(80668, 5044, 21, 'إطبع متعدد للفاكس'),
(80669, 5045, 21, 'إطبع الإسم, التوقيع و التاريخ'),
(80670, 5046, 21, 'إطبع الملاحظة'),
(80671, 5047, 21, 'إطبع الصفحة 1'),
(80672, 5048, 21, 'إطبع الصفحة 2'),
(80673, 5051, 21, 'إطبع أرصدة المزود'),
(80674, 5052, 21, 'إطبع السجل'),
(80675, 5053, 21, 'إطبع البيانات المختارة'),
(80676, 5054, 21, 'إطبع سجل التطعيم'),
(80677, 5056, 21, 'إطبع هذه الزيارة'),
(80678, 5057, 21, 'إطبع هذه الملاحظة'),
(80679, 5058, 21, 'إطبع هذه الملاحظة'),
(80680, 5060, 21, 'إطبع للفاكس'),
(80681, 5061, 21, 'معاينة الطباعة'),
(80682, 5062, 21, 'قابل للطباعة'),
(80683, 5063, 21, 'نسخة قابلة للطباعة'),
(80684, 5064, 21, 'تم الطبع'),
(80685, 5066, 21, 'نتائج الطباعة :'),
(80686, 5067, 21, 'تم تجاوز الطباعة, انظر نتيجة الإختبار في'),
(80687, 5068, 21, 'تم تجاوز الطباعة, انظر نتيجة الإختبار في '),
(80688, 5069, 21, 'تصريح مسبق'),
(80689, 5070, 21, 'طلب تصريح مسبق'),
(80690, 5071, 21, 'زيارة مسبقة'),
(80691, 5072, 21, 'أولوية'),
(80692, 5073, 21, 'أولوية '),
(80693, 5074, 21, 'خاص'),
(80694, 5075, 21, 'مشكلة'),
(80695, 5076, 21, 'تشخيص المشكلة'),
(80696, 5077, 21, 'قائمة المشاكل'),
(80697, 5079, 21, 'مشاكل/إشكاليات'),
(80698, 5080, 21, 'مجموع العملية'),
(80699, 5081, 21, 'تصنيف العملية'),
(80700, 5082, 21, 'حمّل العملية'),
(80701, 5083, 21, 'حجز العملية تحت الطلب'),
(80702, 5084, 21, 'مزود العملية'),
(80703, 5085, 21, 'حجز العملية'),
(80704, 5086, 21, 'عملية'),
(80705, 5087, 21, 'الأجزاء المجري لها العملية'),
(80706, 5088, 21, 'نتائج بولونية للعملية (ناجحة/فاشلة)'),
(80707, 5089, 21, 'رمز العملية'),
(80708, 5090, 21, 'رموز العملية'),
(80709, 5091, 21, 'تجانبات العملية'),
(80710, 5092, 21, 'إسم العملية'),
(80711, 5093, 21, 'أمر العملية'),
(80712, 5094, 21, 'أمر العملية'),
(80713, 5095, 21, 'أمر العملية ل'),
(80714, 5097, 21, 'أوامر و تقارير العملية'),
(80715, 5098, 21, 'مختار العملية'),
(80716, 5099, 21, 'مزود العملية'),
(80717, 5100, 21, 'مزود العملية'),
(80718, 5101, 21, 'مزودي العملية'),
(80719, 5102, 21, 'تقرير العملية'),
(80720, 5103, 21, 'حالات تقرير العملية'),
(80721, 5104, 21, 'نتائج العملية غير طبيعية'),
(80722, 5105, 21, 'حالات نتائج العملية'),
(80723, 5106, 21, 'نتائج العملية'),
(80724, 5107, 21, 'طرق العملية'),
(80725, 5108, 21, 'أنواع عينة العملية'),
(80726, 5109, 21, 'تقرير إحصائات العملية'),
(80727, 5110, 21, 'نوع العملية'),
(80728, 5111, 21, 'أنواع العملية'),
(80729, 5112, 21, 'وحدات العملية'),
(80730, 5113, 21, 'عمليات/خدمات'),
(80731, 5114, 21, 'عمليات'),
(80732, 5115, 21, 'شغّل'),
(80733, 5116, 21, 'شغّل و أرسل التنبيهات'),
(80734, 5117, 21, 'شغّل ملف ERA'),
(80735, 5118, 21, 'شغّل الملفات الجديدة ل تسجيلات CSV'),
(80736, 5119, 21, 'شغّل و أرسل التنبيهات'),
(80737, 5120, 21, 'التشغيل يحتاج الي بعض الوقت'),
(80738, 5121, 21, 'تم تشغيلة'),
(80739, 5122, 21, 'تم تشغيلة من قِبل'),
(80740, 5123, 21, 'تاريخ التشغيل'),
(80741, 5124, 21, 'تم تشغيلة بنجاح'),
(80742, 5125, 21, 'جاري التشغيل'),
(80743, 5126, 21, 'جاري التشغيل و إرسال تنبيهات المرضي'),
(80744, 5127, 21, 'جاري تشغيل تنبيهات المرضي'),
(80745, 5128, 21, 'زمن التشغيل'),
(80746, 5129, 21, 'منتج'),
(80747, 5130, 21, 'طريقة منع الحمل للمنتج'),
(80748, 5131, 21, 'إنتاج'),
(80749, 5132, 21, 'منتجات'),
(80750, 5133, 21, 'منتجات لكن لا عقاقير و لا قوالب'),
(80751, 5134, 21, 'بروفيسور'),
(80752, 5135, 21, 'ملاحظات التقدم'),
(80753, 5136, 21, 'سرطان البروستاتا'),
(80754, 5137, 21, 'الفحص المبكر لسرطان البروستاتا'),
(80755, 5138, 21, 'فحص البروستاتا'),
(80756, 5139, 21, 'مشاكل البروستاتا'),
(80757, 5140, 21, 'بروستاتا بدون تضخم او عقد او الم'),
(80758, 5141, 21, 'بروتوكول'),
(80759, 5142, 21, 'زوّد الطريق الأوحد'),
(80760, 5143, 21, 'زوّد الطريق الأوحد للملف'),
(80761, 5145, 21, 'زوّد الملخصات الطبيبة للمرضي لكل زيارة'),
(80762, 5146, 21, 'زوّد المرضي بنسخ الكترونية عن الحالة الصحية'),
(80763, 5147, 21, 'زوّد المرضي بتصريح الكتروني محدد بوقت عن الحالة الصحية'),
(80764, 5148, 21, 'زوّد المريض بنسخ الكترونية عن الحالة الصحية لهذة الزيارة'),
(80765, 5149, 21, 'أدخل إيميل صالح'),
(80766, 5150, 21, 'تم تزويد الملخص الصحي؟'),
(80767, 5151, 21, 'تم تزويد المصادر التعليمية؟'),
(80768, 5152, 21, 'مزوّد'),
(80769, 5153, 21, 'رقم هوية المزوّد'),
(80770, 5154, 21, 'رقم هوية المزوّد'),
(80771, 5155, 21, 'رقم هوية المزوّد للمنشأة المعنّية'),
(80772, 5156, 21, 'زوّد اﻷخطاء المتشابهة'),
(80773, 5159, 21, 'رقم المزوّد'),
(80774, 5160, 21, 'علاقة المزوّد'),
(80775, 5162, 21, 'مزوّد:'),
(80776, 5163, 21, 'مزودين'),
(80777, 5164, 21, 'رقم تعريف المزوّد الوطني'),
(80778, 5165, 21, 'يمكن للمزوّد رؤية الرزنامة كلها'),
(80779, 5166, 21, 'السابق'),
(80780, 5167, 21, 'مولّد المضاد الخاص بالبروستاتا'),
(80781, 5168, 21, 'الصدفية'),
(80782, 5169, 21, 'التشخيص النفسي'),
(80783, 5170, 21, 'الدواء النفسي'),
(80784, 5171, 21, 'الطب النفسي'),
(80785, 5172, 21, 'رسالة التعريف بالمرض النفسي'),
(80786, 5173, 21, 'تشخيص المرض النفسي'),
(80787, 5174, 21, 'فحص المرض النفسي'),
(80788, 5175, 21, 'تاريخ طبي بالأمراض النفسية'),
(80789, 5176, 21, 'استهلاك الدواء النفسي'),
(80790, 5177, 21, 'الدواء النفسي'),
(80791, 5178, 21, 'نسبة المرضي'),
(80792, 5179, 21, 'ملاحظات المريض'),
(80793, 5180, 21, 'ملاحظات/تصريح المريض'),
(80794, 5181, 21, 'دفع المريض زيادة عن المطلوب'),
(80795, 5182, 21, 'تم الدفع من قبل المريض'),
(80796, 5183, 21, 'طلب رصيد للمريض'),
(80797, 5184, 21, 'تم إرجاع المبلغ للمريض'),
(80798, 5185, 21, 'تم تسريح المريض'),
(80799, 5186, 21, 'تقرير المريض'),
(80800, 5187, 21, 'المريض طالب او اترك فارغاَ'),
(80801, 5188, 21, 'مدينة المريض'),
(80802, 5189, 21, 'تاريخ ميلاد المريض'),
(80803, 5191, 21, 'إسم المريض الأول'),
(80804, 5192, 21, 'إسم المريض الأخير'),
(80805, 5193, 21, 'إسم المريض المتوسط'),
(80806, 5196, 21, 'عنوان المريض البريدي'),
(80807, 5198, 21, 'ولاية المريض'),
(80808, 5199, 21, 'شارع المريض'),
(80809, 5201, 21, 'عام'),
(80810, 5203, 21, 'الخدمات الصحية العامة'),
(80811, 5204, 21, 'برتوريكي'),
(80812, 5205, 21, 'رئوي'),
(80813, 5206, 21, 'نبض'),
(80814, 5207, 21, 'بنجابي'),
(80815, 5208, 21, 'شراء'),
(80816, 5209, 21, 'شراء/إعادة'),
(80817, 5210, 21, 'مشتريات'),
(80818, 5211, 21, 'P{{Justify Header}}'),
(80819, 5213, 21, 'كل 3 ساعات'),
(80820, 5214, 21, 'كل 4 ساعات'),
(80821, 5215, 21, 'كل 5 ساعات'),
(80822, 5216, 21, 'كل 6 ساعات'),
(80823, 5217, 21, 'كل 8 ساعات'),
(80824, 5218, 21, 'مرة واحدة يومياَ'),
(80825, 5219, 21, 'أربع مرات يومياَ'),
(80826, 5220, 21, 'كل ساعة و ترك'),
(80827, 5221, 21, 'جرعة "كل ساعة و ترك" إقل من الجرعة الشهرية'),
(80828, 5222, 21, 'الكمّية'),
(80829, 5223, 21, 'الكمّية'),
(80830, 5224, 21, 'الجودة');
INSERT INTO `lang_definitions` VALUES
(80831, 5225, 21, 'مقاييس الجودة'),
(80832, 5226, 21, 'الكمّية'),
(80833, 5227, 21, 'الكمّية لرمز الدواء الوطني'),
(80834, 5228, 21, 'الكمّية المتوفرة'),
(80835, 5229, 21, 'الكمّية غير قابلة للإستخدام'),
(80836, 5231, 21, 'إشارة إستفهام'),
(80837, 5232, 21, 'كوّن طابوراَ لتشغيل HCFA بالجملة'),
(80838, 5233, 21, 'كوّن طابوراَ لتشغيل و طباعة HCFA بالجملة'),
(80839, 5234, 21, 'كوّن طابوراَ لتشغيل UB-92 بالجملة'),
(80840, 5235, 21, 'كوّن طابوراَ لتشغيل و طباعة UB-92 بالجملة'),
(80841, 5236, 21, 'تم تكوين الطابور'),
(80842, 5237, 21, 'تم تكوين طابور إدارة الأحداث'),
(80843, 5238, 21, 'تم تكوين طابور ل'),
(80844, 5240, 21, 'تم تكوين طابور إدارة التقديم'),
(80845, 5241, 21, 'إمتنع'),
(80846, 5242, 21, 'إمتنع عن الكحول'),
(80847, 5243, 21, 'ر'),
(80848, 5244, 21, 'RA للمريض, الزيارة او التتبع'),
(80849, 5245, 21, 'العِرق'),
(80850, 5246, 21, 'العِرقية'),
(80851, 5247, 21, 'العِرقية'),
(80852, 5248, 21, 'الراديو'),
(80853, 5249, 21, 'مفاتيح الراديو'),
(80854, 5251, 21, 'المجال'),
(80855, 5252, 21, 'طفح جلدي'),
(80856, 5253, 21, 'المعدل'),
(80857, 5254, 21, 'النسبة'),
(80858, 5255, 21, 'تقرير خام'),
(80859, 5256, 21, 'إعادة التعريف'),
(80860, 5257, 21, 'تمت عملية إعادة التعريف'),
(80861, 5258, 21, 'جار العمل علي إعادة التعريف'),
(80862, 5259, 21, 'سيتم حفظ ملفات إعادة التعريف في'),
(80863, 5260, 21, 'تكرار الإصابة؟'),
(80864, 5261, 21, 'إعادة الفتح'),
(80865, 5262, 21, 'تمت'),
(80866, 5263, 21, 'ردة الفعل'),
(80867, 5264, 21, 'ردود الفعل'),
(80868, 5265, 21, 'يقرأ'),
(80869, 5268, 21, 'الإسم الحقيقي'),
(80870, 5269, 21, 'أحذف حقاَ'),
(80871, 5270, 21, 'سبب'),
(80872, 5271, 21, 'سبب الوفاة'),
(80873, 5272, 21, 'سبب الوفاة'),
(80874, 5274, 21, 'سبب الإحالة'),
(80875, 5275, 21, 'سبب الزيارة'),
(80876, 5276, 21, 'سبب/طلب'),
(80877, 5277, 21, 'إيصال'),
(80878, 5278, 21, 'إيصال مدفوعات'),
(80879, 5279, 21, 'تم عمل الإيصال'),
(80880, 5280, 21, 'تقرير عن طرق دفع الإيصالات'),
(80881, 5281, 21, 'موجز الإيصالات'),
(80882, 5282, 21, 'تم الإستلام'),
(80883, 5283, 21, 'تم الإستلام من قِبل'),
(80884, 5284, 21, 'تم إستلام الفاكس'),
(80885, 5285, 21, 'تم الإستلام و لم تتم المراجعة'),
(80886, 5287, 21, 'مستلم'),
(80887, 5288, 21, 'رقم هوية المستلم'),
(80888, 5289, 21, 'رقم هوية المستلم (ISA08)'),
(80889, 5290, 21, 'رقم هوية المستلم (ISA07)'),
(80890, 5291, 21, 'أرقام هوية المستلم'),
(80891, 5292, 21, 'أخر 3 كلمات سر غير مسموح بها'),
(80892, 5293, 21, 'المستفيد'),
(80893, 5294, 21, 'قائمة المستفيدين خالية'),
(80894, 5295, 21, 'أسم المستفيد'),
(80895, 5296, 21, 'المستفيد من التصريح بالمعلومات'),
(80896, 5297, 21, 'مطلوب مستفيد الا إذا كانت الحالة تمت'),
(80897, 5298, 21, 'توصية'),
(80898, 5299, 21, 'التوصية بالمتابعة'),
(80899, 5300, 21, 'التوصيات'),
(80900, 5301, 21, 'التوصيات و العلاج'),
(80901, 5302, 21, 'توصيات الأخصائي'),
(80902, 5303, 21, 'سجل'),
(80903, 5304, 21, 'السجل موجود مسبقا'),
(80904, 5310, 21, 'السجل و المخطط تغيرا في العلامات الحيوية'),
(80905, 5311, 21, 'ديموجرافيا السجل'),
(80906, 5312, 21, 'التصريح بمعلومات السجل'),
(80907, 5313, 21, 'سجل اللياقة'),
(80908, 5314, 21, 'سجّل الدفع'),
(80909, 5315, 21, 'سجّل تاريخ الطلب'),
(80910, 5316, 21, 'سجّل حالة مدخن للمرضي اكبر من 13 سنة'),
(80911, 5317, 21, 'سجلات'),
(80912, 5318, 21, 'تم العثور على السجلات'),
(80913, 5319, 21, 'تم العثور على السجلات.'),
(80914, 5320, 21, 'إستعمال الأدوية الترفيهية'),
(80915, 5321, 21, 'الأدوية الترفيهية'),
(80916, 5322, 21, 'شرجي'),
(80917, 5323, 21, 'فحص شرجي'),
(80918, 5324, 21, 'شرجي'),
(80919, 5325, 21, 'إعادة توجيه'),
(80920, 5326, 21, 'إحمرار'),
(80921, 5327, 21, 'إقلال:'),
(80922, 5328, 21, 'حوّل'),
(80923, 5329, 21, 'محوّل بواسطة'),
(80924, 5330, 21, 'تاريخ التحويل'),
(80925, 5331, 21, 'حوّل الي'),
(80926, 5332, 21, 'تصنيف التحويل (درجة المخاطرة)'),
(80927, 5333, 21, 'مجال نتائج التحويل'),
(80928, 5334, 21, 'سبب التحويل'),
(80929, 5336, 21, 'إسم المحوّل و توقيعة'),
(80930, 5337, 21, 'التحويل'),
(80931, 5338, 21, 'التحويل بواسطة'),
(80932, 5339, 21, 'بطاقة التحويل'),
(80933, 5340, 21, 'تاريخ التحويل'),
(80934, 5341, 21, 'طلب التحويل'),
(80935, 5342, 21, 'بطاقة التحويل'),
(80936, 5343, 21, 'رقم هوية التحويل'),
(80937, 5345, 21, 'مصدر التحويل'),
(80938, 5346, 21, 'مصدر التحويل للزيارات'),
(80939, 5347, 21, 'التحويل إلى'),
(80940, 5348, 21, 'التحويلات'),
(80941, 5349, 21, 'تقارير التحويلات'),
(80942, 5350, 21, 'محوّل بواسطة'),
(80943, 5351, 21, 'محوّل بواسطة'),
(80944, 5352, 21, 'محوّل الي'),
(80945, 5353, 21, 'المحوّل'),
(80946, 5355, 21, 'تشخيص المحوّل'),
(80947, 5356, 21, 'تشخيص المحوّل'),
(80948, 5357, 21, 'الطبيب المحوّل و العيادة'),
(80949, 5358, 21, 'مزود التحويل'),
(80950, 5359, 21, 'إعادة صرف الوصفة مرة واحدة'),
(80951, 5360, 21, 'إعادة صرف الوصفة مرات عديدة'),
(80952, 5361, 21, 'إعادة صرف الوصفة مرات عديدة'),
(80953, 5362, 21, 'كل المنعكسات طبيعية'),
(80954, 5363, 21, 'تنشيط'),
(80955, 5365, 21, 'منبهات منعشة'),
(80956, 5368, 21, 'يرفض التصريح'),
(80957, 5369, 21, 'reg_re'),
(80958, 5370, 21, 'تسجيل'),
(80959, 5372, 21, 'مسجل'),
(80960, 5373, 21, 'مسجل'),
(80961, 5375, 21, 'تاريخ التسجيل'),
(80962, 5376, 21, 'إستمارة التسجيل'),
(80963, 5377, 21, 'إعادة تأهيل'),
(80964, 5380, 21, 'قابلية الإنتكاس'),
(80965, 5381, 21, 'متعلق ب'),
(80966, 5382, 21, 'متعلق'),
(80967, 5383, 21, 'مسألة متعلقة'),
(80968, 5384, 21, 'مسودات متعلقة بالمريض'),
(80969, 5385, 21, 'القرابة / أطفال'),
(80970, 5386, 21, 'القرابة'),
(80971, 5387, 21, 'درجة القرابة'),
(80972, 5388, 21, 'طلبية تقاربية من هذا الصنف'),
(80973, 5389, 21, 'الأقارب'),
(80974, 5399, 21, 'المعلومات الطبية المرحلة مفقودة من حساب هذا المستخدم'),
(80975, 5400, 21, 'رقم الهوية الطبية المرحلة'),
(80976, 5402, 21, 'تاريخ التسريح'),
(80977, 5403, 21, 'ديانة'),
(80978, 5406, 21, 'إعادة الدخول'),
(80979, 5407, 21, 'تذكير'),
(80980, 5408, 21, 'تذكر المنشأة المختارة'),
(80981, 5409, 21, 'تذكير'),
(80982, 5410, 21, 'فواصل التذكير'),
(80983, 5411, 21, 'التذكير لم يرسل بعد'),
(80984, 5412, 21, 'تم ارسال التذكير'),
(80985, 5413, 21, 'تذكيرات'),
(80986, 5414, 21, 'أرسل المبلغ الي'),
(80987, 5415, 21, 'مستضيف قاصي'),
(80988, 5416, 21, 'إزالة'),
(80989, 5419, 21, 'إزالة المجموعة'),
(80990, 5420, 21, 'إزالة المجموعة من'),
(80991, 5421, 21, 'إزالة الدعم للتطعيم'),
(80992, 5422, 21, 'إزالة الدعم لمدير بي اتش بى'),
(80993, 5423, 21, 'إزالة الدعم للوصفات الطبية'),
(80994, 5425, 21, 'إزالة خاصية تتبع مخطط المريض'),
(80995, 5426, 21, 'حصوات كلوية'),
(80996, 5427, 21, 'إعادة تسمية'),
(80997, 5428, 21, 'إعادة تسمية المجموعة'),
(80998, 5429, 21, 'إستخلاص'),
(80999, 5430, 21, 'مقدم الإستخلاص'),
(81000, 5431, 21, 'رقم مقدم الإستخلاص'),
(81001, 5432, 21, 'إعادة الطلب'),
(81002, 5433, 21, 'إعادة الطلب عند'),
(81003, 5434, 21, 'تم التوصل لنقطة إعادة الطلب'),
(81004, 5435, 21, 'نقطة إعادة الطلب'),
(81005, 5436, 21, 'إعادة'),
(81006, 5437, 21, 'اعد كتابة كلمه السر الجديدة'),
(81007, 5438, 21, 'حدث متكرر'),
(81008, 5439, 21, 'تكرار المعلومة:'),
(81009, 5440, 21, 'المتكررات'),
(81010, 5441, 21, 'إبدال'),
(81011, 5444, 21, 'تاريخ الرد'),
(81012, 5445, 21, 'الرد من طرف'),
(81013, 5446, 21, 'تقرير'),
(81014, 5447, 21, 'تقرير - طبي'),
(81015, 5449, 21, 'تقرير بواسطة'),
(81016, 5453, 21, 'تاريخ التقرير / النتائج'),
(81017, 5454, 21, 'نتائج التقارير'),
(81018, 5455, 21, 'نتائج التقارير / التاريخ المرضي'),
(81019, 5457, 21, 'حالة التقرير'),
(81020, 5458, 21, 'مجموع التقرير'),
(81021, 5459, 21, 'التقرير / طلب'),
(81022, 5460, 21, 'قابل للتبليغ'),
(81023, 5461, 21, 'تم التبليغ'),
(81024, 5462, 21, 'تاريخ التبليغ'),
(81025, 5463, 21, 'تقارير'),
(81026, 5467, 21, 'تم تجاهل الطلب - جاري العمل علي المطالبات!'),
(81027, 5474, 21, 'الخدمة المطلوبة'),
(81028, 5475, 21, 'يتطلب كلمة سر قوية'),
(81029, 5476, 21, 'يتطلب كلمة سر فريدة'),
(81030, 5477, 21, 'مطلوب'),
(81031, 5478, 21, 'مطلوب الدفع المشترك'),
(81032, 5479, 21, 'الحقل المطلوب مفقود: الرجاء اختيار ملف EDI-271 للتحميل'),
(81033, 5480, 21, 'الحقل المطلوب مفقود: الرجاء أدخال الأسم الاول'),
(81034, 5481, 21, 'الحقل المطلوب مفقود: الرجاء أدخال الأسم الاخير'),
(81035, 5482, 21, 'الحقل المطلوب مفقود: الرجاء أدخال اسم المستخدم'),
(81036, 5483, 21, 'حقول مطلوبة'),
(81037, 5484, 21, 'المتطلبات'),
(81038, 5485, 21, 'محجوز'),
(81039, 5486, 21, 'محجوز'),
(81040, 5487, 21, 'محجوز لاستخدامه لتحديد موعد العطلة المقررة'),
(81041, 5488, 21, 'محجوز للتحديد عندما لا يكون عند المزود مواعيد خالية'),
(81042, 5489, 21, 'محجوز للتحديد عندما لم يحصل الموعد كما خطط له'),
(81043, 5490, 21, 'محجوز للتحديد عندما يكون عند المزود مواعيد خالية'),
(81044, 5491, 21, 'اعادة الى الوضع الأصلي'),
(81045, 5492, 21, 'تصفير إعتمادات الممر خارج الموقع'),
(81046, 5493, 21, 'تصفير إعتمادات الممر داخل الموقع'),
(81047, 5495, 21, 'Resn'),
(81048, 5496, 21, 'تم الحل'),
(81049, 5497, 21, 'التنفس'),
(81050, 5498, 21, 'الجهد التنفسي بغير اجهاد'),
(81051, 5499, 21, 'تنفسي'),
(81052, 5501, 21, 'منع المستخدمين الغير مصرح لهم من حجز التسهيلات المحدده لمدير المستخدمين'),
(81053, 5502, 21, 'منع المستخدمين من التسهيلات'),
(81054, 5503, 21, 'تدريب مقصور'),
(81055, 5504, 21, 'نتيجة'),
(81056, 5505, 21, 'إسم النتيجة'),
(81057, 5506, 21, 'حالة النتيجة'),
(81058, 5507, 21, 'حالة النتيجة او المرض مفقودة'),
(81059, 5508, 21, 'النيجة، إستخدم % كحرف بديل'),
(81060, 5509, 21, 'النتائج'),
(81061, 5510, 21, 'النتائج و'),
(81062, 5511, 21, 'النتائج التى تم التوصل اليها للبحث'),
(81063, 5512, 21, 'مجموعة النتائج'),
(81064, 5514, 21, 'طريق النتائج'),
(81065, 5515, 21, 'النتائج بالصفحة'),
(81066, 5516, 21, 'النتائج/التفاصيل'),
(81067, 5517, 21, 'فحص الشبكية'),
(81068, 5518, 21, 'مجذوب لليمين'),
(81069, 5519, 21, 'العودة:'),
(81070, 5520, 21, 'إعادة الجزء السابق مع الدفع'),
(81071, 5521, 21, 'العودة للرزنامة'),
(81072, 5522, 21, 'العودة لنتائج التقرير'),
(81073, 5523, 21, 'العودة لهذة الصفحه و ستكون قادرا على اكمال تثبيت ICD10 بالضغط على رأس القائمه الخاص ب ICD10'),
(81074, 5524, 21, 'العودة لهذة الصفحه و ستكون قادرا على اكمال تثبيت ICD9 بالضغط على رأس القائمه الخاص ب ICD9'),
(81075, 5525, 21, 'العودة لهذة الصفحه و ستكون قادرا على اكمال تثبيت RxNorm بالضغط على رأس القائمه الخاص ب RXNORM'),
(81076, 5526, 21, 'العودة لهذة الصفحه و ستكون قادرا على اكمال تثبيت Snomed بالضغط على رأس القائمه الخاص ب SNOMED'),
(81077, 5527, 21, 'قيمة الإعادة'),
(81078, 5528, 21, 'مراجعة'),
(81079, 5529, 21, 'رجع ل اللعب'),
(81080, 5530, 21, 'إعادة إستخدام اخر ثلاث كلمات سر سابقة غير مسموح به'),
(81081, 5534, 21, 'مراجعة PMH:'),
(81082, 5535, 21, 'مراجعة الأنظمة'),
(81083, 5536, 21, 'مراجعة اختبارات الأنظمة'),
(81084, 5537, 21, 'تمت المراجعة'),
(81085, 5538, 21, 'مراجعة'),
(81086, 5539, 21, 'روماتزم المفاصل'),
(81087, 5540, 21, 'روماتزم المفاصل'),
(81088, 5541, 21, 'اﻷيمن'),
(81089, 5542, 21, 'اﻷذن اليمني'),
(81090, 5543, 21, 'اﻷذن اليمني'),
(81091, 5545, 21, 'اﻷيمن:'),
(81092, 5546, 21, 'طنين فى اﻻذنين'),
(81093, 5547, 21, 'طنين فى اﻻذنين'),
(81094, 5549, 21, 'عوامل مخاطرة'),
(81095, 5550, 21, 'مستوي المخاطرة'),
(81096, 5551, 21, 'RLL:'),
(81097, 5552, 21, 'مقدار الحركة للمفاصل'),
(81098, 5553, 21, 'روماني'),
(81099, 5560, 21, 'جدول الخدمة'),
(81100, 5561, 21, 'طريق'),
(81101, 5562, 21, 'طريق الإعطاء، لو ممكن'),
(81102, 5563, 21, 'محول'),
(81103, 5564, 21, 'سطور'),
(81104, 5565, 21, 'RRR without MOR'),
(81105, 5566, 21, 'مسحه:'),
(81106, 5567, 21, 'مسحات:'),
(81107, 5568, 21, 'قانون'),
(81108, 5569, 21, 'اضافة قانون'),
(81109, 5570, 21, 'تفاصيل القانون'),
(81110, 5572, 21, 'تعديل القانون'),
(81111, 5575, 21, 'تثبيت القانون'),
(81112, 5578, 21, 'قوانيين'),
(81113, 5580, 21, 'قوانيين الإعدادات'),
(81114, 5581, 21, 'أمر مستمر: '),
(81115, 5582, 21, 'انفتاق'),
(81116, 5583, 21, 'روسي'),
(81117, 5584, 21, 'الوصفة العلاجية'),
(81118, 5585, 21, 'الوصفة العلاجية'),
(81119, 5586, 21, 'حافة الوصفة العلاجية السفلى (نقطة)'),
(81120, 5587, 21, 'تفعيل رقم صرف الأدوية المخدرة'),
(81121, 5588, 21, 'تفعيل رقم الخدمة القومي'),
(81122, 5589, 21, 'تفعيل رقم ممارسة المهن الطبية'),
(81123, 5590, 21, 'حافة الوصفة العلاجية اليسرى (نقطة)'),
(81124, 5591, 21, 'حجم ورقة الوصفة العلاجية'),
(81125, 5592, 21, 'حافة الوصفة العلاجية اليمنى (نقطة)'),
(81126, 5593, 21, 'الوصفة العلاجية تظهر رقم صرف الأدوية المخدرة'),
(81127, 5594, 21, 'الوصفة العلاجية تظهر رقم الخدمة القومي'),
(81128, 5595, 21, 'الوصفة العلاجية تظهر رقم ممارسة المهن الطبية'),
(81129, 5596, 21, 'حافة الوصفة العلاجية العليا (نقطة)'),
(81130, 5598, 21, 'RxNorm'),
(81131, 5599, 21, 'قاعدة بيانات RxNorm'),
(81132, 5600, 21, 'S'),
(81133, 5601, 21, 'S.S.'),
(81134, 5602, 21, 'S3:'),
(81135, 5603, 21, 'S4:'),
(81136, 5604, 21, 'SA * * To read the license please read the docs/license.txt or visit * http://www.gnu.org/copyleft/gpl.html * */ //========================================================================= // '),
(81137, 5605, 21, 'تخفيض'),
(81138, 5606, 21, 'مبيعات'),
(81139, 5607, 21, 'المبيعات بالصنف'),
(81140, 5608, 21, 'المبيعات بتقرير المنتج'),
(81141, 5609, 21, 'لُعاب'),
(81142, 5610, 21, 'نفس اليوم'),
(81143, 5611, 21, 'جزيرة ساموان'),
(81144, 5612, 21, 'عينة'),
(81145, 5613, 21, 'نوع المنع'),
(81146, 5617, 21, 'السبت'),
(81147, 5618, 21, 'السبت و اﻷحد'),
(81148, 5619, 21, 'السبت'),
(81149, 5620, 21, 'حفظ'),
(81150, 5621, 21, 'حفظ'),
(81151, 5622, 21, 'حفظ وإغلاق'),
(81152, 5624, 21, 'حفظ و صرف'),
(81153, 5625, 21, 'حفظ وتسليم'),
(81154, 5626, 21, 'حفظ جديد'),
(81155, 5627, 21, 'حفظ كملاحظة جديدة'),
(81156, 5628, 21, 'حفظ اعدادت الشهادة'),
(81157, 5629, 21, 'حفظ التغيرات'),
(81158, 5630, 21, 'حفظ النموذج'),
(81159, 5631, 21, 'حفظ التطعيمات'),
(81160, 5632, 21, 'حفظ حقل جديد'),
(81161, 5633, 21, 'حفظ مجموعة جديدة'),
(81162, 5634, 21, 'حفظ القائمة الجديدة'),
(81163, 5635, 21, 'حفظ قالب جديد'),
(81164, 5636, 21, 'إحفظ إختيارات الإلغاء'),
(81165, 5637, 21, 'حفظ بيانات المريض الديموغرافية'),
(81166, 5638, 21, 'تم حفظ سجل الهوية بنجاح'),
(81167, 5639, 21, 'حفظ العملية'),
(81168, 5641, 21, 'تم المسح الضوئي'),
(81169, 5642, 21, 'تم مسح ورقه الزيارة ضوئيا'),
(81170, 5643, 21, 'ملف الماسح الضوئي'),
(81171, 5644, 21, 'دخل الماسح الضوئي'),
(81172, 5645, 21, 'جدولالمواعيد'),
(81173, 5646, 21, 'تسهيلات جدول المواعيد'),
(81174, 5647, 21, 'رسالة للمدرسة'),
(81175, 5648, 21, 'جنف- انحناء العمود الفقري'),
(81176, 5651, 21, 'SE'),
(81177, 5652, 21, 'SE عنوان'),
(81178, 5653, 21, 'SE مدينة'),
(81179, 5654, 21, 'SE بلد'),
(81180, 5655, 21, 'SE المنطقة'),
(81181, 5656, 21, 'SE الرمز البريدي'),
(81182, 5657, 21, 'SE الولاية'),
(81183, 5658, 21, 'SE الرمز البريدي'),
(81184, 5659, 21, 'بحث'),
(81185, 5661, 21, 'بحث'),
(81186, 5662, 21, 'تكرار البحث'),
(81187, 5663, 21, 'بحث جميع القوائم'),
(81188, 5664, 21, 'احث عن طريق'),
(81189, 5665, 21, 'بحث عن'),
(81190, 5666, 21, 'بحث عن'),
(81191, 5667, 21, 'بحث في'),
(81192, 5668, 21, 'بحث في'),
(81193, 5669, 21, 'بحث أو إضافة مريض'),
(81194, 5670, 21, 'بحث المدفوعات'),
(81195, 5671, 21, 'نتائج البحث'),
(81196, 5672, 21, 'نتائج البحث :'),
(81197, 5673, 21, 'بحث عن المختارات'),
(81198, 5674, 21, 'كلمة البحث غير متوافقة مع القائمة فى قاعدة البيانات'),
(81199, 5675, 21, 'كلمة البحث يجب الا تقل عن ثلاثة احرف'),
(81200, 5676, 21, 'بحث النص'),
(81201, 5677, 21, 'بحث في الحدث'),
(81202, 5678, 21, 'بحث - اضافة'),
(81203, 5679, 21, 'بحث - اضافة مؤمن'),
(81204, 5680, 21, 'بحث عن المواعيد'),
(81205, 5681, 21, 'جاري البحث ...'),
(81206, 5682, 21, 'استخدام حزام الأمان'),
(81207, 5683, 21, 'استخدام حزام الأمان'),
(81208, 5684, 21, 'ثان'),
(81209, 5687, 21, 'ثانوي'),
(81210, 5688, 21, 'تأمين إضافي'),
(81211, 5689, 21, 'بيانات التأمين الإضافي'),
(81212, 5690, 21, 'مقدم التأمين الإضافي'),
(81213, 5691, 21, 'نظام ميديكير الثانوي'),
(81214, 5698, 21, 'أمن'),
(81215, 5699, 21, 'مشاهدة الكل'),
(81216, 5700, 21, 'مشاهدة التفاويض'),
(81217, 5701, 21, 'مشاهدة مخطط النمو البياني'),
(81218, 5702, 21, 'راجع الرسائل من اخر مجموعة من المطالبات'),
(81219, 5704, 21, 'فحص منذ'),
(81220, 5705, 21, 'اسم القطعة'),
(81221, 5706, 21, 'مطالبة مجموعة القطع'),
(81222, 5707, 21, 'تشنج'),
(81223, 5708, 21, 'إختر'),
(81224, 5709, 21, 'إختر'),
(81225, 5710, 21, 'إختر'),
(81226, 5712, 21, 'إختر محتوى'),
(81227, 5713, 21, 'إختر نسبة الصفوف او إختر الأيام'),
(81228, 5714, 21, 'إختر فترة زمنية'),
(81229, 5715, 21, 'إختر مستخدم'),
(81230, 5716, 21, 'إختيار الكل'),
(81232, 5720, 21, 'إختر فئة'),
(81233, 5722, 21, 'إختر'),
(81234, 5723, 21, 'إختر الضوابط المراد حذفها'),
(81235, 5724, 21, 'إختر جدول CSV'),
(81236, 5725, 21, 'إختر البيانات المراد إبهامها'),
(81237, 5726, 21, 'إختر بيانات لأدراجها من ضمن البيانات المبهمة'),
(81238, 5727, 21, 'إختر التاريخ'),
(81239, 5728, 21, 'إختر'),
(81240, 5729, 21, 'إختر التشخيص'),
(81241, 5730, 21, 'إختر التشخيص المراد إبهامه'),
(81242, 5731, 21, 'إختر الدواء'),
(81243, 5732, 21, 'إختر الأدوية'),
(81244, 5733, 21, 'إختر الأدوية المراد إبهامها'),
(81245, 5734, 21, 'إختر ملف EDI-271'),
(81246, 5736, 21, 'إختر الحقل'),
(81247, 5737, 21, 'إختر الحقول'),
(81248, 5738, 21, 'إختر للطباعة'),
(81249, 5739, 21, 'إختر التطعيم'),
(81250, 5740, 21, 'إختر التطعيمات المراد إبهامها'),
(81251, 5741, 21, 'إختر تامين وذلك بالكتابة'),
(81252, 5742, 21, 'إختر الأصدار'),
(81253, 5744, 21, 'إختر لغة'),
(81254, 5745, 21, 'إختر واحد'),
(81255, 5746, 21, 'إختر تشخيص او أكثر لتسويغ الخدمة'),
(81256, 5747, 21, 'إختر ملف أو أكثر للتحميل'),
(81257, 5754, 21, 'إختر الإعدادات للتصدير'),
(81258, 5755, 21, 'إختر المسبب الرئيسي لأي حدث مفقود لهذا اليوم'),
(81259, 5759, 21, 'إختر مستخدم'),
(81260, 5760, 21, 'اختيار مستخدمين من القائمة المنسدلة'),
(81261, 5761, 21, 'إختر اي اللغات مسموح اختيارها عند الدخول (مسموح فقط لو كان اختيار كل اللغات معطل)'),
(81262, 5762, 21, 'إختر نعم لتأكيد مسح المجموعة'),
(81263, 5765, 21, 'مُختار'),
(81264, 5766, 21, 'مراجعة مُختارة'),
(81265, 5767, 21, 'تفعيل هذا الإختيار سيكون رسالة يتحتم على كل مستقبل معالجتها كل على حده (هذا ليس اختيارا للمجموعة)'),
(81266, 5768, 21, 'ذاتي'),
(81267, 5769, 21, 'دفع ذاتي'),
(81268, 5771, 21, 'إرسال'),
(81269, 5772, 21, 'إرسال تذكير مؤرخ'),
(81270, 5773, 21, 'أرسل تنبيه'),
(81271, 5774, 21, 'جار الإرسال'),
(81272, 5775, 21, 'أرسل رسالة'),
(81273, 5776, 21, 'أرسل مجموعة تنبيهات'),
(81274, 5777, 21, 'أرسل تنبيهات للمرضي كل على حسب اختياره للوقاية او للمتابعة'),
(81275, 5778, 21, 'إرسال الملخصات مع الإحالات'),
(81276, 5779, 21, 'إرسل هذا الملف'),
(81277, 5780, 21, 'إرسل هذه الرسالة'),
(81278, 5781, 21, 'إرسل الى'),
(81279, 5784, 21, 'إرسل للكل'),
(81280, 5788, 21, 'مُرسل'),
(81281, 5789, 21, 'هوية المُرسل'),
(81282, 5790, 21, 'هوية المُرسل (ISA06)'),
(81283, 5791, 21, 'ًًٍََُِمرقي هوية المُرسل (ISA05)'),
(81284, 5792, 21, 'هويات المرسلين'),
(81285, 5793, 21, 'الإرسل الى'),
(81286, 5794, 21, 'حساسيات'),
(81287, 5795, 21, 'حساسية'),
(81288, 5796, 21, 'الكشف الحِسِّيّ‎ طبيعي  '),
(81289, 5797, 21, 'تم الإرسال'),
(81290, 5799, 21, 'أُرسل من خلال, يُترك فارغ للجميع'),
(81291, 5801, 21, 'تاريخ الإرسال'),
(81292, 5802, 21, 'المواد المُرسلة'),
(81293, 5803, 21, 'التقارير المُرسلة؟'),
(81294, 5804, 21, 'تم الإرسال بنجاح'),
(81295, 5807, 21, 'تم الإرسال للطابعة.'),
(81296, 5808, 21, 'إرسل الى, يترك فارغ للجميع'),
(81297, 5810, 21, 'تم الإرسال, حتى الان لم يتم تأكيد الإستلام'),
(81298, 5811, 21, 'تم الإرسال, لم يُستقبل بعد'),
(81299, 5812, 21, 'سبتمبر -أيلول'),
(81300, 5813, 21, 'مفصول'),
(81301, 5814, 21, 'سبتمبر -أيلول'),
(81302, 5815, 21, 'تتابع'),
(81303, 5816, 21, 'تتابع'),
(81304, 5818, 21, 'ممثل الخدمة'),
(81305, 5821, 21, 'خدمة'),
(81306, 5822, 21, 'فئة الخدمة'),
(81307, 5823, 21, 'رمز الخدمة'),
(81308, 5824, 21, 'رمز الخدمة للتقارير المالية'),
(81309, 5825, 21, 'رموز الخدمة'),
(81310, 5826, 21, 'تاريخ الخدمة'),
(81311, 5827, 21, 'تاريخ الخدمة :'),
(81312, 5829, 21, 'موقع الخدمة'),
(81313, 5830, 21, 'أسم الخدمة'),
(81314, 5831, 21, 'مقدم الخدمة اخصائي'),
(81315, 5832, 21, 'الإبلاغ عن الخدمة'),
(81316, 5833, 21, 'الإبلاغ عن الخدمة فقط'),
(81317, 5834, 21, 'الخدمات'),
(81318, 5835, 21, 'الخدمات عن طريق الفئة'),
(81319, 5836, 21, 'الخدمات المقدمة'),
(81320, 5837, 21, 'الخدمات المقدمة'),
(81321, 5838, 21, 'الخدمات - المنتجات'),
(81322, 5839, 21, 'نوع الجلسة'),
(81323, 5840, 21, 'اضبط'),
(81324, 5841, 21, 'اضبط كعكة المنشئة لتتذكر المنشئة المختارة بين مرات الدخول'),
(81325, 5842, 21, 'اضبط كمكتمل'),
(81326, 5843, 21, 'اضبط اولوية التشغيل لمحرك تقارير CDR'),
(81327, 5844, 21, 'اضبط اولوية التشغيل لإنشاء تنبيهات المرضي (في نمط العيادة الكامل)'),
(81328, 5845, 21, 'اضبط هذا للعنوان الكامل الوحيد لإنشاء شهادات SSL لل HTTPS'),
(81329, 5846, 21, 'اضبط الي'),
(81330, 5847, 21, 'اعادة الضبط'),
(81331, 5848, 21, 'ضبط رقم التعديل لقاعدة البيانات...'),
(81332, 5849, 21, 'الإعدادات'),
(81333, 5851, 21, 'صداع نصفي حاد'),
(81334, 5853, 21, 'شدة الألم'),
(81335, 5854, 21, 'شدة الألم'),
(81336, 5855, 21, 'جنس'),
(81337, 5856, 21, 'الأمراض المنقولة جنسيا'),
(81338, 5857, 21, 'بروتوكول نقل الملفات المؤمن'),
(81339, 5858, 21, 'خوارزمية التشفير'),
(81340, 5859, 21, 'مشاركة'),
(81341, 5860, 21, 'أمر للطباعة من المزود'),
(81342, 5863, 21, 'وصف قصير'),
(81343, 5864, 21, 'نقص في التنفس'),
(81344, 5865, 21, 'نقص في التنفس'),
(81345, 5866, 21, 'نقص في التنفس ٢'),
(81346, 5867, 21, 'سجل الحقنات'),
(81347, 5868, 21, 'سجل الحقنات'),
(81348, 5870, 21, 'يجب ان يكون مثل nnnnn-nnnn-nn'),
(81349, 5871, 21, 'يجب ان يكون حرفين'),
(81350, 5872, 21, 'يجب ان يحتوي على ١٠ خانات'),
(81351, 5873, 21, 'يجب ان يحتوي على ١٠ خانات فقط'),
(81352, 5874, 21, 'الكتف'),
(81353, 5875, 21, 'الكتف + الترقوة'),
(81354, 5876, 21, 'عرض'),
(81355, 5877, 21, 'عرض'),
(81356, 5878, 21, 'عرض الكل'),
(81357, 5880, 21, 'عرض الكل'),
(81358, 5881, 21, 'عرض جميع الإجراءات'),
(81359, 5883, 21, 'عرض جميع المعاملات'),
(81360, 5884, 21, 'عرض ك مشغول'),
(81361, 5885, 21, 'العرض للمصرح لهم فقط'),
(81362, 5886, 21, 'عرض الأوقات المتاحة'),
(81363, 5887, 21, 'عرض الجميع: US & Metric'),
(81364, 5888, 21, 'عرض الجميع: US & Metric'),
(81365, 5889, 21, 'عرض التفاصيل'),
(81366, 5890, 21, 'عرض الأخطاء فقط'),
(81367, 5891, 21, 'عرض الرسم البياني'),
(81368, 5892, 21, 'عرض وصف الحدث عن وضع الفأرة عليه؟'),
(81369, 5893, 21, 'عرض عدد الأحداث على صفحة المدير؟'),
(81370, 5894, 21, 'عرض الغير نشط'),
(81371, 5896, 21, 'عرض القائمة'),
(81372, 5897, 21, 'عرض النِّظامُ المِتْرِيّ‎ فقط'),
(81373, 5898, 21, 'عرض الحاشية'),
(81374, 5900, 21, 'عرض الإجراءات الغير محذوفة فقط'),
(81375, 5901, 21, 'عرض ملاحظات المريض'),
(81376, 5902, 21, 'عرض الرطل و الأوقية'),
(81377, 5903, 21, 'عرض الرطل بالقيمة العشرية'),
(81378, 5904, 21, 'عرض الأساسي كاملا'),
(81379, 5905, 21, 'عرض التنبيهات'),
(81380, 5906, 21, 'عرض التقرير'),
(81381, 5907, 21, 'عرض البحث- تسليم الروابط دفعة واحدة؟'),
(81382, 5910, 21, 'أعرض طلب الحالة المهيئة لأداة إضافة قائمة (هذا سيسأل عن العنوان و اﻹختصار)'),
(81383, 5911, 21, 'اعرض هذة المجموعة علي شاشة عرض المريض حتي لو تكن هناك أحداث مسجلة'),
(81384, 5913, 21, 'عرض الفواتير الغير مدفوعة فقط'),
(81385, 5914, 21, 'عرض الولايات المتحدة فقط'),
(81386, 5915, 21, 'يعرض'),
(81387, 5916, 21, 'يعرض النتائج'),
(81388, 5920, 21, 'الاشقاء'),
(81389, 5921, 21, 'فقر الدم المنجلي'),
(81390, 5922, 21, 'التوقيع'),
(81391, 5923, 21, 'السِّينِيّي -جزء من القولون‎ -فحص القولون'),
(81392, 5925, 21, 'توقيع نتيجة المختبر (كتابة,اختياري)'),
(81393, 5926, 21, 'التوقيع على النتيجة'),
(81394, 5927, 21, 'التوقيع'),
(81395, 5929, 21, 'التوقيع:'),
(81396, 5930, 21, 'وصفة علاجية موقعة'),
(81397, 5932, 21, 'انتفاخ كبير:'),
(81398, 5933, 21, 'مبسط'),
(81399, 5934, 21, 'رسوم ميسرة'),
(81400, 5935, 21, 'ديموغرافيا ميسرة'),
(81401, 5936, 21, 'وصفات ميسرة'),
(81402, 5937, 21, 'منذ'),
(81403, 5938, 21, 'تحياتي الصادقة,'),
(81404, 5940, 21, 'مفرد'),
(81405, 5941, 21, 'مفرد-قائمة الأختيارات'),
(81406, 5942, 21, 'مفرد-قائمة الأختيارات مع مقدرة الأضافة عليها'),
(81407, 5943, 21, 'مُفرد'),
(81408, 5946, 21, 'مشكلة الجيوب الأنفية'),
(81409, 5947, 21, 'جراحة الجيوب الأنفية'),
(81410, 5948, 21, 'SINUS TENDERNESS:'),
(81411, 5949, 21, 'اِلْتِهابُ الجَيْب الأنفية'),
(81412, 5950, 21, 'مكان'),
(81413, 5951, 21, 'رقم هوية الموقع'),
(81414, 5952, 21, 'رقم هوية الموقع لدمج العلومات الصحية, خدمة تبادل المعمل'),
(81415, 5953, 21, 'رقم هوية الموقع للبرنامج, خدمة تبادل المعمل'),
(81416, 5956, 21, 'مقاس'),
(81417, 5957, 21, 'المقاس يجب ان يكون بين 1 و 999'),
(81418, 5958, 21, 'مقاس-قائمة'),
(81419, 5959, 21, 'جلد'),
(81420, 5960, 21, 'سرطان الجلد'),
(81421, 5961, 21, 'مرض جلدي'),
(81422, 5962, 21, 'جلد اخرى'),
(81423, 5963, 21, 'تجاوز تفويض ملاحظات المريض'),
(81424, 5964, 21, 'تجاوز جزء'),
(81425, 5965, 21, 'Skipping SQL-Ledger dump - not implemented for Windows server'),
(81426, 5967, 21, 'أنماط النوم'),
(81427, 5968, 21, 'أنماط النوم'),
(81428, 5969, 21, 'نائم'),
(81429, 5970, 21, 'السلوفاكية'),
(81430, 5972, 21, 'Sm debt w/o'),
(81431, 5973, 21, 'لقد تم مسح مخبئ Smarty'),
(81432, 5974, 21, 'مدخن, الحالة الحالية غير معروفة'),
(81433, 5976, 21, 'حالة التدخين'),
(81434, 5977, 21, 'تفوبض الرسائل النصية القصيرة'),
(81435, 5978, 21, 'ممر الرسائل النصية القصيرة'),
(81436, 5979, 21, 'ممر الرسائل النصية القصيرة, مفتاح API'),
(81437, 5980, 21, 'ممر الرسائل النصية القصيرة, مفتاح API'),
(81438, 5981, 21, 'كلمة سر ممر الرسائل النصية القصيرة'),
(81439, 5982, 21, 'إسم مستخدم ممر الرسائل النصية القصيرة'),
(81440, 5983, 21, 'تذكيرات الرسائل النصية القصيرة'),
(81441, 5984, 21, 'أوقات تذكيرات الرسائل النصية القصيرة'),
(81442, 5985, 21, 'أرسل الرسائل النصية القصيرة قبل'),
(81443, 5986, 21, 'تم إرسال الرسائل النصية القصيرة'),
(81444, 5987, 21, 'SMS Text, Usable Tag: ***NAME***, ***PROVIDER***, ***DATE***, ***STARTTIME***, ***ENDTIME***<br> i.e. Dear ***NAME***'),
(81445, 5988, 21, 'إعدادات الرسائل النصية القصيرة/الإيميل'),
(81446, 5989, 21, 'كلمة سرSMTP للتوثق'),
(81447, 5992, 21, 'إسم مستضيف خادم SMTP'),
(81448, 5993, 21, 'رقم منفذ خادم SMTP'),
(81449, 5994, 21, 'مستخدم SMTP للتوثق'),
(81450, 5995, 21, 'المسميات المنظمة للطب SNOMED'),
(81451, 5996, 21, 'طلب طبي (RF1) المسميات المنظمة للطب'),
(81452, 5997, 21, 'تشخيص (RF1) المسميات المنظمة للطب'),
(81453, 5998, 21, 'عملية (RF1) المسميات المنظمة للطب'),
(81454, 5999, 21, 'تشخيص (RF2) المسميات المنظمة للطب'),
(81455, 6000, 21, 'المصطلح الطبي في المسميات المنظمة للطب'),
(81456, 6001, 21, 'قاعدة بيانات المسميات المنظمة للطب'),
(81457, 6002, 21, 'التشخيص المسميات المنظمة للطب'),
(81458, 6003, 21, 'الإجراءات المسميات المنظمة للطب'),
(81459, 6004, 21, 'شَخير'),
(81460, 6005, 21, 'الشكوي , الفحص , التقييم و خطة العلاج'),
(81461, 6006, 21, 'صعوبات اجتماعية'),
(81462, 6009, 21, 'التاريخ الاجتماعي'),
(81463, 6010, 21, 'رقم الخدمة الأجتماعية'),
(81464, 6011, 21, 'حّل'),
(81465, 6013, 21, 'مضمون جسدى'),
(81466, 6014, 21, 'لم يتم عرض كل التفاويض: انقر هنا لعرض الكل'),
(81467, 6015, 21, 'بعض الرموز لم يتم عرضها'),
(81468, 6016, 21, 'بعض المراجعات لم يتم عرضها:انقر هنا لعرض الكل'),
(81469, 6017, 21, 'حدثت بعض الأخطاء خلال عملية إزالة الهوية'),
(81470, 6018, 21, 'بعض الملاحظات لم يتم عرضها'),
(81471, 6019, 21, 'لم يتم عرض كل الملاحظات. انقر هنا لعرض الكل'),
(81472, 6020, 21, 'بعض الكلمات'),
(81473, 6023, 21, 'حدث خطأ. من فضلك حاول مرة اخرى'),
(81474, 6024, 21, 'فاصل سوف يحين الوقت قريباَ (التذكيرات الطّبية)'),
(81475, 6025, 21, 'فاصل سوف يحين الوقت قريباَ (تذكيرات المرضي)'),
(81476, 6026, 21, 'التهاب الحلق'),
(81477, 6027, 21, 'عفواً لم يتم تحديد الموعد'),
(81478, 6028, 21, 'عفواً. حدث خطأ خلال تحميل الملف'),
(81479, 6029, 21, 'فرز حسب'),
(81480, 6030, 21, 'فرز حسب'),
(81481, 6031, 21, 'فرز حسب تدقيق المجموع'),
(81482, 6032, 21, 'فرز حسب التعليقات'),
(81483, 6034, 21, 'فرز حسب التاريخ'),
(81484, 6035, 21, 'فرز حسب التاريخ- الوقت'),
(81485, 6036, 21, 'فرز حسب المراجعة'),
(81486, 6037, 21, 'فرز حسب المجموعة'),
(81487, 6040, 21, 'فرز حسب بطاقة المريض'),
(81488, 6041, 21, 'فرز حسب العمليات التى تمت بنجاح'),
(81489, 6043, 21, 'فرز حسب المستخدم'),
(81490, 6044, 21, 'فرز حسب التطعيم'),
(81491, 6045, 21, 'إفرز تنازلياَ'),
(81492, 6046, 21, 'فرز حسب النتائج'),
(81493, 6047, 21, 'إفرز تصاعدياَ'),
(81494, 6048, 21, 'المصدر'),
(81495, 6049, 21, 'ملف المصدر'),
(81496, 6050, 21, 'طريق ملف المصدر'),
(81497, 6051, 21, 'رمز المصدر مفقود '),
(81498, 6052, 21, 'جملة المصدر'),
(81499, 6054, 21, 'مريض المصدر'),
(81500, 6055, 21, 'لم يتم تحديد تاريخ ميلاد مريض المصدر'),
(81501, 6056, 21, 'لم يتم العثور علي مريض المصدر'),
(81502, 6057, 21, 'المصدر:'),
(81503, 6060, 21, 'مسافة'),
(81504, 6061, 21, 'مسافة'),
(81505, 6062, 21, 'الأسبانية'),
(81506, 6063, 21, 'الأسبانية (امريكا اللاتينية)'),
(81507, 6064, 21, 'الأسبانية (اسبانيا)'),
(81508, 6066, 21, 'رموز التحكم الخاصة غير مسموح بها'),
(81509, 6067, 21, 'رعاية خاصة لطلب المؤشرات الحيوية'),
(81510, 6068, 21, 'أخصائي'),
(81511, 6069, 21, 'أسم الأخصائي وتوقيعه'),
(81512, 6071, 21, 'مجال التخصص'),
(81513, 6072, 21, 'اﻷنظمة الخاصة'),
(81514, 6073, 21, 'تخصص:'),
(81515, 6074, 21, 'محدد'),
(81516, 6075, 21, 'تطبيق محدد'),
(81517, 6076, 21, 'خدمة منع الحمل محددة'),
(81518, 6077, 21, 'نتيجة محددة'),
(81519, 6078, 21, 'خدمة محددة'),
(81520, 6079, 21, 'محدد'),
(81521, 6080, 21, 'Specifies formatting for codes. # = digit, * = any character. Empty if not used.'),
(81522, 6081, 21, 'Specifies formatting for codes. # = digit, @ = alpha, * = any character. Empty if not used.'),
(81523, 6082, 21, 'Specifies formatting for invoice reference numbers. # = digit, * = any character. Empty if not used.'),
(81524, 6083, 21, 'Specifies formatting for invoice reference numbers. # = digit, @ = alpha, * = any character. Empty if not used.'),
(81525, 6084, 21, 'Specifies formatting for product NDC fields. # = digit, * = any character. Empty if not used.'),
(81526, 6085, 21, 'Specifies formatting for product NDC fields. # = digit, @ = alpha, * = any character. Empty if not used.'),
(81527, 6086, 21, 'Specifies formatting for the external patient ID. # = digit, * = any character. Empty if not used.'),
(81528, 6087, 21, 'Specifies formatting for the external patient ID. # = digit, @ = alpha, * = any character. Empty if not used.'),
(81529, 6088, 21, 'عيّنة'),
(81530, 6089, 21, 'رقم العيّنة- التعريف'),
(81531, 6090, 21, 'نوعية العيّنة'),
(81532, 6092, 21, 'إملاء شفوي'),
(81533, 6093, 21, 'مبيد الحيوانات المنوية'),
(81534, 6094, 21, 'استئصال الطحال'),
(81535, 6095, 21, 'القرين'),
(81536, 6097, 21, 'بَلْغَم'),
(81537, 6098, 21, 'بَلْغَم :'),
(81538, 6099, 21, 'برنامج الضغط SQ'),
(81539, 6102, 21, 'فرقة'),
(81540, 6103, 21, 'عضوية الفرقة'),
(81541, 6104, 21, 'فِرق'),
(81542, 6105, 21, 'الصحة الجنسية و التناسلية'),
(81543, 6106, 21, 'الصحة الجنسية و التناسلية - تخطيط الأسرة'),
(81544, 6107, 21, 'الصحة الجنسية و التناسلية - لا يوجد تخطيط ل الأسرة'),
(81545, 6108, 21, 'تحويلات الصحة الجنسية و التناسلية'),
(81546, 6109, 21, 'طلب زيارة الصحة الجنسية و التناسلية'),
(81547, 6110, 21, 'تاريخ Srv'),
(81548, 6111, 21, 'الضمان الإجتماعي'),
(81549, 6112, 21, 'ادارة شهادة SSL'),
(81550, 6113, 21, 'رقم الخدمة الأجتماعية'),
(81551, 6114, 21, 'اسْتِقْرار'),
(81552, 6115, 21, 'إفراجات مرحلية'),
(81553, 6116, 21, 'نموذجي'),
(81554, 6117, 21, 'الرمز النموذجي'),
(81555, 6118, 21, 'الإجراءات النموذجية'),
(81556, 6119, 21, 'الإجراءات النموذجية (تنبيهات نشطة)'),
(81557, 6120, 21, 'الإجراءات النموذجية (تنبيهات خاملة)'),
(81558, 6121, 21, 'الإجراءات النموذجية (تذكيرات المريض)'),
(81559, 6122, 21, 'الإسم النموذجي'),
(81560, 6123, 21, 'قياسي, مبسّط: العنوان فقط, تاريخ البدء, التعليقات و خانة تأشير نشطة. لا تشخيص او حدوث او تاريخ النهاية او محوّل من'),
(81561, 6124, 21, 'بَدءٌ'),
(81562, 6125, 21, 'بَدءٌ (سنة-شهر-يوم): '),
(81563, 6126, 21, 'بداية تقرير جديد'),
(81564, 6128, 21, 'تاريخ البداية'),
(81565, 6129, 21, 'تاريخ البداية في هذا المركز'),
(81566, 6130, 21, 'يجب ان لايكون تاريخ البداية اكبر من تاريخ النهاية'),
(81567, 6131, 21, 'تاريخ البداية:'),
(81568, 6132, 21, 'تاريخ البداية:'),
(81569, 6133, 21, 'وقت البداية'),
(81570, 6134, 21, 'تاريخ البدء'),
(81571, 6135, 21, 'فَوراً'),
(81572, 6136, 21, 'حالة-ولاية'),
(81573, 6137, 21, 'نوعية بيانات الولاية'),
(81574, 6138, 21, 'رقم الرخصة'),
(81575, 6139, 21, 'رقم لوحة السيارة'),
(81576, 6140, 21, 'قائمة الولايات'),
(81577, 6141, 21, 'قائمة الولايات (اكتب, الإضافة إختيارية)'),
(81578, 6142, 21, 'أداة قائمة الولايات للحقول المفصلة'),
(81579, 6143, 21, 'الولاية او المنطقة'),
(81580, 6144, 21, 'الولاية / المنطقة'),
(81581, 6145, 21, 'الولاية / دائرة الكنيسة'),
(81582, 6146, 21, 'ملخص البيان'),
(81583, 6147, 21, 'البيانات وتحديث الفواتير'),
(81584, 6148, 21, 'البيانات المرسلة:'),
(81585, 6149, 21, 'البيانات: لن يتم تحديث الفواتير'),
(81586, 6150, 21, 'النص الثابت'),
(81587, 6151, 21, 'إحصائيات'),
(81588, 6152, 21, 'مختصرات الحالة'),
(81589, 6153, 21, 'الحالة'),
(81590, 6154, 21, 'حالة التنويم'),
(81591, 6155, 21, 'حالة المطالبة'),
(81592, 6156, 21, 'الوضع الراهن'),
(81593, 6158, 21, 'إرشاد الإيدز'),
(81594, 6159, 21, 'التركيز و التهيئة'),
(81595, 6164, 21, 'خطوات تنصيب قاعدة بيانات ال  DSM IV'),
(81596, 6165, 21, 'خطوات تنصيب قاعدة بيانات ال ICD 10'),
(81597, 6166, 21, 'خطوات تنصيب قاعدة بيانات ال ICD 9'),
(81598, 6167, 21, 'خطوات تنصيب قاعدة بيانات ال RxNorm'),
(81599, 6168, 21, 'خطوات تنصيب قاعدة بيانات ال SNOMED'),
(81600, 6169, 21, 'تصلب المفاصل'),
(81601, 6170, 21, 'تَيَبُّس‎'),
(81602, 6171, 21, 'أشهر المخزون'),
(81603, 6172, 21, 'آلام في المعدة'),
(81604, 6174, 21, 'Stored Hash'),
(81605, 6175, 21, 'شد عضلي-Strain'),
(81606, 6176, 21, 'تَدَفّق'),
(81607, 6177, 21, 'شارع'),
(81608, 6178, 21, 'عنوان الشارع'),
(81609, 6179, 21, 'الشارع والرقم'),
(81610, 6180, 21, 'قُوَّة'),
(81611, 6182, 21, 'بكتيريا في الحلق-Strep'),
(81612, 6183, 21, 'كسر إجهاد'),
(81613, 6184, 21, 'اختبار الجهد'),
(81614, 6185, 21, 'سَكْتَة'),
(81615, 6186, 21, 'كلمة السر القوية تتكون من 8 إدخالات, ثلاثة منها يجب ان تكون احرفا صغري, كبري, ارقاما او رموزا مميزة'),
(81616, 6187, 21, 'أسلوب'),
(81617, 6188, 21, 'أسلوب الطلب المستخدم لإضافة المرضي الجدد'),
(81618, 6189, 21, 'فئة فرعية'),
(81619, 6190, 21, 'المجموع'),
(81620, 6191, 21, 'فية فرعية'),
(81621, 6192, 21, 'فئة فرعية'),
(81622, 6193, 21, 'تحت الجلد'),
(81623, 6194, 21, 'عنوان'),
(81624, 6195, 21, 'شَخْصيّ'),
(81625, 6196, 21, 'تحت اللسان'),
(81626, 6197, 21, 'تحت اللسان'),
(81627, 6198, 21, 'تسليم'),
(81628, 6199, 21, 'تسليم'),
(81629, 6200, 21, 'تسليم جميع المحتويات'),
(81630, 6202, 21, 'تسليم المراجعة'),
(81631, 6203, 21, 'تسليم النموذج'),
(81632, 6204, 21, 'تسليم المحتويات المختارة'),
(81633, 6205, 21, 'تم التسليم'),
(81634, 6206, 21, 'تم التسليم عن طريق'),
(81635, 6207, 21, 'رقم الدخول (PER06) للمسّلم EDI'),
(81636, 6208, 21, 'مشترك'),
(81637, 6209, 21, 'عنوان المشترك'),
(81638, 6213, 21, 'الجهة الموظفة للمشترك'),
(81639, 6214, 21, 'الجهة الموظفة للمشترك (SE)'),
(81640, 6215, 21, 'عنوان الجهة الموظفة للمشترك'),
(81641, 6216, 21, 'مدينة الجهة الموظفة للمشترك'),
(81642, 6217, 21, 'دولة الجهة الموظفة للمشترك'),
(81643, 6218, 21, 'ولاية الجهة الموظفة للمشترك'),
(81644, 6221, 21, 'الرمز البريدي للجهة الموظفة للمشترك'),
(81645, 6225, 21, 'هاتف المشترك'),
(81646, 6226, 21, 'درجة القرابة للمشترك'),
(81647, 6227, 21, 'درجة القرابة للمشترك ليست نفس الشخص لكن الإسم متطابق! هل هذا صحيح؟'),
(81648, 6228, 21, 'درجة القرابة للمشترك ليست نفس الشخص لكن رقم الضمان الإجتماعي متطابق! هل هذا صحيح؟'),
(81649, 6229, 21, 'درجة القرابة للمشترك هي نفس الشخص لكن الإسم مختلف! هل هذا صحيح؟'),
(81650, 6230, 21, 'درجة القرابة للمشترك هي نفس الشخص لكن رقم الضمان الإجتماعي مختلف! هل هذا صحيح؟'),
(81651, 6231, 21, 'جنس المشترك'),
(81652, 6237, 21, 'اسْتِبْدال'),
(81653, 6238, 21, 'الأستبدال مسموح'),
(81654, 6240, 21, 'نجاح'),
(81655, 6241, 21, 'نجاح'),
(81656, 6242, 21, 'نجاح تأكيد استلام نتائج المعمل'),
(81657, 6243, 21, 'تم الحصول على نتائج المختبر بنجاح'),
(81658, 6244, 21, 'تم استرجاع النتائج من شبكة المحتبرات بنجاح'),
(81659, 6246, 21, 'تم اضافة الفئة بنجاح'),
(81660, 6247, 21, 'تم اضافته الى القائمة بنجاح'),
(81661, 6248, 21, 'تم الحذف بنجاح'),
(81662, 6250, 21, 'تم اضافة قاعدة البيانات بنجاح'),
(81663, 6251, 21, 'تم اضافة قواعد البيانات التالية بنجاح'),
(81664, 6252, 21, 'تم التعديل بنجاح'),
(81665, 6253, 21, 'تم الحفظ بنجاح. هل تحب أن تخصص المكان؟'),
(81666, 6254, 21, 'تم الحفظ بنجاح. هل تحب أن توزّع؟'),
(81667, 6256, 21, 'تم الحفظ بنجاح'),
(81668, 6257, 21, 'تمت ترقية قاعدة البيانات بنجاح'),
(81669, 6258, 21, 'تم ترقية قواعد البيانات التالية بنجاح'),
(81670, 6259, 21, 'بنجاح'),
(81671, 6260, 21, 'إنتحار'),
(81672, 6261, 21, 'موجز'),
(81673, 6262, 21, 'موجز ل'),
(81674, 6265, 21, 'الأحد'),
(81675, 6267, 21, 'الأحد'),
(81676, 6268, 21, 'قوائم بيان مفردات الخدمة المقدمة للتأمين/صحيفة المصاريف'),
(81677, 6269, 21, 'رموز قوائم بيان مفردات الخدمة المقدمة للتأمين/صحيفة المصاريف'),
(81678, 6270, 21, 'إدارة قوائم بيان مفردات الخدمة المقدمة للتأمين/صحيفة المصاريف'),
(81679, 6271, 21, 'تقرير قوائم بيان مفردات الخدمة المقدمة للتأمين/صحيفة المصاريف'),
(81680, 6272, 21, 'قوائم بيان مفردات الخدمة المقدمة للتأمين/صحيفة المصاريف'),
(81681, 6273, 21, 'قوائم بيان مفردات الخدمة المقدمة للتأمين'),
(81682, 6274, 21, 'قوائم بيان مفردات الخدمة المقدمة للتأمين (صحيفة المصاريف) يقصد بها نوعية الخدمات الطبية مفنطة علي حسب التشخيص و موقعة من المستشفي لإستلام مبلغ التأمين الصحي'),
(81683, 6275, 21, 'مستخدم مميز-يملك جميع الصلاحيات'),
(81684, 6276, 21, 'يشرف على'),
(81685, 6278, 21, 'الطبيب المشرف علي الأدوية المخدرة'),
(81686, 6279, 21, 'الأسم الأول للطبيب المشرف'),
(81687, 6280, 21, 'الأسم الأخير للطبيب المشرف'),
(81688, 6281, 21, 'رقم المزوّد الوطني للطبيب المشرف'),
(81689, 6282, 21, 'UPIN للطبيب المشرف'),
(81690, 6283, 21, 'اسم الجهة المشرفة'),
(81691, 6284, 21, 'أحداث تقويم الدعم المطبقة علي عدّه مزودين'),
(81692, 6285, 21, 'استيراد/تصدير بيانات التهيئة للدعم عن طريق صفحة الإحتياط'),
(81693, 6286, 21, 'أحداث الدعم المطبقة علي عدّه مزودين'),
(81694, 6288, 21, 'يدعم تشفير و فك التشفير لTripleDES فقط.'),
(81695, 6289, 21, 'نوع السطح'),
(81696, 6290, 21, 'عمليات'),
(81697, 6291, 21, 'عملية'),
(81698, 6292, 21, 'قائمة مشاكل العمليات'),
(81699, 6293, 21, 'معطل'),
(81700, 6294, 21, 'إيقاف عن العمل'),
(81701, 6295, 21, 'تاريخ ال Svc'),
(81702, 6296, 21, 'تاريخ ال Svc:'),
(81703, 6299, 21, 'تعرق:'),
(81704, 6300, 21, 'اللغة السويدية'),
(81705, 6301, 21, 'تورم'),
(81706, 6302, 21, 'تورم -يمين'),
(81707, 6303, 21, 'تورم المفاصل'),
(81708, 6304, 21, 'تورم الغدد اللمفاوية'),
(81709, 6305, 21, 'رمز مستخدم كفاصلة عشرية للعملة. لا تستخدم لو اﻷماكن العشرية تساوى 0.'),
(81710, 6306, 21, 'رمز مستخدم كفاصلة الالاف للعملة.'),
(81711, 6307, 21, 'أعراض'),
(81712, 6308, 21, 'زامن'),
(81713, 6309, 21, 'زامن التراجم مع جدول اللغة المكون حسب الطلب.'),
(81714, 6310, 21, 'زامن الثابت الجديد المكون حسب الطلب:'),
(81715, 6311, 21, 'زامن اللغة المكونة حسب الطلب:'),
(81716, 6312, 21, 'زامن التعريف الجديد (اللغة, الثابت و التعريف):'),
(81717, 6313, 21, 'فقدان الوعي'),
(81718, 6314, 21, 'ترصد المتلازمات'),
(81719, 6315, 21, 'ترصد المتلازمات - الأحداث الغير المبلغ عنها'),
(81720, 6316, 21, 'تقرير ترصد المتلازمات');
INSERT INTO `lang_definitions` VALUES
(81721, 6317, 21, 'التهاب الأغشية المصلية المفصلية, التهاب كيسي'),
(81722, 6318, 21, 'نظام'),
(81723, 6322, 21, 'ت'),
(81724, 6323, 21, 'ثلاث مرات باليوم'),
(81725, 6324, 21, 'تلفاز'),
(81726, 6325, 21, 'جدول'),
(81727, 6327, 21, 'فشل إنشاء جدول'),
(81728, 6328, 21, 'فشل تحديث الجدول'),
(81729, 6330, 21, 'حبة دواء'),
(81730, 6332, 21, 'تاجالو (لغة الفلبين)'),
(81731, 6335, 21, 'يأخد'),
(81732, 6336, 21, 'اختيار التأمين, من القائمة'),
(81733, 6337, 21, 'اختيار طريقة الدفع من القائمة'),
(81734, 6338, 21, 'إسترجاع'),
(81735, 6339, 21, 'يستغرق وقتا'),
(81736, 6340, 21, 'منطقة ملاحة طويلة'),
(81737, 6344, 21, 'تاريخ ميلاد الهدف و المنشأ غير متطابقين'),
(81738, 6345, 21, 'إشتقاق الهدف و المنشأ يجب أن يكونا غير متطابقين'),
(81739, 6346, 21, 'رقم التأمين الأجتماعي للهدف و المنشأ غير متطابقين'),
(81740, 6347, 21, 'الموعد المستهدف'),
(81741, 6348, 21, 'المريض المستهدف'),
(81742, 6349, 21, 'لايوجد تاريخ ميلاد للمريض المستهدف'),
(81743, 6350, 21, 'لم يتم العثور على المريض المستهدف'),
(81744, 6351, 21, 'مجموعات الهدف/الفعل'),
(81745, 6354, 21, 'رقم بطاقة الضرائب'),
(81746, 6355, 21, 'معّدل الضرائب'),
(81747, 6356, 21, 'الضرائب'),
(81748, 6357, 21, 'علم التصنيف'),
(81749, 6358, 21, 'لقاح التيتانس و الدفتيريا'),
(81750, 6359, 21, 'مراجعة إصابة الفريق'),
(81751, 6360, 21, 'لائحة الفريق'),
(81752, 6361, 21, 'عرض لائحة الفريق'),
(81753, 6362, 21, 'فريق/فرقة'),
(81754, 6363, 21, 'تليفون'),
(81755, 6364, 21, 'مفتاح الدولة'),
(81756, 6366, 21, 'الملفات المؤقتة'),
(81757, 6367, 21, 'موضع الملفات المؤقتة'),
(81758, 6368, 21, 'طريقة الملفات المؤقتة'),
(81759, 6369, 21, 'الحرارة'),
(81760, 6370, 21, 'قالب'),
(81761, 6371, 21, 'اسم القالب'),
(81762, 6372, 21, 'اسماء القوالب لايمكن ان تبتدئ بأرقام'),
(81763, 6373, 21, 'قالب:'),
(81764, 6374, 21, 'قوالب'),
(81765, 6375, 21, 'الشريان الصدغي-Tem. Artery'),
(81766, 6376, 21, 'اصابة وتر'),
(81767, 6377, 21, 'التهاب الوتر, osis, التهاب كيسي'),
(81768, 6378, 21, 'رقم الرصيد التجريبي'),
(81769, 6379, 21, 'من الدرجة الثالثة'),
(81770, 6380, 21, 'تأمين من الدرجة الثالثة'),
(81771, 6381, 21, 'بيانات تأمين من الدرجة الثالثة'),
(81772, 6382, 21, 'مقدم تأمين تأمين من الدرجة الثالثة'),
(81773, 6383, 21, 'جدولة الفحص'),
(81774, 6384, 21, 'أختبار النظام'),
(81775, 6385, 21, 'نَصّ'),
(81776, 6386, 21, 'تشخيص نَصّي'),
(81777, 6387, 21, 'حقل نَصّي'),
(81778, 6393, 21, 'تاريخ النَصّ'),
(81779, 6394, 21, 'تاريخ النَصّ'),
(81780, 6395, 21, 'منطقة النَصّ'),
(81781, 6396, 21, 'منطقة النَصّ'),
(81782, 6397, 21, 'صندوق النَصّ'),
(81783, 6398, 21, 'صندوق النَصّ'),
(81784, 6399, 21, 'لائحة صندوق النَصّ'),
(81785, 6400, 21, 'لائحة صندوق النَصّ'),
(81786, 6401, 21, 'تايلندي'),
(81787, 6402, 21, 'شكرا لك'),
(81788, 6403, 21, 'شكرا لك لإختيارك'),
(81789, 6404, 21, 'زر "صَفّى" سوف يزيل كل التذييلات'),
(81790, 6405, 21, 'البيان إعلاة فشل'),
(81791, 6406, 21, 'شهادة الخادم و المفتاح العام ل SSL اﻷباتشى'),
(81792, 6407, 21, 'الشهادة لشهادة السلطة'),
(81793, 6408, 21, 'ملف المطالبة: '),
(81794, 6409, 21, 'لقد تم تثبيت باقة SNOMED الخاصة بالوﻻيات المتحدة المتطابقة المرحلية'),
(81795, 6410, 21, 'المفتاح المتناظر الخاص'),
(81796, 6413, 21, 'رمز الإنكار هو'),
(81797, 6414, 21, 'رمز مجموعة الإنكار هو'),
(81798, 6415, 21, 'طلب محطة الوصول مغلق'),
(81799, 6416, 21, 'طلب محطة الوصول مغلق; لا أستطيع مساعدتك فى هذا الإختيار'),
(81800, 6417, 21, 'الجهة المنفذة للعملية'),
(81801, 6418, 21, 'المستشفى المعتمد او مركز العناية الذي يقوم بإستلام المريض من هيئة اخري عليه القيام بالتالي'),
(81802, 6421, 21, 'المستشفى المعتمد او مركز العناية الذي يقوم بتحويل المريض من هيئة اخري عليه القيام بتزويد تقرير للحالة و العناية المقدّمة'),
(81803, 6422, 21, 'لقد تمت إجازة الحدث'),
(81804, 6423, 21, 'لقد تم إخفاء الحدث'),
(81805, 6424, 21, 'البيانات المصدرة ظاهرة فى منطقة النص أدناة. يمكنك نسخها الي ايميل او أي مكان أخر اذا أحببت'),
(81806, 6426, 21, 'البيانات المصدرة ظاهرة فى منطقة النص أدناة. يمكنك نسخها الي ايميل او أي مكان أخر اذا أحببت'),
(81807, 6427, 21, 'البيانات المصدرة ظاهرة فى منطقة النص أدناة. يمكنك نسخها الي ايميل او أي مكان أخر اذا أحببت'),
(81808, 6428, 21, 'لم نتمكن من حفظ الملف الي CouchDB.'),
(81809, 6429, 21, 'لم نتمكن من تغيير إسم الملف, هذا يرجع الي خطء في قواعد السماح فى نظام التخزين'),
(81810, 6430, 21, 'لم نتمكن من حفظ الملف, هذا يرجع الي خطء في قواعد السماح فى نظام التخزين'),
(81811, 6431, 21, 'مخطط المريض اﻷول ("الهدف") هو الذى يعتبر اﻷكمل و اﻷصح. الديموجرافية, التأمين و التاريخ المرضي سيتم إبقائهم.'),
(81812, 6433, 21, 'الخطوة الأولي هي فتح حساب مع نظام توحيد اللغة الطبية على موقعهم'),
(81813, 6434, 21, 'حدث الرزنامة التالي قد تمت إضافته:'),
(81814, 6435, 21, 'حدث الرزنامة التالي قد تم تعديله:'),
(81815, 6436, 21, 'سيتم إزالي الفئات التالية من قائمة الفئات الخاصة بك'),
(81816, 6437, 21, 'قاعدة البيانات التالية مثيتة حاليا'),
(81817, 6438, 21, 'الوثائق التالية قد تم إرفاقها مع هذة الرسالة المباشرة:'),
(81818, 6439, 21, 'ملف EDI التالي قد تم تحميله'),
(81819, 6440, 21, 'ولوج المستخدم الطارئ قد تم تفعيلة:'),
(81820, 6441, 21, 'الأخطاء التالية وقعت'),
(81821, 6444, 21, 'الحقول التالية مطلوبة'),
(81822, 6446, 21, 'الحقول التالية يجب أن تملأ لإرسال الألتماس'),
(81823, 6447, 21, 'لغات Snomed العالمية التالية مدعومة'),
(81824, 6448, 21, 'المشاكل التالية لها نفس الرموز فلن يتم تجديدها. الرجاء استخدام واجهة الزيارات'),
(81825, 6449, 21, 'إسم المستضيف لجهاز مستودع التحقق ATNA.'),
(81826, 6450, 21, 'النافذة المبدئية مخصصة للبحث عن الإيصالات. فى اﻷعلي يمكنك إدخال منبع (رقم الشيك) المبلغ و تاريخ الدفع.'),
(81827, 6451, 21, 'دليل التثبيت يجب ان يكوّن.'),
(81828, 6452, 21, 'نسخة SNOMED العالمية غير متوافقة مع نسخة الولايات المتحدة'),
(81829, 6453, 21, 'نسخة SNOMED العالمية غير متوافقة مع نسخة الولايات المتحدة و منتهية الصلاحية'),
(81830, 6454, 21, 'النسخة المثبتة و المعروضة هما نفس الشيئ.'),
(81831, 6455, 21, 'النسخة المثبتة أحدث من النسخة المعروضة.'),
(81832, 6456, 21, 'العلامة التي تظهر للمستخدم علي الطلب'),
(81833, 6457, 21, 'الطول يجب الا يتجاوز الرقم التالي من الأحرف'),
(81834, 6458, 21, 'الدمج لن يحدث حتي يتطابق تاريخ الميلاد مع رقم الضمان الإجتماعي. تواريخ الميلاد لا يجب ان تترك خالية'),
(81835, 6459, 21, 'لا يمكن إرسال الرسالة في هذا الوقت.'),
(81836, 6460, 21, 'المجموعة الجديدة ستكون من ضمن المجموعة التالية '),
(81837, 6461, 21, 'كلمة السر الجديدة لا يمكن ان تكون نفس الحالية'),
(81838, 6462, 21, 'حقول كلمة السر ليسو متشابهين'),
(81839, 6463, 21, 'رقم الملفات المعروضة غير صحيح. الرجاء وضع الملف الذي تريد تثبيتة'),
(81840, 6464, 21, 'رقم الملفات المعروضة غير صحيح. الرجاء وضع الملف الذي تريد تثبيتة/ ترقيتة'),
(81841, 6465, 21, 'الصفحة يتوجهك الي الديموجرافيا. بإمكانك تحرير حقل الدولة و تتقدم الي نظام الوصفة الإلكترونية مرة اخري.'),
(81842, 6466, 21, 'كلمة السر يجب الا تقل عن 8 أحرف و يجب ان'),
(81843, 6468, 21, 'تم تسجيل طلبك للحصول علي سجل المريض'),
(81844, 6469, 21, 'لقد تم ظبط تذكيرات المريض'),
(81845, 6470, 21, 'لقد تم تحديث تذكيرات المريض'),
(81846, 6472, 21, 'المدفوعات المعلنة لا يمكن ات تجدول تحت هذا التاريخ لمنع التلاعب فى توايخ سابقة بعد الحصول على التقرير'),
(81847, 6474, 21, 'تزويد البيانات الخام ممكن الحصول عليه من'),
(81848, 6475, 21, 'المعلومات المتبقية أدناة تطبق فقط لو ادخلت يدويا او كنت تصحح يدويا'),
(81849, 6477, 21, 'الوثيقة المطلوبة غير موجودة فى المكان المتوقع فى نظام الملفات او لا تملك صلاحيات لتصفحها'),
(81850, 6479, 21, 'المخطط الثانى ("المنبع") سيكون عديم أقسام ديموجرافيا, التاريخ و التأمين. البيانات الاخري سيتم دمجها فى المخطط الهدف.'),
(81851, 6480, 21, 'أعمدة المنبع و التاريخ منسوخين من الصفحة الأولي فمن الطبيعي عدم التلاعب بهما و لكن يمكنك إضافة المدفوعات'),
(81852, 6481, 21, 'تواريخ إصدار الملفات المعروضة ليست كلها من نفس الإصدار'),
(81853, 6482, 21, 'مراجعات الملفات المعروضة ليست كلها من نفس الإصدار'),
(81854, 6483, 21, 'إصدار SNOMED للولايات المتحدة لا يمكن تثبيته الا بعد تثبيت الاصدار العالمي'),
(81855, 6484, 21, 'توزيعات الوقت فى الروزنامة و اقصر وقت بالدقائق لخانة المواعيد'),
(81856, 6485, 21, 'العلامة المترجمة التي سوف تظهر علي الطلب فى اللغة الحالية'),
(81857, 6486, 21, 'العنوان المترجمة الذي سوف يظهر فى اللغة الحالية'),
(81858, 6487, 21, 'ترجمة الوصف فى اللغة الحالية'),
(81859, 6488, 21, 'تم التزامن بين جداول الترجمة'),
(81860, 6489, 21, 'نوع هذا المكوّن'),
(81861, 6490, 21, 'كود الموزع الخاص ليعرّف هذة العملية او النتيجة'),
(81862, 6491, 21, 'ملفات الX12 و التقارير الناتجة سيتم تخزينها في مجلد ال "era" فى ملفات البرنامج. يمكنك الرجوع اليها بين حين و اخر. العنوان هو:'),
(81863, 6492, 21, 'ملف الضغط سيحتوي على الملفات التالية'),
(81864, 6493, 21, 'مَظهَر'),
(81865, 6494, 21, 'ثم سيكون بالإمكان الحصول علي تغذية البيانات الخام من'),
(81866, 6495, 21, 'حقن علاجية'),
(81867, 6496, 21, 'يوجد'),
(81868, 6497, 21, 'حاليا لا توجد اي وصفات'),
(81869, 6498, 21, 'يوجد أخطاء فى تقديمك و تم توضيحهم أدناة.'),
(81870, 6500, 21, 'لا يوجد مخططات موجودة خارجا.'),
(81871, 6501, 21, 'لا توجد اي إفصاح عن معلومات اهذا المريض'),
(81872, 6502, 21, 'لا توجد اي تقديمات جديدة'),
(81873, 6503, 21, 'لا توجد اي ملاحظات فى ملف هذا المريض'),
(81874, 6504, 21, 'لا توجد اي مدفوعات فى ملف هذا المريض'),
(81875, 6505, 21, 'يوجد خطأ بريدي في الإرسال الي'),
(81876, 6506, 21, 'يوجد حاليا تصنيف بإسم'),
(81877, 6507, 21, 'يوجد حاليا تحت التصنيف بإسم'),
(81878, 6508, 21, 'يوجد حاليا بند بإسم'),
(81879, 6509, 21, 'يوجد حاليا طلب مفتوح لسجل المريض'),
(81880, 6510, 21, 'لا توجد طريقة تعامل مع حساب AR '),
(81881, 6511, 21, 'لا توجد طريقة تعامل مع حساب النقد '),
(81882, 6512, 21, 'لا توجد طريقة تعامل مع حساب الدخل '),
(81883, 6513, 21, 'لا يوجد مريض حالي'),
(81884, 6515, 21, 'لا يوجد مثيل لرقم الرصيد'),
(81885, 6516, 21, 'لا يوجد مثيل لرقم الرصيد = '),
(81886, 6517, 21, 'لا يوجد أجزاء مدخلة لهوية الخدمات '),
(81887, 6519, 21, 'يوجد خطأ في إرسال الرسالة'),
(81888, 6520, 21, 'يوجد خطأ خلال التعامل مع طلبك'),
(81889, 6521, 21, 'يوجد خطأ فى SQL البرنامج فى الخيط التالي'),
(81890, 6522, 21, 'يوجد هناك 2012 رابط'),
(81891, 6523, 21, 'متضخم يمينا:'),
(81892, 6524, 21, 'فخذ'),
(81893, 6525, 21, 'الفخذ و العَضَلاتُ المَأْبِضِيَّة'),
(81894, 6526, 21, 'الأشياء التى يمكن للمكتب الخلفي قراءتها فقط'),
(81895, 6527, 21, 'الأشياء التى يمكن للمكتب الخلفي قراءتها و إدخالها لكن ليس تعديلها'),
(81896, 6528, 21, 'الأشياء التى يمكن للمكتب الخلفي قراءتها و تعديلها'),
(81897, 6529, 21, 'الأشياء التى يمكن للمكتب الخلفي قراءتها و تعديلها جزئيا'),
(81898, 6530, 21, 'الأشياء التى يمكن للممارسين قراءتها فقط'),
(81899, 6531, 21, 'الأشياء التى يمكن للممارسين قراءتها و إدخالها لكن ليس تعديلها'),
(81900, 6532, 21, 'الأشياء التى يمكن للممارسين قراءتها و تعديلها'),
(81901, 6533, 21, 'الأشياء التى يمكن للممارسين قراءتها و تعديلها جزئيا'),
(81902, 6534, 21, 'الأشياء التى يمكن للمكتب الأمامي قراءتها و إدخالها لكن ليس تعديلها'),
(81903, 6535, 21, 'الأشياء التى يمكن للمكتب الأمامي قراءتها و تعديلها'),
(81904, 6536, 21, 'الأشياء التى يمكن للمكتب الأمامي قراءتها و تعديلها جزئيا'),
(81905, 6537, 21, 'الأشياء التى يمكن للمكتب الأمامي قراءتها فقط'),
(81906, 6538, 21, 'الأشياء التى يمكن للأطباء قراءتها فقط'),
(81907, 6539, 21, 'الأشياء التى يمكن للأطباء قراءتها و إدخالها لكن ليس تعديلها'),
(81908, 6540, 21, 'الأشياء التى يمكن للأطباء قراءتها و تعديلها'),
(81909, 6541, 21, 'الأشياء التى يمكن للأطباء قراءتها و تعديلها جزئيا'),
(81910, 6542, 21, 'ثالث'),
(81911, 6544, 21, 'هذا الإجراء لا يمكن التراجع عنه!!!'),
(81912, 6545, 21, 'هذا الإجراء لا يمكن التراجع عنه!!!'),
(81913, 6547, 21, 'هذا الإجراء سيتم تسجيله'),
(81914, 6549, 21, 'حيّز الموعد هذا مستخدم, هل تريد استخدامه علي اي حال؟'),
(81915, 6550, 21, 'حيّز الموعد هذا غير متاح, الرجاء إختيار حيّز اخر.'),
(81916, 6551, 21, 'هذة السنة الشمسية'),
(81917, 6552, 21, 'هذة المطالبة قد تم الغائها'),
(81918, 6553, 21, 'هذة المطالبة قد تم إغلاقها'),
(81919, 6554, 21, 'هذة المطالبة قد تم رفضها. السبب:'),
(81920, 6555, 21, 'هذة المطالبة قد تم تحويلها للمستوي التالي'),
(81921, 6556, 21, 'نوع الرمز هذا لا يقبل العلاقات'),
(81922, 6557, 21, 'هذا السياق يحتوي علي فئات سوف يتم حذفها. هل تريد الإستمرار؟'),
(81923, 6558, 21, 'هذا يحدد طريقة عرض المواعيد على الروزنامة.'),
(81924, 6559, 21, 'هذا يحدد لون المخطط المستخدم للمواعيد'),
(81925, 6561, 21, 'هذة الزيارة'),
(81926, 6562, 21, 'هذة الزيارة قد تمت فوترتها. اذا أردت تغيرها فيجب إعادة فتحها.'),
(81927, 6564, 21, 'هذة الميزة غير متاحة'),
(81928, 6565, 21, 'هذة الميزة تجريبية جدا و غير مكتملة الإختبار. إستخدم علي مسؤوليتك الخاصة!'),
(81929, 6566, 21, 'رقم هذا الإيصال قد تم تغيره الي '),
(81930, 6569, 21, 'هذا هو المخطط الذى سيتم دمجه فى المخطط الرئيس ثم حذفه'),
(81931, 6571, 21, 'هذا هو المخطط الرئيس الذى سيقبل البيانات المدمجة'),
(81932, 6572, 21, 'هذا الموضع'),
(81933, 6575, 21, 'هذة الوحدة البرمجية فى طور التجربة. قاعدة البيانات لن تتغير.'),
(81934, 6576, 21, 'هذة الوحدة البرمجية تشجع علي الإدخال الفعال لبيانات شرح المنافع'),
(81935, 6577, 21, 'هذا الشهر الي اليوم'),
(81936, 6579, 21, 'هذة الصفحة تسمح لك بمراجعة كل من البيانات الخارجية المدعومة التى يمكن تثبيتها و ترقيتها. كل قسم أدناه يمكن توسعته بالضغط علي رأس القسم لرؤية الحالة المتعلقة'),
(81937, 6580, 21, 'هذة الصفحة تم تعطيلها لأسباب أمنية'),
(81938, 6581, 21, 'هذة الصفحة تحتوى علي صفحة الولوج بمحتوياتها و لذلك لا تحتاج الي الضغط علي إعادة الولوج كل مرة'),
(81939, 6582, 21, 'هذا المريض ليس لة نشاط.'),
(81940, 6583, 21, 'رقم هوية هذا المريض قيد الإستخدام!'),
(81941, 6584, 21, 'هذا المنتج يسمح بجملة واحدة فقط لكل مستودع.'),
(81942, 6585, 21, 'هذا البرتوكول غير مطبق'),
(81943, 6586, 21, 'هذا التقرير حاليا يعمل علي رموز ICD9 فقط.'),
(81944, 6591, 21, 'هذة الخطوة ستولد ملفا ينبغى الحفاظ علية لإستخدامة مستقبلا. لا يمكن تكوين الملف مجددا. هل تريد الإستمرار؟'),
(81945, 6592, 21, 'هذا المستخدم ليس عضوا في اي مجموعة'),
(81946, 6593, 21, 'هذا المستخدم سيستلم تتنبيهات بوصول رسائل مباشرة جديدة'),
(81947, 6594, 21, 'هذة الإداة تجريبية. أجر احتياطا لقاعدة البيانات و الوثائق قبل الإستعمال!'),
(81948, 6595, 21, 'هذة الزيارة تبدأ إستعمال جديد لوسيلة منع الحمل'),
(81949, 6596, 21, 'هذة الزيارة تحتاج الي طلب GCAC, تحويل او خدمة العمليات'),
(81950, 6597, 21, 'هذا كان طلب الوظائف الحيوية للنظام المتري فقط و هو مهجور الان'),
(81951, 6598, 21, 'هذا الاسبوع لليوم'),
(81952, 6600, 21, 'هذا سيفعل القرير لاستمرارية سجل الرعاية و استمرارية وثيقة الرعاية'),
(81953, 6602, 21, 'هذا سيسمح بإختيار تصحيح الأخطاء للغة (''dummy'')'),
(81954, 6605, 21, 'هذا سيكون تشغيل تجريبي بدون تجديد فعلي للبيانات'),
(81955, 6606, 21, 'هذا سيكون نسخة إحتياطية علي هيئة تار ليكون بإمكانك إرسالها لمتصفحك و بالتالي حفظها'),
(81956, 6607, 21, 'هذا سيفعّل ميزات التشفير و فك التشفير للوثيقة و إخفائها فى واجهة المستخدام'),
(81957, 6613, 21, 'هذا سيجبر أداة الفوترة فى شاشة ملخص المريض على البقاء مفتوحة دائما'),
(81958, 6616, 21, 'هذا سيدمج تخطيطين لنفس المريض مع بعضهما عندما تحصل أخطاء. لا تكرر إستخدام هذا و أصلح إجراءاتك'),
(81959, 6617, 21, 'هذا لن يمنعك من الذهاب الي موقع الوصف الإلكتروني'),
(81960, 6619, 21, 'هذا سوف يستخدم قائمة التطعيمات المفصلة حسب الطلب'),
(81961, 6622, 21, 'الفقرات الصدرية'),
(81962, 6623, 21, 'الف لكل مم مكعب'),
(81963, 6625, 21, 'حلق'),
(81964, 6626, 21, 'سرطان الحلق'),
(81965, 6627, 21, 'جراحة سرطان الحلق'),
(81966, 6628, 21, 'تخثر/سكتة دماغية'),
(81967, 6629, 21, 'الخميس'),
(81968, 6630, 21, 'الخميس'),
(81969, 6631, 21, 'الخميس'),
(81970, 6632, 21, 'الغدة الدرقية طبيعية'),
(81971, 6633, 21, 'مشاكل الغدة الدرقية'),
(81972, 6634, 21, 'نوبة اقفارية عابرة'),
(81973, 6636, 21, 'ثلاث مرات يوميا'),
(81974, 6638, 21, 'الوقت'),
(81975, 6639, 21, 'طريقة عرض الوقت'),
(81976, 6640, 21, 'مقدار الزيادة فى الوقت (الدقائق 1-60)'),
(81977, 6641, 21, 'إختيار الوقت'),
(81978, 6642, 21, 'حيّز الوقت مفتوح, جارى حفظ الحدث'),
(81979, 6647, 21, 'حدث محدود بوقت'),
(81980, 6648, 21, 'نسق الوقت (غير متوفر)'),
(81981, 6649, 21, 'ختم الوقت و النص'),
(81982, 6650, 21, 'شبكة معلومات الضرائب'),
(81983, 6651, 21, 'طنين'),
(81984, 6652, 21, 'عنوان'),
(81985, 6653, 21, 'عنوان V'),
(81986, 6654, 21, 'عناوين الإعمدة يجب ان تكون ارقاما ما بين 1-999'),
(81987, 6655, 21, 'عناوين'),
(81988, 6656, 21, 'الغِشاءُ الطَّبْلِيّ'),
(81989, 6658, 21, 'إلي'),
(81990, 6659, 21, 'إلي'),
(81991, 6660, 21, 'إلي'),
(81992, 6661, 21, 'إلي الطريق الأوحد للملف'),
(81993, 6662, 21, 'لإضافة ملاحظات, إضغط '),
(81994, 6663, 21, 'لإضافة ملاحظات, إضغط هنا'),
(81995, 6664, 21, 'إلي المنطقة المتأثرة'),
(81996, 6665, 21, 'إلي المنطقة المتأثرة'),
(81997, 6666, 21, 'لفتح الطلب المعين تلقائيا. بعض فرق الرياضة تستخدم football_injury_audit هنا'),
(81998, 6667, 21, 'واجهة الفوترة'),
(81999, 6668, 21, 'الي التصنيف'),
(82000, 6669, 21, 'الي الواجهة الطبية'),
(82001, 6670, 21, 'للدفع المشترك'),
(82002, 6672, 21, 'إلي المستقطعات'),
(82003, 6673, 21, 'إلي المستعرضات'),
(82004, 6674, 21, 'لتعطيل شهادات SSL التابعة للعميل, علّق باﻷسطر العلوية فى ملف تهيئة اﻷباتشى ثم فعّل'),
(82005, 6675, 21, 'لتعطيل شهادات HTTPS, علّق باﻷسطر العلوية فى ملف تهيئة اﻷباتشى ثم أعد تشغيل الخادم'),
(82006, 6676, 21, 'لتفعيل شهادات SSL التابعة للعميل'),
(82007, 6677, 21, 'لتفعيل التأكد من شهادات SSL التابعة للعميل , HTTPS يجب أن يكون مفعّلا'),
(82008, 6678, 21, 'لتفعيل HTTPS فقط , اجر التعديلات العلوية ثم أعد تشغيل خادم اﻷباتشى'),
(82009, 6679, 21, 'إلي الزيارة'),
(82010, 6680, 21, 'للفرز بالجنس'),
(82011, 6681, 21, 'الى التاريخ المرضي'),
(82012, 6682, 21, 'الي المشاكل'),
(82013, 6683, 21, 'لربط هذة الزيارة/الإستشارة لمشكلة قائمة, إضغط ال '),
(82014, 6684, 21, 'لربط هذة الزيارة/الإستشارة لمشكلة قائمة, إضغط المشكلة المعنية أعلاة ثم إضعط [حفظ]. لإختار عدة مشاكل أبق زر [Ctrl] مضغوطا خلال الإختيار'),
(82015, 6685, 21, 'لإعادة الولوج'),
(82016, 6686, 21, 'لتسجيل إفشاء المعلومات: اضغط هنا'),
(82017, 6687, 21, 'للتشغيل'),
(82018, 6688, 21, 'لتثبيت المدخل ل https مع التأكد من الشهادة التابعة للعميل, افعل التالي'),
(82019, 6689, 21, 'للسلخ'),
(82020, 6690, 21, 'للسلخ'),
(82021, 6691, 21, 'لهذة الزيارة؟'),
(82022, 6693, 21, 'إلي:'),
(82023, 6694, 21, 'إلي: '),
(82024, 6695, 21, 'إلي_المدينة'),
(82025, 6696, 21, 'إلي_الفاكس'),
(82026, 6697, 21, 'إلي_الأسم اﻷول'),
(82027, 6698, 21, 'إلي_الأسم اﻷخير'),
(82028, 6699, 21, 'إلي_الأسم اﻷوسط'),
(82029, 6700, 21, 'إلي_المنظمة'),
(82030, 6703, 21, 'إلي_العنوان البريدي'),
(82031, 6704, 21, 'إلي_الولاية'),
(82032, 6705, 21, 'إلي_الشارع'),
(82033, 6706, 21, 'إلي_العنوان'),
(82034, 6707, 21, 'إلي_التوديعى'),
(82035, 6708, 21, 'تبغ'),
(82036, 6709, 21, 'تدّخل االتوقف عن التبغ'),
(82037, 6710, 21, 'تدّخل االتوقف عن التبغ (CQM)'),
(82038, 6712, 21, 'إستعمال التبغ'),
(82039, 6713, 21, 'تقييم إستعمال التبغ'),
(82040, 6714, 21, 'تقييم إستعمال التبغ (CQM)'),
(82041, 6715, 21, 'اليوم الحالي'),
(82042, 6716, 21, 'اليوم الحالي'),
(82043, 6717, 21, 'اليوم الحالي'),
(82044, 6718, 21, 'خالص الحساب لليوم'),
(82045, 6719, 21, 'مديونّيات الدوم'),
(82046, 6720, 21, 'تاريخ اليوم'),
(82047, 6721, 21, 'أحداث اليوم'),
(82048, 6723, 21, 'رقم الهوية الرمزي لإدماج المعلومات الطبية, خدمة تبادل المعمل'),
(82049, 6724, 21, 'رقم الهوية الرمزي لدعم البرنامج,, خدمة تبادل المعمل'),
(82050, 6726, 21, 'عملية إستئصال الوزتين'),
(82051, 6728, 21, 'الأعلى'),
(82052, 6730, 21, 'الموضوع'),
(82053, 6731, 21, 'المجموع'),
(82054, 6732, 21, 'المجموع'),
(82055, 6733, 21, 'مجموع الأحداث النشطة'),
(82056, 6734, 21, 'مجموع التذكيرات النشطة بعد التحديث'),
(82057, 6735, 21, 'مجموع التذكيرات النشطة قبل التحديث'),
(82058, 6737, 21, 'مجموع المبلغ المستحق'),
(82059, 6738, 21, 'مجموع المبلغ المدفوع'),
(82060, 6739, 21, 'إجمالي الرصيد المستحق'),
(82061, 6740, 21, 'إجمالي التكلفة'),
(82062, 6741, 21, 'إجمالي التكاليف'),
(82063, 6742, 21, 'مجموع العملاء'),
(82064, 6743, 21, 'التكلفة الإجمالية'),
(82065, 6744, 21, 'التوزيع الكامل لرقم الشيك التالي غير مكتمل'),
(82066, 6745, 21, 'مجموع المدخلات'),
(82067, 6746, 21, 'إجمالي التذكيرات فشل إرسالها عبر البريد الإلكتروني'),
(82068, 6747, 21, 'إجمالي التذكيرات فشل إرسالها عبر الهاتف'),
(82069, 6748, 21, 'المجموع لل'),
(82070, 6749, 21, 'المجموع لل '),
(82071, 6750, 21, 'إجمالي التصنيف'),
(82072, 6751, 21, 'مجموع التذكيرات المعطلة'),
(82073, 6752, 21, 'مجموع التذكيرات الجديدة'),
(82074, 6753, 21, 'إجمالي عدد المواعيد'),
(82075, 6755, 21, 'إجمالي عدد التطعيمات'),
(82076, 6756, 21, 'مجموع عدد المشاكل'),
(82077, 6758, 21, 'إجمالي عدد المرضى'),
(82078, 6760, 21, 'مجموع رصيد المريض'),
(82079, 6761, 21, 'مجموع المرضى'),
(82080, 6764, 21, 'مجموع السجلات الموجودة'),
(82081, 6765, 21, 'مجمل الصحة الجنسية و التناسلية و الخطيط العائلي'),
(82082, 6766, 21, 'مجموع التذكيرات المرسلة بنجاح عبر البريد الإلكتروني'),
(82083, 6767, 21, 'مجموع التذكيرات المرسلة بنجاح عبر الهاتف'),
(82084, 6770, 21, 'مجموع التذكيرات دون تغيير'),
(82085, 6771, 21, 'مجموع التذكيرات الغير مرسلة بعد عملية الإرسال'),
(82086, 6772, 21, 'مجموع التذكيرات الغير مرسلة بعد التحديث'),
(82087, 6773, 21, 'مجموع التذكيرات الغير مرسلة قبل عملية الإرسال'),
(82088, 6774, 21, 'مجموع التذكيرات الغير مرسلة قبل التحديث'),
(82089, 6775, 21, 'مجموع التذكيرات المحدثة'),
(82090, 6776, 21, 'المجاميع'),
(82091, 6777, 21, 'مجاميع لـ'),
(82092, 6778, 21, 'مجاميع لـ '),
(82093, 6780, 21, 'to{{range}}'),
(82094, 6785, 21, 'نوع التدريب'),
(82095, 6786, 21, 'أجر معاملة'),
(82096, 6787, 21, 'معاملة'),
(82097, 6788, 21, 'معاملة'),
(82098, 6789, 21, 'فشل المعاملة, الكمية المطلوبة غير كافية لتنفيذ العملية'),
(82099, 6790, 21, 'فشل المعاملة, الكمية المطلوبة اقل من صفر'),
(82100, 6791, 21, 'نوع المعاملة'),
(82101, 6792, 21, 'معاملات'),
(82102, 6793, 21, 'معاملات'),
(82103, 6794, 21, 'معاملات (الكتابة إختيارية)'),
(82104, 6795, 21, 'المعاملات/الإحالات'),
(82105, 6797, 21, 'تحويل'),
(82106, 6798, 21, 'تاريخ التحويل'),
(82107, 6799, 21, 'فشل التحويل,كمية غير كافية لتنفيذ العملية'),
(82108, 6800, 21, 'ملخص التحويل'),
(82109, 6801, 21, 'تحويل الى'),
(82110, 6804, 21, 'تحويلات'),
(82111, 6806, 21, 'تحويل-تحويل الرعاية؟'),
(82112, 6807, 21, 'ترجم مجموعات التحكم'),
(82113, 6808, 21, 'ترجم تصنيفات المواعيد'),
(82114, 6809, 21, 'ترجم تصنيفات الوثيقة'),
(82115, 6810, 21, 'ترجم الواجهات'),
(82116, 6811, 21, 'ترجم القوائم'),
(82117, 6812, 21, 'ترجم عناوين ملاحظات المريض'),
(82118, 6813, 21, 'ترجم هذا'),
(82119, 6814, 21, 'الترجمة'),
(82120, 6815, 21, 'تراجم'),
(82121, 6816, 21, 'نقل'),
(82122, 6817, 21, 'فشل النقل'),
(82123, 6818, 21, 'نقل الطلبات المُختارة'),
(82124, 6819, 21, 'رَضّ'),
(82125, 6820, 21, 'معالجة'),
(82126, 6822, 21, 'اهداف المعالجة'),
(82127, 6823, 21, 'خطة المعالجة'),
(82128, 6824, 21, 'خُطَّةُ المُعَالَجَة‎'),
(82129, 6825, 21, 'تم تلقي المعالجة'),
(82130, 6826, 21, 'المعالجة:'),
(82131, 6827, 21, 'المعالجة: '),
(82132, 6828, 21, 'موضة'),
(82133, 6829, 21, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) ); $month_value'),
(82134, 6830, 21, 'نقطة الزناد / مُتَلاَزِمَةُ الحَيِّزِ الأَمامِيّ / الم العضلة المتأخّر / تشنّج'),
(82135, 6831, 21, 'كَسْرٌ كَعْبِيٌّ ثُلاَثِيّ‎'),
(82136, 6832, 21, 'جِذْع‎ و بطن'),
(82137, 6835, 21, 'إنك تحاول تكوين مستخدم بإسم موجود أصلا!'),
(82138, 6837, 21, 'ملعقة-وحدة قياس'),
(82139, 6839, 21, 'جمعية نقل الأعضاء'),
(82140, 6840, 21, 'مرض السل'),
(82141, 6841, 21, 'الثلاثاء'),
(82142, 6842, 21, 'Tues &amp; Thur'),
(82143, 6843, 21, 'الثلاثاء'),
(82144, 6844, 21, 'ورم خبيث'),
(82145, 6845, 21, 'تركي'),
(82146, 6848, 21, 'مرتين باليوم'),
(82147, 6850, 21, 'طبلة الاذن'),
(82148, 6851, 21, 'نوع'),
(82149, 6852, 21, 'نوع رقم الهوية او اﻷسم. 3 أحرف علي اﻷقل (بما فيها المسافة)'),
(82150, 6853, 21, 'نوع اﻷعمدة المعروضة لكل نتائج بحث المريض'),
(82151, 6854, 21, 'نوع الإفشاء'),
(82152, 6855, 21, 'نوع الحدث'),
(82153, 6856, 21, 'نوعية تصميم الشاشة'),
(82154, 6857, 21, 'اكتب او امسح ضوئيا معرّف المريض هنا'),
(82155, 6858, 21, 'اكتب رسالتك هنا'),
(82156, 6859, 21, 'أنواع الأوامر و النتائج'),
(82157, 6864, 21, 'رموز جامعة كالجري, مركز الطب الرياضي'),
(82158, 6865, 21, 'اوكراني'),
(82159, 6866, 21, 'تقرحات'),
(82160, 6867, 21, 'التهاب القولون المتقرح'),
(82161, 6868, 21, 'قرح:'),
(82162, 6871, 21, 'غير قادر علي الإنشاء'),
(82163, 6874, 21, 'غير قادر علي مطابقة هذةالدفعة في ar_activity'),
(82164, 6876, 21, 'غير مطبق'),
(82165, 6877, 21, 'غير محدد'),
(82166, 6878, 21, 'غير مسموح له'),
(82167, 6879, 21, 'غير مسموح له بالدخول علي الوصفة الإلكترونية'),
(82168, 6880, 21, 'غير مسموح له بالدخول'),
(82169, 6881, 21, 'غير مفوتر'),
(82170, 6882, 21, 'غير مفوتر فقط'),
(82171, 6884, 21, 'تحت اللسان'),
(82172, 6885, 21, 'تحت مستوى الوزن الطبيعي'),
(82173, 6886, 21, 'غير مشخص'),
(82174, 6887, 21, 'غير موزع'),
(82175, 6888, 21, 'غير موزع'),
(82176, 6889, 21, 'غير موزع'),
(82177, 6890, 21, 'الغاء التسريح'),
(82178, 6892, 21, 'عملاء مميزين'),
(82179, 6893, 21, 'علامة مميزة لتقرأ بالعين لهذا النوع'),
(82180, 6894, 21, 'عملاء مميزين جدد'),
(82181, 6895, 21, 'علامة رقمية مميزة لهذا النوع'),
(82182, 6896, 21, 'مرضي مميزين تمت رؤيتهم'),
(82183, 6897, 21, 'تقرير لمرضي مميزين تمت رؤيتهم'),
(82184, 6898, 21, 'مريض وهمي مميز'),
(82185, 6899, 21, 'وحدة'),
(82186, 6900, 21, 'وحدات'),
(82187, 6901, 21, 'وحدات'),
(82188, 6902, 21, 'الوحدات قابلة للتطبيق علي وحدة الناتج'),
(82189, 6903, 21, 'وحدات لطلبات الزيارة'),
(82190, 6904, 21, 'الوحدات يجب ان تكون ارقاماَ'),
(82191, 6905, 21, 'الوحدات غير معرفة'),
(82192, 6906, 21, 'وحدات لكل ليتر'),
(82193, 6907, 21, 'غير معروف'),
(82194, 6910, 21, 'غير معروف اذا دخن من قبل'),
(82195, 6911, 21, 'غير معروف او غير قابل للتطبيق'),
(82196, 6912, 21, 'هوية مستخدم غير معروف:'),
(82197, 6913, 21, 'مريض غير مرتبط'),
(82198, 6914, 21, 'شركة تأمين غير مسماه'),
(82199, 6915, 21, 'غير مسجل'),
(82200, 6918, 21, 'عدم إختيار الكل'),
(82201, 6919, 21, 'غير مختار'),
(82202, 6920, 21, 'غير محدد'),
(82203, 6921, 21, 'غير مبني'),
(82204, 6922, 21, 'ملف تحميل غير مدعوم لقاعدة البيانات'),
(82205, 6924, 21, 'حتي'),
(82206, 6925, 21, 'مطالبة تأمينية متأخرة'),
(82207, 6926, 21, 'غير مستخدم'),
(82208, 6927, 21, 'متطلبات عماليتية طارئة'),
(82209, 6928, 21, 'حتي الي'),
(82210, 6929, 21, 'المواعيد المستقبلية'),
(82211, 6930, 21, 'الأحداث المستقبلية'),
(82212, 6931, 21, 'تحديث'),
(82213, 6932, 21, 'تحديث'),
(82214, 6933, 21, 'التحديث نشط'),
(82215, 6934, 21, 'ملفات التحديث'),
(82216, 6935, 21, 'معلومات التحديث'),
(82217, 6936, 21, 'قائمة التحديث'),
(82218, 6937, 21, 'رقم مقدم التحديث'),
(82219, 6938, 21, 'حدث البنود المختارة'),
(82220, 6939, 21, 'حدث المتغيرات التالية بالملف'),
(82221, 6940, 21, 'حدث معلومات المستخدم'),
(82222, 6942, 21, 'جاري تحديث الديموجرافيا غير مصرح به'),
(82223, 6943, 21, 'جاري تحديث التهيئة الإفتراضية للكل'),
(82224, 6944, 21, 'جاري تحديث مدلولات النسخة'),
(82225, 6945, 21, 'ترقية'),
(82226, 6946, 21, 'ترقية'),
(82227, 6947, 21, 'ترقية قاعدة البيانات'),
(82228, 6948, 21, 'ترقية قاعدة البيانات لتشمل العمليات، الوظائف و الجداول اللازمة لعملية اخفاء الهوية'),
(82229, 6949, 21, 'الترقية ستستمر'),
(82230, 6950, 21, 'الرقم الفريد لتعريف الطبيب'),
(82231, 6951, 21, 'ترفيع'),
(82232, 6954, 21, 'ترفيع ملف التهيئة'),
(82233, 6955, 21, 'ترفيع الوثيقة'),
(82234, 6956, 21, 'فشل الترفيع!'),
(82235, 6957, 21, 'ترفيع الصورة الي'),
(82236, 6958, 21, 'ترفيع الملف المستورد:'),
(82237, 6960, 21, 'تمت عملية الرفع بنجاح'),
(82238, 6961, 21, 'ترفيع التقرير'),
(82239, 6963, 21, 'ارفع هذا الملف:'),
(82240, 6964, 21, 'عند ضغط رقم الإيصال "نافذة الإدخال اليدوي" سوف تفتح. هنا يمكنك تغيير تاريخ الإستحقاق و الجةه المعنية. كما يمكنك تغيير الكمية المدفوعه لكل رمز'),
(82241, 6965, 21, 'عند البحث سوف تظهر لك قاءمة الإيصالات. يمكنك إختيار اي منها بالضغط عليها لتفتح نافذة الإدخال اليدوي'),
(82242, 6966, 21, 'اليد العليا'),
(82243, 6968, 21, 'طارئ'),
(82244, 6970, 21, 'بول'),
(82245, 6971, 21, 'التقاطر البولي'),
(82246, 6972, 21, 'تواتر البول'),
(82247, 6973, 21, 'التردد البولي'),
(82248, 6974, 21, 'زلال البول'),
(82249, 6975, 21, 'تدفق البول'),
(82250, 6976, 21, 'طارئ البول'),
(82251, 6977, 21, 'عنوان الانترنت'),
(82252, 6979, 21, 'عنوان الانترنت لدعم البرنامج'),
(82253, 6981, 21, 'عنوان الانترنت لبوابة الهاتف. http://signup.maviq.com'),
(82254, 6985, 21, 'الإستخدام'),
(82255, 6986, 21, 'مؤشر الإستخدام (ISA15)'),
(82256, 6987, 21, 'إستخدم رمز % بمفرها داخل الحقل لترتيب هذا العمود فقط'),
(82257, 6988, 21, 'إستخدام هيئة ال 24 ساعة؟'),
(82258, 6990, 21, 'إستخدم تكنولوجيا معتمدة لبرامج ادارة المستشفيات للتعرف علي مصادر التثقيف الخاصة بالمريض'),
(82259, 6991, 21, 'إستخدم لائحة النفقات'),
(82260, 6992, 21, 'إستخدم CPOE لإدخال الأوامر الطبيه بواسطة الطبيب المرخص له من الهيئات و النقابات'),
(82261, 6997, 21, 'إستخدم قائمة تطعيم مفصلة'),
(82262, 6999, 21, 'إستخدم مجال الأيام'),
(82263, 7000, 21, 'إستخدم الإفتراضي'),
(82264, 7001, 21, 'إستخدم إختيار الإلغاء للمسح'),
(82265, 7002, 21, 'إستخدم تصميم الأيام العالمي؟'),
(82266, 7003, 21, 'إستخدم إسم الملف الأصلي'),
(82267, 7004, 21, 'إستخدم الحقول ادناه للشراء او للنقل'),
(82268, 7005, 21, 'إستخدم هذه الميزة مع المواقع الجديدة فقط '),
(82269, 7006, 21, 'إستخدم المواضيع؟'),
(82270, 7007, 21, 'مستخدم'),
(82271, 7009, 21, 'مستخدم / مجموعة'),
(82272, 7010, 21, 'إدارة المستخدمين'),
(82273, 7011, 21, 'إدارة المستخدمين و المنشأت'),
(82274, 7012, 21, 'إدارة المستخدمين و المجموعات'),
(82275, 7014, 21, 'التأكد من توثيق شهادة المستخد معطل'),
(82276, 7015, 21, 'محدد من قبل المستخدم'),
(82277, 7016, 21, 'المنطقة 11 المحددة من قبل المستخدم'),
(82278, 7017, 21, 'المنطقة 12 المحددة من قبل المستخدم'),
(82279, 7018, 21, 'حقل محدد من قبل المستخدم'),
(82280, 7019, 21, 'قائمة 1 محددة من قبل المستخدم'),
(82281, 7020, 21, 'قائمة 2 محددة من قبل المستخدم'),
(82282, 7021, 21, 'قائمة 3 محددة من قبل المستخدم'),
(82283, 7022, 21, 'قائمة 4 محددة من قبل المستخدم'),
(82284, 7023, 21, 'قائمة 5 محددة من قبل المستخدم'),
(82285, 7024, 21, 'قائمة 6 محددة من قبل المستخدم'),
(82286, 7025, 21, 'قائمة 7 محددة من قبل المستخدم'),
(82287, 7026, 21, 'نص 1 محدد من قبل المستخدم'),
(82288, 7027, 21, 'نص 2 محدد من قبل المستخدم'),
(82289, 7028, 21, 'نص 3 محدد من قبل المستخدم'),
(82290, 7029, 21, 'نص 4 محدد من قبل المستخدم'),
(82291, 7030, 21, 'نص 5 محدد من قبل المستخدم'),
(82292, 7031, 21, 'نص 6 محدد من قبل المستخدم'),
(82293, 7032, 21, 'نص 7 محدد من قبل المستخدم'),
(82294, 7033, 21, 'نص 8 محدد من قبل المستخدم'),
(82295, 7034, 21, 'إسم المستخدم الأول'),
(82296, 7037, 21, 'ولوج المستخدم (لو اكثر من 03, او اترك مسافات) (ISA02)'),
(82297, 7038, 21, 'مؤشر مطلوب لولوج المستخدم ( إستخدم 00 او 03 ~ISA01)'),
(82298, 7039, 21, 'دليل المستخدم'),
(82299, 7040, 21, 'عضويات المستخدم'),
(82300, 7041, 21, 'إسم المستخدم'),
(82301, 7042, 21, 'إسم المستخدم او اسم المضيف لا يمكن ان يترك فارغاَ'),
(82302, 7043, 21, 'إسم المستخدم او اسم المضيف'),
(82303, 7044, 21, 'كلمة سر المستخدم (لو 01 أعلي, او اترك مسافات ~ ISA04)'),
(82304, 7045, 21, 'مؤشر مطلوب لكلمة سر المستخدم ( إستخدم 00 او 01 ~ISA03)'),
(82305, 7046, 21, 'ضبط خيارات المستخدم'),
(82306, 7047, 21, 'خيارات المستخدم المحددة'),
(82307, 7048, 21, 'كلمة سر المستخدمين الجديدة'),
(82308, 7049, 21, 'إسم المستخدم'),
(82309, 7051, 21, 'إسم المستخدم لبوابة الهاتف. http://signup.maviq.com'),
(82310, 7052, 21, 'إسم المستخدم للرسائل النصية القصيرة'),
(82311, 7053, 21, 'إسم المستخدم للرسائل النصية القصيرة.'),
(82312, 7054, 21, 'إسم المستخدم للإتصال ب CouchDB'),
(82313, 7055, 21, 'إسم المستخدم:'),
(82314, 7056, 21, 'المستخدمين'),
(82315, 7057, 21, 'المستخدمين/المجموعات/تسجيلات الإدارة'),
(82316, 7058, 21, 'uses php <a href="http://php.net/strftime">strftime</a> format'),
(82317, 7059, 21, 'التهابات المجري البولي'),
(82318, 7062, 21, 'إجازة'),
(82319, 7063, 21, 'إجازة'),
(82320, 7064, 21, 'تطعيم'),
(82321, 7065, 21, 'حلقة مهبلية'),
(82322, 7066, 21, 'وداعي'),
(82323, 7067, 21, 'تأكد من صحة'),
(82324, 7068, 21, 'قيمة'),
(82325, 7069, 21, 'قيمة 1'),
(82326, 7070, 21, 'قيمة 2'),
(82327, 7072, 21, 'القيمة يجب أن تكون عددية'),
(82328, 7073, 21, 'المتغّير 1'),
(82329, 7074, 21, 'المتغّير 2'),
(82330, 7075, 21, 'متغّير الي واحد لتشغيل كود برمجة الترقية لمحو الهوية'),
(82331, 7076, 21, 'جدري الماء 1'),
(82332, 7077, 21, 'جدري الماء 2'),
(82333, 7078, 21, 'توسع الأوردة / الدوالي الوريدية'),
(82334, 7079, 21, 'حالة الأوعية الدموية'),
(82335, 7080, 21, 'إصابة الأوعية الدموية'),
(82336, 7081, 21, 'جراحة الأوعية الدموية'),
(82337, 7083, 21, 'مزود'),
(82338, 7084, 21, 'إصدار'),
(82339, 7085, 21, 'دوار'),
(82340, 7086, 21, 'ادارة المحاربين القدامى'),
(82341, 7087, 21, 'خطة ادارة المحاربين القدامى'),
(82342, 7088, 21, 'لقاحات للأطفال'),
(82343, 7089, 21, 'فيتنامي'),
(82344, 7090, 21, 'عرض'),
(82345, 7091, 21, 'عرض'),
(82346, 7092, 21, 'عرض أمراض الحساسية'),
(82347, 7093, 21, 'عرض ملف x12-835 ERA'),
(82348, 7094, 21, 'عرض جملة المطالبات x12 النصي'),
(82349, 7097, 21, 'عرض تقرير المريض الشامل'),
(82350, 7098, 21, 'عرض جداول CSV'),
(82351, 7100, 21, 'عرض المستند'),
(82352, 7101, 21, 'عرض المراجعة'),
(82353, 7102, 21, 'عرض نص ERA x12'),
(82354, 7103, 21, 'عرض الأحداث في نافذة منبثقة؟'),
(82355, 7104, 21, 'اعرض معلومات مستخدم منشأة مخصوص'),
(82356, 7106, 21, 'عرض ملف X12 الداخلي'),
(82357, 7107, 21, 'عرض السجل'),
(82358, 7108, 21, 'عرض الصفحة ١'),
(82359, 7109, 21, 'عرض الصفحة ٢'),
(82360, 7110, 21, 'عرض رسائل التذكير الماضية والمستقبلية'),
(82361, 7111, 21, 'عرض المريض'),
(82362, 7116, 21, 'عرض المراجعات ذات العلاقة'),
(82363, 7117, 21, 'عرض التقرير'),
(82364, 7118, 21, 'عرض الملف التمهيدي'),
(82365, 7121, 21, 'عرض / تعديل أمراض الحساسية'),
(82366, 7122, 21, 'عرض / تعديل المشكلة'),
(82367, 7123, 21, 'عرض / طباعة'),
(82368, 7124, 21, 'عرض:'),
(82369, 7125, 21, 'بطاقة فيزا التأمينية'),
(82370, 7126, 21, 'البطاقات التأمينية: فيزا/ماستر كارد/اميركان اكسبرس/ديسكفري'),
(82371, 7127, 21, 'الأحشاء: ضرر/إِصَابَة/جراحة'),
(82372, 7133, 21, 'تصنيف الزيارة'),
(82373, 7134, 21, 'تاريخ الزيارة'),
(82374, 7135, 21, 'تاريخ الزيارة'),
(82375, 7137, 21, 'استمارات الزيارة'),
(82376, 7138, 21, 'تاريخ الزيارة'),
(82377, 7140, 21, 'الزيارات'),
(82378, 7141, 21, 'استمارة الزيارة'),
(82379, 7142, 21, 'العلامات الحيوية'),
(82380, 7143, 21, 'العلامات الحيوية'),
(82381, 7144, 21, 'العلامات الحيوية (النظام المتري)'),
(82382, 7145, 21, 'خيارات استمارة العلامات الحيوية'),
(82383, 7146, 21, 'الصوت'),
(82384, 7147, 21, 'تم إرسال الصوت'),
(82385, 7149, 21, 'التقيؤ'),
(82386, 7151, 21, 'و'),
(82387, 7152, 21, 'محيط الخصر'),
(82388, 7153, 21, 'محيط الخصر'),
(82389, 7154, 21, 'في الانتظار'),
(82390, 7155, 21, 'مراجع بدون موعد'),
(82391, 7157, 21, 'والت بنينجتون'),
(82392, 7158, 21, 'المستودعات'),
(82393, 7159, 21, 'المستودع الحد الأعلى, ٠ إذا كان غير قابل للتطبيق'),
(82394, 7160, 21, 'المستودع الحد الأدنى, ٠ إذا كان غير قابل للتطبيق'),
(82395, 7161, 21, 'المستودعات'),
(82396, 7162, 21, 'دافئ'),
(82397, 7163, 21, 'التحذير'),
(82398, 7164, 21, 'التحذير'),
(82399, 7166, 21, 'تحذير: الرقم موجود سابقاً'),
(82400, 7167, 21, 'تحذير: المريض لديه رموز غامضة في قائمة المشاكل!'),
(82401, 7168, 21, 'تحذير: تم انشاء زيارة لهذا المريض اليوم!'),
(82402, 7169, 21, 'تحذير: إذا كنت تستخدم 2012-10-31 النسخة الاسبانية، لاحظ أنك تحتاج إلى فك الضغط لمرة واحدة قبل وضعه في contrib / SNOMED (هذا لأن الملف المصدر كان  " مضغوط مرتين ").'),
(82403, 7170, 21, 'تحذير: هوية المريض غير مخصصة'),
(82404, 7171, 21, 'تحذير'),
(82405, 7173, 21, 'تحذيرات'),
(82406, 7175, 21, 'تم التحميل تلقائيا'),
(82407, 7176, 21, 'لا يوجد'),
(82408, 7177, 21, 'نُقدر لكم الدفع الفوري للديون المستحقة'),
(82409, 7178, 21, 'رأينا مريضكم المذكور أعلاه لتلقي الكشف والعلاج في عيادة الطب النفسي عياداتنا الخارجية. شكرا لكم على هذه الإحالة.'),
(82410, 7179, 21, 'الضعف'),
(82411, 7181, 21, 'بحث عن طريق الويب'),
(82412, 7182, 21, 'موقع'),
(82413, 7183, 21, 'وصلة الأنترنت لبوابة المريض على الموقع'),
(82414, 7184, 21, 'الأربعاء'),
(82415, 7185, 21, 'الأربعاء'),
(82416, 7186, 21, 'أسبوع'),
(82417, 7187, 21, 'أسبوع'),
(82418, 7188, 21, 'حسب الإسبوع'),
(82419, 7189, 21, 'الإسبوع'),
(82420, 7190, 21, 'التعرض الإسبوعي'),
(82421, 7191, 21, 'أسابيع'),
(82422, 7192, 21, 'أسابيع'),
(82423, 7193, 21, 'الوزن'),
(82424, 7194, 21, 'تقييم الوزن لدى الأطفال و المراهقين'),
(82425, 7195, 21, 'تقييم الوزن لدى الأطفال و المراهقين'),
(82426, 7196, 21, 'تغير الوزن'),
(82427, 7197, 21, 'خسارة الوزن'),
(82428, 7198, 21, 'عيادة خسارة الوزن'),
(82429, 7199, 21, 'أهلاً وسهلاً'),
(82430, 7202, 21, 'ما هو الشيئ الذى تريد عده؟'),
(82431, 7203, 21, 'الوزيز:'),
(82432, 7204, 21, 'الوزيز'),
(82433, 7205, 21, 'الوزيز:'),
(82434, 7208, 21, 'أين يمكن إيجاد الأوراق المنسوخة؟'),
(82435, 7209, 21, 'هل من تأمين؟'),
(82436, 7211, 21, 'أذية العنق'),
(82437, 7212, 21, 'أبيض'),
(82438, 7213, 21, 'من'),
(82439, 7214, 21, 'من قام بالرد؟'),
(82440, 7215, 21, 'أرملة'),
(82441, 7216, 21, 'العرض'),
(82442, 7217, 21, 'العرض بالبكسل لإطار الإبحار الأيسر.'),
(82443, 7221, 21, 'مع المختار:'),
(82444, 7222, 21, 'مع الاسم القديم'),
(82445, 7224, 21, 'مع أي شخص تريد ترك رسالة ؟');
INSERT INTO `lang_definitions` VALUES
(82446, 7225, 21, 'مُعلق!'),
(82447, 7226, 21, 'خلال ساعات'),
(82448, 7227, 21, 'خلال ساعات'),
(82449, 7228, 21, 'خلال دقائق'),
(82450, 7229, 21, 'خلال دقائق'),
(82451, 7230, 21, 'بدون منشأة'),
(82452, 7231, 21, 'بدون مزود'),
(82453, 7232, 21, 'من غير تحديث'),
(82454, 7233, 21, 'شاهد'),
(82455, 7234, 21, 'إسبوع'),
(82456, 7235, 21, 'ضمن الحدود الطبيعية'),
(82457, 7237, 21, 'نساء'),
(82458, 7238, 21, 'نساء فقط'),
(82459, 7240, 21, 'عمل'),
(82460, 7241, 21, 'ملاحظة عمل'),
(82461, 7242, 21, 'رقم العمل'),
(82462, 7243, 21, 'رقم العمل'),
(82463, 7244, 21, 'متعلق بالعمل؟'),
(82464, 7245, 21, 'العمل/التعليم /الهوايات'),
(82465, 7246, 21, 'إشْعار للعمل/المدرسة'),
(82466, 7247, 21, 'يوم عمل'),
(82467, 7248, 21, 'تعويض العامل'),
(82468, 7249, 21, 'خطة صحية لعويض العمال'),
(82469, 7250, 21, 'مستفيد في سن العمل او زوجة لموظف بخطة صحية جماعية'),
(82470, 7251, 21, 'جاري العمل...قد يأخذ هذا وقتا'),
(82471, 7252, 21, 'أسوأ'),
(82472, 7253, 21, 'هل تريد ان تطبق متبقى المبلغ للحساب العالمي؟'),
(82473, 7254, 21, 'هل تريد ان تصنفهم كخالص؟'),
(82474, 7255, 21, 'هل تريد التخصيص ؟'),
(82475, 7256, 21, 'هل تريد مسح التوزيع لهذا المريض ؟'),
(82476, 7257, 21, 'هل تريد مسح توزيع الدفع ؟'),
(82477, 7258, 21, 'هل تريد مسح الدفع ؟'),
(82478, 7259, 21, 'هل تريد ارسال وإنهاء الدفع؟'),
(82479, 7260, 21, 'هل تريد تعديل الدفع؟'),
(82480, 7261, 21, 'هل تريد ارسال وإنهاء الدفع؟'),
(82481, 7262, 21, 'هل تريد ارسال دفعة ؟'),
(82482, 7263, 21, 'هل تريد الحفظ؟'),
(82483, 7264, 21, 'الرسغ'),
(82484, 7265, 21, 'الرسغ و اليد'),
(82485, 7266, 21, 'مشاكل الرسغ'),
(82486, 7267, 21, 'اكتب'),
(82487, 7268, 21, 'امسح'),
(82488, 7271, 21, 'وزن'),
(82489, 7273, 21, 'x ملغي'),
(82490, 7274, 21, 'x ملغي'),
(82491, 7275, 21, 'الاشعة السينية'),
(82492, 7276, 21, 'تفسير الاشعة السينية:'),
(82493, 7277, 21, 'تفسير الاشعة السينية:'),
(82494, 7278, 21, 'X12 فقط: مطالبة بديلة '),
(82495, 7279, 21, 'X12 شريك'),
(82496, 7280, 21, 'X12 شركاء'),
(82497, 7281, 21, 'X12 إمتحان'),
(82498, 7284, 21, 'ي'),
(82499, 7285, 21, 'سنة'),
(82500, 7286, 21, 'سنة'),
(82501, 7287, 21, 'مشاهدة السنة'),
(82502, 7288, 21, 'سنوات'),
(82503, 7289, 21, 'سنوات'),
(82504, 7290, 21, 'سنوات أو شهور'),
(82505, 7291, 21, 'سنوات . شهور و أيام'),
(82506, 7292, 21, 'نعم'),
(82507, 7293, 21, 'نعم'),
(82508, 7294, 21, 'نعم'),
(82509, 7295, 21, 'نعم!'),
(82510, 7296, 21, 'نعم، إحذف وسجّل'),
(82511, 7298, 21, 'نعم / لا'),
(82512, 7299, 21, 'نعم:'),
(82513, 7300, 21, 'اليديشية'),
(82514, 7303, 21, 'أنت على وشك استبدال قالب موجود نهائيا. هل أنت متأكد أنك تريد المتابعة؟'),
(82515, 7304, 21, 'أنت الآن في فترة دخول مسموحة. قم بتغيير كلمة السر قبل'),
(82516, 7305, 21, 'غير مسموح لك بالمسح'),
(82517, 7306, 21, 'غير مسموح لك بالتعديل'),
(82518, 7307, 21, 'لا يحق لك هذا.'),
(82519, 7308, 21, 'غير مصرح لك بالوصول إلى هذه المجموعة.'),
(82520, 7309, 21, 'غير مصرح لك لإضافة / تحرير المشاكل'),
(82521, 7310, 21, 'غير مصرح لك بجدولة المواعيد.'),
(82522, 7311, 21, 'لا يحق لك أن تطلع على هذه المراجعة.'),
(82523, 7312, 21, 'أنت تقوم بالإضافة ضد مراجعة قديمة؟'),
(82524, 7313, 21, 'لا يمكن الوصول لهذه الخدمة مباشرة'),
(82525, 7314, 21, 'لا يمكن الوصول لهذه الصفحة مباشرة'),
(82526, 7315, 21, 'لا يمكنك إضافة قيمة فارغة لفئة!'),
(82527, 7316, 21, 'لا يمكنك إضافة قيمة فارغة لفئة فرعية!'),
(82528, 7317, 21, 'لا يمكنك إضافة قيمة فارغة لعنصر!'),
(82529, 7318, 21, 'لا يمكنك إدخال تاريخ في المستقبل ذا قيمة منجزة من نعم.'),
(82530, 7319, 21, 'لم تختر أي إجراءات'),
(82531, 7320, 21, 'ليس لديك إمكانية الوصول إلى عرض / تعديل هذه المذكرة'),
(82532, 7321, 21, 'لقد حاولت تغيير المحتوى المغلق.  قم بإزالة القفل إذا كنت ترغب في القيام بهذا.  للفتح، قم بإزالة السطر، ''/*lock::*/'''),
(82533, 7322, 21, 'تم الدخول بنجاح'),
(82534, 7323, 21, 'تستطيع تحميل ملفات من نوع .txt فقط'),
(82535, 7324, 21, 'تستطيع تحميل بشكل اختياري نتائج HL7 من ملف'),
(82536, 7325, 21, 'يمكنك وضع نص هنا كشكوى افتراضية في نموذج مراجعة مريض جديد.'),
(82537, 7326, 21, 'يجب عليك إدخال عبارة مرور لتشفير المستند'),
(82538, 7327, 21, 'يجب عليك إدخال كلمة المرور الخاصة بك لتغيير كلمات السر للمستخدم. اتركه فارغا لإبقاء كلمة السر بدون تغيير.'),
(82539, 7329, 21, 'يجب عليك أولا اختيار أو إضافة مريض.'),
(82540, 7330, 21, 'يجب عليك أولا اختيار أو إنشاء مراجعة.'),
(82541, 7331, 21, 'يجب عليك اختيار فئة الزيارة.'),
(82542, 7332, 21, 'يجب عليك اختيار فئة الزيارة'),
(82543, 7333, 21, 'يجب عليك اختيار بعض الحقول للاستمرار'),
(82544, 7334, 21, 'عليك أن تجري هذا الاختبار إذا ظهر أن هذه المطالبة أنشأت بنجاح ولكن لا يحتوي ملف المطالبة الفعلية على أية بيانات أو مجرد جزء غير مكتمل من كمية البيانات التي من المفترض أن تحتوي عليها. فإنه من الواضح مع مطالبات HCFA لأنها قابل للقراءة البشرية، مع مطالبات X12 ستكون العملية أكثر صعوبة لتحديد ما إذا كانت المطالبة كاملة بشكل صحيح.'),
(82545, 7335, 21, 'يجب عليك تحديد سياق واحد على الأقل'),
(82546, 7336, 21, 'يجب عليك اختيار موزع واحد على الاقل'),
(82547, 7339, 21, 'تاريخ اخر يوم غير صحيح'),
(82548, 7340, 21, 'تم مسح الحدث'),
(82549, 7341, 21, 'تم تعديل الحدث'),
(82550, 7342, 21, 'تم ادخال الحدث'),
(82551, 7343, 21, 'الملف كبير جدا'),
(82552, 7345, 21, 'تم تغيير اسم القائمة الخاصة بك لتلبية متطلبات التسمية.'),
(82553, 7346, 21, 'قدمت رسالتك لتسليمها إلى'),
(82554, 7347, 21, 'اسمك لهذه الفئة إجراءات أو نتيجة'),
(82555, 7348, 21, 'كلمة السر الخاصة بك'),
(82556, 7349, 21, 'انتهاء مدة صلاحية كلمة السر الخاصة بك. الرجاء تغيير كلمة السر.'),
(82557, 7350, 21, 'كلمة السر الخاصة بك تنتهي في'),
(82558, 7351, 21, 'انتهاء مدة صلاحية كلمة السر الخاصة بك اليوم. الرجاء تغيير كلمة السر.'),
(82559, 7353, 21, 'وقد تم إعادة ضبط اعدادات PostCalendar الخاصة بك لاستخدام الإعدادات الافتراضية.'),
(82560, 7354, 21, 'تم تحديث اعدادات PostCalendar الخاص بك.'),
(82561, 7355, 21, 'عدد مرات التكرار يجب ان تكون عدد صحيح'),
(82562, 7356, 21, 'عدد مرات التكرار يجب ان تكون ١ على الاقل'),
(82563, 7357, 21, 'تاريخ اول يوم أكبر من تاريخ أخر يوم'),
(82564, 7358, 21, 'تاريخ اول يوم غير صحيح'),
(82565, 7359, 21, 'فشل الإدخال'),
(82566, 7360, 21, 'سنة/شهر/يوم'),
(82567, 7361, 21, 'سنة/شهر/يوم'),
(82568, 7362, 21, 'نظام الأيام لهذة الوثيقة سنة/شهر/يوم'),
(82569, 7363, 21, 'تم اتلاف نظام الأيام سنة/شهر/يوم'),
(82570, 7364, 21, 'تاريخ الوﻻدة سنة/شهر/يوم'),
(82571, 7365, 21, 'تاريخ الوﻻدة سنة/شهر/يوم'),
(82572, 7366, 21, 'تاريخ الوفاة سنة/شهر/يوم'),
(82573, 7367, 21, 'تاريخ البدء او إدخال المستشفي سنة/شهر/يوم'),
(82574, 7368, 21, 'تاريخ البدء, الجراحة او بدء المعالجة سنة/شهر/يوم'),
(82575, 7369, 21, 'تاريخ الشراء او التحويل سنة/شهر/يوم'),
(82576, 7370, 21, 'تاريخ التعافي او نهاية المعالجة سنة/شهر/يوم'),
(82577, 7371, 21, 'تاريخ الرجوع ل اللعب سنة/شهر/يوم'),
(82578, 7372, 21, 'تاريخ الخدمة سنة/شهر/يوم'),
(82579, 7373, 21, 'تاريخ هذة الرسالة سنة/شهر/يوم'),
(82580, 7374, 21, 'تاريخ الرجوع ل اللعب سنة/شهر/يوم'),
(82581, 7375, 21, 'تاريخ هذة الوثيقة سنة/شهر/يوم'),
(82582, 7376, 21, 'تاريخ هذا الحدث او البدء سنة/شهر/يوم'),
(82583, 7377, 21, 'تاريخ النهاية سنة/شهر/يوم ساعه/دقيقة'),
(82584, 7378, 21, 'تاريخ النهاية سنة/شهر/يوم ساعه/دقيقة'),
(82585, 7379, 21, 'تاريخ البداية سنة/شهر/يوم ساعه/دقيقة'),
(82586, 7380, 21, 'تاريخ البداية سنة/شهر/يوم ساعه/دقيقة'),
(82587, 7381, 21, 'سنة/شهر/يوم ساعه/دقيقة/ثانية'),
(82588, 7382, 21, 'سنة/شهر/يوم ساعه(24):دقيقة'),
(82589, 7383, 21, 'آخر موعد لهذا الحدث سنة/شهر/يوم'),
(82590, 7387, 21, 'صفر'),
(82591, 7389, 21, 'البريد'),
(82592, 7390, 21, 'الرمز البريدي'),
(82593, 7391, 21, 'الرمز البريدي/الدولة'),
(82594, 7392, 21, 'زولو'),
(82595, 7393, 21, ' لكن كان '),
(82596, 7394, 21, ' لا يمكن الوصول'),
(82597, 7395, 21, 'هل تريد المسح'),
(82598, 7396, 21, 'الدواء'),
(82599, 7397, 21, 'لم يتم ارسال البريد الالكتروني'),
(82600, 7398, 21, 'من'),
(82601, 7399, 21, 'قد تم الانشاء '),
(82602, 7400, 21, 'قد تم اعادة فتح'),
(82603, 7401, 21, 'تاريخ'),
(82604, 7402, 21, 'ليس رقم'),
(82605, 7403, 21, 'جاهز لاعادة الفوترة'),
(82606, 7404, 21, 'LLL:'),
(82607, 7405, 21, 'كثير'),
(82608, 7406, 21, 'رقم مرجع النسخة الأ صلية للميديكيد (Medicaid) '),
(82609, 7407, 21, 'الأدنى'),
(82610, 7408, 21, 'لا يوجد'),
(82611, 7409, 21, 'النتائج الغير متوقعة في العديد من المتصفحات قد تعني أن المخرجات قد تظهر على الشاشة بشكل مفاجئة وأن هناك فترات توقف طويلة من عدة ثوان حيث يبدو وكأن الأمور قد تعطلت.لكن ليس هذا هو الحال، سوف ترى في نهاية المطاف خرج البيانات سطرا سطرا. قد يكون هناك أرقام متسلسلة تظهر أدناه، وهذه إشارة إلى أنه على الرغم من عدم ظهور أي شيء, يوجد نشاط قائم حاليا. وستتخلل هذه الأرقام مع محتوى الفواتير وهذا أمر طبيعي.'),
(82612, 7410, 21, 'الوصف قد وصلت لحدود ال'),
(82613, 7411, 21, 'حتى'),
(82614, 7412, 21, 'فشل التحديث, غير موجود في قاعدة البيانات؟'),
(82615, 7413, 21, 'تم تحديدها كرسوم'),
(82616, 7414, 21, 'تم الوضع في قائمة الانتظار بنجاح.'),
(82617, 7415, 21, 'تُرك بدون زيارة!'),
(82618, 7416, 21, '" للترميز'),
(82619, 7417, 21, '"محددا في إعدادات PostCalendar!'),
(82620, 7418, 21, '# مسألة تأمينية/مالية'),
(82621, 7419, 21, '# من الحبوب:'),
(82622, 7420, 21, '$'),
(82623, 7421, 21, '$ تم الترميز'),
(82624, 7422, 21, '$ تسمية سنة/شهر/يوم: '),
(82625, 7423, 21, '%'),
(82626, 7424, 21, '٪ ملغاة < 24 ساعة'),
(82627, 7425, 21, '٪ ملغاة < 24 ساعة '),
(82628, 7426, 21, 'كان يجب أن تكون موجودة ولكنها ليست كذلك.'),
(82629, 7427, 21, '(% تطابق أي سلسلة، _ تطابق أي حرف)'),
(82630, 7428, 21, '([ctrl] + انقر لتحديد عدة مستلمين)'),
(82631, 7429, 21, '(رجوع)'),
(82632, 7430, 21, '(انقر للتعديل)'),
(82633, 7431, 21, '(ارسال بريد إلكتروني عاجل, في حين يتم ارسال VOIP آلي إلى مزود الخدمة لمزيد من المعالجة)'),
(82634, 7432, 21, '(أكثر)'),
(82635, 7433, 21, '(مريض جديد)'),
(82636, 7434, 21, '(الملاحظات والصلاحيات)'),
(82637, 7435, 21, '(ملاحظات المريض)'),
(82638, 7436, 21, '(اختر واحده من هذه, أو اكتب عنوان خاص بك)'),
(82639, 7437, 21, '(مفتاح Shift) انقر أو اسحب لتغيير القيمة'),
(82640, 7438, 21, '*تم التذكير'),
(82641, 7439, 21, '** يرجى نقل الجراحات إلى المشاكل!'),
(82642, 7440, 21, '*مطلوب'),
(82643, 7441, 21, 'الرسم البياني انسحب +'),
(82644, 7442, 21, '- لا شيء'),
(82645, 7443, 21, '-- الكل --'),
(82646, 7444, 21, '--تحديد المهمة--'),
(82647, 7445, 21, '.'),
(82648, 7446, 21, '0'),
(82649, 7447, 21, '0-10'),
(82650, 7448, 21, '0-24'),
(82651, 7451, 21, '1'),
(82652, 7452, 21, '1=امريكا الشمالية. انظر http://www.wtng.info/ لقائمة رموز باقي الدول'),
(82653, 7453, 21, 'يوم واحد من الان'),
(82654, 7454, 21, 'شهر واحد من الان'),
(82655, 7455, 21, 'اسبوع واحد من الان'),
(82656, 7456, 21, 'سنة واحدة من الان'),
(82657, 7457, 21, '1.راحة 2.ثلج لمدة يومين 3. ضغط، وترك خلع الملابس ما لم تتخدر القدم أو لون شاحب 4.رفع القدم والساق'),
(82658, 7458, 21, '11-14'),
(82659, 7459, 21, '12 ساعة'),
(82660, 7460, 21, '15-19'),
(82661, 7462, 21, '2'),
(82662, 7463, 21, 'يومين من الان'),
(82663, 7464, 21, 'شهرين من الان'),
(82664, 7465, 21, 'أسبوعين من الان'),
(82665, 7466, 21, 'سنتين من الان'),
(82666, 7467, 21, '2-20 سنه'),
(82667, 7468, 21, '20-24'),
(82668, 7477, 21, '2111-13'),
(82669, 7478, 21, '24 ساعة'),
(82670, 7479, 21, '25+'),
(82671, 7480, 21, '25-29'),
(82672, 7481, 21, 'الثاني'),
(82673, 7482, 21, '٣ أيام من الان'),
(82674, 7483, 21, '٣ أشهر'),
(82675, 7484, 21, '٣ أشهر من الان'),
(82676, 7485, 21, '٣ مرات يوميا'),
(82677, 7486, 21, '٣ أسابيع من الان'),
(82678, 7487, 21, '30-34'),
(82679, 7488, 21, '35-39'),
(82680, 7489, 21, 'الثالث'),
(82681, 7490, 21, '٤ أيام من الان'),
(82682, 7491, 21, '٤ أشهر'),
(82683, 7492, 21, '٤ أشهر من الان'),
(82684, 7493, 21, '٤ مرات يوميا'),
(82685, 7494, 21, '٤ أسابيع من الان'),
(82686, 7495, 21, '40-44'),
(82687, 7496, 21, '45+'),
(82688, 7497, 21, '465.9,عدوى الجهاز التنفسى العلوي'),
(82689, 7498, 21, '466.0, التهاب الشعب الهوائية الحاد'),
(82690, 7499, 21, '486.0, إلتهاب رئوي حاد'),
(82691, 7500, 21, '491.21, الدَّاءُ الرِّئَوِيُّ المُسِدُّ المُزْمِن - تفاقم'),
(82692, 7501, 21, '491.8, إلتهاب رئوي مزمن'),
(82693, 7502, 21, '493.92, ربو - تفاقم حاد'),
(82694, 7503, 21, '496.0, الدَّاءُ الرِّئَوِيُّ المُسِدُّ المُزْمِن'),
(82695, 7504, 21, 'الرابع'),
(82696, 7505, 21, '5 أيام من الان'),
(82697, 7506, 21, '5 أشهر من الان'),
(82698, 7507, 21, '5 أسابيع من الان'),
(82699, 7508, 21, '519.7, تَشَنُّجٌ قَصَبِيّ'),
(82700, 7509, 21, 'الخامس'),
(82701, 7510, 21, '6 أيام من الان'),
(82702, 7511, 21, '6 أشهر'),
(82703, 7512, 21, '6 أشهر من الان'),
(82704, 7513, 21, '6 أسابيع من الان'),
(82705, 7514, 21, 'السادس'),
(82706, 7515, 21, '7 أشهر من الان'),
(82707, 7516, 21, '8 أشهر من الان'),
(82708, 7517, 21, '824.0, كسر, الكَعْبُ الإِنْسِيّ, مغلق'),
(82709, 7518, 21, '824.2, كسر, الكَعْبُ الوَحْشِيّ , مغلق'),
(82710, 7519, 21, '824.6, كسر,كَعْبِيٌّ ثُلاَثِيّ , مغلق'),
(82711, 7520, 21, '825.32, كسر, زورقي كعبي'),
(82712, 7521, 21, '825.35, كسر, قاعدة عظمة مشط القدم الخامسة'),
(82713, 7522, 21, '845.00, التواء الكاحل'),
(82714, 7523, 21, '845.01, التواء رباط الدَّالِيَّة'),
(82715, 7524, 21, '845.02, التواء العَقِبِيّ الشَظَوِيّ'),
(82716, 7525, 21, '9 أشهر من الان'),
(82717, 7526, 21, '99212 أنشأت - بدون صعوبات'),
(82718, 7527, 21, '99213 أنشأت - بقليل من الصعوبة'),
(82719, 7528, 21, '< في غرفة الاختبارات'),
(82720, 7529, 21, '> خروج'),
(82721, 7530, 21, '؟'),
(82722, 7531, 21, '؟ عدم حضور'),
(82723, 7532, 21, '@ وصل'),
(82724, 7533, 21, '[تغيير طريقة العرض]'),
(82725, 7534, 21, '[تاريخ أخر مراجعة]'),
(82726, 7535, 21, '[يوم منذ أخر مراجعة]'),
(82727, 7536, 21, '[EOBs]'),
(82728, 7537, 21, '[تصدير OFX]'),
(82729, 7538, 21, '[غير موصى به]'),
(82730, 7539, 21, '[عدد المراجعات]'),
(82731, 7540, 21, '[التقارير]'),
(82732, 7541, 21, '[تحديد الكل]'),
(82733, 7542, 21, '[SQL-Ledger]'),
(82734, 7543, 21, '[بدء معالجة الحزمة]'),
(82735, 7544, 21, '[عرض السجل]'),
(82736, 7545, 21, '[عرض تقرير قابل للطباعة]'),
(82737, 7546, 21, '_مدة تشغيل_الكمبيوتر_بالساعات'),
(82738, 7547, 21, '_مدة تشغيل_الكمبيوتر_بالدقائق'),
(82739, 7548, 21, '_منطقة_الكمبيوتر'),
(82740, 7549, 21, '~ وصول متأخر'),
(82741, 1, 22, 'A'),
(82742, 2, 22, 'Nummer, der identificerer betalingen'),
(82743, 3, 22, 'Patient certificat til administrator'),
(82744, 4, 22, 'Et klinisk dokument er vedhæftet.'),
(82745, 5, 22, 'Et klinisk dokument er vedhæftet.'),
(82746, 7, 22, 'En distributør skal anføres'),
(82747, 9, 22, 'Det er nødvendigt med et serienummer'),
(82748, 10, 22, 'Det er nødvendigt med et serienummer'),
(82749, 11, 22, 'Et "lille" bogstav'),
(82750, 12, 22, 'Et tal'),
(82751, 14, 22, 'Der findes allerede en patient med dette nummer'),
(82752, 15, 22, 'Der findes allerede en patient med dette navn'),
(82753, 16, 22, 'Der findes allerede en patient med dette CPRnummer'),
(82754, 17, 22, 'Et positivt tal vil vise dette antal tidligere aftaler på en widget på Patient Resume skærmen. (Et negativt tal vil vise aftalerne i faldende orden.)'),
(82755, 18, 22, 'Et positivt tal vil vise dette antal tidligere aftaler på en widget på Patient Resume skærmen.'),
(82756, 19, 22, 'En henvisning kilde kan specificeres for hvert besøg.'),
(82757, 20, 22, 'En relateret IPPF kode kræves.'),
(82758, 21, 22, 'En special karakter'),
(82759, 22, 22, 'En unik værdi der identificerer dette område, usynligt for brugeren'),
(82760, 23, 22, 'Et konsultation findes allerede for denne patient i dag. Klik på Annuller for at åbne den, eller OK for at fortsætte med at skabe en ny.'),
(82761, 24, 22, 'Før et måltid'),
(82762, 25, 22, 'Formiddag'),
(82763, 27, 22, 'AB'),
(82764, 28, 22, 'Forkortelse'),
(82765, 29, 22, 'Abcess:'),
(82766, 30, 22, 'Abdominal'),
(82767, 31, 22, 'Kan bære en vægt fire (4) trin:'),
(82768, 32, 22, 'Abn'),
(82769, 33, 22, 'ABN1'),
(82770, 34, 22, 'abnorm'),
(82771, 35, 22, 'abnorm blodprøve'),
(82772, 36, 22, 'Abnorm Hårvækst'),
(82773, 37, 22, 'Abnormt mammogram'),
(82774, 39, 22, 'Abort'),
(82775, 40, 22, 'Abortproblematik'),
(82776, 41, 22, 'Abortmetod'),
(82777, 42, 22, 'Abortrelaterede kategorier'),
(82778, 43, 22, 'Aborter'),
(82779, 44, 22, 'Om kalenderen'),
(82780, 46, 22, 'Fraværende ved diagnose'),
(82781, 47, 22, 'Acceptér opgaven'),
(82782, 48, 22, 'Acceptér betaling for'),
(82783, 49, 22, 'Acceptér betaling for'),
(82784, 50, 22, 'Accepterer opgaven'),
(82785, 51, 22, 'Adgangskontrol'),
(82786, 52, 22, 'Administration af adgangskontrolliste'),
(82787, 53, 22, 'Dato for adgang'),
(82788, 54, 22, 'Adgang ikke tilladt'),
(82789, 55, 22, 'Adgang ikke autoriseret'),
(82790, 56, 22, 'Få adgang til din patient Portal'),
(82791, 57, 22, 'Ulykke'),
(82792, 59, 22, 'Konto navn'),
(82793, 62, 22, 'Regnskab'),
(82794, 64, 22, 'Ømhed'),
(82795, 65, 22, 'Bekræftelse er nødvendig (ISA14)'),
(82796, 66, 22, 'Anerkendelser, Licenser og certificering'),
(82797, 67, 22, 'hjemmepleje'),
(82798, 68, 22, 'Hjemmepleje Administration'),
(82799, 69, 22, 'Hjemmepleje Administration ikke tilladt'),
(82800, 71, 22, 'Acne'),
(82801, 72, 22, 'Akt'),
(82802, 73, 22, 'aktivitetsdato'),
(82803, 74, 22, 'handling'),
(82804, 75, 22, 'Handlinger'),
(82805, 77, 22, 'Aktiver CCR/CCD Reporting'),
(82806, 78, 22, 'Aktiv'),
(82807, 79, 22, 'Aktiv alarm'),
(82808, 80, 22, 'Regler for aktiv alarm'),
(82809, 81, 22, 'Aktive alarmer/påmindelser'),
(82810, 82, 22, 'Aktiv aftale'),
(82811, 84, 22, 'Aktive lister'),
(82812, 85, 22, 'Aktiv patient'),
(82813, 86, 22, 'Aktive planer'),
(82814, 87, 22, 'Aktivitet'),
(82815, 88, 22, 'Aktivitetstype'),
(82816, 92, 22, 'Acuta in chronica'),
(82817, 93, 22, 'Tilføj'),
(82818, 94, 22, 'Tilføj'),
(82819, 95, 22, 'Tilføj'),
(82820, 96, 22, 'Tilføj et firma'),
(82821, 98, 22, 'Tilføj et apotek'),
(82822, 100, 22, 'Tilføj aktivitet til '),
(82823, 101, 22, 'Tilføj ny note'),
(82824, 102, 22, 'Tilføj som ny'),
(82825, 104, 22, 'Tilføj knapper'),
(82826, 106, 22, 'Tilføj Kategori'),
(82827, 107, 22, 'Tilføj konstant'),
(82828, 108, 22, 'Tilføj sammenhæng'),
(82829, 109, 22, 'Tilføj medbetaling'),
(82830, 110, 22, 'Tilføj kriteria'),
(82831, 111, 22, 'Tilføj special knap'),
(82832, 112, 22, 'Tilføj diagnose'),
(82833, 113, 22, 'Tilføj lægemiddel'),
(82834, 114, 22, 'Tilføj aftale'),
(82835, 115, 22, 'Tilføj aftale/note'),
(82836, 116, 22, 'Tilføj kllinik'),
(82837, 117, 22, 'Tilføj felt'),
(82838, 118, 22, 'Tilføj følgende linier til Apaches konfigurationsfil'),
(82839, 119, 22, 'Tilføj gruppe'),
(82840, 120, 22, 'Tilføj ICD kode'),
(82841, 121, 22, 'Tilføj vaccination'),
(82842, 122, 22, 'Tilføjelse ikke autoriseret!'),
(82843, 123, 22, 'Tilføj emne'),
(82844, 124, 22, 'Tilføj emne der skal følges'),
(82845, 125, 22, 'Tilføj sprog'),
(82846, 126, 22, 'Tilføj ny'),
(82847, 127, 22, 'Tilføj ny'),
(82848, 128, 22, 'Tilføj ny kategori '),
(82849, 129, 22, 'Tilføj nyt certifikat til Apaches konfigurationsfil'),
(82850, 130, 22, 'Tilføj ny komponent'),
(82851, 131, 22, 'Tilføj nye komponenter'),
(82852, 132, 22, 'Tilføj ny gruppe'),
(82853, 133, 22, 'Tilføj ny problemstilling'),
(82854, 134, 22, 'Tilføj nyt lod og transaktioner'),
(82855, 135, 22, 'Tilføj ny note'),
(82856, 136, 22, 'Tilføj ny note'),
(82857, 137, 22, 'Tilføj ny partner'),
(82858, 138, 22, 'Tilføj ny patient'),
(82859, 140, 22, 'Tilføj note'),
(82860, 141, 22, 'Tilføj ny patientjournal'),
(82861, 142, 22, 'Tilføj recept'),
(82862, 143, 22, 'Tilføj procedure'),
(82863, 144, 22, 'Tilføj behandlernummer'),
(82864, 146, 22, 'Tilføj regel'),
(82865, 147, 22, 'Tilføj til'),
(82866, 148, 22, 'Tilføj til medicinliste'),
(82867, 149, 22, 'Tilføj top niveau'),
(82868, 150, 22, 'Tilføj transaktion'),
(82869, 151, 22, 'Tilføj bruger'),
(82870, 152, 22, 'Tilføj bruger til gruppen'),
(82871, 153, 22, 'Tilføj/rediger eRx'),
(82872, 154, 22, 'Tilføj/ret patient transaktion'),
(82873, 155, 22, 'tilføjet'),
(82874, 156, 22, 'Det er ikke tilladt at tilføje oplysninger'),
(82875, 157, 22, 'Tilføjelse af emne der skal følges mislykkedes'),
(82876, 158, 22, 'Addison Syndrom'),
(82877, 159, 22, 'Addison Syndrom'),
(82878, 161, 22, 'Andre diagnoser'),
(82879, 162, 22, 'Yderligere historie'),
(82880, 163, 22, 'Yderligere historienoter'),
(82881, 164, 22, 'Yderligere info'),
(82882, 165, 22, 'Yderligere Lab'),
(82883, 166, 22, 'Yderligere noter'),
(82884, 168, 22, 'Yderligere noter:'),
(82885, 169, 22, 'Yderligere noter: '),
(82886, 170, 22, 'Yderligere røntgen noter:'),
(82887, 172, 22, 'kun tilføjelser'),
(82888, 173, 22, 'Adressebog'),
(82889, 174, 22, 'Adressebog'),
(82890, 175, 22, 'Adresse'),
(82891, 178, 22, 'Adressebog'),
(82892, 182, 22, 'Adressebogtyper'),
(82893, 187, 22, 'Adresse 1'),
(82894, 188, 22, 'Adresse 2'),
(82895, 189, 22, 'Adressent'),
(82896, 190, 22, 'Adj'),
(82897, 192, 22, 'Justér'),
(82898, 193, 22, 'Justering'),
(82899, 194, 22, 'Juster beløb'),
(82900, 195, 22, 'Årsag til justering'),
(82901, 196, 22, 'Koden justeringsværdi '),
(82902, 197, 22, 'Justeringer'),
(82903, 198, 22, 'Adm justering'),
(82904, 199, 22, 'Admin'),
(82905, 200, 22, 'Admin emailadresse'),
(82906, 201, 22, 'Administrer via'),
(82907, 202, 22, 'Administrreret'),
(82908, 203, 22, 'Administreret af'),
(82909, 206, 22, 'Sys.Administration'),
(82910, 208, 22, 'Administratorer'),
(82911, 209, 22, 'Administratorer kan gøre alt'),
(82912, 218, 22, 'Avanceret'),
(82913, 219, 22, 'Råd'),
(82914, 221, 22, 'Påvirker normal'),
(82915, 223, 22, 'Opkald efter arbejdstid'),
(82916, 226, 22, 'Klik på [View Log] for at søge efter fejl, efter at have gemt PDF.'),
(82917, 227, 22, 'Klik på [Se log] for at søge efter fejl, efter at have gemt TEXT fil(er).'),
(82918, 228, 22, 'Klik på [Se log] for at søge efter fejl, efter at have gemt din batch.'),
(82919, 229, 22, 'Herefter vil resultatsøjlen vise den valgte patient-ID eller 0 for ny patient'),
(82920, 230, 22, 'Klik [gem] når du er sikker på at informationen er korrekt.'),
(82921, 231, 22, 'efter hentning klik "Import" knappen'),
(82922, 232, 22, 'Plan for efterbehandling'),
(82923, 233, 22, 'Igen'),
(82924, 234, 22, 'Alder'),
(82925, 235, 22, 'Alder ved'),
(82926, 236, 22, 'Alderskategori'),
(82927, 237, 22, 'Alder - data udenfor interval'),
(82928, 239, 22, 'Aldersformat for "alder fra" er ikke gyldigt'),
(82929, 240, 22, 'Aldersformat for "alder til" er ikke gyldigt'),
(82930, 241, 22, 'Alder fra'),
(82931, 243, 22, 'max. alder'),
(82932, 244, 22, 'min. alder'),
(82933, 245, 22, 'Aldersinterval'),
(82934, 247, 22, 'Aldringssøjler:'),
(82935, 250, 22, 'Alkohol'),
(82936, 251, 22, 'Alkoholkonsumtion'),
(82937, 252, 22, 'Alkoholforbrug'),
(82938, 253, 22, 'Alarmoptælling'),
(82939, 255, 22, 'Alarmer'),
(82940, 259, 22, 'Alle'),
(82941, 260, 22, 'Alle'),
(82942, 261, 22, 'Alle (Collated Format A)'),
(82943, 262, 22, 'Alle (Collated Format B)'),
(82944, 263, 22, 'Alle (Cumulative)'),
(82945, 266, 22, 'Alle kategorier'),
(82946, 268, 22, 'Alle koder'),
(82947, 269, 22, 'Hele dagen'),
(82948, 270, 22, 'Heldagshændelse'),
(82949, 272, 22, 'Alle kliniker'),
(82950, 273, 22, 'Alle skader/prolemer/emner'),
(82951, 274, 22, 'Alle sprog tilladt'),
(82952, 276, 22, 'Hele eller en del af fornavn'),
(82953, 277, 22, 'Hele eller en del af efternavn'),
(82954, 279, 22, 'Alle patienter'),
(82955, 280, 22, 'Alle produkter'),
(82956, 281, 22, 'Alle leverandører'),
(82957, 282, 22, 'Alle kontrolleret og fundet negative'),
(82958, 283, 22, 'Alle emner'),
(82959, 284, 22, 'Alle brugere'),
(82960, 285, 22, 'Allergisk'),
(82961, 286, 22, 'Allergier'),
(82962, 287, 22, 'Allergier:'),
(82963, 288, 22, 'Allergi'),
(82964, 291, 22, 'Allergisk reaktion'),
(82965, 294, 22, 'Tildel'),
(82966, 295, 22, 'Tillad'),
(82967, 296, 22, 'Tillad alle tilgengængelige sprog som mulige ved login'),
(82968, 299, 22, 'Tillad e-mail'),
(82969, 300, 22, 'Tillad e-mail meddelelser'),
(82970, 301, 22, 'Tillad e-mail?'),
(82971, 306, 22, 'Tillad brev'),
(82972, 308, 22, 'Tillad patientportal'),
(82973, 309, 22, 'Tillad SMS-kontakt'),
(82974, 310, 22, 'Tillad SMS-kontakt?'),
(82975, 311, 22, 'Tillåt skickade händelser att bli aktiva omedelbart?'),
(82976, 312, 22, 'Tillad telefonmeddelser?'),
(82977, 313, 22, 'Tillad brugere at puplicere Globale begivenheder'),
(82978, 314, 22, 'Tillad brugere at puplicere personlige kalendere'),
(82979, 315, 22, 'Tillad telefonsvarerbeskeder'),
(82980, 316, 22, 'Tilladt'),
(82981, 317, 22, 'Tilladte sprog'),
(82982, 318, 22, 'Tilladt(c)'),
(82983, 323, 22, 'Eksisterer allerede'),
(82984, 324, 22, 'findes allerede'),
(82985, 325, 22, 'Findes allerede, vælg en anden ID'),
(82986, 326, 22, 'Findes allerede, vælg en anden titel'),
(82987, 327, 22, 'Alt Adress'),
(82988, 328, 22, 'Ændre'),
(82989, 329, 22, 'Alternativt kan du använda sökfunktionen sida att lägga upp en elektronisk remittance (X12 835) fil som du fått från din betalare eller clearingorganisationer. Du kan göra detta genom att klicka på knappen Bläddra och välj den fil som ska laddas upp och sedan klicka på Sök för att utföra de ladda upp och visa motsvarande fakturor. I detta fall är det andra parametrar som nämns ovan gäller inte och kommer att ignoreras. Överföring sparar filen menprocessar ännu inte innehållet - detta är gjort separat enligt nedan.'),
(82990, 330, 22, 'FM'),
(82991, 338, 22, 'Ändra Befintlig notering'),
(82992, 345, 22, 'AMEX'),
(82993, 347, 22, 'Beløb'),
(82994, 349, 22, 'Beløb opkrævet'),
(82995, 350, 22, 'Tidigere saldo'),
(82996, 351, 22, 'Beløb for dette besøg'),
(82997, 352, 22, 'Betalt beløb'),
(82998, 353, 22, 'Beløb:'),
(82999, 360, 22, 'En ofullständig GCAC fråga har inrättats och knutits. Någon kommer att behöva fylla i det senare.'),
(83000, 362, 22, 'Der er opstået en uventet fejl'),
(83001, 363, 22, 'Et stort bogstav'),
(83002, 365, 22, 'Og'),
(83003, 366, 22, 'OG'),
(83004, 367, 22, 'og'),
(83005, 368, 22, 'og '),
(83006, 369, 22, 'Og alle underordnede data? Denne handling vil blive logget'),
(83007, 371, 22, 'og udført'),
(83008, 373, 22, 'og årsagen er'),
(83009, 374, 22, 'Anemi'),
(83010, 375, 22, 'Ankel'),
(83011, 376, 22, 'Ankel og hæl'),
(83012, 377, 22, 'Ankel Utvärderingsformulär'),
(83013, 378, 22, 'AnkelProblem'),
(83014, 379, 22, 'Ankyloserande Sondlilitis'),
(83015, 380, 22, 'Ankyloserande Spondlilitis'),
(83016, 381, 22, 'Anorexia'),
(83017, 382, 22, 'En annan sak du kan göra i utstationering fönstret är att begära en sekundära fakturering. Om du markerar rutan innan du sparar, så kommer den ursprungliga fordran att öppnas igen och köas på faktureringssidan och sedan behandlas under nästa faktureringskörning.'),
(83018, 383, 22, 'før'),
(83019, 384, 22, 'Anus, ingen rektal ömhet'),
(83020, 385, 22, 'Angst'),
(83021, 386, 22, 'Valgfri'),
(83022, 387, 22, 'Enhver kategori'),
(83023, 388, 22, 'Varje del av en kod eller dess beskrivning'),
(83024, 389, 22, 'Varje del av önskad specialitet'),
(83025, 392, 22, 'Varje del av patientens namn, eller "sista, första " eller "X-Y "'),
(83026, 395, 22, 'Apnea'),
(83027, 396, 22, 'Udseende'),
(83028, 397, 22, 'Udseende:'),
(83029, 398, 22, 'Tilføj note'),
(83030, 399, 22, 'Tilføj til eksisterende note'),
(83031, 400, 22, 'Tilføj til denne note'),
(83032, 401, 22, 'Tilføj til denne note'),
(83033, 402, 22, 'Appendektomi'),
(83034, 412, 22, 'Foretag kun ændringer for denne begivenhed, for denne og alle fremtidige eller for alle begivenheder?'),
(83035, 413, 22, 'Påfør inficeret område'),
(83036, 414, 22, 'Påføres på huden'),
(83037, 415, 22, 'påføres'),
(83038, 417, 22, 'Aftale'),
(83039, 418, 22, 'Aftaledato'),
(83040, 420, 22, 'Påmindelse på aftale'),
(83041, 421, 22, 'Aftalestatus'),
(83042, 422, 22, 'Aftalestatus''er'),
(83043, 423, 22, 'Aftale inden for'),
(83044, 424, 22, 'Aftale/begivenhed farve'),
(83045, 425, 22, 'Aftaler'),
(83046, 426, 22, 'Aftaler (Ikke nødvendigt at skrive)'),
(83047, 430, 22, 'Aftaler og besøg'),
(83048, 431, 22, 'Aftalerapport'),
(83049, 432, 22, 'Aftale- og besøgsrapport'),
(83050, 434, 22, 'Godkend'),
(83051, 436, 22, 'Godkendt'),
(83052, 437, 22, 'Godkendt begivenhed administration'),
(83053, 440, 22, 'Aftaler-Besøg'),
(83054, 441, 22, 'Aftaler'),
(83055, 442, 22, 'apr'),
(83056, 443, 22, 'April'),
(83057, 448, 22, 'Skal aftalekategoriens navn oversættes?'),
(83058, 450, 22, 'Er der udgifter for denne type?'),
(83059, 451, 22, 'Skal patientnoter oversættes?'),
(83060, 453, 22, 'Er du forberedt på at gennemføre et nyt GCAC-emne for denne aftale?'),
(83061, 455, 22, 'Er du sikker på du vil godkende disse begivenheder?'),
(83062, 457, 22, 'Er du sikker på du vil fjerne denne form?'),
(83063, 460, 22, 'Er du sikker på du ønsker at slette denne begivenhed?'),
(83064, 461, 22, 'Er du sikker på du ønsker at slette denne fil fra databasen?'),
(83065, 462, 22, 'Er du sikker på du ønsker at slette denne note?'),
(83066, 464, 22, 'Er du sikker på du ønsker at ændre disse begivenheder?'),
(83067, 465, 22, 'Er du sikker på du ønsker at skjule disse begivenheder?'),
(83068, 467, 22, 'Er du sikker på du ønsker at se disse begivenheder?'),
(83069, 468, 22, 'Er du sikker på du ønsker at slette hele den valgte gruppe?'),
(83070, 469, 22, 'Er du sikker på du vil slette hele listen?'),
(83071, 470, 22, 'Er du sikker på du vil slette feltet i?'),
(83072, 471, 22, 'Er du sikker på du vil slette de valgte felter?'),
(83073, 472, 22, 'Er du sikker på du vil forsætte disse handlinger?'),
(83074, 473, 22, 'Området er ikke specificeret'),
(83075, 475, 22, 'Armensk'),
(83076, 477, 22, 'Arrytmi'),
(83077, 478, 22, 'Artrit'),
(83078, 479, 22, 'Artrit / Degen ledsjukdom'),
(83079, 480, 22, 'Artrit / Degen ledsjukdom'),
(83080, 481, 22, 'som'),
(83081, 482, 22, 'pr.'),
(83082, 484, 22, 'Asiatisk'),
(83083, 487, 22, 'Vurdering'),
(83084, 488, 22, 'Tildelt til'),
(83085, 489, 22, 'Assistent'),
(83086, 490, 22, 'Astma'),
(83087, 491, 22, 'på'),
(83088, 493, 22, 'Vid Båtbenet'),
(83089, 494, 22, 'Vid Båtbenet:'),
(83090, 497, 22, 'Atletisk / Skada'),
(83091, 503, 22, 'OBS'),
(83092, 504, 22, 'OBS'),
(83093, 516, 22, 'Aug'),
(83094, 517, 22, 'August'),
(83095, 519, 22, 'Forfatter'),
(83096, 520, 22, 'Forfatter/noter'),
(83097, 525, 22, 'Tilladelser'),
(83098, 526, 22, 'At give tilladelse til'),
(83099, 527, 22, 'Tillad - alle aftaler'),
(83100, 528, 22, 'Tillad - mine aftaler'),
(83101, 530, 22, 'Tilladt'),
(83102, 531, 22, 'Kun tilladte'),
(83103, 532, 22, 'Send automatisk'),
(83104, 535, 22, 'opret automatisk ny aftale'),
(83105, 536, 22, 'Autogeneret'),
(83106, 544, 22, 'Automatisk'),
(83107, 549, 22, 'Automobilemedicin'),
(83108, 550, 22, 'Gemt automatisk'),
(83109, 551, 22, 'Tilgængelige kategorier'),
(83110, 552, 22, 'tilgængelige tider'),
(83111, 557, 22, 'Gennemsnitlig om måneden'),
(83112, 558, 22, 'Avulsion / avulsion fraktur'),
(83113, 559, 22, 'Avulsion laterala malleolus'),
(83114, 560, 22, 'Avulsion mediala malleolus '),
(83115, 561, 22, 'Medvetandebaserad'),
(83116, 562, 22, 'Axillär'),
(83117, 565, 22, '2 ggr/dag'),
(83118, 566, 22, 'Tilbage'),
(83119, 567, 22, 'Tilbage'),
(83120, 568, 22, 'Tilbage otte besøg'),
(83121, 569, 22, 'Tilbage elleve besøg'),
(83122, 570, 22, 'Tilbage fem besøg'),
(83123, 571, 22, 'Tilbage fire besøg'),
(83124, 572, 22, 'Tilbage ni besøg'),
(83125, 573, 22, 'Tilbage et besøg'),
(83126, 574, 22, 'Rygsmerter'),
(83127, 575, 22, 'Ryggproblem'),
(83128, 576, 22, 'Tilbage 7 besøg'),
(83129, 577, 22, 'Tilbage 6 besøg'),
(83130, 578, 22, 'Ryggkirurgi'),
(83131, 579, 22, 'Tilbage 10 besøg'),
(83132, 580, 22, 'Tilbage 3 besøg'),
(83133, 584, 22, 'Tilbage til Patient'),
(83134, 586, 22, 'Tilbage til oversigt'),
(83135, 587, 22, 'Tilbage 12 besøg'),
(83136, 588, 22, 'Tilbage 2 besøg'),
(83137, 590, 22, 'Backup'),
(83138, 591, 22, 'Backupfilen er oprettet. Sender nu download'),
(83139, 594, 22, 'Dålig kontroll'),
(83140, 595, 22, 'Kundförluster'),
(83141, 596, 22, 'Bahasa Indonesia'),
(83142, 597, 22, 'Bal'),
(83143, 598, 22, 'Saldo'),
(83144, 599, 22, 'saldo'),
(83145, 601, 22, 'Restskuld'),
(83146, 603, 22, 'Bankudtræk'),
(83147, 607, 22, 'Basen av femte (5e) Metarsal'),
(83148, 608, 22, 'Basen av femte (5e) Metarsal'),
(83149, 612, 22, 'Batchkummunikationsverktyg'),
(83150, 615, 22, 'Batchprocess påbörjad, detta kan ta ett tag.'),
(83151, 617, 22, 'BatchCom'),
(83152, 619, 22, 'För att ID inte existerar'),
(83153, 620, 22, 'Start'),
(83154, 621, 22, 'Startdato'),
(83155, 623, 22, 'Startdato for service ÅÅÅÅ-MM-DD'),
(83156, 624, 22, 'Starttidspunkt for aftaler i kalender'),
(83157, 626, 22, 'Rapningar'),
(83158, 630, 22, 'Mellem'),
(83159, 633, 22, 'Bilateral'),
(83160, 634, 22, 'Bilateral'),
(83161, 636, 22, 'Fakturadato:'),
(83162, 637, 22, 'Faktura'),
(83163, 638, 22, 'Faktureret'),
(83164, 640, 22, 'Faktureringspreferenser'),
(83165, 641, 22, 'Fakturering (skriv valgfri)'),
(83166, 642, 22, 'Faktureringspreferenser Attn'),
(83167, 644, 22, 'Betalningskod för begärd service'),
(83168, 645, 22, 'Betalningskoder'),
(83169, 646, 22, 'Fakturadata'),
(83170, 647, 22, 'Fakturaafdeling'),
(83171, 649, 22, 'Faktureringsinformation'),
(83172, 650, 22, 'Faktureringsadresse'),
(83173, 656, 22, 'Faktureringspreferenser Anmärkning'),
(83174, 657, 22, 'Faktureringspreferenser anmärkning för '),
(83175, 658, 22, 'Faktureringspreferenser Obs!'),
(83176, 659, 22, 'Faktureringspreferenser kö resultat:'),
(83177, 660, 22, 'Faktureringsrapport'),
(83178, 662, 22, 'Fakturastatus = ikke faktureret'),
(83179, 663, 22, 'Fakturerer til '),
(83180, 665, 22, 'Biopsi'),
(83181, 666, 22, 'Fødselsdato'),
(83182, 669, 22, 'Sort'),
(83183, 672, 22, 'Cancer i urinblåsan'),
(83184, 673, 22, 'Infektioner i urinblåsan'),
(83185, 674, 22, 'Blank formular'),
(83186, 675, 22, 'Problem med blödning'),
(83187, 676, 22, 'Blinda punkter'),
(83188, 677, 22, 'Svullnad'),
(83189, 678, 22, 'Blokeret'),
(83190, 679, 22, 'Blod'),
(83191, 680, 22, 'Blodtryk'),
(83192, 681, 22, 'Blodtryk'),
(83193, 682, 22, 'Næseblod'),
(83194, 683, 22, 'Blått kors blå sköld'),
(83195, 684, 22, 'Blå linjerna i denna rapport är informativa. Svarta linjer visar tidigare information. Gröna linjerna visar förändringar som tillämpats framgångsrikt. Röda linjer visar fel eller förändringar som inte har genomförts, och dessa måste behandlas manuellt. För närvarande nekas fordringar och betalning reverseringar inte hanteras automatiskt och det kommer att visas i rött.'),
(83196, 685, 22, 'Dimsyn'),
(83197, 686, 22, 'BMI'),
(83198, 687, 22, 'BMI status'),
(83199, 689, 22, 'kroppsregion'),
(83200, 692, 22, 'Benømhed'),
(83201, 693, 22, 'Benömhet: Malleoulus Medialis'),
(83202, 694, 22, 'Boolean'),
(83203, 696, 22, 'Bund'),
(83204, 697, 22, 'Begge ører'),
(83205, 698, 22, 'begge ører'),
(83206, 699, 22, 'Bund'),
(83207, 701, 22, 'RUTA 10 A. sysselsättningsrelaterad '),
(83208, 702, 22, 'RUTA 10 B. Bilolycka '),
(83209, 703, 22, 'RUTA 10 C. Övriga olyckor '),
(83210, 708, 22, 'FÄLT 16. Datum, oförmögen till arbete från (åååå-mm-dd):'),
(83211, 709, 22, 'FÄLT 16. Datum, oförmögen att arbeta tills (åååå-mm-dd):'),
(83212, 710, 22, 'FÄLT 18. Sjukhusvistelse datum, från (åååå-mm-dd): '),
(83213, 711, 22, 'FÄLT 18. Sjukhusvistelse till, datum (åååå-mm-dd): '),
(83214, 712, 22, 'FÄLT 20. Ligger utanför Lab användas?'),
(83215, 715, 22, 'Blodtryk'),
(83216, 716, 22, 'BT Diastoliskt'),
(83217, 717, 22, 'BT Systoliskt'),
(83218, 719, 22, 'BPD'),
(83219, 721, 22, 'Puls'),
(83220, 722, 22, 'Brasiliansk portugisiska'),
(83221, 723, 22, 'Bryst'),
(83222, 724, 22, 'Bröst Biopsi'),
(83223, 725, 22, 'Bröstlossning'),
(83224, 726, 22, 'Bröstsjukdom'),
(83225, 727, 22, 'Bröstundersökning'),
(83226, 728, 22, 'Bröstvävnad'),
(83227, 730, 22, 'Andningsljud:'),
(83228, 732, 22, 'Brutna ben'),
(83229, 734, 22, 'Bronkit Formulär'),
(83230, 735, 22, 'Søg'),
(83231, 736, 22, 'Søg efter journal'),
(83232, 737, 22, 'Blåmärken / hematom'),
(83233, 739, 22, 'Utbuktningen Höger:'),
(83234, 741, 22, 'Sveda vid vattenkastning'),
(83235, 742, 22, 'Sveda vid urinering'),
(83236, 744, 22, 'Optaget'),
(83237, 745, 22, 'Men endnu ikke gennemført'),
(83238, 747, 22, 'Skinkan + S.I.'),
(83239, 748, 22, 'via'),
(83240, 749, 22, 'Via'),
(83241, 750, 22, 'Via munden'),
(83242, 751, 22, 'via/ kilden'),
(83243, 752, 22, 'Via:'),
(83244, 753, 22, 'C'),
(83245, 755, 22, 'Cache, livstid (i sekunder)'),
(83246, 756, 22, 'Cache template output?'),
(83247, 757, 22, 'Koffein konsumsion'),
(83248, 758, 22, 'Kalender'),
(83249, 759, 22, 'Kalender sluttid'),
(83250, 760, 22, 'Kalenderinterval'),
(83251, 761, 22, 'Kalenderskærm'),
(83252, 762, 22, 'Indstillinger for kalender'),
(83253, 763, 22, 'Kalender starttid'),
(83254, 764, 22, 'Kalender UI'),
(83255, 765, 22, 'Se kalender'),
(83256, 766, 22, 'Call to addForm() goes here.<br>'),
(83257, 767, 22, 'Kalorier'),
(83259, 774, 22, 'Afbryd'),
(83260, 775, 22, 'Fortryd ændringer'),
(83261, 776, 22, 'Aflyst'),
(83262, 777, 22, 'Cancer'),
(83263, 782, 22, 'Kan ikke tilføje denne indgang da den allerede eksisterer!'),
(83264, 783, 22, 'Kan ikke tilføje/opdatere denne indgang da der allerede findes en kopi'),
(83265, 785, 22, 'Kan ikke konverteres til JPEG. Måske er ImageMagick ikke installeret?'),
(83266, 787, 22, 'Kan ikke vises inline fordi typen ikke understøttes af browseren'),
(83267, 788, 22, 'Kan ikke vises inline fordi typen ikke understøttes af browseren'),
(83268, 789, 22, 'Kan ikke vises inline fordi typen ikke understøttes af browseren'),
(83269, 790, 22, 'Ikke muligt at oprette'),
(83270, 795, 22, 'Ikke muligt at finde '),
(83271, 796, 22, 'Ikke muligt at finde en destination for filnavn'),
(83272, 799, 22, 'Kan inte hitta patienten från SQL-Reskontra kundnummer'),
(83273, 800, 22, 'Kan ej hitta postscript dokumenthänvisning i '),
(83274, 801, 22, 'Kan inte hitta patienten från SQL-Reskontra arbetsgivare '),
(83275, 803, 22, 'Kan ikke åbnes '),
(83276, 807, 22, 'Kan ikke læses'),
(83277, 809, 22, 'Kan ikke opdatere fordi du ikke ændrer i en eksisterende indgang'),
(83278, 812, 22, 'kapsel'),
(83279, 813, 22, 'Kort'),
(83280, 814, 22, 'Cardiac Katetrisering'),
(83281, 815, 22, 'Cardiac Echo'),
(83282, 816, 22, 'Kardiovaskulära'),
(83283, 821, 22, 'Cartilage / chondral / skiva skador'),
(83284, 822, 22, 'Cartilago skada'),
(83285, 824, 22, 'kontanter'),
(83286, 825, 22, 'Kontanter'),
(83287, 827, 22, 'Inbetalningar av Provider'),
(83288, 829, 22, 'Kataraktkirurgi'),
(83289, 830, 22, 'Katarakt'),
(83290, 831, 22, 'Kategorier'),
(83291, 832, 22, 'Kategorier for'),
(83292, 833, 22, 'Kategori'),
(83293, 834, 22, 'kategori'),
(83294, 835, 22, 'Kategori '),
(83295, 836, 22, 'Kategori Detaljer'),
(83296, 837, 22, 'Kategori grænser'),
(83297, 838, 22, 'kategorinavn'),
(83298, 839, 22, 'Kategorinavn er tomt'),
(83299, 840, 22, 'Kategori / Titel'),
(83300, 841, 22, 'Kaukasisk'),
(83301, 853, 22, 'Mobiltelefon'),
(83302, 855, 22, 'Mobiltelefonnummer'),
(83303, 856, 22, 'Central Certifiering'),
(83304, 864, 22, 'ChampUS'),
(83305, 865, 22, 'ChampUSVA'),
(83306, 866, 22, 'Ændre'),
(83307, 867, 22, 'Ændre'),
(83308, 868, 22, 'Ændre aktivitet'),
(83309, 870, 22, 'Förändrat synsätt'),
(83310, 874, 22, 'Ændret'),
(83311, 875, 22, 'Förändrad tarm'),
(83312, 877, 22, 'Karaktertræk'),
(83313, 879, 22, 'Afgift'),
(83314, 882, 22, 'Afgifter'),
(83315, 883, 22, 'Diagram'),
(83316, 884, 22, 'Diagram aktivitet'),
(83317, 885, 22, 'Diagram Check-in/out Aktivitetsrapport'),
(83318, 886, 22, 'Diagram ID'),
(83319, 887, 22, 'Diagram-id:'),
(83320, 889, 22, 'Diagram Läge Aktivitet'),
(83321, 890, 22, 'Diagramanteckning'),
(83322, 891, 22, 'Journalnummer'),
(83323, 892, 22, 'Diagramlagringsplats'),
(83324, 893, 22, 'Diagramtracker'),
(83325, 894, 22, 'Diagramtrk.'),
(83326, 895, 22, 'Diagram utcheckat'),
(83327, 898, 22, 'Kontrol'),
(83328, 899, 22, 'Kontrol'),
(83329, 900, 22, 'Kontroller alle'),
(83330, 902, 22, 'kontroler beløb'),
(83331, 903, 22, 'Kontroldato'),
(83332, 906, 22, 'checka in till'),
(83333, 907, 22, 'Kontroller input data'),
(83334, 912, 22, 'Kontrollnummer'),
(83335, 915, 22, 'kontrolbetaling'),
(83336, 919, 22, 'Kontrollera / EOB Datum:'),
(83337, 920, 22, 'Kontrollera / EOB Antal:'),
(83338, 921, 22, 'kontrol/ ref. nummer'),
(83339, 922, 22, 'kontrol/ ref. nummer'),
(83340, 923, 22, 'Afkrydsningsboks liste'),
(83341, 924, 22, 'Afkrydsningsboks liste'),
(83342, 925, 22, 'Afkrydsningsboks m/tekst'),
(83343, 926, 22, 'Afkrydsningsboks m/tekst'),
(83344, 928, 22, 'Kontrolleret'),
(83345, 929, 22, 'Markerede felter = ja, tomme felter = nej'),
(83346, 932, 22, 'Kasse'),
(83347, 934, 22, 'Bröst'),
(83348, 935, 22, 'Chest CTAB'),
(83349, 936, 22, 'Bröstsmärtor'),
(83350, 937, 22, 'Bröstsmärta:'),
(83351, 938, 22, 'Bröstsmärtor'),
(83352, 940, 22, 'Chg'),
(83353, 943, 22, 'Barn'),
(83354, 946, 22, 'Frossbrytningar'),
(83355, 947, 22, 'Kinesiska'),
(83356, 951, 22, 'Valg'),
(83357, 952, 22, 'Cholecystectomia'),
(83358, 954, 22, 'Cholecystotomia'),
(83359, 955, 22, 'Vælg'),
(83360, 956, 22, 'Välj ett avsnitt och klicka på ett objekt i den; Då, i den andra sektionen visas relaterade objekt. Klicka på avsnitten om du vill lägga till och ta bort relationer.'),
(83361, 957, 22, 'Vælg kriterier'),
(83362, 962, 22, 'Vælg liste'),
(83363, 965, 22, 'Vælg printformat for denne aftalerapport'),
(83364, 967, 22, 'Kronisk bronkit'),
(83365, 968, 22, 'Kronisk ledvärk'),
(83366, 970, 22, 'Kronisk synovit / effusion / ledvärk / gikt'),
(83367, 971, 22, 'Kronisk / Återkommande'),
(83368, 973, 22, 'Leverciros'),
(83369, 974, 22, 'Levercirros'),
(83370, 975, 22, 'By'),
(83371, 976, 22, 'Bynavn'),
(83372, 977, 22, 'By, stat'),
(83373, 978, 22, 'By, postnummer'),
(83374, 979, 22, 'By'),
(83375, 980, 22, 'Krav'),
(83376, 981, 22, 'Påstå '),
(83377, 988, 22, 'Klassificering'),
(83378, 989, 22, 'Tøm'),
(83379, 991, 22, 'Slet alt'),
(83380, 993, 22, 'Tøm justering'),
(83381, 994, 22, 'Rensa Smarty Cache'),
(83382, 996, 22, 'CLIA Antal'),
(83383, 997, 22, 'Klik'),
(83384, 1001, 22, 'Klik for mere'),
(83385, 1005, 22, 'Tryk her'),
(83386, 1006, 22, 'Tryk her for at tilføje ny patient'),
(83387, 1008, 22, 'Tryk her for at vælge en dato'),
(83388, 1009, 22, 'Tryk her for at vælge dato og tidspunkt'),
(83389, 1010, 22, 'Tryk her for at vælge startdato'),
(83390, 1020, 22, 'tryk her for at søge'),
(83391, 1021, 22, 'Klicka här för att uppdatera prioritet, kategori och smeknamn inställningar'),
(83392, 1022, 22, 'Tryk her for at se alle'),
(83393, 1026, 22, 'Tryk her for at se patientdetaljer'),
(83394, 1027, 22, 'Tryk her for at se dem alle'),
(83395, 1035, 22, 'Tryk for at oprette en ny konsultation'),
(83396, 1037, 22, 'Tryk for at downloade'),
(83397, 1038, 22, 'Tryk for at ændre'),
(83398, 1040, 22, 'Tryk for at ændre denne begivenhed'),
(83399, 1041, 22, 'Tryk for at generere rapporten'),
(83400, 1043, 22, 'Tryk for at printe'),
(83401, 1044, 22, 'Klicka för att lägga till/få ny lot'),
(83402, 1045, 22, 'Tryk for at vælge'),
(83403, 1046, 22, 'Tryk for at vælge'),
(83404, 1051, 22, 'Tryk for at vælge eller ændre diagnose'),
(83405, 1053, 22, 'Tryk for at vælge patient'),
(83406, 1054, 22, 'Tryk for at vælge en relateret kode'),
(83407, 1056, 22, 'Tryk for at vælge den ønskede procedure'),
(83408, 1058, 22, 'Tryk for at se'),
(83409, 1059, 22, 'Tryk for at se eller ændre'),
(83410, 1060, 22, 'Tryk for at se/ændre'),
(83411, 1063, 22, 'Tryk:'),
(83412, 1067, 22, 'Patientkopi'),
(83413, 1069, 22, 'Annamnese'),
(83414, 1072, 22, 'Klientprofil - Ny Klient'),
(83415, 1073, 22, 'Klientprofil - Unika klienter'),
(83416, 1074, 22, 'patienter'),
(83417, 1075, 22, 'Klinik'),
(83418, 1076, 22, 'Klinikkopi'),
(83419, 1077, 22, 'Kliniken Daily Record'),
(83420, 1078, 22, 'Klinik ID'),
(83421, 1079, 22, 'klinisk'),
(83422, 1083, 22, 'Kliniske planer'),
(83423, 1087, 22, 'Kliniske påmindelser'),
(83424, 1088, 22, 'kliniske rapporter'),
(83425, 1093, 22, 'Kliniske regler'),
(83426, 1106, 22, 'Klinikmedverkande'),
(83427, 1109, 22, 'Luk'),
(83428, 1111, 22, 'Luk vinduet'),
(83429, 1112, 22, 'Lukket'),
(83430, 1113, 22, 'cm'),
(83431, 1118, 22, 'CMS-id'),
(83432, 1127, 22, 'CN2-12 intakta'),
(83433, 1131, 22, 'Kode'),
(83434, 1132, 22, 'kode'),
(83435, 1133, 22, 'kodesøger'),
(83436, 1134, 22, 'Kode skal være mindre end 2 bogstaver'),
(83437, 1135, 22, 'kode eller tegn for at indikere kurs'),
(83438, 1136, 22, 'Kodetekst'),
(83439, 1138, 22, 'Kodetype'),
(83440, 1141, 22, 'Kodetype'),
(83441, 1144, 22, 'Koder'),
(83442, 1145, 22, 'Kodning'),
(83443, 1147, 22, 'Coding - any encounters (write,wsome optional)'),
(83444, 1148, 22, 'Coding - my encounters (write,wsome optional)'),
(83445, 1149, 22, 'Kodning ikke tilladt'),
(83446, 1150, 22, 'Kaffe'),
(83447, 1153, 22, 'Förf.saml w / o'),
(83448, 1154, 22, 'Kolaps'),
(83449, 1155, 22, 'kolaps'),
(83450, 1156, 22, 'Kolaps alle'),
(83451, 1157, 22, 'Kolaps alle'),
(83452, 1158, 22, 'Kolaps alle'),
(83453, 1161, 22, 'Samlinger'),
(83454, 1162, 22, 'Samlingsrapport'),
(83455, 1163, 22, 'Koloncancer'),
(83456, 1165, 22, 'Koloncancer Kirurgi'),
(83457, 1166, 22, 'Kolonoskopi'),
(83458, 1167, 22, 'kolonoskopi'),
(83459, 1168, 22, 'Farve'),
(83460, 1170, 22, 'Kolonne'),
(83461, 1171, 22, 'kolonner'),
(83462, 1173, 22, 'Komma'),
(83463, 1174, 22, 'Kommentar'),
(83464, 1175, 22, 'Kommentarer'),
(83465, 1176, 22, 'kommentarer til dette resultat eller anbefaling'),
(83466, 1177, 22, 'Commercial Insurance Co'),
(83467, 1178, 22, 'godkend ændringer'),
(83468, 1180, 22, 'Kommunikation'),
(83469, 1182, 22, 'Firma'),
(83470, 1183, 22, 'Firmanavn'),
(83471, 1184, 22, 'Komplet'),
(83472, 1186, 22, 'Afsluttet'),
(83473, 1188, 22, 'Afsluttet?'),
(83474, 1190, 22, 'Komplikationer ved serviceudbyder'),
(83475, 1191, 22, 'Problemer ved lukning'),
(83476, 1192, 22, 'komponenter'),
(83477, 1193, 22, 'Datorstödd Medical Ordering System'),
(83478, 1194, 22, 'Konklussioner'),
(83479, 1199, 22, 'konfiguration'),
(83480, 1208, 22, 'Bekræft Ny Patient'),
(83481, 1209, 22, 'Bekræft Nyt Kodeord'),
(83482, 1210, 22, 'Bekræft Betaling'),
(83483, 1214, 22, 'Kongenital'),
(83484, 1215, 22, 'Conjuntiva, elever'),
(83485, 1218, 22, 'Konstant'),
(83486, 1219, 22, 'konstantnavn'),
(83487, 1220, 22, 'konstantnavn er sort'),
(83488, 1221, 22, 'Konstanter'),
(83489, 1222, 22, 'Förstoppning'),
(83490, 1223, 22, 'Konstitutionella'),
(83491, 1226, 22, 'Konsultation, kort beskrivelse'),
(83492, 1227, 22, 'Kontakt'),
(83493, 1228, 22, 'kontakt email'),
(83494, 1229, 22, 'Kontak E-mail'),
(83495, 1231, 22, 'Kontaktinformation'),
(83496, 1232, 22, 'Kontaktlinser'),
(83497, 1236, 22, 'kontaktnavn'),
(83498, 1237, 22, 'Kontaktperson'),
(83499, 1239, 22, 'Kontakttelefonnummer'),
(83500, 1241, 22, 'indehold mindst tre af fire følgende ting'),
(83501, 1243, 22, 'Indhold'),
(83502, 1244, 22, 'Indhold'),
(83503, 1245, 22, 'Sammenhæng'),
(83504, 1246, 22, 'Sammenhæng navn kan ikke tømmes'),
(83505, 1247, 22, 'Fortsæt'),
(83506, 1250, 22, 'kontraindikationer'),
(83507, 1251, 22, 'Preventivmedel'),
(83508, 1252, 22, 'Preventivmedelsproblematik'),
(83509, 1253, 22, 'Preventivmedelsproblematik (specificera)'),
(83510, 1254, 22, 'Preventivmedel Metod'),
(83511, 1256, 22, 'Preventivmedel, tjänster som tidigare startats'),
(83512, 1257, 22, 'Preventivmedel start'),
(83513, 1258, 22, 'Kontrol ID'),
(83514, 1259, 22, 'Kontrollnum.'),
(83515, 1262, 22, 'Medbetaler'),
(83516, 1263, 22, 'Medbetaler');
INSERT INTO `lang_definitions` VALUES
(83517, 1266, 22, 'Medbetalare'),
(83518, 1267, 22, 'COPD'),
(83519, 1268, 22, 'Kopiera Sidor till Patientdiagram'),
(83520, 1269, 22, 'Kopier værdier'),
(83521, 1270, 22, 'Kopier databasen, Dette kan tage lang tid'),
(83522, 1271, 22, 'Ophavsret'),
(83523, 1273, 22, 'Coronary Artery Bypass'),
(83524, 1275, 22, 'Korrigeret'),
(83525, 1289, 22, 'Hoste'),
(83526, 1290, 22, 'Hoste'),
(83527, 1294, 22, 'Kunne ikke læse fil'),
(83528, 1296, 22, 'Kunne ikke sende email pga. problemer med serveren '),
(83529, 1298, 22, 'kunne ikke oprette backup dir:'),
(83530, 1299, 22, 'Kunne ikke fjerne dir:'),
(83531, 1300, 22, 'Kunne ikke fjerne gammel backupfil'),
(83532, 1301, 22, 'Kunne ikke fjerne gamle exporteret fil'),
(83533, 1303, 22, 'Couns av metod'),
(83534, 1304, 22, 'Rådgivning'),
(83535, 1305, 22, 'Rådgivning, Aktivitet'),
(83536, 1306, 22, 'svarsremiss, formulär'),
(83537, 1307, 22, 'Remisssvar'),
(83538, 1308, 22, 'Land'),
(83539, 1310, 22, 'Land, liste'),
(83540, 1311, 22, 'Land, Lista'),
(83541, 1313, 22, 'Amt'),
(83542, 1315, 22, 'kuppon'),
(83543, 1318, 22, 'CPT'),
(83544, 1320, 22, 'CPT Koder'),
(83545, 1324, 22, 'Sprickor:'),
(83546, 1325, 22, 'creme'),
(83547, 1329, 22, 'Opret en begivenhed'),
(83548, 1330, 22, 'Opret og download fuld backup'),
(83549, 1332, 22, 'Opret backup'),
(83550, 1336, 22, 'Opret kopi'),
(83551, 1339, 22, 'Opret nyt emne'),
(83552, 1340, 22, 'Opret ny patient'),
(83553, 1344, 22, 'Opret patient note'),
(83554, 1346, 22, 'Opret aftale'),
(83555, 1347, 22, 'Oprettet'),
(83556, 1348, 22, 'Opretter export fil'),
(83557, 1351, 22, 'Opretter'),
(83558, 1352, 22, 'kredit'),
(83559, 1353, 22, 'Kreditkort'),
(83560, 1354, 22, 'Kredit'),
(83561, 1356, 22, 'Kriterier'),
(83562, 1358, 22, 'Crohn''s sjukdom'),
(83563, 1359, 22, 'Chrons sjukdom'),
(83564, 1361, 22, 'Csv-fil'),
(83565, 1369, 22, 'Nuværende'),
(83566, 1371, 22, 'Nuværende konsultation'),
(83567, 1372, 22, 'Nuværende kriterier'),
(83568, 1373, 22, 'Aktuel dag i farve'),
(83569, 1375, 22, 'Nuværende filnavn er ændret til'),
(83570, 1377, 22, 'Nuværende lokation'),
(83571, 1379, 22, 'Nuværende kodeord'),
(83572, 1380, 22, 'Nuværende patient'),
(83573, 1386, 22, 'Nuværende aktiv'),
(83574, 1389, 22, 'Cushing Syndrom'),
(83575, 1390, 22, 'Cushings syndrom'),
(83576, 1392, 22, 'Custom'),
(83577, 1400, 22, 'CYP'),
(83578, 1401, 22, 'CYP Factor'),
(83579, 1402, 22, 'CYP Rapport'),
(83580, 1404, 22, 'D'),
(83581, 1405, 22, 'D & C'),
(83582, 1406, 22, 'D & E'),
(83583, 1407, 22, 'Fødselsdag'),
(83584, 1408, 22, 'Daglig'),
(83585, 1409, 22, 'Daglig optegnelse'),
(83586, 1410, 22, 'dansk'),
(83587, 1411, 22, 'Lignende data er allerede registreret. Skift kode eller beskrivelse'),
(83588, 1412, 22, 'Lignende data er allerede registreret. Skift navn på konstant'),
(83589, 1413, 22, 'Data kolonner'),
(83590, 1420, 22, 'Datatype'),
(83591, 1421, 22, 'Database'),
(83592, 1422, 22, 'Databasen er ikke installeret'),
(83593, 1424, 22, 'Databaserapportering'),
(83594, 1425, 22, 'Opgradering af database er afsluttet'),
(83595, 1426, 22, 'Datacols måste ha ett nummer mellan 1 och 999'),
(83596, 1427, 22, 'Dato'),
(83597, 1428, 22, 'dato'),
(83598, 1431, 22, 'Administreringsdato'),
(83599, 1432, 22, 'Prøvedato og tid'),
(83600, 1435, 22, 'Prøvedato og tid'),
(83601, 1436, 22, 'Dato kan ikke være senere end i dag'),
(83602, 1437, 22, 'Datum då preventivmeddel insattes för första gången'),
(83603, 1438, 22, 'Dato oprettet'),
(83604, 1439, 22, 'Dødsdato'),
(83605, 1440, 22, 'Ødelæggelsesdato'),
(83606, 1441, 22, 'Vis datoformat'),
(83607, 1442, 22, 'Datoformat for "aftale slut" er ikke gyldig'),
(83608, 1443, 22, 'Datoformat for "aftale start" er ikke gyldig'),
(83609, 1444, 22, 'Datoformat for "næste aftale" er ikke gyldig'),
(83610, 1445, 22, 'Datoformat for "ikke set siden" er ikke gyldig'),
(83611, 1446, 22, 'Datoformat for "seneste aftale" er ikke gyldig'),
(83612, 1447, 22, 'Datum för vaccinationsinformation'),
(83613, 1448, 22, 'Koden mangler dato '),
(83614, 1450, 22, 'Dato for bankindbetaling åååå-mm-dd'),
(83615, 1452, 22, 'Fødselsdag'),
(83616, 1453, 22, 'Fødselsdag'),
(83617, 1454, 22, 'Fødselsdag'),
(83618, 1456, 22, 'Dato for skade'),
(83619, 1458, 22, 'Dato for betaling åååå-mm-dd'),
(83620, 1459, 22, 'Henvisningsdato'),
(83621, 1460, 22, 'Svardato'),
(83622, 1463, 22, 'Dato for service'),
(83623, 1464, 22, 'Dato for service = I dag'),
(83624, 1465, 22, 'Dato for service MM / DD / ÅÅÅÅ'),
(83625, 1466, 22, 'Dato for service'),
(83626, 1467, 22, 'Underskriftsdato'),
(83627, 1469, 22, 'Ordredato'),
(83628, 1470, 22, 'Rapportdato'),
(83629, 1471, 22, 'Ej tilldelad'),
(83630, 1472, 22, 'Ordredato'),
(83631, 1475, 22, 'Datovælger'),
(83632, 1476, 22, 'Afsendelsesdato'),
(83633, 1479, 22, 'Datofelter kan ikke være tomme'),
(83634, 1480, 22, 'Dato / aftale'),
(83635, 1481, 22, 'Dato / Noter'),
(83636, 1482, 22, 'Seneste dato/noter'),
(83637, 1483, 22, 'Dato / tid'),
(83638, 1484, 22, 'Dato:'),
(83639, 1486, 22, 'Dag'),
(83640, 1487, 22, 'Dag'),
(83641, 1489, 22, 'dagsoversigt'),
(83642, 1490, 22, 'Dag(e)'),
(83643, 1491, 22, 'Dag(e) man-fre'),
(83644, 1492, 22, 'Dage'),
(83645, 1493, 22, 'Dage'),
(83646, 1494, 22, 'dage siden'),
(83647, 1495, 22, 'Dagar och spel Missade'),
(83648, 1496, 22, 'dage siden sidste aftale'),
(83649, 1498, 22, 'dage per kolonne'),
(83650, 1500, 22, 'dage / kolonne'),
(83651, 1501, 22, 'DB installeret'),
(83652, 1502, 22, 'DD/MM/ÅÅÅÅ'),
(83653, 1509, 22, 'DEA'),
(83654, 1512, 22, 'Debuginformation'),
(83655, 1515, 22, 'dec'),
(83656, 1516, 22, 'Afdød'),
(83657, 1517, 22, 'december'),
(83658, 1520, 22, 'Fratrække'),
(83659, 1522, 22, 'Standard'),
(83660, 1523, 22, 'Standard kalender opslag'),
(83661, 1526, 22, 'Standard Klinik'),
(83662, 1527, 22, 'Standard sprog'),
(83663, 1528, 22, 'Standart sprog hvis ikke andet er tilladt eller valgt'),
(83664, 1529, 22, 'Standardliste'),
(83665, 1530, 22, 'Standardmetode'),
(83666, 1531, 22, 'Standartudløbsdato for kodeord'),
(83667, 1536, 22, 'Standardbehandler'),
(83668, 1537, 22, 'Standardomfang'),
(83669, 1540, 22, 'Standardindstilling'),
(83670, 1546, 22, 'Standardenhed'),
(83671, 1547, 22, 'Standardværdi'),
(83672, 1549, 22, 'Standard X12 Partner'),
(83673, 1550, 22, 'Default / Global'),
(83674, 1551, 22, 'Slet'),
(83675, 1552, 22, 'slet'),
(83676, 1553, 22, 'Fördröjd Återkommande (> 12 mån)'),
(83677, 1554, 22, 'Slet'),
(83678, 1555, 22, 'Slet'),
(83679, 1556, 22, 'Slet kategorier med disse ID(er): '),
(83680, 1557, 22, 'Slet kategori'),
(83681, 1560, 22, 'Slet gruppe'),
(83682, 1561, 22, 'Slet liste'),
(83683, 1562, 22, 'Slet sider'),
(83684, 1563, 22, 'Slet patient, aftaler, form, emner, dokument, betaling, fakturering eller transaktion'),
(83685, 1565, 22, 'Slet række'),
(83686, 1566, 22, 'Slet valgte'),
(83687, 1568, 22, 'Slettelse afsluttet'),
(83688, 1569, 22, 'Slet dette dokument'),
(83689, 1570, 22, 'Slet denne formular'),
(83690, 1571, 22, 'Slet denne note'),
(83691, 1573, 22, 'Slettelse afsluttet'),
(83692, 1581, 22, 'Demens'),
(83693, 1582, 22, 'Demografi'),
(83694, 1583, 22, 'Demografi'),
(83695, 1586, 22, 'Demografi ej auktoriserad'),
(83696, 1587, 22, 'Demografi ej auktoriserad'),
(83697, 1590, 22, 'Dental'),
(83698, 1592, 22, 'Dentale problemer'),
(83699, 1596, 22, 'Betalingsdato'),
(83700, 1598, 22, 'Betalingsdato'),
(83701, 1599, 22, 'Deprimeret'),
(83702, 1600, 22, 'Depression'),
(83703, 1602, 22, 'Beskrivelse'),
(83704, 1603, 22, 'beskrivelse'),
(83705, 1607, 22, 'Oversat beskrivelse'),
(83706, 1609, 22, 'Mål'),
(83707, 1610, 22, 'Destination filnavn'),
(83708, 1611, 22, 'Ødelagt Lot'),
(83709, 1612, 22, 'Ødelæg'),
(83710, 1613, 22, 'Ødelagt'),
(83711, 1614, 22, 'Ødelagte medikamenter'),
(83712, 1615, 22, 'Förstöras narkotika Rapport'),
(83713, 1616, 22, 'Detalje'),
(83714, 1617, 22, 'Detaljer'),
(83715, 1619, 22, 'Utvecklingstoxicitet abnormalitet'),
(83716, 1620, 22, 'Diabetes'),
(83717, 1631, 22, 'Diag'),
(83718, 1633, 22, 'Diagnose'),
(83719, 1634, 22, 'Diagnose kode'),
(83720, 1636, 22, 'Daiagnose dato'),
(83721, 1637, 22, 'Diagnos måste kodas in i ett länkat patientmöte'),
(83722, 1638, 22, 'Diagnose navn'),
(83723, 1639, 22, 'Diagnose rapport'),
(83724, 1642, 22, 'Diagnose titel'),
(83725, 1643, 22, 'Diagnose:'),
(83726, 1644, 22, 'Diagnose: '),
(83727, 1645, 22, 'Diagnose test'),
(83728, 1646, 22, 'Dials'),
(83729, 1648, 22, 'Diarée'),
(83730, 1650, 22, 'Diktat'),
(83731, 1651, 22, 'Diktat: '),
(83732, 1652, 22, 'Fick du en kopia av denna HIPAA notering?'),
(83733, 1653, 22, 'Diffus'),
(83734, 1654, 22, 'Elektronisk underskrift'),
(83735, 1657, 22, 'Direkte mail'),
(83736, 1665, 22, 'Handicap'),
(83737, 1667, 22, 'Deaktiver kalender'),
(83738, 1675, 22, 'handicappet'),
(83739, 1676, 22, 'Handiccapet'),
(83740, 1678, 22, 'DISC'),
(83741, 1681, 22, 'Udskrive'),
(83742, 1682, 22, 'Flytningar från urinröret'),
(83743, 1689, 22, 'Videregive info'),
(83744, 1694, 22, 'Rabat'),
(83745, 1695, 22, 'Rabat beløb'),
(83746, 1696, 22, 'Rabat nivaue'),
(83747, 1701, 22, 'Sygdom'),
(83748, 1702, 22, 'Forskydning'),
(83749, 1703, 22, 'Antal:'),
(83750, 1704, 22, 'Afsendelse'),
(83751, 1705, 22, 'Afsendt modtagne dokumenter'),
(83752, 1706, 22, 'Dispenseras'),
(83753, 1709, 22, 'Vis dato for begivenheder i blokke?'),
(83754, 1711, 22, 'Hvor mange begivenheder skal vises?'),
(83755, 1713, 22, 'Vis lokationer i blokke?'),
(83756, 1714, 22, 'Vis navn'),
(83757, 1715, 22, 'Vis kalender?'),
(83758, 1718, 22, 'Vis dagens begivenheder i blokken?'),
(83759, 1719, 22, 'Vis emne i blokke?'),
(83760, 1720, 22, 'Vis kommende begivenheder i blokke?'),
(83761, 1721, 22, 'Vis kolonner'),
(83762, 1725, 22, 'Distrubition'),
(83763, 1729, 22, 'Divertikulit'),
(83764, 1730, 22, 'Diverticulitis Kirurgi'),
(83765, 1731, 22, 'Divertikulit'),
(83766, 1732, 22, 'Divertikulit Kirurgi'),
(83767, 1733, 22, 'Skilt'),
(83768, 1734, 22, 'Svimmelhed'),
(83769, 1735, 22, 'Må ikke ændres'),
(83770, 1742, 22, 'Vis ikke kalenderen'),
(83771, 1747, 22, 'Må ikke gemmes'),
(83772, 1748, 22, 'Må ikke erstattes'),
(83773, 1749, 22, 'Gør intet'),
(83774, 1751, 22, 'Er du sikker på du vil slette?'),
(83775, 1752, 22, 'Er du sikker på du vil slette det valgte?'),
(83776, 1753, 22, 'Vil du virkelig slette dene gruppe?'),
(83777, 1755, 22, 'Vil du fortsætte?'),
(83778, 1756, 22, 'Vil du slette dette?'),
(83779, 1757, 22, 'Vil du slette?'),
(83780, 1758, 22, 'Vil du fjerne denne optagelse?'),
(83781, 1759, 22, 'Vil du fortsætte tilføjelsen af denne patient'),
(83782, 1760, 22, 'Vil du fortsætte med det nye navn?'),
(83783, 1762, 22, 'Fødselsdato'),
(83784, 1763, 22, 'Fødseldato mangler, udfyld hvis mulig'),
(83785, 1764, 22, 'Dokument'),
(83786, 1765, 22, 'Læge'),
(83787, 1766, 22, 'Læge:'),
(83788, 1767, 22, 'Læges navn og underskrift'),
(83789, 1768, 22, 'Dokument'),
(83790, 1769, 22, 'dokument'),
(83791, 1770, 22, 'Dokument Kategorier'),
(83792, 1775, 22, 'Dokumentet kunne ikke flyttes til Patient ID'),
(83793, 1777, 22, 'Dokument dato'),
(83794, 1778, 22, 'Dokumentets datum och utförande uppdaterats'),
(83795, 1780, 22, 'Dokumentet er flyttet til ny kategori'),
(83796, 1781, 22, 'Dokumentet er flyttet til patient ID'),
(83797, 1785, 22, 'Dokumentet er gendøbt'),
(83798, 1790, 22, 'Dokument/billede lager'),
(83799, 1791, 22, 'Dokumenter'),
(83800, 1794, 22, 'DOE'),
(83801, 1799, 22, 'Indenlandsk partner'),
(83802, 1800, 22, 'Gem ikke'),
(83803, 1801, 22, 'Gem ikke'),
(83804, 1802, 22, 'Gem ikke ændringer'),
(83805, 1803, 22, 'Færdig'),
(83806, 1804, 22, 'Klar med:'),
(83807, 1805, 22, 'Færdig. Sender nu download'),
(83808, 1806, 22, 'DOS'),
(83809, 1807, 22, 'Dosering'),
(83810, 1809, 22, 'Dobbeltklik for at ændre'),
(83811, 1810, 22, 'Dubbelseende'),
(83812, 1811, 22, 'Download'),
(83813, 1814, 22, 'Dowload alligevel'),
(83814, 1817, 22, 'Download certifikater'),
(83815, 1828, 22, 'læge kontrol'),
(83816, 1829, 22, 'lægebesøg'),
(83817, 1830, 22, 'Dr.'),
(83818, 1831, 22, 'Træk for at flytte'),
(83819, 1833, 22, 'kørekortnummer'),
(83820, 1834, 22, 'lægemiddel'),
(83821, 1836, 22, 'Läkemedelsformulär'),
(83822, 1837, 22, 'Läkemeddels ID saknas!'),
(83823, 1838, 22, 'Läkemedel intervall'),
(83824, 1839, 22, 'Inventarielista, läkemedel'),
(83825, 1840, 22, 'Läkemedelsnamn'),
(83826, 1841, 22, 'Läkemedelslinje/väg'),
(83827, 1845, 22, 'Läkemedel, enheter'),
(83828, 1846, 22, 'medikamenter'),
(83829, 1847, 22, 'medicin og produkter'),
(83830, 1848, 22, 'Mundtørhed'),
(83831, 1850, 22, 'DT 1'),
(83832, 1851, 22, 'DT 2'),
(83833, 1852, 22, 'DT 3'),
(83834, 1853, 22, 'DT 4'),
(83835, 1854, 22, 'DT 5'),
(83836, 1855, 22, 'DTaP 1'),
(83837, 1856, 22, 'DTaP 2'),
(83838, 1857, 22, 'DTaP 3'),
(83839, 1858, 22, 'DTaP 4'),
(83840, 1859, 22, 'DTaP 5'),
(83841, 1861, 22, 'Forfaldsdato'),
(83842, 1862, 22, 'Forfaldsdato mm/dd/åååå el. åååå/mm/dd'),
(83843, 1863, 22, 'Forfaldsdato'),
(83844, 1866, 22, 'Forfald snart'),
(83845, 1867, 22, 'Forfald status'),
(83846, 1868, 22, 'Forfald status opdatering'),
(83847, 1869, 22, 'Dumping LibreEHR database'),
(83848, 1870, 22, 'Dumping LibreEHR web directory tree'),
(83849, 1871, 22, 'Dumping phpGACL database'),
(83850, 1872, 22, 'Dumping phpGACL web directory tree'),
(83851, 1873, 22, 'Dumping SQL-Ledger database'),
(83852, 1874, 22, 'Dumping SQL-Ledger web directory tree'),
(83853, 1878, 22, 'KOPI ADVARSEL'),
(83854, 1880, 22, 'varighed'),
(83855, 1881, 22, 'varighed'),
(83856, 1882, 22, 'Holländsk'),
(83857, 1884, 22, 'Dysphagi'),
(83858, 1885, 22, 'Dyspné:'),
(83859, 1886, 22, 'Dysuria'),
(83860, 1888, 22, 'E-recept?'),
(83861, 1894, 22, 'Tidig Återkommande (<2 Mo)'),
(83862, 1895, 22, 'Ører'),
(83863, 1896, 22, 'EKG'),
(83864, 1898, 22, 'Ødem'),
(83865, 1904, 22, 'Rediger'),
(83866, 1905, 22, 'rediger'),
(83867, 1906, 22, 'Rediger allergier'),
(83868, 1907, 22, 'Rediger kategorier'),
(83869, 1908, 22, 'Rediger definitioner'),
(83870, 1909, 22, 'Rediger definitioner'),
(83871, 1910, 22, 'Rediger diagnose for'),
(83872, 1911, 22, 'Rediger videresendelse'),
(83873, 1912, 22, 'Rediger kliniker'),
(83874, 1913, 22, 'Rediger kliniker'),
(83875, 1914, 22, 'Rediger klinikinformation'),
(83876, 1916, 22, 'Rediger fil i'),
(83877, 1917, 22, 'Rediger form'),
(83878, 1920, 22, 'Rediger layout'),
(83879, 1921, 22, 'Rediger liste'),
(83880, 1922, 22, 'Rediger betaling'),
(83881, 1923, 22, 'Rediger struktur'),
(83882, 1924, 22, 'Rediger bruger'),
(83883, 1925, 22, 'Rediger bruger-opsætning'),
(83884, 1928, 22, 'Uddannelse'),
(83885, 1929, 22, 'Uddannelsesdato'),
(83886, 1932, 22, 'Dato for ikrafttrædelse'),
(83887, 1934, 22, 'Effektivitet'),
(83888, 1936, 22, 'Ejaculation'),
(83889, 1937, 22, 'Albue'),
(83890, 1938, 22, 'Problemer med albuen'),
(83891, 1939, 22, 'Elektronik'),
(83892, 1942, 22, 'Elektronisk remiss'),
(83893, 1949, 22, 'Email'),
(83894, 1951, 22, 'Emailadresse'),
(83895, 1957, 22, 'Email fra Batchcom'),
(83896, 1958, 22, 'Email'),
(83897, 1961, 22, 'Email sendt før'),
(83898, 1962, 22, 'Email afsender'),
(83899, 1963, 22, 'Email sendt'),
(83900, 1965, 22, 'Email emneord'),
(83901, 1966, 22, 'Email Text, användbara Tag: *** NAMN ***, dvs Bäste *** NAMN ***'),
(83902, 1969, 22, 'Email var sendt til følgende adresse'),
(83903, 1971, 22, 'Akut kontakt'),
(83904, 1972, 22, 'Akut kontaktperson'),
(83905, 1973, 22, 'ICE kontakt telefonnummer'),
(83906, 1974, 22, 'Akut Preventivmedel'),
(83907, 1975, 22, 'Akut Login'),
(83908, 1978, 22, 'Akut Login emailadresse'),
(83909, 1980, 22, 'ICE Telefon'),
(83910, 1982, 22, 'Emfysem'),
(83911, 1983, 22, 'Ansat'),
(83912, 1984, 22, 'Arbejdsgiver'),
(83913, 1985, 22, 'Arbejdsgivers adresse'),
(83914, 1986, 22, 'Arbejdsgiver oplysninger'),
(83915, 1987, 22, 'Arbejdsgivers navn'),
(83916, 1988, 22, 'TØM'),
(83917, 1989, 22, 'Ryd'),
(83918, 1991, 22, 'Ryd værdi i "Email timer"'),
(83919, 1992, 22, 'Ryd værdi i "email afsender"'),
(83920, 1993, 22, 'Ryd værdi i "Email Emne"'),
(83921, 1994, 22, 'Ryd værdi i "Email Tekst"'),
(83922, 1995, 22, 'Ta bort i "Försörjarens namn"'),
(83923, 1996, 22, 'Ryd værdi i "Kodeord"'),
(83924, 1997, 22, 'Ta bort "SMS tider"'),
(83925, 1998, 22, 'Ryd værdi i "SMS tekst"'),
(83926, 1999, 22, 'Ryd værdi i "Brugernavn"'),
(83927, 2061, 22, 'Aktiver scanner support'),
(83928, 2068, 22, 'Aktiveret'),
(83929, 2071, 22, 'Aftale'),
(83930, 2072, 22, 'Aftale'),
(83931, 2073, 22, 'Aftale'),
(83932, 2074, 22, 'Aftale'),
(83933, 2075, 22, 'Aftale '),
(83934, 2081, 22, 'Aftaledato'),
(83935, 2086, 22, 'Patientmöte formulär'),
(83936, 2088, 22, 'Aftale historik'),
(83937, 2089, 22, 'Aftale ID'),
(83938, 2091, 22, 'Aftale nummer/antal'),
(83939, 2096, 22, 'Aftal kontor besøg'),
(83940, 2110, 22, 'Aftalen var kodet'),
(83941, 2111, 22, 'Aftale'),
(83942, 2113, 22, 'Aftaler'),
(83943, 2115, 22, 'Patientmöte & Formulär'),
(83944, 2116, 22, 'Aftale ikke autoriseret'),
(83945, 2117, 22, 'Aftaler, rapport'),
(83946, 2118, 22, 'Aftaler, afsnit'),
(83947, 2121, 22, 'Slut'),
(83948, 2122, 22, 'Slut (åååå-mm-dd) '),
(83949, 2123, 22, 'Slutdato'),
(83950, 2124, 22, 'Slutdato'),
(83951, 2126, 22, 'Slutdato skal være senere end Statdato'),
(83952, 2127, 22, 'Slutdato:'),
(83953, 2131, 22, 'Sluttid'),
(83954, 2133, 22, 'Tjenesten slutter åååå-mm-dd'),
(83955, 2135, 22, 'Slut-time for dagens kalender-begivenheder'),
(83956, 2137, 22, 'Endokrina'),
(83957, 2138, 22, 'Endoskopi'),
(83958, 2141, 22, 'Engelsk'),
(83959, 2142, 22, 'Engelsk '),
(83960, 2143, 22, 'Engelsk (indien)'),
(83961, 2144, 22, 'Engelsk (standard)'),
(83962, 2147, 22, 'ENT afslut'),
(83963, 2148, 22, 'ENT smerter'),
(83964, 2149, 22, 'Skriv en diagnos kod för att utesluta alla fakturor som inte innehåller det'),
(83965, 2155, 22, 'Indtast medicin'),
(83966, 2159, 22, 'Indtast nøgle'),
(83967, 2165, 22, 'Angiv dine søgekriterier herover'),
(83968, 2168, 22, 'Miljöpåverkan'),
(83969, 2169, 22, 'EOB Data tillträde'),
(83970, 2171, 22, 'EOB Boknings - Instruktioner'),
(83971, 2172, 22, 'EOB Boknings - Faktura'),
(83972, 2173, 22, 'EOB Boknings - Patient Anmärkning'),
(83973, 2174, 22, 'EOB Boknings - Sök'),
(83974, 2176, 22, 'Epilepsi'),
(83975, 2181, 22, 'Slet'),
(83976, 2182, 22, 'Erektion'),
(83977, 2183, 22, 'Fejl'),
(83978, 2188, 22, 'Fejl i valg af "køn"'),
(83979, 2189, 22, 'Fel i "HIPAA" val'),
(83980, 2190, 22, 'Fel i "Process" val'),
(83981, 2191, 22, 'Fel i "SMS Gateway" val'),
(83982, 2192, 22, 'Fel i "Sortera efter" val'),
(83983, 2194, 22, 'Fejl i JA eller NEJ valgmulighed'),
(83984, 2195, 22, 'Fejl i åbningen af uploadet fil til læsning'),
(83985, 2205, 22, 'Fejl i registreringsformen!'),
(83986, 2210, 22, 'Fejl, filen eksisterer ikke'),
(83987, 2211, 22, 'FEJL, ikke muligt at samle data fra serveren'),
(83988, 2216, 22, 'Fejl, ikke muligt at åbne fil'),
(83989, 2219, 22, 'FEL: kunde inte öppna table.sql bruten form?'),
(83990, 2225, 22, 'Fejl i kodeord. Tjek din indtastning'),
(83991, 2226, 22, 'Fejl i kodeord. Tjek din indtastning'),
(83992, 2227, 22, 'Fejl: Filen eksisterer ikke'),
(83993, 2229, 22, 'FEJL: Ikke muligt at kopiere filen'),
(83994, 2235, 22, 'Fejl'),
(83995, 2242, 22, 'Erythema:'),
(83996, 2247, 22, 'Etableret patient'),
(83997, 2250, 22, 'Etnicitet'),
(83998, 2252, 22, 'ETIN'),
(83999, 2253, 22, 'Begivenhed'),
(84000, 2254, 22, 'Begivenhed begynder'),
(84001, 2255, 22, 'Begivenhed kategori'),
(84002, 2256, 22, 'Begivenhed dato'),
(84003, 2257, 22, 'Begivenhed beskrivelse'),
(84004, 2258, 22, 'Begivenhed detaljer'),
(84005, 2259, 22, 'Begivenheden gentages ikke'),
(84006, 2260, 22, 'Begivenhed varighed'),
(84007, 2261, 22, 'Begivenhed, varighed i minutter'),
(84008, 2262, 22, 'Begivenhed, afgift'),
(84009, 2263, 22, 'Event Location'),
(84010, 2264, 22, 'Begivenheden gentages hver'),
(84011, 2265, 22, 'Begivenheden gentages d.'),
(84012, 2266, 22, 'Begivenhed starttid'),
(84013, 2267, 22, 'Begivenhed titel'),
(84014, 2268, 22, 'Begivenhed titel'),
(84015, 2269, 22, 'Begivenhed hjemmeside'),
(84016, 2270, 22, 'Begivenheder'),
(84017, 2271, 22, 'Begivenheder for'),
(84018, 2272, 22, 'Begivenhed åbner i nyt vindue'),
(84019, 2273, 22, 'hver'),
(84020, 2274, 22, 'Hver'),
(84021, 2275, 22, 'Hver tredje time'),
(84022, 2276, 22, 'Hver fjerde time'),
(84023, 2277, 22, 'Hver femte time'),
(84024, 2278, 22, 'Hver sjette time'),
(84025, 2279, 22, 'Hver ottende time'),
(84026, 2280, 22, 'Hver fjerde'),
(84027, 2281, 22, 'Hver anden'),
(84028, 2282, 22, 'Hver tredje'),
(84029, 2283, 22, 'Varje, var andra, var 3:e, etc'),
(84030, 2285, 22, 'Tenta och testresultat'),
(84031, 2286, 22, 'Testresultat'),
(84032, 2289, 22, 'Undersøgelse'),
(84033, 2290, 22, 'Undersøgelse dato'),
(84034, 2291, 22, 'Eksempel'),
(84035, 2292, 22, 'Eksempler'),
(84036, 2293, 22, 'Exams / Tester'),
(84037, 2295, 22, 'Överdrivet rivande'),
(84038, 2300, 22, 'Øvelse'),
(84039, 2301, 22, 'Övningsmönster'),
(84040, 2302, 22, 'Motions mönster'),
(84041, 2304, 22, 'lämna från Administration'),
(84042, 2306, 22, 'Udvide'),
(84043, 2307, 22, 'udvide'),
(84044, 2308, 22, 'Udvid alle'),
(84045, 2311, 22, 'Udvidet view'),
(84046, 2312, 22, 'Förväntad form_mötes.pid att '),
(84047, 2313, 22, 'Utgångsdatum'),
(84048, 2314, 22, 'Utgångsdatum'),
(84049, 2315, 22, 'Udløber i'),
(84050, 2316, 22, 'Udløber i'),
(84051, 2317, 22, 'Exporter'),
(84052, 2318, 22, 'Exportera som CSV'),
(84053, 2327, 22, 'Exportera till CSV'),
(84054, 2328, 22, 'Exportera till externa faktureringssystem'),
(84055, 2329, 22, 'Exponering för andra länder'),
(84056, 2342, 22, 'Extern remiss'),
(84057, 2344, 22, 'Extern remiss?'),
(84058, 2345, 22, 'Externa remisser'),
(84059, 2352, 22, 'Øjne'),
(84060, 2353, 22, 'F'),
(84061, 2356, 22, 'Kliniker'),
(84062, 2357, 22, 'Klinik'),
(84063, 2358, 22, 'klinik'),
(84064, 2359, 22, 'Klinikadm'),
(84065, 2361, 22, 'Klinik kode'),
(84066, 2365, 22, 'Klinik NPI'),
(84067, 2372, 22, 'Klinik:'),
(84068, 2374, 22, 'mislykkedes'),
(84069, 2375, 22, 'Mislykkedes'),
(84070, 2383, 22, 'fejl'),
(84071, 2390, 22, 'Familiehistorie'),
(84072, 2392, 22, 'Familiehistorie'),
(84073, 2394, 22, 'Familie betaling'),
(84074, 2395, 22, 'Familie størrelse'),
(84075, 2400, 22, 'Fader'),
(84076, 2403, 22, 'Fatigue'),
(84077, 2404, 22, 'Fax'),
(84078, 2406, 22, 'Faxnummer'),
(84079, 2408, 22, 'Fax/scan'),
(84080, 2409, 22, 'Fax ind'),
(84081, 2410, 22, 'Fax ud'),
(84082, 2411, 22, 'Funktioner'),
(84083, 2412, 22, 'Feb'),
(84084, 2413, 22, 'Februar'),
(84085, 2415, 22, 'Läkemedel ID'),
(84086, 2417, 22, 'Skatt ID'),
(84087, 2418, 22, 'Afgift'),
(84088, 2419, 22, 'Afgift'),
(84089, 2420, 22, 'Afgiften er ikke tilladt'),
(84090, 2421, 22, 'Afgift blankett'),
(84091, 2423, 22, 'Afgifter'),
(84092, 2424, 22, 'Kvinde'),
(84093, 2425, 22, 'Kvinde AP'),
(84094, 2427, 22, 'Kvinde G'),
(84095, 2428, 22, 'Kvinde LC'),
(84096, 2429, 22, 'Kvinde P'),
(84097, 2430, 22, 'Kvindelige symptomer'),
(84098, 2431, 22, 'Kvinde VSC'),
(84099, 2434, 22, 'Feber'),
(84100, 2435, 22, 'Feber:'),
(84101, 2447, 22, 'Fil'),
(84102, 2449, 22, 'Fil lokation'),
(84103, 2459, 22, 'Filnavn'),
(84104, 2461, 22, 'Filer'),
(84105, 2463, 22, 'Udfyld en af rækkerne herunder'),
(84106, 2464, 22, 'Udfyld kun her, hvis du vil sende emailnotifikation til patient'),
(84107, 2465, 22, 'Udfyld værdier herunder'),
(84108, 2467, 22, 'Udfyld rækken'),
(84109, 2468, 22, 'Filter'),
(84110, 2473, 22, 'Filter'),
(84111, 2475, 22, 'Endelig diagnose'),
(84112, 2476, 22, 'Endelig diagnose af specialist'),
(84113, 2478, 22, 'Finansielle'),
(84114, 2479, 22, 'Finansiel slutdato (åååå-mm-dd)'),
(84115, 2480, 22, 'Finansiel rapport - hvilken som helst'),
(84116, 2481, 22, 'Finansiel rapport - mine aftaler'),
(84117, 2482, 22, 'Finansiel oversigt dato'),
(84118, 2484, 22, 'Find'),
(84119, 2485, 22, 'Find ledig'),
(84120, 2486, 22, 'Find ledige tider'),
(84121, 2487, 22, 'Find patient'),
(84122, 2489, 22, 'Søgeresultater'),
(84123, 2490, 22, 'Søgeresultater ved specialist'),
(84124, 2491, 22, 'Fin'),
(84125, 2492, 22, 'Afslut betalinger'),
(84126, 2495, 22, 'Første'),
(84127, 2497, 22, 'Første dag i ugen'),
(84128, 2498, 22, 'Fornavn'),
(84129, 2499, 22, 'Fornavn'),
(84130, 2500, 22, 'Fornavn'),
(84131, 2503, 22, 'Fitness'),
(84132, 2507, 22, 'Fitness att spela'),
(84133, 2509, 22, 'Løs dette'),
(84134, 2512, 22, 'Flov'),
(84135, 2514, 22, 'Influenzasæson'),
(84136, 2516, 22, 'Influensavaccination'),
(84137, 2517, 22, 'Vätske-och elektrolyt problem'),
(84138, 2520, 22, 'Følg manuelt'),
(84139, 2522, 22, 'Opfølgning'),
(84140, 2524, 22, 'Opfølgningsgrund'),
(84141, 2526, 22, 'Følgende er et nyt brugerdefineret sprog'),
(84142, 2529, 22, 'Opfølgning sevice'),
(84143, 2531, 22, 'Fødeallergier'),
(84144, 2532, 22, 'Fod'),
(84145, 2533, 22, 'Fodproblemer'),
(84146, 2534, 22, 'Fod:'),
(84147, 2537, 22, 'Fotboll Skaderapport'),
(84148, 2538, 22, 'Skotyp'),
(84149, 2539, 22, 'for'),
(84150, 2540, 22, 'For'),
(84151, 2541, 22, 'For kode'),
(84152, 2543, 22, 'For aftale krav'),
(84153, 2544, 22, 'F.eks.:'),
(84154, 2547, 22, 'Til faktura'),
(84155, 2553, 22, 'For de seneste'),
(84156, 2555, 22, 'for:'),
(84157, 2557, 22, 'Gennemtving Ny Patient'),
(84158, 2559, 22, 'Underarm'),
(84159, 2560, 22, 'Formular'),
(84160, 2561, 22, 'formular'),
(84161, 2564, 22, 'Format'),
(84162, 2565, 22, 'format'),
(84163, 2567, 22, 'Fejlformat for NDC'),
(84164, 2568, 22, 'Formatet plejede at vise de fleste datoer'),
(84165, 2569, 22, 'Formatet plejede at vise de fleste tider'),
(84166, 2570, 22, 'Formateret'),
(84167, 2571, 22, 'Tidligere ryger'),
(84168, 2572, 22, 'Formularer'),
(84169, 2573, 22, 'Formularer administration'),
(84170, 2576, 22, 'Videresend sider via fax'),
(84171, 2577, 22, 'Videresendt'),
(84172, 2579, 22, 'Fjerde'),
(84173, 2581, 22, 'Fraktur'),
(84174, 2582, 22, 'Fracture på Navicula'),
(84175, 2583, 22, 'Fracture laterala malleolus'),
(84176, 2584, 22, 'Fracture mediala malleolus'),
(84177, 2590, 22, 'Frekvens'),
(84178, 2593, 22, 'Fre'),
(84179, 2594, 22, 'Fredag'),
(84180, 2595, 22, 'Fra'),
(84181, 2596, 22, 'FRA'),
(84182, 2597, 22, 'fra'),
(84183, 2598, 22, 'Fra-Dato må ikke være senere end Til-Dato'),
(84184, 2599, 22, 'Fra:'),
(84185, 2600, 22, 'Fra: '),
(84186, 2613, 22, 'Reception'),
(84187, 2614, 22, 'Reception, kvittering'),
(84188, 2615, 22, 'Reception, kvittering rapport'),
(84189, 2617, 22, 'Frontal højre'),
(84190, 2619, 22, 'Fulde navn'),
(84191, 2624, 22, 'Fuld betaling'),
(84192, 2625, 22, 'Fuld træning'),
(84193, 2626, 22, 'Fuldt ud betalt'),
(84194, 2637, 22, 'Gallsten'),
(84195, 2638, 22, 'Game Period'),
(84196, 2639, 22, 'Spil'),
(84197, 2641, 22, 'spel / evenemang'),
(84198, 2644, 22, 'Gastrit'),
(84199, 2646, 22, 'Gastrointestinala'),
(84200, 2647, 22, 'GCAC Statistik Rapport'),
(84201, 2650, 22, 'Køn'),
(84202, 2651, 22, 'Køn '),
(84203, 2652, 22, 'Generelt'),
(84204, 2655, 22, 'Generel service kategori'),
(84205, 2657, 22, 'Opret og download CMS 1500 papir krav'),
(84206, 2658, 22, 'Opret og download HCFA 1500 papir krav'),
(84207, 2659, 22, 'Opret og dowload X12 batch'),
(84208, 2669, 22, 'Opret brev'),
(84209, 2670, 22, 'Opret brev angående '),
(84210, 2677, 22, 'Opret rapport'),
(84211, 2678, 22, 'Opret brugernavn og kodeord for'),
(84212, 2680, 22, 'Opret X12 besøg'),
(84213, 2682, 22, 'Oprettet på'),
(84214, 2683, 22, 'Opretter'),
(84215, 2692, 22, 'Glaukom'),
(84216, 2694, 22, 'Global'),
(84217, 2700, 22, 'gå'),
(84218, 2701, 22, 'Gå'),
(84219, 2704, 22, 'Gå til'),
(84220, 2705, 22, 'Gå til uge nr'),
(84221, 2706, 22, 'Gå til i dag'),
(84222, 2711, 22, 'Grad af skade'),
(84223, 2712, 22, 'Grad:'),
(84224, 2714, 22, 'Tilsammen'),
(84225, 2715, 22, 'Tilsammen'),
(84226, 2720, 22, 'Større end'),
(84227, 2721, 22, 'Større eller lig med'),
(84228, 2724, 22, 'Gruppe'),
(84229, 2725, 22, 'Gruppenavn'),
(84230, 2726, 22, 'Gruppenavne må ikke være blanke'),
(84231, 2727, 22, 'Gruppenavne må ikke starte med tal eller mellemrum'),
(84232, 2728, 22, 'Gruppenavne må ikke starte med tal'),
(84233, 2729, 22, 'Gruppenummer'),
(84234, 2730, 22, 'Gruppebetaling'),
(84235, 2731, 22, 'Gruppe:'),
(84236, 2732, 22, 'Gruppenavn'),
(84237, 2733, 22, 'Grupper og adgangskontroller'),
(84238, 2736, 22, 'Droppar'),
(84239, 2746, 22, 'Hematom / blåmärken'),
(84240, 2750, 22, 'Hånd + fingre'),
(84241, 2751, 22, 'Håndproblemer'),
(84242, 2753, 22, 'Umbäranden w / o'),
(84243, 2755, 22, 'Er udløbet'),
(84244, 2761, 22, 'Farliga aktiviteter'),
(84245, 2767, 22, 'han PostCalendar '),
(84246, 2768, 22, 'Hoved'),
(84247, 2771, 22, 'Hovedpine'),
(84248, 2772, 22, 'Hovedpiner'),
(84249, 2773, 22, 'Helbredsoplysninger'),
(84250, 2774, 22, 'Helbredsoplysninger'),
(84251, 2778, 22, 'Høretab'),
(84252, 2779, 22, 'Hjertetilfælde'),
(84253, 2780, 22, 'Hjertesygdom'),
(84254, 2781, 22, 'Hjärtsvikt'),
(84255, 2782, 22, 'Hjerteproblemer'),
(84256, 2783, 22, 'hjerteproblemer'),
(84257, 2784, 22, 'Hjärtkirurgi'),
(84258, 2785, 22, 'Heart Transplant'),
(84259, 2786, 22, 'Heart:'),
(84260, 2788, 22, 'varm eller kold'),
(84261, 2789, 22, 'varm eller kold'),
(84262, 2794, 22, 'Højde'),
(84263, 2796, 22, 'Hjælp'),
(84264, 2797, 22, 'hjælp'),
(84265, 2802, 22, 'Hemoglobin'),
(84266, 2805, 22, 'Hepatit'),
(84267, 2811, 22, 'Her'),
(84268, 2813, 22, 'Bråck Reparation'),
(84269, 2814, 22, 'Diskbråck'),
(84270, 2815, 22, 'Herpes'),
(84271, 2817, 22, 'heyyo. du har varit här i '),
(84272, 2822, 22, 'Skjulte'),
(84273, 2823, 22, 'Skjulte begivenheder administration'),
(84274, 2824, 22, 'skjul'),
(84275, 2825, 22, 'skjul deltaljer'),
(84276, 2828, 22, 'Skjul menu'),
(84277, 2831, 22, 'Skjul/vis kolonner'),
(84278, 2833, 22, 'Høj'),
(84279, 2834, 22, 'Forhøjet blodtryk'),
(84280, 2836, 22, 'Höft + ljumske'),
(84281, 2837, 22, 'Höft och ljumske'),
(84282, 2838, 22, 'Hip Problem'),
(84283, 2839, 22, 'Höftledsplastik'),
(84284, 2840, 22, 'Ej Tilldelad'),
(84285, 2843, 22, 'Spansktalande'),
(84286, 2847, 22, 'Historie'),
(84287, 2848, 22, 'Historie data'),
(84288, 2849, 22, 'Historie dato'),
(84289, 2862, 22, 'Hold [Ctrl] nede for at vælge eller fravælge flere'),
(84290, 2863, 22, 'Hold Ctrl nede for at vælge flere emner'),
(84291, 2865, 22, 'Hjem'),
(84292, 2866, 22, 'Fastnet'),
(84293, 2867, 22, 'Fastnet'),
(84294, 2868, 22, 'Hjemløs el. lign.'),
(84295, 2872, 22, 'Værtsnavn'),
(84296, 2873, 22, 'Værtsnavn må ikke være tomt'),
(84297, 2875, 22, 'Time'),
(84298, 2876, 22, 'Timer'),
(84299, 2878, 22, 'Hur uppstod skadan?'),
(84300, 2879, 22, 'Hur uppstod skadan?:'),
(84301, 2880, 22, 'Hvor har de hørt om os?'),
(84302, 2881, 22, 'Hur många månader att fråga efter kommande evenemang?'),
(84303, 2892, 22, 'Hyperaktiv'),
(84304, 2896, 22, 'Hyperthyroidism'),
(84305, 2897, 22, 'Hypotyreoidism'),
(84306, 2898, 22, 'Hysterektomi'),
(84307, 2899, 22, 'Jeg'),
(84308, 2900, 22, 'Jeg er optaget i løbet af denne tid'),
(84309, 2901, 22, 'Jeg har ikke tilladelse til at læse '),
(84310, 2914, 22, 'Identificeret som'),
(84311, 2919, 22, 'Hvis al data for denne kolonne er komplet for denne blanket'),
(84312, 2921, 22, 'Hvis indtastet, vælg kun dem der har haft denne service'),
(84313, 2922, 22, 'Hvis navn, en del af efternavn eller efternavn, fornavn'),
(84314, 2923, 22, 'Hvis betaling med'),
(84315, 2924, 22, 'Hvis person er afgået ved døden, indtast da dødsdato'),
(84316, 2927, 22, 'Hvis arbejdsløs eller studerende'),
(84317, 2933, 22, 'Hvis du vil ændre datatype eller tilføje rækker eller kolonner'),
(84318, 2936, 22, 'Ignorer'),
(84319, 2937, 22, 'Sygdom'),
(84320, 2942, 22, 'Vaccinering'),
(84321, 2947, 22, 'Vaccin, Lotnummer'),
(84322, 2948, 22, 'Vaccin, tillverkare'),
(84323, 2953, 22, 'Vaccineringar'),
(84324, 2954, 22, 'Vaccinera'),
(84325, 2956, 22, 'Implantater'),
(84326, 2957, 22, 'Importer'),
(84327, 2964, 22, 'Importer patient'),
(84328, 2965, 22, 'Importera Patientdemografi'),
(84329, 2969, 22, 'Importeret fra regnskab'),
(84330, 2972, 22, 'Forbedret'),
(84331, 2973, 22, 'i'),
(84332, 2974, 22, 'i'),
(84333, 2975, 22, 'I begge øjne'),
(84334, 2976, 22, 'I venstre øje'),
(84335, 2977, 22, 'i næsebor'),
(84336, 2978, 22, 'Arbejder'),
(84337, 2979, 22, 'i højre øre'),
(84338, 2981, 22, 'Inaktiv'),
(84339, 2982, 22, 'Inaktive dage'),
(84340, 2983, 22, 'Indbakke'),
(84341, 2986, 22, 'Inkluder kontrolsum'),
(84342, 2987, 22, 'Inkluder fuldstændig'),
(84343, 2989, 22, 'Inkluder ukategoriserede'),
(84344, 2994, 22, 'Indkomst'),
(84345, 2996, 22, 'Ufuldstændig'),
(84346, 3001, 22, 'Øget'),
(84347, 3002, 22, 'Ansvarsforsikring'),
(84348, 3003, 22, 'Ubestemt'),
(84349, 3005, 22, 'Indikerer abnormalitet'),
(84350, 3006, 22, 'Indikerar om detta problem/frågeställning är aktiv'),
(84351, 3009, 22, 'Trængende patienter'),
(84352, 3010, 22, 'Trængende patienter rapport'),
(84353, 3011, 22, 'Trængende'),
(84354, 3016, 22, 'Ikke-støtteberettigede'),
(84355, 3017, 22, 'Infektion / Abscess'),
(84356, 3018, 22, 'Infektioner'),
(84357, 3019, 22, 'Infert Couns'),
(84358, 3026, 22, 'Info'),
(84359, 3027, 22, 'Info test 1'),
(84360, 3028, 22, 'Info test 2'),
(84361, 3029, 22, 'Info test 3'),
(84362, 3030, 22, 'Info test 4'),
(84363, 3031, 22, 'Info test 5'),
(84364, 3032, 22, 'Info test 6'),
(84365, 3034, 22, 'inhalation'),
(84366, 3035, 22, 'inhalationer'),
(84367, 3037, 22, 'Indledende bruger'),
(84368, 3040, 22, 'Injektion'),
(84369, 3041, 22, 'Skadet legemesdel'),
(84370, 3043, 22, 'Skade'),
(84371, 3044, 22, 'Skademekanism'),
(84372, 3045, 22, 'Skada, översiktsrapport'),
(84373, 3047, 22, 'Skada Typ'),
(84374, 3051, 22, 'Inmatningsfält'),
(84375, 3052, 22, 'INR'),
(84376, 3056, 22, 'Ins juster'),
(84377, 3057, 22, 'Ins paketering'),
(84378, 3061, 22, 'Ins överskjutande'),
(84379, 3063, 22, 'Ins återbetalning'),
(84380, 3064, 22, 'Ins Sammering'),
(84381, 3065, 22, 'Ins1'),
(84382, 3066, 22, 'Ins2'),
(84383, 3067, 22, 'Ins3'),
(84384, 3069, 22, 'Indsæt mislykkedes '),
(84385, 3070, 22, 'Indsæt gamle begivenheder i tabeller'),
(84386, 3072, 22, 'Insomnia'),
(84387, 3074, 22, 'Inspektion'),
(84388, 3075, 22, 'Instabilitet / subluxation'),
(84389, 3077, 22, 'Installer'),
(84390, 3079, 22, 'Installer DB'),
(84391, 3081, 22, 'Instrueret'),
(84392, 3082, 22, 'Instruktion'),
(84393, 3084, 22, 'Instruktioner:'),
(84394, 3086, 22, 'Insulinberoende diabetiker'),
(84395, 3087, 22, 'Forsikring'),
(84396, 3088, 22, 'Forsikring'),
(84397, 3094, 22, 'Fosikringsselskaber'),
(84398, 3095, 22, 'Forsikringsselskab'),
(84399, 3096, 22, 'Forsikringsselskab søg/tilføj'),
(84400, 3098, 22, 'Forsikring data'),
(84401, 3100, 22, 'Forsikringsnummer'),
(84402, 3101, 22, 'Forsikringsbetaling'),
(84403, 3103, 22, 'Forsikringsudbyder'),
(84404, 3113, 22, 'Internt fel - inga sidor valdes!'),
(84405, 3114, 22, 'Internt fel - patient-ID fanns inte!'),
(84406, 3116, 22, 'Intern fejl!'),
(84407, 3119, 22, 'Intern fejl: krav '),
(84408, 3120, 22, 'Intern fejl: aftale'),
(84409, 3126, 22, 'Inre Övergångar'),
(84410, 3129, 22, 'Tolk'),
(84411, 3130, 22, 'Tolk nødvendig?'),
(84412, 3131, 22, 'Interstitiell lungsjukdom'),
(84413, 3132, 22, 'Interval'),
(84414, 3135, 22, 'Indgreb'),
(84415, 3137, 22, 'Intolerance'),
(84416, 3139, 22, 'intramuskulärt'),
(84417, 3140, 22, 'intravenöst'),
(84418, 3141, 22, 'Introduktion'),
(84419, 3149, 22, 'Ogiltig eller saknas betalaren i källan för kod '),
(84420, 3151, 22, 'Ogiltig Service Kod'),
(84421, 3152, 22, 'Ogiltig källdestination"'),
(84422, 3155, 22, 'Opgørelse'),
(84423, 3159, 22, 'Inventering är inte tillgänglig för denna beställning.'),
(84424, 3160, 22, 'Inventar liste'),
(84425, 3162, 22, 'Faktura'),
(84426, 3163, 22, 'faktura'),
(84427, 3166, 22, 'Fakturadato'),
(84428, 3167, 22, 'Faktura har ingen dato!'),
(84429, 3168, 22, 'Fakturanummer'),
(84430, 3169, 22, 'Faktura refenrencenummer'),
(84431, 3173, 22, 'Faktura:'),
(84432, 3185, 22, 'Oregelbunden hjärtrytm'),
(84433, 3186, 22, 'Retlighet'),
(84434, 3187, 22, 'Irritation'),
(84435, 3191, 22, 'Er et obligatiorisk felt'),
(84436, 3197, 22, 'inte är giltig (decimalbråk är OK).'),
(84437, 3198, 22, 'Är PHP använder felsäkert läge?'),
(84438, 3201, 22, 'Skal teksten fra listen oversættes?'),
(84439, 3214, 22, 'er for lang'),
(84440, 3216, 22, 'spørgsmål'),
(84441, 3217, 22, 'spørgsmål'),
(84442, 3223, 22, 'Aktuellt'),
(84443, 3225, 22, 'Aktuellt (Problem / Medicin / Allergi):'),
(84444, 3226, 22, 'Information och Patientmöten'),
(84445, 3227, 22, 'Information och möten för'),
(84446, 3228, 22, 'Problematik, ej behörig'),
(84447, 3229, 22, 'Frågeställningssektion'),
(84448, 3231, 22, 'Artikel'),
(84449, 3232, 22, 'artikel'),
(84450, 3238, 22, 'Jan'),
(84451, 3239, 22, 'Januar'),
(84452, 3243, 22, 'Jobbeskrivelse'),
(84453, 3244, 22, 'Job ID'),
(84454, 3245, 22, 'Led dislokation'),
(84455, 3246, 22, 'Ledsmerter'),
(84456, 3247, 22, 'Led vrickning'),
(84457, 3248, 22, 'Jul'),
(84458, 3249, 22, 'Juli'),
(84459, 3250, 22, 'Jun'),
(84460, 3251, 22, 'Juni'),
(84461, 3253, 22, 'Bare min'),
(84462, 3258, 22, 'k, her er resten'),
(84463, 3265, 22, 'Nøgleord'),
(84464, 3266, 22, 'kg'),
(84465, 3269, 22, 'Njurcancer'),
(84466, 3270, 22, 'Njursvikt'),
(84467, 3271, 22, 'Njure Infektioner'),
(84468, 3272, 22, 'Njursten'),
(84469, 3273, 22, 'Njurtransplantation'),
(84470, 3277, 22, 'knæ'),
(84471, 3278, 22, 'Knä Problem'),
(84472, 3279, 22, 'Knä Ersättning /protes'),
(84473, 3286, 22, 'Lab'),
(84474, 3295, 22, 'Lab Rapport'),
(84475, 3303, 22, 'Etikett'),
(84476, 3305, 22, 'Label Cols'),
(84477, 3308, 22, 'Etiketter'),
(84478, 3311, 22, 'Labs'),
(84479, 3312, 22, 'Laceration / hudkodition'),
(84480, 3313, 22, 'Laceration / nötning'),
(84481, 3316, 22, 'Sprog'),
(84482, 3317, 22, 'Sprog kode'),
(84483, 3318, 22, 'Sprogdefinition tilføjet'),
(84484, 3320, 22, 'Sprog liste (skriv, addonly optional)'),
(84485, 3321, 22, 'Sprog navn'),
(84486, 3322, 22, 'Sprog:'),
(84487, 3325, 22, 'Sidst'),
(84488, 3326, 22, 'Dato for sidste aktivitet'),
(84489, 3328, 22, 'Dato for sidste regning'),
(84490, 3330, 22, 'Sidste kalenderår'),
(84491, 3333, 22, 'Sidste besøg'),
(84492, 3343, 22, 'Sidste måned'),
(84493, 3344, 22, 'Efternavn'),
(84494, 3345, 22, 'Efternavn'),
(84495, 3346, 22, 'Efternavn:'),
(84496, 3350, 22, 'Set sidst'),
(84497, 3352, 22, 'Sidst gemt'),
(84498, 3356, 22, 'Sidst opdateret af'),
(84499, 3358, 22, 'Seneste besøg'),
(84500, 3360, 22, 'Sen Återkommande (2-12 mån)'),
(84501, 3365, 22, 'sidled fördrivna PMI:'),
(84502, 3374, 22, 'Layout Editor'),
(84503, 3379, 22, 'Layouter'),
(84504, 3382, 22, 'LDL'),
(84505, 3383, 22, 'lämna tom om fortfarande aktiv'),
(84506, 3385, 22, 'Lämna tomt för att hålla lösenord oförändrad.'),
(84507, 3386, 22, 'Kontakt via'),
(84508, 3387, 22, 'Lämna Form'),
(84509, 3390, 22, 'Venstre'),
(84510, 3391, 22, 'Venstre øre'),
(84511, 3392, 22, 'venstre øre'),
(84512, 3394, 22, 'Venstre:'),
(84513, 3395, 22, 'Vänster: '),
(84514, 3396, 22, 'Ben smärta / Kramper'),
(84515, 3397, 22, 'Rättsärenden'),
(84516, 3400, 22, 'Förklaring:'),
(84517, 3401, 22, 'Längd'),
(84518, 3403, 22, 'Mindre end'),
(84519, 3404, 22, 'Mindre end eller lig med'),
(84520, 3406, 22, 'Brev'),
(84521, 3407, 22, 'Brevgenerator'),
(84522, 3412, 22, 'Ansvar'),
(84523, 3413, 22, 'Ansvar för medicinskt'),
(84524, 3414, 22, 'passnr'),
(84525, 3423, 22, 'Livsstil'),
(84526, 3424, 22, 'Livstilsstatus'),
(84527, 3425, 22, 'Ligament skada eller vrickning'),
(84528, 3428, 22, 'Begränsning av händelser'),
(84529, 3431, 22, 'Link'),
(84530, 3438, 22, 'Förteckning'),
(84531, 3443, 22, 'List Editor'),
(84532, 3446, 22, 'Lista Insurance Companies'),
(84533, 3451, 22, 'Lista listor'),
(84534, 3452, 22, 'Lista Namn'),
(84535, 3454, 22, 'Lista recept'),
(84536, 3458, 22, 'Listor'),
(84537, 3464, 22, 'Ladda definitioner'),
(84538, 3470, 22, 'Laddar'),
(84539, 3473, 22, 'Lokalt'),
(84540, 3477, 22, 'Lokalitet'),
(84541, 3478, 22, 'Lokalisation'),
(84542, 3481, 22, 'Lokalisation ospecificerad'),
(84543, 3484, 22, 'Lokalisation'),
(84544, 3492, 22, 'Log ind'),
(84545, 3494, 22, 'Log ud'),
(84546, 3495, 22, 'logget ind'),
(84547, 3496, 22, 'logget ind som'),
(84548, 3497, 22, 'logget ind som '),
(84549, 3498, 22, 'logget ud'),
(84550, 3500, 22, 'log ind'),
(84551, 3501, 22, 'log ind'),
(84552, 3505, 22, 'Log ud'),
(84553, 3506, 22, 'log ud'),
(84554, 3507, 22, 'Logs'),
(84555, 3508, 22, 'Log viewer'),
(84556, 3510, 22, 'Slå op'),
(84557, 3511, 22, 'Batch'),
(84558, 3513, 22, 'Batchnummer'),
(84559, 3514, 22, 'lav'),
(84560, 3516, 22, 'Benet'),
(84561, 3519, 22, 'Lumbal delen av ryggraden'),
(84562, 3520, 22, 'Frokost'),
(84563, 3521, 22, 'Frokost'),
(84564, 3522, 22, 'Lung Cancer'),
(84565, 3523, 22, 'Lung Cancer kirurgi'),
(84566, 3524, 22, 'Lungor:'),
(84567, 3525, 22, 'Lungor:'),
(84568, 3528, 22, 'M'),
(84569, 3529, 22, 'MA Kategori'),
(84570, 3533, 22, 'Mail sendt'),
(84571, 3534, 22, 'hoved'),
(84572, 3535, 22, 'Hovedadresse'),
(84573, 3540, 22, 'Lav ændringer i nuværende kategorier'),
(84574, 3541, 22, 'Lav ny aftale for'),
(84575, 3542, 22, 'Försäkra "'),
(84576, 3545, 22, 'Sjukdomskänsla:'),
(84577, 3548, 22, 'Mand'),
(84578, 3549, 22, 'Manlig Kondomer'),
(84579, 3552, 22, 'Mammogram'),
(84580, 3553, 22, 'Administrer'),
(84581, 3556, 22, 'Administrer oversættelser'),
(84582, 3557, 22, 'Administration'),
(84583, 3561, 22, 'Manual'),
(84584, 3562, 22, 'Manuell post'),
(84585, 3563, 22, 'Tillverkare'),
(84586, 3568, 22, 'Marts'),
(84587, 3569, 22, 'Civilstatus'),
(84588, 3571, 22, 'Markera som faktureras men hoppa fakturering'),
(84589, 3572, 22, 'Markera som avklarad'),
(84590, 3573, 22, 'Markera som ej fakturerad'),
(84591, 3575, 22, 'Markerad som avslutad'),
(84592, 3576, 22, 'Gift'),
(84593, 3578, 22, 'Maske'),
(84594, 3582, 22, 'Match'),
(84595, 3591, 22, 'Max'),
(84596, 3594, 22, 'Maxillary Höger:'),
(84597, 3595, 22, 'Maksimal alder'),
(84598, 3603, 22, 'Maj'),
(84599, 3604, 22, 'MC'),
(84600, 3605, 22, 'mcg'),
(84601, 3611, 22, 'Måling'),
(84602, 3614, 22, 'Medicinsk'),
(84603, 3620, 22, 'Medicinska problem'),
(84604, 3623, 22, 'Medicinska problem'),
(84605, 3624, 22, 'Journal'),
(84606, 3625, 22, 'Journal #'),
(84607, 3626, 22, 'Journaler'),
(84608, 3632, 22, 'Journal / Historia ( frivilligt att skriva )'),
(84609, 3635, 22, 'Medicin'),
(84610, 3640, 22, 'Läkemedel'),
(84611, 3641, 22, 'Läkemedel:'),
(84612, 3642, 22, 'Medicinska enheter'),
(84613, 3643, 22, 'Medium'),
(84614, 3645, 22, 'Ledamot Association Statistik Rapport'),
(84615, 3646, 22, 'Minnes Problem'),
(84616, 3647, 22, 'Män'),
(84617, 3648, 22, 'Män och kvinnor'),
(84618, 3649, 22, 'Män Endast'),
(84619, 3651, 22, 'Klimakteriet'),
(84620, 3653, 22, 'Menstruation frekvens'),
(84621, 3654, 22, 'Psykisk sjukdom'),
(84622, 3661, 22, 'Meddelande'),
(84623, 3666, 22, 'Beskedstatus'),
(84624, 3670, 22, 'MEDELANDE:'),
(84625, 3671, 22, 'Beskeder'),
(84626, 3673, 22, 'Metod'),
(84627, 3676, 22, 'Metod för förstöring'),
(84628, 3679, 22, 'mg'),
(84629, 3680, 22, 'mg/ml'),
(84630, 3681, 22, 'g'),
(84631, 3682, 22, 'g/ml'),
(84632, 3686, 22, 'Mellan'),
(84633, 3687, 22, 'Mellannamn'),
(84634, 3688, 22, 'Mellannamn'),
(84635, 3696, 22, 'Migrerande eller säsongsarbetare?'),
(84636, 3697, 22, 'Migrerande / Säsong'),
(84637, 3705, 22, 'Minimum alder'),
(84638, 3708, 22, 'Minut'),
(84639, 3709, 22, 'minuter'),
(84640, 3710, 22, 'Protokoll'),
(84641, 3716, 22, 'Diverse'),
(84642, 3717, 22, 'Missade'),
(84643, 3718, 22, 'Mangler'),
(84644, 3726, 22, 'Blandat'),
(84645, 3727, 22, 'ml'),
(84646, 3728, 22, 'MM/DD/ÅÅÅÅ'),
(84647, 3733, 22, 'Mobil'),
(84648, 3734, 22, 'Mobiltelefon'),
(84649, 3753, 22, 'Man'),
(84650, 3754, 22, 'Mandag til fredag'),
(84651, 3755, 22, 'Mandag, onsdag og fredag'),
(84652, 3756, 22, 'Mandag'),
(84653, 3758, 22, 'Måned'),
(84654, 3759, 22, 'måned'),
(84655, 3760, 22, 'Månadsvy'),
(84656, 3761, 22, 'Måned(er)'),
(84657, 3762, 22, 'Månadsinkomst'),
(84658, 3763, 22, 'Måneder'),
(84659, 3766, 22, 'Mer än 50 resultat, gör din sökning mer specifik.'),
(84660, 3771, 22, 'Moder'),
(84661, 3772, 22, 'Moders navn'),
(84662, 3774, 22, 'Mund'),
(84663, 3775, 22, 'Flyt'),
(84664, 3776, 22, 'Flyt dokument til kategori:'),
(84665, 3777, 22, 'Flyt ned'),
(84666, 3779, 22, 'Flyt til patient'),
(84667, 3780, 22, 'Flyt til...'),
(84668, 3781, 22, 'Flyt op'),
(84669, 3783, 22, 'Hr.'),
(84670, 3785, 22, 'Fru'),
(84671, 3786, 22, 'Frøken'),
(84672, 3796, 22, 'Multi Language Tool'),
(84673, 3797, 22, 'Flere områder'),
(84674, 3803, 22, 'Sorla:'),
(84675, 3804, 22, 'Muskel värk'),
(84676, 3807, 22, 'Muskulær stivhed'),
(84677, 3810, 22, 'Muskel'),
(84678, 3811, 22, 'Muskel skada'),
(84679, 3812, 22, 'Muskuloskeletala'),
(84680, 3814, 22, 'Ömsesidigt Definierad'),
(84681, 3823, 22, 'Navn'),
(84682, 3825, 22, 'Navn (tryk for mere)'),
(84683, 3826, 22, 'Navn 1'),
(84684, 3827, 22, 'Navn 2'),
(84685, 3828, 22, 'Namn på administratör'),
(84686, 3831, 22, 'Navn på begivenhed'),
(84687, 3832, 22, 'Namn på försäkringsbolag'),
(84688, 3833, 22, 'Namn på Provider'),
(84689, 3835, 22, 'Navngiv oversættelse'),
(84690, 3836, 22, 'Navn / Værdi'),
(84691, 3837, 22, 'Navn:'),
(84692, 3838, 22, 'Narės:'),
(84693, 3839, 22, 'Narės: Normal Rätt'),
(84694, 3840, 22, 'Nasal mucosa rosa, septumets mittlinje'),
(84695, 3844, 22, 'Nationalitet'),
(84696, 3854, 22, 'Navigering'),
(84697, 3866, 22, 'Nacke'),
(84698, 3867, 22, 'Nackproblem'),
(84699, 3869, 22, 'Måste ange en beskrivning'),
(84700, 3870, 22, 'Ange ett returvärde'),
(84701, 3871, 22, 'Ange identifieraren'),
(84702, 3872, 22, 'Ange titel'),
(84703, 3875, 22, 'Ange sekundära fakturering'),
(84704, 3876, 22, 'Negativ'),
(84705, 3880, 22, 'Nervskada'),
(84706, 3881, 22, 'Neurala tillstånd / nervskada'),
(84707, 3885, 22, 'Aldrig'),
(84708, 3886, 22, 'Aldrig alkohol'),
(84709, 3887, 22, 'Aldrig ryger'),
(84710, 3888, 22, 'Ny'),
(84711, 3889, 22, 'Ny =>'),
(84712, 3890, 22, 'Nye modtagere'),
(84713, 3892, 22, 'Ny allergi'),
(84714, 3894, 22, 'Ny aftale'),
(84715, 3895, 22, 'Nye kategorier'),
(84716, 3896, 22, 'Ny kategori'),
(84717, 3897, 22, 'Nye kunder'),
(84718, 3898, 22, 'Ny konsultation'),
(84719, 3899, 22, 'Ny gruppe'),
(84720, 3900, 22, 'Nyt definitionssæt tilføjet'),
(84721, 3901, 22, 'Nyt dokument'),
(84722, 3904, 22, 'Ny konsultation'),
(84723, 3906, 22, 'Ny konsultationsformular'),
(84724, 3907, 22, 'Nye møder som ikke godkendes'),
(84725, 3909, 22, 'Nya Klinikinformation'),
(84726, 3912, 22, 'Ny gruppe'),
(84727, 3913, 22, 'Ny gruppeinformation'),
(84728, 3914, 22, 'Ny inj/status'),
(84729, 3916, 22, 'Ny begrænsning af begivenheder'),
(84730, 3917, 22, 'Ny liste'),
(84731, 3919, 22, 'Ny regel'),
(84732, 3920, 22, 'Nyt kodeord'),
(84733, 3921, 22, 'Ny Patient'),
(84734, 3922, 22, 'Ny patient'),
(84735, 3923, 22, 'Ny konsultation'),
(84736, 3924, 22, 'Ny patientformular'),
(84737, 3925, 22, 'Nytt patient-ID'),
(84738, 3926, 22, 'Ny betaling'),
(84739, 3928, 22, 'Ny patient'),
(84740, 3930, 22, 'Ny søgning'),
(84741, 3931, 22, 'Nye forslag'),
(84742, 3932, 22, 'Ny bruger'),
(84743, 3933, 22, 'Ny værdi'),
(84744, 3934, 22, 'Nyt besøg'),
(84745, 3935, 22, 'Ny/Søg'),
(84746, 3960, 22, 'Aldrig'),
(84747, 3961, 22, 'Avis'),
(84748, 3962, 22, 'Næste'),
(84749, 3964, 22, 'Næste dag'),
(84750, 3965, 22, 'Næste måned'),
(84751, 3966, 22, 'Næste måned (hold for menu)'),
(84752, 3968, 22, 'Næste uge'),
(84753, 3969, 22, 'Næste år (hold for menu)'),
(84754, 3971, 22, 'Alias'),
(84755, 3973, 22, 'Nattliga svettningar'),
(84756, 3975, 22, 'Nej'),
(84757, 3976, 22, 'NEJ'),
(84758, 3977, 22, 'Ingen adgang'),
(84759, 3983, 22, 'Ingen aftaler'),
(84760, 3985, 22, 'Inget faktureringssystem är aktivt'),
(84761, 3989, 22, 'Ingen kod specificerades!'),
(84762, 3992, 22, 'Ingen diagnose'),
(84763, 3993, 22, 'Ingen dokumenter fundet'),
(84764, 3995, 22, 'Ingen slutdato'),
(84765, 3996, 22, 'Inga poster funna, använda formuläret nedan för att lägga till en post.'),
(84766, 3997, 22, 'Ingen fejl fundet'),
(84767, 3998, 22, 'Inga händelser'),
(84768, 4001, 22, 'Ingen grupp valdes'),
(84769, 4002, 22, 'Inga bråck'),
(84770, 4005, 22, 'Ingen skader/sygdomme'),
(84771, 4006, 22, 'Nr Insurance Companies Found'),
(84772, 4007, 22, 'Ingen emner'),
(84773, 4009, 22, 'Ingen emner under valgte kategori'),
(84774, 4010, 22, 'Ingen emner valgt!'),
(84775, 4031, 22, 'Der blev ikke fundet noget match. Opret ny patient nu?'),
(84776, 4033, 22, 'Der blev ikke fundet nye resultater'),
(84777, 4034, 22, 'Ingen noter'),
(84778, 4036, 22, 'Inga tider hittades för denna period.'),
(84779, 4037, 22, 'Ingen andre telefonnumre registreret'),
(84780, 4039, 22, 'Inga Partners hittades'),
(84781, 4042, 22, 'Inga perifera ödem'),
(84782, 4043, 22, 'Inga apotek hittades'),
(84783, 4044, 22, 'Inga recept hittades'),
(84784, 4045, 22, 'Ingen sjukdom / skada visas'),
(84785, 4053, 22, 'Ingen optagelser fundet'),
(84786, 4055, 22, 'Ingen optagelser fundet. Udvid venligst deres søgekriterier'),
(84787, 4058, 22, 'Ingen resultater'),
(84788, 4060, 22, 'Inga resultat hittades i sökningen'),
(84789, 4062, 22, 'Inga resultat, försök igen.'),
(84790, 4063, 22, 'Ingen resultater, forsøg venligst igen'),
(84791, 4065, 22, 'Ej kommit på avtalad tid'),
(84792, 4068, 22, 'Ingen hud dimpling eller bröst knölar'),
(84793, 4075, 22, 'Ingen besøg'),
(84794, 4079, 22, 'Nr:'),
(84795, 4081, 22, 'Ingen betalt'),
(84796, 4083, 22, 'Icke specifika skada'),
(84797, 4085, 22, 'Icke-insulinberoende diabetes'),
(84798, 4087, 22, 'Icke-SRH Medical'),
(84799, 4088, 22, 'Icke-SRH icke-medicinska'),
(84800, 4089, 22, 'Ingen'),
(84801, 4090, 22, 'ingen'),
(84802, 4093, 22, 'Inget av ovanstående'),
(84803, 4096, 22, 'Inte heller'),
(84804, 4097, 22, 'Normal'),
(84805, 4108, 22, 'Normal:'),
(84806, 4115, 22, 'Næse'),
(84807, 4116, 22, 'Næseblod'),
(84808, 4117, 22, 'Ikke et bogstav eller nummer'),
(84809, 4119, 22, 'Alla fält är obligatoriska för alla nummer eller kod typer.'),
(84810, 4120, 22, 'Ikke tilladt'),
(84811, 4121, 22, 'Ej tillåtet att ta bort gruppen Administratörer'),
(84812, 4122, 22, 'ikke tilladt at redigere'),
(84813, 4123, 22, 'Ej tillåtet att inaktivera alla trygghet objekt'),
(84814, 4124, 22, 'Ej tillåtet att inaktivera allt från Administratörer ACL'),
(84815, 4125, 22, 'Ej tillåtet att ta bort admin-användare från gruppen Administratörer'),
(84816, 4126, 22, 'Ikke tilladt at fjerne denne bruger fra Administrator gruppen'),
(84817, 4128, 22, 'Ej behörighet att nå PostCalendar modulen'),
(84818, 4135, 22, 'Ikke tilgængelig'),
(84819, 4137, 22, 'Ikke faktureret'),
(84820, 4143, 22, 'Inte undersökt'),
(84821, 4144, 22, 'Inte undersökt:'),
(84822, 4145, 22, 'Inte undersökt: '),
(84823, 4146, 22, 'Ikke fundet'),
(84824, 4148, 22, 'Ikke fundet!'),
(84825, 4152, 22, 'Inte sett sedan'),
(84826, 4154, 22, 'Ikke set endnu'),
(84827, 4156, 22, 'Ikke specificeret'),
(84828, 4157, 22, 'kommentera'),
(84829, 4162, 22, 'Kommentartyp'),
(84830, 4168, 22, 'Anmärkning: Denna kod har inte förts in av en auktoriserad användare. Endast godkända koder kan laddas upp till Open Medical Billing nätverket för bearbetning. Om du vill ladda upp dessa nummer kan du välja en auktoriserad användare här.'),
(84831, 4171, 22, 'OBS: Överföra filer med duplikat namn gör att filerna automatiskt ska döpas. Till exempel "<i> file.jpg </ i>" blir "<i> file.jpg.1 </ i>". Filnamnen anses unika per patient, inte per kategori.'),
(84832, 4172, 22, 'Kommentarer'),
(84833, 4182, 22, 'Ingenting valdes'),
(84834, 4184, 22, 'MEDDELANDE: PostCalendar Inlämning / Modifiering'),
(84835, 4185, 22, 'Besked'),
(84836, 4188, 22, 'Notifikationer'),
(84837, 4189, 22, 'Meddela Admin Om Händelse Inlämning / Modifieringsförslag?'),
(84838, 4191, 22, 'November'),
(84839, 4193, 22, 'Printer nu'),
(84840, 4198, 22, 'NPI'),
(84841, 4200, 22, 'Nummer'),
(84842, 4204, 22, 'Antal kolumner i år-vy.'),
(84843, 4237, 22, 'Yrke'),
(84844, 4239, 22, 'Forekomst'),
(84845, 4241, 22, 'Oktober'),
(84846, 4245, 22, 'tabletter'),
(84847, 4246, 22, 'i månaden per'),
(84848, 4249, 22, 'Mottagningskommentarer'),
(84849, 4250, 22, 'Mottagningsbesök'),
(84850, 4263, 22, 'Avkomma'),
(84851, 4265, 22, 'salva'),
(84852, 4267, 22, 'OK'),
(84853, 4270, 22, 'Gammel'),
(84854, 4272, 22, 'Gamla klienter'),
(84855, 4285, 22, 'underlåtit att autoassign'),
(84856, 4286, 22, 'på'),
(84857, 4288, 22, 'På Hand'),
(84858, 4289, 22, 'På beställning'),
(84859, 4292, 22, 'När du byter lösenord måste du logga in på nytt.'),
(84860, 4297, 22, 'Online Support'),
(84861, 4299, 22, 'Endast aktiva'),
(84862, 4302, 22, 'endast om faktureringsadress'),
(84863, 4303, 22, 'Endast Inaktiva'),
(84864, 4304, 22, 'Endast Min');
INSERT INTO `lang_definitions` VALUES
(84865, 4310, 22, 'Uppkomsten av sjukdom:'),
(84866, 4311, 22, 'Uppkomsten av sjukdom: '),
(84867, 4312, 22, 'Uppkomsten av Svullnad:'),
(84868, 4313, 22, 'Debut / Inskrivning. Datum:'),
(84869, 4315, 22, 'Ups!'),
(84870, 4316, 22, 'Åben'),
(84871, 4321, 22, 'Åben dagens besøg'),
(84872, 4328, 22, 'LibreEHR kräver Javascript för att utföra användarverifiering.'),
(84873, 4333, 22, 'Alternativ'),
(84874, 4336, 22, 'Valfritt'),
(84875, 4345, 22, 'Frivillig information om denna händelse'),
(84876, 4348, 22, 'Valfri procedurkodkod'),
(84877, 4350, 22, 'Muligheder'),
(84878, 4351, 22, 'Eller'),
(84879, 4352, 22, 'ELLER'),
(84880, 4353, 22, 'Eller välj'),
(84881, 4359, 22, 'Eller ladda upp ERA fil:'),
(84882, 4360, 22, 'Oral'),
(84883, 4362, 22, 'Ordning'),
(84884, 4364, 22, 'Bestillingskatalog'),
(84885, 4365, 22, 'Bestllingsdato'),
(84886, 4367, 22, 'Bestil fra'),
(84887, 4381, 22, 'Bestilt'),
(84888, 4386, 22, 'Organskada'),
(84889, 4387, 22, 'Organisation'),
(84890, 4391, 22, 'Orienterad x 3'),
(84891, 4398, 22, 'P.O. (via munnen)'),
(84892, 4402, 22, 'Övrigt'),
(84893, 4403, 22, 'annan'),
(84894, 4408, 22, 'Andra skador inte specificerade på någon annan plats'),
(84895, 4410, 22, 'anden måned'),
(84896, 4411, 22, 'Andra icke-federala program'),
(84897, 4412, 22, 'Andre noter'),
(84898, 4413, 22, 'Andra relevanta Symtom'),
(84899, 4414, 22, 'Andra relevanta Symtom:'),
(84900, 4417, 22, 'Andra kirurgiska'),
(84901, 4420, 22, 'Andre'),
(84902, 4423, 22, 'OU'),
(84903, 4425, 22, 'Ikke tilstede'),
(84904, 4427, 22, 'Udfald'),
(84905, 4428, 22, 'Outlook'),
(84906, 4432, 22, 'Overforbrug'),
(84907, 4434, 22, 'Overvægt'),
(84908, 4440, 22, 'vid behov'),
(84909, 4444, 22, 'Pedriatisk'),
(84910, 4445, 22, 'Side'),
(84911, 4446, 22, 'Sidor'),
(84912, 4447, 22, 'Betald'),
(84913, 4448, 22, 'Betalt belopp som du kommer att fördela'),
(84914, 4450, 22, 'Betalas via'),
(84915, 4451, 22, 'Smerte'),
(84916, 4453, 22, 'Palpation'),
(84917, 4463, 22, 'Partner'),
(84918, 4472, 22, 'Kodeord'),
(84919, 4473, 22, 'Ændre kodeord'),
(84920, 4480, 22, 'Lösenord för SMS Gateway'),
(84921, 4486, 22, 'Lösenord:'),
(84922, 4495, 22, 'Tidligere aftaler'),
(84923, 4496, 22, 'Tidigare möten och dokument'),
(84924, 4497, 22, 'Tidligere aftaler for'),
(84925, 4498, 22, 'Klistra in HL7 Data'),
(84926, 4514, 22, 'Patient'),
(84927, 4522, 22, 'Patient Allergier'),
(84928, 4523, 22, 'Patient träff/bokning'),
(84929, 4528, 22, 'Patient diagram ID'),
(84930, 4539, 22, 'Patientdata'),
(84931, 4544, 22, 'Patientdokument'),
(84932, 4547, 22, 'Patientmöten'),
(84933, 4548, 22, 'Patientmötesformulär'),
(84934, 4549, 22, 'Patientmöten'),
(84935, 4550, 22, 'Patientsök'),
(84936, 4551, 22, 'Patient Fornavn'),
(84937, 4558, 22, 'Patient køn'),
(84938, 4561, 22, 'Patienthistoria'),
(84939, 4562, 22, 'Patientens historia / Livsstil'),
(84940, 4563, 22, 'Patient hjemmetelefonnummer'),
(84941, 4564, 22, 'Patient-ID'),
(84942, 4568, 22, 'Patient -vaccination'),
(84943, 4569, 22, 'Patient information'),
(84944, 4570, 22, 'Patient instruktioner'),
(84945, 4571, 22, 'Ej tilldelad!'),
(84946, 4573, 22, 'Patient -problem'),
(84947, 4575, 22, 'Patient eftenavn'),
(84948, 4581, 22, 'Patientlista'),
(84949, 4587, 22, 'Patientens medicinska problem'),
(84950, 4588, 22, 'Patient -Mediciner'),
(84951, 4589, 22, 'Patientnavn'),
(84952, 4590, 22, 'Patient: Namn och Adress'),
(84953, 4596, 22, 'Patientanteckning, typ'),
(84954, 4597, 22, 'Patient -kommentarer'),
(84955, 4599, 22, 'Patientnummer'),
(84956, 4600, 22, 'Patient-betaling'),
(84957, 4609, 22, 'Patient -Journalrapport'),
(84958, 4613, 22, 'Patient påmindelse'),
(84959, 4620, 22, 'Patientrapport'),
(84960, 4621, 22, 'Patientförfrågan'),
(84961, 4623, 22, 'Patient resultater'),
(84962, 4626, 22, 'Patient opsætning'),
(84963, 4629, 22, 'Patient -Sammanfattning'),
(84964, 4630, 22, 'Patient -Remisser m.m.'),
(84965, 4633, 22, 'Patient / Klient'),
(84966, 4634, 22, 'Patient:'),
(84967, 4636, 22, 'Patienter'),
(84968, 4638, 22, 'Betala'),
(84969, 4640, 22, 'Betalningsdatum:'),
(84970, 4643, 22, 'Betaler'),
(84971, 4644, 22, 'Betalare Typ'),
(84972, 4645, 22, 'Betalende'),
(84973, 4647, 22, 'Betaling'),
(84974, 4654, 22, 'Betalingsdato'),
(84975, 4660, 22, 'Betalingsmetode'),
(84976, 4664, 22, 'Betalingsvædi til kode '),
(84977, 4665, 22, 'Betalinger'),
(84978, 4674, 22, 'Oavslutad'),
(84979, 4677, 22, 'Oklart'),
(84980, 4688, 22, 'via näsborre'),
(84981, 4689, 22, 'via näsborre'),
(84982, 4692, 22, 'Rektalt'),
(84983, 4693, 22, 'rektalt'),
(84984, 4694, 22, 'Procent'),
(84985, 4699, 22, 'Udfør søgning'),
(84986, 4700, 22, 'Udfør denne handling'),
(84987, 4705, 22, 'Periode'),
(84988, 4717, 22, 'Apotek'),
(84989, 4718, 22, 'Patient Insurance Distribution'),
(84990, 4720, 22, 'Pheumothorax'),
(84991, 4729, 22, 'Telefon'),
(84992, 4730, 22, 'Telefon samtalslistan'),
(84993, 4738, 22, 'Telefonnummer'),
(84994, 4741, 22, 'Fotos'),
(84995, 4747, 22, 'Hälsokontroll'),
(84996, 4749, 22, 'Läkares Begäran'),
(84997, 4750, 22, 'Läkares Underskrift'),
(84998, 4752, 22, 'Läkare'),
(84999, 4753, 22, 'välj'),
(85000, 4758, 22, 'Tablett Storlek'),
(85001, 4759, 22, 'Tabletter'),
(85002, 4767, 22, 'Vanlig text'),
(85003, 4784, 22, 'Spelare'),
(85004, 4785, 22, 'Position'),
(85005, 4792, 22, 'Välj ett värde för'),
(85006, 4797, 22, 'Stäng detta fönster'),
(85007, 4798, 22, 'Jämför det nya namnet'),
(85008, 4810, 22, 'indtast dato'),
(85009, 4814, 22, 'indtast nyt kodeord'),
(85010, 4815, 22, 'Indtast en titel'),
(85011, 4823, 22, 'Indtast kodeord'),
(85012, 4826, 22, 'Udfyld dato'),
(85013, 4834, 22, 'Indtast søgekriterie ovenover og tryk TILMELD for at se resultater'),
(85014, 4836, 22, 'Prøv at logge ind igen'),
(85015, 4839, 22, 'Vänligen använ endast alfabetiska tecken'),
(85016, 4840, 22, 'Vänligen använd endast alfabetiska tecken utan mellanslag'),
(85017, 4841, 22, 'Vänligen betala detta belopp'),
(85018, 4849, 22, 'Vælg et sprog'),
(85019, 4850, 22, 'Vælg en patient'),
(85020, 4855, 22, 'Vælg en start- og slutdato'),
(85021, 4859, 22, 'Vælg en begivenhed'),
(85022, 4866, 22, 'Vælg betalingsform'),
(85023, 4882, 22, 'EM'),
(85024, 4891, 22, 'Lunginflammations Vaccination'),
(85025, 4897, 22, 'Förhållningssätt'),
(85026, 4902, 22, 'Polyper'),
(85027, 4904, 22, 'Dålig apptit'),
(85028, 4905, 22, 'Dålig cirkulation'),
(85029, 4906, 22, 'Dålig hörsel'),
(85030, 4909, 22, 'Popup-vinduer'),
(85031, 4927, 22, 'Efterbetalinger'),
(85032, 4937, 22, 'Postnr'),
(85033, 4938, 22, 'Postnummer'),
(85034, 4946, 22, 'Överförings Datum'),
(85035, 4953, 22, 'Practice'),
(85036, 4959, 22, 'Forudbetaling'),
(85037, 4964, 22, 'Refrerencer'),
(85038, 4969, 22, 'Graviditets test'),
(85039, 4972, 22, 'Forudbetalt'),
(85040, 4977, 22, 'Receptbelagda märken'),
(85041, 4979, 22, 'Recept'),
(85042, 4980, 22, 'Föreskrifter och dispenser'),
(85043, 4981, 22, 'Recept och andra råd'),
(85044, 4982, 22, 'Recept och andra råd av specialist'),
(85045, 4983, 22, 'recept rapport'),
(85046, 4984, 22, 'Recept/råd'),
(85047, 4985, 22, 'Nuværende'),
(85048, 4986, 22, 'Presentera Klagomål'),
(85049, 4988, 22, 'Tryck på fortsätt för att fortsätta'),
(85050, 4989, 22, 'Förmodad diagnos'),
(85051, 4990, 22, 'Förmodad diagnos från specialist'),
(85052, 4991, 22, 'Forrige'),
(85053, 5001, 22, 'Forrige'),
(85054, 5002, 22, 'Forrige konsultationer'),
(85055, 5003, 22, 'Forrige dag'),
(85056, 5005, 22, 'Forrige måned'),
(85057, 5006, 22, 'Forrige uge'),
(85058, 5007, 22, 'Pris'),
(85059, 5009, 22, 'Prisniveau'),
(85060, 5010, 22, 'Prisniveau:'),
(85061, 5011, 22, 'Priser'),
(85062, 5012, 22, 'Primær'),
(85063, 5023, 22, 'Primära Försäkring'),
(85064, 5024, 22, 'Primära Försäkrings Data'),
(85065, 5025, 22, 'Primär försäkringsbolag'),
(85066, 5027, 22, 'Print'),
(85067, 5032, 22, 'Printa blankt remissformulär'),
(85068, 5043, 22, 'Print flere'),
(85069, 5056, 22, 'Print denne aftale'),
(85070, 5057, 22, 'Print denne note'),
(85071, 5058, 22, 'Print denne note'),
(85072, 5062, 22, 'Utskrivbar'),
(85073, 5063, 22, 'Utskriftsversion'),
(85074, 5066, 22, 'Printer resultater'),
(85075, 5073, 22, 'Prioritet '),
(85076, 5074, 22, 'Privat'),
(85077, 5079, 22, 'Problemer/emner'),
(85078, 5086, 22, 'Procedure'),
(85079, 5114, 22, 'Procedure'),
(85080, 5115, 22, 'Process'),
(85081, 5125, 22, 'Bearbetning'),
(85082, 5132, 22, 'Produkter'),
(85083, 5134, 22, 'Prof.'),
(85084, 5136, 22, 'Prostata Cancer'),
(85085, 5138, 22, 'Prostata undersökning'),
(85086, 5139, 22, 'Prostata problem'),
(85087, 5152, 22, 'Leverandør'),
(85088, 5159, 22, 'Leverandør nummer'),
(85089, 5162, 22, 'Levenradør'),
(85090, 5163, 22, 'Levenrandører'),
(85091, 5184, 22, 'Pt refundering'),
(85092, 5185, 22, 'Pt afsluttet'),
(85093, 5201, 22, 'Offentlig'),
(85094, 5206, 22, 'Puls'),
(85095, 5208, 22, 'Køb'),
(85096, 5213, 22, 'Var 3:e timme'),
(85097, 5214, 22, 'Var 4:e timme'),
(85098, 5215, 22, 'Var 5:e timme'),
(85099, 5216, 22, 'Var 6:e timme'),
(85100, 5217, 22, 'Var 8:e timme'),
(85101, 5218, 22, '1 ggr/dag'),
(85102, 5219, 22, '4ggr/dag'),
(85103, 5222, 22, 'Antal'),
(85104, 5224, 22, 'Kvalitet'),
(85105, 5226, 22, 'Kvantitet'),
(85106, 5227, 22, 'Kvantitet för NDC'),
(85107, 5231, 22, 'Spøgsmålstegn'),
(85108, 5236, 22, 'köad'),
(85109, 5237, 22, 'Kö Evenemang Administration'),
(85110, 5238, 22, 'köad för'),
(85111, 5240, 22, 'Kö föreläggande Administration'),
(85112, 5245, 22, 'Ras'),
(85113, 5247, 22, 'Etnisitet'),
(85114, 5248, 22, 'Radio'),
(85115, 5252, 22, 'Udslæt'),
(85116, 5253, 22, 'Betygsätta'),
(85117, 5261, 22, 'Genåben'),
(85118, 5262, 22, 'Genåbnet'),
(85119, 5263, 22, 'Reaktion'),
(85120, 5264, 22, 'Reaktioner'),
(85121, 5265, 22, 'Læs'),
(85122, 5268, 22, 'Rigtigt navn'),
(85123, 5269, 22, 'Virkelig slette?'),
(85124, 5270, 22, 'Årsag'),
(85125, 5272, 22, 'Dødsårsag'),
(85126, 5274, 22, 'Anledning till remiss'),
(85127, 5275, 22, 'Anledning till besök'),
(85128, 5276, 22, 'Orsak / Form'),
(85129, 5277, 22, 'Kvitto'),
(85130, 5278, 22, 'Kvitto för betalning'),
(85131, 5281, 22, 'Kvitton Sammanfattning'),
(85132, 5282, 22, 'Modtaget'),
(85133, 5283, 22, 'Modtaget af'),
(85134, 5284, 22, 'Modtaget fax'),
(85135, 5287, 22, 'Modtager'),
(85136, 5288, 22, 'Modtager ID'),
(85137, 5298, 22, 'Anbefaling'),
(85138, 5300, 22, 'Anbefalinger'),
(85139, 5301, 22, 'Anbefalinger og behandling'),
(85140, 5302, 22, 'Anbefalet af specialist'),
(85141, 5303, 22, 'Optag'),
(85142, 5314, 22, 'Optag betaling'),
(85143, 5317, 22, 'Optagelser'),
(85144, 5318, 22, 'Optagelser fundet'),
(85145, 5319, 22, 'patienter fundet.'),
(85146, 5327, 22, 'reduceras:'),
(85147, 5328, 22, 'Referer'),
(85148, 5329, 22, 'Referer af'),
(85149, 5330, 22, 'Remissdatum'),
(85150, 5331, 22, 'Referer til'),
(85151, 5332, 22, 'Prioritetsnivå (Risknivå)'),
(85152, 5334, 22, 'reference årsag'),
(85153, 5336, 22, 'Remittent, namn och signatur'),
(85154, 5337, 22, 'Remiss'),
(85155, 5338, 22, 'Remitterad av'),
(85156, 5339, 22, 'Remisskort'),
(85157, 5340, 22, 'Remissdadum'),
(85158, 5341, 22, 'Remissformulär'),
(85159, 5342, 22, 'REMISSFORMULÄR'),
(85160, 5345, 22, 'Remisskälla'),
(85161, 5347, 22, 'Remitteras till'),
(85162, 5348, 22, 'remittering'),
(85163, 5349, 22, 'remiss'),
(85164, 5350, 22, 'Remiterats från'),
(85165, 5351, 22, 'Remiterats från'),
(85166, 5352, 22, 'Remitterats till'),
(85167, 5353, 22, 'Remiterats av'),
(85168, 5360, 22, 'Refill'),
(85169, 5361, 22, 'Refill'),
(85170, 5362, 22, 'Reflexer normala'),
(85171, 5363, 22, 'Opdater'),
(85172, 5372, 22, 'Registrerad'),
(85173, 5373, 22, 'registrerade'),
(85174, 5375, 22, 'Registreringsdag'),
(85175, 5377, 22, 'Rehabilitering'),
(85176, 5381, 22, 'Relatere til'),
(85177, 5382, 22, 'Relateret'),
(85178, 5386, 22, 'Relationer'),
(85179, 5387, 22, 'Forhold'),
(85180, 5389, 22, 'Anhöriga'),
(85181, 5403, 22, 'Religion'),
(85182, 5406, 22, 'Relogin'),
(85183, 5409, 22, 'Påmindelse'),
(85184, 5410, 22, 'Påmindelse Intervaller'),
(85185, 5411, 22, 'Påmindelse endnu ikke sendt'),
(85186, 5416, 22, 'Fjern'),
(85187, 5419, 22, 'Fjern gruppe'),
(85188, 5427, 22, 'Gendøb'),
(85189, 5428, 22, 'Gendøb gruppe'),
(85190, 5432, 22, 'Genbestil'),
(85191, 5438, 22, 'Gentagene event'),
(85192, 5439, 22, 'Gentagene information'),
(85193, 5440, 22, 'Gentag'),
(85194, 5444, 22, 'Svardato'),
(85195, 5445, 22, 'Svar fra'),
(85196, 5446, 22, 'Rapport'),
(85197, 5463, 22, 'Rapporter'),
(85198, 5477, 22, 'Nødvendig'),
(85199, 5485, 22, 'RESERVERET'),
(85200, 5486, 22, 'reserveret'),
(85201, 5491, 22, 'Genstart'),
(85202, 5496, 22, 'Løst'),
(85203, 5503, 22, 'Begränsat Utbildning'),
(85204, 5504, 22, 'Resultat'),
(85205, 5518, 22, 'Infällda Höger:'),
(85206, 5519, 22, 'Tilbage'),
(85207, 5521, 22, 'Tilbage til kalender'),
(85208, 5527, 22, 'Returvärde'),
(85209, 5528, 22, 'Återresa'),
(85210, 5536, 22, 'Översyn av System Kontroller'),
(85211, 5538, 22, 'Revision'),
(85212, 5541, 22, 'Højre'),
(85213, 5542, 22, 'Højre øre'),
(85214, 5543, 22, 'højre øre'),
(85215, 5545, 22, 'Højre:'),
(85216, 5546, 22, 'Ringningar i öron'),
(85217, 5547, 22, 'Tinitus'),
(85218, 5549, 22, 'Risikofaktorer'),
(85219, 5561, 22, 'Rutt'),
(85220, 5564, 22, 'Rader'),
(85221, 5566, 22, 'Massera:'),
(85222, 5567, 22, 'Gnuggar:'),
(85223, 5568, 22, 'Regel'),
(85224, 5569, 22, 'Tilføj regel'),
(85225, 5578, 22, 'Regler'),
(85226, 5581, 22, 'Kör kommando: '),
(85227, 5584, 22, 'Recept'),
(85228, 5585, 22, 'Recept'),
(85229, 5600, 22, 'K'),
(85230, 5601, 22, 'Personnr'),
(85231, 5605, 22, 'Salg'),
(85232, 5609, 22, 'Spyt'),
(85233, 5610, 22, 'Samme dag'),
(85234, 5612, 22, 'Prøve'),
(85235, 5613, 22, 'Sanktions Typ'),
(85236, 5617, 22, 'Lørdag'),
(85237, 5618, 22, 'Lørdag og Søndag'),
(85238, 5619, 22, 'Lørdag'),
(85239, 5620, 22, 'Gem'),
(85240, 5621, 22, 'Gem'),
(85241, 5624, 22, 'Gem og fordel'),
(85242, 5626, 22, 'Gem som ny'),
(85243, 5627, 22, 'Gem som ny note'),
(85244, 5628, 22, 'Gem certifikatindstillinger'),
(85245, 5629, 22, 'Gem ændringer'),
(85246, 5630, 22, 'Gem form'),
(85247, 5631, 22, 'Spara vaccination'),
(85248, 5632, 22, 'Gem nyt felt'),
(85249, 5633, 22, 'Gem ny gruppe'),
(85250, 5634, 22, 'Gem ny liste'),
(85251, 5637, 22, 'Gem patientoplysninger'),
(85252, 5639, 22, 'Gem transaktion'),
(85253, 5641, 22, 'Scannet'),
(85254, 5644, 22, 'Scanner i'),
(85255, 5645, 22, 'Skema'),
(85256, 5648, 22, 'Skolios'),
(85257, 5651, 22, 'SE'),
(85258, 5652, 22, 'SE Adresse'),
(85259, 5653, 22, 'SE By'),
(85260, 5654, 22, 'SE Land'),
(85261, 5656, 22, 'SE Postnummer'),
(85262, 5658, 22, 'SE Postnummer'),
(85263, 5659, 22, 'Søg'),
(85264, 5661, 22, 'Søg'),
(85265, 5662, 22, 'Søg igen'),
(85266, 5664, 22, 'Søg efter:'),
(85267, 5665, 22, 'Søg efter:'),
(85268, 5666, 22, 'Søg efter:'),
(85269, 5668, 22, 'Søg i'),
(85270, 5669, 22, 'Søg eller tilføj patient'),
(85271, 5670, 22, 'Søg betaling'),
(85272, 5672, 22, 'søgeresultater'),
(85273, 5673, 22, 'Søgning valgt'),
(85274, 5676, 22, 'Søg tekst'),
(85275, 5677, 22, 'Søg i begivenheder'),
(85276, 5678, 22, 'Søg/Tilføj'),
(85277, 5679, 22, 'Sök / Lägg till försäkringsgivaren'),
(85278, 5680, 22, 'Søg efter aftaler'),
(85279, 5681, 22, 'Søger...'),
(85280, 5682, 22, 'Bilbältesanvändning'),
(85281, 5684, 22, 'Anden'),
(85282, 5687, 22, 'Sekundær'),
(85283, 5688, 22, 'Sekundär Försäkring'),
(85284, 5689, 22, 'Sekundär Försäkrings Data'),
(85285, 5698, 22, 'Sikkerhed'),
(85286, 5699, 22, 'Se alle'),
(85287, 5700, 22, 'Se autorisationer'),
(85288, 5704, 22, 'Set siden'),
(85289, 5709, 22, 'Vælg'),
(85290, 5710, 22, 'Vælg'),
(85291, 5712, 22, 'Vælg en sammenhæng'),
(85292, 5715, 22, 'Vælg en bruger'),
(85293, 5716, 22, 'Vælg alle'),
(85294, 5720, 22, 'Vælg kategori'),
(85295, 5723, 22, 'Vælg kriterie for at fjerne'),
(85296, 5727, 22, 'Vælg dato'),
(85297, 5729, 22, 'Vælg diagnose'),
(85298, 5731, 22, 'Vælg præpprarat'),
(85299, 5732, 22, 'Vælg præpparater'),
(85300, 5738, 22, 'Vælg for at printe'),
(85301, 5742, 22, 'Vælg emne'),
(85302, 5744, 22, 'Vælg sprog'),
(85303, 5759, 22, 'Vælg bruger'),
(85304, 5760, 22, 'Vælg brugere fra Dropdown-listen'),
(85305, 5765, 22, 'Valgt'),
(85306, 5766, 22, 'Vælg møde'),
(85307, 5769, 22, 'Egenbetaling'),
(85308, 5771, 22, 'Send'),
(85309, 5774, 22, 'Överföring pågår'),
(85310, 5775, 22, 'Send besked'),
(85311, 5779, 22, 'Send denne fil'),
(85312, 5788, 22, 'Afsender'),
(85313, 5789, 22, 'Afsender ID'),
(85314, 5795, 22, 'Känslighet:'),
(85315, 5802, 22, 'Sendte emner'),
(85316, 5804, 22, 'Sendt'),
(85317, 5807, 22, 'Sendt til printer'),
(85318, 5813, 22, 'Separeret'),
(85319, 5814, 22, 'September'),
(85320, 5816, 22, 'Sekvens'),
(85321, 5821, 22, 'Service'),
(85322, 5822, 22, 'Service kategori'),
(85323, 5823, 22, 'Service kode'),
(85324, 5825, 22, 'Service koder'),
(85325, 5826, 22, 'Service dato'),
(85326, 5827, 22, 'Service dato:'),
(85327, 5829, 22, 'Service Location'),
(85328, 5834, 22, 'Tjenester'),
(85329, 5835, 22, 'Tjenester efter kategori'),
(85330, 5836, 22, 'Tjänster som tillhandahålls'),
(85331, 5837, 22, 'Tjänster som Tillhandahålls'),
(85332, 5849, 22, 'Indstillinger'),
(85333, 5851, 22, 'Svår huvudvärk'),
(85334, 5853, 22, 'Svårighetsgrad av smärta'),
(85335, 5854, 22, 'Svårighetsgrad av smärta:'),
(85336, 5855, 22, 'Køn'),
(85337, 5856, 22, 'Sexuellt överförbara sjukdomar'),
(85338, 5859, 22, 'Dele'),
(85339, 5864, 22, 'Åndenød'),
(85340, 5870, 22, 'bör vara som nnnnn-nnnn-nn'),
(85341, 5874, 22, 'Axel'),
(85342, 5875, 22, 'Axel + nyckelben'),
(85343, 5876, 22, 'Axelproblem'),
(85344, 5877, 22, 'Vis'),
(85345, 5880, 22, 'Vis alle'),
(85346, 5883, 22, 'Vis alle transaktioner'),
(85347, 5884, 22, 'Vis som optaget'),
(85348, 5885, 22, 'Visa endast behöriga'),
(85349, 5886, 22, 'Vis tilgængelige tider'),
(85350, 5889, 22, 'Vis detaljer'),
(85351, 5891, 22, 'Vis graf'),
(85352, 5896, 22, 'Vis Menu'),
(85353, 5898, 22, 'Vis Noter'),
(85354, 5901, 22, 'Vis Patient Noter'),
(85355, 5906, 22, 'Vis rapport'),
(85356, 5913, 22, 'Visa endast icke fakturerad'),
(85357, 5920, 22, 'Søskende'),
(85358, 5927, 22, 'Underskrift'),
(85359, 5929, 22, 'Underskrift:'),
(85360, 5932, 22, 'Betydande Svullnad:'),
(85361, 5937, 22, 'Siden'),
(85362, 5940, 22, 'Singel'),
(85363, 5956, 22, 'Størrelse'),
(85364, 5958, 22, 'Størrelse/Liste'),
(85365, 5959, 22, 'Hud'),
(85366, 5967, 22, 'sömn mönster'),
(85367, 5969, 22, 'sover'),
(85368, 5985, 22, 'SMS sendt før'),
(85369, 5986, 22, 'SMS sendt'),
(85370, 6004, 22, 'Snorker'),
(85371, 6009, 22, 'Social History:'),
(85372, 6011, 22, 'Løsning'),
(85373, 6016, 22, 'Vissa möten visas inte. Klicka här för att visa alla.'),
(85374, 6018, 22, 'Nogle noter blev ikke vist'),
(85375, 6020, 22, 'Nogle ord'),
(85376, 6023, 22, 'Noget gik galt. Prøv venligst igen'),
(85377, 6026, 22, 'Øm hals'),
(85378, 6028, 22, 'Beklager, der var et problem med at åbne din fil'),
(85379, 6029, 22, 'Sorter efter'),
(85380, 6030, 22, 'Sorter efter'),
(85381, 6032, 22, 'Sorter efter kommentarer'),
(85382, 6034, 22, 'Sorter efter dato'),
(85383, 6036, 22, 'Sorter efter begivenhed'),
(85384, 6037, 22, 'Sorter efter gruppe'),
(85385, 6040, 22, 'Sorter efter CPRnummer'),
(85386, 6043, 22, 'Soter efter bruger'),
(85387, 6048, 22, 'Kilde'),
(85388, 6051, 22, 'Källa saknas för kod '),
(85389, 6057, 22, 'Kilde:'),
(85390, 6060, 22, 'mellemrum'),
(85391, 6061, 22, 'MELLEMRUM:'),
(85392, 6068, 22, 'Specialist'),
(85393, 6069, 22, 'Specialist navn og underskrift'),
(85394, 6071, 22, 'Specialtet'),
(85395, 6073, 22, 'Specielt:'),
(85396, 6074, 22, 'Specifik'),
(85397, 6077, 22, 'Specifik resultat'),
(85398, 6078, 22, 'Specifikke tjenester'),
(85399, 6092, 22, 'Diktering'),
(85400, 6093, 22, 'Spermiedödande'),
(85401, 6095, 22, 'Ægtefælle'),
(85402, 6098, 22, 'Sputum:'),
(85403, 6111, 22, 'Personnummmer'),
(85404, 6113, 22, 'Persnr'),
(85405, 6114, 22, 'Stabilitet'),
(85406, 6116, 22, 'Standard'),
(85407, 6124, 22, 'Start'),
(85408, 6125, 22, 'Start (åååå-mm-dd): '),
(85409, 6128, 22, 'Startdato'),
(85410, 6129, 22, 'Startdato på denne klinik'),
(85411, 6130, 22, 'Startdato kan ikke være senere end slutdato'),
(85412, 6131, 22, 'Startdato:'),
(85413, 6132, 22, 'Startdato:'),
(85414, 6133, 22, 'Start tid'),
(85415, 6134, 22, 'Startdato'),
(85416, 6136, 22, 'Stat'),
(85417, 6144, 22, 'församling'),
(85418, 6151, 22, 'Statistik'),
(85419, 6152, 22, 'Övrigt'),
(85420, 6153, 22, 'Status'),
(85421, 6156, 22, 'Oförändrat'),
(85422, 6170, 22, 'Stivhed'),
(85423, 6172, 22, 'Ont i magen'),
(85424, 6175, 22, 'Överbelastade muskler'),
(85425, 6176, 22, 'Strøm'),
(85426, 6177, 22, 'Gade'),
(85427, 6178, 22, 'Adresse'),
(85428, 6179, 22, 'Gade og nummer'),
(85429, 6180, 22, 'Styrke'),
(85430, 6183, 22, 'Stress fraktur'),
(85431, 6184, 22, 'Stresstest'),
(85432, 6185, 22, 'Stroke'),
(85433, 6190, 22, 'Del-sum'),
(85434, 6191, 22, 'Underkategori'),
(85435, 6192, 22, 'underkategori'),
(85436, 6193, 22, 'subkutant'),
(85437, 6195, 22, 'Subjektiv'),
(85438, 6196, 22, 'Sublingual'),
(85439, 6197, 22, 'sublingual'),
(85440, 6198, 22, 'Tilmeld'),
(85441, 6199, 22, 'tilmeld'),
(85442, 6200, 22, 'Tilmeld al indhold'),
(85443, 6202, 22, 'Tilmeld begivenhed'),
(85444, 6203, 22, 'Tilmeldingsblanket'),
(85445, 6205, 22, 'Tilmeldt'),
(85446, 6206, 22, 'Tilmeldt af'),
(85447, 6208, 22, 'Abonnent'),
(85448, 6209, 22, 'Abonnent adresse'),
(85449, 6237, 22, 'Erstatning'),
(85450, 6238, 22, 'Erstatning tilladt'),
(85451, 6240, 22, 'Success'),
(85452, 6241, 22, 'Success'),
(85453, 6260, 22, 'Självmord'),
(85454, 6261, 22, 'Sammenfatning'),
(85455, 6265, 22, 'Søn'),
(85456, 6267, 22, 'Søndag'),
(85457, 6275, 22, 'Superbruger'),
(85458, 6291, 22, 'Kirurgi'),
(85459, 6293, 22, 'Suspenderet'),
(85460, 6294, 22, 'Uppslammad vätska'),
(85461, 6300, 22, 'Svenska'),
(85462, 6301, 22, 'Sluge'),
(85463, 6303, 22, 'Hævede led'),
(85464, 6307, 22, 'Symptomer'),
(85465, 6308, 22, 'Synkroniser'),
(85466, 6318, 22, 'System'),
(85467, 6323, 22, '3 ggr/dag'),
(85468, 6327, 22, 'Tabell skapas inte'),
(85469, 6328, 22, 'Tabell uppdateringen misslyckades'),
(85470, 6330, 22, 'tablett'),
(85471, 6335, 22, 'Ta'),
(85472, 6339, 22, 'Tager lang tid'),
(85473, 6356, 22, 'Skatter'),
(85474, 6363, 22, 'Tlf.'),
(85475, 6370, 22, 'Mall'),
(85476, 6373, 22, 'Mall:'),
(85477, 6383, 22, 'Test skema'),
(85478, 6384, 22, 'Test system'),
(85479, 6385, 22, 'Tekst'),
(85480, 6387, 22, 'Tekst felt'),
(85481, 6398, 22, 'Testboks'),
(85482, 6402, 22, 'Tak'),
(85483, 6408, 22, 'Påstående ärendet: '),
(85484, 6415, 22, 'Destinationen er lukket'),
(85485, 6422, 22, 'Begivenheden er godkendt'),
(85486, 6423, 22, 'Begivenheden er skjult'),
(85487, 6434, 22, 'Følgende kalender er tilføjet:'),
(85488, 6435, 22, 'Følgende kalender er ændret:'),
(85489, 6461, 22, 'Nyt password må ikke være magen til det nuværende'),
(85490, 6470, 22, 'Patientpåmindelser er sendt'),
(85491, 6493, 22, 'Emne'),
(85492, 6495, 22, 'Terapeutiska Injektioner'),
(85493, 6496, 22, 'Der er'),
(85494, 6497, 22, 'Der er ingen recepter i øjeblikket'),
(85495, 6498, 22, 'Det är fel med din ansökan. Dessa beskrivs nedan.'),
(85496, 6502, 22, 'Det finns inga nya synpunkter'),
(85497, 6503, 22, 'Der er ingen noter for denne patient'),
(85498, 6520, 22, 'Det uppstod ett fel när din begäran behandlades.'),
(85499, 6523, 22, 'Förtjockad Höger:'),
(85500, 6524, 22, 'Lår'),
(85501, 6525, 22, 'Lår + knäsena'),
(85502, 6542, 22, 'Tredje'),
(85503, 6544, 22, 'Denne handling kan IKKE fortrydes'),
(85504, 6545, 22, 'Denne handling kan ikke fortrydes'),
(85505, 6551, 22, 'Dette kalendeår'),
(85506, 6561, 22, 'Dette besøg'),
(85507, 6566, 22, 'Dette fakturanummer er ændret til '),
(85508, 6577, 22, 'Denne måned til dato'),
(85509, 6582, 22, 'Denne patient er ikke aktiv'),
(85510, 6583, 22, 'Denne patiens ID bruges allerede!'),
(85511, 6592, 22, 'Denne bruger er ikke medlem af nogen gruppe'),
(85512, 6598, 22, 'Denne uge til dato'),
(85513, 6625, 22, 'Hals'),
(85514, 6629, 22, 'Tor'),
(85515, 6630, 22, 'torsdag'),
(85516, 6631, 22, 'Torsdag'),
(85517, 6632, 22, 'Sköldkörtel normal'),
(85518, 6638, 22, 'Tid'),
(85519, 6647, 22, 'Fastsat begivenhed'),
(85520, 6649, 22, 'Tidsstämpel och Text'),
(85521, 6652, 22, 'Titel'),
(85522, 6655, 22, 'Titler'),
(85523, 6658, 22, 'Til'),
(85524, 6659, 22, 'TIL'),
(85525, 6660, 22, 'til'),
(85526, 6662, 22, 'Gå til TILFØJ NOTER, tryk '),
(85527, 6663, 22, 'Gå til TILFØJ NOTER, tryk her'),
(85528, 6664, 22, 'På det påverkade området'),
(85529, 6665, 22, 'på det påverkade området'),
(85530, 6667, 22, 'Gå til regningsoversigt'),
(85531, 6668, 22, 'Gå til kategori'),
(85532, 6670, 22, 'Gå til medbetalere'),
(85533, 6679, 22, 'Gå til aftaler'),
(85534, 6680, 22, 'Sorter efter køn'),
(85535, 6681, 22, 'Gå til Historik'),
(85536, 6682, 22, 'Gå til emner'),
(85537, 6684, 22, 'För att länka detta besök till objekt i ovanstående lista, markera önskade objekt och klicka sedan på [spara]. Håll ner [Ctrl] för att markera fler objekt.'),
(85538, 6685, 22, 'Gå til Log på igen'),
(85539, 6689, 22, 'På huden'),
(85540, 6690, 22, 'På huden'),
(85541, 6691, 22, 'Gå til denne aftale?'),
(85542, 6693, 22, 'Til:'),
(85543, 6694, 22, 'Til: '),
(85544, 6708, 22, 'Tobak'),
(85545, 6712, 22, 'Tobaks användande'),
(85546, 6715, 22, 'Idag'),
(85547, 6717, 22, 'idag'),
(85548, 6720, 22, 'Dags dato'),
(85549, 6721, 22, 'Dagens begivenheder'),
(85550, 6726, 22, 'Tonsillektomi'),
(85551, 6728, 22, 'Top'),
(85552, 6730, 22, 'Emne'),
(85553, 6731, 22, 'total'),
(85554, 6732, 22, 'Total'),
(85555, 6737, 22, 'Total beløb'),
(85556, 6738, 22, 'Totalt beløb betalt'),
(85557, 6741, 22, 'Total opkrævning'),
(85558, 6742, 22, 'Totalt antal Kunder'),
(85559, 6743, 22, 'Total udgift'),
(85560, 6744, 22, 'T'),
(85561, 6748, 22, 'Totalt for'),
(85562, 6749, 22, 'Totalt for '),
(85563, 6750, 22, 'Totalt for kategori'),
(85564, 6752, 22, 'Nye påmindelser total'),
(85565, 6756, 22, 'Emner total'),
(85566, 6758, 22, 'Totalt antal patienter'),
(85567, 6761, 22, 'Patienter total'),
(85568, 6776, 22, 'Totaler'),
(85569, 6777, 22, 'Totaler for'),
(85570, 6778, 22, 'Totaler for '),
(85571, 6785, 22, 'Utbildnings sort'),
(85572, 6786, 22, 'Transaktion'),
(85573, 6787, 22, 'Transaktion'),
(85574, 6788, 22, 'Transaktion'),
(85575, 6789, 22, 'Transaktion mislykkedes, insufficient kvantitet i destination lot'),
(85576, 6790, 22, 'Transaktionen mislykkedes, beløbet er mindre end nul'),
(85577, 6791, 22, 'Transaktionstype'),
(85578, 6792, 22, 'Transaktioner'),
(85579, 6793, 22, 'Transaktioner'),
(85580, 6794, 22, 'Transaktioner (tekst valgfri)'),
(85581, 6795, 22, 'Transaktioner / Övergångar'),
(85582, 6797, 22, 'Overførsel'),
(85583, 6804, 22, 'Overførsler'),
(85584, 6813, 22, 'Oversæt dette'),
(85585, 6814, 22, 'Oversættelse'),
(85586, 6815, 22, 'Oversættelser'),
(85587, 6819, 22, 'Traume'),
(85588, 6820, 22, 'Behandling'),
(85589, 6822, 22, 'Behandlings mål'),
(85590, 6823, 22, 'Behandlingsplan'),
(85591, 6826, 22, 'Behandling:'),
(85592, 6827, 22, 'Behandling: '),
(85593, 6837, 22, 'tesked'),
(85594, 6841, 22, 'Tir'),
(85595, 6842, 22, 'Tirsdag og Torsdag'),
(85596, 6843, 22, 'Tirsdag'),
(85597, 6844, 22, 'Tumör'),
(85598, 6848, 22, 'To gange dagligt'),
(85599, 6851, 22, 'Skriv'),
(85600, 6855, 22, 'Type af begivenhed'),
(85601, 6857, 22, 'Skriv in eller skanna patientidentifikation här'),
(85602, 6866, 22, 'Ulcerations'),
(85603, 6867, 22, 'Ulcerös kolit'),
(85604, 6868, 22, 'Sår:'),
(85605, 6871, 22, 'Ikke muligt at oprette'),
(85606, 6877, 22, 'Ikke tildelt'),
(85607, 6880, 22, 'Obehörig åtkomst.'),
(85608, 6884, 22, 'Under tungen'),
(85609, 6885, 22, 'Undervægtig'),
(85610, 6886, 22, 'Udianogstiseret'),
(85611, 6890, 22, 'Fortryd betaling'),
(85612, 6892, 22, 'Unika Kunder'),
(85613, 6894, 22, 'Unika nya kunder'),
(85614, 6899, 22, 'Enhed'),
(85615, 6900, 22, 'Enheder'),
(85616, 6901, 22, 'Enheder'),
(85617, 6903, 22, 'Enheder skal være tal'),
(85618, 6904, 22, 'Enheder skal være tal'),
(85619, 6907, 22, 'Ukendt'),
(85620, 6911, 22, 'Okänd eller N / A'),
(85621, 6914, 22, 'Namnlöst försäkringsbolag'),
(85622, 6915, 22, 'Uregistreret'),
(85623, 6918, 22, 'Fravælg alle'),
(85624, 6919, 22, 'Uvalgt'),
(85625, 6920, 22, 'Uspecifiseret'),
(85626, 6924, 22, 'Indtil'),
(85627, 6926, 22, 'Ubrugt'),
(85628, 6928, 22, 'Op til'),
(85629, 6929, 22, 'Kommende aftaler'),
(85630, 6930, 22, 'Kommende begivenheder'),
(85631, 6931, 22, 'Opdatere'),
(85632, 6932, 22, 'Opdatere'),
(85633, 6934, 22, 'Opdater filer'),
(85634, 6935, 22, 'Opdater info'),
(85635, 6936, 22, 'Opdater liste'),
(85636, 6940, 22, 'Opdater bruger information'),
(85637, 6946, 22, 'Opgradere'),
(85638, 6947, 22, 'Opgrader database'),
(85639, 6951, 22, 'Hent dokument'),
(85640, 6955, 22, 'Hent dokument'),
(85641, 6957, 22, 'Hent billede til'),
(85642, 6958, 22, 'Hent importeret fil'),
(85643, 6961, 22, 'Hent rapport'),
(85644, 6963, 22, 'Hent denne fil'),
(85645, 6966, 22, 'Överarmen'),
(85646, 6968, 22, 'Brådskande'),
(85647, 6972, 22, 'Urin Frekvens'),
(85648, 6973, 22, 'Urin Tveksamhet'),
(85649, 6977, 22, 'URL'),
(85650, 6988, 22, 'Anvend 24timers format?'),
(85651, 7000, 22, 'Anvend standart'),
(85652, 7002, 22, 'Använd internationellt utseende på datum?'),
(85653, 7006, 22, 'Anvend emne?'),
(85654, 7007, 22, 'Bruger'),
(85655, 7009, 22, 'Bruger/Gruppe'),
(85656, 7010, 22, 'Bruger administration'),
(85657, 7011, 22, 'Användar-och Facility Administration'),
(85658, 7012, 22, 'Användare och grupp Administration'),
(85659, 7015, 22, 'Bruger defineret'),
(85660, 7016, 22, 'Användar definierad Area 11'),
(85661, 7017, 22, 'Användar definierad Area 12'),
(85662, 7040, 22, 'Användare Medlemskap'),
(85663, 7041, 22, 'Brugernavn'),
(85664, 7043, 22, 'Bruger- eller hostnavn'),
(85665, 7046, 22, 'Brugeropsætning'),
(85666, 7049, 22, 'Brugernavn'),
(85667, 7052, 22, 'Brugernavn for SMS gateway'),
(85668, 7055, 22, 'Brugernavn:'),
(85669, 7056, 22, 'Brugere'),
(85670, 7057, 22, 'Användare / grupper / Logs Administration'),
(85671, 7062, 22, 'FERIE'),
(85672, 7063, 22, 'Ferie'),
(85673, 7064, 22, 'Vaccination'),
(85674, 7068, 22, 'Værdi'),
(85675, 7069, 22, 'Værdi 1'),
(85676, 7070, 22, 'Værdi 2'),
(85677, 7079, 22, 'Blodkärls kondition'),
(85678, 7080, 22, 'Blodkärsl skada'),
(85679, 7081, 22, 'Kärlkirurgi'),
(85680, 7084, 22, 'Version'),
(85681, 7085, 22, 'Svindel'),
(85682, 7090, 22, 'vis'),
(85683, 7091, 22, 'Vis'),
(85684, 7092, 22, 'Vis allergier'),
(85685, 7097, 22, 'Visa Omfattande Patient Rapport'),
(85686, 7100, 22, 'Vis dokument'),
(85687, 7101, 22, 'Vis aftale'),
(85688, 7103, 22, 'Vis begivenheder i et pop-up-vindue?'),
(85689, 7108, 22, 'Vis side 1'),
(85690, 7109, 22, 'Vis side 2'),
(85691, 7111, 22, 'Vis patient'),
(85692, 7116, 22, 'Vis relaterede aftaler'),
(85693, 7121, 22, 'Vis/rediger allergier'),
(85694, 7122, 22, 'Vis/rediger emner'),
(85695, 7123, 22, 'Vis/print'),
(85696, 7124, 22, 'Vis:'),
(85697, 7125, 22, 'VISA'),
(85698, 7126, 22, 'VISA/MC/AMEX/Dis'),
(85699, 7127, 22, 'Visceral skada / trauma / kirurgi'),
(85700, 7133, 22, 'Aftalekategori'),
(85701, 7134, 22, 'Aftaledato'),
(85702, 7138, 22, 'Aftalehistorik'),
(85703, 7140, 22, 'Aftaler'),
(85704, 7141, 22, 'Aftaler fra'),
(85705, 7143, 22, 'Livsvigtig'),
(85706, 7144, 22, 'Livsviktiga (metriska)'),
(85707, 7146, 22, 'Stemme'),
(85708, 7147, 22, 'Stemme sendt'),
(85709, 7149, 22, 'Kräkningar'),
(85710, 7151, 22, 'W'),
(85711, 7154, 22, 'Venter'),
(85712, 7162, 22, 'Varm'),
(85713, 7164, 22, 'ADVARSEL'),
(85714, 7166, 22, 'Advarsel, cheknummer eksisterer allerede i databasen'),
(85715, 7168, 22, 'Advarsel: Der er allerede booket en aftale med denne patient i dag!'),
(85716, 7170, 22, 'Varning: patient-ID är inte unikt!'),
(85717, 7175, 22, 'Er allerede hentet'),
(85718, 7179, 22, 'Svaghed'),
(85719, 7182, 22, 'Hjemmeside'),
(85720, 7184, 22, 'Ons'),
(85721, 7185, 22, 'Onsdag'),
(85722, 7186, 22, 'Uge'),
(85723, 7187, 22, 'uge'),
(85724, 7188, 22, 'Ugeoversigt'),
(85725, 7189, 22, 'Uge(r)'),
(85726, 7192, 22, 'Uger'),
(85727, 7193, 22, 'Vægt'),
(85728, 7196, 22, 'Vægtforandring'),
(85729, 7197, 22, 'Vægttab'),
(85730, 7199, 22, 'Velkommen'),
(85731, 7202, 22, 'Hvad skal tælles?'),
(85732, 7205, 22, 'Wheezing:'),
(85733, 7211, 22, 'Whiplash'),
(85734, 7212, 22, 'Hvid'),
(85735, 7213, 22, 'Hvem'),
(85736, 7214, 22, 'Hvem har svaret?'),
(85737, 7215, 22, 'Enke'),
(85738, 7221, 22, 'Med valgte:'),
(85739, 7222, 22, 'Med gammelt navn'),
(85740, 7224, 22, 'Med vem kan vi lämna ett meddelande?'),
(85741, 7226, 22, 'inom några timmar'),
(85742, 7227, 22, 'inom några timmar:'),
(85743, 7228, 22, 'inom några minuter'),
(85744, 7229, 22, 'inom några minuter:'),
(85745, 7232, 22, 'Uden opdatering'),
(85746, 7233, 22, 'Vine'),
(85747, 7237, 22, 'Kvinder'),
(85748, 7238, 22, 'Kun kvinder'),
(85749, 7240, 22, 'Arbejde'),
(85750, 7242, 22, 'Telefon, arbejde'),
(85751, 7243, 22, 'Tlf.nr., arbejde'),
(85752, 7244, 22, 'Arbejdsrelateret?'),
(85753, 7245, 22, 'Arbete/ Utbildning/ Hobby'),
(85754, 7246, 22, 'Arbete / Skola Anmärkning'),
(85755, 7247, 22, 'Arbejdsdag'),
(85756, 7252, 22, 'Forværret'),
(85757, 7258, 22, 'Vil du slette indbetaling?'),
(85758, 7260, 22, 'Vil du ændre indbetaling?'),
(85759, 7263, 22, 'Vil du gemme?'),
(85760, 7264, 22, 'Håndled'),
(85761, 7265, 22, 'Håndled og hånd'),
(85762, 7266, 22, 'Håndledsproblemer'),
(85763, 7267, 22, 'skriv'),
(85764, 7268, 22, 'Skrive af'),
(85765, 7274, 22, 'x inställt'),
(85766, 7275, 22, 'Røntgen'),
(85767, 7276, 22, 'Røntgen tolkning'),
(85768, 7277, 22, 'Røntgen tolkning'),
(85769, 7278, 22, 'Endast X12: Ersättningskrav '),
(85770, 7279, 22, 'X12 Partner'),
(85771, 7280, 22, 'X12 Partners'),
(85772, 7284, 22, 'Y'),
(85773, 7285, 22, 'År'),
(85774, 7286, 22, 'år'),
(85775, 7287, 22, 'Vis År'),
(85776, 7288, 22, 'År'),
(85777, 7289, 22, 'År'),
(85778, 7292, 22, 'JA'),
(85779, 7293, 22, 'Ja'),
(85780, 7294, 22, 'ja'),
(85781, 7295, 22, 'JA!'),
(85782, 7296, 22, 'JA, slet og log'),
(85783, 7298, 22, 'Ja/Nej'),
(85784, 7299, 22, 'Ja:'),
(85785, 7303, 22, 'Du håller på att permanent ersätta den befintliga mallen. Är du säker på att du vill fortsätta?'),
(85786, 7305, 22, 'Det er ikke tilladt at slette denne begivenhed'),
(85787, 7306, 22, 'Det er ikke tilladt at ændre denne begivenhed'),
(85788, 7307, 22, 'Du har ikke rettigheder til dette.'),
(85789, 7308, 22, 'Du har inte behörighet att komma åt den här gruppen.'),
(85790, 7309, 22, 'Du har inte behörighet att lägga till / redigera frågor'),
(85791, 7310, 22, 'Du har ikke rettigheder til at planlægge aftaler.'),
(85792, 7311, 22, 'Du har ikke rettigheder til at se denne aftale'),
(85793, 7313, 22, 'Du kan inte komma åt denna funktion direkt.'),
(85794, 7314, 22, 'Du kan inte komma åt den här sidan direkt.'),
(85795, 7319, 22, 'Du har inte valt några åtgärder.'),
(85796, 7320, 22, 'Du har inte behörighet att se / redigera denna anmärkning'),
(85797, 7323, 22, 'Du kan kun hente tekstfiler'),
(85798, 7329, 22, 'Du skal først vælge eller tilføje en patient'),
(85799, 7330, 22, 'Du skal først vælge eller oprette en aftale'),
(85800, 7333, 22, 'Du måste välja några områden för att fortsätta.'),
(85801, 7335, 22, 'Du skal vælge mindst en sammenhæng'),
(85802, 7339, 22, 'Din slutdato er ugyldig'),
(85803, 7340, 22, 'Din aftale er slettet'),
(85804, 7341, 22, 'Din aftale er ændret'),
(85805, 7342, 22, 'Din aftale er tilføjet'),
(85806, 7343, 22, 'Din fil er for stor'),
(85807, 7345, 22, 'Din namnlista har ändrats för att uppfylla namngivnings krav.'),
(85808, 7349, 22, 'Dit kodeord er udløbet, Skift kodeord'),
(85809, 7350, 22, 'Dit kodeord udløber til'),
(85810, 7351, 22, 'Dit kodeord udløber i dag, opret venligst et nyt'),
(85811, 7353, 22, 'Din Post Kalender konfiguration har återställts att använda standardvärden.'),
(85812, 7354, 22, 'Din Post Kalender konfiguration har uppdaterats.'),
(85813, 7355, 22, 'Den upprepade frekvens måste vara ett heltal.'),
(85814, 7356, 22, 'Den upprepade frekvensen måste vara minst 1.'),
(85815, 7357, 22, 'Ditt startdatum är större än ditt slutdatum'),
(85816, 7358, 22, 'Din startdato er ugyldig'),
(85817, 7359, 22, 'Din tilføjelse mislykkedes'),
(85818, 7360, 22, 'åååå-mm-dd'),
(85819, 7361, 22, 'ÅÅÅÅ-MM-DD'),
(85820, 7362, 22, 'ÅÅÅÅ-MM-DD-dato har sammenhæng med dette dokument'),
(85821, 7363, 22, 'ÅÅÅÅ-MM-DD-dato er ødelagt'),
(85822, 7364, 22, 'ÅÅÅÅ-MM-DD fødselsdato'),
(85823, 7365, 22, 'ÅÅÅÅ-MM-DD fødselsdato'),
(85824, 7366, 22, 'ÅÅÅÅ-MM-DD udløbsdato'),
(85825, 7367, 22, 'åååå-mm-dd Datum för uppkomsten eller sjukhusvistelse'),
(85826, 7368, 22, 'åååå-mm-dd datum debut, kirurgi eller början av medicinering'),
(85827, 7369, 22, 'ÅÅÅÅ-MM-DD-dato for køb eller transaktion'),
(85828, 7370, 22, 'åååå-mm-dd dagen för tillfrisknande eller slutet av medicinering'),
(85829, 7372, 22, 'ÅÅÅÅ-MM-DD-dato for service'),
(85830, 7373, 22, 'ÅÅÅÅ-MM-DD-dato for dette brev'),
(85831, 7375, 22, 'åååå-mm-dd dokumentets datum'),
(85832, 7376, 22, 'åååå-mm-dd händelse datum eller startdatum'),
(85833, 7383, 22, 'ÅÅÅÅ-MM-DD sidste dato for denne aftale'),
(85834, 7387, 22, 'Nul'),
(85835, 7389, 22, 'postadress'),
(85836, 7390, 22, 'postnummer'),
(85837, 7391, 22, 'land'),
(85838, 7393, 22, ' men var '),
(85839, 7394, 22, ' Ikke tilgængelig'),
(85840, 7395, 22, 'Vil du virkelig slette?'),
(85841, 7396, 22, 'Lægemiddel'),
(85842, 7397, 22, 'email blev ikke sendt'),
(85843, 7398, 22, 'fra'),
(85844, 7399, 22, 'Er skabt '),
(85845, 7400, 22, 'Er genåbnet'),
(85846, 7401, 22, 'Historie'),
(85847, 7402, 22, 'er ikke et nummer'),
(85848, 7403, 22, 'är redo för ny fakturering'),
(85849, 7404, 22, 'LLL:'),
(85850, 7405, 22, 'Lot'),
(85851, 7406, 22, 'Medicaid orginal referensnr. '),
(85852, 7407, 22, 'min'),
(85853, 7408, 22, 'Ikke fundet!'),
(85854, 7411, 22, 'Indtil'),
(85855, 7412, 22, 'Opdatering mislykkedes, ikke i databasen?'),
(85856, 7413, 22, 'Er kun markeret som faktureret'),
(85857, 7414, 22, 'var kö framgångsrikt.'),
(85858, 7415, 22, '! Lämnat utan besök'),
(85859, 7416, 22, '"För kod'),
(85860, 7417, 22, 'Kontrolleras PostCalendar Inställningar! "'),
(85861, 7420, 22, 'kr'),
(85862, 7421, 22, 'Kodningen av kronor är färdig'),
(85863, 7422, 22, '$ etikett (åååå-mm-dd): '),
(85864, 7423, 22, '%'),
(85865, 7425, 22, '% Annullerat <24h '),
(85866, 7426, 22, 'Burde eksistere, men gør ikke'),
(85867, 7427, 22, '(% Matchar alla strängar, _ matchar alla tecken)'),
(85868, 7429, 22, '(tilbage)'),
(85869, 7430, 22, '(tryk for at redigere)'),
(85870, 7432, 22, '(mere)'),
(85871, 7433, 22, '(Ny Patient)'),
(85872, 7434, 22, '(bemærkninger og tilladelser)'),
(85873, 7435, 22, '(patientnoter)'),
(85874, 7436, 22, '(vælg en af disse eller opret din egen titel)'),
(85875, 7438, 22, '* påmindelse sendt'),
(85876, 7440, 22, '* Obligatorisk'),
(85877, 7441, 22, '#ERROR!:parse'),
(85878, 7445, 22, '.'),
(85879, 7447, 22, '0-10'),
(85880, 7457, 22, '1.Vila 2. Lägg på is i två dagar 3. Komprimering lämna förbandet på plats om inte foten utvecklar domningar eller blek färg 4. Ha foten och ben i Upphöjt läge.'),
(85881, 7458, 22, '11-14'),
(85882, 7460, 22, '15-19'),
(85883, 7468, 22, '20-24'),
(85884, 7477, 22, '2111-13'),
(85885, 7479, 22, '25+'),
(85886, 7480, 22, '25-29'),
(85887, 7481, 22, '2:a'),
(85888, 7483, 22, '3 måneder'),
(85889, 7485, 22, '3 gange om dagen'),
(85890, 7487, 22, '30-34'),
(85891, 7488, 22, '35-39'),
(85892, 7489, 22, 'tredje'),
(85893, 7491, 22, '4 måneder'),
(85894, 7493, 22, '4 gange om dagen'),
(85895, 7495, 22, '40-44'),
(85896, 7496, 22, '45+'),
(85897, 7504, 22, 'fjerde'),
(85898, 7509, 22, 'femte'),
(85899, 7511, 22, '6 måneder'),
(85900, 7514, 22, 'sjette'),
(85901, 7526, 22, '99212 Etablerade - okomplicerad'),
(85902, 7527, 22, '99213 Etablerade - Låg komplexitet'),
(85903, 7528, 22, '< På klinikken'),
(85904, 7529, 22, '> Afsluttet'),
(85905, 7531, 22, '? Udeblevet'),
(85906, 7532, 22, '@ Ankommet'),
(85907, 7533, 22, '[Ändra vy]'),
(85908, 7534, 22, '[Dato for seneste aftale]'),
(85909, 7535, 22, '[Dage siden sidste aftale]'),
(85910, 7538, 22, '[rekommenderas inte]'),
(85911, 7539, 22, '[Antal aftaler]'),
(85912, 7540, 22, '[Rapporter]'),
(85913, 7541, 22, '[Vælg alle]'),
(85914, 7542, 22, '[SQL-Ledger]'),
(85915, 7543, 22, '[Starta batchprocess]'),
(85916, 7544, 22, '[Se log]'),
(85917, 7545, 22, '[Se printbar rapport]'),
(85918, 7549, 22, '~kommet for sent'),
(85919, 1, 23, 'Bir'),
(85920, 2, 23, 'Ödemeyi tanımlamak için bir çek numarası veya talep numarası'),
(85921, 3, 23, 'Yönetici kullanıcısı için bir müşteri sertifikası'),
(85922, 4, 23, 'Bir klinik belge ekli'),
(85923, 5, 23, 'Bir klinik belge ekli'),
(85924, 7, 23, 'Bir bayi gerekiyor'),
(85925, 8, 23, 'Bu kayda Jenerik Bağlantı Kabul Kontrol  vizit formunun eklenmesi gerekiyor.'),
(85926, 9, 23, 'Bir parti numarası gerekiyor.'),
(85927, 10, 23, 'Bir parti numarası gerekiyor!'),
(85928, 11, 23, 'Bir küçük harf'),
(85929, 12, 23, 'Bir sayı'),
(85930, 14, 23, 'Bu ID ile önceden kayıtlı bir hasta var.'),
(85931, 15, 23, 'Bu isim ile önceden kayıtlı bir hasta var.'),
(85932, 16, 23, 'Bu SGK numarası ile önceden kayıtlı bir hasta var.'),
(85933, 17, 23, 'Hasta RandevularıÖzeti Sihirbazında artı bir sayı geçmişte pek çok randevu olduğunu gösterir. ( Eksi bir sayı eski randevuları azalan sırada gösterir.)'),
(85934, 18, 23, 'Hasta RandevularıÖzeti Sihirbazında artı bir sayı geçmişte pek çok randevu olduğunu gösterir.'),
(85935, 19, 23, 'Her vizite için sevk eden bir kaynak belirtilebilir.'),
(85936, 20, 23, 'İlgili bir IPPF kodu gerekiyor!'),
(85937, 21, 23, 'Özel bir karakter'),
(85938, 22, 23, 'Bu alanı tanımlayacak,kullanıcıya görünmeyen, benzersiz bir değer'),
(85939, 23, 23, 'Bu hastanın bu gün için önceden kayıtlı bir randevusu var. Bu randevuyu açmam için İptali tıklayınız. Yeni bir randevu oluşturmak için Tamamı tıklayınız.'),
(85940, 24, 23, 'yemekten önce'),
(85941, 25, 23, 'öğleden önce'),
(85942, 26, 23, 'A/F Sağ Düzey'),
(85943, 27, 23, 'AB'),
(85944, 28, 23, 'Kısaltma'),
(85945, 29, 23, 'Abse'),
(85946, 30, 23, 'Abdominal'),
(85947, 31, 23, 'Dört (4) Basamak Ağırlık Taşıyabilir:'),
(85948, 32, 23, 'Abn'),
(85949, 33, 23, 'ABN1'),
(85950, 34, 23, 'Anormal'),
(85951, 35, 23, 'Anormal kan testi'),
(85952, 36, 23, 'Anormal tüylenme'),
(85953, 37, 23, 'Anormal Mamografi filmi'),
(85954, 39, 23, 'Düşük'),
(85955, 40, 23, 'Düşük Konuları'),
(85956, 41, 23, 'Düşük Yöntemi'),
(85957, 42, 23, 'Düşük ile İlgili Kategoriler'),
(85958, 43, 23, 'Düşükler'),
(85959, 44, 23, 'Takvim Hakkında'),
(85960, 46, 23, 'Tanıya göre Devamsızlıklar'),
(85961, 47, 23, 'Görevi Kabul'),
(85962, 48, 23, 'İçin ödeme kabul'),
(85963, 49, 23, 'İçin Ödeme Kabul'),
(85964, 50, 23, 'Görevi Kabul Eder'),
(85965, 51, 23, 'Erişim Kontrolü'),
(85966, 52, 23, 'Erişim Kontrolü Listesi Yönetimi'),
(85967, 53, 23, 'Erişim tarihi'),
(85968, 54, 23, 'Erişime izin verilmiyor'),
(85969, 55, 23, 'Erişme yetkiniz yok'),
(85970, 56, 23, 'Hasta Kaydı Erişiminiz'),
(85971, 57, 23, 'Kaza'),
(85972, 59, 23, 'Hesap Adı'),
(85973, 62, 23, 'Muhasebe'),
(85974, 64, 23, 'Ağrıları'),
(85975, 65, 23, 'Alındı İsteniyor (ISA14)'),
(85976, 66, 23, 'Teşekkürler, Lisans ve Sertifikasyon'),
(85977, 67, 23, 'EKL'),
(85978, 68, 23, 'EKL Yönetimi'),
(85979, 69, 23, 'EKL Yönetimine İzin Verilmiyor'),
(85980, 70, 23, 'EKL başarı ile güncellendi'),
(85981, 71, 23, 'Akne'),
(85982, 72, 23, 'Resmi yazı'),
(85983, 73, 23, 'Resmi yazı tarihi'),
(85984, 74, 23, 'Eylem'),
(85985, 75, 23, 'Eylemler'),
(85986, 77, 23, 'CCR/CCD raporlamayı etkinleştir'),
(85987, 78, 23, 'Aktif'),
(85988, 79, 23, 'Etkin Uyarı'),
(85989, 80, 23, 'Etkin Uyarı Kralları'),
(85990, 81, 23, 'Etkin Uyarılar/Anımsatıcılar'),
(85991, 82, 23, 'Aktif görüşme'),
(85992, 84, 23, 'Aktif listeler'),
(85993, 85, 23, 'Aktif Hasta'),
(85994, 86, 23, 'Aktif Planlar'),
(85995, 87, 23, 'Aktivite'),
(85996, 88, 23, 'Aktivite Tipi'),
(85997, 90, 23, 'Akut Zehirlenme/Yoksunluk'),
(85998, 91, 23, 'Kronik hastalığın Akut Belirtileri'),
(85999, 92, 23, 'Kronik Alevlenmesi'),
(86000, 93, 23, 'ekle'),
(86001, 94, 23, 'Ekle'),
(86002, 95, 23, 'EKLE'),
(86003, 96, 23, 'Bir Şirket Ekle'),
(86004, 98, 23, 'Bir Eczane Ekle'),
(86005, 100, 23, 'için bir olay ekle '),
(86006, 101, 23, 'Yeni bir not olarak ekle'),
(86007, 102, 23, 'Yeni Olarak Ekle'),
(86008, 104, 23, 'Ekle Düğmeleri'),
(86009, 105, 23, 'Özel karakterlerin, metinlerin bir tıklama ile metine eklenmeleri için editörün üst kısmında görülen düğmeler'),
(86010, 106, 23, 'Kategori Ekle'),
(86011, 107, 23, 'Sabit Ekle'),
(86012, 108, 23, 'İçerik Ekle'),
(86013, 109, 23, 'Katkı payı ekle'),
(86014, 110, 23, 'Kriter ekle'),
(86015, 111, 23, 'Özel Düğme Ekle'),
(86016, 112, 23, 'Tanı Ekle'),
(86017, 113, 23, 'İlaç Ekle'),
(86018, 114, 23, 'Görüşme Ekle'),
(86019, 115, 23, 'Görüşme/notlar ekle'),
(86020, 116, 23, 'Tesis Ekle'),
(86021, 117, 23, 'Alan Ekle'),
(86022, 118, 23, 'Aşağıdaki satırları Apache konfigürasyon dosyasına ekleyiniz.'),
(86023, 119, 23, 'Grup Ekle'),
(86024, 120, 23, 'ICD kodu Ekle'),
(86025, 121, 23, 'Aşılama Ekle'),
(86026, 122, 23, 'Eklemeye izin verilmiyor!'),
(86027, 123, 23, 'Konu Ekle'),
(86028, 124, 23, 'İzlenecek başlık ekleyin'),
(86029, 125, 23, 'Dil Ekle'),
(86030, 126, 23, 'Yeni Ekle'),
(86031, 127, 23, 'Yeni ekle'),
(86032, 128, 23, 'Yeni kategori ekle: '),
(86033, 129, 23, 'Apache konfigürasyon dosyasına yeni sertifikalar ekle'),
(86034, 130, 23, 'Yeni bileşen ekle'),
(86035, 131, 23, 'Yeni bileşenler ekle'),
(86036, 132, 23, 'Yeni Grup Ekle'),
(86037, 133, 23, 'Yeni Konu Ekle'),
(86038, 134, 23, 'Yeni parti ve işlem ekle'),
(86039, 135, 23, 'Yeni Not Ekle'),
(86040, 136, 23, 'Yeni not ekle'),
(86041, 137, 23, 'Yeni Tedarikçi Ekle'),
(86042, 138, 23, 'Yeni Hasta Ekle'),
(86043, 140, 23, 'Not Ekle'),
(86044, 141, 23, 'Hasta Kaydı Ekle'),
(86045, 142, 23, 'Reçete Ekle'),
(86046, 143, 23, 'İşlem Ekle'),
(86047, 144, 23, 'Tedarikçi Numarası Ekle'),
(86048, 145, 23, 'Rehab Ekle'),
(86049, 146, 23, 'Kural Ekle'),
(86050, 147, 23, 'Eklenecek yer:'),
(86051, 148, 23, 'İlaç Listesine Ekle'),
(86052, 149, 23, 'En üst düzeye ekle'),
(86053, 150, 23, 'İşlem Ekle'),
(86054, 151, 23, 'Kullanıcı Ekle'),
(86055, 152, 23, 'Kullanıcıyı Gruba Ekle:'),
(86056, 153, 23, 'eReçete Ekle/Düzenle'),
(86057, 154, 23, 'Hasta İşlemi Ekle/Düzenle'),
(86058, 155, 23, 'eklendi'),
(86059, 156, 23, 'Demografi eklenmesine izin verilmiyor.'),
(86060, 157, 23, 'İzlenecek başlık eklenmesi başarısız oldu'),
(86061, 158, 23, 'Addison Sendromu'),
(86062, 159, 23, 'Addison Sendromu'),
(86063, 160, 23, 'Ek Nitelikler'),
(86064, 161, 23, 'Ek Tanı:'),
(86065, 162, 23, 'Ek Öykü'),
(86066, 163, 23, 'Ek öykü notları'),
(86067, 164, 23, 'Ek Bilgi'),
(86068, 165, 23, 'Ek Laboratuvarlar'),
(86069, 166, 23, 'Ek Notlar'),
(86070, 167, 23, 'Bu sonuç veya öneri için ek notlar'),
(86071, 168, 23, 'Ek Notlar:'),
(86072, 169, 23, 'Ek Notlar: '),
(86073, 170, 23, 'Ek Röntgen filmi Notları:'),
(86074, 171, 23, 'Ek olarak, ilgili Somed uzantısı paketi uluslararası (İngilizce versiyon) Snomed Sürümünü kurduktan sonra ayrıca eklenebilir.'),
(86075, 172, 23, 'sadece eklenir'),
(86076, 173, 23, 'Adres Def'),
(86077, 174, 23, 'Adres Defteri'),
(86078, 175, 23, 'Adres'),
(86079, 178, 23, 'Adres Defteri'),
(86080, 179, 23, 'Bu işlemi yapan şirketin adres defteri kaydı'),
(86081, 180, 23, 'Distribütör için adres girdisi'),
(86082, 181, 23, 'Satıcının adres defteri kaydı'),
(86083, 182, 23, 'Adres Defteri Tipleri'),
(86084, 183, 23, 'Adres Etiketi'),
(86085, 187, 23, 'Adres1'),
(86086, 188, 23, 'Adres2'),
(86087, 189, 23, 'ALACAK OLAN'),
(86088, 190, 23, 'Dzn'),
(86089, 191, 23, 'Düzeltilmiş Miktar'),
(86090, 192, 23, 'Düzenle'),
(86091, 193, 23, 'Düzenleme'),
(86092, 194, 23, 'Düzeltilen miktar'),
(86093, 195, 23, 'Düzenleme Nedenleri'),
(86094, 196, 23, 'Kaynak için düzenleme değeri '),
(86095, 197, 23, 'Düzenlemeler'),
(86096, 198, 23, 'Yntm düzenle'),
(86097, 199, 23, 'Yönetici'),
(86098, 200, 23, 'Yönetim Eposta Adresi'),
(86099, 201, 23, 'Yönetim Yolu:'),
(86100, 202, 23, 'Yönetildi'),
(86101, 203, 23, 'Yöneten:'),
(86102, 204, 23, 'Uygulandığı tarih'),
(86103, 205, 23, 'Uygulandığı Yer'),
(86104, 206, 23, 'Yönetim'),
(86105, 207, 23, 'Uygulama Yeri'),
(86106, 208, 23, 'Yöneticiler'),
(86107, 209, 23, 'Yöneticiler her şeyi yapabilir.'),
(86108, 210, 23, 'Kabul tarihi'),
(86109, 212, 23, 'Erişkin Ağırlık Tarama ve İzlemi'),
(86110, 213, 23, 'Erişkin Ağırlık Tarama ve İzlemi (KYM)'),
(86111, 214, 23, 'Avans Yönergesi'),
(86112, 215, 23, 'Avans Yönergeleri'),
(86113, 216, 23, 'Avans Yönergeleri Uyarısı'),
(86114, 218, 23, 'İleri'),
(86115, 219, 23, 'Tavsiye'),
(86116, 220, 23, 'Uzaktan'),
(86117, 221, 23, 'Normal affekt'),
(86118, 222, 23, 'Afrikaca'),
(86119, 223, 23, 'saat icap sonrası'),
(86120, 224, 23, 'Şifrelerin kullanıcı tablosunda saklandığı eski şifre yönteminden geçiş yaotıktan sonra sadece yeni yöntem ile kimlik doğrulamasının yapılabilmesi için bu bayrak false olarak işaretlenmelidir'),
(86121, 225, 23, 'Yukarıdaki konfigürasyonu uyguladıktan sonra yönetici müşterisi sertifikasını tarayıcıya ekleyiniz ve Apache sunucusunu (boş şifre ile) tekrar başlatınız.'),
(86122, 226, 23, 'PDF yi kaydettikten sonra hataları kontrol etmek için [Kaydı Gör] ü tıklayınız.'),
(86123, 227, 23, 'TEXT dosyalarını kaydettikten sonra hataları kontrol etmek için [Kaydı Gör] ü tıklayınız.'),
(86124, 228, 23, 'BAT dosyanızı kaydettikten sonra hataları kontrol etmek için [Kaydı Gör] ü tıklayınız.'),
(86125, 229, 23, 'Ondan sonra uyum sütununda hasta kimlik numarası veya yenisinin oluşturulması için 0 görülür.'),
(86126, 230, 23, 'Bilgi doğru olarak girildikten sonra Kaydet düğmesini tıklayınız'),
(86127, 231, 23, 'Yükledikten sonra "İçe Aktar" düğmesini tıklayınız'),
(86128, 232, 23, 'Sonraki Bakım Planlaması'),
(86129, 233, 23, 'Tekrar'),
(86130, 234, 23, 'Yaş'),
(86131, 235, 23, 'Yaşı :'),
(86132, 236, 23, 'Yaş Kategorisi'),
(86133, 237, 23, 'Yaş verisi erim dışında'),
(86134, 238, 23, 'Yaş gösteriliş kalıbı'),
(86135, 239, 23, '"yaşından itibaren" Yaş kalıbı geçerli değil'),
(86136, 240, 23, '"yaşına kadar" Yaş kalıbı geçerli değil'),
(86137, 241, 23, 'Yaşından İtibaren'),
(86138, 242, 23, 'Yıl olarak Yaş görüntü kalıbı değişimi'),
(86139, 243, 23, 'Maksimum yaş'),
(86140, 244, 23, 'Minimum yaş'),
(86141, 245, 23, 'Yaş Dağılımı'),
(86142, 247, 23, 'Yaşlanma Sütunları:'),
(86143, 248, 23, 'Gana/Fildişi Akan etnisitesi'),
(86144, 249, 23, 'Arnavut'),
(86145, 250, 23, 'Alkol'),
(86146, 251, 23, 'Alkol tüketimi'),
(86147, 252, 23, 'Alkol Kullanımı'),
(86148, 253, 23, 'Uyarı Sayısı'),
(86149, 255, 23, 'Uyarılar'),
(86150, 258, 23, 'Aleut'),
(86151, 259, 23, 'Hepsi'),
(86152, 260, 23, 'HEPSİ'),
(86153, 261, 23, 'Hepsi (A formatına harmanlanmış)'),
(86154, 262, 23, 'Hepsi (B formatına harmanlanmış)'),
(86155, 263, 23, 'Hepsi (Kümülatif)'),
(86156, 265, 23, 'Tüm Otomatik Ölçüm Hesaplamaları'),
(86157, 266, 23, 'Tüm Kategoriler'),
(86158, 267, 23, 'Tüm Klinik Kalite Ölçümleri'),
(86159, 268, 23, 'Tüm Kodlar'),
(86160, 269, 23, 'Bütün Gün'),
(86161, 270, 23, 'Tüm gün süren bir olay'),
(86162, 271, 23, 'Tüm demografik alanlar, arama ve çiftleşme kontrolü ile'),
(86163, 272, 23, 'Tüm Tesisler'),
(86164, 273, 23, 'Tüm yaralanmalar/Sorunlar/Konular'),
(86165, 274, 23, 'Tüm Dillere İzin Verilir'),
(86166, 275, 23, 'Tüm Klinik Kalite Ölçüleri Ölçü Grupları'),
(86167, 276, 23, 'İsminin tamamı veya bir kısmı'),
(86168, 277, 23, 'Soyadının tamamı veya bir kısmı'),
(86169, 278, 23, 'Organizasyonun tamamı veya bir kısmı'),
(86170, 279, 23, 'Tüm Hastalar'),
(86171, 280, 23, 'Tüm ürünler'),
(86172, 281, 23, 'Tüm Tedarikçiler'),
(86173, 282, 23, 'Tüm Gözden Geçirilmiş ve Negatif:'),
(86174, 283, 23, 'Tüm Konular'),
(86175, 284, 23, 'Tüm Kullanıcılar'),
(86176, 285, 23, 'Alerjik'),
(86177, 286, 23, 'Alerjiler');
INSERT INTO `lang_definitions` VALUES
(86178, 287, 23, 'Alerjiler:'),
(86179, 288, 23, 'Alerji'),
(86180, 289, 23, 'Allerji bilgisi başarı ile alındı.'),
(86181, 290, 23, 'Allerji Konuları Listesi'),
(86182, 291, 23, 'Alerji Reaksiyonu'),
(86183, 294, 23, 'Yer Ayır'),
(86184, 295, 23, 'İzin verin'),
(86185, 296, 23, 'Girişte menüde seçenek olarak mevcut tüm dillere izin verin'),
(86186, 297, 23, 'Tanıları içeren fakat işlemleri veya ücretleri içermeyen faturalandırmaya izin verin. Çoğu klinik bunu istemez.'),
(86187, 298, 23, 'Debugging diline izin verin'),
(86188, 299, 23, 'Epostaya izin verin'),
(86189, 300, 23, 'Eposta mesajlarına izin verilsin mi?'),
(86190, 301, 23, 'Epostaya izin verilsin mi?'),
(86191, 302, 23, 'Vizit Başı Faturalandırmaya izin verilsin'),
(86192, 303, 23, 'Sağlık Bilgisi Değişimine İzin Verilsin'),
(86193, 304, 23, 'Aşı Bilgisi Paylaşımına İzin Verilsin'),
(86194, 305, 23, 'Aşı Kayıtları Kullanımına İzin verilsin'),
(86195, 306, 23, 'posta mesajına izin verilsin'),
(86196, 308, 23, 'Hasta Portaline İzin verilsin'),
(86197, 309, 23, 'SMS e izin verilsin'),
(86198, 310, 23, 'SMS (tekst mesajlarına) izin verilsin mi?'),
(86199, 311, 23, 'İletilen olayların derhal aktif olmasına izin verilsin mi?'),
(86200, 312, 23, 'Telefon mesajlarına izin verilsin mi?'),
(86201, 313, 23, 'Kullanıcıların Herkese Olay yayınlamasına izin verilsin'),
(86202, 314, 23, 'Kullanıcıların Kişisel Takvim yayınlamasına izin verilsin'),
(86203, 315, 23, 'Ses Mesajına izin verilsin'),
(86204, 316, 23, 'İzin verildi'),
(86205, 317, 23, 'İzin verilen Diller'),
(86206, 318, 23, 'İzin verilmiş(c)'),
(86207, 319, 23, 'Tüm görüşmenin E-imza ile imzalanmasına müsaade eder'),
(86208, 320, 23, 'Tek tek formların E-imza ile imzalanmasına müsaade eder'),
(86209, 321, 23, 'Postaya izin verir'),
(86210, 322, 23, 'Ses Mesajına izin verir'),
(86211, 323, 23, 'önceden var.'),
(86212, 324, 23, 'önceden var.'),
(86213, 325, 23, 'Önceden kullanıldı, farklı bir tanımlayıcı seçiniz'),
(86214, 326, 23, 'Önceden kullanıldı, farklı bir başlık seçiniz'),
(86215, 327, 23, 'Adres değ'),
(86216, 328, 23, 'değiştir'),
(86217, 329, 23, 'Alternatif olarak takas veya borçlunuzdan aldığınız elektronik havale (X12 835) dosyasını yüklemek için arama sayfasını kullanabilirsiniz. Bunu yapabilmek için Araştır düğmesini tıklayın ve yükleyeceğiniz dosyayı seçin. Daha sonra Seç düğmesini tıklayın ve ilgili faturaları görüntüleyip yüklemeyi bitirin. Bu durumda yukarıda bahsedilen parametreler uygulanmaz. Yüklemek dosyayı kaydeder ama içeriğini işlemden geçirmez.--bu iş aşağıda ayrıca anlatılmıştır.'),
(86218, 330, 23, 'ÖÖ'),
(86219, 331, 23, 'ÖÖ Programı'),
(86220, 332, 23, 'Otomatik Ölçüm Hesapları'),
(86221, 333, 23, 'Otomatik Ölçüm Hesapları İzleme'),
(86222, 334, 23, 'Otomatik Ölçüm Hesapları 2011'),
(86223, 335, 23, 'Otomatik Ölçüm Hesapları 2014'),
(86224, 338, 23, 'Mevcut Notu Düzelt'),
(86225, 339, 23, 'Düzeltma Formu'),
(86226, 340, 23, 'Düzeltme Durumu'),
(86227, 341, 23, 'Değişiklikler'),
(86228, 342, 23, 'Değişiklik yapılan:'),
(86229, 343, 23, 'Kızılderili'),
(86230, 344, 23, 'Kızılderili veya Alaska Yerlisi'),
(86231, 345, 23, 'AMEX'),
(86232, 346, 23, 'Amharik'),
(86233, 347, 23, 'Miktar'),
(86234, 348, 23, 'Uygulanan Miktar'),
(86235, 349, 23, 'Ücretler Miktarı'),
(86236, 350, 23, 'Geçmiş Bakiye Miktarı'),
(86237, 351, 23, 'Bu Vizite Miktarı'),
(86238, 352, 23, 'Ödenen Miktar'),
(86239, 353, 23, 'Miktar:'),
(86240, 354, 23, 'Fatura edilen miktar'),
(86241, 355, 23, 'Tekrarlanan olaylar için bitiş tarihinin başlangıç tarihinden daha sonra olması gerekir'),
(86242, 356, 23, 'Form imzalanırken bir hata oluştu'),
(86243, 357, 23, 'ÖzgürETK web dizin ağacı dökümü yapılır iken bir hata oluştu'),
(86244, 358, 23, 'phpGACL web dizin ağacı dökümü yapılır iken bir hata oluştu'),
(86245, 359, 23, 'SQL-Defter-i-Kebir web dizin ağacı dökümü yapılır iken bir hata oluştu'),
(86246, 360, 23, 'Tam olmayan bir GCAC konusu oluşturuldu ve link edildi. Daha sonra birisinin tamamlaması gerekiyor.'),
(86247, 362, 23, 'Beklenmeyen bir hata oluştu'),
(86248, 363, 23, 'Bir büyük harf'),
(86249, 365, 23, 'Ve'),
(86250, 366, 23, 'VE'),
(86251, 367, 23, 've'),
(86252, 368, 23, 've '),
(86253, 369, 23, 've tüm bağlı verilerde mi? Bu işlem kaydedilecek.'),
(86254, 370, 23, 've değiştirici.'),
(86255, 371, 23, 've işlendi'),
(86256, 372, 23, 've Apache sunucusunu tekrar başlatınız.'),
(86257, 373, 23, 'sebep:'),
(86258, 374, 23, 'Anemi'),
(86259, 375, 23, 'Ayak bileği'),
(86260, 376, 23, 'Ayak bileği + topuk'),
(86261, 377, 23, 'Ayak bileği Değerlendirme Formu'),
(86262, 378, 23, 'Ayak bileği Sorunları'),
(86263, 379, 23, 'Ankilozan Spondilit'),
(86264, 380, 23, 'Ankilozan Spondilit'),
(86265, 381, 23, 'Anoreksi'),
(86266, 382, 23, 'Gönderme penceresinde yapabileceğiniz bir diğer şey ikinci faturalandırma istemektir. Eğer kaydetmeden önce bu kutuyu işaretlerseniz, izleyen faturalandırma programı çalıştırılmasında orijinal fatura tekrar açılır ve tekrar işlenmek üzere Faturalandırma sayfası kuyruğuna eklenir'),
(86267, 383, 23, 'önce'),
(86268, 384, 23, 'Anüs normal, rektal hassasiyet/kitle yok'),
(86269, 385, 23, 'Anksiyete'),
(86270, 386, 23, 'Herhangi bir'),
(86271, 387, 23, 'Herhangi bir Kategori'),
(86272, 388, 23, 'İstenen kodun herhangi bir parçası veya tanımı'),
(86273, 389, 23, 'İstenen uzmanlığın herhangi bir parçası'),
(86274, 390, 23, 'İlaç ismi veya ilaç kimliğinin herhangi bir parçası'),
(86275, 391, 23, 'Aşı kimliği veya aşı isminin herhangi bir parçası'),
(86276, 392, 23, 'Hasta isminin herhangi bir parçası, veya "ad,soyad", veya "X-Y"'),
(86277, 393, 23, 'İlgili diğer tüm bilgiler'),
(86278, 394, 23, 'SMS için API anahtarı'),
(86279, 395, 23, 'Apne'),
(86280, 396, 23, 'Görünüm'),
(86281, 397, 23, 'Görünüm:'),
(86282, 398, 23, 'Bu notu ekle'),
(86283, 399, 23, 'Mevcut nota ekle'),
(86284, 400, 23, 'Bu nota ekle'),
(86285, 401, 23, 'Bu Nota Ekle'),
(86286, 402, 23, 'Apendektomi'),
(86287, 403, 23, 'apendektomi'),
(86288, 404, 23, 'Uygulanabilir Hastalar'),
(86289, 405, 23, 'Uygulama'),
(86290, 406, 23, 'Giriş sayfası ve ana pencere başlığı için uygulama ismi'),
(86291, 407, 23, 'Uygulama alıcı kodu (GS03- boş ise ISA08 kullanılacaktır.)'),
(86292, 408, 23, 'Uygulama Gönderici Kodu (GS02)'),
(86293, 409, 23, 'Uygulama Başlığı'),
(86294, 410, 23, 'ANT formu ve Büyüme Çizelgesine Uygulanır'),
(86295, 411, 23, 'Vital Bulgulara uygulanır formu'),
(86296, 412, 23, 'Değişiklikler sadece burada mı yoksa bu ve benzeri tüm durumlarda mı uygulansın?'),
(86297, 413, 23, 'etkilenmiş alana uygulayın'),
(86298, 414, 23, 'cilde uygulayın'),
(86299, 415, 23, 'Uygulanıyor'),
(86300, 416, 23, 'Siteye yama uygulanıyor'),
(86301, 417, 23, 'Randevu'),
(86302, 418, 23, 'Randevu Tarihi'),
(86303, 419, 23, 'Randevu Görüntüleme Stili'),
(86304, 420, 23, 'Randevu Hatırlatma Kuralı'),
(86305, 421, 23, 'Randevu durumu'),
(86306, 422, 23, 'Randevu Durumları'),
(86307, 423, 23, 'Randevuya kalan zaman:'),
(86308, 424, 23, 'Randevu/Olay Rengi'),
(86309, 425, 23, 'Randevular'),
(86310, 426, 23, 'Randevular (yazma seçmeli)'),
(86311, 427, 23, 'Randevular (yazma)'),
(86312, 430, 23, 'Randevular ve görüşmelar'),
(86313, 431, 23, 'Randevu Raporu'),
(86314, 432, 23, 'Randevu-görüşme Raporu'),
(86315, 434, 23, 'Onama'),
(86316, 435, 23, 'Hastayı Hasta/Müşteri->içe aktar->Bekleyen onaylarda onaylayınız'),
(86317, 436, 23, 'Onaylandı'),
(86318, 437, 23, 'Onaylanmış Olaylar Yönetimi'),
(86319, 438, 23, 'Başarı ile onaylandı'),
(86320, 440, 23, 'Gör-Rand'),
(86321, 441, 23, 'Randevular'),
(86322, 442, 23, 'Nis'),
(86323, 443, 23, 'Nisan'),
(86324, 444, 23, 'Arapça'),
(86325, 445, 23, 'Aragonca'),
(86326, 446, 23, 'Arşiv'),
(86327, 447, 23, 'Erişim kontrol grup isimleri tercüme edilecek mi?'),
(86328, 448, 23, 'Randevu kategori isimleri tercüme edilecek mi?'),
(86329, 449, 23, 'Belge kategori isimleri tercüme edilecek mi?'),
(86330, 450, 23, 'Bu tip ücretlendirilecek mi?'),
(86331, 451, 23, 'Hasta not başlıkları tercüme edilecek mi?'),
(86332, 452, 23, 'Kodlar dış sql tablolarında kayıtlı mı? (0-Hayır 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2))'),
(86333, 453, 23, 'Bu vizit için yeni bir GCAC konusu doldurmaya hazırlıklı mısın?'),
(86334, 454, 23, 'Bugün göndermek istediğinizden emin misiniz?'),
(86335, 455, 23, 'Bu olayları onaylamak istediğinizden emin misiniz?'),
(86336, 457, 23, 'Bu formu tamamen silmek istediğinizden emin misiniz?'),
(86337, 458, 23, 'Silmek istediğinizden emin misiniz?'),
(86338, 459, 23, 'Bu açıklamayı silmek istediğinizden emin misiniz?'),
(86339, 460, 23, 'Bu olayı silmek istediğinizden emin misiniz?'),
(86340, 461, 23, 'Bu maddeyi veritabanından silmek istediğinize emin misiniz?'),
(86341, 462, 23, 'Bu notu silmek istediğinizden emin misiniz?'),
(86342, 464, 23, 'Bu olayları düzenlemek istediğinizden emin misiniz?'),
(86343, 465, 23, 'Bu olayları gizlemek istediğinizden emin misiniz?'),
(86344, 466, 23, 'Tekrar göndermek istediğinizden emin misiniz?'),
(86345, 467, 23, 'Bu olayları görmek istediğinizden emin misiniz?'),
(86346, 468, 23, 'Grubun tamamını silmek istediğinizden emin misiniz?'),
(86347, 469, 23, 'Bütün listeyi silmek istediğinizden emin misiniz?'),
(86348, 470, 23, 'Alanı silmek istediğinizden emin misiniz?'),
(86349, 471, 23, 'Seçilmiş alanları silmek istediğinizden emin misiniz?'),
(86350, 472, 23, 'Bu işlemlere devam etmek istediğinizden emin misiniz?'),
(86351, 473, 23, 'Alan tanımlanmamış'),
(86352, 474, 23, 'Kol'),
(86353, 475, 23, 'Ermenice'),
(86354, 477, 23, 'Aritmi'),
(86355, 478, 23, 'Artrit'),
(86356, 479, 23, 'Artrit /eklem hastalığı'),
(86357, 480, 23, 'Artrit /eklem hastalığı'),
(86358, 481, 23, 'gibi'),
(86359, 482, 23, 'olarak'),
(86360, 483, 23, 'ASC'),
(86361, 484, 23, 'Asyalı'),
(86362, 485, 23, 'Assamca'),
(86363, 487, 23, 'Değerlendirme'),
(86364, 488, 23, 'Atanmış:'),
(86365, 489, 23, 'Asistan'),
(86366, 490, 23, 'Astım'),
(86367, 491, 23, 'de'),
(86368, 492, 23, 'Hepsini seçer iseniz en azından bir araştırma parametresi gereklidir.'),
(86369, 493, 23, 'Navikülerde'),
(86370, 494, 23, 'Navikülerde:'),
(86371, 495, 23, 'Atletizm takımı'),
(86372, 496, 23, 'Atletizm takımı'),
(86373, 497, 23, 'Atletizm/Zedelenme'),
(86374, 498, 23, 'Güvenli iletişim CA sertifika denetimi'),
(86375, 499, 23, 'Güvenli iletişim denetimi sunucusu'),
(86376, 500, 23, 'Güvenli iletişim denetimi yerel sertifika'),
(86377, 501, 23, 'Güvenli iletişim denetimi portu'),
(86378, 503, 23, 'Dikkat'),
(86379, 504, 23, 'Dikkat'),
(86380, 506, 23, 'Klinik Karar Kuralları Algoritmaları Denetimi'),
(86381, 507, 23, 'Kurcalanma Kütüğü Denetimi'),
(86382, 508, 23, 'Kurcalanma Kütüğü Raporu Denetimi'),
(86383, 509, 23, 'Denetim Kaydı Yedekleri'),
(86384, 510, 23, 'Denetim Kaydı Çeşitli'),
(86385, 511, 23, 'Denetim Kaydı Sırası'),
(86386, 512, 23, 'Denetim Kaydı Hasta Raporu'),
(86387, 513, 23, 'Denetim Kaydı Zamanlaması'),
(86388, 514, 23, 'Denetim Kaydı Güvenlik Yönetimi'),
(86389, 515, 23, 'Denetim Kaydı SEÇ Sorgusu'),
(86390, 516, 23, 'Ağu'),
(86391, 517, 23, 'Ağustos'),
(86392, 519, 23, 'Yazan'),
(86393, 520, 23, 'Yaz/notlar'),
(86394, 523, 23, 'Yetkilendirme grubu'),
(86395, 524, 23, 'Yetkilendirme durumu'),
(86396, 525, 23, 'Yetkilendirmeler'),
(86397, 526, 23, 'Yetkilendirmek'),
(86398, 527, 23, 'Yetkilendir - herhangi bir görüşme'),
(86399, 528, 23, 'Yetkilendir - görüşmelerim'),
(86400, 529, 23, 'Ağı yetkilendir'),
(86401, 530, 23, 'Yetkili'),
(86402, 531, 23, 'Sadece Yetkililer'),
(86403, 532, 23, 'Otomatik Gönder'),
(86404, 535, 23, 'Yeni Görüşmeleri Otomatik Oluştur'),
(86405, 536, 23, 'Otomatik oluşturulmuş'),
(86406, 537, 23, 'Otomatik Ölçüm Hasaplamaları'),
(86407, 538, 23, 'Otomatik Ölçüm Hesaplamaları -  2011'),
(86408, 539, 23, 'Otomatik Ölçüm Hesaplamaları -  2014'),
(86409, 542, 23, 'Otomatik Ölçüm Hesapları İzleme'),
(86410, 543, 23, 'Otomatik Ölçümler'),
(86411, 544, 23, 'Otomatik'),
(86412, 546, 23, 'Randevu durumu "@" (geldi) ye ayarlandığında yeni bir vizit kaydını otomatik oluştur'),
(86413, 549, 23, 'Medikal Otomobil'),
(86414, 550, 23, 'otomatik kaydedildi'),
(86415, 551, 23, 'Mevcut kategoriler'),
(86416, 552, 23, 'Mevcut Olduğu Zamanlar'),
(86417, 553, 23, 'Erişilebilir kayıtlar'),
(86418, 554, 23, 'Avarca'),
(86419, 555, 23, 'Sol izleme penceresinden çıkan açılır pencerelerden basım için hasta etiketleri'),
(86420, 556, 23, 'Zendçe'),
(86421, 557, 23, 'Aylık Ortalama'),
(86422, 558, 23, 'Avulsiyon /avulsiyon kırığı'),
(86423, 559, 23, 'Lateral malleolde avulsiyon'),
(86424, 560, 23, 'Medial malleolde avulsiyon '),
(86425, 561, 23, 'Uyanıklık-Temelli'),
(86426, 562, 23, 'Aksiller'),
(86427, 563, 23, 'Aymaraca'),
(86428, 564, 23, 'Azerbeycanca'),
(86429, 565, 23, '2x1'),
(86430, 566, 23, 'Geri'),
(86431, 567, 23, 'geri'),
(86432, 568, 23, 'Sekiz vizit öncesi'),
(86433, 569, 23, 'Onbir vizit öncesi'),
(86434, 570, 23, 'Beş vizit öncesi'),
(86435, 571, 23, 'Dört vizit öncesi'),
(86436, 572, 23, 'Dokuz vizit öncesi'),
(86437, 573, 23, 'Bir vizit öncesi'),
(86438, 574, 23, 'Sırt Ağrısı'),
(86439, 575, 23, 'Sırt Sorunları'),
(86440, 576, 23, 'Yedi vizit öncesi'),
(86441, 577, 23, 'Altı vizit öncesi'),
(86442, 578, 23, 'Sırt Cerrahisi'),
(86443, 579, 23, 'On vizit öncesi'),
(86444, 580, 23, 'Üç vizit öncesi'),
(86445, 581, 23, 'Yönetici sayfasına geri'),
(86446, 582, 23, 'Görüşmeye geri'),
(86447, 583, 23, 'Hasta Kaydına Geri'),
(86448, 584, 23, 'Hastaya Geri'),
(86449, 585, 23, 'Kullanıcılara geri'),
(86450, 586, 23, 'Görünüme Geri'),
(86451, 587, 23, 'Oniki vizit öncesi'),
(86452, 588, 23, 'İki vizit öncesi'),
(86453, 589, 23, 'Arka Plan Hizmetleri'),
(86454, 590, 23, 'Yedek'),
(86455, 591, 23, 'Yedek dosyası oluşturuldu. Şimdi indir e gönderilecek'),
(86456, 592, 23, 'Yedek Listesi'),
(86457, 593, 23, 'Yedek Başarıyla Alındı:'),
(86458, 594, 23, 'Kontrol Kötü'),
(86459, 595, 23, 'Borç Kötü'),
(86460, 596, 23, 'Endonezya Bahasa'),
(86461, 597, 23, 'Bky'),
(86462, 598, 23, 'Bakiye'),
(86463, 599, 23, 'bakiye'),
(86464, 600, 23, 'Bakiye miktarı'),
(86465, 601, 23, 'Vadesi Gelmiş Borç'),
(86466, 602, 23, 'Bambaraca'),
(86467, 603, 23, 'Banka Poliçesi'),
(86468, 604, 23, 'Barkot etiketi'),
(86469, 605, 23, 'Berkot etiket tipi'),
(86470, 606, 23, 'Sol navigasyon penceresinden açılan pencerelerden barkot etiketi bastırmak için barkot tipi'),
(86471, 607, 23, 'Beşinci (5.) Metatars Kaidesi'),
(86472, 608, 23, 'Beşinci (5.) Metatars Kaidesi:'),
(86473, 609, 23, 'Başkurtça'),
(86474, 610, 23, 'Baskça'),
(86475, 611, 23, 'Toplu alacak'),
(86476, 612, 23, 'Toplu İletişim Aracı'),
(86477, 613, 23, 'Parti Ödeme Girişi'),
(86478, 614, 23, 'Parti ödemeler'),
(86479, 615, 23, 'Toplu işlem başlatıldı; bu bir süre alabilir.'),
(86480, 616, 23, 'Toplu Sonuçlar'),
(86481, 617, 23, 'Toplu İletişim'),
(86482, 618, 23, 'Bazı dosyaların işlenmesi zaman almaktadır. Lütfen bekleyiniz.'),
(86483, 619, 23, 'çünkü o kimlik yok.'),
(86484, 620, 23, 'Başla'),
(86485, 621, 23, 'Başlama Tarihi'),
(86486, 623, 23, 'Hizmet tarihinden itibaren yyyy-aa-gg'),
(86487, 624, 23, 'Takvim etkinlikleri için günün başladığı saat'),
(86488, 625, 23, 'Belarusça'),
(86489, 626, 23, 'Geğirme'),
(86490, 628, 23, 'Bengalli'),
(86491, 629, 23, 'Bengalce'),
(86492, 630, 23, 'arasında'),
(86493, 631, 23, 'İki yönlü'),
(86494, 632, 23, 'Biharca'),
(86495, 633, 23, 'Bilateral'),
(86496, 634, 23, 'Bilateral:'),
(86497, 636, 23, 'Fatura Tarihi'),
(86498, 637, 23, 'Fatura/Tahsil'),
(86499, 638, 23, 'Faturalandırılmış'),
(86500, 640, 23, 'Faturalandırma'),
(86501, 641, 23, 'Faturalandırma (opsiyonlu yazım)'),
(86502, 642, 23, 'Faturalandırma Dikkatine'),
(86503, 644, 23, 'İstenilen Hizmet için Faturalandırma Kodu'),
(86504, 645, 23, 'Faturalandırma kodları'),
(86505, 646, 23, 'Faturalandırma Verisi'),
(86506, 647, 23, 'Fatura Bölümü'),
(86507, 648, 23, 'Fatura Tesisi'),
(86508, 649, 23, 'Fatura Bilgisi'),
(86509, 650, 23, 'Fatura Yeri'),
(86510, 655, 23, 'Fatura Yöneticisi'),
(86511, 656, 23, 'Fatura Notu'),
(86512, 657, 23, 'Fatura Notu: '),
(86513, 658, 23, 'Fatura Notu:'),
(86514, 659, 23, 'Fatura kuyruğu sonuçları:'),
(86515, 660, 23, 'Fatura Raporu'),
(86516, 661, 23, 'Faturalama durumu'),
(86517, 662, 23, 'Fatura Durumu=Fatura edilmemiş'),
(86518, 663, 23, 'fatura kesilen '),
(86519, 665, 23, 'Biyopsi'),
(86520, 666, 23, 'Doğum Tarihi'),
(86521, 667, 23, 'Doğum-24 ay'),
(86522, 668, 23, 'Vanuatu Bislama dili'),
(86523, 669, 23, 'Siyah'),
(86524, 670, 23, 'Siyah akciğer'),
(86525, 671, 23, 'Siyah veya Afrika kökenli Amerikalı'),
(86526, 672, 23, 'Mesane Kanseri'),
(86527, 673, 23, 'Mesane Enfeksiyonları'),
(86528, 674, 23, 'Boş Formlar'),
(86529, 675, 23, 'Kanama Sorunları'),
(86530, 676, 23, 'Kör Noktalar'),
(86531, 677, 23, 'Şişkinlik'),
(86532, 678, 23, 'Tıkanmış'),
(86533, 679, 23, 'Kan'),
(86534, 680, 23, 'Kan Basıncı'),
(86535, 681, 23, 'Kan basıncı'),
(86536, 682, 23, 'Burun Kanaması'),
(86537, 683, 23, 'SGK Yeşilkart Özel Sigorta'),
(86538, 684, 23, 'Bu rapordaki mavi satırlar bilgi içindir. Siyah satırlar önceden mevcut bilgiyi gösterir. Yeşil satırlar başarı ile uygulanmış değişiklikleri gösterir. Kırmızı satırlar hataları veya uygulanmamış değişiklikleri gösterir; bunların el ile düzeltilmesi gerekmektedir. Halen sigorta kurumunun kabul etmediği talepler ve geri dönen ödemeler otomatik olarak işlenmez ve bu nedenle kırmızı görünür.'),
(86539, 685, 23, 'Bulanık Görme'),
(86540, 686, 23, 'VKI'),
(86541, 687, 23, 'VKI Durumu'),
(86542, 689, 23, 'Vücut Bölgesi'),
(86543, 690, 23, 'Vücuttaki Yeri'),
(86544, 691, 23, 'Vücuttaki yeri, uygulanabiliyor ise,'),
(86545, 692, 23, 'Kemik Hassasiyeti'),
(86546, 693, 23, 'Kemik Hassasiyeti: Medial Malleol'),
(86547, 694, 23, 'Mantıksal'),
(86548, 695, 23, 'Boşnakça'),
(86549, 696, 23, 'Alt'),
(86550, 697, 23, 'Her iki Kulak'),
(86551, 698, 23, 'her iki kulak'),
(86552, 699, 23, 'En alt'),
(86553, 700, 23, 'Alt kenar(piksel)'),
(86554, 701, 23, 'KUTU 10 A. İş ile ilgili '),
(86555, 702, 23, 'KUTU 10 B. Araba Kazası '),
(86556, 703, 23, 'KUTU 10 C. Diğer Kazalar '),
(86557, 704, 23, 'KUTU 14 Tarih Tanımlayıcı'),
(86558, 705, 23, 'KUTU 15 Diğer Tarih Tanımlayıcı'),
(86559, 706, 23, 'KUTU 15 aynı veya benzer hastalıkların tarihi (yyyy-aa-gg)'),
(86560, 707, 23, 'KUTU 15 aynı veya benzer hastalıkların/Diğer tarihi (yyyy-aa-gg)'),
(86561, 708, 23, 'KUTU 16 Tarihinden itibaren çalışamaz ( yyyy-aa-gg)'),
(86562, 709, 23, 'KUTU 16 Tarihinden itibaren çalışamaz ( yyyy-aa-gg)'),
(86563, 710, 23, 'KUTU 18. Hastaneye yatış tarihi (yyyy-aa-gg) '),
(86564, 711, 23, 'KUTU 18. Hastaneden çıkış tarihi (yyyy-aa-gg) '),
(86565, 712, 23, 'KUTU 20. Harici Laboratuvar kullanıldı mı?'),
(86566, 713, 23, 'KUTU 22. Tıbbi Tekrar Gönderme kodu (ICD10) '),
(86567, 714, 23, 'Önceki Yetki No: '),
(86568, 715, 23, 'KB'),
(86569, 716, 23, 'Diyastolik KB'),
(86570, 717, 23, 'Sistolik KB'),
(86571, 719, 23, 'Bpd'),
(86572, 721, 23, 'Bps'),
(86573, 722, 23, 'Brezilya Portekizcesi'),
(86574, 723, 23, 'Meme'),
(86575, 724, 23, 'Meme Biyopsisi'),
(86576, 725, 23, 'Meme Akıntısı'),
(86577, 726, 23, 'Meme Hastalığı'),
(86578, 727, 23, 'Meme Muayenesi'),
(86579, 728, 23, 'Memede Kitle'),
(86580, 730, 23, 'Solunum Sesleri:'),
(86581, 731, 23, 'Bretonca'),
(86582, 732, 23, 'Kemik Kırıkları'),
(86583, 733, 23, 'kırılmış kalıp'),
(86584, 734, 23, 'Bronşit Formu'),
(86585, 735, 23, 'Tara'),
(86586, 736, 23, 'Kayıt Araması'),
(86587, 737, 23, 'Morarma/hematom'),
(86588, 738, 23, 'Bulgarca'),
(86589, 739, 23, 'Sağa Şişkin:'),
(86590, 740, 23, 'Burmaca'),
(86591, 741, 23, 'İdrarda yaparken Yanma'),
(86592, 742, 23, 'İdrar Yaparken Yanma'),
(86593, 743, 23, 'İş Telefonu'),
(86594, 744, 23, 'Meşgul'),
(86595, 745, 23, 'fakat henüz işlem yapılmadı.'),
(86596, 746, 23, 'Kalça'),
(86597, 747, 23, 'Kalça + S.I.'),
(86598, 748, 23, 'tarafından'),
(86599, 749, 23, 'Tarafından'),
(86600, 750, 23, 'ağızdan'),
(86601, 751, 23, 'Tarafından/Kaynak'),
(86602, 752, 23, 'Tarafından:'),
(86603, 753, 23, 'C'),
(86604, 754, 23, 'RFC 5425 TLS syslog sunucusunu doğrulamak için CA Sertifikası.'),
(86605, 755, 23, 'Önbellek Ömrü (saniye)'),
(86606, 756, 23, 'Önbellek çıktı şablonu?'),
(86607, 757, 23, 'Kafein tüketimi'),
(86608, 758, 23, 'Takvim'),
(86609, 759, 23, 'Takvim Bitme Saati'),
(86610, 760, 23, 'Takvim Aralığı'),
(86611, 761, 23, 'Takvim Ekranı'),
(86612, 762, 23, 'Takvim Ayarları'),
(86613, 763, 23, 'Takvim Başlangıç Saati'),
(86614, 764, 23, 'Takvim Kullanıcı Ara birimi'),
(86615, 765, 23, 'Takvim Görünümü'),
(86616, 766, 23, 'addForm() Çağrısı buraya gider.<br>'),
(86617, 767, 23, 'Kalori'),
(86618, 768, 23, 'Kamboçça'),
(86619, 769, 23, 'Bilgisayarla Tıbbi Order'),
(86620, 774, 23, 'İptal'),
(86621, 775, 23, 'Değişiklikleri İptal Et'),
(86622, 776, 23, 'İptal edildi'),
(86623, 777, 23, 'Kanser'),
(86624, 778, 23, 'Kanser Taraması: Kolon Kanseri Taraması'),
(86625, 779, 23, 'Kanser Taraması: Mamografi'),
(86626, 780, 23, 'Kanser Taraması: Serviks Yayması'),
(86627, 781, 23, 'Kanser Taraması: Prostat Kanseri Taraması'),
(86628, 782, 23, 'Bu kayıt eklenemiyor çünkü zaten önceden var!'),
(86629, 783, 23, 'Bu kayıt eklenemiyor/düzenlenemiyor çünkü zaten önceden çift kayıt var!'),
(86630, 784, 23, 'arşivlenemiyor,  göz ardı edildi.'),
(86631, 785, 23, 'JPEG ye çevrilemiyor. Belki ImageMagick kurulu değil?'),
(86632, 786, 23, 'Silinemiyor, göz ardı edildi.'),
(86633, 787, 23, 'Tipi tarayıcı tarafından desteklenmediğinden satır içerisinde gösterilemiyor.'),
(86634, 788, 23, 'Tipi tarayıcı tarafından desteklenmediğinden satır içerisinde gösterilemiyor.'),
(86635, 789, 23, 'Tipi tarayıcı tarafından desteklenmediğinden satır içerisinde gösterilemiyor.'),
(86636, 790, 23, 'Oluşturulamıyor'),
(86637, 791, 23, 'Dosya oluşturulamıyor'),
(86638, 792, 23, '(SFTP sunucudan) dosya silinemiyor'),
(86639, 793, 23, 'Dosya silinemiyor'),
(86640, 794, 23, 'Hedef dosya ismi belirlenemiyor'),
(86641, 795, 23, 'Bulunamıyor '),
(86642, 796, 23, 'hedef dosya ismi bulunamıyor.'),
(86643, 799, 23, 'Hasta SQL-Defter-i-Kebir müşteri kimliğinden bulunamıyor'),
(86644, 800, 23, 'Postskript belge referansı bulunamıyor. '),
(86645, 801, 23, 'Sağlayıcı SQL-Ledger employee = den bulunamıyor '),
(86646, 802, 23, 'Ödemeler Değiştirilemiyor. Dağıtılmamış Negatif.'),
(86647, 803, 23, 'Açılamıyor '),
(86648, 804, 23, 'Sigorta gönderilemiyor. Ödeyici olarak hasta seçili'),
(86649, 805, 23, 'Hastaya gönderilemiyor. Ödeyen olarak sigorta seçilmiş.'),
(86650, 806, 23, 'Ödemeler gönderilemiyor. Dağıtılmadı Menfi.'),
(86651, 807, 23, 'Okunamıyor'),
(86652, 808, 23, 'Dizin okunamıyor.'),
(86653, 809, 23, 'Güncellenemiyor çünkü bulunan bir kaydı düzenlemiyorsunuz!'),
(86654, 810, 23, 'Büyük harflerle yazılsın'),
(86655, 811, 23, 'Hepsini büyük harfe dönüştür'),
(86656, 812, 23, 'kapsül'),
(86657, 813, 23, 'Kart'),
(86658, 814, 23, 'Kalp Kateterizasyonu'),
(86659, 815, 23, 'Kalp Ekosu'),
(86660, 816, 23, 'Kardiyovasküler'),
(86661, 821, 23, 'Kıkırdak / kondral / disk hasarı'),
(86662, 822, 23, 'Kıkırdak zedelenmesi'),
(86663, 823, 23, 'Karotis nabzı normal, dorsalis pedis normal'),
(86664, 824, 23, 'peşin'),
(86665, 825, 23, 'Peşin'),
(86666, 826, 23, 'Peşin Mak'),
(86667, 827, 23, 'Sağlayıcının Peşin Makbuzları'),
(86668, 828, 23, 'Katalanca-Valensiyaca'),
(86669, 829, 23, 'Katarakt Cerrahisi'),
(86670, 830, 23, 'Kataraktlar'),
(86671, 831, 23, 'Kategoriler'),
(86672, 832, 23, 'Kategorilendirilecek olan:'),
(86673, 833, 23, 'Kategori'),
(86674, 834, 23, 'kategori'),
(86675, 835, 23, 'Kategori '),
(86676, 836, 23, 'Kategori Ayrıntıları'),
(86677, 837, 23, 'Kategori Limitleri'),
(86678, 838, 23, 'Kategori İsmi'),
(86679, 839, 23, 'Kategori ismi boş.'),
(86680, 840, 23, 'Kategori/Başlık'),
(86681, 841, 23, 'Beyaz'),
(86682, 842, 23, 'Görüşmede Yazdırılacak Nedenler Makbuzlar/Primer Sağlayıcı Bilgisi'),
(86683, 846, 23, 'Hasta provizyon onayı'),
(86684, 847, 23, 'Hasta Provizyon geçmişi'),
(86685, 848, 23, 'Hasta provizyon izleme ve /Onay'),
(86686, 850, 23, 'Klinik Karar verme Kuralları Algoritmaları'),
(86687, 851, 23, 'Klinik Karar verme Kuralları Algoritmaları Raporları işleme önceliği'),
(86688, 852, 23, 'Hücre'),
(86689, 853, 23, 'Cep Telefonu'),
(86690, 854, 23, 'Cep Telefonu Numarası'),
(86691, 855, 23, 'Cep Telefonu Numarası'),
(86692, 856, 23, 'Merkezi Sertifikasyon'),
(86693, 857, 23, 'Merkezi/Güney Amerikalı'),
(86694, 858, 23, 'Sertifika Yetkilisi crt dosya yeri boş bırakılamaz'),
(86695, 859, 23, 'Sertifika Yetkilisi anahtar dosya yeri boş bırakılamaz'),
(86696, 860, 23, 'RFC 5425 TLS syslog sunucusuna gönderilecek sertifika'),
(86697, 861, 23, 'Sertifika Kullanıcısı'),
(86698, 862, 23, 'Sertifikalar'),
(86699, 863, 23, 'Şamorro dili'),
(86700, 864, 23, 'ChampUS'),
(86701, 865, 23, 'ChampUSVA'),
(86702, 866, 23, 'değiştir'),
(86703, 867, 23, 'Değiştir'),
(86704, 868, 23, 'Değiştirme Etkinliği'),
(86705, 869, 23, 'Değiştirme başarısız oldu! Veritabanına bağlanma hatası?'),
(86706, 870, 23, 'Görmede Değişiklik'),
(86707, 871, 23, 'Görmede Değişiklik'),
(86708, 872, 23, 'Şifre Değişikliği'),
(86709, 874, 23, 'Değiştirildi'),
(86710, 875, 23, 'Değişmiş Barsak'),
(86711, 876, 23, 'Belgenin hasta kimliğini değiştirmek'),
(86712, 877, 23, 'Özellikler'),
(86713, 878, 23, 'Kalan harf sayısı'),
(86714, 879, 23, 'Fatura kesmek'),
(86715, 880, 23, 'Düzeltmeyi fatura et.'),
(86716, 881, 23, 'ücret kodlandı'),
(86717, 882, 23, 'ücretleri'),
(86718, 883, 23, 'Çizelge'),
(86719, 884, 23, 'Çizelgesinde Etkinlik'),
(86720, 885, 23, 'Giriş/çıkış kontrolü çizelgesi etkinlik raporu'),
(86721, 886, 23, 'Çizelge ID'),
(86722, 887, 23, 'Çizelge ID:'),
(86723, 888, 23, 'Çizelge Etiketi'),
(86724, 889, 23, 'Çizelge Yeri Etkinliği'),
(86725, 890, 23, 'Çizelge Notu'),
(86726, 891, 23, 'Çizelge Numarası'),
(86727, 892, 23, 'Çizelge Saklama Yerleri'),
(86728, 893, 23, 'Çizelge İzleyici'),
(86729, 894, 23, 'Çizelge İz.'),
(86730, 895, 23, 'Kontrol Edilmiş Çizelgeler'),
(86731, 896, 23, 'Dışarı Çizelgeler'),
(86732, 897, 23, 'Çeçence'),
(86733, 898, 23, 'Kontrol et'),
(86734, 899, 23, 'kontrol et'),
(86735, 900, 23, 'Hepsini işaretle'),
(86736, 902, 23, 'Çek miktarı'),
(86737, 903, 23, 'Çek Tarihi'),
(86738, 904, 23, 'Özel dil tablosu ile farklılıkları kontrol et.'),
(86739, 906, 23, 'Kontrol'),
(86740, 907, 23, 'Girilen verileri Kontrol et'),
(86741, 908, 23, 'Grafik çizilecek konuları işaretleyiniz'),
(86742, 909, 23, 'Laboratuvar sonuçlarını kontrol ediniz.'),
(86743, 910, 23, 'İşaretlenmiş olanlar görüldüğünü gösterir'),
(86744, 911, 23, 'Çek No'),
(86745, 912, 23, 'Çek Numarası'),
(86746, 915, 23, 'Çek Ödemesi'),
(86747, 916, 23, 'Şifreli bir dosya ise kutucuğu işaretleyiniz.'),
(86748, 917, 23, 'Sağlayıcıların yalnız kendilerininkini değil, tüm randevuları ön tanımlı olarak görmelerini isterseniz bunu işaretleyiniz.'),
(86749, 918, 23, 'Bu teşhis için problem oluşturmak için işaretleyiniz'),
(86750, 919, 23, 'Çek/Müstahaklık Tarihi'),
(86751, 920, 23, 'Çek/Müstahaklık No:'),
(86752, 921, 23, 'Çek/Ref Numarası'),
(86753, 922, 23, 'Çek/Referans Numarası'),
(86754, 923, 23, 'Onay kutusu listesi'),
(86755, 924, 23, 'onay kutusu listesi'),
(86756, 925, 23, 'onay kutusu y/tekst'),
(86757, 926, 23, 'Onay kutusu y/tekst'),
(86758, 927, 23, 'Yukarıdaki onay kutuları sizin HL7 dosyasını reddetmek ve silmek istediğinizi gösterir'),
(86759, 928, 23, 'İşaretli'),
(86760, 929, 23, 'İşaretlenmiş kutu = evet , boş = hayır'),
(86761, 931, 23, 'Kilitle kutusunun seçilmesi bu vizite ile ilgili hiçbir formda daha başka her hangi bir düzenleme yapılmasını önler'),
(86762, 932, 23, 'Çıkış (Kasa)'),
(86763, 933, 23, 'Toplam'),
(86764, 934, 23, 'Göğüs'),
(86765, 935, 23, 'Oskültasyon ile her iki hemitoraks temiz'),
(86766, 936, 23, 'Göğüs Ağrısı'),
(86767, 937, 23, 'Göğüs Ağrısı:'),
(86768, 938, 23, 'Göğüs Ağrıları'),
(86769, 940, 23, 'Değ'),
(86770, 941, 23, 'Çevaca Nyanca'),
(86771, 942, 23, 'Esas Yakınma'),
(86772, 943, 23, 'Çocuk'),
(86773, 945, 23, 'Çocukluk immünizasyon durumu'),
(86774, 946, 23, 'Titreme'),
(86775, 947, 23, 'Çinli'),
(86776, 948, 23, 'Çince (Basit)'),
(86777, 949, 23, 'Çince (Geleneksel)'),
(86778, 950, 23, 'Kiropraksi'),
(86779, 951, 23, 'Seçenekler'),
(86780, 952, 23, 'Kolesistektomi'),
(86781, 953, 23, 'Kolesistestomi'),
(86782, 954, 23, 'Kolesistestomi'),
(86783, 955, 23, 'Seçiniz'),
(86784, 956, 23, 'Bir bölüm seçiniz ve içerisindeki bir konuyu tıklayınız, daha sonraki bölümde ilgili konuları parlak göreceksiniz, o bölümde ilişkileri oluşturmak veya silmek için tıklayabilirsiniz.'),
(86785, 957, 23, 'Özellikleri Seçiniz'),
(86786, 958, 23, 'İndirmeyi veya ekranda göstermeyi seçiniz'),
(86787, 959, 23, 'Dosyayı seçiniz'),
(86788, 960, 23, 'Listeden seçiniz'),
(86789, 961, 23, 'Düzenleme yönünü seçiniz'),
(86790, 962, 23, 'Listeyi seçiniz'),
(86791, 963, 23, 'Kağıt büyüklüğünü seçiniz'),
(86792, 964, 23, 'PDF dil tercihinizi seçiniz'),
(86793, 965, 23, 'Bu vizite raporunun basım formatını seçiniz.'),
(86794, 967, 23, 'Kronik Bronşit'),
(86795, 968, 23, 'Kronik Eklem Ağrısı'),
(86796, 969, 23, 'Kronik Böbrek Hastalığı'),
(86797, 970, 23, 'Kronik sinovit / effüzyon / eklem ağrısı / gut'),
(86798, 971, 23, 'Kronik / Tekrarlayan'),
(86799, 972, 23, 'Çuvaşça'),
(86800, 973, 23, 'Karaciğer Sirozu'),
(86801, 974, 23, 'Karaciğer Sirozu'),
(86802, 975, 23, 'Semt'),
(86803, 976, 23, 'Semt Adı'),
(86804, 977, 23, 'Semt, Şehir'),
(86805, 978, 23, 'Semt, Şehir Posta kodu'),
(86806, 979, 23, 'Semt/Şehir'),
(86807, 980, 23, 'Alacak'),
(86808, 981, 23, 'Alacak '),
(86809, 982, 23, 'Alacak Durumu'),
(86810, 983, 23, 'Alacak testinin çalışması tamamlandı'),
(86811, 984, 23, 'Alacak Tipi'),
(86812, 985, 23, 'Alacağın oluşturulduğu dosya:'),
(86813, 986, 23, 'Alacağın oluşturulduğu dosya: '),
(86814, 987, 23, 'Alacaklar'),
(86815, 988, 23, 'Sınıflandırma'),
(86816, 989, 23, 'Berrak'),
(86817, 990, 23, 'BU HASTAYI SİL'),
(86818, 991, 23, 'Hepsini Temizle'),
(86819, 992, 23, 'HL7 Verilerini Sil'),
(86820, 993, 23, 'Hizalamayı Temizle'),
(86821, 994, 23, 'Smarty Ön belleği Temizle'),
(86822, 995, 23, 'EDI 270 yığın düzenlenmesi için bir takasbank bigisinin girilmesi gerekiyor.'),
(86823, 996, 23, 'Klinik Laboratuvar Düzenleme Numarası'),
(86824, 997, 23, 'Tıklayınız'),
(86825, 998, 23, 'Kategori, Alt kategori kaleminizi dışarı bir tekst dosyasına aktarmak için ''dışarı aktar''a tıklayınız. Bu dosyanın bir XML e benzemesi tamamen tesadüftür. Açma ve kapama ekleri aynı satırda olmalıdır, küçük harfle yazılmalı, boşluk bırakılmamalıdır. Dışarıdan aktarmak için bir dosya seçiniz ve ''dışarıdan aktar''ı tıklayınız. Eğer veri tamamen farklı ise mevcut veriniz ile birleşecektir. Eğer benzer kalem isimleri var ise eskileri korunacak yeniler sonlarına bir rakam eklenerek kaydedilecektir.'),
(86826, 999, 23, 'Yeni bir not eklemek için grafik üzerinde bir noktayı tıklayınız. Silmek için tekrar tıklayınız.'),
(86827, 1000, 23, 'ssl.zip dosyasındaki sertifikaları indirmek için Sertifika İndir i tıklayınız'),
(86828, 1001, 23, 'devam için tıklayınız'),
(86829, 1002, 23, 'Daha fazla ayrıntı için tıklayınız'),
(86830, 1003, 23, 'Sipariş özeti için tıklayınız'),
(86831, 1004, 23, 'Sonuçlar için tıklayınız'),
(86832, 1005, 23, 'Buraya tıklayınız'),
(86833, 1006, 23, 'Yeni bir hasta eklemek için Burayı tıklayınız.'),
(86834, 1007, 23, 'Yeni bir yaralanma eklemek, durum değiştirmek veya günlük etkinlik girmek için burayı tıklayınız.'),
(86835, 1008, 23, 'Bir tarih seçmek için burayı tıklayınız.'),
(86836, 1009, 23, 'Tarih ve zaman seçmek için burayı tıklayınız.'),
(86837, 1010, 23, 'Bir başlangıç tarihi seçmek için burayı tıklayınız.'),
(86838, 1011, 23, 'Tarih ve zaman seçmek için burayı tıklayınız.'),
(86839, 1012, 23, 'Başlangıç tarihi ve zamanını seçmek için burayı tıklayınız.'),
(86840, 1013, 23, 'Bitiş tarihi ve zamanını seçmek için burayı tıklayınız.'),
(86841, 1014, 23, 'Bu Modülü Yapılandırmak için Buraya Tıklayınız'),
(86842, 1016, 23, 'Bu Modülü Devre Dışı Bırakmak için Buraya Tıklayınız'),
(86843, 1018, 23, 'Bu Modülü Etkinleştirmek için Buraya Tıklayınız'),
(86844, 1019, 23, 'Mu Modülü Kurmak için Burata Tıklayınız'),
(86845, 1020, 23, 'aramak için burayı tıklayınız.'),
(86846, 1021, 23, 'öncelik, kategori ve takma ad ayarlarını güncellemek için burayı tıklayınız.'),
(86847, 1022, 23, 'Hepsini görmek için burayı tıklayınız.'),
(86848, 1023, 23, 'Görmek ve grafiğini çizmek için burayı tıklayınız.'),
(86849, 1024, 23, 'Tüm laboratuvar bulgularını görmek ve çizdirmek için burayı tıklayınız'),
(86850, 1025, 23, 'Tüm vital bulguları görmek ve grafiğini çizdirmek için buraya tıklayınız.'),
(86851, 1026, 23, 'Hasta detaylarını görmek için burayı tıklayınız.'),
(86852, 1027, 23, 'Onların hepsini görmek için burayı tıklayınız.'),
(86853, 1028, 23, 'Daha fazla ayrıntı için tıklayınız'),
(86854, 1029, 23, 'İzleyen tarihten itibaren veritabanı kurmak için Kur düğmesini tıklayınız.'),
(86855, 1030, 23, 'Artırmak için zaman parçalarının herhangi birini tıklayınız'),
(86856, 1031, 23, 'Hasta dosyasını açmak için hasta ismini tıklayınız'),
(86857, 1032, 23, 'Tüm sonuçları görmek için Tazele yi tıklayınız, veya özel sonuçları görmek için yukarıdaki arama kriterlerini doldurunuz.'),
(86858, 1033, 23, 'Bir tanı eklemek için tıklayınız'),
(86859, 1034, 23, 'Yeni bileşenler eklemek için tıklayınız.'),
(86860, 1035, 23, 'Yeni konsültasyon eklemek için tıklayınız.'),
(86861, 1036, 23, 'Doğrulanacak tanıları seçmek için tıklayınız'),
(86862, 1037, 23, 'İndirmek için tıklayınız'),
(86863, 1038, 23, 'Düzenlemek için tıklayınız'),
(86864, 1039, 23, 'Tanımını düzenlemek için tıklayınız'),
(86865, 1040, 23, 'Bu olayı düzenlemek için tıklayınız'),
(86866, 1041, 23, 'Rapor oluşturmak için tıklayınız'),
(86867, 1042, 23, 'Hastayı eşleştirmek için tıklayınız'),
(86868, 1043, 23, 'Yazdırmak için tıklayınız'),
(86869, 1044, 23, 'Yeni bir parti almak (eklemek) için tıklayınız'),
(86870, 1045, 23, 'Seçmek için tıklayınız'),
(86871, 1046, 23, 'Seçmek için Tıklayınız.'),
(86872, 1047, 23, 'Bu işlem için bir endüstri standardı kodu seçmek için tıklayınız'),
(86873, 1048, 23, 'Opsiyonel işlem kodunu seçmek için tıklayınız'),
(86874, 1049, 23, 'Kodlamayı seçmek veya değiştirmek için tıklayınız'),
(86875, 1050, 23, 'Uygulanmış aşı kodunu seçmek veya değiştirmek için tıklayınız.'),
(86876, 1051, 23, 'Seçmek veya tanıları değiştirmek için tıklayınız'),
(86877, 1052, 23, 'Servis kodlarını seçmek veya değiştirmek için tıklayınız.'),
(86878, 1053, 23, 'Hastayı seçmek için tıklayınız'),
(86879, 1054, 23, 'İlgili kodu seçmek tıklayınız'),
(86880, 1055, 23, 'Bu sonuç anormal ise yapılacak hizmetleri seçmek için tıklayınız'),
(86881, 1056, 23, 'İstenilen işlemi seçmek için tıklayınız'),
(86882, 1057, 23, 'Sıralamak için tıklayınız'),
(86883, 1058, 23, 'Görmek için tıklayınız'),
(86884, 1059, 23, 'Görmek veya düzenlemek için tıklayınız'),
(86885, 1060, 23, 'Görmek/düzenlemek için tıklayınız'),
(86886, 1061, 23, 'İzleyen tarihten itibaren veritabannı yükseltmek için Yükselt düğmesini tıklayınız.'),
(86887, 1062, 23, 'Hastayı eşleştirmek için yukarıdaki işaretli yeri tıklayınız'),
(86888, 1063, 23, 'Tıklayınız:'),
(86889, 1064, 23, 'Müşteri Sertifikası Zaman aşımı Günleri'),
(86890, 1065, 23, 'Müşteri Sertifikası geçerlilik dönemi'),
(86891, 1066, 23, 'Müşteri sertifikası onayı geçerli bir sayı olmalıdır'),
(86892, 1067, 23, 'Müşteri Kopyası'),
(86893, 1069, 23, 'Müşteri tıbbi öykü özeti'),
(86894, 1070, 23, 'Müşteri İsmi'),
(86895, 1071, 23, 'Müşteri Numarası'),
(86896, 1072, 23, 'Müşteri Profili - Yeni Müşteriler'),
(86897, 1073, 23, 'Müşteri Profili - Benzersiz Müşteriler'),
(86898, 1074, 23, 'Müşteriler'),
(86899, 1075, 23, 'Klinik'),
(86900, 1076, 23, 'Klinik Kopyası'),
(86901, 1077, 23, 'Günlük Klinik Kaydı'),
(86902, 1078, 23, 'Klinik ID'),
(86903, 1079, 23, 'Klinik'),
(86904, 1080, 23, 'Klinik Karar Kuralları Uyarı Yöneticisi'),
(86905, 1081, 23, 'Klinik Öykü'),
(86906, 1083, 23, 'Klinik Planlar'),
(86907, 1084, 23, 'Klinik Kalite Ölçümleri'),
(86908, 1085, 23, 'Klinik Kalite Ölçümleri 2011'),
(86909, 1086, 23, 'Klinik Kalite Ölçümleri 2014'),
(86910, 1087, 23, 'Klinik Hatırlatıcılar'),
(86911, 1088, 23, 'Klinik Raporlar'),
(86912, 1089, 23, 'Klinik Kural Aksiyon Kategorisi'),
(86913, 1090, 23, 'Klinik Kural Aksiyon Kalemi'),
(86914, 1091, 23, 'Klinik Kural Filtreleme Yöntemleri'),
(86915, 1092, 23, 'Klinik Kural Hedef Yöntemleri'),
(86916, 1093, 23, 'Klinik Kurallar'),
(86917, 1094, 23, 'Klinik Kurallar Yaş Aralıkları'),
(86918, 1095, 23, 'Klinik Kural Karşılaştırmaları'),
(86919, 1096, 23, 'Klinik Kurallar Görüşme Tipleri'),
(86920, 1097, 23, 'Klinik Kuralları Hatırlatma nedeniyle Seçenekleri'),
(86921, 1098, 23, 'Klinik Kuralları Hatırlatma inaktivasyonu Seçenekleri'),
(86922, 1099, 23, 'Klinik Kuralları Hatırlatma Aralıkları'),
(86923, 1100, 23, 'Klinik Kuralları Hatırlatma Yöntemleri'),
(86924, 1101, 23, 'Klinik Kuralları Hedef Aralıkları'),
(86925, 1102, 23, 'Klinik hedefler'),
(86926, 1103, 23, 'Klinik Terim'),
(86927, 1104, 23, 'Klinik Terim Kodları'),
(86928, 1106, 23, 'Klinisyenler'),
(86929, 1107, 23, 'Çoğalt'),
(86930, 1108, 23, 'Son Viziteyi Çoğalt'),
(86931, 1109, 23, 'Kapat'),
(86932, 1110, 23, 'Pencereyi Kapat'),
(86933, 1111, 23, 'pencereyi kapat'),
(86934, 1112, 23, 'Kapalı'),
(86935, 1113, 23, 'cm'),
(86936, 1114, 23, 'İçerik Yönetim Sistemi 1500 kenarlıkları'),
(86937, 1115, 23, 'İçerik Yönetim Sistemi 1500 Kağıt Form Kalıbı'),
(86938, 1116, 23, 'İçerik Yönetim Sistemi 1500 Kutu 31 Kalıbı'),
(86939, 1117, 23, 'İçerik Yönetim Sistemi 1500 Kutu 31 Kalıbı Tarihi (İmza)'),
(86940, 1118, 23, 'İçerik Yönetim Sistemi Kimlik'),
(86941, 1119, 23, 'İçerik Yönetim Sistemi Portali'),
(86942, 1120, 23, 'İçerik Yönetim Sistemi Portali Giriş'),
(86943, 1121, 23, 'İçerik Yönetim Sistemi Portali Giriş Kimliği'),
(86944, 1122, 23, 'İçerik Yönetim Sistemi Portali etkinleştirilmemiş!'),
(86945, 1123, 23, 'İçerik Yönetim Sistemi Portali Şifresi'),
(86946, 1124, 23, 'İçerik Yönetim Sistemi Portali İstemi'),
(86947, 1125, 23, 'İçerik Yönetim Sistemi Portali Site Adresi'),
(86948, 1126, 23, 'İçerik Yönetim Sistemi Portali Kullanıcı Adı'),
(86949, 1127, 23, '2-12 kraniyal sinirler intakt'),
(86950, 1128, 23, 'Katkı Payı'),
(86951, 1129, 23, 'Ödenen Katkı Payı'),
(86952, 1130, 23, 'KATKI PAYI'),
(86953, 1131, 23, 'Kod'),
(86954, 1132, 23, 'kod'),
(86955, 1133, 23, 'Kod Bulucu'),
(86956, 1134, 23, 'Kod iki küçük harf olmalıdır'),
(86957, 1135, 23, 'Para birimini gösteren kod veya sembol'),
(86958, 1136, 23, 'Kod Teksti'),
(86959, 1137, 23, 'Kod Tipi'),
(86960, 1138, 23, 'kod tipi'),
(86961, 1139, 23, 'Kod tipi tanınmadı'),
(86962, 1140, 23, 'Kod tipi henüz tanımlanmadı'),
(86963, 1141, 23, 'Kod Tipleri'),
(86964, 1142, 23, 'Kod(lar)'),
(86965, 1143, 23, 'Kodlanmış'),
(86966, 1144, 23, 'Kodlar'),
(86967, 1145, 23, 'Kodlama'),
(86968, 1146, 23, 'Kodlama(eğitim için tıklayınız)'),
(86969, 1147, 23, 'Kodlama-Herhangi bir görüşme(Yazma, bazı seçmeli)'),
(86970, 1148, 23, 'Kodlama - Benim Görüşmelerim (Yazma bazı seçmeli)'),
(86971, 1149, 23, 'Kodlamaya izin verilmiyor'),
(86972, 1150, 23, 'Kahve'),
(86973, 1151, 23, 'Kahve Kullanımı'),
(86974, 1152, 23, 'Ek sigorta'),
(86975, 1153, 23, 'Coll w/o'),
(86976, 1154, 23, 'Daralt'),
(86977, 1155, 23, 'daralt'),
(86978, 1156, 23, 'Tümünü Daralt'),
(86979, 1157, 23, 'Tümünü daralt'),
(86980, 1158, 23, 'tümünü daralt'),
(86981, 1160, 23, 'Alınma Tarihi'),
(86982, 1161, 23, 'Kolleksiyonlar'),
(86983, 1162, 23, 'Kolleksiyonlar Raporu'),
(86984, 1163, 23, 'Kolon Kanseri'),
(86985, 1164, 23, 'Kolon Kanseri Taraması'),
(86986, 1165, 23, 'Kolon Kanseri Cerrahisi'),
(86987, 1166, 23, 'Kolonoskopi'),
(86988, 1167, 23, 'kolonoskopi'),
(86989, 1168, 23, 'Renk'),
(86990, 1169, 23, 'Renk:Kıslt'),
(86991, 1170, 23, 'Sütun'),
(86992, 1171, 23, 'Sütunlar'),
(86993, 1172, 23, 'Partileri Birleştirmek'),
(86994, 1173, 23, 'Virgül'),
(86995, 1174, 23, 'Yorum'),
(86996, 1175, 23, 'Yorumlar'),
(86997, 1176, 23, 'Bu sonuç veya öneri için yorumlar'),
(86998, 1177, 23, 'Ticari Sigorta Şir.'),
(86999, 1178, 23, 'Kaydet'),
(87000, 1179, 23, 'İletişim'),
(87001, 1180, 23, 'İletişimler'),
(87002, 1182, 23, 'Şirket'),
(87003, 1183, 23, 'Şirket İsmi'),
(87004, 1184, 23, 'Tam'),
(87005, 1186, 23, 'Tamamlanmış'),
(87006, 1188, 23, 'Tamamlandı mı?'),
(87007, 1190, 23, 'Servis Sağlayıcının Komplikasyonları'),
(87008, 1191, 23, 'Düşük Komplikasyonları'),
(87009, 1192, 23, 'Bileşenler'),
(87010, 1193, 23, 'Bilgisayar Destekli Tıbbi Order Sistemi'),
(87011, 1194, 23, 'Sonuçlar'),
(87012, 1198, 23, 'Yapılandırma'),
(87013, 1199, 23, 'Yapılandırma'),
(87014, 1200, 23, 'Yapılandırmayı İçe/Dışa aktar'),
(87015, 1201, 23, 'Yapılandırma başarı ile kaydedildi'),
(87016, 1202, 23, 'Müşteri SSL sertifikalarını kullanmak üzere Apache ve LibreEHR ı yapılandır'),
(87017, 1203, 23, 'Müşteri tarafı SSL sertifikalarını kullanmak üzere Apache''yi yapılandır.'),
(87018, 1204, 23, 'Apacheyi HTTPS kullanmak üzere yapılandır'),
(87019, 1205, 23, 'ÖzgürETK yı Kullanıcı tarafı SSL sertifikalarını kullanmak üzere yapılandır'),
(87020, 1206, 23, 'Yolları yapılandır'),
(87021, 1207, 23, 'Yolları Yapılandır'),
(87022, 1208, 23, 'Yeni Hasta Kaydı Oluşturmayı Onayla'),
(87023, 1209, 23, 'Yeni Şifreyi Onaylayınız'),
(87024, 1210, 23, 'Ödemeyi Onaylayın'),
(87025, 1214, 23, 'Konjenital'),
(87026, 1215, 23, 'Konjonktiva, pupillalar'),
(87027, 1216, 23, 'Bağlantı hatası'),
(87028, 1217, 23, 'Bağlayıcılar'),
(87029, 1218, 23, 'Sabit'),
(87030, 1219, 23, 'sabit isim'),
(87031, 1220, 23, 'Sabit isim boş'),
(87032, 1221, 23, 'sabitler'),
(87033, 1222, 23, 'Kabızlık'),
(87034, 1223, 23, 'Yapısal'),
(87035, 1226, 23, 'Konsültasyon Kısa Özeti'),
(87036, 1227, 23, 'Bağlantı'),
(87037, 1228, 23, 'Bağlantı Eposta'),
(87038, 1229, 23, 'Bağlantı Eposta Adresi'),
(87039, 1230, 23, 'phiMail Doğrudan mesj hizmetine kaydolmak için EMR Direct ile temas kurunuz'),
(87040, 1231, 23, 'İletişim bilgileri'),
(87041, 1232, 23, 'Kontakt Lens'),
(87042, 1236, 23, 'Bağlantı kurulacak kişinin adı'),
(87043, 1237, 23, 'Bağlantı kurulacak kişi'),
(87044, 1239, 23, 'Bağlantı kurulacak telefon numarası'),
(87045, 1241, 23, 'aşağıdaki kalemlerden en az üç veya dördünü içerir:'),
(87046, 1242, 23, 'Konteyner grup adı'),
(87047, 1243, 23, 'İçerik'),
(87048, 1244, 23, 'içerik'),
(87049, 1245, 23, 'İçerik'),
(87050, 1246, 23, 'İçerik ismi boş olamaz'),
(87051, 1247, 23, 'Devam'),
(87052, 1248, 23, 'Bakımın Devamlılığı Belgesi (BDB)'),
(87053, 1249, 23, 'Bakımın Devamlılığı Kaydı(BDK)'),
(87054, 1250, 23, 'Aile Planlaması Hastaları'),
(87055, 1251, 23, 'Gebelikten Korunma'),
(87056, 1252, 23, 'Gebelikten Korunma Konuları'),
(87057, 1253, 23, 'Kontraseptif Komplikasyon (belirtiniz)'),
(87058, 1254, 23, 'Doğum Kontrol Yöntemi'),
(87059, 1255, 23, 'Aile Planlaması Ürünleri'),
(87060, 1256, 23, 'Önceden başlanmış doğum kontrol hizmetleri'),
(87061, 1257, 23, 'Kontraseptiflere Başla'),
(87062, 1258, 23, 'Kontrol ID'),
(87063, 1259, 23, 'Kontrol No:'),
(87064, 1261, 23, 'Eş ödeme'),
(87065, 1262, 23, 'Eködeme'),
(87066, 1263, 23, 'EkÖdeme'),
(87067, 1264, 23, 'Eködeme olumlu değil'),
(87068, 1265, 23, 'Eködeme Ödendi'),
(87069, 1266, 23, 'Eködemeler'),
(87070, 1267, 23, 'KOAH'),
(87071, 1268, 23, 'Sayfaları Hasta Dosyasına Kopyala'),
(87072, 1269, 23, 'Değerleri Kopyala'),
(87073, 1270, 23, 'Veritabanı dosyası kopyalanıyor. Biraz zaman alacak.'),
(87074, 1271, 23, 'Telif hakkı bilgisi'),
(87075, 1273, 23, 'Koroner Arter Baypas'),
(87076, 1274, 23, 'Koroner Arter Baypas Grefti'),
(87077, 1275, 23, 'Düzeltildi'),
(87078, 1276, 23, 'Korsika'),
(87079, 1277, 23, 'CouchDB'),
(87080, 1278, 23, 'CouchDB Bağlantısı Başarısız oldu'),
(87081, 1279, 23, 'CouchDB Veritabanı'),
(87082, 1280, 23, 'CouchDB veritabanı adı'),
(87083, 1281, 23, 'CouchDB sağlayıcı'),
(87084, 1282, 23, 'CouchDB Host ismi'),
(87085, 1283, 23, 'CouchDB Log etkinleştir'),
(87086, 1284, 23, 'CouchDB şifresi'),
(87087, 1285, 23, 'CouchDB Portu'),
(87088, 1286, 23, 'CouchDB portu'),
(87089, 1287, 23, 'CouchDB kayıdı başarısız oldu'),
(87090, 1288, 23, 'CouchDB KullanıcıAdı'),
(87091, 1289, 23, 'Öksürük'),
(87092, 1290, 23, 'Öksürük:'),
(87093, 1291, 23, 'sunucuya bağlanılamadı'),
(87094, 1293, 23, 'tablo açılamadı'),
(87095, 1294, 23, 'Dosya okunamadı'),
(87096, 1295, 23, 'Dosya okunamadı'),
(87097, 1296, 23, 'Sunucu sorunu nedeniyle eposta gönderilemedi. '),
(87098, 1297, 23, 'email sunucu hatası nedeniyle gönderilemedi '),
(87099, 1298, 23, 'Yedek klasörü oluşturulamadı:'),
(87100, 1299, 23, 'Klasör silinemedi:'),
(87101, 1300, 23, 'Eski yedek dosyası silinemedi:'),
(87102, 1301, 23, 'Eski dışarı aktarım dosyası silinemedi:'),
(87103, 1302, 23, 'Kumadin tedavisi INR izlemi'),
(87104, 1303, 23, 'Yönteme göre ülkeler'),
(87105, 1304, 23, 'Danışma'),
(87106, 1305, 23, 'Danışmanlık Faaliyetleri'),
(87107, 1306, 23, 'KARŞI SEVK FORMU'),
(87108, 1307, 23, 'Karşı-Sevk'),
(87109, 1308, 23, 'Ülke'),
(87110, 1309, 23, 'Ülke Veri Tipi'),
(87111, 1310, 23, 'Ülke listesi'),
(87112, 1311, 23, 'Ülke Listesi (yaz, yalnızca ekle seçmeli)'),
(87113, 1312, 23, 'Ülke İsmi iki harfle temsil edilmelidir. ( Örnek: Türkiye TR dir)'),
(87114, 1313, 23, 'kasaba'),
(87115, 1315, 23, 'Bono'),
(87116, 1318, 23, 'GİT (Güncel İşlem Terminolojisi)'),
(87117, 1319, 23, 'GİT Kodu'),
(87118, 1320, 23, 'GİT Kodları'),
(87119, 1324, 23, 'Raller:'),
(87120, 1325, 23, 'krem'),
(87121, 1326, 23, 'Her bir kullanıcı veya her bir iş istasyonu için yeni bir müşteri SSL sertifikası oluştur'),
(87122, 1327, 23, 'Her bir kullanıcı veya her bir kullanıcı ev sahibi ismi için yeni bir müşteri SSL sertifikası oluştur'),
(87123, 1328, 23, 'Yeni yol oluştur'),
(87124, 1329, 23, 'Bir Olay Oluştur'),
(87125, 1330, 23, 'Tam bir yedek oluştur ve indir'),
(87126, 1331, 23, 'Yolları oluştur ve düzenle'),
(87127, 1332, 23, 'Yedek Oluştur'),
(87128, 1333, 23, 'Yığın dosyası oluştur.'),
(87129, 1334, 23, 'Müşteri Sertifikası Oluştur'),
(87130, 1335, 23, 'Müşteri tarafı sertifikaları oluştur'),
(87131, 1336, 23, 'Kopyasını Oluştur'),
(87132, 1337, 23, 'Vizite kaydı oluştur'),
(87133, 1338, 23, 'Olay kaydının yedeğini oluştur'),
(87134, 1339, 23, 'Yeni konu oluştur'),
(87135, 1340, 23, 'Yeni Hasta Oluştur'),
(87136, 1341, 23, 'Yeni Yol oluştur'),
(87137, 1342, 23, 'Ofis erişimi kimlik bilgilerini oluştur'),
(87138, 1343, 23, 'Yerinde kimlik bilgilerini oluştur'),
(87139, 1344, 23, 'Hasta Notu Oluştur'),
(87140, 1345, 23, 'SSL Sertifikası Yetkilisi ve Sunucu sertifikaları oluştur.'),
(87141, 1346, 23, 'Vizit Oluştur.'),
(87142, 1347, 23, 'Oluşturuldu'),
(87143, 1348, 23, 'Dışa aktarım dosyası oluşturuluyor'),
(87144, 1349, 23, 'Yeni yol oluşturulması başarısız oldu'),
(87145, 1350, 23, 'Uzak sunucuda bu dosya oluşturulamadı'),
(87146, 1351, 23, 'İlk oluşturan'),
(87147, 1352, 23, 'alacak'),
(87148, 1353, 23, 'Kredi Kartı'),
(87149, 1354, 23, 'Krediler'),
(87150, 1355, 23, 'Kri'),
(87151, 1356, 23, 'Kriter'),
(87152, 1357, 23, 'Hırvat'),
(87153, 1358, 23, 'Kron Hastalığı'),
(87154, 1359, 23, 'Kron Hastalığı'),
(87155, 1360, 23, 'CSV dışa aktarma'),
(87156, 1361, 23, 'CSV Dosyası'),
(87157, 1362, 23, 'CSV Tablolar'),
(87158, 1363, 23, 'mm3'),
(87159, 1364, 23, 'Kübalı'),
(87160, 1365, 23, 'Para Birimi Ondalık Yerleri'),
(87161, 1366, 23, 'Para birimi Ondalık Sembolü'),
(87162, 1367, 23, 'Para Birimi Kısaltması'),
(87163, 1368, 23, 'Para Birimi Binler Ayırıcısı'),
(87164, 1369, 23, 'Güncel'),
(87165, 1370, 23, 'Güncel Alkol'),
(87166, 1371, 23, 'Güncel Konsültasyon'),
(87167, 1372, 23, 'Güncel Kriterler'),
(87168, 1373, 23, 'Güncel günü vurgulama rengi'),
(87169, 1374, 23, 'Halen her gün sigara içer'),
(87170, 1375, 23, 'Güncel dosyanın yeni ismi:'),
(87171, 1376, 23, 'Güncel Karma'),
(87172, 1377, 23, 'Güncel Yer'),
(87173, 1378, 23, 'Güncel İlaçlar'),
(87174, 1379, 23, 'Güncel Şifre'),
(87175, 1380, 23, 'Güncel Hasta'),
(87176, 1381, 23, 'Sadece Güncel Hasta'),
(87177, 1382, 23, 'Halen kullandığı uyuşturucu ilaçlar'),
(87178, 1383, 23, 'Halen bazı günler sigara içer'),
(87179, 1385, 23, 'Şu anki Değeri'),
(87180, 1386, 23, 'Halen Aktif'),
(87181, 1387, 23, 'Halen Çalışıyor'),
(87182, 1388, 23, 'Halen hiç tesis yok.'),
(87183, 1389, 23, 'Cushing Sendromu'),
(87184, 1390, 23, 'Cushing Sendromu'),
(87185, 1392, 23, 'Özel'),
(87186, 1393, 23, 'Özel Giriş?'),
(87187, 1394, 23, 'Özel Tablo'),
(87188, 1396, 23, 'Aşı Kodu'),
(87189, 1397, 23, 'Aşı Kod Haritası'),
(87190, 1398, 23, 'Aşı Bağışıklama'),
(87191, 1399, 23, 'Siklus'),
(87192, 1400, 23, 'CYP (Çocuklar ve Gençler)'),
(87193, 1401, 23, 'CYP faktörü ( Yıl başına konunan çift katsayısı)'),
(87194, 1402, 23, 'CYP (Çocuklar ve Gençler) Raporu'),
(87195, 1403, 23, 'Çek'),
(87196, 1404, 23, 'D'),
(87197, 1405, 23, 'D&C'),
(87198, 1406, 23, 'D&E'),
(87199, 1407, 23, 'Doğum Tarihi'),
(87200, 1408, 23, 'günde'),
(87201, 1409, 23, 'Günlük Kayıt'),
(87202, 1410, 23, 'Danimarkaca'),
(87203, 1411, 23, 'Veritabanında benzeri veri önceden var, lütfen kod ve/veya tanımı değiştiriniz'),
(87204, 1412, 23, 'Veritabanında benzeri veri önceden var, lütfen sabit ismini değiştiriniz'),
(87205, 1413, 23, 'Veri Sütunları'),
(87206, 1416, 23, 'Veri Hatası'),
(87207, 1417, 23, 'Verinin alındığı yer'),
(87208, 1419, 23, 'Bugüne kadar olan tüm vizitelerin verileri'),
(87209, 1420, 23, 'Veri Tipi'),
(87210, 1421, 23, 'Veritabanı'),
(87211, 1422, 23, 'Veritabanı kurulu değil.'),
(87212, 1423, 23, 'Veritabanı yaması'),
(87213, 1424, 23, 'Veritabanı Raporlama'),
(87214, 1425, 23, 'Veritabanı yükseltilmesi bitti.'),
(87215, 1426, 23, 'VeriSütunları 1 ile 999 arasında bir sayı olmak zorunda'),
(87216, 1427, 23, 'Tarih'),
(87217, 1428, 23, 'TARİH'),
(87218, 1429, 23, 'Uygulandığı Tarih ve Zaman'),
(87219, 1431, 23, 'Uygulama Tarihi'),
(87220, 1432, 23, 'Örneğin alındığı tarih ve zaman'),
(87221, 1433, 23, 'Bu gözlemin tarih ve saati'),
(87222, 1435, 23, 'Örneğin alındığı tarih ve zaman');
INSERT INTO `lang_definitions` VALUES
(87223, 1436, 23, 'Tarih bugünden büyük olamaz'),
(87224, 1437, 23, 'Doğum kontrol hizmetlerinin ilk defa sağlandığı tarih'),
(87225, 1438, 23, 'Oluşturulduğu Tarih'),
(87226, 1439, 23, 'Ölüm Tarihi'),
(87227, 1440, 23, 'Tarih Kaldırıldı'),
(87228, 1441, 23, 'Tarih Görüntülenme Biçimi'),
(87229, 1442, 23, '"randevu sonu" için tarih formatı geçerli değil'),
(87230, 1443, 23, '"randevu başlangıcı" için tarih formatı geçerli değil'),
(87231, 1444, 23, '"Sonraki Randevu" için tarih formatı geçerli değil'),
(87232, 1445, 23, '"den beri görülmedi" için tarih formatı geçerli değil'),
(87233, 1446, 23, '"den beri görülmedi" için tarih formatı geçerli değil'),
(87234, 1447, 23, 'Bağışıklama Tabloları Bilgisinin Verildiği Tarih'),
(87235, 1448, 23, 'kod için tarih eksik '),
(87236, 1449, 23, 'Master kriter tarihi'),
(87237, 1450, 23, 'Banka hesap tarihi yyyy-aa-gg'),
(87238, 1451, 23, 'Fatura tarihi'),
(87239, 1452, 23, 'Doğum Tarihi'),
(87240, 1453, 23, 'Doğum tarihi'),
(87241, 1454, 23, 'Doğum Tarihi'),
(87242, 1455, 23, 'Kayıt tarihi'),
(87243, 1456, 23, 'Yaralanma tarihi'),
(87244, 1458, 23, 'Ödeme tarihi yyyy-aa-gg'),
(87245, 1459, 23, 'Sevk tarihi'),
(87246, 1460, 23, 'Cevap tarihi'),
(87247, 1461, 23, 'Rapor tarihi'),
(87248, 1462, 23, 'Servis tarihi'),
(87249, 1463, 23, 'Servis tarihi'),
(87250, 1464, 23, 'Servis Tarihi = Bugün'),
(87251, 1465, 23, 'Servis tarihi aa/gg/yyyy'),
(87252, 1466, 23, 'Servis Tarihi:'),
(87253, 1467, 23, 'İmza tarihi'),
(87254, 1468, 23, 'Durum Değişikliği Tarihi'),
(87255, 1469, 23, 'Bu siparişin tarihi'),
(87256, 1470, 23, 'Bu raporun tarihi'),
(87257, 1471, 23, 'Aşı Bilgi Beyanı tarihi'),
(87258, 1472, 23, 'Sipariş tarihi'),
(87259, 1474, 23, 'Tarih Seçici'),
(87260, 1475, 23, 'Tarih seçici'),
(87261, 1476, 23, 'Gönderildiği Tarih'),
(87262, 1477, 23, 'Mesajın Gönderildiği Tarih'),
(87263, 1478, 23, 'Tarih Zaman'),
(87264, 1479, 23, 'Tarih değerleri boş bırakılamaz'),
(87265, 1480, 23, 'Rand/ Tarih'),
(87266, 1481, 23, 'Notlar/Tarih'),
(87267, 1482, 23, 'Son Notlar/ Tarih'),
(87268, 1483, 23, 'Tarih/Saat'),
(87269, 1484, 23, 'Tarih:'),
(87270, 1485, 23, 'Tarihe göre mesaj kütüğü'),
(87271, 1486, 23, 'Gün'),
(87272, 1487, 23, 'gün'),
(87273, 1489, 23, 'Gün Görünümü'),
(87274, 1490, 23, 'Gün'),
(87275, 1491, 23, 'Gün(ler)Pt-Cu'),
(87276, 1492, 23, 'günler'),
(87277, 1493, 23, 'Günler'),
(87278, 1494, 23, 'gün önce.'),
(87279, 1495, 23, 'Kaçırılmış Günler ve Oyunlar'),
(87280, 1496, 23, 'Son Görüşmeden Sonra Geçen Gün'),
(87281, 1497, 23, 'Kaçırılan Günler'),
(87282, 1498, 23, 'Sütun başı Günler'),
(87283, 1500, 23, 'Günler/Süt'),
(87284, 1501, 23, 'VT kuruldu'),
(87285, 1502, 23, 'GG/AA/YYYY'),
(87286, 1503, 23, 'Hasta kimlik bilgilerinin gizlenmesi'),
(87287, 1504, 23, 'Hasta kimlik bilgilerinin gizlenmesi işlemi tamamlandı'),
(87288, 1505, 23, 'Hasta kimlik bilgilerinin gizlenmesi işlemi devam ediyor'),
(87289, 1506, 23, 'Hasta kimlik bilgilerinin gizlenmesi işlemi başlatıldı ve arka planda devam ediyor'),
(87290, 1507, 23, 'Kimlik bilgileri gizlenmiş veriler tam olmayabilir'),
(87291, 1508, 23, 'Kimlik bilgileri gizlenmiş dosyaların kaydedileceği yer:'),
(87292, 1509, 23, 'DEA'),
(87293, 1511, 23, 'Sağır'),
(87294, 1512, 23, 'Hata bulma bilgisi'),
(87295, 1514, 23, 'Hata bulma'),
(87296, 1515, 23, 'Ara'),
(87297, 1516, 23, 'ÖLDÜ'),
(87298, 1517, 23, 'Aralık'),
(87299, 1518, 23, 'Ondalık libreler beya libre ve onslar # işaretiyle ayrılır (5#4 gibi)'),
(87300, 1519, 23, 'Konuşmayı Red Etti'),
(87301, 1520, 23, 'Vergiden düşülebilir'),
(87302, 1521, 23, 'Karşılanan indirimler'),
(87303, 1522, 23, 'Ön tanımlı'),
(87304, 1523, 23, 'Ön Tanımlı Takvim Görümümü'),
(87305, 1524, 23, 'Ön Tanımlı Görüşme Formu ID'),
(87306, 1526, 23, 'Ön Tanımlı Tesis'),
(87307, 1527, 23, 'Ön Tanımlı Dil'),
(87308, 1528, 23, 'Başka hiçbirisine izin verilmez ya da seçilmemiş ise ön tanımlı dil.'),
(87309, 1529, 23, 'Ön Tanımlı Liste (yaz, ekle seçmeli)'),
(87310, 1530, 23, 'Ön Tanımlı Yöntem'),
(87311, 1531, 23, 'Ön Tanımlı Şifrenin Sona ereceği Gün Sayısı'),
(87312, 1532, 23, 'Ön Tanımlı Şifrenin Sona ereceği Gün Sayısı 0 ise bu özelliğin devre dışı bırakıldığını gösterir'),
(87313, 1533, 23, 'Öntanımlı Hasta Ülkesi'),
(87314, 1535, 23, 'Ön Tanımlı Öncelik'),
(87315, 1536, 23, 'Ön Tanımlı Hizmet Sağlayıcı'),
(87316, 1537, 23, 'Ön Tanımlı Erim'),
(87317, 1538, 23, 'Vizitenin Ön Tanımlı Sebebi'),
(87318, 1540, 23, 'Ön tanımlı ayar'),
(87319, 1541, 23, 'Hasta listesinde Yeni Pencere işaret kutusunun ön tanımlı durumu'),
(87320, 1542, 23, 'Ön Tanımlı Kalıp'),
(87321, 1546, 23, 'Ön Tanımlı Birimler'),
(87322, 1547, 23, 'Ön Tanımlı Değer'),
(87323, 1548, 23, 'Ön Tanımlı Depo'),
(87324, 1549, 23, 'Ön Tanımlı X12 Partneri'),
(87325, 1550, 23, 'Ön Tanımlı/Global'),
(87326, 1551, 23, 'Sil'),
(87327, 1552, 23, 'sil'),
(87328, 1553, 23, 'Geç Nüks (>12 ay)'),
(87329, 1554, 23, 'Sil'),
(87330, 1555, 23, 'sil'),
(87331, 1556, 23, 'Silinecek Kategorilerin ID(leri): '),
(87332, 1557, 23, 'Silme Kategorisi'),
(87333, 1559, 23, 'Silme Başarısız'),
(87334, 1560, 23, 'Grubu Sil'),
(87335, 1561, 23, 'Listeyi Sil'),
(87336, 1562, 23, 'Sayfaları Sil'),
(87337, 1563, 23, 'Hasta Görüşme,Form, Konu, Belge, Ödeme, Fatura veya İşlemi Sil'),
(87338, 1565, 23, 'Satırı Sil'),
(87339, 1566, 23, 'Seçili Kalemleri Sil'),
(87340, 1568, 23, 'Silme başarılı.'),
(87341, 1569, 23, 'Bu belgeyi sil'),
(87342, 1570, 23, 'Bu formu sil'),
(87343, 1571, 23, 'Bu notu sil'),
(87344, 1573, 23, 'Başarıyla Silindi'),
(87345, 1581, 23, 'Demans'),
(87346, 1582, 23, 'Demografi'),
(87347, 1583, 23, 'Demografik Bilgiler(yaz, sadece ekle seçmeli)'),
(87348, 1585, 23, 'Demografik filtre kriterleri'),
(87349, 1586, 23, 'Demografik Bilgilere izin verilmiyor'),
(87350, 1587, 23, 'Demografik Bilgilere izin verilmiyor'),
(87351, 1589, 23, 'Payda'),
(87352, 1590, 23, 'Diş'),
(87353, 1592, 23, 'Diş Konuları'),
(87354, 1595, 23, 'Test ettiğiniz fatura tipine bağlı olarak HCFA (Sağlık Hizmeti Finans Yönetimi) faturaları için boş bir sayfada HCFA benzeri çıktılar göreceksiniz, Eğer X12 ödeme emri inceliyor iseniz karışık şifrelendirilmiş harflerden oluşan pekçok satır. Bu karışık yazı X12 EDI (Elektronik Data Değişimi) 4010A formatındadır. Bazen domino veya spiral benzeri acayip karakterler görebilirsiniz, bunlar sayfa sonu vs gibi kontrol karakteridir ve normaldir.'),
(87355, 1596, 23, 'Hesap Tarihi'),
(87356, 1597, 23, 'Hesap Tarihi Bugünden sonra olamaz'),
(87357, 1598, 23, 'Hesap Tarihi:'),
(87358, 1599, 23, 'Çökkün'),
(87359, 1600, 23, 'Depresyon'),
(87360, 1602, 23, 'Tanım'),
(87361, 1603, 23, 'tanım'),
(87362, 1605, 23, 'Açıklama Tanımı'),
(87363, 1606, 23, 'Bu işlemin tanımı veya sonuç kodu'),
(87364, 1607, 23, 'Tanım Çevirisi'),
(87365, 1609, 23, 'Varış Yeri'),
(87366, 1611, 23, 'Partiyi İmha Et'),
(87367, 1612, 23, 'İmha Et...'),
(87368, 1613, 23, 'İmha Edildi'),
(87369, 1614, 23, 'İmha Edilmiş İlaçlar'),
(87370, 1615, 23, 'İmha Edilmiş İlaçlar Raporu'),
(87371, 1616, 23, 'Ayrıntı'),
(87372, 1617, 23, 'Ayrıntılar'),
(87373, 1619, 23, 'Gelişimsel bozukluk'),
(87374, 1620, 23, 'Diyabet'),
(87375, 1621, 23, 'Diyabet Mellit'),
(87376, 1622, 23, 'Diyabet:Kan Basıncı Yönetimi'),
(87377, 1623, 23, 'Diyabet:Göz Muayenesi'),
(87378, 1624, 23, 'Diyabet:Göz Muayenesi Kalite Kontrol'),
(87379, 1625, 23, 'Diyabet Ayak Muayenesi'),
(87380, 1626, 23, 'Diyabet Ayak Muayenesi Kalite Kontrol'),
(87381, 1627, 23, 'Diyabet: Hemoglobin A1c Kötü Kontrol Kalite Kontrol'),
(87382, 1628, 23, 'Diyabet: Hemoglobin A1c'),
(87383, 1629, 23, 'Diyabet: LDL Yönetim ve Kontrolü Kalite Kontrol'),
(87384, 1630, 23, 'Diyabet: İdrarda Mikroalbüminemi'),
(87385, 1631, 23, 'Tanı'),
(87386, 1633, 23, 'Tanı'),
(87387, 1634, 23, 'Tanı Kodu'),
(87388, 1636, 23, 'Tanı tarihi'),
(87389, 1637, 23, 'Bağlanmış bir görüşmede tanı kodlanmalıdır'),
(87390, 1638, 23, 'Tanı İsmi'),
(87391, 1639, 23, 'Tanı Raporu'),
(87392, 1642, 23, 'Tanı Başlığı'),
(87393, 1643, 23, 'Tanı:'),
(87394, 1644, 23, 'Tanı: '),
(87395, 1645, 23, 'Tanısal Testler:'),
(87396, 1646, 23, 'Çevriliyor'),
(87397, 1647, 23, 'Diyaframlar/Başlıklar'),
(87398, 1648, 23, 'Diyare'),
(87399, 1650, 23, 'Dikte'),
(87400, 1651, 23, 'Dikte: '),
(87401, 1652, 23, 'Sağlık Sigortası Taşınabilirlik ve Sorumluluk Yasası Bildiriminin bir kopyasını aldınız mı?'),
(87402, 1653, 23, 'Yaygın:'),
(87403, 1654, 23, 'Dijital Olarak İmzalanmış'),
(87404, 1657, 23, 'Doğrudan Posta'),
(87405, 1663, 23, 'Müdür İsmi'),
(87406, 1665, 23, 'Sakatlık'),
(87407, 1667, 23, 'Takvimi Kaldır'),
(87408, 1668, 23, 'Çizelge İzleyicisini Kaldır'),
(87409, 1669, 23, 'Aşılamaları Kaldır'),
(87410, 1670, 23, 'Eski Metrik ANT Formunu Kaldır'),
(87411, 1672, 23, 'phpMyAdmin i kaldır'),
(87412, 1673, 23, 'Reçeteleri Kaldır'),
(87413, 1674, 23, 'Kullanıcı Gruplarını Kaldır'),
(87414, 1675, 23, 'kaldırıldı'),
(87415, 1676, 23, 'Kaldırıldı'),
(87416, 1678, 23, 'DISC'),
(87417, 1681, 23, 'Çıkart'),
(87418, 1682, 23, 'Uretra Akıntısı'),
(87419, 1684, 23, 'Sağ Akıntı'),
(87420, 1685, 23, 'Sağ Akıntı:'),
(87421, 1689, 23, 'Açıklama bilgisi'),
(87422, 1690, 23, 'Açıklama Tipi'),
(87423, 1691, 23, 'Açıklama Tipleri'),
(87424, 1692, 23, 'Açıklamalar'),
(87425, 1694, 23, 'İndirim'),
(87426, 1695, 23, 'İndirim Miktarı'),
(87427, 1696, 23, 'İndirim Düzeyi'),
(87428, 1697, 23, 'İndirim Yüzdesi'),
(87429, 1698, 23, 'Parasal Miktar olarak İndirimler'),
(87430, 1699, 23, 'Çıkış zamanında indirimler yüzde olarak değil para miktarı olarak girilir.'),
(87431, 1700, 23, 'Ayrık Sonuç'),
(87432, 1701, 23, 'Hastalık'),
(87433, 1702, 23, 'Çıkık'),
(87434, 1703, 23, 'Sevk No'),
(87435, 1704, 23, 'Sevk'),
(87436, 1705, 23, 'Alınan Belgelerin Dağıtımı'),
(87437, 1706, 23, 'Reçete edilmiş'),
(87438, 1707, 23, 'İleri direktifler ve demografik bilgiler sayfasını göster.'),
(87439, 1709, 23, 'Olay tarihleri blok olarak gösterilsin mi?'),
(87440, 1711, 23, 'Kaç olay gösterilsin'),
(87441, 1713, 23, 'Yer blok içerisinde gösterilsin mi?'),
(87442, 1714, 23, 'Görünen Ad'),
(87443, 1715, 23, 'Takvim gösterilsin mi?'),
(87444, 1718, 23, 'Bugünkü olaylar blokta gösterilsin mi?'),
(87445, 1719, 23, 'Konu blokta gösterilsin mi?'),
(87446, 1720, 23, 'Gelecek olaylar blokta gösterilsin mi?'),
(87447, 1721, 23, 'Gösterilen Sütunlar'),
(87448, 1722, 23, 'En son aşağıdaki sayıda açıklama gösteriliyor'),
(87449, 1723, 23, 'Aşağıdaki sayıda en yeni notlar gösterilmektedir'),
(87450, 1724, 23, 'En son notlardan izleyen sayıda olanlar gösteriliyor:'),
(87451, 1725, 23, 'Dağılım'),
(87452, 1726, 23, 'Dağılımlar'),
(87453, 1727, 23, 'Dağıtıcı'),
(87454, 1729, 23, 'Divertikülit'),
(87455, 1730, 23, 'Divertikülit Cerrahisi'),
(87456, 1731, 23, 'Divertikülitis'),
(87457, 1732, 23, 'Divertikülitis Cerrahisi'),
(87458, 1733, 23, 'Boşanmış'),
(87459, 1734, 23, 'Baş dönmesi'),
(87460, 1735, 23, 'Değiştirmeyiniz'),
(87461, 1742, 23, 'Takvimi göstermeyiniz'),
(87462, 1744, 23, 'Hiçbir ürünün envanterini çıkartmayınız ve satmayınız.'),
(87463, 1745, 23, 'Hasta notlarına yetkilendirme istemeyiniz.'),
(87464, 1746, 23, 'Resisüte Edilmeyecek Orderi'),
(87465, 1747, 23, 'kaydetmeyiniz'),
(87466, 1748, 23, 'yerine koymayınız'),
(87467, 1749, 23, 'hiçbir şey yapmayınız'),
(87468, 1751, 23, 'Gerçekten silmek istiyor musunuz?'),
(87469, 1752, 23, 'Seçili kısmı gerçekten silmek istiyor musunuz?'),
(87470, 1753, 23, 'Bu grubu gerçekten silmek istiyor musunuz?'),
(87471, 1755, 23, 'Devan etmek istiyor musunuz?'),
(87472, 1756, 23, 'Bunu silmek istiyor musunuz?'),
(87473, 1757, 23, 'Silmek istiyor musunuz?'),
(87474, 1758, 23, 'Bu kaydı silmek istiyor musunuz?'),
(87475, 1759, 23, 'Bu yeni hastayı eklemeye gerçekten devam etmek istiyor musunuz?'),
(87476, 1760, 23, 'Yeni isim ile devam etmek istiyor musunuz?'),
(87477, 1761, 23, 'Bu aşılama kaydını gerçekten KALICI OLARAK silmek istiyor musunuz?'),
(87478, 1762, 23, 'Doğum Tarihi'),
(87479, 1763, 23, 'Doğum Tarihi eksik mümkünse giriniz'),
(87480, 1764, 23, 'Doktorlar'),
(87481, 1765, 23, 'Doktor'),
(87482, 1766, 23, 'Doktor:'),
(87483, 1767, 23, 'Doktorun adı ve imzası'),
(87484, 1768, 23, 'Belge'),
(87485, 1769, 23, 'belge'),
(87486, 1770, 23, 'Belge Kategorileri'),
(87487, 1775, 23, 'Belge hasta id sine transfer edilemedi'),
(87488, 1777, 23, 'Belge Tarihi'),
(87489, 1778, 23, 'Belge tarih ve konusu başarıyla güncellendi'),
(87490, 1779, 23, 'Belge ID'),
(87491, 1780, 23, 'Belge yeni bir kategoriye taşındı'),
(87492, 1781, 23, 'Belge hasta id sine transfer edildi'),
(87493, 1783, 23, 'Belge bütünlük kontrolünü geçti.'),
(87494, 1785, 23, 'Belge/Resim Saklama'),
(87495, 1790, 23, 'Belge/Görüntüleme Saklanması'),
(87496, 1791, 23, 'Belgeler'),
(87497, 1792, 23, 'Belgeler (yaz, sadece ekle seçmeli)'),
(87498, 1794, 23, 'DOE'),
(87499, 1798, 23, 'Bu tip ilgili kodlara izin veriyor mu?'),
(87500, 1799, 23, 'Ev Arkadaşı'),
(87501, 1800, 23, 'Kaydetme'),
(87502, 1801, 23, 'Kaydetme'),
(87503, 1802, 23, 'Kaydetme'),
(87504, 1803, 23, 'Bitti'),
(87505, 1804, 23, 'Biten işlem:'),
(87506, 1805, 23, 'Bitti. Şimdi indire gönderilecek'),
(87507, 1806, 23, 'Ameliyat Tarihi'),
(87508, 1807, 23, 'Dozaj'),
(87509, 1809, 23, 'Düzenlemek için çift tıklayınız'),
(87510, 1810, 23, 'Çift Görme'),
(87511, 1811, 23, 'İndir'),
(87512, 1814, 23, 'Yine de İndir'),
(87513, 1815, 23, 'Fatura dosyasını indir, muhasebeye gönder ve faturalandırıldı diye işaretle.'),
(87514, 1817, 23, 'Sertifikaları İndir'),
(87515, 1818, 23, 'Konfigürasyon verilerini indir'),
(87516, 1820, 23, 'şifreli dosyayı indir'),
(87517, 1827, 23, 'Seçili Tabloları İndir'),
(87518, 1828, 23, 'Dr Kontrolü'),
(87519, 1829, 23, 'Dr Viziti'),
(87520, 1830, 23, 'Dr.'),
(87521, 1831, 23, 'Hareket ettirmek için sürükleyiniz'),
(87522, 1832, 23, 'Damlama'),
(87523, 1833, 23, 'Sürücü Belgesi No:'),
(87524, 1834, 23, 'İlaç'),
(87525, 1835, 23, 'İlaç Bulucu'),
(87526, 1836, 23, 'İlaç Formları'),
(87527, 1837, 23, 'İlaç ID si eksik'),
(87528, 1838, 23, 'İlaç araları'),
(87529, 1839, 23, 'İlaç envanteri'),
(87530, 1840, 23, 'İlaç İsmi'),
(87531, 1841, 23, 'İlacın verildiği Yollar'),
(87532, 1845, 23, 'İlaç Birimleri'),
(87533, 1846, 23, 'İlaçlar'),
(87534, 1847, 23, 'İlaçlar ve Ürünler'),
(87535, 1848, 23, 'Ağız Kuruluğu'),
(87536, 1850, 23, 'DT 1'),
(87537, 1851, 23, 'DT 2'),
(87538, 1852, 23, 'DT 3'),
(87539, 1853, 23, 'DT 4'),
(87540, 1854, 23, 'DT 5'),
(87541, 1855, 23, 'DBT 1'),
(87542, 1856, 23, 'DBT 2'),
(87543, 1857, 23, 'DBT 3'),
(87544, 1858, 23, 'DBT 4'),
(87545, 1859, 23, 'DBT 5'),
(87546, 1860, 23, 'Vadesi dolmuş'),
(87547, 1861, 23, 'Vade Tarihi'),
(87548, 1862, 23, 'Vade Tarihi aa/gg/yyyy veya yyyy/-aa-gg'),
(87549, 1863, 23, 'Vade Tarihi:'),
(87550, 1864, 23, 'Sigorta Borcu'),
(87551, 1865, 23, 'Hasta Borcu'),
(87552, 1866, 23, 'Vadesi Yakın'),
(87553, 1867, 23, 'Temerrüt Durumu'),
(87554, 1868, 23, 'Vade Durumu Güncelleme'),
(87555, 1869, 23, 'ÖzgürETK veritabanı dökümü yapılıyor'),
(87556, 1870, 23, 'ÖzgürETK web dizini ağacı dökümü yapılıyor'),
(87557, 1871, 23, 'phpGACL veritabanı dökümü yapılıyor'),
(87558, 1872, 23, 'phpGACL web dizini ağacı dökümü yapılıyor'),
(87559, 1873, 23, 'SQL-Defteri-kebir Veritabanı Dökümü Yapılıyor'),
(87560, 1874, 23, 'SQL-Defteri-kebir Veritabanı Dökümü Yapılıyor'),
(87561, 1875, 23, 'Çift Kontrolü'),
(87562, 1876, 23, 'Satırında çift ID'),
(87563, 1877, 23, 'Satırında çift isim'),
(87564, 1878, 23, 'ÇİFT UYARISI'),
(87565, 1879, 23, 'Avukatın Kalıcı Gücü'),
(87566, 1880, 23, 'süre'),
(87567, 1881, 23, 'süre'),
(87568, 1882, 23, 'Hollandaca'),
(87569, 1884, 23, 'Disfaji'),
(87570, 1885, 23, 'Dispne:'),
(87571, 1886, 23, 'Dizüri'),
(87572, 1888, 23, 'E-Reçete?'),
(87573, 1890, 23, 'e-Rx'),
(87574, 1892, 23, 'eRx Yenileme'),
(87575, 1894, 23, 'Erken Nüks (<2 Ay)'),
(87576, 1895, 23, 'Kulaklar'),
(87577, 1896, 23, 'EKG'),
(87578, 1898, 23, 'Ödem'),
(87579, 1902, 23, 'EDI-271 Dosya Yükleme'),
(87580, 1903, 23, 'EDI-271 Cevap Dosyası Yükleme'),
(87581, 1904, 23, 'Düzenle'),
(87582, 1905, 23, 'düzenle'),
(87583, 1906, 23, 'Alerjileri Düzenle'),
(87584, 1907, 23, 'Kategorileri Düzenle'),
(87585, 1908, 23, 'Tanımları Düzenle'),
(87586, 1909, 23, 'Tanımları düzenle'),
(87587, 1910, 23, 'Tanıları Düzenlenecek:'),
(87588, 1911, 23, 'Açıklamayı Düzenle'),
(87589, 1912, 23, 'Tesisleri Düzenle'),
(87590, 1913, 23, 'Tesisi Düzenle'),
(87591, 1914, 23, 'Tesis Bilgisini Düzenle'),
(87592, 1916, 23, 'Dosya düzenlenecek:'),
(87593, 1917, 23, 'Formu düzenle'),
(87594, 1918, 23, 'Global Ayarları Düzenle'),
(87595, 1920, 23, 'Görünümü düzenle'),
(87596, 1921, 23, 'Listeyi düzenle'),
(87597, 1922, 23, 'Ödemeyi düzenle'),
(87598, 1923, 23, 'Yapıyı Düzenle'),
(87599, 1924, 23, 'Kullanıcıyı Düzenle'),
(87600, 1925, 23, 'Kullanıcı ayarlarını düzenle'),
(87601, 1928, 23, 'Eğitim'),
(87602, 1929, 23, 'Eğitim Tarihi'),
(87603, 1931, 23, 'Daha fazla ayrıntı için GNU Genel Kamu Lisansına bakınız. ** Bu programla birlikte size GNU Genel Kamu Lisansının bir Kopyası gelmiş olmalıdır, gelmedi ise Özgür Yazılım Vakfına yazınız '),
(87604, 1932, 23, 'Etkili Olduğu Tarih'),
(87605, 1934, 23, 'Etkinlik'),
(87606, 1935, 23, 'İşveren No'),
(87607, 1936, 23, 'Ejakülasyonlar'),
(87608, 1937, 23, 'Dirsek'),
(87609, 1938, 23, 'Dirsek Sorunları'),
(87610, 1939, 23, 'Elektronik'),
(87611, 1942, 23, 'Elektronik Alındılar'),
(87612, 1944, 23, 'Seçilebilirlik'),
(87613, 1945, 23, 'Seçilebilirlik 270 Sorgu Yığını'),
(87614, 1946, 23, 'Seçilebilirlik Yanıtı'),
(87615, 1947, 23, 'Sağlık Bakanlığınca Sağlanan Çocuk Aşılarına seçilebilir durumu'),
(87616, 1948, 23, 'Seçilebilir'),
(87617, 1949, 23, 'Eposta'),
(87618, 1951, 23, 'Eposta Adresi'),
(87619, 1953, 23, 'Hasta hatırlatılatıcılarının gönderileceği eposta adresi. Yanıtlar bu adrese geleceğinden gereksiz postalar klasörüne düşmemesi için kliniğinizin alan adını içeren bir eposta adresi kullanmanız önemlidir.'),
(87620, 1954, 23, 'Yönetimsel uyarıların, eğer var ise, alınacağı eposta adresi'),
(87621, 1955, 23, 'Acil giriş kullanıcısının, eğer varsa, aktivasyon uyarılarını alacağı eposta adresi'),
(87622, 1956, 23, 'Eposta Yazan'),
(87623, 1957, 23, 'Batchcom dan Eposta'),
(87624, 1958, 23, 'Eposta Duyurusu'),
(87625, 1959, 23, 'Eposta Duyurusu Saatleri'),
(87626, 1961, 23, 'Önce Eposta gönder'),
(87627, 1962, 23, 'Eposta Gönderen'),
(87628, 1963, 23, 'Gönderilmiş Eposta'),
(87629, 1965, 23, 'Eposta Konusu'),
(87630, 1966, 23, 'Eposta metin, Kullanılabilir Etiket:***İsim***, örneğin Sayın ***İsim***'),
(87631, 1968, 23, 'Eposta Gönderme Yöntemi'),
(87632, 1969, 23, 'Eposta aşağıdaki adrese gönderildi'),
(87633, 1971, 23, 'Acil Durumda Temas Kurulacak'),
(87634, 1972, 23, 'Acil Durumda Temas Kurulacak Kişi'),
(87635, 1973, 23, 'Acil Durumda Temas Kurulacak Telefon Numarası'),
(87636, 1974, 23, 'Acil Kontrasepsiyon'),
(87637, 1975, 23, 'Acil Giriş'),
(87638, 1976, 23, 'Acil Giriş ACL seçildi. Kullanıcı hala aktif durumda. Lütfen kullanıcıyı deaktive edin ve acil durumlarda gerektiğinde aynısını aktive edin. Vizit Yönetimi->Aktivasyon veya deaktivasyon için kullanıcılar'),
(87639, 1977, 23, 'Acil Giriş aktivasyon epostasının dolaştırılması için tek şart arayüz/global.php dosyasındaki izleyen ayarların yapılmasıdır.'),
(87640, 1978, 23, 'Acil Giriş Eposta Adresi'),
(87641, 1979, 23, 'Acil Giriş Kullanıcısı her şeyi yapabilir.'),
(87642, 1980, 23, 'Acil Telefon'),
(87643, 1982, 23, 'Amfizem'),
(87644, 1983, 23, 'Çalışan'),
(87645, 1984, 23, 'İşveren'),
(87646, 1985, 23, 'İşveren Adresi'),
(87647, 1986, 23, 'İşveren Bilgileri'),
(87648, 1987, 23, 'İşveren İsmi'),
(87649, 1988, 23, 'BOŞ'),
(87650, 1989, 23, 'Boş'),
(87651, 1991, 23, '"Eposta Saatleri"nde boş değer'),
(87652, 1992, 23, '"Eposta Gönderen" de boş değer'),
(87653, 1993, 23, '"Eposta Konusu"nda boş değer'),
(87654, 1994, 23, '"Eposta metini"nde boş değer'),
(87655, 1995, 23, '"Sağlayıcı İsmi"nde boş değer'),
(87656, 1996, 23, '"Şifre"de boş değer'),
(87657, 1997, 23, '"SMS saatleri"nde boş değer'),
(87658, 1998, 23, '"SMS Metni"nde boş değer'),
(87659, 1999, 23, '"Kullanıcı İsmi"nde boş değer'),
(87660, 2006, 23, 'Otomatik Ölçüm Hesaplamaları Uyarılarını Etkinleştir'),
(87661, 2008, 23, 'Otomatik Ölçüm Hesaplamaları Raporlamayı Etkinleştir'),
(87662, 2009, 23, 'Otomatik Ölçüm Hesaplamaları İzlemeyi Etkinleştir'),
(87663, 2011, 23, 'Güvenli iletişim denetimini etkinleştir.'),
(87664, 2013, 23, 'Denetim Kaydını Etkinleştir.'),
(87665, 2014, 23, 'Katar ve Düğüm Doğrulama Denetimini Etkinleştir.'),
(87666, 2015, 23, 'Otomatik Ölçüm Hesaplamalarını Etkinleştir'),
(87667, 2016, 23, 'Müşteri SSL etkinleştir'),
(87668, 2017, 23, 'Müşteri SSL doğrulamasını etkinleştir'),
(87669, 2019, 23, 'Klinik Karar Kurallarını Etkinleştir'),
(87670, 2022, 23, 'Klinik Kalite Ölçüm Raporlamasını Etkinleştir'),
(87671, 2023, 23, 'Klinik Uyarıcı Açılır Penceresini Etkinleştir'),
(87672, 2024, 23, 'Klinik Uyarıcı Uygulamasını Etkinleştir'),
(87673, 2027, 23, 'Klinik Kalite Yönetimi Raporlamayı Etkinleştir'),
(87674, 2031, 23, 'Hylafax Desteğini Etkinleştir'),
(87675, 2037, 23, 'Lab Değişimini Etkinleştir'),
(87676, 2040, 23, 'Tüm SQL SEÇ sorgularının kaydını etkinleştir.'),
(87677, 2041, 23, 'Yedekleme ile ilgili etkinliklerin kaydını etkinleştir.'),
(87678, 2043, 23, 'Çeşitli etkinliklerin kaydını etkinleştir.'),
(87679, 2044, 23, 'Order etkinliklerinin kaydını etkinleştir.'),
(87680, 2045, 23, 'Hasta kaydı değişikliklerinin kaydını etkinleştir.'),
(87681, 2046, 23, 'Zamanlama etkinliklerinin kaydını etkinleştir'),
(87682, 2047, 23, 'Güvenlik ve yönetim etkinliklerinin kaydını etkinleştir.'),
(87683, 2049, 23, 'Yeni eRx Hizmetini etkinleştir'),
(87684, 2051, 23, 'Hariçte Hasta Portalini Etkinleştir'),
(87685, 2052, 23, 'Hariçte Hasta Portalini Etkinleştir'),
(87686, 2053, 23, 'Yerinde Hasta Portalini Etkinleştir'),
(87687, 2055, 23, 'Yerinde Hasta Portalini Etkinleştir'),
(87688, 2056, 23, 'Hasta Hatırlatıcı Programını Etkinleştir'),
(87689, 2058, 23, 'Otomatik Ölçüm Hesaplamaları için Veri Gerekli Uyarısını Etkinleştir'),
(87690, 2060, 23, 'Otomatik Ölçüm Hesaplamaları için İzleme Tarihi Raporlamasını Etkinleştir'),
(87691, 2061, 23, 'Tarayıcı desteğini etkinleştir'),
(87692, 2065, 23, 'LLC Lab değişim servisine ÖzgürETK desteğini etkinleştir.'),
(87693, 2066, 23, 'Kullanıcı Sertifika Doğrulamasını Etkinleştir'),
(87694, 2067, 23, 'eRx ZMG LLC servisini etkinleştir'),
(87695, 2068, 23, 'etkinleştirildi'),
(87696, 2070, 23, 'Fatura kodları ve ödemeler için eski Ücretler panelini etkinleştirir. Önerilmez, Bunun yerine Ücret Sayfasını kullanın.'),
(87697, 2071, 23, 'Görüşme'),
(87698, 2072, 23, 'Görüşme'),
(87699, 2073, 23, 'Görüşme'),
(87700, 2074, 23, 'görüşme'),
(87701, 2075, 23, 'Görüşme '),
(87702, 2076, 23, 'acil hasta görüşmesi'),
(87703, 2081, 23, 'Görüşme Tarihi'),
(87704, 2086, 23, 'Görüşme Formları'),
(87705, 2087, 23, 'sağlık ve davranış değerlendirilmesi görüşmesi'),
(87706, 2088, 23, 'Görüşme Öyküsü'),
(87707, 2089, 23, 'Görüşme ID'),
(87708, 2090, 23, 'görüşme influenza'),
(87709, 2091, 23, 'Görüşme numarası'),
(87710, 2093, 23, 'Doğum taburcu görüşmesi'),
(87711, 2094, 23, 'doğum tesisi görüşmesi'),
(87712, 2095, 23, 'meslek tedavisi görüşmesi'),
(87713, 2096, 23, 'muayenehane görüşmesi'),
(87714, 2097, 23, 'ayaktan hasta görüşmesi'),
(87715, 2098, 23, 'ayaktan aile hekimi ve kadın doğum uzmanı görüşmesi'),
(87716, 2099, 23, 'görüşme sayfa büyüklüğü'),
(87717, 2101, 23, 'gebelik görüşmesi'),
(87718, 2102, 23, 'koruyucu hekimlik ve danışmanlık görüşmesi'),
(87719, 2103, 23, '40 yaş ve üzeri koruyucu hekimlik görüşmesi'),
(87720, 2104, 23, 'koruyucu hekimlik grup görüşmesi'),
(87721, 2105, 23, 'koruyucu hekimlik diğer hizmetlerde görüşme'),
(87722, 2106, 23, '18 yaş ve üzeri koruyucu hekimlik görüşmesi'),
(87723, 2107, 23, 'psikiyatrik ve psikolojik görüşme'),
(87724, 2108, 23, 'Görüşme istatistikleri'),
(87725, 2109, 23, 'Görüşme Özeti'),
(87726, 2110, 23, 'Görüşme kodlandı'),
(87727, 2111, 23, 'Görüşme:'),
(87728, 2112, 23, 'Acil olmayan ayaktan veya yatan ya da göz görüşmesi'),
(87729, 2113, 23, 'Görüşmeler'),
(87730, 2114, 23, 'Görüşmeler ve Formlar'),
(87731, 2115, 23, 'Görüşmeler ; Formlar'),
(87732, 2116, 23, 'Görüşmelere izin verilmiyor'),
(87733, 2117, 23, 'Görüşmeler Raporu'),
(87734, 2118, 23, 'Görüşmeler Bölümü'),
(87735, 2120, 23, 'Şifreleme'),
(87736, 2121, 23, 'Son'),
(87737, 2122, 23, 'Bitiş (yyyy-aa-gg) '),
(87738, 2123, 23, 'Bitiş Tarihi'),
(87739, 2124, 23, 'Bitiş tarihi'),
(87740, 2126, 23, 'Bitiş tarihi başlangıç tarihinden daha sonra olmalıdır.'),
(87741, 2127, 23, 'Bitiş Tarihi:'),
(87742, 2131, 23, 'Bitiş Zamanı:'),
(87743, 2133, 23, 'Hizmet bitiş tarihi yyyy-aa-gg'),
(87744, 2134, 23, 'Hizmet bitiş tarihi yyyy-aa-gg bir süre girmek ister iseniz'),
(87745, 2135, 23, 'Takvim olayları için günün bitiş saati.'),
(87746, 2136, 23, 'Endokrin Anormal Kan'),
(87747, 2137, 23, 'Endokrin'),
(87748, 2138, 23, 'Endoskopi'),
(87749, 2141, 23, 'İngilizce'),
(87750, 2142, 23, 'İngilizce '),
(87751, 2143, 23, 'İngilizce (Hint)'),
(87752, 2144, 23, 'İngilizce(Standart)'),
(87753, 2145, 23, 'Hylafax yazdır komutu'),
(87754, 2146, 23, 'LibreEHR nin klasöre yazma ayrıcalığı olmasını sağlayınız'),
(87755, 2147, 23, 'KBB Akıntı'),
(87756, 2148, 23, 'KBB ağrısı'),
(87757, 2149, 23, 'Onu içermeyen tüm faturaların dışarıda bırakılması için bir tanı kodu giriniz'),
(87758, 2151, 23, 'Mektubun gövdesini buraya giriniz'),
(87759, 2152, 23, 'Veri Tabanı root Şifresini giriniz'),
(87760, 2153, 23, 'Veritabanı root kullanıcı ismini giriniz'),
(87761, 2154, 23, 'Tanıyı Giriniz'),
(87762, 2155, 23, 'İlaçları Giriniz'),
(87763, 2158, 23, 'Aşılamaları Giriniz'),
(87764, 2159, 23, 'Anahtar Giriniz'),
(87765, 2161, 23, 'Yeni Şehiri giriniz'),
(87766, 2164, 23, 'Yeni Kimlik kodunu giriniz'),
(87767, 2165, 23, 'Arama kriterlerinizi yukarı giriniz'),
(87768, 2168, 23, 'Çevresel'),
(87769, 2169, 23, 'Sigortadan Yararlanma Veri Girişi'),
(87770, 2170, 23, 'Müstahaklık Gönderme - Elektronik Alındılar'),
(87771, 2171, 23, 'Müstahaklık Gönderme - Açıklamalar'),
(87772, 2172, 23, 'Müstahaklık Gönderme - Fatura'),
(87773, 2173, 23, 'Müstahaklık Gönderme - Hasta Notu'),
(87774, 2174, 23, 'Müstahaklık Gönderme -Ara'),
(87775, 2176, 23, 'Epilepsi'),
(87776, 2178, 23, 'Elektronik Havale'),
(87777, 2180, 23, 'Elektronik Havale Gönderme'),
(87778, 2181, 23, 'Sil'),
(87779, 2182, 23, 'Ereksiyonlar'),
(87780, 2183, 23, 'Hata'),
(87781, 2185, 23, 'Laboratuvar sonuçlarının alındısının onaylanmasında hata'),
(87782, 2187, 23, 'Laboratuvar sonuçlarının Lab-Değişim Ağından alınmasında hata'),
(87783, 2188, 23, '"Cinsiyet" seçiminde hata'),
(87784, 2189, 23, '"Sağlık Sigortası Taşınabilirlik ve Sorumluluk Yasası" seçiminde hata'),
(87785, 2190, 23, '"İşlem" seçiminde hata'),
(87786, 2191, 23, '"SMS Yolu" seçiminde hata'),
(87787, 2192, 23, '"e göre sırala" seçiminde hata'),
(87788, 2193, 23, 'gzip sıkıştırma dosyasında hata: '),
(87789, 2194, 23, 'Evet veya Hayır seçiminde hata'),
(87790, 2195, 23, 'Yüklenmiş dosyayı okumak için açmada hata'),
(87791, 2199, 23, 'Lab Değişim Ağından Sonuçları Alma Hatası'),
(87792, 2202, 23, 'Dosya ayrıcalığını ÖzgürETK kullanıcısına vermede hata'),
(87793, 2205, 23, 'formu kaydederken hata!'),
(87794, 2206, 23, 'Dosyaya kaydederken hata'),
(87795, 2208, 23, 'Dosyaya yazarken hata'),
(87796, 2210, 23, 'Hata, dosya bulunmuyor'),
(87797, 2211, 23, 'HATA, sunucudan veri alınamıyor'),
(87798, 2212, 23, 'Hata, müşteri sertifikası oluşturulamıyor.'),
(87799, 2213, 23, 'Hata, admin.p12 sertifikası oluşturulamıyor.'),
(87800, 2214, 23, 'Hata, Sertifika Yetkilisi sertifikası oluşturulamıyor'),
(87801, 2215, 23, 'Hata, Sunucu sertifikası oluşturulamıyor'),
(87802, 2216, 23, 'Hata, dosya açılamıyor'),
(87803, 2217, 23, 'Hata, ÖzgürETK da Kullanıcı Sertifika Doğrulanması etkinleştirilmemiş'),
(87804, 2218, 23, 'Hata, Arşiv/Tar.php php modülünü kurmanız gerekiyor'),
(87805, 2219, 23, 'HATA: table.sql açılamadı, form bozuk?'),
(87806, 2220, 23, 'Hata: satırda id tekrarı'),
(87807, 2221, 23, 'Hata: satırda isim tekrarı'),
(87808, 2222, 23, 'HATA: Alan'),
(87809, 2223, 23, 'HATA: Eksik ZipArşivi PHP modülü'),
(87810, 2225, 23, 'Hata: şifreler uyuşmuyor. Lütfen yazdığınızı kontrol edin.'),
(87811, 2226, 23, 'Hata: şifreler uyuşmuyor. Lütfen yazdığınızı kontrol edin.'),
(87812, 2227, 23, 'Hata: dosya yok.'),
(87813, 2229, 23, 'Hata: Dosya kopyalanamıyor'),
(87814, 2230, 23, 'Hata: İndirilebilir arşiv oluşturulamıyor'),
(87815, 2231, 23, 'HATA : Zip Arşivi oluşturulamıyor'),
(87816, 2232, 23, 'HATA: Dosya çıkartılamıyor'),
(87817, 2233, 23, 'HATA: Dosya veritabanına yüklenemiyor'),
(87818, 2234, 23, 'HATA: Sürüm numarası düzenlenemiyor.'),
(87819, 2235, 23, 'Hatalar'),
(87820, 2236, 23, 'eRx Hesap Durumu'),
(87821, 2238, 23, 'ERX İsim'),
(87822, 2239, 23, 'ERX Şifre'),
(87823, 2240, 23, 'ERX Rol'),
(87824, 2241, 23, 'REX Kullanıcı'),
(87825, 2242, 23, 'Eritem:'),
(87826, 2245, 23, 'Eskimo'),
(87827, 2247, 23, 'Bilinen Hasta'),
(87828, 2249, 23, 'Etnisite'),
(87829, 2250, 23, 'Irk veya Etnisite'),
(87830, 2251, 23, 'Etnisite-Irk Listesi (yaz, sadece ekle seçmeli)'),
(87831, 2252, 23, 'Vergi No'),
(87832, 2253, 23, 'Olay'),
(87833, 2254, 23, 'Olay Başlar'),
(87834, 2255, 23, 'Olay Kategorisi'),
(87835, 2256, 23, 'Olay Tarihi'),
(87836, 2257, 23, 'Olay Tanımı'),
(87837, 2258, 23, 'Olay Ayrıntıları'),
(87838, 2259, 23, 'Olay tekrarlamıyor'),
(87839, 2260, 23, 'Olay Süresi'),
(87840, 2261, 23, 'Dakika olarak olay süresi'),
(87841, 2262, 23, 'Olay Ücreti'),
(87842, 2263, 23, 'Olay Yeri'),
(87843, 2264, 23, 'Olayın tekrarı her'),
(87844, 2265, 23, 'Olayın tekrarı her'),
(87845, 2266, 23, 'Olay başlangıç zamanı'),
(87846, 2267, 23, 'Olay başlığı'),
(87847, 2268, 23, 'Olay Başlığı'),
(87848, 2269, 23, 'Olay Web Sitesi'),
(87849, 2270, 23, 'Olaylar'),
(87850, 2271, 23, 'Olaylar:'),
(87851, 2272, 23, 'Olaylar yeni pencerede açılır'),
(87852, 2273, 23, 'her'),
(87853, 2274, 23, 'Her'),
(87854, 2275, 23, 'her 3 saatte'),
(87855, 2276, 23, 'her 4 saatte'),
(87856, 2277, 23, 'her 5 saatte'),
(87857, 2278, 23, 'her 6 saatte'),
(87858, 2279, 23, 'her 8 saatte'),
(87859, 2280, 23, 'Her Dördüncü'),
(87860, 2281, 23, 'Her ikinci'),
(87861, 2282, 23, 'Her Üçüncü'),
(87862, 2283, 23, 'Her, her ikinci, her 3. vs.'),
(87863, 2285, 23, 'Muayene ve test sonuçları'),
(87864, 2286, 23, 'Muayene sonuçları'),
(87865, 2289, 23, 'Muayene'),
(87866, 2290, 23, 'Muayene Tarihi'),
(87867, 2291, 23, 'Örnek'),
(87868, 2292, 23, 'Örnekler'),
(87869, 2293, 23, 'Muayeneler/testler'),
(87870, 2295, 23, 'Aşırı Göz yaşı'),
(87871, 2296, 23, 'Hariç Hastalar'),
(87872, 2297, 23, 'Hariç tutma'),
(87873, 2298, 23, 'Tek Sağlayıcı Örgütü'),
(87874, 2300, 23, 'Egzersiz'),
(87875, 2301, 23, 'Egzersiz Örnekleri'),
(87876, 2302, 23, 'Egzersiz örnekleri'),
(87877, 2303, 23, 'Var'),
(87878, 2304, 23, 'Çıkış Yönetimi'),
(87879, 2305, 23, 'Gen'),
(87880, 2306, 23, 'Genişlet'),
(87881, 2307, 23, 'genişlet'),
(87882, 2308, 23, 'Hepsini Genişlet'),
(87883, 2311, 23, 'Genişletilmiş Görünüm'),
(87884, 2312, 23, 'form_encounter.pid sinin olması gereken: '),
(87885, 2313, 23, 'Sona erme'),
(87886, 2314, 23, 'Sona erme Tarihi'),
(87887, 2315, 23, 'Sona eriyor'),
(87888, 2316, 23, 'Sona erime süresi:'),
(87889, 2317, 23, 'Dışa aktar'),
(87890, 2318, 23, 'CSV olarak dışa aktar'),
(87891, 2319, 23, 'Dışa aktarma Konfigürasyonu'),
(87892, 2322, 23, 'Hastanın Demografik Bilgilerini Dışa Aktar'),
(87893, 2323, 23, 'Doktor Kalite Raporunu Dışa Aktar'),
(87894, 2325, 23, 'Seçileni CSV olarak dışa aktar'),
(87895, 2326, 23, 'Seçileni Koleksiyonlara aktar'),
(87896, 2327, 23, 'CSV ye aktar'),
(87897, 2328, 23, 'Dış faturalama sistemine aktar'),
(87898, 2329, 23, 'Yabancı Ülkelere Maruziyet'),
(87899, 2330, 23, 'Yabancı Ülkelere Maruziyet'),
(87900, 2331, 23, 'Toplanmış Dış Zaman'),
(87901, 2332, 23, 'Dış'),
(87902, 2336, 23, 'TC Kimlik:'),
(87903, 2337, 23, 'TC Kimlik'),
(87904, 2338, 23, 'TC Kimlik No:'),
(87905, 2339, 23, 'Yalnızca Dıştan'),
(87906, 2342, 23, 'Dış Sevk'),
(87907, 2343, 23, 'Dış Sevk İzlemleri'),
(87908, 2344, 23, 'Dış sevk?'),
(87909, 2345, 23, 'Dış Sevkler'),
(87910, 2346, 23, 'zip dosyasını çıkart'),
(87911, 2347, 23, 'Dosya çıkartılıyor. Bu zaman alacak.'),
(87912, 2348, 23, 'Eksüda:'),
(87913, 2349, 23, 'Göz Tahrişi'),
(87914, 2350, 23, 'Göz Ağrısı'),
(87915, 2351, 23, 'Göz Kızarıklığı'),
(87916, 2352, 23, 'Gözler'),
(87917, 2353, 23, 'Cu'),
(87918, 2354, 23, 'K/H Kan Problemleri'),
(87919, 2355, 23, 'K/H Kadın Hirsutism/Strialar'),
(87920, 2356, 23, 'Tesisler'),
(87921, 2357, 23, 'Tesis'),
(87922, 2358, 23, 'tesis'),
(87923, 2359, 23, 'Tesis Yönetimi'),
(87924, 2360, 23, 'Tesis İlçe'),
(87925, 2361, 23, 'Tesis Kodu'),
(87926, 2362, 23, 'Tesis ülke kodu'),
(87927, 2363, 23, 'Tesis Belgegeçer no'),
(87928, 2364, 23, 'Tesis Adı'),
(87929, 2365, 23, 'Tesis Ulusal Sağlayıcı Kimliği'),
(87930, 2366, 23, 'Tesis Telefonu'),
(87931, 2368, 23, 'Tesis İl'),
(87932, 2369, 23, 'Tesis Cadde'),
(87933, 2370, 23, 'Tesis Posta Kodu'),
(87934, 2372, 23, 'Tesis:'),
(87935, 2373, 23, 'BAŞARISIZ'),
(87936, 2374, 23, 'başarısız'),
(87937, 2375, 23, 'Başarısız'),
(87938, 2383, 23, 'başarısızlık'),
(87939, 2390, 23, 'Aile Öyküsü'),
(87940, 2391, 23, 'Ailesinde Glokom Öyküsü'),
(87941, 2392, 23, 'Aile Öyküsü:'),
(87942, 2394, 23, 'Aile Ödemesi'),
(87943, 2395, 23, 'Aile Büyüklüğü'),
(87944, 2396, 23, 'Fantezi'),
(87945, 2398, 23, 'Farsça'),
(87946, 2400, 23, 'Baba'),
(87947, 2402, 23, 'Yorgunluk'),
(87948, 2403, 23, 'Yorgun'),
(87949, 2404, 23, 'Faks'),
(87950, 2405, 23, 'Faks sayısı'),
(87951, 2406, 23, 'Faks numarası'),
(87952, 2408, 23, 'Faks/Tarama'),
(87953, 2409, 23, 'Gelen Fakslar'),
(87954, 2410, 23, 'Giden Fakslar'),
(87955, 2411, 23, 'Özellikler'),
(87956, 2412, 23, 'Şub'),
(87957, 2413, 23, 'Şubat'),
(87958, 2414, 23, 'FECA'),
(87959, 2415, 23, 'Federal İlaç ID'),
(87960, 2416, 23, 'Federal İşveren Numarası'),
(87961, 2417, 23, 'Federal Vergi Numarası'),
(87962, 2418, 23, 'Ücret'),
(87963, 2419, 23, 'ücret'),
(87964, 2420, 23, 'Ücrete izin verilmez'),
(87965, 2421, 23, 'Ücret Sayfası'),
(87966, 2422, 23, 'Ücret Sayfası Seçenekleri'),
(87967, 2423, 23, 'Ücretler'),
(87968, 2424, 23, 'Kadın'),
(87969, 2425, 23, 'Kadın AP'),
(87970, 2426, 23, 'Kadın Kondomları'),
(87971, 2427, 23, 'Kadın G'),
(87972, 2428, 23, 'Kadın LC'),
(87973, 2429, 23, 'Kadın H'),
(87974, 2430, 23, 'Kadın Semptomlar'),
(87975, 2431, 23, 'Kadın Tüp Ligasyonu'),
(87976, 2434, 23, 'Ateş'),
(87977, 2435, 23, 'Ateş:'),
(87978, 2436, 23, 'Aile Öyküsünde Kan Hastalıkları'),
(87979, 2437, 23, 'Fibroidler'),
(87980, 2441, 23, 'İşveren veya abone ülke demografik bilgilerinde kullanılacak alan tipi'),
(87981, 2442, 23, 'İşveren veya abone ülke demografik bilgilerinde kullanılacak alan tipi'),
(87982, 2443, 23, 'Alan(lar) eksik!'),
(87983, 2447, 23, 'Dosya'),
(87984, 2448, 23, 'giriş yedeklerini oluşturma işleminin nasıl otomatik hale getirileceğini öğrenmek için Belgelendirme klasöründeki dosya'),
(87985, 2449, 23, 'dosya yeri'),
(87986, 2453, 23, 'ÖzgürETK kullanıcısına dosya ayrıcalığı verildi'),
(87987, 2455, 23, 'Dosya Odası'),
(87988, 2456, 23, 'Yüklenecek Dosya'),
(87989, 2458, 23, 'Aynı isimli dosya önceden şu yerde bulunmaktadır:'),
(87990, 2459, 23, 'Dosya ismi'),
(87991, 2461, 23, 'Dosyalar'),
(87992, 2462, 23, 'Filipinli'),
(87993, 2463, 23, 'Aşağıdaki satırın herhangi bir yerini doldurun'),
(87994, 2464, 23, 'Burayı sadece hastalara eposta duyurusu göndermek isterseniz doldurunuz'),
(87995, 2465, 23, 'Aşağıdaki değerleri doldurunuz'),
(87996, 2467, 23, 'Sırayı Doldurunuz'),
(87997, 2468, 23, 'Ayır'),
(87998, 2469, 23, 'Sabitleri ayır'),
(87999, 2470, 23, 'Tanımları ayır'),
(88000, 2473, 23, 'Filtreler'),
(88001, 2474, 23, 'Son'),
(88002, 2475, 23, 'Son Tanı'),
(88003, 2476, 23, 'Uzmanın son tanısı'),
(88004, 2478, 23, 'Finansal'),
(88005, 2479, 23, 'Finansal kapanış tarihi (yyyy-aa-gg)'),
(88006, 2480, 23, 'Finansal Raporlama - herhangi bir şey'),
(88007, 2481, 23, 'Finansal Raporlama - benim görüşmelerim'),
(88008, 2482, 23, 'Finansal Gözden Geçirme Tarihi'),
(88009, 2484, 23, 'Bul'),
(88010, 2485, 23, 'Mevcut Olanı Bul'),
(88011, 2486, 23, 'Mevcut Randevuları Bul'),
(88012, 2487, 23, 'Hastayı Bul'),
(88013, 2488, 23, 'Hasta Eğitim Materyelleri Bul'),
(88014, 2489, 23, 'Bulgular'),
(88015, 2490, 23, 'Uzmanın bulguları'),
(88016, 2491, 23, 'Mükemmel'),
(88017, 2492, 23, 'Ödemeleri Bitir'),
(88018, 2495, 23, 'İlk'),
(88019, 2497, 23, 'Haftanın ilk günü'),
(88020, 2498, 23, 'İsim'),
(88021, 2499, 23, 'İsim'),
(88022, 2500, 23, 'İsim:'),
(88023, 2503, 23, 'Uygunluk'),
(88024, 2504, 23, 'Uygunluk Düzeyi'),
(88025, 2505, 23, 'Bu oyuncunun bu gün için form düzeyi'),
(88026, 2507, 23, 'Oynamaya Uygunluk'),
(88027, 2508, 23, 'Görüşme tarihlerini belirle - herhangi bir görüşme'),
(88028, 2509, 23, 'Bunu düzelt'),
(88029, 2510, 23, 'FL'),
(88030, 2511, 23, 'Gaz'),
(88031, 2512, 23, 'Akış'),
(88032, 2514, 23, 'Nezle mevsimi'),
(88033, 2515, 23, 'Nezla Mevsimi'),
(88034, 2516, 23, 'Grip Aşılaması'),
(88035, 2517, 23, 'Sıvı ve elektrolit sorunu'),
(88036, 2518, 23, 'FMS'),
(88037, 2520, 23, 'El ile izle'),
(88038, 2521, 23, 'İzleyen veritabanını kurmak veya yükseltmek için bu yönergeleri izleyiniz'),
(88039, 2522, 23, 'İzlem'),
(88040, 2524, 23, 'İzlem sebebi'),
(88041, 2525, 23, 'Yeni bir özel sabit aşağıdadır:'),
(88042, 2526, 23, 'Yeni bir özel dil aşağıdadır:'),
(88043, 2527, 23, 'Yeni bir tanım aşağıdadır (Dil,Sabit,Tanım):'),
(88044, 2528, 23, 'Denetim günlüğünde aşağıdaki satırlarda bozukluk var'),
(88045, 2529, 23, 'İzleme Hizmetleri'),
(88046, 2530, 23, 'İzlenmesi Endikasyonu vardır'),
(88047, 2531, 23, 'Besin alamama'),
(88048, 2532, 23, 'Ayak'),
(88049, 2533, 23, 'Ayak Sorunları'),
(88050, 2534, 23, 'Ayak:'),
(88051, 2535, 23, 'Futbol yaralanmaları'),
(88052, 2536, 23, 'Futbol yaralanması'),
(88053, 2537, 23, 'Futbol Yaralanması Raporu'),
(88054, 2538, 23, 'Ayakkabı Tipi'),
(88055, 2539, 23, 'için'),
(88056, 2540, 23, 'İçin'),
(88057, 2541, 23, 'Kod için'),
(88058, 2543, 23, 'Görüşme Alacakları İçin'),
(88059, 2544, 23, 'Örnek olarak:'),
(88060, 2547, 23, 'Fatura için'),
(88061, 2548, 23, 'Sadece Medicare için, sevk eden sağlayıcı ile ödeyen sağlayıcının aynı olması zorunludur.'),
(88062, 2550, 23, 'hasta için'),
(88063, 2552, 23, 'Sevk Edilen Kurum/Hekim İçin'),
(88064, 2553, 23, 'Geçmiş için'),
(88065, 2554, 23, 'değişken için'),
(88066, 2555, 23, 'için:'),
(88067, 2556, 23, 'Fatura Programını Açık Kalmaya Zorla'),
(88068, 2557, 23, 'Yeni Hasta Oluşturulmasını Zorla'),
(88069, 2559, 23, 'Ön kol'),
(88070, 2560, 23, 'Form'),
(88071, 2561, 23, 'form'),
(88072, 2563, 23, 'Form başarıyla imzalandı'),
(88073, 2564, 23, 'Kalıp'),
(88074, 2565, 23, 'kalıp'),
(88075, 2566, 23, 'Yaş gösterme biçimi'),
(88076, 2567, 23, 'NDC için format yanlış'),
(88077, 2568, 23, 'Çoğu tarihi göstermek için kullanılan format.'),
(88078, 2569, 23, 'Çoğu kez gösterimde kullanılan biçim'),
(88079, 2570, 23, 'Biçimlendirilöiş rapor'),
(88080, 2571, 23, 'Eskiden sigara içmiş'),
(88081, 2572, 23, 'Formlar'),
(88082, 2573, 23, 'Form Yönetimi'),
(88083, 2575, 23, 'İlet'),
(88084, 2576, 23, 'Sayfaları Faks ile İlet'),
(88085, 2577, 23, 'İletilmiş'),
(88086, 2579, 23, 'Dördüncü'),
(88087, 2581, 23, 'Kırık'),
(88088, 2582, 23, 'Navikülerde kırık'),
(88089, 2583, 23, 'Lateral Malleol kırığı'),
(88090, 2584, 23, 'Medial malleol kırığı'),
(88091, 2585, 23, '5. Metatars kaidesinde kırık'),
(88092, 2586, 23, 'Çerçeve desteği gerekli'),
(88093, 2587, 23, 'Fransızca'),
(88094, 2588, 23, 'Fransızca (Kanada)'),
(88095, 2589, 23, 'Fransızca (Standart)'),
(88096, 2590, 23, 'Frekans'),
(88097, 2591, 23, 'Sık sık nezle'),
(88098, 2592, 23, 'Sık sık Hastalık'),
(88099, 2593, 23, 'Cum'),
(88100, 2594, 23, 'Cuma'),
(88101, 2595, 23, 'Başlangıç:'),
(88102, 2596, 23, 'BAŞLANGIÇ:'),
(88103, 2597, 23, 'başlangıç'),
(88104, 2598, 23, 'Başlangıç tarihi bitiş tarihinden daha sonrası olamaz.'),
(88105, 2599, 23, 'Başlangıç:'),
(88106, 2600, 23, 'Başlangıç '),
(88107, 2601, 23, 'GÖNDEREN_SEMT'),
(88108, 2602, 23, 'GÖNDEREN_EPOSTA'),
(88109, 2603, 23, 'GÖNDEREN_İSİM'),
(88110, 2604, 23, 'GÖNDEREN_SOYİSİM'),
(88111, 2605, 23, 'GÖNDEREN_İKİNCİİSİM'),
(88112, 2606, 23, 'GÖNDEREN_TELEFON'),
(88113, 2607, 23, 'GÖNDEREN_CEPTEL'),
(88114, 2608, 23, 'GÖNDEREN_POSTAKODU'),
(88115, 2609, 23, 'GÖNDEREN_ŞEHİR'),
(88116, 2610, 23, 'GÖNDEREN_CADDE'),
(88117, 2611, 23, 'GÖNDEREN_UNVAN'),
(88118, 2612, 23, 'GÖNDEREN_VEDA'),
(88119, 2613, 23, 'Ön Büro'),
(88120, 2614, 23, 'Ön Büro Makbuzları'),
(88121, 2615, 23, 'Ön Büro Makbuzları Raporu'),
(88122, 2616, 23, 'Resepsiyon'),
(88123, 2617, 23, 'Sağ Frontal:'),
(88124, 2619, 23, 'Tam İsim'),
(88125, 2620, 23, 'MYSQL çalışanlarını içeren klasörün tam yolu.'),
(88126, 2621, 23, 'Perl çalışanlarını içeren klasörün tam yolu'),
(88127, 2622, 23, 'Olay kaydı yedeği klasörünün tam yolu'),
(88128, 2623, 23, 'Geçici dosyalar için kullanılan klasörün tam yolu'),
(88129, 2624, 23, 'Tam Oynat'),
(88130, 2625, 23, 'Tam Eğitim'),
(88131, 2626, 23, 'Tamamen Ödendi'),
(88132, 2631, 23, 'Gelecek'),
(88133, 2633, 23, 'G'),
(88134, 2634, 23, 'G/DL'),
(88135, 2635, 23, 'Galiçyaca'),
(88136, 2636, 23, 'Safra Kesesi Rahatsızlığı'),
(88137, 2637, 23, 'Safra Taşları'),
(88138, 2638, 23, 'Oyun Dönemi'),
(88139, 2639, 23, 'Oyunlar'),
(88140, 2640, 23, 'Kaçırılmış Oyunlar'),
(88141, 2641, 23, 'oyunlar/olaylar'),
(88142, 2642, 23, 'Kaçırılmış Oyunlar/Olaylar'),
(88143, 2644, 23, 'Gastrit'),
(88144, 2645, 23, 'Mide Ağrısı'),
(88145, 2646, 23, 'Gastroentestinal'),
(88146, 2647, 23, 'Jenerik Bağlantı Kabul Kontrol İstatistik Raporu'),
(88147, 2648, 23, 'Jenerik Bağlantı Kabul Kontrol İstatistikleri'),
(88148, 2649, 23, 'Jenerik Bağlantı Kabul Kontrol vizit formu eksik'),
(88149, 2650, 23, 'Cinsiyet'),
(88150, 2651, 23, 'Cinsiyet '),
(88151, 2652, 23, 'Genel'),
(88152, 2653, 23, 'Genel Konu Listesi'),
(88153, 2655, 23, 'Genel Servis Kategorisi'),
(88154, 2656, 23, 'Oluştur'),
(88155, 2657, 23, 'CMS 1500 kağıdı alacaklarını oluştur ve indir'),
(88156, 2658, 23, 'HCFA 1500 kağıdı alacaklarını oluştur ve indir'),
(88157, 2659, 23, 'X12 yığın dosyasını oluştur ve indir'),
(88158, 2660, 23, 'Görüşme alacakları X12 yığın dosyasını oluştur ve indir'),
(88159, 2663, 23, 'İzin verilmiş reçeteleri oluştur ve elektronik olarak gönder.'),
(88160, 2664, 23, 'CMS 1500 oluştur'),
(88161, 2665, 23, 'CMS 1500 PDF oluştur'),
(88162, 2666, 23, 'CMS 1500 TEKST oluştur'),
(88163, 2667, 23, 'HCFA oluştur'),
(88164, 2668, 23, 'Fatura Oluştur'),
(88165, 2669, 23, 'Mektup Oluştur'),
(88166, 2670, 23, 'Oluşturulacak Mektup Konusu: '),
(88167, 2671, 23, 'Doktor Kalite Raporu Oluştur (A Yöntemi)'),
(88168, 2673, 23, 'Doktor Kalite Raporu Oluştur (B Yöntemi)'),
(88169, 2677, 23, 'Rapor Oluştur'),
(88170, 2678, 23, 'Kullanıcı Adı ve Şifre Oluşturulacak Kişi:'),
(88171, 2679, 23, 'X12 Oluştur'),
(88172, 2680, 23, 'X12 Görüşme Oluştur'),
(88173, 2682, 23, 'Oluşturulduğu tarih:'),
(88174, 2683, 23, 'Oluşturur'),
(88175, 2684, 23, 'Genitoüriner'),
(88176, 2686, 23, 'Gürcüce'),
(88177, 2687, 23, 'Almanca'),
(88178, 2691, 23, 'HL7 Al'),
(88179, 2692, 23, 'Glokom'),
(88180, 2693, 23, 'Glokom Aile Öyküsü'),
(88181, 2694, 23, 'Global'),
(88182, 2696, 23, 'Global ID'),
(88183, 2697, 23, 'Global Ayarlar'),
(88184, 2698, 23, 'Globaller'),
(88185, 2699, 23, 'GM/DL'),
(88186, 2700, 23, 'git'),
(88187, 2701, 23, 'Git'),
(88188, 2704, 23, 'Gidilecek yer:'),
(88189, 2705, 23, 'Gidilecek hafta:'),
(88190, 2706, 23, 'Bugüne Git'),
(88191, 2707, 23, 'Hedef A'),
(88192, 2708, 23, 'Hedef ve Yöntemler'),
(88193, 2709, 23, 'Hedef B'),
(88194, 2710, 23, 'Hedef C'),
(88195, 2711, 23, 'Yaralanma Derecesi'),
(88196, 2712, 23, 'Grade:'),
(88197, 2713, 23, 'gram'),
(88198, 2714, 23, 'Büyük Toplam'),
(88199, 2715, 23, 'Büyük Toplamlar'),
(88200, 2718, 23, 'Grafiği çizilebilir'),
(88201, 2720, 23, 'Den Daha Büyük:'),
(88202, 2721, 23, 'Den Daha Büyük:veya Eşit:'),
(88203, 2722, 23, 'Yunanca'),
(88204, 2723, 23, 'Çağdaş Yunanca'),
(88205, 2724, 23, 'Grup'),
(88206, 2725, 23, 'Grup İsmi'),
(88207, 2726, 23, 'Grup isimleri boş bırakılamaz.'),
(88208, 2727, 23, 'Grup isimleri rakamlarla veya boşluklarla başlayamaz.'),
(88209, 2728, 23, 'Grup isimleri rakamlarla başlayamaz.'),
(88210, 2729, 23, 'Grup Numarası:'),
(88211, 2730, 23, 'Grup Ödemesi'),
(88212, 2731, 23, 'Grup'),
(88213, 2732, 23, 'Grup ismi'),
(88214, 2733, 23, 'Gruplar ve Erişim Kontrolleri'),
(88215, 2734, 23, 'Büyüme Çizelgesi'),
(88216, 2735, 23, 'Büyüme-Çizelgesi'),
(88217, 2736, 23, 'gtts(damla)'),
(88218, 2737, 23, 'Guamca'),
(88219, 2739, 23, 'Veli / Vasi Adı'),
(88220, 2741, 23, 'Jinekolojik Muayene'),
(88221, 2742, 23, 's'),
(88222, 2743, 23, 'yatarken'),
(88223, 2744, 23, 'H/O Hepatit'),
(88224, 2745, 23, 'başarıyla silinmişti. Eğer var ise alt kategoriler aşağı taşındı.'),
(88225, 2746, 23, 'Hematom / Morarma'),
(88226, 2747, 23, 'HAI Durumu'),
(88227, 2748, 23, 'Haitice'),
(88228, 2750, 23, 'El + Parmaklar'),
(88229, 2751, 23, 'El Sorunları'),
(88230, 2752, 23, 'Sabit sürücü'),
(88231, 2753, 23, 'Güçlük ile / değil'),
(88232, 2754, 23, 'vizite ilişkilendirildi'),
(88233, 2755, 23, 'zaman aşımına uğradı'),
(88234, 2756, 23, 'Parmak izi dosyası'),
(88235, 2757, 23, 'Bu dosyanın parmak izi dosyası bulunamadı. Yenisi oluşturuldu.'),
(88236, 2758, 23, 'Parmak izi dosyası uyuşmuyor. Veri bütünlüğü bozuldu.'),
(88237, 2760, 23, 'Havaice'),
(88238, 2761, 23, 'Tehlikeli Etkinlikler'),
(88239, 2762, 23, 'Tehlikeli etkinlikler'),
(88240, 2763, 23, 'HCFA sol kenarlık'),
(88241, 2764, 23, 'HCFA Kenarlıkları'),
(88242, 2765, 23, 'HCFA üst kenarlığı'),
(88243, 2767, 23, 'o TakvimPostası '),
(88244, 2768, 23, 'Baş'),
(88245, 2769, 23, 'Baş Çev'),
(88246, 2770, 23, 'Baş Çevresi'),
(88247, 2771, 23, 'Baş Ağrısı'),
(88248, 2772, 23, 'Baş ağrıları'),
(88249, 2773, 23, 'sağlık işlemleri'),
(88250, 2774, 23, 'Sağlık İşlemleri'),
(88251, 2775, 23, 'Sağlık Merkezi / Klinik'),
(88252, 2776, 23, 'Sağlığı Sürdürme Kurumu'),
(88253, 2777, 23, 'Sağlığı Sürdürme Kurumu Tıbbi Bakım Riski'),
(88254, 2778, 23, 'İşitme Kaybı'),
(88255, 2779, 23, 'Kalp Krizi'),
(88256, 2780, 23, 'Kalp Hastalığı'),
(88257, 2781, 23, 'Kalp Yetmezliği'),
(88258, 2782, 23, 'Kalp Sorunu'),
(88259, 2783, 23, 'Kalp Sorunları'),
(88260, 2784, 23, 'Kalp Cerrahisi'),
(88261, 2785, 23, 'Kalp Nakli'),
(88262, 2786, 23, 'KALP:'),
(88263, 2787, 23, 'Mide ekşimesi'),
(88264, 2788, 23, 'Sıcak veya Soğuk'),
(88265, 2789, 23, 'Sıcak Veya Soğuk'),
(88266, 2790, 23, 'Çok sigara içen'),
(88267, 2791, 23, 'İbranice'),
(88268, 2792, 23, 'Çağdaş İbranice'),
(88269, 2793, 23, 'Baş Göz KBB'),
(88270, 2794, 23, 'Boy'),
(88271, 2795, 23, 'Boy/Uzunluk'),
(88272, 2796, 23, 'Yardım'),
(88273, 2797, 23, 'yardım'),
(88274, 2798, 23, 'Hematemez'),
(88275, 2799, 23, 'Hematokezya'),
(88276, 2800, 23, 'Hematolojik'),
(88277, 2801, 23, 'Hematüri'),
(88278, 2802, 23, 'Hemoglobin'),
(88279, 2803, 23, 'Hemoglobin A1C'),
(88280, 2804, 23, 'Hemoptizi'),
(88281, 2805, 23, 'Hepatit'),
(88282, 2806, 23, 'Hepatit A1'),
(88283, 2807, 23, 'Hepatit A 2'),
(88284, 2808, 23, 'Hepatit B 1'),
(88285, 2809, 23, 'Hepatit B 2'),
(88286, 2810, 23, 'Hepatit B 3'),
(88287, 2811, 23, 'buraya'),
(88288, 2813, 23, 'Fıtık Onarımı'),
(88289, 2814, 23, 'Disk Hernisi'),
(88290, 2815, 23, 'Herpes'),
(88291, 2816, 23, 'Duraksama'),
(88292, 2817, 23, 'Hey, siz şu zamandır buradasınız: '),
(88293, 2818, 23, 'Hib 1'),
(88294, 2819, 23, 'Hib 2'),
(88295, 2820, 23, 'Hib 3'),
(88296, 2821, 23, 'Hib 4'),
(88297, 2822, 23, 'Gizli'),
(88298, 2823, 23, 'Gizli Olaylar Yönetimi'),
(88299, 2824, 23, 'Gizle'),
(88300, 2825, 23, 'Ayrıntıları Gizle'),
(88301, 2826, 23, 'Raporda Boş E-İmza Günlüklerini Gizle'),
(88302, 2827, 23, 'Belge yönetiminde sifreleme/şifre açma seçeneklerini gizle'),
(88303, 2828, 23, 'Menüyü Gizle'),
(88304, 2830, 23, 'Hatırlatıcıları Gizle'),
(88305, 2831, 23, 'Sütunları Gizle/Göster'),
(88306, 2833, 23, 'Yüksek'),
(88307, 2834, 23, 'Yüksek Kan Basıncı'),
(88308, 2835, 23, 'Hintli'),
(88309, 2836, 23, 'Kalça + kasık'),
(88310, 2837, 23, 'Kalça ve kasık'),
(88311, 2838, 23, 'Kalça sorunları'),
(88312, 2839, 23, 'Kalça Protezi'),
(88313, 2840, 23, 'HIPAA Uyarısı Alındı'),
(88314, 2842, 23, 'Hirsutizm/Strialar'),
(88315, 2843, 23, 'Esmer'),
(88316, 2844, 23, 'Esmer - Diğer ( ABD de doğmuş)'),
(88317, 2845, 23, 'Esmer - Diğer ( ABD dışında doğmuş)'),
(88318, 2846, 23, 'Latin Amerikalı'),
(88319, 2847, 23, 'Öykü'),
(88320, 2848, 23, 'Öykü Verisi'),
(88321, 2849, 23, 'Öykü Tarihi'),
(88322, 2851, 23, 'Üfürüm Öyküsü'),
(88323, 2852, 23, 'Öykü yetkilendirilmemiş'),
(88324, 2853, 23, 'Kalp Üfürümü Öyküsü'),
(88325, 2854, 23, 'Vuruşlar'),
(88326, 2855, 23, 'HIV'),
(88327, 2858, 23, 'HL7 Görüntüleyici'),
(88328, 2860, 23, 'HMOL/L'),
(88329, 2861, 23, 'Hmongca'),
(88330, 2862, 23, 'Çoklu seçim yapmak veya seçimden çıkarmak için [Ctrl] yi basılı tutunuz.'),
(88331, 2863, 23, 'Çok kalem seçmek için [Ctrl] yi basılı tutunuz'),
(88332, 2864, 23, 'Çok takım seçmek için [Ctrl] yi basılı tutunuz'),
(88333, 2865, 23, 'Ev'),
(88334, 2866, 23, 'Ev Telefonu'),
(88335, 2867, 23, 'Ev Telefon Numarası'),
(88336, 2868, 23, 'Evsiz veya benzer?'),
(88337, 2869, 23, 'Evsiz, vs.'),
(88338, 2870, 23, 'Evsiz, vs.'),
(88339, 2871, 23, 'Kancalar'),
(88340, 2872, 23, 'Sunucu Adı'),
(88341, 2873, 23, 'Sunucu Adı boş olamaz'),
(88342, 2875, 23, 'Saat'),
(88343, 2876, 23, 'Saat'),
(88344, 2878, 23, 'Yaralanma nasıl oldu?'),
(88345, 2879, 23, 'Yaralanma nasıl oldu?'),
(88346, 2880, 23, 'Bizi nereden duymuşlar?'),
(88347, 2881, 23, 'Gelen olaylar için kaç ay ilerisi sorgulansın?'),
(88348, 2882, 23, 'HPI:'),
(88349, 2883, 23, 'HT'),
(88350, 2884, 23, 'HTML'),
(88351, 2885, 23, 'HTML Çıktısı?'),
(88352, 2886, 23, 'LLC Lab Değişim Hizmeti ÖzgürETK desteği için https bağlantısı'),
(88353, 2888, 23, 'Hylafax Dizini'),
(88354, 2889, 23, 'Hylafax Yazdır Komutu'),
(88355, 2890, 23, 'Hylafax Sunucu.'),
(88356, 2891, 23, 'Hylafax sunucu ana bilgisayar adı.'),
(88357, 2892, 23, 'Hiperaktif'),
(88358, 2893, 23, 'Hipertansiyon'),
(88359, 2894, 23, 'Hipertansiyon: Kan Basıncı Yönetimi');
INSERT INTO `lang_definitions` VALUES
(88360, 2895, 23, 'Hipertansiyon: Kan Basıncı Yönetimi Kalite Kontrol'),
(88361, 2896, 23, 'Hipertiroidi'),
(88362, 2897, 23, 'Hipotiroidi'),
(88363, 2898, 23, 'Histerektomi'),
(88364, 2899, 23, 'Ben'),
(88365, 2900, 23, 'Bu süre boyunca meşgulüm.'),
(88366, 2901, 23, 'Okuma iznim yok '),
(88367, 2902, 23, 'ICD'),
(88368, 2903, 23, 'ICD10 Tanı'),
(88369, 2904, 23, 'ICD10 İşlem/Hizmet'),
(88370, 2905, 23, 'ICD9'),
(88371, 2906, 23, 'ICD9 Tanı'),
(88372, 2907, 23, 'ICD9 İşlem/Hizmet'),
(88373, 2908, 23, 'İzlandaca'),
(88374, 2909, 23, 'Kimlik no'),
(88375, 2910, 23, 'kimlik no'),
(88376, 2911, 23, 'Kimlik no boş olamaz'),
(88377, 2912, 23, 'Nüfus Kağıdı'),
(88378, 2913, 23, 'IDays'),
(88379, 2914, 23, 'Tanımlandı:'),
(88380, 2915, 23, 'Tanımlayıcı (bir sözcük)'),
(88381, 2916, 23, 'Tanımlama kodu'),
(88382, 2917, 23, 'Oturum Boşta Zaman Aşımı Saniye'),
(88383, 2919, 23, 'eğer bu formun tüm sütunlarının tüm bilgileri tamam ise'),
(88384, 2920, 23, 'Eğer paket faturalandırma kullanılıyor ise teşhis kodu tipini ismini giriniz.'),
(88385, 2921, 23, 'eğer girilir ise sadece bu hizmeti alanları seçiniz.'),
(88386, 2922, 23, 'Eğer isim, soyad veya soyad, ad bir kısmı'),
(88387, 2923, 23, 'Eğer ödeme yolu:'),
(88388, 2924, 23, 'eğer kişi öldü ise ölüm tarihini giriniz.'),
(88389, 2925, 23, 'Eğer SMTP kullanılıyor ise sunucu ismi veya IP adresi.'),
(88390, 2926, 23, 'SMTP kullanılıyor ise sunucunun TCP port mumarası (genellikle 25)'),
(88391, 2927, 23, 'İşsiz ise Öğrenci giriniz'),
(88392, 2928, 23, 'Hasta yaşı gösterilmesinde yıl/ay/gün seçildi ise yaş yıl olarak bu rakamı geçerse sadece yılın gösterileceği sınır yaş'),
(88393, 2929, 23, 'eReçete için eRx rolünü değiştirirseniz eReçete iş akışını etkileyebilir. Bir zorluk ile karşılaşırsanız eReçete satıcınız ile temas ediniz.'),
(88394, 2931, 23, 'Elektronik havale göndermeyi seçmiş iseniz X12 dosyasından karşılık helen faturalar ile bir araştırma penceresi tekrar görünür. Havale bilgisi uygulanmadan önce eğer bir düzeltme yapmak ister iseniz bu fatura numaralarının her hangi birini aşağıda anlatıldığı gibi tıklayabilirsiniz. Değişiklikleri uygulamak için sayfanın en altındaki Havale Dosyasını Oluştur düğmesini tıklayınız. Bu ayrıntılı bir rapor ile yeni bir pencere oluşturacaktır.'),
(88395, 2932, 23, 'Arama Sayfasına bir Ödeme Tarihi girdiyseniz bu ödemelerin atama tarihinin ve X12 dosyasından alınan düzeltmelerin önüne geçer. Bunun rapor amaçlı yararı olabilir.eğer sizin gönderme tarihinizi sigorta şirketinin işlem tarihi yerine kullanmak ister iseniz Bunun önceki ödemeleri ve bunlara ikincil alacakları etkilediğine dikkat ediniz'),
(88396, 2933, 23, 'Sütunlar'),
(88397, 2934, 23, 'Veritabanını yükseltmek isterseniz veritabanı zip dosyasını şu klasöre yerleştiriniz:'),
(88398, 2936, 23, 'Görmezden gelin'),
(88399, 2937, 23, 'hastalık'),
(88400, 2938, 23, 'IM'),
(88401, 2941, 23, 'Görüntüleme Servisi'),
(88402, 2942, 23, 'Aşılama'),
(88403, 2943, 23, 'Aşılama Kodu'),
(88404, 2945, 23, 'Aşılama Tarihi'),
(88405, 2947, 23, 'Aşı Parti Numarası'),
(88406, 2948, 23, 'Aşı Üreticisi'),
(88407, 2949, 23, 'Aşılama Kaydı'),
(88408, 2951, 23, 'Aşılama Servisi'),
(88409, 2952, 23, 'Aşılama Başlığı'),
(88410, 2953, 23, 'Aşılamalar'),
(88411, 2954, 23, 'Aşılar'),
(88412, 2955, 23, 'İmmünolojik'),
(88413, 2956, 23, 'İmplantlar'),
(88414, 2957, 23, 'İçe aktarmak'),
(88415, 2961, 23, 'Sertifikayı tarayıcıya aktar'),
(88416, 2962, 23, 'Konfigürasyonu aktar'),
(88417, 2964, 23, 'Hastayı içe aktar'),
(88418, 2965, 23, 'Hasta Demografik Bilgilerini içe aktar'),
(88419, 2969, 23, 'Muhasebeden içe aktarıldı'),
(88420, 2972, 23, 'İyileştirilmiş'),
(88421, 2973, 23, 'içinde'),
(88422, 2974, 23, 'İÇİNDE'),
(88423, 2975, 23, 'her bir gözde'),
(88424, 2976, 23, 'sol gözde'),
(88425, 2977, 23, 'burun deliğinde'),
(88426, 2978, 23, 'Ofiste'),
(88427, 2979, 23, 'sağ gözde'),
(88428, 2980, 23, 'ev içi'),
(88429, 2981, 23, 'inaktif'),
(88430, 2982, 23, 'boş Günler'),
(88431, 2983, 23, 'Gelen Kutusu'),
(88432, 2986, 23, 'Kontrol Toplamı Dahil'),
(88433, 2987, 23, 'Dahil Tamamlandı'),
(88434, 2988, 23, 'İnaktif kullanıcılar dahil'),
(88435, 2989, 23, 'Kategorize edilmeyenler dahil'),
(88436, 2990, 23, 'Yapılandırılmamış Veriler dahil'),
(88437, 2991, 23, 'Vital bulgular dahil'),
(88438, 2992, 23, 'Vital veriler dahil edilsin mi?'),
(88439, 2993, 23, 'Dahil etme'),
(88440, 2994, 23, 'Gelir'),
(88441, 2996, 23, 'Tamamlanmamış'),
(88442, 2997, 23, 'Abort İnkomplet Tedavisi'),
(88443, 2998, 23, 'İnkontinans'),
(88444, 2999, 23, 'Klinik laboratuvar test sonuçlarını yapılandırılmış veri olarak sertifiye elektronik sağlık kaydı raporuna dahil et.'),
(88445, 3001, 23, 'Artmış:'),
(88446, 3002, 23, 'Mesuliyet Sigortası'),
(88447, 3003, 23, 'Belirsiz'),
(88448, 3004, 23, 'Hintli'),
(88449, 3005, 23, 'Anormalliği gösterir'),
(88450, 3006, 23, 'Bu konunun halen aktif olup olmadığını gösterir'),
(88451, 3008, 23, 'Özelleşmiş kullanım belirteci'),
(88452, 3009, 23, 'Yoksul Hastalar'),
(88453, 3010, 23, 'Yoksul Hastalar Raporu'),
(88454, 3011, 23, 'Yoksullar'),
(88455, 3014, 23, 'Kürtaj'),
(88456, 3016, 23, 'Seçilemez'),
(88457, 3017, 23, 'Enfeksiyon / Apse'),
(88458, 3018, 23, 'Enfeksiyonlar'),
(88459, 3019, 23, 'Kısır'),
(88460, 3020, 23, 'Kısırlık'),
(88461, 3021, 23, 'İnfluenza 1'),
(88462, 3022, 23, 'İnfluenza 2'),
(88463, 3023, 23, '50 yaş ve üzeri hastalar için grip aşısı'),
(88464, 3024, 23, '50 yaş ve üzeri hastalar için grip aşısı kalite kontrol'),
(88465, 3025, 23, 'Grip Aşısı'),
(88466, 3026, 23, 'Bilgi'),
(88467, 3027, 23, 'test 1 bilgi'),
(88468, 3028, 23, 'test 2 bilgi'),
(88469, 3029, 23, 'test 3 bilgi'),
(88470, 3030, 23, 'test 4 bilgi'),
(88471, 3031, 23, 'test 5 bilgi'),
(88472, 3032, 23, 'test 6 bilgi'),
(88473, 3034, 23, 'inhalasyon'),
(88474, 3035, 23, 'inhalasyon'),
(88475, 3037, 23, 'İlk Kullanıcı'),
(88476, 3039, 23, 'Enjeksiyon ilaçları'),
(88477, 3040, 23, 'Enjeksiyon'),
(88478, 3041, 23, 'Yaralı Vücut Kısmı'),
(88479, 3042, 23, 'Yaralı'),
(88480, 3043, 23, 'Yara'),
(88481, 3044, 23, 'Yara Mekanizması'),
(88482, 3045, 23, 'Yara İnceleme Raporu'),
(88483, 3046, 23, 'Yara Denetimi'),
(88484, 3047, 23, 'Yara Tipi'),
(88485, 3048, 23, 'Yara/hastalık ilgili'),
(88486, 3051, 23, 'Giriş Alanları'),
(88487, 3056, 23, 'Sig düzenle'),
(88488, 3057, 23, 'Sig paket'),
(88489, 3058, 23, 'Sig Kod'),
(88490, 3061, 23, 'Sig fazla ödenmiş'),
(88491, 3063, 23, 'Sig geri ödeme'),
(88492, 3064, 23, 'Sig Özet'),
(88493, 3065, 23, 'Sig1'),
(88494, 3066, 23, 'Sig2'),
(88495, 3067, 23, 'Sig3'),
(88496, 3069, 23, 'Araya ekleme başarısız '),
(88497, 3070, 23, 'Eski olayları tablolara ekle'),
(88498, 3072, 23, 'Uykusuzluk'),
(88499, 3074, 23, 'Gözlem'),
(88500, 3075, 23, 'İnstabilite /sublüksasyon'),
(88501, 3079, 23, 'VT kur'),
(88502, 3081, 23, 'Talimat verilmiş'),
(88503, 3082, 23, 'Talimat'),
(88504, 3084, 23, 'Talimatlar:'),
(88505, 3086, 23, 'İnsüline Bağımlı Diyabet'),
(88506, 3087, 23, 'Sigorta'),
(88507, 3088, 23, 'sigorta'),
(88508, 3093, 23, 'Sigorta Şirk.'),
(88509, 3094, 23, 'Sigorta Şirketleri'),
(88510, 3095, 23, 'Sigorta Şirketi'),
(88511, 3096, 23, 'Sigorta Şirketi Ara/Ekle'),
(88512, 3098, 23, 'Sigorta Bilgileri'),
(88513, 3099, 23, 'Sigorta bilgisi dosyada'),
(88514, 3100, 23, 'Sigorta Numaraları'),
(88515, 3101, 23, 'Sigorta Ödemesi'),
(88516, 3103, 23, 'Sigorta Sağlayıcı'),
(88517, 3107, 23, 'Alma Sonu'),
(88518, 3108, 23, 'Alma Tarihi'),
(88519, 3109, 23, 'Zihinsel Becerilerde Azalma'),
(88520, 3113, 23, 'İç hata - hiç bir sayfa seçilmedi!'),
(88521, 3114, 23, 'İç hata - hasta ID verilmedi!'),
(88522, 3115, 23, 'İç hata yüklenmiş dosyaya erişiliyor!'),
(88523, 3116, 23, 'İç hata!'),
(88524, 3117, 23, 'İç hata, hiç bir ilaç ID belirtilmemiş!'),
(88525, 3119, 23, 'İç hata: alacak '),
(88526, 3120, 23, 'İç hata: görüşme'),
(88527, 3121, 23, 'İç hata: pid veya görüşme eksik'),
(88528, 3123, 23, 'İç Tanımlayıcı (pid)'),
(88529, 3126, 23, 'İç Sevkler'),
(88530, 3127, 23, 'İç Zaman Toplandı'),
(88531, 3128, 23, 'Uluslararası Gümrük Vergisi'),
(88532, 3129, 23, 'Tercüman'),
(88533, 3130, 23, 'Tercüman gerekli mi?'),
(88534, 3131, 23, 'İnterstisyel Akciğer Hastalığı'),
(88535, 3132, 23, 'Ara'),
(88536, 3137, 23, 'Dayanıksızlık'),
(88537, 3139, 23, 'kas içerisine'),
(88538, 3140, 23, 'damardan'),
(88539, 3141, 23, 'sunu'),
(88540, 3149, 23, 'kaynakta kod için geçersiz veya eksik ödeyen '),
(88541, 3151, 23, 'Geçersiz Servis Kodları'),
(88542, 3152, 23, 'Geçersiz kaynak atama'),
(88543, 3154, 23, 'InvAmt'),
(88544, 3155, 23, 'Envanter'),
(88545, 3156, 23, 'Envanter Etkinliği'),
(88546, 3157, 23, 'Hem ilaçların hem de ilaç dışı ürünlerin envanterini çıkart ve sat'),
(88547, 3158, 23, 'Sadece ilaçların envanterini çıkart ve sat'),
(88548, 3159, 23, 'Bu sipariş için envanter yok'),
(88549, 3160, 23, 'Envanter Listesi'),
(88550, 3161, 23, 'Envanter İşlemleri'),
(88551, 3162, 23, 'Fatura'),
(88552, 3163, 23, 'Fatura'),
(88553, 3166, 23, 'Fatura'),
(88554, 3167, 23, 'Faturada tarih yok!'),
(88555, 3169, 23, 'Fatura referans numarası'),
(88556, 3170, 23, 'Fatura referans numarası havuzu, eğer kullanıldı ise'),
(88557, 3171, 23, 'Fatura Referans Numarası Havuzları'),
(88558, 3172, 23, 'Fatura RefNo Havuzu'),
(88559, 3173, 23, 'Fatura:'),
(88560, 3174, 23, 'Aile Planlaması'),
(88561, 3177, 23, 'Aile Planlaması Üreme Sağlığı verisi için'),
(88562, 3178, 23, 'Aile Planlaması İstatistik Raporu'),
(88563, 3179, 23, 'Aile Planlaması İstatistikleri'),
(88564, 3180, 23, 'IPV 1'),
(88565, 3181, 23, 'IPV 2'),
(88566, 3182, 23, 'IPV 3'),
(88567, 3183, 23, 'IPV 4'),
(88568, 3185, 23, 'Düzensiz Kalp Atımı'),
(88569, 3186, 23, 'İritabilite'),
(88570, 3187, 23, 'Tahriş'),
(88571, 3191, 23, 'gerekli bir alandır.'),
(88572, 3192, 23, 'bir root düğümüdür ve silinemez.'),
(88573, 3197, 23, 'geçerli değil (ondalık kısımlar tamam)'),
(88574, 3198, 23, 'PHP Güvenli Modu mu kullanıyor?'),
(88575, 3200, 23, 'taslaklardan metin tercüme edilecek mi?'),
(88576, 3201, 23, 'Listelerden metin tercüme edilecek mi?'),
(88577, 3204, 23, 'Bu bir tanı tipi mi?'),
(88578, 3212, 23, 'Bu tip ücret sayfasında gizli mi?'),
(88579, 3214, 23, 'çok uzun'),
(88580, 3216, 23, 'Konu'),
(88581, 3217, 23, 'konu'),
(88582, 3218, 23, 'Yayın Tarihi'),
(88583, 3219, 23, 'Yayın ID'),
(88584, 3220, 23, 'Yayın Başlığı'),
(88585, 3223, 23, 'Konular'),
(88586, 3224, 23, 'Konular (Yaralanmalar/Medikal/Alerji)'),
(88587, 3225, 23, 'Konular (Yaralanmalar/Medikal/Alerji):'),
(88588, 3226, 23, 'Konular ve Görüşmeler'),
(88589, 3227, 23, 'Konular ve Görüşmeler:'),
(88590, 3228, 23, 'Konulara yetki yok'),
(88591, 3229, 23, 'Konular Bölümü'),
(88592, 3230, 23, 'İtalyanca'),
(88593, 3231, 23, 'Madde'),
(88594, 3232, 23, 'madde'),
(88595, 3234, 23, 'maddelerin yüklenmesi başarısız'),
(88596, 3235, 23, 'IU/L'),
(88597, 3236, 23, 'RİA'),
(88598, 3237, 23, 'IV'),
(88599, 3238, 23, 'Oca'),
(88600, 3239, 23, 'Ocak'),
(88601, 3240, 23, 'Japonca'),
(88602, 3241, 23, 'Sarılık'),
(88603, 3243, 23, 'İş Tanımı'),
(88604, 3244, 23, 'İş ID'),
(88605, 3245, 23, 'Eklem çıkıkları'),
(88606, 3246, 23, 'Eklem Ağrısı'),
(88607, 3247, 23, 'Eklem burkulmaları'),
(88608, 3248, 23, 'Tem'),
(88609, 3249, 23, 'Temmuz'),
(88610, 3250, 23, 'Haz'),
(88611, 3251, 23, 'Haziran'),
(88612, 3252, 23, 'Tam aşağıda mavi bir alana arama kriterlerinizi girebilirsiniz. Hasta soyadı, dosya numarası, görüşme numarası, servis tarihi veya bunların herhangi bir kombinasyonu ile arama yapabilirsiniz. Tüm faturaları görmeyi isteyip istemediğinizi, açık faturaları veya vadesi gelmiş (hastaya) faturaları görmeyi seçebilirsiniz. Aramayı yapmak için Ara düğmesini tıklayınız.'),
(88613, 3253, 23, 'Sadece Benim'),
(88614, 3255, 23, 'Hizala'),
(88615, 3256, 23, 'Hizala/Kaydet'),
(88616, 3258, 23, 'k, işte kalan'),
(88617, 3265, 23, 'Anahtar sözcükler'),
(88618, 3266, 23, 'kg'),
(88619, 3267, 23, 'kg/m^2'),
(88620, 3269, 23, 'Böbrek Kanseri'),
(88621, 3270, 23, 'Böbrek Yetmezliği'),
(88622, 3271, 23, 'Böbrek Enfeksiyonları'),
(88623, 3272, 23, 'Böbrek Taşları'),
(88624, 3273, 23, 'Böbrek Nakli'),
(88625, 3277, 23, 'Diz'),
(88626, 3278, 23, 'Diz Sorunları'),
(88627, 3279, 23, 'Diz Protezi'),
(88628, 3282, 23, 'Korece'),
(88629, 3286, 23, 'Lab'),
(88630, 3288, 23, 'Lab Değişim Site Adresi'),
(88631, 3289, 23, 'Lab Değişim Site Kimliği'),
(88632, 3290, 23, 'Lab Değişim Fiş Idsi'),
(88633, 3294, 23, 'Lab Ara Durumu'),
(88634, 3295, 23, 'Lab Raporu'),
(88635, 3296, 23, 'Lab Sonucu'),
(88636, 3297, 23, 'Lab Sonuçları'),
(88637, 3299, 23, 'Lab Sonuçları Raporu'),
(88638, 3300, 23, 'Lab Servisi'),
(88639, 3303, 23, 'Etiket'),
(88640, 3304, 23, 'Etiket boş olamaz'),
(88641, 3305, 23, 'Etiket Sütunları'),
(88642, 3307, 23, 'Etiket Sütunları 1 ve 999 arası bir sayı olmalıdır'),
(88643, 3308, 23, 'Etiketler'),
(88644, 3311, 23, 'Laboratuvarlar'),
(88645, 3312, 23, 'Kesi / cilt durumu'),
(88646, 3313, 23, 'Kesi/sıyrık'),
(88647, 3316, 23, 'Dil'),
(88648, 3317, 23, 'Dil Kodu'),
(88649, 3318, 23, 'Dil tanımı eklendi'),
(88650, 3319, 23, 'Dil Arayüz Aracı'),
(88651, 3320, 23, 'Dil Listesi (yaz, sadece ekle seçmeli)'),
(88652, 3321, 23, 'Dil İsmi'),
(88653, 3322, 23, 'Dil'),
(88654, 3324, 23, 'Laosça'),
(88655, 3325, 23, 'Son'),
(88656, 3326, 23, 'Son Etkinlik Tarihi'),
(88657, 3328, 23, 'Son Fatura Tarihi:'),
(88658, 3330, 23, 'Son takvim Yılı'),
(88659, 3333, 23, 'Son Görüşme'),
(88660, 3343, 23, 'Geçen Ay'),
(88661, 3344, 23, 'Soyad'),
(88662, 3345, 23, 'Soyad'),
(88663, 3346, 23, 'Soyad:'),
(88664, 3350, 23, 'Son Gözden Geçirme:'),
(88665, 3352, 23, 'Son Kaydetme:'),
(88666, 3356, 23, 'Son Güncellemeyi Yapan'),
(88667, 3357, 23, 'En son doğrulandığı tarih:'),
(88668, 3358, 23, 'Son Vizit'),
(88669, 3360, 23, 'Geç Nüks (2-12 ay)'),
(88670, 3361, 23, 'Lateral Malleol'),
(88671, 3362, 23, 'Lateral Malleol'),
(88672, 3363, 23, 'Lateralizasyon'),
(88673, 3364, 23, 'Bu işlemin Lateralizasyonu (uygun ise)'),
(88674, 3365, 23, 'Yana kaymış tepe vurumu:'),
(88675, 3373, 23, 'Düzen Temelli'),
(88676, 3374, 23, 'Düzen Editörü'),
(88677, 3375, 23, 'Düzen grupları'),
(88678, 3376, 23, 'Düzen Stili'),
(88679, 3378, 23, 'Düzen Temelli Vizit Formları'),
(88680, 3379, 23, 'Düzenler'),
(88681, 3380, 23, 'lb'),
(88682, 3381, 23, 'lbs'),
(88683, 3382, 23, 'LDL'),
(88684, 3383, 23, 'hala aktif ise boş bırak'),
(88685, 3385, 23, 'Şifreyi değiştirmemek için boş bırakın'),
(88686, 3386, 23, 'İle Mesaj Bırakın'),
(88687, 3387, 23, 'Formu Bırakın'),
(88688, 3390, 23, 'Sol'),
(88689, 3391, 23, 'Sol Kulak'),
(88690, 3392, 23, 'sol kulak'),
(88691, 3394, 23, 'Kalan:'),
(88692, 3395, 23, 'Kalan: '),
(88693, 3396, 23, 'Bacak Ağrısı/Kramp'),
(88694, 3397, 23, 'Yasal'),
(88695, 3400, 23, 'Yazı:'),
(88696, 3401, 23, 'Uzunluk'),
(88697, 3402, 23, 'Değiştiricinin uzunluğu, yoksa 0'),
(88698, 3405, 23, 'Az-özel bilgi (yaz, sadece ekle seçmeli)'),
(88699, 3406, 23, 'Mektup'),
(88700, 3407, 23, 'Mektup Oluşturucu'),
(88701, 3409, 23, 'Doktorun imzaladığı antetli kağıt'),
(88702, 3410, 23, 'Hastanın imzaladığı antetli kağıt'),
(88703, 3411, 23, 'Aciliyet düzeyi'),
(88704, 3412, 23, 'Sorumluluk'),
(88705, 3413, 23, 'Tıbbi Sorumluluk'),
(88706, 3414, 23, 'Sürücü Belge No:'),
(88707, 3423, 23, 'Yaşam Tarzı'),
(88708, 3424, 23, 'Yaşam Tarzı durumu'),
(88709, 3425, 23, 'Lif yırtılması veya zedelenmesi'),
(88710, 3428, 23, 'Olayların Sınırı'),
(88711, 3433, 23, 'Link edildi'),
(88712, 3436, 23, 'Belgeye bağlandı'),
(88713, 3438, 23, 'Liste'),
(88714, 3439, 23, 'Liste kutusu'),
(88715, 3440, 23, 'liste kutusu'),
(88716, 3441, 23, 'liste kutusu y/ekle'),
(88717, 3442, 23, 'Liste kutusu y/ekle'),
(88718, 3443, 23, 'Liste düzenleyici'),
(88719, 3445, 23, 'Grupları listele'),
(88720, 3446, 23, 'Sigorta Şirketlerini Listele'),
(88721, 3448, 23, 'Liste maddeleri bir rakam ile başlayamaz.'),
(88722, 3449, 23, 'Liste maddeleri illegal karakter(ler) içeriyor.'),
(88723, 3451, 23, 'Listeleri listele'),
(88724, 3452, 23, 'Liste Adı'),
(88725, 3453, 23, 'Liste Adları rakamlarla başlayamaz.'),
(88726, 3454, 23, 'Reçeteleri Listele'),
(88727, 3458, 23, 'Listeler'),
(88728, 3460, 23, 'Güncel Vasiyetname'),
(88729, 3461, 23, 'LLL:'),
(88730, 3462, 23, 'SAT'),
(88731, 3464, 23, 'Tanımları Yükle'),
(88732, 3470, 23, 'YÜKLÜYOR'),
(88733, 3472, 23, 'YER'),
(88734, 3473, 23, 'Yerel'),
(88735, 3476, 23, 'Yer'),
(88736, 3477, 23, 'Şehir'),
(88737, 3478, 23, 'Yer'),
(88738, 3479, 23, 'özgüretk makinesinin yeri ve hassas bilgiler içerebilir. Kullandıktan sonra bilgilerin el ile silinmesi tavsiye olunur.'),
(88739, 3480, 23, 'Bu partinin yeri'),
(88740, 3481, 23, 'Yer belirtilmemiş'),
(88741, 3482, 23, 'Hylafaxın faksları kaydettiği yer'),
(88742, 3483, 23, 'Tarama dosyalarının kaydedildiği yer'),
(88743, 3484, 23, 'Yer:'),
(88744, 3485, 23, 'Kilit'),
(88745, 3495, 23, 'Girdi'),
(88746, 3496, 23, 'Girdi:'),
(88747, 3497, 23, 'Olarak girdi: '),
(88748, 3498, 23, 'Çıktı.'),
(88749, 3500, 23, 'Giriş'),
(88750, 3501, 23, 'giriş'),
(88751, 3505, 23, 'Çıkış'),
(88752, 3506, 23, 'Çıkış'),
(88753, 3507, 23, 'Günlükler'),
(88754, 3508, 23, 'Günlükler Görüntüleyici'),
(88755, 3510, 23, 'Ara'),
(88756, 3511, 23, 'Parti'),
(88757, 3512, 23, 'Parti ID eksik'),
(88758, 3513, 23, 'Parti Numarası'),
(88759, 3514, 23, 'Düşük'),
(88760, 3516, 23, 'Alt bacak'),
(88761, 3519, 23, 'Lomber omurgalar'),
(88762, 3520, 23, 'ÖĞLE'),
(88763, 3521, 23, 'Öğle Yemeği'),
(88764, 3522, 23, 'Akciğer Kanseri'),
(88765, 3523, 23, 'Akciğer Kanseri Cerrahisi'),
(88766, 3524, 23, 'AKCİĞERLER:'),
(88767, 3525, 23, 'Akciğerler:'),
(88768, 3526, 23, 'Lupus'),
(88769, 3528, 23, 'Pt'),
(88770, 3529, 23, 'MA Kategorisi'),
(88771, 3530, 23, 'Düşüğü Kabul Eden MA Hastası'),
(88772, 3531, 23, 'MA İstatistikleri'),
(88773, 3534, 23, 'Ana'),
(88774, 3535, 23, 'Ana Adres'),
(88775, 3536, 23, 'Esas Orta Üst Ekran'),
(88776, 3540, 23, 'Güncel kategorilerde değişiklikler yap'),
(88777, 3541, 23, 'Yeni randevu oluşturulacak'),
(88778, 3542, 23, 'Emin olun:'),
(88779, 3543, 23, 'Takas Kurumuna yüklemek için toplu dosyalar oluşturuluyor ve faturalandırıldı olarak işaretlenecek'),
(88780, 3545, 23, 'Halsizlik:'),
(88781, 3548, 23, 'Erkek'),
(88782, 3549, 23, 'Erkek Kondomları'),
(88783, 3550, 23, 'Vazektomi'),
(88784, 3552, 23, 'Mamografi'),
(88785, 3553, 23, 'Yönet'),
(88786, 3556, 23, 'Tercümeleri Yönet'),
(88787, 3557, 23, 'Yönetim'),
(88788, 3558, 23, 'Zorunlu ve belirli alanlar'),
(88789, 3559, 23, 'Sadece zorunlu ve belirli alanlar, çift kontrol, arama yok'),
(88790, 3560, 23, 'Sadece zorunlu ve belirli alanlar, çift kontrol, ve ara'),
(88791, 3561, 23, 'El Kitabı'),
(88792, 3562, 23, 'El ilel Gönderme'),
(88793, 3563, 23, 'Üretici'),
(88794, 3565, 23, 'Mar'),
(88795, 3568, 23, 'Mart'),
(88796, 3569, 23, 'Medeni Hal'),
(88797, 3570, 23, 'Fatura edildi olarak İşaretle'),
(88798, 3571, 23, 'Faturalanmış olarak işaretle ama faturalamayı atla'),
(88799, 3572, 23, 'Ödenmiş olarak İşaretle'),
(88800, 3573, 23, 'Faturalanmamış olarak işaretle'),
(88801, 3574, 23, 'Bu raporları gözden geçirildi olarak işaretle'),
(88802, 3575, 23, 'Ödenilmiş olarak işaretle'),
(88803, 3576, 23, 'Evli'),
(88804, 3578, 23, 'Maske'),
(88805, 3579, 23, 'Fatura Numaraları için Maske'),
(88806, 3580, 23, 'Hasta ID leri için Maske'),
(88807, 3581, 23, 'Ürün IDleri için Maske'),
(88808, 3594, 23, 'Sağ Maksiller:'),
(88809, 3597, 23, 'Saniye olarak çıkıştan önceki maksimum boş zaman. Ön tanımlı 7200 (2 saat)'),
(88810, 3603, 23, 'Mayıs'),
(88811, 3604, 23, 'MC'),
(88812, 3605, 23, 'mcg'),
(88813, 3607, 23, 'Şifreyi değiştirir iken son üç şifrenin hiçbirisine izin verilmez demektir.'),
(88814, 3612, 23, 'Medial malleol:'),
(88815, 3613, 23, 'Medicaid'),
(88816, 3614, 23, 'Medikal'),
(88817, 3615, 23, 'Medikal Abort'),
(88818, 3617, 23, 'Tıbbi Öykü'),
(88819, 3620, 23, 'Medikal problem'),
(88820, 3623, 23, 'Medikal Problemler'),
(88821, 3624, 23, 'Tıbbi Kayıt'),
(88822, 3625, 23, 'Tıbbi Kayıt No:'),
(88823, 3626, 23, 'Tıbbi Kayıtlar'),
(88824, 3630, 23, 'Tıp Sistemi'),
(88825, 3631, 23, 'Medikal Tip'),
(88826, 3632, 23, 'Tıbbi/öykü (yaz, sadece ekle opsiyon)'),
(88827, 3633, 23, 'Medicare Bölüm B'),
(88828, 3634, 23, 'Medicare Sevkeden Vericidir'),
(88829, 3635, 23, 'İlaç'),
(88830, 3640, 23, 'İlaçlar'),
(88831, 3641, 23, 'İlaçlar:'),
(88832, 3642, 23, 'İlaç Birimleri'),
(88833, 3643, 23, 'Ortam'),
(88834, 3645, 23, 'Üye Derneği İstatistikleri Raporu'),
(88835, 3646, 23, 'Bellek Sorunları'),
(88836, 3647, 23, 'Erkekler'),
(88837, 3648, 23, 'Erkekler ve Kadınlar'),
(88838, 3649, 23, 'Yalnız Erkekler'),
(88839, 3650, 23, 'Menarş'),
(88840, 3651, 23, 'Menopoz'),
(88841, 3652, 23, 'Adet Kanaması'),
(88842, 3653, 23, 'Adet Sıklığı'),
(88843, 3654, 23, 'Akıl Hastalığı'),
(88844, 3661, 23, 'Mesaj'),
(88845, 3666, 23, 'Mesaj Durumu'),
(88846, 3670, 23, 'MESAJ:'),
(88847, 3671, 23, 'Mesajlar'),
(88848, 3673, 23, 'Yöntem'),
(88849, 3674, 23, 'Yöntem ve Özel Ürün'),
(88850, 3675, 23, 'Dışarı giden epostayı gönderme yöntemi'),
(88851, 3676, 23, 'İmha Yöntemi'),
(88852, 3677, 23, 'Meksikalı/MeksikaAmerika'),
(88853, 3679, 23, 'mg'),
(88854, 3680, 23, 'mg/1cc'),
(88855, 3681, 23, 'mg/2cc'),
(88856, 3682, 23, 'mg/3cc'),
(88857, 3683, 23, 'mg/4cc'),
(88858, 3684, 23, 'mg/5cc'),
(88859, 3685, 23, 'MG/DL'),
(88860, 3686, 23, 'Ortam'),
(88861, 3687, 23, 'Orta İsim'),
(88862, 3688, 23, 'Orta isim'),
(88863, 3695, 23, 'Mien'),
(88864, 3696, 23, 'Göçer veya mevsimlik işçi mi?'),
(88865, 3697, 23, 'Göçer/Mevsimlik'),
(88866, 3698, 23, 'Mil/mm3'),
(88867, 3702, 23, 'Mime Tipi'),
(88868, 3704, 23, 'dak'),
(88869, 3706, 23, 'Hafif eklem burkulması +/- sinovit'),
(88870, 3709, 23, 'dakika'),
(88871, 3710, 23, 'Dakika'),
(88872, 3712, 23, 'Çeşitli'),
(88873, 3713, 23, 'Çeşitli Faturalama Seçenekleri'),
(88874, 3714, 23, 'HCFA-1500 için Çeşitli Faturalama Seçenekleri'),
(88875, 3715, 23, 'Çeşitli Faturalama Seçenekleri HCFA'),
(88876, 3716, 23, 'Çeşitli'),
(88877, 3717, 23, 'Eksik'),
(88878, 3719, 23, 'Gerekli bir alan eksik'),
(88879, 3720, 23, 'Ücret Eksik'),
(88880, 3721, 23, 'Sadece Eksik Modlar'),
(88881, 3722, 23, 'Eksik veya Geçersiz'),
(88882, 3723, 23, 'Eksik PID'),
(88883, 3724, 23, 'Eksik rapor tarihi'),
(88884, 3725, 23, 'Kaynak kodda ödeyenden sonra eksik slash '),
(88885, 3726, 23, 'Karışık'),
(88886, 3727, 23, 'ml'),
(88887, 3728, 23, 'MM/DD/YYYY'),
(88888, 3729, 23, 'mm/hg'),
(88889, 3731, 23, 'MMR 1'),
(88890, 3732, 23, 'MMR 2'),
(88891, 3733, 23, 'Mobil'),
(88892, 3734, 23, 'Cep Telefonu'),
(88893, 3735, 23, 'Mod'),
(88894, 3741, 23, 'Değiştirici'),
(88895, 3745, 23, 'Ödemeleri Değiştir'),
(88896, 3746, 23, 'ModUzunluğu'),
(88897, 3753, 23, 'Pzt'),
(88898, 3754, 23, 'Pzt - Cum'),
(88899, 3755, 23, 'Pzt, Çar, Cum'),
(88900, 3756, 23, 'Pazartesi'),
(88901, 3758, 23, 'Ay'),
(88902, 3759, 23, 'ay'),
(88903, 3760, 23, 'Ay Görünümü'),
(88904, 3761, 23, 'Ay(lar)'),
(88905, 3762, 23, 'Aylık Gelir'),
(88906, 3763, 23, 'Aylar'),
(88907, 3765, 23, '100 kayıttan fazla bulundu. Lütfen arama kriterinizi daraltınız.'),
(88908, 3766, 23, '50 sonuçtan fazla var, lütfen aramanızı daha spesifik yapınız.'),
(88909, 3768, 23, 'En son alınan'),
(88910, 3770, 23, 'Son vital bulguları alan:'),
(88911, 3771, 23, 'Anne'),
(88912, 3772, 23, 'Ana Adı'),
(88913, 3774, 23, 'Ağız'),
(88914, 3775, 23, 'Taşı'),
(88915, 3776, 23, 'Belgeyi Şu Kategoriye Taşıyın:'),
(88916, 3777, 23, 'Aşağı Taşı'),
(88917, 3779, 23, 'Hastaya Taşı'),
(88918, 3780, 23, 'Taşınacak yer:'),
(88919, 3781, 23, 'Yukarı Taşı'),
(88920, 3783, 23, 'Bay'),
(88921, 3785, 23, 'Bayan'),
(88922, 3786, 23, 'Bn.'),
(88923, 3796, 23, 'Çoklu Dil Aracı'),
(88924, 3797, 23, 'Pek çok bölgeler'),
(88925, 3799, 23, 'Pek çok Kalemler'),
(88926, 3802, 23, 'Çok ırklı'),
(88927, 3803, 23, 'Üfürüm'),
(88928, 3804, 23, 'Kas Ağrısı'),
(88929, 3805, 23, 'Kas Ağrıları'),
(88930, 3806, 23, 'Kas Kızarıklığı'),
(88931, 3807, 23, 'Kas Sertliği'),
(88932, 3808, 23, 'Kas Şişmesi'),
(88933, 3809, 23, 'Kas Isı artışı'),
(88934, 3810, 23, 'Kas'),
(88935, 3811, 23, 'Kas yaralanması'),
(88936, 3812, 23, 'Kas iskelet'),
(88937, 3813, 23, 'SMTP doğrulaması kullanılmıyor ise boş olmalıdır.'),
(88938, 3814, 23, 'Karşılıklı Tanımlanmış'),
(88939, 3815, 23, 'MVA'),
(88940, 3821, 23, 'Yok'),
(88941, 3822, 23, 'yok'),
(88942, 3823, 23, 'İsim'),
(88943, 3825, 23, 'İsim (fazlası için tıklayınız)'),
(88944, 3826, 23, 'İsim 1'),
(88945, 3827, 23, 'İsim 2'),
(88946, 3828, 23, 'Aşı Yapanın İsim ve Unvanı'),
(88947, 3831, 23, 'Olayların İsmi'),
(88948, 3832, 23, 'Sigorta şirketinin ismi'),
(88949, 3833, 23, 'Sağlayıcının İsmi'),
(88950, 3835, 23, 'İsim Tercümesi'),
(88951, 3836, 23, 'İsim/Değer'),
(88952, 3837, 23, 'İsim:'),
(88953, 3838, 23, 'BURUN DELİKLERİ:'),
(88954, 3839, 23, 'BURUN DELİKLERİ: Sağ Normal'),
(88955, 3840, 23, 'Nazal mukoza pembe, septum orta hatta'),
(88956, 3844, 23, 'Tabiiyet'),
(88957, 3852, 23, 'Bulantı'),
(88958, 3854, 23, 'Gezinme'),
(88959, 3858, 23, 'Gezinme Alanı Genişliği'),
(88960, 3859, 23, 'Gezinme menüsü radyo düğmeleri çiftlerinden ibarettir.'),
(88961, 3860, 23, 'Gezinme menüsü ağaç görünümündedir.'),
(88962, 3861, 23, 'Gezinmede kayan bir menü kullanılmaktadır.'),
(88963, 3862, 23, 'NDC'),
(88964, 3864, 23, 'NDC Numarası'),
(88965, 3866, 23, 'Boyun'),
(88966, 3867, 23, 'Boyun sorunları'),
(88967, 3868, 23, 'Boyun esnek'),
(88968, 3869, 23, 'Bir tanım girilmesi gerekiyor'),
(88969, 3870, 23, 'Bir İade Değeri girilmesi gerekiyor'),
(88970, 3871, 23, 'Tanımlayıcı girilmesi gerekiyor'),
(88971, 3872, 23, 'Başlık girilmesi gerekiyor'),
(88972, 3873, 23, 'Doğrulanması gerekiyor'),
(88973, 3874, 23, 'Ayarlanması gerekiyor'),
(88974, 3875, 23, 'İkincil fatura gerekiyor'),
(88975, 3876, 23, 'Negatif'),
(88976, 3877, 23, 'Negatifler'),
(88977, 3880, 23, 'Sinir yaralanması'),
(88978, 3881, 23, 'Sinir hastalığı / sinir hasarı'),
(88979, 3882, 23, 'Sinirsel Uyuşma'),
(88980, 3883, 23, 'Sinirsel Zayıflık'),
(88981, 3884, 23, 'Nörolojik'),
(88982, 3885, 23, 'Asla'),
(88983, 3886, 23, 'Hiç Alkol Kullanmamış'),
(88984, 3887, 23, 'Hiç Sigara İçmamiş'),
(88985, 3888, 23, 'Yeni'),
(88986, 3889, 23, 'Yeni=>'),
(88987, 3890, 23, 'Yeni Alıcılar'),
(88988, 3892, 23, 'Yeni Alerji'),
(88989, 3894, 23, 'Yeni Randevu'),
(88990, 3895, 23, 'Yeni Kategoriler'),
(88991, 3896, 23, 'Yeni Kategori'),
(88992, 3897, 23, 'Yeni Müşteriler'),
(88993, 3898, 23, 'Yeni Konsültasyon'),
(88994, 3900, 23, 'Yeni Tanı dizisi eklendi'),
(88995, 3901, 23, 'Yeni Belge'),
(88996, 3904, 23, 'Yeni Görüşme'),
(88997, 3906, 23, 'Yeni Görüşme Formu'),
(88998, 3907, 23, 'Yeni görüşmelere izin verilmiyor'),
(88999, 3908, 23, 'Yeni Görüşme'),
(89000, 3909, 23, 'Yeni Tesis Bilgisi'),
(89001, 3912, 23, 'Yeni Grup'),
(89002, 3913, 23, 'Yeni Grup Bilgisi'),
(89003, 3916, 23, 'Yeni Olaylar Sınırı'),
(89004, 3917, 23, 'Yeni Liste'),
(89005, 3918, 23, 'Yeni Order lar'),
(89006, 3921, 23, 'Yeni Hasta'),
(89007, 3922, 23, 'YENİ HASTA'),
(89008, 3923, 23, 'Yeni Hasta Görüşmesi'),
(89009, 3924, 23, 'Yeni Hasta Formu'),
(89010, 3925, 23, 'Yeni Hasta ID'),
(89011, 3926, 23, 'Yeni Ödeme'),
(89012, 3928, 23, 'Yeni Hasta'),
(89013, 3929, 23, 'Lab Değişimden yeni sonuçlar'),
(89014, 3930, 23, 'Yeni Arama'),
(89015, 3931, 23, 'Yeni Başvurular'),
(89016, 3932, 23, 'Yeni Kullanıcı'),
(89017, 3934, 23, 'Yeni Vizit'),
(89018, 3935, 23, 'Yeni / Ara'),
(89019, 3961, 23, 'Gazete'),
(89020, 3962, 23, 'Sonraki'),
(89021, 3964, 23, 'Sonraki Gün'),
(89022, 3965, 23, 'Sonraki Ay'),
(89023, 3966, 23, 'Sonraki Ay (menü için basılı tutun)'),
(89024, 3968, 23, 'Sonraki Hafta'),
(89025, 3969, 23, 'Sonraki Yıl (menü için basılı tutun)'),
(89026, 3971, 23, 'Takma isim'),
(89027, 3973, 23, 'Gece Terlemeleri'),
(89028, 3974, 23, 'Dış genitaller, vaginal mukoza, serviks normal'),
(89029, 3975, 23, 'Hayır'),
(89030, 3976, 23, 'HAYIR'),
(89031, 3977, 23, 'Giriş yok'),
(89032, 3979, 23, 'Adenopati yok (2 alan gerekiyor)'),
(89033, 3980, 23, 'Düzeltme sebebi tipi bulunamadı:'),
(89034, 3981, 23, 'Adneksiyal hassasiyet/kitle yok'),
(89035, 3985, 23, 'Halen bir faturalama sistemi etkin değil'),
(89036, 3987, 23, 'OFX Dışa aktar da eklenecek hiçbir fatura bulunmadı'),
(89037, 3989, 23, 'Hiçbir kod belirtilmedi'),
(89038, 3992, 23, 'Teşhis yok'),
(89039, 3993, 23, 'Belge Bulunmadı'),
(89040, 3995, 23, 'Son Tarihi yok'),
(89041, 3996, 23, 'Hiçbir kayıt bulunmadı.Bir kayıt eklemek için aşağıdaki formu kullanın'),
(89042, 3997, 23, 'Hiçbir hata bulunamadı'),
(89043, 3998, 23, 'Olay Yok'),
(89044, 4001, 23, 'Hiçbir grup seçilmedi'),
(89045, 4002, 23, 'Fıtık yok'),
(89046, 4005, 23, 'Yaralanma / hastalık yok'),
(89047, 4006, 23, 'Hiçbir sigorta şirketi bulunamadı'),
(89048, 4007, 23, 'Konu Yok'),
(89049, 4010, 23, 'Hiçbir kalem seçilmedi'),
(89050, 4027, 23, 'Kitle,hassasiyet yok.'),
(89051, 4028, 23, 'Verilen tekrar kimlik kodu ile eşleşen bir Hasta kaydı bulunamadı'),
(89052, 4031, 23, 'Hiç bir eşleşme bulunamadı. Yeni hasta kaydı oluşturulsun mu?'),
(89053, 4033, 23, 'Hiçbir yeni sonuç bulunmadı'),
(89054, 4034, 23, 'Not yok'),
(89055, 4035, 23, 'Organomegali yok'),
(89056, 4036, 23, 'Bu dönem için hiç açık yok'),
(89057, 4037, 23, 'Başka telefon numarası listelenmedi'),
(89058, 4039, 23, 'Hiçbir Partner bulunamadı'),
(89059, 4040, 23, 'Verilen Seçim Kriterleri için hiçbir hasta kaydı bulunmadı'),
(89060, 4041, 23, 'Verilen tekrar kimlik kodu için bir Hasta kaydı bulunamadı'),
(89061, 4042, 23, 'Periferde ödem yok'),
(89062, 4043, 23, 'Hiç bir ilaç bulunamadı'),
(89063, 4044, 23, 'Hiç bir reçete bulunamadı'),
(89064, 4045, 23, 'Halen hastalık/yaralanma yok'),
(89065, 4051, 23, 'Hiç bir Sağlayıcı Bulunamadı'),
(89066, 4052, 23, 'Döküntü veya anormal lezyonlar yok'),
(89067, 4053, 23, 'Hiçbir kayıt bulunamadı.'),
(89068, 4055, 23, 'Hiçbir kayıt bulunamadı. Lütfen arama kriterlerinizi genişletiniz.'),
(89069, 4057, 23, 'Yukarıdaki arama kriterleri için hiçbir sonuç bulunmadı.'),
(89070, 4058, 23, 'Sonuç Yok'),
(89071, 4060, 23, 'Arama İçin Hiçbir Sonuç Bulunamadı'),
(89072, 4062, 23, 'Sonuç yok, lütfen tekrar deneyin'),
(89073, 4063, 23, 'Sonuç yok, lütfen tekrar deneyin'),
(89074, 4065, 23, 'Gelmedi'),
(89075, 4067, 23, 'Sinüs hassasiyeti yok'),
(89076, 4068, 23, 'Memede nodul veya deri çöküntüsü yok'),
(89077, 4071, 23, 'Testiste hassasiyet, kitle yok'),
(89078, 4072, 23, 'Kalpte ele gelen titreşim veya kaldırma yok'),
(89079, 4075, 23, 'Vizit yok'),
(89080, 4076, 23, 'Hiçbir vital bulgu kaydedilmedi'),
(89081, 4077, 23, 'İptal yok'),
(89082, 4079, 23, 'No:'),
(89083, 4080, 23, 'Noktüri'),
(89084, 4081, 23, 'Ödenmemiş'),
(89085, 4082, 23, 'Rapor edilmemiş Rapor'),
(89086, 4083, 23, 'Spesifik olmayan yaralanma'),
(89087, 4085, 23, 'İnsüline bağlı olmayan diyabet'),
(89088, 4087, 23, 'CSÜS dışı Tıbbi'),
(89089, 4088, 23, 'CSÜS dışı Tıbbi Değil'),
(89090, 4089, 23, 'Hiçbiri'),
(89091, 4090, 23, 'hiçbiri'),
(89092, 4092, 23, 'Hiçbiri belgelendirilmemiş.'),
(89093, 4093, 23, 'Yukarıdakilerin hiçbiri'),
(89094, 4094, 23, 'En üst Dağılım Satırının hiçbiri tamamen boş bırakılamaz.'),
(89095, 4095, 23, 'İnsüline bağlı olmayan diyabet'),
(89096, 4096, 23, 'Nor'),
(89097, 4097, 23, 'Normal'),
(89098, 4098, 23, 'Normal BL'),
(89099, 4099, 23, 'Normal Kalp Muayenesi:'),
(89100, 4100, 23, 'Normal Kalp Muayenesi: '),
(89101, 4101, 23, 'Normal Akciğer Muayenesi'),
(89102, 4102, 23, 'Normal Akciğer Muayenesi '),
(89103, 4103, 23, 'Normal Muayene Viziti'),
(89104, 4104, 23, 'Normal Orofarinks'),
(89105, 4105, 23, 'Normal Sağ'),
(89106, 4106, 23, 'Normal Sağ'),
(89107, 4107, 23, 'Normal Görünüş'),
(89108, 4108, 23, 'normal:'),
(89109, 4109, 23, 'Normal olarak bu işaretlenmelidir. Erişim kontrolü ile ilgili değildir.'),
(89110, 4112, 23, 'Norveççe'),
(89111, 4115, 23, 'Burun'),
(89112, 4116, 23, 'Burun kanaması'),
(89113, 4117, 23, 'bir harf veya rakam değil'),
(89114, 4119, 23, 'Tüm kodlar veya kod tipleri için tüm alanlar gerekli değil'),
(89115, 4120, 23, 'İzin verilmiyor'),
(89116, 4121, 23, 'Yöneticiler grubunun silinmesine izin verilmiyor'),
(89117, 4123, 23, 'Tüm güvenlik nesnelerinin inaktif hale getirilmesine izin verilmiyor'),
(89118, 4124, 23, 'Yöneticiler ACLden herhangi bir şeyin inaktif hale getirilmesine izin verilmiyor'),
(89119, 4125, 23, 'Yöneticiler grubundan admin kullanıcısının silinmesine izin verilmiyor'),
(89120, 4126, 23, 'Bu kullanıcının yöneticiler grubundan silinmesine izin verilmiyor'),
(89121, 4128, 23, 'Takvim modülüne erişme yetkisi yok'),
(89122, 4129, 23, 'Yetkisi yok'),
(89123, 4132, 23, 'Bu bölüm için yetkisi yok'),
(89124, 4135, 23, 'Mevcudu yok'),
(89125, 4137, 23, 'Faturalanmamış'),
(89126, 4138, 23, 'Kontrol edilmemiş'),
(89127, 4139, 23, 'Çıkışı yapılmamış'),
(89128, 4143, 23, 'Muayene edilmemiş'),
(89129, 4144, 23, 'Muayene Edilmemiş:'),
(89130, 4145, 23, 'Muayene Edilmemiş: '),
(89131, 4146, 23, 'bulunamadı'),
(89132, 4148, 23, 'bulunamadı!'),
(89133, 4149, 23, 'Latin veya esmer değil.'),
(89134, 4152, 23, 'Den beri görülmedi'),
(89135, 4156, 23, 'Belirtilmemiş'),
(89136, 4157, 23, 'Not'),
(89137, 4161, 23, 'Denetleme Kaydının yukarıda etkinleştirilmiş olması gerektiğine dikkat ediniz'),
(89138, 4162, 23, 'Not Tipi'),
(89139, 4168, 23, 'Not:Bu kod yetkili bir kullanıcı tarafından girilmedi. Açık Tıbbi Faturalama Ağına sadece yetkili kodlar girilebilir. Bu kodları yüklemek istiyorsanız, lütfen buradaki yetkili bir kullanıcıyı seçiniz.'),
(89140, 4170, 23, 'NOT: Çift isimli dosyalar yüklendiğinde dosyalar otomatik olarak yeniden adlandırılır. ( Mesela dosya.jpg dosya.1.jpg ) Dosya isimleri her kategori için değil her hasta için eşsiz kabul edilir.'),
(89141, 4171, 23, 'NOT: Çift isimli dosyalar yüklendiğinde dosyalar otomatik olarak yeniden adlandırılır. Mesela ''<i>dosya.jpg, dosya.1.jpg </i>'' olur ) Dosya isimleri her kategori için değil her hasta için eşsiz kabul edilir.'),
(89142, 4172, 23, 'Notlar'),
(89143, 4173, 23, 'Notlar - herhangi bir görüşme (yaz, sadece ekle opsiyon)'),
(89144, 4174, 23, 'Notlar - görüşmelerim (yaz, sadece ekle opsiyon)'),
(89145, 4175, 23, 'Notlar yetkilendirilmemiş'),
(89146, 4182, 23, 'Hiçbir şey seçilmemiş'),
(89147, 4184, 23, 'UYARI :: Takvim Ekleme/Değiştirme'),
(89148, 4185, 23, 'Uyarı'),
(89149, 4186, 23, 'Uyarı Eposta Adresi'),
(89150, 4188, 23, 'Uyarılar'),
(89151, 4189, 23, 'Admin Olay Ekleme/Değiştirme hakkında uyarılsın mı?'),
(89152, 4190, 23, 'Kas'),
(89153, 4191, 23, 'Kasım'),
(89154, 4192, 23, 'Şimdi postalanan alıcı:'),
(89155, 4193, 23, 'Şimdi'),
(89156, 4194, 23, 'Şimdi $stmt_count bilançoları bastırılıyor ve görüşmeler güncelleniyor.'),
(89157, 4195, 23, 'Şimdi $stmt_count bilançoları bastırılıyor ve faturalar güncelleniyor.'),
(89158, 4196, 23, 'Şimdi $stmt_count bilançoları bastırılıyor, görüşmeler güncellenmeyecek.'),
(89159, 4197, 23, 'Şimdi $stmt_count bilançoları bastırılıyor, faturalar güncellenmeyecek.'),
(89160, 4198, 23, 'NPI'),
(89161, 4200, 23, 'Sayı'),
(89162, 4204, 23, 'Yıl görünümünde sütun sayısı'),
(89163, 4211, 23, 'Müşteri sertifikasının geçerli olduğu gün sayısı'),
(89164, 4213, 23, 'Para birimi için ondalık sonrası rakam sayısı, genellikle 0 veya 2 dir.'),
(89165, 4215, 23, 'Hiç varsa kaçırılan olay veya oyunlar'),
(89166, 4216, 23, 'Eposta uyarıları göndermek için önceden saat sayısı.'),
(89167, 4218, 23, 'SMS uyarılar göndermek için önceden saat sayısı'),
(89168, 4221, 23, 'Geçmiş öykü sütunlarının sayısı'),
(89169, 4223, 23, 'Uyuşukluk'),
(89170, 4225, 23, 'Rakamsal görünüm sırası'),
(89171, 4229, 23, 'O.A.F.V'),
(89172, 4230, 23, 'O2 Sat'),
(89173, 4231, 23, 'Obezite I'),
(89174, 4232, 23, 'Obezite III'),
(89175, 4233, 23, 'Obezite III'),
(89176, 4234, 23, 'Objektif'),
(89177, 4237, 23, 'Meslek'),
(89178, 4239, 23, 'Oluş'),
(89179, 4240, 23, 'Eki'),
(89180, 4241, 23, 'Ekim'),
(89181, 4242, 23, 'OD'),
(89182, 4244, 23, 'Miktarında'),
(89183, 4245, 23, 'tablet'),
(89184, 4246, 23, 'aydan her'),
(89185, 4247, 23, 'Ofis Notları'),
(89186, 4249, 23, 'Ofis Notları'),
(89187, 4250, 23, 'Ofis Viziti'),
(89188, 4263, 23, 'Bebek'),
(89189, 4265, 23, 'merhem'),
(89190, 4267, 23, 'TAMAM'),
(89191, 4269, 23, 'tarihli GCAC konusunu link etmek için TAMAM'),
(89192, 4270, 23, 'Eski'),
(89193, 4272, 23, 'Eski Müşteriler'),
(89194, 4273, 23, 'Eski kırık non / malunion'),
(89195, 4274, 23, 'Sol menü olmaksızın eski stil görünüş.'),
(89196, 4275, 23, 'Çiftleşme kontrolü ve araması bulunmayan eski stil statik form'),
(89197, 4279, 23, 'Hasta demografik bilgilerinde işveren bilgisini İhmal et'),
(89198, 4280, 23, 'İşverenleri İhmal Et'),
(89199, 4281, 23, 'Dozajın sonradan parçası olan form, yol ve aralığı ihmal et.'),
(89200, 4282, 23, 'Demografik formdan sigorta ve bazı başka şeyleri ihmal et'),
(89201, 4283, 23, 'İlk kullanıcılar ihmal edilsin mi?'),
(89202, 4284, 23, 'Birlikte ödeme panelinden ödeme yöntemini ihmal et'),
(89203, 4285, 23, 'otomatik atamayı ihmal et'),
(89204, 4286, 23, 'üzerinde'),
(89205, 4288, 23, 'Elde'),
(89206, 4289, 23, 'Siparişte'),
(89207, 4290, 23, 'Yerinde'),
(89208, 4292, 23, 'Şifrenizi değiştirdiğiniz zaman tekrar giriş yapmanız gerekecektir.'),
(89209, 4297, 23, 'Çevrim içi destek'),
(89210, 4298, 23, 'Çevrim içi destek bağlantısı'),
(89211, 4299, 23, 'Sadece Aktif'),
(89212, 4302, 23, 'sadece eğer faturalama yeri ise'),
(89213, 4303, 23, 'Sadece inaktif'),
(89214, 4304, 23, 'Sadece Benim'),
(89215, 4310, 23, 'Hastalığın başlangıcı:'),
(89216, 4311, 23, 'Hastalığın başlangıcı: '),
(89217, 4312, 23, 'Şişmenin başlangıcı:'),
(89218, 4313, 23, 'Hastaneye yatış/başlangıç tarihi'),
(89219, 4316, 23, 'Açık'),
(89220, 4321, 23, 'Bugünkü Görüşmeyi Aç'),
(89221, 4322, 23, 'ÖzgürETK önceden düzenlenmiş bir Sertifika Yetkilisine sahip'),
(89222, 4324, 23, 'ÖzgürETK Veri Tabanı Güncellemesi'),
(89223, 4325, 23, 'Kişisel verileri gizlemek için ÖzgürETK Veri Tabanı Güncellemesi'),
(89224, 4327, 23, 'ÖzgürETKnın müşteri sertifikalarını oluşturabilmesi için sertifika kullanmak üzere yapılandırılması gerekir'),
(89225, 4328, 23, 'ÖzgürETK kullanıcı doğrulaması yapabilmek için JavaScripte ihtiyaç duyar.'),
(89226, 4329, 23, 'ÖzgürETK Kullanıcıları'),
(89227, 4333, 23, 'Seçenek'),
(89228, 4335, 23, 'Ürünlerin envanterini ve satışlarını destekleme opsiyonu'),
(89229, 4336, 23, 'Seçmeli'),
(89230, 4337, 23, 'Hasta özet sayfasında görülebilecek bir Nüfus kağıdı resmi için opsiyonel kategori ismi'),
(89231, 4338, 23, 'Hasta özet sayfasında görülebilecek fotoğraf resmleri için opsiyonel kategori ismi'),
(89232, 4339, 23, 'Hasta özet sayfasından bir belgeye bağlantı yapmak için seçmeli kategori ismi. Hasta ismine tıklayıp ID kartını görmenizi sağlar.'),
(89233, 4340, 23, 'Sonuçların el ile girilmesinde seçimlik ön tanımlı aralık'),
(89234, 4341, 23, 'Sonuçların el ile girilmesinde seçimlik ön tanımlı birimler'),
(89235, 4343, 23, 'Seçimlik ilaç adı joker için % kullanınız.'),
(89236, 4345, 23, 'Bu olay için seçimlik bilgi'),
(89237, 4346, 23, 'Seçmeli parti numarası, joker için % kullanınız'),
(89238, 4347, 23, 'Seçmeli nümerik hasta ID si'),
(89239, 4348, 23, 'Seçmeli işlem kodu'),
(89240, 4350, 23, 'Seçenekler'),
(89241, 4351, 23, 'Veya'),
(89242, 4352, 23, 'VEYA'),
(89243, 4353, 23, 'Veya seçin'),
(89244, 4354, 23, 'veya hızlı seçim için tıklayıp sürükleyin.'),
(89245, 4356, 23, 'Veya Dışarı'),
(89246, 4358, 23, 'veya azaltmak için Shift-tıkla'),
(89247, 4359, 23, 'Veya ERA dosyasını yükle'),
(89248, 4360, 23, 'Oral'),
(89249, 4361, 23, 'Oral mukoza pembe, boğaz temiz'),
(89250, 4362, 23, 'Order'),
(89251, 4363, 23, 'Order ve Sonuç Tipleri'),
(89252, 4364, 23, 'Sipariş Kataloğu'),
(89253, 4367, 23, 'Order Formu'),
(89254, 4369, 23, 'Order 1 -999 arası bir sayı olmalıdır'),
(89255, 4371, 23, 'Order Öncelikleri'),
(89256, 4372, 23, 'Order İşlemcisi'),
(89257, 4375, 23, 'Sipariş Durumları'),
(89258, 4378, 23, 'Sipariş Tipi'),
(89259, 4380, 23, 'Sipariş Sonucu/Tipi'),
(89260, 4381, 23, 'Sipariş edildi'),
(89261, 4384, 23, 'Sipariş Sağlayıcı'),
(89262, 4386, 23, 'Organ yaralanması'),
(89263, 4387, 23, 'Organizasyon'),
(89264, 4388, 23, 'Organizasyon Adı'),
(89265, 4389, 23, 'Organizasyon Birim Adı'),
(89266, 4390, 23, 'Organizasyonlar'),
(89267, 4391, 23, 'Oriyante x 3'),
(89268, 4392, 23, 'Orijinal'),
(89269, 4396, 23, 'OROFARENKS: '),
(89270, 4397, 23, 'Ortopne'),
(89271, 4398, 23, 'OS'),
(89272, 4399, 23, 'Osteoartrit'),
(89273, 4402, 23, 'Diğer'),
(89274, 4403, 23, 'diğer'),
(89275, 4404, 23, 'Diğer (Belirtiniz)'),
(89276, 4405, 23, 'Diğer - Belirtilmiş'),
(89277, 4406, 23, 'Diğer Federal Program'),
(89278, 4407, 23, 'Diğer HCFA'),
(89279, 4408, 23, 'Başka yerde belirtilmemiş diğer yaralanmalar'),
(89280, 4410, 23, 'diğer ay'),
(89281, 4411, 23, 'Diğer Federal Olmayan Programlar'),
(89282, 4412, 23, 'Diğer Notlar'),
(89283, 4413, 23, 'Diğer İlgili Semptomlar'),
(89284, 4414, 23, 'Diğer İlgili Semptomlar:'),
(89285, 4415, 23, 'Diğer ilgili resp.'),
(89286, 4416, 23, 'Diğer stres/aşırı kullanım yaralanması'),
(89287, 4417, 23, 'Diğer Cerrahi'),
(89288, 4418, 23, 'Diğer/Jenerik Düşük ile ilgili'),
(89289, 4420, 23, 'Diğerleri'),
(89290, 4421, 23, 'diğer halde mevcut verilere yapılan referansları imha edeceksiniz.'),
(89291, 4422, 23, 'Ottawa Ayak Bileği Kuralları'),
(89292, 4423, 23, 'OU'),
(89293, 4424, 23, 'DIŞARI'),
(89294, 4425, 23, 'Ofis Dışında'),
(89295, 4426, 23, 'Dışa Sevk'),
(89296, 4427, 23, 'Sonuç'),
(89297, 4428, 23, 'Görünüm'),
(89298, 4432, 23, 'Aşırı kullanım'),
(89299, 4434, 23, 'Aşırı kilolu'),
(89300, 4435, 23, 'HIPAA seçiminin üzerine yaz'),
(89301, 4437, 23, 'Oksijen Satürasyonu'),
(89302, 4439, 23, 'P'),
(89303, 4440, 23, 'Yemekten sonra'),
(89304, 4441, 23, 'ö.s.'),
(89305, 4442, 23, 'gerektiğinde'),
(89306, 4443, 23, 'Pasifik Adalarından'),
(89307, 4444, 23, 'Pediyatrik'),
(89308, 4445, 23, 'Sayfa'),
(89309, 4446, 23, 'Sayfalar'),
(89310, 4447, 23, 'Ödenmiş'),
(89311, 4448, 23, 'Ayıracağınız ödenmiş miktar'),
(89312, 4450, 23, 'Ödendi:'),
(89313, 4451, 23, 'Ağrı'),
(89314, 4453, 23, 'Çarpıntı'),
(89315, 4455, 23, 'Sürüntü'),
(89316, 4458, 23, 'Felç'),
(89317, 4461, 23, 'HL7 yi incele'),
(89318, 4463, 23, 'Partner'),
(89319, 4472, 23, 'Şifre'),
(89320, 4473, 23, 'Şifre Değişikliği'),
(89321, 4475, 23, 'Şifre Değişikliği Başarılı.'),
(89322, 4477, 23, 'Şifre Son Mühlet'),
(89323, 4480, 23, 'SMS ara birimi için Şifre'),
(89324, 4481, 23, 'SMS ara birimi için Şifre:'),
(89325, 4486, 23, 'Şifre:'),
(89326, 4494, 23, 'Eski Görüşmeler Listesi'),
(89327, 4495, 23, 'Geçmiş Görüşmeler'),
(89328, 4496, 23, 'Geçmiş Görüşmeler ve Belgeler'),
(89329, 4498, 23, 'HL7 Verisini Yapıştırınız'),
(89330, 4499, 23, 'İçe aktarılacak veriyi aşağıdaki metin kutusuna yapıştırınız:'),
(89331, 4502, 23, 'Yama'),
(89332, 4508, 23, 'Olay Günlüğü Yedeğinin Yolu'),
(89333, 4509, 23, 'CA Sertifika Dosyasının Yolu'),
(89334, 4510, 23, 'CA Sertifikası Anahtar Dosyasının Yolu'),
(89335, 4511, 23, 'MySQL binary dosyalarının yolu'),
(89336, 4512, 23, 'Perl Binary dosyalarının yolu'),
(89337, 4513, 23, 'Geçici Dosyaların Yolu'),
(89338, 4514, 23, 'Hasta'),
(89339, 4515, 23, 'hasta'),
(89340, 4516, 23, 'HASTA'),
(89341, 4521, 23, 'Hasta alerjileri'),
(89342, 4522, 23, 'Hasta Alerjileri'),
(89343, 4523, 23, 'Hasta Randevusu'),
(89344, 4528, 23, 'Hasta Çizelge ID'),
(89345, 4529, 23, 'Hasta Ödemesi'),
(89346, 4530, 23, 'Hasta ödemesi: '),
(89347, 4533, 23, 'Hasta Epikrizi Gönderildi'),
(89348, 4534, 23, 'Hasta Epikrizi Gönderildi'),
(89349, 4539, 23, 'Hasta Bilgileri'),
(89350, 4544, 23, 'Hasta Belgesi'),
(89351, 4547, 23, 'Hasta Görüşmesi'),
(89352, 4548, 23, 'Hasta Görüşme Formu'),
(89353, 4549, 23, 'Hasta Görüşmeleri'),
(89354, 4550, 23, 'Hasta Bulucu'),
(89355, 4561, 23, 'Hasta Öyküsü'),
(89356, 4562, 23, 'Hasta Öyküsü/yaşam tarzı'),
(89357, 4564, 23, 'Hasta ID'),
(89358, 4566, 23, 'Hasta Kimlik Kartı'),
(89359, 4567, 23, 'Hasta ID Kategori İsmi'),
(89360, 4568, 23, 'Hasta Aşılamaları'),
(89361, 4569, 23, 'Hasta Danışma'),
(89362, 4570, 23, 'Hasta Talimatları'),
(89363, 4571, 23, 'Hasta Sigorta Dağılımı'),
(89364, 4572, 23, 'Hasta Sigorta Dağılımı Raporu'),
(89365, 4573, 23, 'Hasta Konuları'),
(89366, 4581, 23, 'Hasta Listesi'),
(89367, 4586, 23, 'Hasta Arama Hataları'),
(89368, 4587, 23, 'Hasta Tıbbi Sorunları'),
(89369, 4588, 23, 'Hasta İlaçları'),
(89370, 4589, 23, 'Hasta İsmi'),
(89371, 4590, 23, 'Asta İsmi & Adres'),
(89372, 4595, 23, 'Hasta Notu'),
(89373, 4596, 23, 'Hasta Not Tipleri'),
(89374, 4597, 23, 'Hasta Notları'),
(89375, 4598, 23, 'Hasta Notları (Yaz sadece ekle seçmeli)'),
(89376, 4599, 23, 'Hasta Numarası'),
(89377, 4600, 23, 'Hasta Ödemesi'),
(89378, 4602, 23, 'Hasta Fotoğraf kategorisi ismi'),
(89379, 4608, 23, 'Basılı Hasta Raporu'),
(89380, 4609, 23, 'Hasta Kaydı Raporu'),
(89381, 4619, 23, 'Hasta Hatırlatmaları'),
(89382, 4620, 23, 'Hasta Raporu'),
(89383, 4621, 23, 'Hasta İsteği'),
(89384, 4623, 23, 'Hasta Sonuçları'),
(89385, 4624, 23, 'Hasta Sonuç Arama Stili'),
(89386, 4625, 23, 'Hasta Ara/Ekle Ekranı'),
(89387, 4629, 23, 'Hasta Özeti'),
(89388, 4630, 23, 'Hasta İşlemleri'),
(89389, 4632, 23, 'girdiğiniz demografik bilgi ile eşleşen veri tabanındaki hasta(lar)'),
(89390, 4633, 23, 'Hasta/Müşteri'),
(89391, 4634, 23, 'Hasta:'),
(89392, 4635, 23, 'HastaID'),
(89393, 4636, 23, 'Hastalar'),
(89394, 4638, 23, 'Öde'),
(89395, 4639, 23, '"işim bitti" kutularına dikkat ediniz. Sigortalar tamam olarak işaretlendikten sonra borcun geri kalanını hastalardan istemeye başlayacağız. Eğer tüm sigortaları tamam olarak işaretlemez iseniz o zaman kalan miktar toplanamaz! Hastanın ödemesi gereken bir borç var ise, vade tarihini uygun şekilde düzenleyiniz, bu hastalara giden ödeme emirlerindeki dili etkiler.'),
(89396, 4640, 23, 'Ödeme Tarihi:'),
(89397, 4641, 23, 'Ödeme Durumu'),
(89398, 4642, 23, 'Ödenenin Adı'),
(89399, 4643, 23, 'Ödeyen'),
(89400, 4644, 23, 'Ödeyen Tipi'),
(89401, 4645, 23, 'Ödeme yapan'),
(89402, 4646, 23, 'Ödeme Başlığı'),
(89403, 4647, 23, 'Ödeme'),
(89404, 4648, 23, 'ödeme'),
(89405, 4649, 23, 'Ödeme Düzeltme Kodu'),
(89406, 4651, 23, 'Ödeme Miktarı'),
(89407, 4652, 23, 'Ödeme Miktarı sayısal olmalı'),
(89408, 4653, 23, 'Ödeme kategorisi'),
(89409, 4654, 23, 'Ödeme Tarihi'),
(89410, 4655, 23, 'ödemenin girildiği tarih'),
(89411, 4656, 23, 'Ödeyen'),
(89412, 4658, 23, 'Ödeme İzh'),
(89413, 4659, 23, 'Ödeme Listesi'),
(89414, 4660, 23, 'Ödeme Yöntemi'),
(89415, 4661, 23, 'Ödemeleri Sırala:'),
(89416, 4662, 23, 'Ödeme Durumu'),
(89417, 4663, 23, 'Ödeme Tipi'),
(89418, 4664, 23, 'Kod için ödeme değeri '),
(89419, 4665, 23, 'Ödemeler'),
(89420, 4669, 23, 'PDF'),
(89421, 4670, 23, 'Seçili Bilançoları PDF olarak İndir'),
(89422, 4672, 23, 'Pelvis ve kalça'),
(89423, 4673, 23, 'Pemfigus'),
(89424, 4674, 23, 'Beklemede'),
(89425, 4676, 23, 'F/U Askıda'),
(89426, 4677, 23, 'İzlem beklemede'),
(89427, 4678, 23, 'Sonuçlardan İzlem Beklemede'),
(89428, 4679, 23, 'Bekleyen Siparişler'),
(89429, 4680, 23, 'Bekleyen Res'),
(89430, 4681, 23, 'Bekleyen Değerlendirme'),
(89431, 4684, 23, 'Pennington Firması ÖzgürETK v'),
(89432, 4685, 23, 'Peptik Ülser Hastalığı'),
(89433, 4687, 23, 'dakikada'),
(89434, 4688, 23, 'Burundan'),
(89435, 4689, 23, 'burundan'),
(89436, 4690, 23, 'Ağızdan'),
(89437, 4691, 23, 'ağızdan'),
(89438, 4692, 23, 'Makattan'),
(89439, 4693, 23, 'makattan'),
(89440, 4694, 23, 'Yüzde'),
(89441, 4697, 23, 'persentil'),
(89442, 4698, 23, 'Sağda perfore'),
(89443, 4699, 23, 'Aramayı Başlat'),
(89444, 4700, 23, 'Bu eylemi uygula'),
(89445, 4703, 23, 'Anlaşmalı Laboratuvar Tesisi'),
(89446, 4705, 23, 'Dönem'),
(89447, 4706, 23, 'Bir kullanıcının miadı dolmuş bir şifre ile giriş yapabileceği gün olarak dönem.'),
(89448, 4708, 23, 'Çevresel'),
(89449, 4712, 23, 'Kişi'),
(89450, 4714, 23, 'PG'),
(89451, 4715, 23, 'Ecza'),
(89452, 4717, 23, 'Eczaneler'),
(89453, 4718, 23, 'Eczane'),
(89454, 4719, 23, 'Eczane Dispanseri'),
(89455, 4720, 23, 'Pnömotoraks'),
(89456, 4729, 23, 'Telefon'),
(89457, 4730, 23, 'Telefon Rehberi'),
(89458, 4738, 23, 'Telefon Numarası'),
(89459, 4740, 23, 'Fotofobi'),
(89460, 4741, 23, 'Fotoğraflar'),
(89461, 4742, 23, 'Sıkıştırılmış PHP'),
(89462, 4744, 23, 'Ayıklanmış PHP'),
(89463, 4745, 23, 'php-GACL erişim kontrolleri kapatıldı'),
(89464, 4746, 23, 'php-GACL kurulu değil'),
(89465, 4747, 23, 'Fizik Muayene'),
(89466, 4749, 23, 'Doktor İstemi'),
(89467, 4750, 23, 'Doktor İmzası'),
(89468, 4752, 23, 'Doktorlar'),
(89469, 4753, 23, 'Seçiniz'),
(89470, 4755, 23, 'bir CSS teması seçiniz'),
(89471, 4756, 23, 'PID'),
(89472, 4757, 23, 'PID ( Pelvik Enflamatuvar Hastalık)'),
(89473, 4758, 23, 'Hap Büyüklüğü'),
(89474, 4759, 23, 'Haplar'),
(89475, 4765, 23, 'Yer tutucu'),
(89476, 4766, 23, 'Yer tutucu (Boş ACL leri sürdürür)'),
(89477, 4767, 23, 'Düz Metin'),
(89478, 4768, 23, 'Plan'),
(89479, 4771, 23, 'Plan İsmi'),
(89480, 4779, 23, 'Plan:'),
(89481, 4784, 23, 'Oyuncu'),
(89482, 4785, 23, 'Oyun Pozisyonu'),
(89483, 4786, 23, 'Yukarıdaki bilgilerin bir kısmı dahi yanlış ise lütfen arayın.'),
(89484, 4787, 23, 'Lütfen şifrenizi değiştiriniz.'),
(89485, 4788, 23, 'Lütfen bir dosya Seçiniz.'),
(89486, 4789, 23, 'Lütfen bir hasta seçiniz'),
(89487, 4790, 23, 'Lütfen listeden geçerli bir bölüm seçiniz'),
(89488, 4791, 23, 'Lütfen geçerli bir bölüm seçiniz'),
(89489, 4792, 23, 'Lütfen bir değer seçiniz:'),
(89490, 4793, 23, 'Lütfen yukarıdaki vade süresi kriterlerini seçiniz ve sonuçları görmek için tazeleyi tıklayınız'),
(89491, 4794, 23, 'Lütfen Uygun Formatlı EDI-271 dosyasını seçiniz'),
(89492, 4795, 23, 'Lütfen kimliği gizlenmiş verileri indirmek için indir düğmesini tıklayınız'),
(89493, 4796, 23, 'Lütfen yeniden kimliklendirilmiş verileri indirmek için indir düğmesini tıklayınız'),
(89494, 4797, 23, 'Lütfen bu pencereyi kapatınız.'),
(89495, 4798, 23, 'Lütfen yeni ismi karşılaştırınız'),
(89496, 4802, 23, 'Lütfen eğer faks ile gelmemiş ise bu reçeteyi kabul etmeyiniz.'),
(89497, 4803, 23, 'Lütfen eğer faks ile gelmemiş ise bu reçeteyi kabul etmeyiniz.'),
(89498, 4804, 23, '10 dakikadan daha fazla geçmemiş ise lütfen tarayıcınızın dur veya yeniden yükle düğmesini kullanMAYINIZ, bu sunucuda işlemin durmasına yol açmaz ve gereksiz kaynak tüketir.'),
(89499, 4809, 23, 'Lütfen Son Gözden Geçirildi için bir tarih giriniz.'),
(89500, 4813, 23, 'Lütfen sadece rakamlar ve bir ondalık noktası ile parasal bir miktar giriniz.'),
(89501, 4815, 23, 'Lütfen bir başlık giriniz!'),
(89502, 4819, 23, 'Lütfen doğru Yeniden Kimliklendirme kodu giriniz'),
(89503, 4821, 23, 'Lütfen yeni arama dizisi giriniz');
INSERT INTO `lang_definitions` VALUES
(89504, 4822, 23, 'Lütfen doğru Yeniden Kimliklendirme kodu giriniz'),
(89505, 4823, 23, 'Lütfen şifreyi giriniz'),
(89506, 4824, 23, 'Lütfen Çek Numarasını Doldurunuz'),
(89507, 4826, 23, 'Lütfen Tarihi Doldurunuz'),
(89508, 4827, 23, 'Lütfen Ödeme Miktarını Doldurunuz'),
(89509, 4828, 23, 'Lütfen Ödeme Kategorisini Doldurunuz'),
(89510, 4829, 23, 'Lütfen Ödemeyi Yapanı Doldurunuz'),
(89511, 4830, 23, 'Lütfen Tarihe Kadar Gönderi Doldurunuz.'),
(89512, 4831, 23, 'Lütfen devam etmeden önce onları doldurunuz.'),
(89513, 4834, 23, 'Lütfen yukarıya arama kriterlerini giriniz, ve sonuçları görmek için Gönder i tıklayınız'),
(89514, 4837, 23, 'Lütfen bunun birkaç dakikaya kadar uzun bir süre alabileceğini göz önüne alınız, bu süre boyunca tarayıcınız çok aktif görünmeyebilir, fakat bir faturanın oluşturulması karmaşık bir işlemdir ve tarayıcınız sadece daha fazla veri beklemektedir.'),
(89515, 4838, 23, 'Lütfen Dikkat: Sabitler büyük ve küçük harfe duyarlıdır herhangi bir dizi olabilir'),
(89516, 4839, 23, 'Lütfen sadece alfabedeki karakterleri kullanınız'),
(89517, 4840, 23, 'Lütfen sadece alfabedeki karakterleri boşluk bırakmadan kullanınız'),
(89518, 4841, 23, 'Lütfen bu miktarı ödeyiniz'),
(89519, 4843, 23, 'Lütfen bakın:'),
(89520, 4844, 23, 'Lütfen şifreyi sıfırlayınız.'),
(89521, 4845, 23, 'Kimliksizleştirmeyi çalıştırmadan önce lütfen apache sunucusunu tekrar çalıştırınız'),
(89522, 4849, 23, 'Lütfen bir dil seçiniz'),
(89523, 4850, 23, 'Lütfen bir Hasta Seçiniz'),
(89524, 4858, 23, 'Lütfen kod için bir düzeltme sebebi seçiniz '),
(89525, 4859, 23, 'Lütfen bir olay seçiniz'),
(89526, 4860, 23, 'Lütfen herhangi bir Arama Opsiyonu seçiniz'),
(89527, 4863, 23, 'Lütfen en az bir reçete seçiniz!'),
(89528, 4865, 23, 'Lütfen kopyalamak veya iletilmek istenen sayfaları seçiniz'),
(89529, 4866, 23, 'Lütfen Ödeme Yöntemini Seçiniz'),
(89530, 4869, 23, 'Lütfen 270 yığın dosyası oluşturmak için gerekli X12 partnerini seçiniz'),
(89531, 4870, 23, 'Lütfen ayarlayınız'),
(89532, 4871, 23, 'Lütfen de_identification_config değişkenini tekrar 0 a ayarlayınız'),
(89533, 4873, 23, 'Lütfen yeni kimlik gizleme işlemi başlatınız'),
(89534, 4874, 23, 'Lütfen LibreEHR Veri tabanını kimlik gizleme işlemleri, fonksiyonları, tablolarını içerecek şekilde güncelleyiniz'),
(89535, 4875, 23, 'Lütfen daha fazla ayrıntı için kimlik gizleme günlük hata kaydına bakınız'),
(89536, 4876, 23, 'Bir süre sonra lütfen kimlik gizleme ekranını ziyaret ediniz'),
(89537, 4877, 23, 'Bir süre sonra lütfen kimlik gösterme ekranını ziyaret ediniz'),
(89538, 4878, 23, 'Bir süre sonra lütfen ekranı ziyaret ediniz'),
(89539, 4882, 23, 'ÖS'),
(89540, 4884, 23, 'Pmt Yöntemi'),
(89541, 4885, 23, 'PND'),
(89542, 4886, 23, 'Pnömokokal Konjugat 1'),
(89543, 4887, 23, 'Pnömokokal Konjugat 2'),
(89544, 4888, 23, 'Pnömokokal Konjugat 3'),
(89545, 4889, 23, 'Pnömokokal Konjugat 4'),
(89546, 4891, 23, 'Pnömoni Aşısı'),
(89547, 4896, 23, 'Hizmet Noktası (POS)'),
(89548, 4897, 23, 'Politika'),
(89549, 4898, 23, 'Poliçe No'),
(89550, 4899, 23, 'Poliçe Numarası'),
(89551, 4900, 23, 'Lehçe'),
(89552, 4901, 23, 'Polidipsi'),
(89553, 4902, 23, 'Polipler'),
(89554, 4903, 23, 'Poliüri'),
(89555, 4904, 23, 'İştahsızlık'),
(89556, 4905, 23, 'Dolaşım bozukluğu'),
(89557, 4906, 23, 'İşitme bozukluğu'),
(89558, 4908, 23, 'Yıl görünüşü olaylarla doldurulsun mu?'),
(89559, 4909, 23, 'Açılır'),
(89560, 4917, 23, 'Portekizce'),
(89561, 4918, 23, 'Portekizce (Brezilya)'),
(89562, 4919, 23, 'Portekizce (Avrupa)'),
(89563, 4920, 23, 'POS Kodu'),
(89564, 4922, 23, 'Pozitif'),
(89565, 4923, 23, 'Pozitifler'),
(89566, 4925, 23, 'Gönderilecek:'),
(89567, 4926, 23, 'Geniz Akıntısı'),
(89568, 4927, 23, 'Ödemeleri Gönder'),
(89569, 4928, 23, 'Ameliyat sonrası'),
(89570, 4929, 23, 'Muhasebeye gönder ve faturalandırılmış olarak işaretle'),
(89571, 4930, 23, 'Tarihe kadar gönder'),
(89572, 4931, 23, 'Tarihe kadar gönder bugünden büyük olamaz'),
(89573, 4932, 23, 'Tarihe kadar gönder Mali Kapanış tarihinden sonra olmalı'),
(89574, 4933, 23, 'Düşük Sonrası Bakım'),
(89575, 4934, 23, 'Düşük Sonrası Kontrasepsiyon'),
(89576, 4935, 23, 'Düşük Sonrası Danışma'),
(89577, 4936, 23, 'Düşük Sonrası İzlem'),
(89578, 4937, 23, 'Posta'),
(89579, 4938, 23, 'Posta Kodu'),
(89580, 4939, 23, 'Posta kodu'),
(89581, 4941, 23, 'Takvim Modülü'),
(89582, 4942, 23, 'Takvim Modülü Yönetimi'),
(89583, 4943, 23, 'Takvim Modülü Kategori Ayarları'),
(89584, 4944, 23, 'Takvim modülü global ayarları'),
(89585, 4945, 23, 'Tarihinde gönderildi'),
(89586, 4946, 23, 'Gönderilme Tarihi'),
(89587, 4949, 23, 'PPE + Önceki Medikal/Cerrahi Öykü'),
(89588, 4953, 23, 'Uygulama'),
(89589, 4955, 23, 'Uygulama Koşulları'),
(89590, 4956, 23, 'Uygulayıcı'),
(89591, 4959, 23, 'Ön Ödeme'),
(89592, 4960, 23, 'Düşük-Öncesi Konsültasyon'),
(89593, 4961, 23, 'Düşük Öncesi Danışma'),
(89594, 4962, 23, 'Seç Kat'),
(89595, 4964, 23, 'Tercihler'),
(89596, 4965, 23, 'Seçilen Olay Kategorisi'),
(89597, 4966, 23, 'Seçilen Dil'),
(89598, 4967, 23, 'Seçilen Eczane'),
(89599, 4968, 23, 'Seçilen Sağlayıcı Örgüt'),
(89600, 4969, 23, 'Gebelik Testi'),
(89601, 4970, 23, 'İlk'),
(89602, 4972, 23, 'Ön Ödeme'),
(89603, 4973, 23, 'Reçete'),
(89604, 4974, 23, 'reçete limitine ulaştı:'),
(89605, 4977, 23, 'Reçete Etiketi'),
(89606, 4978, 23, 'Reçete Raporu'),
(89607, 4979, 23, 'Reçeteler'),
(89608, 4980, 23, 'Reçeteler ve Dağıtımlar'),
(89609, 4981, 23, 'Reçeteler ve diğer sevkler'),
(89610, 4982, 23, 'Reçeteler ve/veya uzmanın sevkleri'),
(89611, 4983, 23, 'Reçeteler Raporu'),
(89612, 4984, 23, 'Reçeteler/Sevkler'),
(89613, 4985, 23, 'Mevcut'),
(89614, 4986, 23, 'Başvuru Yakınması'),
(89615, 4988, 23, 'İlerlemek için Devam ı Tıklayınız.'),
(89616, 4989, 23, 'Tahmini Tanı'),
(89617, 4990, 23, 'Uzmanın Tahmini Tanısı'),
(89618, 4991, 23, 'Önceki'),
(89619, 4992, 23, 'Önceki Tıb/Cer Öyk'),
(89620, 4993, 23, 'Önc. ay (menü için basılı tutun)'),
(89621, 4994, 23, 'Önc. yıl (menü için basılı tutun)'),
(89622, 4998, 23, 'Olay Ön İzleme'),
(89623, 5001, 23, 'Önceki'),
(89624, 5002, 23, 'Önceki Konsültasyonlar'),
(89625, 5003, 23, 'Önceki Gün'),
(89626, 5004, 23, 'Önceki Öykü/Tarama'),
(89627, 5005, 23, 'Önceki Ay'),
(89628, 5006, 23, 'Önceki Hafta'),
(89629, 5007, 23, 'Fiyat'),
(89630, 5008, 23, 'Fiyatta İskonto'),
(89631, 5009, 23, 'Fiyat Seviyesi'),
(89632, 5010, 23, 'Fiyat Seviyesi:'),
(89633, 5011, 23, 'Fiyatlar'),
(89634, 5012, 23, 'Birinci'),
(89635, 5022, 23, 'Birinci Sig'),
(89636, 5023, 23, 'Birinci Sigorta'),
(89637, 5024, 23, 'Birinci Sigorta Verileri'),
(89638, 5025, 23, 'Birinci Sigorta Sağlayıcısı'),
(89639, 5026, 23, 'Birinci Sağlayıcı'),
(89640, 5027, 23, 'Yazdır'),
(89641, 5028, 23, 'Yazdır (HTML)'),
(89642, 5029, 23, 'Yazdır (PDF)'),
(89643, 5031, 23, 'Yazdır Herhangi bir Görüşme'),
(89644, 5032, 23, 'Boş Sevk Formu Yazdır'),
(89645, 5033, 23, 'Yazdır Komutu'),
(89646, 5039, 23, 'Yazdır Formatı'),
(89647, 5040, 23, 'Dört Panelli Yazdır'),
(89648, 5042, 23, 'Yazdır Mesajı'),
(89649, 5043, 23, 'Çoklu Yazdır'),
(89650, 5044, 23, 'Faksa Çoklu Yazdır'),
(89651, 5045, 23, 'İsim İmza ve Tarih yazdır.'),
(89652, 5046, 23, 'Yazdırma Notları'),
(89653, 5047, 23, 'Sayfa 1 Yazdır'),
(89654, 5048, 23, 'Sayfa 2 Yazdır'),
(89655, 5052, 23, 'Yazdırma Kaydı'),
(89656, 5053, 23, 'Seçili Bilançoları Yazdır'),
(89657, 5054, 23, 'Aşı Kayıt Tutanağını Yazdır'),
(89658, 5056, 23, 'Bu Görüşmeyi Yazdır'),
(89659, 5057, 23, 'Bu notu yazdır'),
(89660, 5058, 23, 'Bu Notu Yazdır'),
(89661, 5060, 23, 'Faksa Yazdır'),
(89662, 5061, 23, 'Yazdırma Görünüşü'),
(89663, 5062, 23, 'yazdırılabilir'),
(89664, 5063, 23, 'Yazdırılabilir Sürüm'),
(89665, 5064, 23, 'Yazılmış'),
(89666, 5066, 23, 'Yazdırma sonuçları:'),
(89667, 5067, 23, 'Yazdırma atlandı; test çıktısı'),
(89668, 5068, 23, 'Yazdırma atlandı; test çıktısı: '),
(89669, 5069, 23, 'Önc Yetk'),
(89670, 5070, 23, 'Önce Yetkilendirme Formu'),
(89671, 5072, 23, 'Öncelik'),
(89672, 5073, 23, 'Öncelik '),
(89673, 5074, 23, 'Özel'),
(89674, 5075, 23, 'Sorun'),
(89675, 5076, 23, 'Problem Tanısı'),
(89676, 5077, 23, 'Sorun Listesi'),
(89677, 5079, 23, 'Sorunlar/Konular'),
(89678, 5080, 23, 'İşl Yğn'),
(89679, 5081, 23, 'İşl Kat'),
(89680, 5083, 23, 'Bekleyen İşl Gör'),
(89681, 5085, 23, 'İşl Arş'),
(89682, 5086, 23, 'İşlem'),
(89683, 5087, 23, 'İşlem Gövde Siteleri'),
(89684, 5088, 23, 'İşlem Mantık Sonuçları'),
(89685, 5089, 23, 'İşlem Kodu'),
(89686, 5091, 23, 'İşlem Lateralizasyonları'),
(89687, 5093, 23, 'İşlem Sırası'),
(89688, 5095, 23, 'İşlem Sırası Yapılacak'),
(89689, 5102, 23, 'İşlem Raporu'),
(89690, 5103, 23, 'İşlem Rapor Durumları'),
(89691, 5104, 23, 'İşlem Sonucu Anormal'),
(89692, 5105, 23, 'İşlem Sonuç Durumları'),
(89693, 5106, 23, 'İşlem Sonuçları'),
(89694, 5107, 23, 'İşlem Yolları'),
(89695, 5108, 23, 'İşlem Numune Tipleri'),
(89696, 5109, 23, 'İşlem İstatistik Raporu'),
(89697, 5110, 23, 'İşlem Tipi'),
(89698, 5111, 23, 'İşlem Tipleri'),
(89699, 5112, 23, 'İşlem Birimleri'),
(89700, 5114, 23, 'İşlemler'),
(89701, 5115, 23, 'İşlem'),
(89702, 5117, 23, 'İşlem ERA Dosyası'),
(89703, 5125, 23, 'İşleniyor'),
(89704, 5129, 23, 'Ürün'),
(89705, 5130, 23, 'Ürün Doğum Kontrol Yöntemi'),
(89706, 5132, 23, 'Ürünler'),
(89707, 5133, 23, 'Şablonlar ve reçeteli ilaçlar dışında Ürünler'),
(89708, 5134, 23, 'Prof.'),
(89709, 5135, 23, 'Progres Notları'),
(89710, 5136, 23, 'Prostat Kanseri'),
(89711, 5138, 23, 'Prostat Muayenesi'),
(89712, 5139, 23, 'Prostat Sorunları'),
(89713, 5140, 23, 'Prostatta büyüme, nodul, hassasiyet yok.'),
(89714, 5142, 23, 'Tam yolu yazınız'),
(89715, 5143, 23, 'Dosyanın tam yolunu yazınız'),
(89716, 5149, 23, 'Geçerli Eposta adresi yazınız'),
(89717, 5152, 23, 'Sağlayıcı'),
(89718, 5156, 23, 'Sağlayıcı eşleşme hataları'),
(89719, 5159, 23, 'Sağlayıcı Numarası'),
(89720, 5162, 23, 'Sağlayıcı:'),
(89721, 5163, 23, 'Sağlayıcılar:'),
(89722, 5164, 23, 'Sağlayıcılar NPI'),
(89723, 5165, 23, 'Sağlayıcılar Tüm Takvimi Görür'),
(89724, 5166, 23, 'Önc'),
(89725, 5167, 23, 'PSA'),
(89726, 5168, 23, 'Psoriasis'),
(89727, 5169, 23, 'Psik. Tanı'),
(89728, 5170, 23, 'Psik İlaç'),
(89729, 5171, 23, 'Psikiyatrik'),
(89730, 5172, 23, 'Psikiyatrik Özet Mektup'),
(89731, 5173, 23, 'Psikiyatrik Tanı'),
(89732, 5174, 23, 'Psikiyatrik Muayene'),
(89733, 5175, 23, 'Psikiyatrik Öykü'),
(89734, 5176, 23, 'Psikiyatrik Kullanımı'),
(89735, 5177, 23, 'Psikiyatrik İlaç'),
(89736, 5178, 23, '% Hs'),
(89737, 5179, 23, 'Hs Notları'),
(89738, 5180, 23, 'Hs Notları/Ytk'),
(89739, 5181, 23, 'Hs fazla ödedi'),
(89740, 5182, 23, 'Hs Ödedi'),
(89741, 5184, 23, 'Hs geri ödeme'),
(89742, 5185, 23, 'Hs bırakıldı'),
(89743, 5186, 23, 'Hs Raporu'),
(89744, 5187, 23, 'HS ÖĞRENCİ veya boş bıralın'),
(89745, 5188, 23, 'PT_CITY'),
(89746, 5189, 23, 'PT_DOB'),
(89747, 5191, 23, 'PT_FNAME'),
(89748, 5192, 23, 'PT_LNAME'),
(89749, 5193, 23, 'PT_MNAME'),
(89750, 5196, 23, 'PT_POSTAL'),
(89751, 5198, 23, 'PT_STATE'),
(89752, 5199, 23, 'PT_STREET'),
(89753, 5201, 23, 'Kamu'),
(89754, 5204, 23, 'Porto Rikolu'),
(89755, 5205, 23, 'Akciğer'),
(89756, 5206, 23, 'Nabız'),
(89757, 5207, 23, 'Pencaplı'),
(89758, 5208, 23, 'Satın Alma'),
(89759, 5209, 23, 'Satın alma/iade'),
(89760, 5210, 23, 'Satın Almalar'),
(89761, 5213, 23, 'her 3 saatte bir'),
(89762, 5214, 23, 'her 4 saatte bir'),
(89763, 5215, 23, 'her 5 saatte bir'),
(89764, 5216, 23, 'her 6 saatte bir'),
(89765, 5217, 23, 'her 8 saatte bir'),
(89766, 5218, 23, 'her gün'),
(89767, 5219, 23, 'günde 4 kez'),
(89768, 5220, 23, 'Eldeki Mevcut Miktar'),
(89769, 5221, 23, 'Eldeki Mevcut Miktar bir aylık kullanılandan az'),
(89770, 5222, 23, 'Miktar'),
(89771, 5223, 23, 'MİKTAR'),
(89772, 5224, 23, 'Kalite'),
(89773, 5226, 23, 'Miktar'),
(89774, 5227, 23, 'NDC için Miktar'),
(89775, 5228, 23, 'Eldeki Miktar'),
(89776, 5229, 23, 'miktar kullanılamaz görünüyor'),
(89777, 5232, 23, 'HCFA yığın işlemi için kuyruğa at'),
(89778, 5233, 23, 'HCFA yığın işlemi ve yazdırma için kuyruğa at'),
(89779, 5234, 23, 'UB-92 yığın işlemi için kuyruğa at'),
(89780, 5235, 23, 'UB-92 yığın işlemi ve yazdırma yığın işlemi için kuyruğa at'),
(89781, 5236, 23, 'Kuyruğa atıldı'),
(89782, 5237, 23, 'Kuyruğa Atılmış Olaylar Yönetimi'),
(89783, 5238, 23, 'Kuyruğa atıldı:'),
(89784, 5240, 23, 'Kuyruğa Atılmış Sunular Yönetimi'),
(89785, 5241, 23, 'Çık'),
(89786, 5242, 23, 'Alkolü Bırakınız'),
(89787, 5243, 23, 'R'),
(89788, 5245, 23, 'Irk'),
(89789, 5246, 23, 'Irk ve Etnisite'),
(89790, 5247, 23, 'Irk/etnisite'),
(89791, 5248, 23, 'Radyo'),
(89792, 5249, 23, 'Radyo düğmeleri'),
(89793, 5251, 23, 'Erim'),
(89794, 5252, 23, 'Döküntüler'),
(89795, 5253, 23, 'Hız'),
(89796, 5254, 23, 'Oran'),
(89797, 5255, 23, 'Ham Rapor'),
(89798, 5256, 23, 'Yeniden Kimliklendirme'),
(89799, 5257, 23, 'Yeniden Kimliklendirme İşlemi tamamlandı'),
(89800, 5258, 23, 'Yeniden Kimliklendirme İşlemi sürüyor'),
(89801, 5259, 23, 'Yeniden Kimliklendirme dosyalarının kaydedileceği yer:'),
(89802, 5260, 23, 'Tekrar Yaralanma mı?'),
(89803, 5261, 23, 'Tekrar-Aç'),
(89804, 5262, 23, 'Tekrar-Açıldı'),
(89805, 5263, 23, 'Reaksiyon'),
(89806, 5264, 23, 'Tepkiler'),
(89807, 5265, 23, 'Oku'),
(89808, 5268, 23, 'Gerçek İsim'),
(89809, 5269, 23, 'Gerçekten sil'),
(89810, 5270, 23, 'Sebep'),
(89811, 5274, 23, 'Sevk Sebebi'),
(89812, 5275, 23, 'Vizit Sebebi'),
(89813, 5276, 23, 'Sebep/Form'),
(89814, 5277, 23, 'Makbuz'),
(89815, 5278, 23, 'Ödeme Makbuzu'),
(89816, 5279, 23, 'Makbuz Oluşturuldu'),
(89817, 5280, 23, 'Ödeme Metoduna Göre Makbuzlar Raporu'),
(89818, 5281, 23, 'Makbuzlar Özeti'),
(89819, 5282, 23, 'Alındı'),
(89820, 5283, 23, 'Alındı, Alan:'),
(89821, 5284, 23, 'Alınmış Fakslar'),
(89822, 5287, 23, 'Alıcı'),
(89823, 5288, 23, 'Alıcı ID'),
(89824, 5289, 23, 'Alıcı ID (ISA08)'),
(89825, 5290, 23, 'Alıcı ID Niteleyici (ISA07)'),
(89826, 5292, 23, 'Son üç şifreye izin verilmemektedir.'),
(89827, 5293, 23, 'Alıcı'),
(89828, 5295, 23, 'Alıcı Adı'),
(89829, 5296, 23, 'Bilgilendirmenin Alıcısı'),
(89830, 5298, 23, 'Tavsiye'),
(89831, 5300, 23, 'Tavsiyeler'),
(89832, 5301, 23, 'Tavsiyeler ve tedavi'),
(89833, 5302, 23, 'Uzman tavsiyeleri'),
(89834, 5303, 23, 'Kayıt'),
(89835, 5312, 23, 'Kayıt Açıklama'),
(89836, 5313, 23, 'Sağlam Raporu'),
(89837, 5314, 23, 'Ödeme Tutanağı'),
(89838, 5318, 23, 'kayıt bulundu'),
(89839, 5319, 23, 'kayıtlar bulundu'),
(89840, 5320, 23, 'uyuşturucu kullanımı'),
(89841, 5321, 23, 'uyuşturucular'),
(89842, 5322, 23, 'Rektal'),
(89843, 5323, 23, 'Rektal Muayene'),
(89844, 5324, 23, 'makattan'),
(89845, 5326, 23, 'Kızarıklık'),
(89846, 5327, 23, 'azalmış:'),
(89847, 5328, 23, 'Sevk'),
(89848, 5329, 23, 'Sevk Aracı'),
(89849, 5330, 23, 'Sevk Tarihi'),
(89850, 5331, 23, 'Kendisine Sevk Edilen:'),
(89851, 5332, 23, 'Sevk sınıflandırması (risk düzeyi)'),
(89852, 5333, 23, 'Sonuçların Referans aralığı'),
(89853, 5334, 23, 'Sevk Sebebi'),
(89854, 5336, 23, 'Sevk edenin adı ve imzası'),
(89855, 5337, 23, 'Sevk'),
(89856, 5338, 23, 'Sevk Eden'),
(89857, 5339, 23, 'Sevk Kartı'),
(89858, 5340, 23, 'Sevk Tarihi'),
(89859, 5341, 23, 'Sevk Formu'),
(89860, 5342, 23, 'SEVK FORMU'),
(89861, 5345, 23, 'Sevk Kaynağı'),
(89862, 5346, 23, 'Vizitler için sevk kaynağı'),
(89863, 5347, 23, 'Kendisine Sevk Edilen'),
(89864, 5348, 23, 'Sevkler'),
(89865, 5349, 23, 'Sevkler Raporu'),
(89866, 5350, 23, 'Sevk eden'),
(89867, 5351, 23, 'Sevk Eden'),
(89868, 5352, 23, 'Kendisine Sevk edilen'),
(89869, 5353, 23, 'Sevk eden'),
(89870, 5355, 23, 'Sevk Edenin Teşhisi'),
(89871, 5356, 23, 'Sevk edenin teşhisi'),
(89872, 5357, 23, 'Sevk eden doktor ve uygulama'),
(89873, 5358, 23, 'Sevk eden Sağlayıcı'),
(89874, 5359, 23, 'yenile'),
(89875, 5360, 23, 'yenilenir'),
(89876, 5361, 23, 'yenilenir'),
(89877, 5362, 23, 'Refleksler normal'),
(89878, 5363, 23, 'Tazele'),
(89879, 5368, 23, 'Devlet Reddetti'),
(89880, 5369, 23, 'reg_re'),
(89881, 5370, 23, 'kayıt'),
(89882, 5372, 23, 'Kayıtlı'),
(89883, 5373, 23, 'kayıtlı'),
(89884, 5375, 23, 'Kayıt Tarihi'),
(89885, 5376, 23, 'Kayıt Formu'),
(89886, 5377, 23, 'Rehabilitasyon'),
(89887, 5381, 23, 'İle İlişkili'),
(89888, 5382, 23, 'İlişkili'),
(89889, 5383, 23, 'İlişkili Konu'),
(89890, 5385, 23, 'İlişki(ler)/Çocuklar'),
(89891, 5386, 23, 'İlişkiler'),
(89892, 5387, 23, 'İlişki'),
(89893, 5388, 23, 'Bu başlıkta nisbi sipariş'),
(89894, 5389, 23, 'Akrabalar'),
(89895, 5399, 23, 'Bu kullanıcı hesabının Yedek Sağlık güvenceleri eksik'),
(89896, 5400, 23, 'Yedek Sağık ID'),
(89897, 5403, 23, 'Din'),
(89898, 5406, 23, 'Tekrar giriş'),
(89899, 5407, 23, 'Remdr'),
(89900, 5408, 23, 'Seçili Tesisi Anımsa'),
(89901, 5414, 23, 'HAVALE EDİLECEK ALICI:'),
(89902, 5416, 23, 'Kaldır'),
(89903, 5419, 23, 'Grubu Kaldır'),
(89904, 5420, 23, 'Grubu Kaldır'),
(89905, 5421, 23, 'Aşılamalar için desteği kaldırır.'),
(89906, 5422, 23, 'phpMyAdmin desteğini kaldırır'),
(89907, 5423, 23, 'Reçete desteğini kaldırır'),
(89908, 5425, 23, 'Çizelge İzleme özelliğini kaldırır'),
(89909, 5426, 23, 'Böbrek Taşları'),
(89910, 5428, 23, 'Grubu Yeniden Adlandır'),
(89911, 5429, 23, 'İş'),
(89912, 5430, 23, 'İş Sağlayıcı'),
(89913, 5431, 23, 'İş Sağlayıcı Numarası'),
(89914, 5432, 23, 'Tekrar Sipariş'),
(89915, 5433, 23, 'De Tekrar Sipariş'),
(89916, 5434, 23, 'Tekrar sipariş noktasına erişildi'),
(89917, 5436, 23, 'Tekr'),
(89918, 5439, 23, 'Tekrar Bilgisi:'),
(89919, 5440, 23, 'Tekrarlar'),
(89920, 5444, 23, 'Cevap Tarihi'),
(89921, 5445, 23, 'Cevap Formu'),
(89922, 5446, 23, 'Rapor'),
(89923, 5447, 23, 'Rapor - Klinik'),
(89924, 5449, 23, 'Raporu yazan'),
(89925, 5457, 23, 'Rapor Durumu'),
(89926, 5458, 23, 'Rapor Toplamları'),
(89927, 5460, 23, 'Rapor Edilebilir'),
(89928, 5461, 23, 'Rapor Edilmiş'),
(89929, 5463, 23, 'Raporlar'),
(89930, 5467, 23, 'İstek dikkate alınmadı -alacak işleme zaten çalışıyor!'),
(89931, 5474, 23, 'İstenen Hizmet'),
(89932, 5475, 23, 'Kuvvetli Şifreler Gerekiyor'),
(89933, 5476, 23, 'Eşsiz Şifreler Gerekiyor'),
(89934, 5477, 23, 'Gerekli'),
(89935, 5479, 23, 'Gerekli Alan Eksik. Lütfen yüklenecek EDI-271 dosyasını seçiniz.'),
(89936, 5485, 23, 'REZERVE EDİLMİŞ'),
(89937, 5486, 23, 'Rezerve edilmiş'),
(89938, 5487, 23, 'Programlanmış Tatil Zamanını belirlemek için ayrılmıştır'),
(89939, 5488, 23, 'Bir sağlayıcının daha sonra uygun randevusu olmayabileceğini belirtmek için ayrılmıştır'),
(89940, 5489, 23, 'Bir olayın belirtildiği şekilde gerçekleşmediğini tanımlamak için ayrılmıştır'),
(89941, 5490, 23, 'Bir sağlayıcının daha sonra uygun randevusu olabileceğini belirtmek için ayrılmıştır'),
(89942, 5496, 23, 'Çözüldü'),
(89943, 5497, 23, 'Solunum'),
(89944, 5498, 23, 'Solunum çabası artmamış'),
(89945, 5499, 23, 'Solunum'),
(89946, 5501, 23, 'Yetkili olmayan kullanıcıları programdan kısıtla'),
(89947, 5502, 23, 'Kullanıcıları tesislere kısıtla'),
(89948, 5503, 23, 'Kısıtlı Egzersiz'),
(89949, 5504, 23, 'Sonuç'),
(89950, 5506, 23, 'Sonuç Durumu'),
(89951, 5507, 23, 'Sonuç durumu veya anormallik eksik'),
(89952, 5508, 23, 'Joker olarak % kullanınız.'),
(89953, 5510, 23, 'Sonuçlar ve'),
(89954, 5511, 23, 'Arama İçin Sonuçlar Bulundu'),
(89955, 5517, 23, 'Retina Muayenesi'),
(89956, 5518, 23, 'Sağa Çekilmiş:'),
(89957, 5519, 23, 'İade'),
(89958, 5520, 23, 'Üstteki kısmı ödemenizle birlikte iade ediniz.'),
(89959, 5521, 23, 'Takvime geri'),
(89960, 5527, 23, 'Geri Dönüş Değeri'),
(89961, 5528, 23, 'İade -i ziyaret'),
(89962, 5529, 23, 'Oynamak için Döndürüldü'),
(89963, 5534, 23, 'Öz geçmişi:'),
(89964, 5535, 23, 'Sistemlerin Gözden Geçirilmesi'),
(89965, 5536, 23, 'Sistem Kontrollerinin Gözden Geçirilmesi'),
(89966, 5537, 23, 'Gözden geçirildi'),
(89967, 5538, 23, 'Revizyon'),
(89968, 5540, 23, 'Romatoid Artrit'),
(89969, 5541, 23, 'Sağ'),
(89970, 5542, 23, 'Sağ Kulak'),
(89971, 5543, 23, 'sağ kulak'),
(89972, 5545, 23, 'Sağ:'),
(89973, 5546, 23, 'Kulaklarda çınlama'),
(89974, 5547, 23, 'Kulaklarda çınlama'),
(89975, 5549, 23, 'Risk Faktörleri'),
(89976, 5550, 23, 'Risk Düzeyi'),
(89977, 5551, 23, 'Sağ Alt Lob'),
(89978, 5552, 23, 'Mortalite Riski'),
(89979, 5560, 23, 'Liste'),
(89980, 5561, 23, 'Yol'),
(89981, 5562, 23, 'Uygulama yolu, varsa'),
(89982, 5563, 23, 'Yönlendirilmiş'),
(89983, 5564, 23, 'Satırlar'),
(89984, 5565, 23, 'Risksiz Tıbbi Referans'),
(89985, 5566, 23, 'Friksiyon'),
(89986, 5567, 23, 'Friksiyonlar'),
(89987, 5581, 23, 'Çalışan Komut '),
(89988, 5582, 23, 'Rüptür'),
(89989, 5583, 23, 'Rusça'),
(89990, 5584, 23, 'Rx'),
(89991, 5585, 23, 'RX'),
(89992, 5600, 23, 'CP'),
(89993, 5601, 23, 'SGK :'),
(89994, 5602, 23, 'S3:'),
(89995, 5603, 23, 'S4:'),
(89996, 5604, 23, 'Öneri** Lisansı okumak için lütfen docs/license.txt dosyası okuyunuz veya * http://www.gnu.org/copyleft/gpl.html sayfasını ziyaret ediniz * */ //========================================================================= // '),
(89997, 5605, 23, 'Satış'),
(89998, 5606, 23, 'Satışlar'),
(89999, 5607, 23, 'Kalem başına Satışlar'),
(90000, 5608, 23, 'Ürün Raporuna göre Satışlar'),
(90001, 5609, 23, 'Tükürük'),
(90002, 5610, 23, 'Aynı Gün'),
(90003, 5611, 23, 'Samoaca'),
(90004, 5612, 23, 'Örnek'),
(90005, 5613, 23, 'Yaptırım Tipi'),
(90006, 5617, 23, 'Cts'),
(90007, 5618, 23, 'Cts &amp; Paz'),
(90008, 5619, 23, 'Cumartesi'),
(90009, 5620, 23, 'Kaydet'),
(90010, 5624, 23, 'Kaydet ve Dağıt'),
(90011, 5626, 23, 'Yeni olarak Kaydet'),
(90012, 5627, 23, 'yeni not olarak kaydet'),
(90013, 5628, 23, 'Sertifika Ayarlarını Kaydet'),
(90014, 5629, 23, 'Kaydet'),
(90015, 5630, 23, 'Formu Kaydet'),
(90016, 5631, 23, 'Bağışıklamayı Kaydet'),
(90017, 5632, 23, 'Yeni Alanı Kaydet'),
(90018, 5633, 23, 'Yeni Grubu Kaydet'),
(90019, 5634, 23, 'Yeni Liste Kaydet'),
(90020, 5635, 23, 'Yeni kalıp kaydet'),
(90021, 5637, 23, 'Hasta Demografik Bilgilerini Kaydet'),
(90022, 5638, 23, 'Çizelge ID Kaydı Başarılı'),
(90023, 5639, 23, 'İşlemi Kaydet'),
(90024, 5641, 23, 'Tarandı'),
(90025, 5642, 23, 'Taranmış Görüşme Notu'),
(90026, 5643, 23, 'Tarayıcı Dizini'),
(90027, 5644, 23, 'Tarayıcı giriş'),
(90028, 5645, 23, 'Program'),
(90029, 5646, 23, 'Program Kolaylıkları:'),
(90030, 5647, 23, 'OKUL NOTU'),
(90031, 5648, 23, 'Skolyoz'),
(90032, 5651, 23, 'İşveren'),
(90033, 5652, 23, 'İşveren Adresi'),
(90034, 5653, 23, 'İşveren Semt'),
(90035, 5654, 23, 'İşveren Ülke'),
(90036, 5655, 23, 'İşveren Yer'),
(90037, 5656, 23, 'İşveren Posta Kodu'),
(90038, 5657, 23, 'İşveren Şehir'),
(90039, 5658, 23, 'İşveren Posta Kodu'),
(90040, 5659, 23, 'Ara'),
(90041, 5661, 23, 'ara'),
(90042, 5662, 23, 'tekrar ara'),
(90043, 5664, 23, 'Arayan'),
(90044, 5665, 23, 'Aranan'),
(90045, 5666, 23, 'Aranan'),
(90046, 5669, 23, 'Hasta Ara veya Ekle'),
(90047, 5670, 23, 'Ödemeyi Ara'),
(90048, 5672, 23, 'Arama Sonuçları'),
(90049, 5673, 23, 'Seçili Olanı Ara'),
(90050, 5674, 23, 'Arama dizesi veritabanında bulunamadı'),
(90051, 5675, 23, 'Arama dizesinde en az 3 karakter olmalı'),
(90052, 5677, 23, 'Olayları Ara'),
(90053, 5678, 23, 'Ara/Ekle'),
(90054, 5679, 23, 'Sigortacı Ara/Ekle'),
(90055, 5680, 23, 'Randevular aranıyor'),
(90056, 5681, 23, 'Aranıyor'),
(90057, 5682, 23, 'Emniyet kemeri kullanımı'),
(90058, 5683, 23, 'Emniyet kemeri kullanımı'),
(90059, 5684, 23, 'İkinci'),
(90060, 5687, 23, 'İkincil'),
(90061, 5688, 23, 'İkinci Sigorta'),
(90062, 5689, 23, 'İkinci Sigorta Verileri'),
(90063, 5690, 23, 'İkinci Sigorta Sağlayıcı'),
(90064, 5698, 23, 'Güvenlik'),
(90065, 5699, 23, 'Hepsini Gör'),
(90066, 5700, 23, 'Yetkilendirmeleri Gör'),
(90067, 5701, 23, 'Büyüme Çizelgesini Gör'),
(90068, 5702, 23, 'Oluşturulmuş son alacak listesinin mesajlarını gör'),
(90069, 5704, 23, 'Son görülme'),
(90070, 5707, 23, 'Konvülsiyonlar'),
(90071, 5708, 23, 'Seç'),
(90072, 5709, 23, 'Seçiniz'),
(90073, 5710, 23, 'Seçiniz'),
(90074, 5716, 23, 'Hepsini Seçiniz'),
(90076, 5723, 23, 'Kaldırılacak kriterleri seçiniz.'),
(90077, 5725, 23, 'Kimliksizleştirme için Gereken Verileri Seçiniz'),
(90078, 5726, 23, 'Kimliksizleştirme verisinin içereceği verileri deçiniz'),
(90079, 5727, 23, 'Tarihi seçiniz'),
(90080, 5729, 23, 'Tanıyı Seçiniz'),
(90081, 5730, 23, 'Kimliksizleştirme istemi için Tanıyı Seçiniz'),
(90082, 5731, 23, 'İlacı Seçiniz'),
(90083, 5732, 23, 'İlaçları Seçiniz'),
(90084, 5733, 23, 'Kimliksizleştirme isteği için İlaçları Seçiniz'),
(90085, 5734, 23, 'EDI-271 dosyasını seçin'),
(90086, 5736, 23, 'Alanı seçiniz'),
(90087, 5737, 23, 'Alanları Seçiniz'),
(90088, 5738, 23, 'Yazdırmak için Seçiniz'),
(90089, 5739, 23, 'Aşıları Seçiniz'),
(90090, 5740, 23, 'Kimliksizleştirme istemi için Aşıları Seçiniz'),
(90091, 5741, 23, 'Sigortayı yazıp seçin'),
(90092, 5742, 23, 'Konuyu Seçiniz'),
(90093, 5744, 23, 'Dili Seçiniz'),
(90094, 5754, 23, 'Dışarı aktarılacak yapılandırma konularını seçiniz'),
(90095, 5755, 23, 'Bu günün atlanmış herhangi bir olayından esas olarak sorumlu konuyu seçiniz'),
(90096, 5761, 23, 'Girişte varsa hangi dillerin seçilebileceğini seçiniz( Tüm dillere izin ver seçeneğinin kapalı olması durumunda)'),
(90097, 5762, 23, 'Grup silmeyi onaylamak için Evet seçiniz'),
(90098, 5765, 23, 'Seçili'),
(90099, 5768, 23, 'Kendi'),
(90100, 5769, 23, 'Ücretli'),
(90101, 5771, 23, 'Gönder'),
(90102, 5772, 23, 'Tarihli Hatırlatıcı Gönder'),
(90103, 5773, 23, 'Hatırlatıcı Gönder'),
(90104, 5774, 23, 'Gönderme devam ediyor'),
(90105, 5775, 23, 'Mesaj gönder'),
(90106, 5776, 23, 'Hatırlatıcı Yığın Dosyası Gönser'),
(90107, 5779, 23, 'Bu dosyayı gönder'),
(90108, 5788, 23, 'Gönderici'),
(90109, 5789, 23, 'Gönderici ID'),
(90110, 5790, 23, 'Gönderici ID (ISA06)'),
(90111, 5791, 23, 'Gönderici ID Niteleyici (ISA05)'),
(90112, 5794, 23, 'Duyarlılıklar'),
(90113, 5795, 23, 'Duyarlılık'),
(90114, 5796, 23, 'Duyusal muayene normal'),
(90115, 5804, 23, 'Başarıyla gönderildi'),
(90116, 5807, 23, 'yazıcıya gönderildi'),
(90117, 5812, 23, 'Eyl'),
(90118, 5813, 23, 'Ayrılmış'),
(90119, 5814, 23, 'Eylül'),
(90120, 5815, 23, 'Ard'),
(90121, 5816, 23, 'Ardışıklık'),
(90122, 5821, 23, 'Hizmet'),
(90123, 5822, 23, 'Hizmet Kategorisi'),
(90124, 5823, 23, 'Hizmet Kodu'),
(90125, 5825, 23, 'Hizmet Kodları'),
(90126, 5826, 23, 'Hizmet Tarihi'),
(90127, 5827, 23, 'Hizmet Tarihi:'),
(90128, 5829, 23, 'Hizmet Yeri'),
(90129, 5831, 23, 'Hizmet uzman tarafından verildi'),
(90130, 5834, 23, 'Hizmetler'),
(90131, 5835, 23, 'Kategoriye göre Hizmetler'),
(90132, 5836, 23, 'Sağlanan hizmetler'),
(90133, 5837, 23, 'Sağlanan Hizmetler'),
(90134, 5838, 23, 'Hizmetler/Ürünler'),
(90135, 5839, 23, 'Oturum Tipi'),
(90136, 5840, 23, 'Oluştur'),
(90137, 5841, 23, 'Girişler arasında seçilmiş tesisi anımsamak için bir tesis çerezi oluştur'),
(90138, 5845, 23, 'HTTPS için SSL müşteri sertifikaları oluşturmak için bunu dosyanın mutlak yoluna ayarlayınız'),
(90139, 5846, 23, 'Ayarla:'),
(90140, 5847, 23, 'Ön Tanımlıya Ayarla'),
(90141, 5849, 23, 'Ayarlar'),
(90142, 5851, 23, 'şiddetli migren'),
(90143, 5853, 23, 'Ağrının Şiddeti'),
(90144, 5854, 23, 'Ağrının Şiddeti:'),
(90145, 5855, 23, 'Cinsiyet'),
(90146, 5856, 23, 'Cinsel Yolla Bulaşan Hastalık'),
(90147, 5859, 23, 'Paylaşma'),
(90148, 5860, 23, 'Sunucudan yazdırmak için kabuk komutu'),
(90149, 5864, 23, 'Nefes Darlığı'),
(90150, 5865, 23, 'Nefes Darlığı'),
(90151, 5866, 23, 'Nefes Darlığı 2'),
(90152, 5867, 23, 'Aşı Kaydı'),
(90153, 5868, 23, 'Şu Tarih İtibarı İle Aşı Kaydı:'),
(90154, 5870, 23, 'nnnnn-nnnn-nn gibi olmalıdır'),
(90155, 5871, 23, 'iki harfli olmalıdır'),
(90156, 5874, 23, 'Omuz'),
(90157, 5875, 23, 'Omuz + klaviküla'),
(90158, 5876, 23, 'Omuz Sorunları'),
(90159, 5877, 23, 'Göster'),
(90160, 5878, 23, 'Etkin Olanları Göster'),
(90161, 5880, 23, 'Tümünü Göster'),
(90162, 5881, 23, 'Tüm işlemleri Göster'),
(90163, 5883, 23, 'Tüm İşlemleri Göster'),
(90164, 5884, 23, 'Meşgul Göster'),
(90165, 5885, 23, 'Sadece Yetkilileri Göster'),
(90166, 5886, 23, 'Uygun Zamanları Göster'),
(90167, 5887, 23, 'Hem Amerikan hem de metrik göster (ana birim metrik)'),
(90168, 5888, 23, 'Hem Amerikan hem de metrik göster (ana birim Amerikan)'),
(90169, 5889, 23, 'Ayrıntıları Göster'),
(90170, 5890, 23, 'Sadece Hatalar mı Gösterilsin?'),
(90171, 5891, 23, 'Grafiği Göster'),
(90172, 5892, 23, 'Üzerine fare geldiğinde düz metin olayı gösterilsin mi?'),
(90173, 5893, 23, 'Yönetici sayfalarında kaç olay görülsün?'),
(90174, 5894, 23, 'Etkin Olmayanları Göster'),
(90175, 5896, 23, 'Menüyü Göster'),
(90176, 5897, 23, 'Sadece Metrik Göster'),
(90177, 5898, 23, 'Notları Göster'),
(90178, 5900, 23, 'Sadece atlanmamış işlemleri göster'),
(90179, 5901, 23, 'Hasta Notlarını Göster'),
(90180, 5902, 23, 'Libre ve ons göster'),
(90181, 5903, 23, 'Libreleri ondalık değer olarak göster'),
(90182, 5904, 23, 'Tam Birinciyi Göster'),
(90183, 5905, 23, 'Hatırlatıcıları Göster'),
(90184, 5906, 23, 'Raporu Göster'),
(90185, 5907, 23, 'Bloktaki ara/gönder bağlantıları gösterilsin mi?'),
(90186, 5910, 23, 'Ekleme listesi için özel şehir tablosunu göster.'),
(90187, 5913, 23, 'Sadece Fatura Edilmemişi Göster'),
(90188, 5914, 23, 'Sadece Amerikan göster'),
(90189, 5915, 23, 'Gösteriliyor'),
(90190, 5916, 23, 'Sonuçlar gösteriliyor'),
(90191, 5918, 23, 'Kardeşler Öyküsü'),
(90192, 5920, 23, 'Kardeşler'),
(90193, 5921, 23, 'Orak Hücreli'),
(90194, 5922, 23, 'Sig'),
(90195, 5923, 23, 'Sigmoid/Kolonoskopi'),
(90196, 5924, 23, 'İmza'),
(90197, 5925, 23, 'Laboratuvar Sonuçlarını İmzala (yaz, sadece ekle seçmeli)'),
(90198, 5926, 23, 'Sonuçları İmzala'),
(90199, 5927, 23, 'İmza'),
(90200, 5928, 23, 'İmza Dosyada'),
(90201, 5929, 23, 'İmza:'),
(90202, 5930, 23, 'İmzalanmış Rx'),
(90203, 5932, 23, 'Belirgin Şişlik:'),
(90204, 5933, 23, 'Basitleştirilmiş'),
(90205, 5934, 23, 'Basitleştirilmiş Ek-Ödeme'),
(90206, 5935, 23, 'Basitleştirilmiş Demografik Bilgiler'),
(90207, 5936, 23, 'Basitleştirilmiş Reçeteler'),
(90208, 5937, 23, 'Den beri:'),
(90209, 5938, 23, 'Saygılarımızla,'),
(90210, 5940, 23, 'Bekar'),
(90211, 5941, 23, 'Tek-seçim listesi'),
(90212, 5942, 23, 'Listeye ekleme olanağı olan tek-seçimlik liste'),
(90213, 5946, 23, 'Sinüs Problemleri'),
(90214, 5947, 23, 'Sinüs Cerrahisi'),
(90215, 5948, 23, 'SİNÜS HASSASİYETİ:'),
(90216, 5949, 23, 'Sinüzit'),
(90217, 5950, 23, 'Site'),
(90218, 5951, 23, 'Site kimliği'),
(90219, 5953, 23, 'LLC Lab Değişim Servisi LibreEHR desteği için site kimliği'),
(90220, 5956, 23, 'Büyüklük'),
(90221, 5957, 23, 'Büyüklüğü 1 ve 999 arasına bir sayı olmalıdır'),
(90222, 5958, 23, 'Büyüklük/Liste'),
(90223, 5959, 23, 'Deri'),
(90224, 5960, 23, 'Deri Kanseri'),
(90225, 5961, 23, 'Deri Hastalığı'),
(90226, 5962, 23, 'Deri Diğer'),
(90227, 5963, 23, 'Hasta Notlarının Yetkilendirilmesini Atla'),
(90228, 5964, 23, 'Bölüm atlanıyor'),
(90229, 5965, 23, 'Defter-i Kebir SQL dökümü atlanıyor-Windows sunucusuna uygulanmamıştır'),
(90230, 5967, 23, 'Uyku Paternleri'),
(90231, 5968, 23, 'Uyku paternleri'),
(90232, 5969, 23, 'Uyuyor'),
(90233, 5970, 23, 'Slovakça'),
(90234, 5971, 23, 'Slovence'),
(90235, 5972, 23, 'Toplam Borç suz'),
(90236, 5973, 23, 'Smarty Cache boşaltıldı'),
(90237, 5974, 23, 'Sigara içer, son durumu bilinmiyor.'),
(90238, 5976, 23, 'Sigara içme durumu'),
(90239, 5978, 23, 'SMS Geçidi'),
(90240, 5979, 23, 'SMS Geçidi API anahtarı'),
(90241, 5980, 23, 'SMS Geçidi API Anahtarı'),
(90242, 5981, 23, 'SMS Geçidi Şifresi'),
(90243, 5982, 23, 'SMS Geçidi Kullanıcı Adı'),
(90244, 5983, 23, 'SMS Uyarısı'),
(90245, 5984, 23, 'SMS Uyarısı Saatleri'),
(90246, 5985, 23, 'SMS son gönderme saati'),
(90247, 5987, 23, 'SMS Metni, Kullanılabilir Etiket: ***İSİM***,***SAĞLAYICI***,***TARİH***,***BAŞLAMAZAMANI***,***BİTİŞZAMANI***<BR>örneğin Sayın ***İSİM***'),
(90248, 5988, 23, 'SMS/Eposta uyarı ayarları'),
(90249, 5989, 23, 'Kimlik Doğrulama için SMTP Şifresi'),
(90250, 5992, 23, 'SMTP Sunucu Adı'),
(90251, 5993, 23, 'SMTP Sunucu Port Numarası'),
(90252, 5994, 23, 'Kimlik Doğrulama için SMTP Kullanıcı Adı'),
(90253, 6004, 23, 'Horlama'),
(90254, 6005, 23, 'SODP'),
(90255, 6006, 23, 'Toplumsal Güçlükler'),
(90256, 6009, 23, 'Toplumsal Öykü'),
(90257, 6010, 23, 'SGK Numarası'),
(90258, 6011, 23, 'solüsyon'),
(90259, 6013, 23, 'Somatik İçerik'),
(90260, 6014, 23, 'Bazı yetkilendirilmeler gösterilmedi. Tümünü görüntülemek için burayı tıklayınız'),
(90261, 6015, 23, 'Bazı kodlar gösterilmedi'),
(90262, 6016, 23, 'Bazı görüşmeler gösterilmedi. Tümünü görüntülemek için burayı tıklayınız'),
(90263, 6017, 23, 'Kimlik gizleme işlemi sırasına bir hata oluştu'),
(90264, 6018, 23, 'Bazı notlar gösterilmedi'),
(90265, 6020, 23, 'bazı sözcükler'),
(90266, 6026, 23, 'Boğaz Ağrısı'),
(90267, 6028, 23, 'Üzgünüm, dosyanız yüklenir iken bir problem oluştu.'),
(90268, 6029, 23, 'Sırala:'),
(90269, 6030, 23, 'Sırala:'),
(90270, 6031, 23, 'Toplama göre sırala'),
(90271, 6032, 23, 'Yorumlara göre sırala'),
(90272, 6033, 23, 'Crt kullanıcısına göre sırala'),
(90273, 6034, 23, 'Tarihe göre sırala'),
(90274, 6035, 23, 'Tarih/zaman a göre sırala'),
(90275, 6036, 23, 'Olaya göre sırala'),
(90276, 6037, 23, 'Gruba göre sırala'),
(90277, 6040, 23, 'Hasta ID ye göre sırala'),
(90278, 6041, 23, 'Başarıya göre sırala'),
(90279, 6043, 23, 'Kullanıcıya göre sırala'),
(90280, 6044, 23, 'Aşıya göre sırala'),
(90281, 6045, 23, 'Aşağıya doğru sırala'),
(90282, 6046, 23, 'Sonuçların Sıralanacağı tür:'),
(90283, 6047, 23, 'Yukarıya doğru sırala'),
(90284, 6048, 23, 'Kaynak'),
(90285, 6049, 23, 'Kaynak Dosya'),
(90286, 6051, 23, 'Kod için Kaynak eksik '),
(90287, 6052, 23, 'Kaynak Yığını'),
(90288, 6057, 23, 'Kaynak:'),
(90289, 6060, 23, 'Yer'),
(90290, 6061, 23, 'BOŞLUK'),
(90291, 6062, 23, 'İspanyolca'),
(90292, 6063, 23, 'İspanyolca (Latin Amerika)'),
(90293, 6064, 23, 'İspanyolca (ispanya)'),
(90294, 6066, 23, 'Özel karakter girilemez'),
(90295, 6068, 23, 'Uzman'),
(90296, 6069, 23, 'Uzman isim ve imzası'),
(90297, 6071, 23, 'Uzmanlık'),
(90298, 6072, 23, 'Uzmanlık Sistemleri'),
(90299, 6073, 23, 'Uzmanlık:'),
(90300, 6074, 23, 'Özel'),
(90301, 6075, 23, 'Özel Uygulama'),
(90302, 6076, 23, 'Özel Doğum Kontrol Hizmeti'),
(90303, 6077, 23, 'Özel Sonuç'),
(90304, 6078, 23, 'Özel Hizmet'),
(90305, 6079, 23, 'Belirtilmiş'),
(90306, 6080, 23, 'kod için formatı belirtir, # = rakam *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90307, 6081, 23, 'kod için formatı belirtir, # = rakam, @=alfa, *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90308, 6082, 23, 'Fatura referans numaraları için formatı belirtir, # = rakam *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90309, 6083, 23, 'Fatura referans numaraları için formatı belirtir, # = rakam, @=alfa, *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90310, 6084, 23, 'Ürün NDC alanları için formatı belirtir, # = rakam *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90311, 6085, 23, 'Ürün NDC alanları için formatı belirtir, # = rakam, @=alfa, *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90312, 6086, 23, 'Harici hasta ID için formatı belirtir, # = rakam *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90313, 6087, 23, 'Harici hasta ID için formatı belirtir, # = rakam, @=alfa, *=herhangi bir karakter. Kullanılmaz ise boş.'),
(90314, 6088, 23, 'Örnek'),
(90315, 6089, 23, 'Örnek numarası/tanımlayıcı'),
(90316, 6090, 23, 'Örnek Tipi'),
(90317, 6092, 23, 'Konuşma dikte ettirme'),
(90318, 6093, 23, 'Spermisitler'),
(90319, 6094, 23, 'Splenektomi'),
(90320, 6095, 23, 'Eş'),
(90321, 6096, 23, 'Eşler Öyküsü'),
(90322, 6097, 23, 'Balgam'),
(90323, 6098, 23, 'Balgam:'),
(90324, 6099, 23, 'SQ'),
(90325, 6100, 23, 'sql'),
(90326, 6102, 23, 'Ekip'),
(90327, 6103, 23, 'Ekip Üyeliği'),
(90328, 6104, 23, 'Ekipler'),
(90329, 6105, 23, 'Cinsel Sağlık ve Üreme Sağlığı'),
(90330, 6106, 23, 'Üreme Sağlığı - Aile Planlaması'),
(90331, 6107, 23, 'Aile Planlaması Dışında Üreme Sağlığı'),
(90332, 6108, 23, 'Üreme Sağlığı Sevkleri'),
(90333, 6109, 23, 'Üreme Sağlığı Vizit Formu'),
(90334, 6110, 23, 'Hizmet Tarihi'),
(90335, 6111, 23, 'SGK'),
(90336, 6112, 23, 'SSL Sertifikası Yönetimi'),
(90337, 6113, 23, 'SGK No'),
(90338, 6114, 23, 'İstikrar'),
(90339, 6116, 23, 'Standart'),
(90340, 6117, 23, 'Standart Kod'),
(90341, 6118, 23, 'Standart Tedbirler'),
(90342, 6119, 23, 'Standart Tedbirler  (Etkin Uyarılar )'),
(90343, 6120, 23, 'Standart Tedbirler ( Etkin Olmayan Uyarılar )'),
(90344, 6121, 23, 'Standart Tedbirler ( Hasta Hatırlatıcıları )'),
(90345, 6122, 23, 'Standart İsim'),
(90346, 6124, 23, 'Başla'),
(90347, 6125, 23, 'Başlangıç (yyyy-aa-gg): '),
(90348, 6126, 23, 'Yeni Bir Rapora Başla'),
(90349, 6128, 23, 'Başlama Tarihi'),
(90350, 6129, 23, 'Bu Klinikte Başlama Tarihi'),
(90351, 6130, 23, 'Başlama Tarihi Bitiş Tarihinden sonra olmamalıdır.'),
(90352, 6131, 23, 'Başlama tarihi:'),
(90353, 6132, 23, 'Başlama Tarihi:'),
(90354, 6133, 23, 'Başlama Zamanı'),
(90355, 6134, 23, 'Başlangıç Tarihi'),
(90356, 6135, 23, 'stat'),
(90357, 6136, 23, 'Şehir'),
(90358, 6137, 23, 'Şehir Veri Tipi'),
(90359, 6140, 23, 'Şehir Listesi'),
(90360, 6141, 23, 'Şehir Listesi (yaz, ekleme seçmeli)'),
(90361, 6142, 23, 'Şehir Listesi Simgesi Özel Alanlar'),
(90362, 6143, 23, 'Şehir veya Vilayet'),
(90363, 6144, 23, 'Şehir/Yer'),
(90364, 6145, 23, 'Şehir/Mahalle'),
(90365, 6146, 23, 'BİLANÇO ÖZETİ'),
(90366, 6147, 23, 'bilançolar ve gelecek faturalar'),
(90367, 6148, 23, 'Gönderilmiş Bilançolar:'),
(90368, 6149, 23, 'bilançolar; faturalar güncellenmeyecek'),
(90369, 6150, 23, 'Statik Metin'),
(90370, 6151, 23, 'İstatistik'),
(90371, 6152, 23, 'İstatistikler'),
(90372, 6153, 23, 'Durum'),
(90373, 6154, 23, 'Kabul Durumu'),
(90374, 6155, 23, 'Alacak Durumu'),
(90375, 6156, 23, 'Haliyle'),
(90376, 6158, 23, 'Zührevi Hastalıklar/AIDS Danışmanlıkları'),
(90377, 6159, 23, 'Güç ve Kondisyon'),
(90378, 6169, 23, 'Eklemlerde Sertlik'),
(90379, 6170, 23, 'Sertlik'),
(90380, 6171, 23, 'Stok Ayları'),
(90381, 6172, 23, 'Mide Ağrıları'),
(90382, 6175, 23, 'Kas gerilmesi'),
(90383, 6176, 23, 'Akım'),
(90384, 6177, 23, 'Sokak'),
(90385, 6178, 23, 'Sokak Adresi'),
(90386, 6179, 23, 'Sokak ve Numara'),
(90387, 6180, 23, 'Güç'),
(90388, 6182, 23, 'Streptokoksik Boğaz'),
(90389, 6183, 23, 'Stres Kırığı'),
(90390, 6184, 23, 'Stres Testi'),
(90391, 6185, 23, 'Felç'),
(90392, 6186, 23, 'Kuvvetli şifre demek en az 8 karakter ve en az üçü bir rakam bir küçük harf, bir büyük harf ve bir özel karakter demektir'),
(90393, 6188, 23, 'Yeni hastaları eklemek için kullanılan form stili'),
(90394, 6189, 23, 'Alt-kategori'),
(90395, 6190, 23, 'Alt-toplam'),
(90396, 6191, 23, 'Alt kategori'),
(90397, 6192, 23, 'alt kategori'),
(90398, 6193, 23, 'cilt altı'),
(90399, 6195, 23, 'Sübjektif'),
(90400, 6196, 23, 'Dilaltı'),
(90401, 6197, 23, 'dilaltı'),
(90402, 6198, 23, 'Gönder'),
(90403, 6199, 23, 'gönder'),
(90404, 6200, 23, 'Tüm İçeriği Gönder'),
(90405, 6201, 23, 'Gönder ve İstemi İptal Et'),
(90406, 6202, 23, 'Olayı Gönder'),
(90407, 6203, 23, 'formu gönder'),
(90408, 6204, 23, 'Seçilmiş İçeriği Gönder'),
(90409, 6205, 23, 'gönderildi'),
(90410, 6206, 23, 'Gönderen:'),
(90411, 6207, 23, 'Gönderenin EDI Erişim Numarası (PER06)'),
(90412, 6208, 23, 'Abone'),
(90413, 6209, 23, 'Abone Adresi'),
(90414, 6210, 23, 'Abone Şehri'),
(90415, 6211, 23, 'Abone Ülkesi'),
(90416, 6212, 23, 'Abone Doğum Tarihi'),
(90417, 6213, 23, 'Abone İşveren'),
(90418, 6214, 23, 'Abone İşveren (Aİ)'),
(90419, 6215, 23, 'Abone İşveren Adresi'),
(90420, 6216, 23, 'Abone İşveren Semt'),
(90421, 6217, 23, 'Abone İşveren Ülke'),
(90422, 6218, 23, 'Abone İşveren Şehir'),
(90423, 6219, 23, 'Abone İşveren Cadde'),
(90424, 6220, 23, 'Abone İşveren Posta Kodu'),
(90425, 6221, 23, 'Abone İşveren Posta Kodu'),
(90426, 6222, 23, 'Abone Adı'),
(90427, 6223, 23, 'Abone Soyadı'),
(90428, 6224, 23, 'Abone İkinci Adı'),
(90429, 6225, 23, 'Abone Telefonu'),
(90430, 6226, 23, 'Abone İlişkisi'),
(90431, 6227, 23, 'Abone ilişkisi kendisi değil fakat isim kendisi! Bu gerçekten TAMAM mı?'),
(90432, 6228, 23, 'Abone ilişkisi kendisi değil fakat SGK numarası kendisi!'),
(90433, 6229, 23, 'Abone ilişkisi kendisi fakat isim farklı! Bu gerçekten TAMAM mı?'),
(90434, 6230, 23, 'Abone ilişkisi kendisi fakat SGK numarası farklı!'),
(90435, 6231, 23, 'Abone Cinsiyeti'),
(90436, 6233, 23, 'Abone Şehir'),
(90437, 6234, 23, 'Abone Posta Kodu'),
(90438, 6235, 23, 'Abone Telefonu'),
(90439, 6237, 23, 'Yerine Koyma'),
(90440, 6238, 23, 'yerine koymaya izin veriliyor'),
(90441, 6240, 23, 'Başarı'),
(90442, 6241, 23, 'başarı'),
(90443, 6242, 23, 'Lab sonucu alındısı doğrulaması başarılı'),
(90444, 6243, 23, 'Lab sonuçlarının alınması başarılı'),
(90445, 6244, 23, 'Sonuçlar Lab Değişim Ağından başarıyla alındı.'),
(90446, 6246, 23, 'Başaarı ile eklenmiş kategori'),
(90447, 6247, 23, 'başarıyla kategoriye eklendi.'),
(90448, 6248, 23, 'Başarıyla Silindi.'),
(90449, 6249, 23, 'Ayrıntılar Başarılı olarak alındı. Lütfen hastayı Bekleyen Kabul Ekranından onaylayınız'),
(90450, 6250, 23, 'Veritabanı başarılı olarak kuruldu.'),
(90451, 6251, 23, 'İzleyen veritabanı başarıyla kuruldu.'),
(90452, 6252, 23, 'Başarıyla Değiştirildi.'),
(90453, 6253, 23, 'Başarıyla Kaydedildi. Paylaştırmak ister misiniz?'),
(90454, 6254, 23, 'Başarıyla Kaydedildi Dağıtmak ister misiniz?'),
(90455, 6256, 23, 'başarıyla saklandı'),
(90456, 6257, 23, 'Veritabanı başarıyla yükseltildi'),
(90457, 6258, 23, 'Aşağıdakş veritabanı başarı ile yükseltildi.'),
(90458, 6259, 23, 'başarılı olarak'),
(90459, 6260, 23, 'İntihar'),
(90460, 6261, 23, 'Özet'),
(90461, 6262, 23, 'Özeti Yapılan :'),
(90462, 6265, 23, 'Paz'),
(90463, 6267, 23, 'Pazar'),
(90464, 6268, 23, 'Süperfatura'),
(90465, 6269, 23, 'Süperfatura Kodları'),
(90466, 6270, 23, 'Süperfatura Kodları Yönetimi'),
(90467, 6271, 23, 'Süperfatura Raporu'),
(90468, 6272, 23, 'Süperfatura/Ücret dökümü'),
(90469, 6273, 23, 'Süperfaturalar'),
(90470, 6274, 23, 'Bazen Görüşme Formları veya Yönlendirme Fişleri denilen Süperfaturalar pek çok tıbbi uygulamanın zorunlu kısımlarından biridir.'),
(90471, 6275, 23, 'Süper kullanıcı'),
(90472, 6276, 23, 'Gözetmen'),
(90473, 6279, 23, 'Süpervayzır Doktor İsmi'),
(90474, 6280, 23, 'Süpervayzır Doktor Soyadı'),
(90475, 6283, 23, 'Sağlayıcı tesis adı'),
(90476, 6284, 23, 'çeşitli sağlayıcılara uygulanan takvim olaylarını destekle'),
(90477, 6285, 23, 'İçe aktar/dışa aktar konfigürasyonunu yedek dosyası ile destekle'),
(90478, 6286, 23, 'Çok-Sağlayıcılı olayları Destekle'),
(90479, 6289, 23, 'Yüzey Tipi'),
(90480, 6290, 23, 'Ameliyatlar'),
(90481, 6291, 23, 'Cerrahi'),
(90482, 6293, 23, 'Ertelendi'),
(90483, 6294, 23, 'asma'),
(90484, 6295, 23, 'Svc Tarihi'),
(90485, 6296, 23, 'Svc Tarihi:'),
(90486, 6299, 23, 'Terleme:'),
(90487, 6300, 23, 'İsveççe'),
(90488, 6301, 23, 'Şişlik'),
(90489, 6302, 23, 'Sağda Şişlik'),
(90490, 6303, 23, 'Eklemlerde Şişlik'),
(90491, 6304, 23, 'Lenf Nodlarında Şişlik'),
(90492, 6305, 23, 'Para biriminde ondalık belirteci, Ondalık yeri 0 ise kullanılmaz'),
(90493, 6306, 23, 'Para biriminde binleri ayırma belirteci'),
(90494, 6307, 23, 'Semptomlar'),
(90495, 6308, 23, 'Senkronize et'),
(90496, 6309, 23, 'Tercümeleri özel dil tablosu ile senkronize et.'),
(90497, 6310, 23, 'Senkronize edilmiş yeni özel sabit:'),
(90498, 6311, 23, 'Senkronize edilmiş yeni özel dil:'),
(90499, 6312, 23, 'Senkronize edilmiş yeni tanım(Dil, Sabit, Tanım):'),
(90500, 6313, 23, 'Senkop'),
(90501, 6314, 23, 'Sendrom Sürveyansı'),
(90502, 6315, 23, 'Sendrom Sürveyansı - Rapor Edilmemiş Konular'),
(90503, 6316, 23, 'Sendrom İzleme Raporu'),
(90504, 6317, 23, 'Sinovit, sıkışma, bursit'),
(90505, 6318, 23, 'Sistem'),
(90506, 6322, 23, 'S'),
(90507, 6323, 23, '3x1'),
(90508, 6324, 23, 'Hazneye'),
(90509, 6325, 23, 'Tablo'),
(90510, 6327, 23, 'Tablo oluşturulamadı'),
(90511, 6328, 23, 'Tablo güncellenemedi'),
(90512, 6329, 23, 'Tablolar'),
(90513, 6330, 23, 'tablet'),
(90514, 6332, 23, 'Takalotça'),
(90515, 6335, 23, 'Alınız'),
(90516, 6336, 23, 'Açılır menüden Sigortayı seçin'),
(90517, 6337, 23, 'Açılır menüden Ödemeyi seçin'),
(90518, 6338, 23, 'Geri alın'),
(90519, 6339, 23, 'Uzun süre alır'),
(90520, 6354, 23, 'Vergi No'),
(90521, 6355, 23, 'Vergi Oranı'),
(90522, 6356, 23, 'Vergiler'),
(90523, 6357, 23, 'Taksonomi'),
(90524, 6358, 23, 'Td'),
(90525, 6359, 23, 'Takım Yaralanma Genel Bakış'),
(90526, 6360, 23, 'Takım Kadrosu'),
(90527, 6361, 23, 'Takım Kadrosu Görünümü'),
(90528, 6362, 23, 'Ekip/Takım'),
(90529, 6363, 23, 'Tel'),
(90530, 6364, 23, 'Telefon Ülke Kodu'),
(90531, 6366, 23, 'Temp'),
(90532, 6367, 23, 'Geçici Yer'),
(90533, 6368, 23, 'Geçici Yöntem'),
(90534, 6369, 23, 'Sıcaklık'),
(90535, 6370, 23, 'Kalıp'),
(90536, 6371, 23, 'Kalıp İsmi'),
(90537, 6372, 23, 'Kalıp isimleri rakamlarla başlayamaz'),
(90538, 6373, 23, 'Kalıp:'),
(90539, 6374, 23, 'Kalıplar'),
(90540, 6375, 23, 'Temporal Arter'),
(90541, 6376, 23, 'Tendon Yaralanması'),
(90542, 6377, 23, 'Tendonit / tendonozis /bursit'),
(90543, 6378, 23, 'Geçici Fatura Ref No'),
(90544, 6379, 23, 'Üçüncü'),
(90545, 6380, 23, 'Üçüncü Sigorta'),
(90546, 6381, 23, 'Üçüncü Sigorta Verileri'),
(90547, 6382, 23, 'Üçüncü Sigorta sağlayıcı'),
(90548, 6383, 23, 'Test planlama'),
(90549, 6384, 23, 'Sistem Testi'),
(90550, 6385, 23, 'Metin'),
(90551, 6386, 23, 'Tanı Metin'),
(90552, 6387, 23, 'Metin alanı'),
(90553, 6393, 23, 'Tarih metin'),
(90554, 6394, 23, 'tarih-metin'),
(90555, 6395, 23, 'Metinalanı'),
(90556, 6396, 23, 'metin alanı'),
(90557, 6397, 23, 'Metin Kutusu'),
(90558, 6398, 23, 'metin kutusu'),
(90559, 6399, 23, 'Metin kutusu listesi'),
(90560, 6400, 23, 'metin kutusu listesi'),
(90561, 6401, 23, 'Taylandca'),
(90562, 6402, 23, 'Teşekkürler'),
(90563, 6403, 23, 'Seçtiğiniz için teşekkürler'),
(90564, 6404, 23, '"Temizle" düğmesi tüm açıklamaları siler'),
(90565, 6405, 23, 'Yukarıdaki açıklama başarısız'),
(90566, 6406, 23, 'Apache sunucu sertifikası ve temel anahtar'),
(90567, 6407, 23, 'Sertifika Yetkilisi sertifikası'),
(90568, 6408, 23, 'Alacak dosyası: '),
(90569, 6410, 23, 'İlgili özel anahtar'),
(90570, 6413, 23, 'Red şifresi'),
(90571, 6414, 23, 'Grup Red Şifresi'),
(90572, 6415, 23, 'Hedef form kapatıldı'),
(90573, 6416, 23, 'Hedef form kapatıldı; Seçiminiz üzerinde işlem yapamıyorum.'),
(90574, 6422, 23, 'Olay(lar) onaylandı.'),
(90575, 6423, 23, 'Olay(lar) gizlendi.'),
(90576, 6424, 23, 'Dışarı aktarılan veriler aşağıdaki metin penceresinde görüntülenmektedir. Bunu kopyalayıp epostaya veya arzu ettiğiniz her hangi bir hedefe yapıştırabilirsiniz.'),
(90577, 6426, 23, 'Dışarı aktarılan veriler aşağıdaki metin penceresinde görüntülenmektedir. Bunu kopyalayıp epostaya veya arzu ettiğiniz her hangi bir hedefe yapıştırabilirsiniz.'),
(90578, 6427, 23, 'Dışarı aktarılan veriler aşağıdaki metin penceresinde görüntülenmektedir. Bunu kopyalayıp epostaya veya arzu ettiğiniz her hangi bir hedefe yapıştırabilirsiniz.'),
(90579, 6434, 23, 'Aşağıdaki takvim olayı eklendi:'),
(90580, 6435, 23, 'Aşağıdaki takvim olayı değiştirildi:'),
(90581, 6439, 23, 'Aşağıdaki EDI dosyası yüklendi'),
(90582, 6440, 23, 'Aşağıdaki Acil Giriş Kullanıcısı etkinleştirildi:'),
(90583, 6441, 23, 'Aşağıdaki hatalar oluştu'),
(90584, 6444, 23, 'Aşağıdaki alanlar gereklidir'),
(90585, 6449, 23, 'ATNA yedek denetim makinası ana bilgisayar adı'),
(90586, 6450, 23, 'İlk pencere fatura arama penceresidir. En üste bir kaynak (örneğin çek numarası) ödeme tarihi ve çek miktarı girebilirsiniz. Kaynak ve ödeme tarihinin öyle olmasının sebebi her alacaktan sonra tekrar tekrar girmek zorunda kalmamanız içindir. Girdiğiniz miktar ödenen kısım için verdiğiniz her faturada düşülecek ve bittiğinde 0 ile sonlanacaktır.'),
(90587, 6456, 23, 'Form üzerinde kullanıcıya görünen etiket'),
(90588, 6460, 23, 'Yeni kategorinin üst kategorisi: '),
(90589, 6466, 23, 'Şifre en az sekiz karakter içermeli ve'),
(90590, 6472, 23, 'Yapılan ödemeler bu tarihten öncesine gidemez. Bunun sebebi son rapor çıktıktan sonra kimsenin önceki tarihler için kayıt yapmamasını garanti etmektir.'),
(90591, 6475, 23, 'Aşağıdaki bilgi sadece el ile gönderiyorsanız ve el ile düzeltmeler yapıyorsanız geçerlidir.'),
(90592, 6477, 23, 'İstenen belge dosya sisteminde bulunmamaktadır veya ona erişmek için yeterli izin yoktur'),
(90593, 6480, 23, 'Kaynak ve Tarih sütunları ilk sayfadan kopyalanır, bu nedenle normal olarak onlara dokunmanız gerekmeyecektir. Ödeme sütununa bir ödeme miktarını, Düzeltme sütununa bir düzeltme miktarını veya her ikisini girebilirsiniz. Aynı zamanda sağdaki "Y" yi tıklayıp düzeltme değerini otomatik hesaplattırıp aynı satır için alacağın kalanını yazdırabilirsiniz.'),
(90594, 6484, 23, 'Takvim için zaman boyutu ve bir randevu için dakika olarak en kısa aralık.'),
(90595, 6485, 23, 'Form üzerinde güncel dilde görüntülenecek tercüme edilmiş etiket'),
(90596, 6486, 23, 'Güncel dilde görüntülenecek tercüme edilmiş Başlık'),
(90597, 6487, 23, 'Güncel dilin çeviri tanımı'),
(90598, 6488, 23, 'Tercüme tabloları senkronize edildi'),
(90599, 6489, 23, 'Bu konunun tipi'),
(90600, 6490, 23, 'Bu işlem veya sonucun satıcıya özgül kimlik kodu'),
(90601, 6491, 23, 'X12 dosyaları ve sonuç HTML çıktı raporları ana Özgür ETK kurulum dizininin "era" alt dizininde arşivlenmektedirler. Bazen bu arşivlere erişmek ister iseniz yolu'),
(90602, 6492, 23, 'zip dosyasında şu kalemler olacak'),
(90603, 6493, 23, 'Tema'),
(90604, 6495, 23, 'Terapötik enjeksiyonlar'),
(90605, 6496, 23, 'Var'),
(90606, 6497, 23, 'Halen hiç reçete yok'),
(90607, 6498, 23, 'Gönderinizde hatalar var. Bunlar aşağıda özetlenmiştir.'),
(90608, 6500, 23, 'İşaretlenmiş hiç çizelge yok'),
(90609, 6502, 23, 'Hiç Yeni Teslimat yok'),
(90610, 6503, 23, 'Bu hasta için dosyada hiç not yok'),
(90611, 6504, 23, 'Bu hasta için dosyada hiçbir işlem yok.'),
(90612, 6505, 23, 'Bir eposta hatası oldu'),
(90613, 6506, 23, 'isimli bir kategori zaten var'),
(90614, 6507, 23, 'isimli bir alt kategori zaten var'),
(90615, 6508, 23, 'isimli bir kalem zaten var'),
(90616, 6510, 23, 'AR hesabı için hiçbir COA girdisi yok '),
(90617, 6511, 23, 'Peşin hesabı için COA girdisi yok '),
(90618, 6512, 23, 'Gelir hesabı için COA girdisi yok '),
(90619, 6513, 23, 'Güncel hasta yok'),
(90620, 6515, 23, 'Fatura ID si ile eşleşme yok'),
(90621, 6516, 23, 'Fatura ID si ile eşleşme yok= ');
INSERT INTO `lang_definitions` VALUES
(90622, 6517, 23, 'Servis ID için parça girişi yok '),
(90623, 6520, 23, 'İsteğinizin işlemi sırasında bir hata oldu.'),
(90624, 6523, 23, 'Sağda Kalınlaşmış:'),
(90625, 6524, 23, 'Uyluk'),
(90626, 6525, 23, 'Uyluk + diz arkası kirişi'),
(90627, 6527, 23, 'Arka büronun okuyup girebileceği ancak değiştiremeyeceği şeyler'),
(90628, 6528, 23, 'Arka büronun okuyup değişiştirebileceği şeyler'),
(90629, 6531, 23, 'Klinisyenlerin okuyup girebileceği ancak değiştiremeyeceği şeyler'),
(90630, 6532, 23, 'Klinisyenlerin okuyup değişiştirebileceği şeyler'),
(90631, 6535, 23, 'Ön büronun okuyup girebileceği ancak değiştiremeyeceği şeyler'),
(90632, 6536, 23, 'Ön büronun okuyup değişiştirebileceği şeyler'),
(90633, 6539, 23, 'Doktorların okuyup girebileceği ancak değiştiremeyeceği şeyler'),
(90634, 6540, 23, 'Doktorların okuyup değişiştirebileceği şeyler'),
(90635, 6542, 23, 'Üçüncü'),
(90636, 6544, 23, 'Bu işlem geri ALINAMAZ.'),
(90637, 6545, 23, 'Bu işlem geri alınamaz.'),
(90638, 6547, 23, 'Bu işlem günlüğe kaydedilecek'),
(90639, 6551, 23, 'Takvim Yılı'),
(90640, 6554, 23, 'Bu alacak reddedildi. Sebep:'),
(90641, 6555, 23, 'Bu alacak üst düzeye iletildi.'),
(90642, 6556, 23, 'Bu kod tipi ilişkileri kabul etmiyor'),
(90643, 6558, 23, 'Bu randevuların takvimde nasıl görüntüleneceğini belirler.'),
(90644, 6561, 23, 'Bu Görüşme'),
(90645, 6565, 23, 'Bu özellik çok deneyseldir ve tam olarak test edilmemiştir. Sorumluluk sizindir!'),
(90646, 6566, 23, 'Fatura numarası değiştirildi. Yenisi: '),
(90647, 6575, 23, 'Modül test modundadır. Veritabanı değiştirilmeyecek.'),
(90648, 6576, 23, 'Bu modül Müstahaklık verisinin verimli olarak girilmesini sağlar.'),
(90649, 6577, 23, 'Bu aybaşından bu güne kadar'),
(90650, 6581, 23, 'Bu sayfa satır içinde giriş sayfasını içerecek, böylece her seferinde tekrar gir tıklamak zorunda kalmayacağız.'),
(90651, 6582, 23, 'Bu hastanın hiçbir etkinliği yok'),
(90652, 6583, 23, 'Bu Hasta ID önceden kullanımda!'),
(90653, 6584, 23, 'Bu ürün depo başına sadece tek partiye müsaade ediyor'),
(90654, 6591, 23, 'Bu adımda gelecekte kullanmanız için saklamanız gereken bir dosya oluşturulacak. Bu dosya tekrar oluşturulamaz. Devam etmek istiyor musunuz?'),
(90655, 6592, 23, 'Bu kullanıcı hiçbir grubun üyesi değil'),
(90656, 6595, 23, 'Bu vizit yeni kontraseptif kullanımına başlar'),
(90657, 6596, 23, 'Bu vizite bir GCAC formu, sevk veya işlem hizmeti gerekecek.'),
(90658, 6597, 23, 'Bu önceki sadece metrik Vitalis formu idi, şimdi kullanılmıyor.'),
(90659, 6598, 23, 'Bu hafta başından bugüne kadar'),
(90660, 6600, 23, 'Bu BDK (Bakım Devam Kaydı) ve BDB(Bakım Devam Belgesi) bildirilmesini etkinleştirir.'),
(90661, 6606, 23, 'Bu tar formatında bir yedek oluşturup sonra tarayıcınıza gönderecek böylece kaydedebilirsiniz'),
(90662, 6613, 23, 'Bu hasta özet ekranında Fatura Simgesini devamlı açık kalmaya zorlar.'),
(90663, 6622, 23, 'Torakal omurga'),
(90664, 6623, 23, 'mm3 te bin'),
(90665, 6625, 23, 'Boğaz'),
(90666, 6626, 23, 'Gırtlak Kanseri'),
(90667, 6627, 23, 'Gırtlak Kanseri Cerrahisi'),
(90668, 6628, 23, 'Tromboz/Felç'),
(90669, 6629, 23, 'Perş'),
(90670, 6630, 23, 'Perşembe'),
(90671, 6631, 23, 'Perşembe'),
(90672, 6632, 23, 'Tiroid normal'),
(90673, 6633, 23, 'Tiroid sorunları'),
(90674, 6634, 23, 'Geçici İskemik Atak'),
(90675, 6638, 23, 'Zaman'),
(90676, 6639, 23, 'Zaman görüntüleme formatı'),
(90677, 6640, 23, 'Eklenecek zaman (1-60 dakika)'),
(90678, 6641, 23, 'Zaman seçimi'),
(90679, 6647, 23, 'Zamanlanmış olay'),
(90680, 6648, 23, 'Zaman değişeni (yok)'),
(90681, 6649, 23, 'Zaman Damgası ve Metin'),
(90682, 6650, 23, 'TIN'),
(90683, 6651, 23, 'Kulak çınlaması'),
(90684, 6652, 23, 'Başlık'),
(90685, 6653, 23, 'Başlık V'),
(90686, 6654, 23, 'Başlık Sütunları 1 ve 999 arası bir sayı olmalıdır'),
(90687, 6655, 23, 'Başlıklar'),
(90688, 6656, 23, 'Boğaz Ağız:'),
(90689, 6657, 23, 'Boğaz ağız,Dış kulak yolu,dış kulak, burun:'),
(90690, 6658, 23, 'Bitiş'),
(90691, 6659, 23, 'BİTİŞ'),
(90692, 6660, 23, 'bitiş'),
(90693, 6661, 23, 'dosyanın mutlak yoluna'),
(90694, 6662, 23, 'Not eklemek için lütfen tıklayınız '),
(90695, 6664, 23, 'Etkilenmiş bölgeye'),
(90696, 6665, 23, 'etkilenmiş bölgeye'),
(90697, 6666, 23, 'Belirlenen formu otomatik olarak açmak için bazı spor takımları burada football_injury_audit kullanır'),
(90698, 6667, 23, 'Faturalama Görünümü'),
(90699, 6668, 23, 'kategoriye'),
(90700, 6669, 23, 'Klinik Görünüme'),
(90701, 6670, 23, 'Eş Ödemeye'),
(90702, 6672, 23, 'ded ble ye'),
(90703, 6673, 23, 'Demse'),
(90704, 6674, 23, 'Müşteri tarafı SSL sertifikalarını hizmet dışı bırakma için yukarıdaki satırları Apache konfigürasyon dosyasında # ile iptal edip sunucuyu tekrar başlatın'),
(90705, 6675, 23, 'HTTPS i hizmet dışı bırakmak için Apache Konfigürasyon dosyasında yukarıdaki satırları # ile iptal edin ve Apache sunucusunu tekrar başlatın.'),
(90706, 6676, 23, 'Müşteri tarafı ssl sertifikalarını etkinleştirmek için'),
(90707, 6677, 23, 'Müşteri tarafı SSL sertifikası doğrulanmasının etkinleştirilmesi için HTTPS in etkinleştirilmesi gerekir.'),
(90708, 6678, 23, 'Sadece HTTPS i etkinleştirmek için yukarıdaki değişiklikleri uygulayın ve Apache sunucusunu tekrar başlatın. Eğer müşteri tarafı sertifikalarını da düzenlemek isterseniz lütfen sonraki bölümde düzenleyin.'),
(90709, 6679, 23, 'Görüşmeye'),
(90710, 6680, 23, 'cinsiyete göre filtrele'),
(90711, 6681, 23, 'Öyküye'),
(90712, 6682, 23, 'Konulara'),
(90713, 6683, 23, 'Bu görüşmeyi/konsültasyonu mevcut bir konu ile bağlantılandırmak için tıklayınız '),
(90714, 6684, 23, 'Bu görüşmeyi/konsültasyonu mevcut bir konu ile bağlantılandırmak için yukarıdan istenen konuyu tıklayıp vurgulayınız sonra [Kaydet] i tıklayınız. Çoklu seçim için [Ctrl] düğmesini basılı tutunuz.'),
(90715, 6685, 23, 'tekrar giriş için'),
(90716, 6686, 23, 'Açıklamaları kaydetmek için lütfen tıklayınız'),
(90717, 6687, 23, 'çalıştırmak için'),
(90718, 6688, 23, 'Müşteri sertifika doğrulaması ile https erişimini kurmak için şunları yapın'),
(90719, 6689, 23, 'Deriye'),
(90720, 6690, 23, 'deriye'),
(90721, 6691, 23, 'bu vizite mi?'),
(90722, 6693, 23, 'Bitiş:'),
(90723, 6694, 23, 'Bitiş: '),
(90724, 6695, 23, 'ALACAK_SEMT'),
(90725, 6696, 23, 'ALACAK_FAKS'),
(90726, 6697, 23, 'ALACAK_İSİM'),
(90727, 6698, 23, 'ALACAK_SOYİSİM'),
(90728, 6699, 23, 'ALACAK_İKİNCİ_İSİM'),
(90729, 6700, 23, 'ALACAK_KURUM'),
(90730, 6703, 23, 'ALACAK_POSTAKODU'),
(90731, 6704, 23, 'ALACAK_ŞEHİR'),
(90732, 6705, 23, 'ALACAK_CADDE'),
(90733, 6706, 23, 'ALACAK_UNVANI'),
(90734, 6707, 23, 'ALACAK_VEDA'),
(90735, 6708, 23, 'Tütün'),
(90736, 6712, 23, 'Tütün kullanımı'),
(90737, 6715, 23, 'Bugün'),
(90738, 6717, 23, 'bugün'),
(90739, 6720, 23, 'Bugünün tarihi'),
(90740, 6721, 23, 'Bugünün Olayları'),
(90741, 6724, 23, 'LLC Lab. Değişim hizmeti LibreEHR desteği için Simge kimliği'),
(90742, 6726, 23, 'Tonsilektomi'),
(90743, 6728, 23, 'Üst'),
(90744, 6730, 23, 'Konu'),
(90745, 6731, 23, 'Toplam'),
(90746, 6732, 23, 'toplam'),
(90747, 6737, 23, 'Vadesi gelmiş toplam alacak'),
(90748, 6738, 23, 'Ödenen Toplam'),
(90749, 6741, 23, 'Masraflar Toplamı'),
(90750, 6742, 23, 'Müşteriler Toplamı'),
(90751, 6743, 23, 'Maliyet Toplamı'),
(90752, 6744, 23, 'Tam dağıtım için çek numarası dolu değil.'),
(90753, 6748, 23, 'Toplam'),
(90754, 6749, 23, 'Toplamı: '),
(90755, 6750, 23, 'Kategori toplamı'),
(90756, 6756, 23, 'Konuların Toplam Sayısı'),
(90757, 6758, 23, 'Hastaların Toplam Sayısı'),
(90758, 6760, 23, 'Toplam Hasta Hesabı'),
(90759, 6765, 23, 'Toplam ÜS ve Aile Planlaması'),
(90760, 6776, 23, 'Toplamlar'),
(90761, 6777, 23, 'Toplam:'),
(90762, 6778, 23, 'Toplam: '),
(90763, 6785, 23, 'Antreman Tipi'),
(90764, 6786, 23, 'İşlem'),
(90765, 6787, 23, 'İşlem'),
(90766, 6788, 23, 'işlem'),
(90767, 6789, 23, 'İşlem başarısız hedef kalemde yetersiz miktar.'),
(90768, 6790, 23, 'İşlem başarısız, miktar sıfırdan az'),
(90769, 6791, 23, 'İşlem Tipi'),
(90770, 6792, 23, 'işlemler'),
(90771, 6793, 23, 'İşlemler'),
(90772, 6794, 23, 'İşlemler (yaz seçmeli)'),
(90773, 6795, 23, 'İşlemler/Sevkler'),
(90774, 6797, 23, 'Transfer'),
(90775, 6799, 23, 'Transfer başarısız, kaynak kalemden yetersiz miktar'),
(90776, 6804, 23, 'Transferler'),
(90777, 6807, 23, 'Erişim Kontrol Gruplarını Tercüme et'),
(90778, 6808, 23, 'Randevu kategorilerini Tercüme Et'),
(90779, 6809, 23, 'Belge Kategorilerini Tercüme Et'),
(90780, 6810, 23, 'Görünümleri Tercüme Et'),
(90781, 6811, 23, 'Listeleri Tercüme Et'),
(90782, 6812, 23, 'Hasta Notu Başlıklarını Tercüme Et'),
(90783, 6813, 23, 'bunu tercüme et'),
(90784, 6814, 23, 'Tercüme'),
(90785, 6815, 23, 'Tercümeler'),
(90786, 6819, 23, 'Travma'),
(90787, 6820, 23, 'Tedavi'),
(90788, 6822, 23, 'Tedavi Hedefleri'),
(90789, 6823, 23, 'Tedavi Planı'),
(90790, 6826, 23, 'Tedavi:'),
(90791, 6827, 23, 'Tedavi: '),
(90792, 6828, 23, 'Eğilim'),
(90793, 6829, 23, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) ); $month_value'),
(90794, 6830, 23, 'Tetik nokta /kompartman sendromu/Geç Başlayan Kas Ağrısı/kramp'),
(90795, 6831, 23, 'Trimaleolar'),
(90796, 6832, 23, 'Gövde ve batın'),
(90797, 6837, 23, 'çay kaşığı'),
(90798, 6839, 23, 'Yazıdan Sese'),
(90799, 6840, 23, 'Tüberküloz'),
(90800, 6841, 23, 'Sal'),
(90801, 6842, 23, 'Sal ve Perş'),
(90802, 6843, 23, 'Salı'),
(90803, 6844, 23, 'Tümör'),
(90804, 6845, 23, 'Türkçe'),
(90805, 6848, 23, 'Günde iki kez'),
(90806, 6850, 23, 'Kulak zarı'),
(90807, 6851, 23, 'Tip'),
(90808, 6852, 23, 'Tip Kimliği veya ismi (boşluklar dahil) minimum 3 harf'),
(90809, 6853, 23, 'Hasta arama sonuçları için görüntülenen sütunların tipleri'),
(90810, 6854, 23, 'Açıklama Tipi'),
(90811, 6855, 23, 'Olayların Tipleri'),
(90812, 6856, 23, 'Ekran görünümünün tipi'),
(90813, 6857, 23, 'Buraya hasta kimliğini yazın veya tarayıcıdan geçirin'),
(90814, 6859, 23, 'Order ve Sonuç Tipleri'),
(90815, 6864, 23, 'UCSM kodları Calgary Üniversitesi Spor Tıbbı Merkezinden alınmıştır'),
(90816, 6866, 23, 'Ülserasyonlar'),
(90817, 6867, 23, 'Ülseratif kolit'),
(90818, 6868, 23, 'Ülserler:'),
(90819, 6871, 23, 'Oluşturulamıyor'),
(90820, 6876, 23, 'Uygulanamadı'),
(90821, 6877, 23, 'Atanmamış'),
(90822, 6880, 23, 'Yetkisiz erişim'),
(90823, 6882, 23, 'Yalnız Fatura Edilmemişler'),
(90824, 6884, 23, 'dil altı'),
(90825, 6885, 23, 'Zayıf'),
(90826, 6886, 23, 'Tanı konmamış'),
(90827, 6887, 23, 'DAĞITILMIYOR'),
(90828, 6888, 23, 'Dağıtılmıyor'),
(90829, 6889, 23, 'Dağıtılmıyor:'),
(90830, 6890, 23, 'Çıkışı geri al'),
(90831, 6892, 23, 'Eşsiz Müşteriler'),
(90832, 6893, 23, 'Bu tip için insanın okuyabildiği eşsiz kimlik'),
(90833, 6894, 23, 'Eşsiz Yeni Hastalar'),
(90834, 6895, 23, 'Bu tip için eşsiz nümerik kimlik'),
(90835, 6896, 23, 'Sadece Bir Kez Görülmüş Hastalar'),
(90836, 6897, 23, 'Sadece Bir Kez Görülmüş Hastalar Raporu'),
(90837, 6898, 23, 'Eşsiz SP'),
(90838, 6899, 23, 'Birim'),
(90839, 6900, 23, 'Ünite'),
(90840, 6901, 23, 'ünite'),
(90841, 6903, 23, 'Vizit Formları için Birimler'),
(90842, 6904, 23, 'Birimler bir sayı olmalıdır'),
(90843, 6905, 23, 'Birimler tanımlanmadı'),
(90844, 6906, 23, 'Unite/L'),
(90845, 6907, 23, 'Bilinmiyor'),
(90846, 6910, 23, 'Hiç sigara içip içmediği bilinmiyor.'),
(90847, 6911, 23, 'Bilinmiyor veya YOK'),
(90848, 6914, 23, 'İsimsiz sigorta şirketi'),
(90849, 6915, 23, 'Kayıt edilmemiş'),
(90850, 6918, 23, 'Hepsini seçimden çıkart'),
(90851, 6919, 23, 'Seçilmemiş'),
(90852, 6920, 23, 'Belirtilmemiş'),
(90853, 6921, 23, 'yapılandırılmamış'),
(90854, 6924, 23, 'süre sonu:'),
(90855, 6925, 23, 'Zamansız dosyalama'),
(90856, 6926, 23, 'Kullanılmayan'),
(90857, 6927, 23, 'Araştırma Birimi'),
(90858, 6928, 23, 'son :'),
(90859, 6929, 23, 'Gelecek Randevular'),
(90860, 6930, 23, 'Gelecek Olaylar'),
(90861, 6931, 23, 'Güncelle'),
(90862, 6932, 23, 'güncelle'),
(90863, 6933, 23, 'Güncelleme Aktif'),
(90864, 6934, 23, 'Dosyaları güncelle'),
(90865, 6935, 23, 'Güncelleme Bilgisi'),
(90866, 6936, 23, 'Güncelleme Listesi'),
(90867, 6937, 23, 'Sağlayıcı Numarasını Güncelle'),
(90868, 6938, 23, 'Seçilmiş Konuları Güncelle'),
(90869, 6939, 23, 'İzleyen değişkenleri dosyaya güncelle'),
(90870, 6940, 23, 'Kullanıcı bilgisini güncelle'),
(90871, 6942, 23, 'Demografik bilgilerin güncellenmesine izin verilmiyor'),
(90872, 6947, 23, 'Veritabanını Yükselt'),
(90873, 6948, 23, 'İşlemleri, İşlevleri ve kimliksizleştirme işlemi için gerekli tabloları içermek üzere ÖzgürETK yı yükseltir'),
(90874, 6949, 23, 'Yükseltme sürecek'),
(90875, 6950, 23, 'UPIN'),
(90876, 6951, 23, 'Yükle'),
(90877, 6954, 23, 'Konfigürasyon verisini Yükle'),
(90878, 6955, 23, 'Belgeyi Yükle'),
(90879, 6956, 23, 'Yükleme Başarısız!'),
(90880, 6957, 23, 'Resmin yükleneceği yer'),
(90881, 6958, 23, 'İçe aktarma dosyasını yükle'),
(90882, 6961, 23, 'Raporu yükle'),
(90883, 6963, 23, 'Bu dosyayı yükle'),
(90884, 6964, 23, 'Fatura numarasına tıklayınca "el ile gönderme penceresi" görüntülenir. Burada vade tarihini ve notları değiştirebilir, gönderdiğiniz muhatabı seçebilir ve beklenen ödemelerin alınmış olduğu tüm sigortaları işaretleyebilirsiniz. En önemlisi, ücretlendirilmesi yapılmış her fatura kodu için ödeme ve düzeltme bilgisini girebilirsiniz.'),
(90885, 6965, 23, 'Arama sonrası bir fatura listesi görüntülenir. Fatura numaralarından birini tıkladığınızda yeni bir pencere açılır, burada göndermek üzere el ile veri girebilirsiniz. Aynı zamanda hastanın ismi üzerine tıklayıp ön büro elemanlarının hasta geldiğinde görebileceği bir not girebilirsiniz. Faturaların hasta bilançolarında görüntülenmesini seçebilir ve bu bilançoları bastırabilirsiniz.'),
(90886, 6966, 23, 'Üst kol'),
(90887, 6968, 23, 'Acil'),
(90888, 6970, 23, 'İdrar'),
(90889, 6971, 23, 'İdrarda damlama'),
(90890, 6972, 23, 'İdrar Sıklığı'),
(90891, 6973, 23, 'İdrarda duraksama'),
(90892, 6975, 23, 'İdrar Akışı'),
(90893, 6976, 23, 'Ani İdrar Gelmesi'),
(90894, 6977, 23, 'URL'),
(90895, 6979, 23, 'ÖzgürETK desteği için URL'),
(90896, 6986, 23, 'Kullanım Belirteci (ISA15)'),
(90897, 6988, 23, '24 saat formatı mı kullanılsın?'),
(90898, 6991, 23, 'Masraflar Panelini Kullan'),
(90899, 7000, 23, 'Ön Tanımlıları Kullan'),
(90900, 7001, 23, 'Silmek İçin Delete Opsiyonunu Kullanın.'),
(90901, 7002, 23, 'Uluslararası veri stili mi kullanılsın?'),
(90902, 7004, 23, 'Aşağıdaki alanları bir satın alma veya transfer için kullanınız'),
(90903, 7005, 23, 'Bu özelliği sadece yeni kurulmuş yerlerde kullanınız. '),
(90904, 7006, 23, 'Konular kullanılsın mı?'),
(90905, 7007, 23, 'Kullanıcı'),
(90906, 7009, 23, 'Kullanıcı / Gruplar'),
(90907, 7010, 23, 'Kullanıcı Yönetimi'),
(90908, 7011, 23, 'Kullanıcı ve Tesis Yönetimi'),
(90909, 7012, 23, 'Kullanıcı ve Grup Yönetimi'),
(90910, 7014, 23, 'Kullanıcı Sertifikası doğrulaması etkisizleştirildi'),
(90911, 7015, 23, 'Kullanıcı Tanımlanmış'),
(90912, 7016, 23, 'Kullanıcı Tanımlanmış Alan 11'),
(90913, 7017, 23, 'Kullanıcı Tanımlanmış Alan 12'),
(90914, 7018, 23, 'Kullanıcı Tanımlanmış Alan'),
(90915, 7019, 23, 'Kullanıcı Tanımlanmış Liste 1'),
(90916, 7020, 23, 'Kullanıcı Tanımlanmış Liste 2'),
(90917, 7021, 23, 'Kullanıcı Tanımlanmış Liste 3'),
(90918, 7022, 23, 'Kullanıcı Tanımlanmış Liste 4'),
(90919, 7023, 23, 'Kullanıcı Tanımlanmış Liste 5'),
(90920, 7024, 23, 'Kullanıcı Tanımlanmış Liste 6'),
(90921, 7025, 23, 'Kullanıcı Tanımlanmış Liste 7'),
(90922, 7026, 23, 'Kullanıcı Tanımlanmış Metin 1'),
(90923, 7027, 23, 'Kullanıcı Tanımlanmış Metin 2'),
(90924, 7028, 23, 'Kullanıcı Tanımlanmış Metin 3'),
(90925, 7029, 23, 'Kullanıcı Tanımlanmış Metin 4'),
(90926, 7030, 23, 'Kullanıcı Tanımlanmış Metin 5'),
(90927, 7031, 23, 'Kullanıcı Tanımlanmış Metin 6'),
(90928, 7032, 23, 'Kullanıcı Tanımlanmış Metin 7'),
(90929, 7033, 23, 'Kullanıcı Tanımlanmış Metin 8'),
(90930, 7039, 23, 'Kullanıcı El Kitabı'),
(90931, 7040, 23, 'Kullanıcı Üyelikleri'),
(90932, 7042, 23, 'Kullanıcı ismi veya Host adı boş olamaz'),
(90933, 7043, 23, 'Kullanıcı veya Host Adı'),
(90934, 7046, 23, 'Kullanıcı Ayarları'),
(90935, 7047, 23, 'Kullanıcıya Özel Ayarlar'),
(90936, 7049, 23, 'Kullanıcı Adı'),
(90937, 7052, 23, 'SMS Yolu için Kullanıcı Adı'),
(90938, 7053, 23, 'SMS Yolu için Kullanıcı Adı'),
(90939, 7055, 23, 'Kullanıcı Adı'),
(90940, 7056, 23, 'Kullanıcılar'),
(90941, 7057, 23, 'Kullanıcılar/Gruplar/Günlükler Yönetimi'),
(90942, 7058, 23, '<a href="http://php.net/strftime">strftime</a> php formatını kullanır'),
(90943, 7059, 23, 'İYE ler'),
(90944, 7062, 23, 'TATİL'),
(90945, 7063, 23, 'Tatil'),
(90946, 7064, 23, 'Aşı'),
(90947, 7065, 23, 'Vajinal Halka'),
(90948, 7066, 23, 'Ayrılış'),
(90949, 7068, 23, 'Değer'),
(90950, 7069, 23, 'Değer 1'),
(90951, 7070, 23, 'Değer 2'),
(90952, 7072, 23, 'Değer Sayısal Olmalı'),
(90953, 7073, 23, 'Var1'),
(90954, 7074, 23, 'Var2'),
(90955, 7075, 23, 'kimliksizleştirme yükseltmesi komutu çalıştırma değişkeni'),
(90956, 7076, 23, 'Su çiçeği 1'),
(90957, 7077, 23, 'Su çiçeği 2'),
(90958, 7078, 23, 'Variköz Damarlar'),
(90959, 7079, 23, 'Damar hastalığı'),
(90960, 7080, 23, 'Damar yaralanması'),
(90961, 7081, 23, 'Damar Cerrahisi'),
(90962, 7083, 23, 'Satıcı'),
(90963, 7084, 23, 'Sürüm'),
(90964, 7085, 23, 'Vertigo'),
(90965, 7087, 23, 'Gaziler Yönetim Planı'),
(90966, 7088, 23, 'Çocuk Aşıları'),
(90967, 7089, 23, 'Vietnamlı'),
(90968, 7090, 23, 'görünüm'),
(90969, 7091, 23, 'Görünüm'),
(90970, 7092, 23, 'Alerjileri Gör'),
(90971, 7097, 23, 'Kapsamlı Hasta Raporunu Gör'),
(90972, 7100, 23, 'Belgeyi Gör'),
(90973, 7101, 23, 'Görüşmeye bak'),
(90974, 7103, 23, 'olaylar açılan pencerede gösterilsin mi?'),
(90975, 7107, 23, 'Günlüğü Göster'),
(90976, 7108, 23, '1. Sayfayı Göster'),
(90977, 7109, 23, '2. Sayfayı Göster'),
(90978, 7110, 23, 'Eski ve Gelecek Hatırlatıcıları Göster'),
(90979, 7111, 23, 'Hastayı Gör'),
(90980, 7116, 23, 'İlgili görüşmeleri gör'),
(90981, 7117, 23, 'Raporu Göster'),
(90982, 7118, 23, 'OKUBENİ dosyasını göster'),
(90983, 7121, 23, 'Alerjileri Gör/Düzenle'),
(90984, 7122, 23, 'Konuyı göster/düzenle'),
(90985, 7123, 23, 'İzle/Yazdır'),
(90986, 7124, 23, 'Görünüm:'),
(90987, 7125, 23, 'VISA'),
(90988, 7126, 23, 'VISA/Mastercard/AMEX'),
(90989, 7127, 23, 'İç organ yaralanması travma/cerrahi'),
(90990, 7132, 23, 'Vizit Kategorisi'),
(90991, 7133, 23, 'Vizit Kategorisi:'),
(90992, 7134, 23, 'Vizit Tarihi'),
(90993, 7135, 23, 'Vizite darihi'),
(90994, 7137, 23, 'Vizit Formları'),
(90995, 7138, 23, 'Vizit Öyküsü'),
(90996, 7140, 23, 'Vizitler'),
(90997, 7141, 23, 'Vizitleri Yapan'),
(90998, 7142, 23, 'Vital Bulgular'),
(90999, 7143, 23, 'Vital Bulgular'),
(91000, 7144, 23, 'Vital Bulgular (Metrik)'),
(91001, 7145, 23, 'Vital Bulgular Formu Seçenekleri'),
(91002, 7146, 23, 'Ses'),
(91003, 7147, 23, 'Gönderilmiş Ses'),
(91004, 7149, 23, 'Kusma'),
(91005, 7151, 23, 'Ç'),
(91006, 7152, 23, 'Bel Çev'),
(91007, 7153, 23, 'Bel Çevresi'),
(91008, 7154, 23, 'Bekleme'),
(91009, 7155, 23, 'Randevusuz'),
(91010, 7157, 23, 'Walt Pennington'),
(91011, 7158, 23, 'Depo'),
(91012, 7161, 23, 'Depolar'),
(91013, 7162, 23, 'Ilık'),
(91014, 7163, 23, 'Uyarı'),
(91015, 7164, 23, 'UYARI'),
(91016, 7166, 23, 'Uyarı. Çek numarası veri tabanında daha önceden kayıtlı.'),
(91017, 7168, 23, 'Uyarı: Bugün bu hasta için bir vizit oluşturulmuş!'),
(91018, 7170, 23, 'Uyarı:Hasta ID si eşsiz değil'),
(91019, 7171, 23, 'UYARI: Bu, yüklenen dosyadan alınan veri ile konfigürasyon bilgisinin üzerine yazacak!'),
(91020, 7173, 23, 'Uyarılar'),
(91021, 7177, 23, 'Vadesi gelmiş borçlarınızı zamanında ödediğinizi takdir ediyoruz'),
(91022, 7178, 23, 'yukarıdaki hastanızı psikiyatri kliniğimizde değerlendirme ve tedavi için ayaktan hasta olarak gördük. Bu sevk nedeniyle teşekkür ederiz.'),
(91023, 7179, 23, 'Zayıflık'),
(91024, 7182, 23, 'Web Sitesi'),
(91025, 7184, 23, 'Çar'),
(91026, 7185, 23, 'Çarşamba'),
(91027, 7186, 23, 'Hafta'),
(91028, 7187, 23, 'hafta'),
(91029, 7188, 23, 'Hafta Görünümü'),
(91030, 7189, 23, 'Hafta (lar)'),
(91031, 7190, 23, 'Haftalık Etkilenmeler'),
(91032, 7192, 23, 'Haftalar'),
(91033, 7193, 23, 'Ağırlık'),
(91034, 7196, 23, 'Ağırlıkta Değişme'),
(91035, 7197, 23, 'Kilo kaybı'),
(91036, 7198, 23, 'Zayıflama kliniği'),
(91037, 7199, 23, 'Hoş Geldiniz'),
(91038, 7202, 23, 'Sayılacak olan nedir?'),
(91039, 7203, 23, 'Hırıltı:'),
(91040, 7204, 23, 'Hırıldama'),
(91041, 7205, 23, 'Hırıldama:'),
(91042, 7208, 23, 'İlgili taranmış veya kağıt belgeler nerede bulunabilir?'),
(91043, 7211, 23, 'Omurga incinmesi'),
(91044, 7212, 23, 'Beyaz'),
(91045, 7213, 23, 'Kim'),
(91046, 7214, 23, 'Kim yanıtladı?'),
(91047, 7215, 23, 'Dul'),
(91048, 7217, 23, 'Gezinme çerçevesinin piksel olarak genişliği'),
(91049, 7221, 23, 'Seçilen ile:'),
(91050, 7222, 23, 'eski ismi ile'),
(91051, 7224, 23, 'Kim ile bir mesaj bırakabiliriz?'),
(91052, 7225, 23, 'Alıkondu'),
(91053, 7226, 23, 'saatler içerisinde'),
(91054, 7227, 23, 'saatler içerisinde:'),
(91055, 7228, 23, 'dakikalar içerisinde'),
(91056, 7229, 23, 'dakikalar içerisinde:'),
(91057, 7232, 23, 'Güncellemesiz'),
(91058, 7233, 23, 'Tanık'),
(91059, 7234, 23, 'hf'),
(91060, 7235, 23, 'Normal sınırlarda'),
(91061, 7237, 23, 'Kadınlar'),
(91062, 7238, 23, 'Sadece Kadınlar'),
(91063, 7240, 23, 'İş'),
(91064, 7241, 23, 'İŞ NOTU'),
(91065, 7242, 23, 'İş Telefonu'),
(91066, 7243, 23, 'İş Telefon Numarası'),
(91067, 7244, 23, 'İş ile ilgili mi?'),
(91068, 7245, 23, 'İş/Eğitim/Hobiler'),
(91069, 7246, 23, 'İş/Okul Notu'),
(91070, 7247, 23, 'iş günü'),
(91071, 7249, 23, 'İşçi Tazminat Sağlık Planı'),
(91072, 7252, 23, 'Daha kötü'),
(91073, 7253, 23, 'Bakiye miktarın toplam hesaba uygulanmasını ister misiniz?'),
(91074, 7254, 23, 'Ödendi olarak işaretlenmelerini ister misiniz?'),
(91075, 7255, 23, 'Paylaştırmak istermisiniz?'),
(91076, 7256, 23, 'Bu hastanın dağılımını iptal etmek ister misiniz?'),
(91077, 7257, 23, 'Ödeme dağılımını silmek ister misiniz?'),
(91078, 7258, 23, 'Ödemeleri silmek ister misiniz?'),
(91079, 7259, 23, 'Ödemeleri değiştirmek ve bitirmek ister misiniz?'),
(91080, 7260, 23, 'Ödemeleri değiştirmek ister misiniz?'),
(91081, 7261, 23, 'Ödemeleri göndermek ve bitirmek ister misiniz?'),
(91082, 7262, 23, 'Ödemeleri göndermek ister misiniz?'),
(91083, 7263, 23, 'Kaydetmek ister misiniz?'),
(91084, 7264, 23, 'Bilek'),
(91085, 7265, 23, 'Bilek ve el'),
(91086, 7266, 23, 'Bilek Sorunları'),
(91087, 7267, 23, 'yaz'),
(91088, 7268, 23, 'iptal et'),
(91089, 7270, 23, 'korkunç'),
(91090, 7271, 23, 'WT'),
(91091, 7273, 23, 'x İptal'),
(91092, 7274, 23, 'x İptal'),
(91093, 7275, 23, 'Röntgen'),
(91094, 7276, 23, 'Röntgen filmi yorumu:'),
(91095, 7277, 23, 'Röntgen filmi yorumu:'),
(91096, 7278, 23, 'Sadece X12: Yedek İddiası '),
(91097, 7279, 23, 'X12 Partneri'),
(91098, 7280, 23, 'X12 Partnerleri'),
(91099, 7284, 23, 'Y'),
(91100, 7285, 23, 'Yıl'),
(91101, 7286, 23, 'yıl'),
(91102, 7287, 23, 'Yıl Görünümü'),
(91103, 7288, 23, 'Yıl(lar)'),
(91104, 7292, 23, 'EVET'),
(91105, 7293, 23, 'Evet'),
(91106, 7294, 23, 'evet'),
(91107, 7295, 23, 'EVET!'),
(91108, 7296, 23, 'Evet, Sil ve günlüğe kaydet'),
(91109, 7298, 23, 'Evet/Hayır'),
(91110, 7299, 23, 'Evet:'),
(91111, 7300, 23, 'Yidiş'),
(91112, 7303, 23, 'Dizi kalıbını kalıcı olarak değiştirmek üzeresiniz. Devam etmek istediğinizden emin misiniz?'),
(91113, 7304, 23, 'Giriş döneminiz bitmek üzere. Önce şifrenizi değiştirin'),
(91114, 7305, 23, 'Bu olayı silme izniniz yok'),
(91115, 7306, 23, 'Bu olayı düzenleme izniniz yok'),
(91116, 7307, 23, 'Bunu yapmaya yetkiniz yok'),
(91117, 7308, 23, 'Bu ekibe erişim yetkiniz yok'),
(91118, 7309, 23, 'Konuları ekleme/düzenleme yetkiniz yok'),
(91119, 7311, 23, 'Bu görülmeyi görmeye yetkiniz yok'),
(91120, 7313, 23, 'Bu işleve doğrudan erişemezsiniz'),
(91121, 7314, 23, 'Bu sayfaya doğrudan erişemezsiniz'),
(91122, 7315, 23, 'Bir kategori için boş değer giremezsiniz'),
(91123, 7316, 23, 'Bir alt kategori için boş değer giremezsiniz'),
(91124, 7317, 23, 'Bir kalem için boş değer giremezsiniz'),
(91125, 7319, 23, 'Hiçbir işlem seçmediniz'),
(91126, 7320, 23, 'Bu notu görme/düzenleme yetkiniz yok'),
(91127, 7321, 23, 'Kilitlenmiş bir içeriği değiştirmeye çalıştınız. Bunu yapmak istiyorsanız kilidi kaldırın. Kilidi açmak için, ''/*lock::*/'', yazılı satırı silin'),
(91128, 7323, 23, 'Sadece metin .txt dosyalarını yükleyebilirsiniz.'),
(91129, 7325, 23, 'Yeni Hasta Görüşme formunda ön tanımlı yakınma olarak buraya metin koyabilirsiniz.'),
(91130, 7329, 23, 'Önce bir hasta seçmeli veya eklemelisiniz'),
(91131, 7330, 23, 'Önce bir görüşme seçmeli veya eklemelisiniz'),
(91132, 7332, 23, 'Bir vizit kategorisi seçmelisiniz'),
(91133, 7333, 23, 'Devam etmek için bazı alanları seçmelisiniz'),
(91134, 7334, 23, 'Bu testi çalıştırmanızın sebebi bu alacak başarıyla oluşturulmuş görünse de gerçek alacak dosyasının hiçbir beri içermemesi veya içermesi gereken bilgileri kısmen içermesidir. HCFA dosyalarında bu aşikardır çünkü insan okuyabilir, X12 alacaklarında bir alacağın uygun şekilde doldurulup doldurulmadığını kontrol etmek ise daha güç bir işlemdir.'),
(91135, 7339, 23, 'Bitiş tarihiniz geçersiz'),
(91136, 7340, 23, 'Olayınız silindi'),
(91137, 7341, 23, 'Olayınız değiştirildi'),
(91138, 7342, 23, 'Olayınız gönderildi'),
(91139, 7345, 23, 'Liste isminiz isimlendirme gereksinimlerine göre değiştirildi'),
(91140, 7347, 23, 'Bu kategori, işlem veya sonuç için isminiz'),
(91141, 7349, 23, 'Şifrenizin süresi doldu. Lütfen şifrenizi değiştiriniz.'),
(91142, 7350, 23, 'Şifrenizin süresinin dolacağı tarih:'),
(91143, 7351, 23, 'Şifrenizin süresi bugün doluyor. Lütfen şifrenizi değiştiriniz.'),
(91144, 7353, 23, 'Takvim konfigürasyonunuz ön tanımlı değerlere sıfırlandı'),
(91145, 7354, 23, 'Takvim konfigürasyonunuz güncellendi'),
(91146, 7355, 23, 'Tekrarlama sıklığınız bir tam sayı olmalı'),
(91147, 7356, 23, 'Tekrarlama sıklığınız en az 1 olmalı'),
(91148, 7357, 23, 'Başlama tarihiniz bitirme tarihinizden sonra'),
(91149, 7358, 23, 'Başlama tarihiniz geçersiz'),
(91150, 7359, 23, 'Göndermeniz başarısız oldu'),
(91151, 7360, 23, 'yyyy-aa-gg'),
(91152, 7361, 23, 'YYYY-AA-GG'),
(91153, 7362, 23, 'Bu belge ile ilgili yyyy-aa-gg tarihi'),
(91154, 7363, 23, 'yyyy-aa-gg tarihi yok'),
(91155, 7364, 23, 'yyyy.aa-gg doğum tarihi'),
(91156, 7365, 23, 'yyyy.aa-gg Doğum Tarihi'),
(91157, 7366, 23, 'yyyy.aa-gg son kullanım tarihi'),
(91158, 7367, 23, 'yyyy.aa-gg hastaneye yatış tarihi'),
(91159, 7368, 23, 'yyyy.aa-gg ameliyat tarihi veya ilaca başlama tarihi'),
(91160, 7369, 23, 'yyyy.aa-gg satın alma veya transfer tarihi'),
(91161, 7370, 23, 'yyyy.aa-gg iyi olma veya ilacı kesme tarihi'),
(91162, 7371, 23, 'yyyy.aa-gg Oyuna geri dönme tarihi'),
(91163, 7372, 23, 'yyyy.aa-gg servis tarihi'),
(91164, 7373, 23, 'yyyy.aa-gg bu mektubun tarihi'),
(91165, 7374, 23, 'yyyy.aa-gg Oyuna geri döndüğü tarih'),
(91166, 7375, 23, 'yyyy.aa-gg belge tarihi'),
(91167, 7376, 23, 'yyyy.aa-gg olay tarihi veya başlama tarihi'),
(91168, 7383, 23, 'yyyy.aa-gg bu olayın son günü tarihi'),
(91169, 7387, 23, 'Sıfır'),
(91170, 7389, 23, 'Posta kodu'),
(91171, 7390, 23, 'Posta kodu'),
(91172, 7391, 23, 'Posta kodu/Ülke'),
(91173, 7392, 23, 'Zulu'),
(91174, 7393, 23, ' fakat idi '),
(91175, 7394, 23, ' erişilemedi'),
(91176, 7395, 23, 'Gerçekten silmek istiyor musunuz?'),
(91177, 7396, 23, 'İlaç'),
(91178, 7397, 23, 'epostalar gönderilmedi'),
(91179, 7398, 23, 'Gönderen:'),
(91180, 7399, 23, 'oluşturuldu. '),
(91181, 7400, 23, 'tekrar açıldı.'),
(91182, 7401, 23, 'Öykü'),
(91183, 7402, 23, 'bir sayı değil'),
(91184, 7403, 23, 'tekrar faturalandırmak için hazır'),
(91185, 7404, 23, 'Sol Alt Lob'),
(91186, 7405, 23, 'Parti'),
(91187, 7406, 23, 'Orijinal Medicaid Referans No: '),
(91188, 7407, 23, 'dak'),
(91189, 7408, 23, 'bulunamadı!'),
(91190, 7409, 23, 'Bazı tarayıcılardaki farklı özellikler nedeniyle aşağıdaki çıktı ekrana ani sıçramalarla gelebilir, birkaç saniyelik uzun duraksamalar olabilir, program çökmüş gibi görünebilir. Durum bu değildir. n sonunda çıktı satır satır görüntülenir. Altta sıralı sayılar görülebilir. Bir şey olmuyor gibi görünse de program çalışmaya devam etmektedir. Bu rakamlar fatura içeriği ile aralıklıdır ve bu da normaldir'),
(91191, 7410, 23, 'reçete limitlerine ulaşıyor :'),
(91192, 7411, 23, 'Bitiş:'),
(91193, 7412, 23, 'Güncelleme başarısız. Veritabanında yok mu?'),
(91194, 7413, 23, 'sadece faturalandı olarak işaretlendi.'),
(91195, 7414, 23, 'başarıyla kuyruğa atıldı.'),
(91196, 7415, 23, '! Vizit olmadan terk etti'),
(91197, 7416, 23, '" kod için'),
(91198, 7417, 23, '" Takvim ayarlarında İŞARETLENDİ!'),
(91199, 7418, 23, '# Sig/mal konu'),
(91200, 7419, 23, '# tablet'),
(91201, 7420, 23, '$'),
(91202, 7421, 23, '$ kodlaması bitti'),
(91203, 7422, 23, '$label (yyyy-aa-gg): '),
(91204, 7423, 23, '%'),
(91205, 7424, 23, '% İptal Edildi < 24 saat'),
(91206, 7425, 23, '% İptal Edildi < 24 saat '),
(91207, 7426, 23, 'bulunmalı fakat yok.'),
(91208, 7427, 23, '(% herhangi bir dizinin, _ herhangi bir karakterin yerini tutar)'),
(91209, 7429, 23, '(Geri)'),
(91210, 7430, 23, '(Düzenlemek için tıklayınız)'),
(91211, 7432, 23, '(Daha Fazla)'),
(91212, 7433, 23, '(Yeni Hasta)'),
(91213, 7434, 23, '(Notlar ve Yetkiler)'),
(91214, 7435, 23, '(Hasta Notları)'),
(91215, 7436, 23, '(Bunlardan birisini seçin veya kendi başlığınızı yazın)'),
(91216, 7437, 23, 'Değeri değiştirmek için (shift-)Tıklayın veya sürükleyin'),
(91217, 7438, 23, '* Hatırlatma yapıldı'),
(91218, 7439, 23, '** Lütfen ameliyatları Konulara taşıyınız!'),
(91219, 7440, 23, '**Gerekli'),
(91220, 7441, 23, '*+ Çizelge çekildi'),
(91221, 7442, 23, '- Hiç'),
(91222, 7445, 23, '.'),
(91223, 7446, 23, '0'),
(91224, 7447, 23, '0-10'),
(91225, 7448, 23, '0-24'),
(91226, 7451, 23, '1'),
(91227, 7452, 23, '1 = Kuzey Amerika. Diğer ülke kodları için http://www.wtng.info/'),
(91228, 7457, 23, '1.İstirahat 2.İki gün buz 3. Kompresyon ayakta solukluk veya uyuşma oluncaya kadar sargıyı yerinde bırak 4. Ayak ve bacağı yükselt'),
(91229, 7458, 23, '11-14'),
(91230, 7459, 23, '12 saat'),
(91231, 7460, 23, '15-19'),
(91232, 7462, 23, '2'),
(91233, 7468, 23, '20-24'),
(91234, 7477, 23, '2111-13'),
(91235, 7478, 23, '24 saat'),
(91236, 7479, 23, '25'),
(91237, 7480, 23, '25-29'),
(91238, 7481, 23, '2inci'),
(91239, 7483, 23, '3 ay'),
(91240, 7485, 23, 'Günde 3 kez'),
(91241, 7487, 23, '30-34'),
(91242, 7488, 23, '35-39'),
(91243, 7489, 23, '3üncü'),
(91244, 7491, 23, '4 ay'),
(91245, 7493, 23, 'Günde 4 kez'),
(91246, 7495, 23, '40-44'),
(91247, 7496, 23, '45'),
(91248, 7497, 23, '465.9, IYE'),
(91249, 7498, 23, '466.0, Bronşit, Akut, başka türlü sınıflandırılmamış'),
(91250, 7499, 23, '486.0, Pnömoni, Akut'),
(91251, 7500, 23, '491.21,KOAH alevlenmesi'),
(91252, 7501, 23, '491.8, Bronşit, Kronik'),
(91253, 7502, 23, '493.92,Astım, Akut Alevlenme'),
(91254, 7503, 23, '496.0, KOAH'),
(91255, 7504, 23, '4 üncü'),
(91256, 7508, 23, '519.7, Bronkospazm'),
(91257, 7509, 23, '5 inci'),
(91258, 7511, 23, '6 ay'),
(91259, 7514, 23, '6 ıncı'),
(91260, 7517, 23, '824.0 Kırık, medial malleol, kapalı'),
(91261, 7518, 23, '824.2 Kırk, lateral malleol, kapalı'),
(91262, 7519, 23, '824.6 Kırık, Trimalleolar, kapalı'),
(91263, 7520, 23, '825.32 Kırık Naviküler (ayak bileği)'),
(91264, 7521, 23, '825.35 Kırık, 5. Metatars kaidesi'),
(91265, 7522, 23, '845.00 ayak bileği burkulması başka yerde tanımlanmamış'),
(91266, 7523, 23, '845.01 Medial Lig.(Deltoid) incinmesi'),
(91267, 7524, 23, '845.02 Burkulma, kalkaneal, fibular'),
(91268, 7526, 23, '99212 Yerleşmiş - Komplikasyonsuz'),
(91269, 7527, 23, '99213 Yerleşmiş - düşük karmaşıklıkta'),
(91270, 7528, 23, '< Muayene odasında'),
(91271, 7529, 23, '> Çıkış Yaptı'),
(91272, 7531, 23, '? Gelmedi'),
(91273, 7532, 23, '@ Geldi'),
(91274, 7533, 23, '[Görünümü Değiştir]'),
(91275, 7534, 23, '[Son Görüşme Tarihi]'),
(91276, 7535, 23, '[Son Görüşmeden Beri Gün]'),
(91277, 7536, 23, '[Müstahaklıklar]'),
(91278, 7537, 23, '[Açık Hesapları Dışarı Aktar]'),
(91279, 7538, 23, '[tavsiye edilmiyor]'),
(91280, 7539, 23, '[Görüşme Sayısı]'),
(91281, 7540, 23, '[Raporlar]'),
(91282, 7541, 23, '[Hepsini Seç]'),
(91283, 7542, 23, '[Defter-i Kebir SQL]'),
(91284, 7543, 23, '[Toplu İşlemi Başlat]'),
(91285, 7544, 23, '[Günlüğü Gör]'),
(91286, 7545, 23, '[Yazdırılabilir Raporu Gör]'),
(91287, 7546, 23, '_PC_DUR_HOURS'),
(91288, 7547, 23, '_PC_DUR_MINUTES'),
(91289, 7548, 23, '_PC_LOCALE'),
(91290, 7549, 23, '~ geç geldi.'),
(91291, 1, 24, 'A'),
(91292, 2, 24, 'Numer czeku lub rachunku do identyfikacji płatności'),
(91293, 3, 24, 'Certifikat klienta dla użytkownika administracyjnego'),
(91294, 5, 24, 'Dokument kliniczny w załączeniu.'),
(91295, 7, 24, 'Wymagany jest dystybutor'),
(91296, 8, 24, 'Formularz GCAC powinien być dodany do tej wizyty'),
(91297, 9, 24, 'Wymagany jest numer serii'),
(91298, 10, 24, 'Wymagany jest numer serii!'),
(91299, 11, 24, 'Mała litera'),
(91300, 12, 24, 'Numer'),
(91301, 14, 24, 'Pacjent z tym numerem ID już istnieje'),
(91302, 15, 24, 'Pacjent o tym nazwisku już istnieje'),
(91303, 16, 24, 'Pacjent z tym PESELem istnieje'),
(91304, 18, 24, 'Dodatnia liczba pokaże, że wiele poprzednich spotkań na Widget w pacjencie ekranie Podsumowanie.'),
(91305, 19, 24, 'Źródło skierowania może być określone dla każdej wizyty'),
(91306, 20, 24, 'Wymagany jest odpowiadający kod IPPF!'),
(91307, 21, 24, 'Znak specjalny'),
(91308, 22, 24, 'Unikalna wartość identyfikująca to pole, nie widoczna dla użytkownika'),
(91309, 24, 24, 'przed posiłkiem'),
(91310, 25, 24, 'rano'),
(91311, 26, 24, 'A/F Prawo Level:'),
(91312, 27, 24, 'AB'),
(91313, 28, 24, 'Skrót'),
(91314, 29, 24, 'Ropień:'),
(91315, 30, 24, 'brzuszny'),
(91316, 31, 24, 'Nośne cztery (4) czynności:'),
(91317, 32, 24, 'Abn'),
(91318, 33, 24, 'ABN1'),
(91319, 34, 24, 'Odchylenie'),
(91320, 35, 24, 'Nieprawidłowy wynik badania krwi'),
(91321, 36, 24, 'Nieprawidłowy wzrost włosów'),
(91322, 37, 24, 'Nieprawidłowy wynik badania mammograficznego'),
(91323, 39, 24, 'Aborcja'),
(91324, 40, 24, 'Problemy podczas zabiegu aborcji'),
(91325, 41, 24, 'Metoda aborcji'),
(91326, 42, 24, 'Kategorie związane z aborcją'),
(91327, 43, 24, 'Aborcje'),
(91328, 44, 24, 'O kalendarzu'),
(91329, 46, 24, 'Nieobecności według Diagnozy'),
(91330, 47, 24, 'Zebrane przypisanie'),
(91331, 48, 24, 'Przyjęcie płatności za'),
(91332, 49, 24, 'Przyjęcie płatności za'),
(91333, 50, 24, 'Akceptacja przypisania'),
(91334, 51, 24, 'Kontrola dostępu'),
(91335, 52, 24, 'Administracja kontroli dostępu'),
(91336, 54, 24, 'Dostęp wzbroniony'),
(91337, 55, 24, 'Dostep nie Autoryzowany'),
(91338, 56, 24, 'Dostęp portalu Pacjenta'),
(91339, 59, 24, 'Nazwa konta'),
(91340, 62, 24, 'Księgowość'),
(91341, 64, 24, 'Bóle'),
(91342, 65, 24, 'Potwierdzenie Oczekiwana (ISA14)'),
(91343, 66, 24, 'Podziękowania, licencjonowania i certyfikacji'),
(91344, 67, 24, 'ACL'),
(91345, 68, 24, 'ACL administracja'),
(91346, 69, 24, 'ACL administracja nie Autoryzowany'),
(91347, 71, 24, 'trądzik'),
(91348, 72, 24, 'działać'),
(91349, 73, 24, 'Ustaw Date'),
(91350, 74, 24, 'Działanie'),
(91351, 75, 24, 'Działania'),
(91352, 77, 24, 'aktywować CCR / CCD Sprawozdawczość'),
(91353, 78, 24, 'Aktywny'),
(91354, 79, 24, 'Alarm aktywny'),
(91355, 80, 24, 'Aktywne zasady alarmowania'),
(91356, 81, 24, 'Aktywne alarmy/przypomnienia'),
(91357, 82, 24, 'aktywny napotkać'),
(91358, 84, 24, 'Aktywne listy'),
(91359, 85, 24, 'Aktywni pacjenci'),
(91360, 86, 24, 'Aktywne plany'),
(91361, 87, 24, 'Działalność'),
(91362, 88, 24, 'Rodzaj działalności'),
(91363, 90, 24, 'Ostre zatrucie / Wypłaty'),
(91364, 92, 24, 'Ostre przewlekłe'),
(91365, 93, 24, 'dodaj'),
(91366, 94, 24, 'Dodaj'),
(91367, 95, 24, 'DODAJ'),
(91368, 96, 24, 'Dodaj firmę'),
(91369, 98, 24, 'Dodaj aptekę'),
(91370, 100, 24, 'dodaj zdarzenie dla '),
(91371, 101, 24, 'Dodaj jako nową notatkę'),
(91372, 102, 24, 'Dodaj jako nowy'),
(91373, 104, 24, 'Dodaj przyciski'),
(91374, 105, 24, 'Dodaj przyciski na znaki specjalne, Teksty, które mają być wyświetlane w górnej części edytora o włączenie do tekstu na Click'),
(91375, 106, 24, 'Dodaj kategorię'),
(91376, 107, 24, 'Dodaj stałą'),
(91377, 108, 24, 'Dodaj Kontekst'),
(91378, 109, 24, 'Dodaj współpłatność'),
(91379, 110, 24, 'Dodaj kryteria'),
(91380, 111, 24, 'Dodaj przycisk użytkownika'),
(91381, 112, 24, 'Dodaj diagnozę'),
(91382, 113, 24, 'Dodaj lek'),
(91383, 114, 24, 'Dodaj wizytę'),
(91384, 115, 24, 'Dodaj wizytę/notatki'),
(91385, 116, 24, 'Dodaj ośrodek'),
(91386, 117, 24, 'Dodaj pole'),
(91387, 118, 24, 'Dodaj poniższe wiersze do pliku konfiguracyjnego serwera Apache'),
(91388, 119, 24, 'Dodaj grupę'),
(91389, 120, 24, 'Dodaj kod ICD'),
(91390, 121, 24, 'Dodaj szczepienie'),
(91391, 122, 24, 'Dodaj nie jest upoważniony!'),
(91392, 123, 24, 'Dodaj problem'),
(91393, 125, 24, 'Dodaj język'),
(91394, 126, 24, 'Dodaj nowe'),
(91395, 127, 24, 'Dodaj nowe'),
(91396, 128, 24, 'Dodaj nową kategorię: '),
(91397, 129, 24, 'Dodaj nowe certyfikaty do pliku konfiguracyjnego serwera Apache'),
(91398, 132, 24, 'Dodaj nową grupę'),
(91399, 134, 24, 'Dodaj nowy nr serii i transakcję'),
(91400, 135, 24, 'Dodaj nową notatkę'),
(91401, 136, 24, 'Dodaj nową notatkę'),
(91402, 137, 24, 'Dodaj nowego partnera'),
(91403, 140, 24, 'Dodaj notatkę'),
(91404, 141, 24, 'Dodaj dane pacjenta'),
(91405, 142, 24, 'Dodaj receptę'),
(91406, 143, 24, 'Dodaj Procedura'),
(91407, 144, 24, 'Dodaj numer lekarza'),
(91408, 145, 24, 'Dodaj kurację odwykową'),
(91409, 146, 24, 'Dodaj regułę'),
(91410, 147, 24, 'Dodaj do'),
(91411, 148, 24, 'Dodaj do listy leków'),
(91412, 149, 24, 'Dodaj najwyższy poziom'),
(91413, 150, 24, 'Dodaj transakcję'),
(91414, 151, 24, 'Dodaj użytkownika'),
(91415, 152, 24, 'Dodaj użytkownika do grupy'),
(91416, 153, 24, 'Dodaj/Edytuj eReceptę'),
(91417, 154, 24, 'Dodaj/Edytuj transakcję pacjenta'),
(91418, 155, 24, 'dodano'),
(91419, 156, 24, 'Dodawanie danych demograficznych jest nieautoryzowane.'),
(91420, 158, 24, 'Zespół Addisona'),
(91421, 159, 24, 'Zespół Addisona'),
(91422, 160, 24, 'Dodatkowe atrybuty'),
(91423, 161, 24, 'Dodatkowa diagnoza:'),
(91424, 162, 24, 'Dodatkowa historia'),
(91425, 163, 24, 'Dodatkowe notatki do historii'),
(91426, 164, 24, 'Dodatkowe informacje'),
(91427, 165, 24, 'Dodatkowe badania lab.'),
(91428, 166, 24, 'Dodatkowe notatki'),
(91429, 167, 24, 'Dodatkowe informacje i objaśnienia do tego wyniku lub zalecenia'),
(91430, 168, 24, 'Dodatkowe notatki:'),
(91431, 169, 24, 'Dodatkowe notatki: '),
(91432, 170, 24, 'Dodatkowe notatki dot. RTG:'),
(91433, 171, 24, 'Dodatkowo odpowiada US Pakiet rozszerzający SNOMED mogą być importowane osobno po zainstalowaniu International (English version) SNOMED prasowy'),
(91434, 172, 24, 'tylko dodawanie'),
(91435, 173, 24, 'Książka adresowa'),
(91436, 174, 24, 'Książka adresowa'),
(91437, 175, 24, 'Adres'),
(91438, 178, 24, 'Książka adresowa'),
(91439, 179, 24, 'Wpis w książce adresowej dla instytucji wykonującej tę procedurę'),
(91440, 180, 24, 'Wpis w książce adresowej dla dystrybutora'),
(91441, 181, 24, 'Wpis w książce adresowej dla sprzedawcy'),
(91442, 182, 24, 'Typy książki adresów'),
(91443, 187, 24, 'Adres 1'),
(91444, 188, 24, 'Adres 2'),
(91445, 189, 24, 'ADRESAT'),
(91446, 190, 24, 'przym'),
(91447, 191, 24, 'Kwota przym'),
(91448, 192, 24, 'wyregulować'),
(91449, 193, 24, 'Korekta'),
(91450, 194, 24, 'korekta AMT'),
(91451, 195, 24, 'Przyczyny korekty'),
(91452, 196, 24, 'Wartość ustawienia kodu '),
(91453, 197, 24, 'Korekty'),
(91454, 198, 24, 'Adminitration dostosować'),
(91455, 199, 24, 'Admin'),
(91456, 200, 24, 'Adres e-mail Admina'),
(91457, 201, 24, 'Droga podawania'),
(91458, 202, 24, 'Zarządzane'),
(91459, 203, 24, 'Zarządzane przez'),
(91460, 205, 24, 'podawany Site'),
(91461, 206, 24, 'Administracja'),
(91462, 207, 24, 'Administracja witryny'),
(91463, 208, 24, 'Administratorzy'),
(91464, 209, 24, 'Administratorzy mogą wszystko'),
(91465, 210, 24, 'Przyznaj Data'),
(91466, 212, 24, 'Adult Screening Waga i Uzupełnienie'),
(91467, 213, 24, 'Adult Screening Waga i Uzupełnienie (CQM)'),
(91468, 214, 24, 'Dyrektywa Advance'),
(91469, 215, 24, 'dyrektywy Advance'),
(91470, 216, 24, 'Advance Dyrektywy Ostrzeżenie'),
(91471, 218, 24, 'Zaawansowany'),
(91472, 219, 24, 'Wskazówka'),
(91473, 221, 24, 'wpływać na normalne'),
(91474, 223, 24, 'Wezwania po godzinach'),
(91475, 224, 24, 'Po migracji ze starych mechanizmów hasło gdzie hasła są przechowywane w tabeli użytkowników bez soli jest kompletna, ta flaga powinna być ustawiona na false, aby tylko uwierzytelniania przez nowe metody jest możliwe'),
(91476, 225, 24, 'Po wykonaniu wyżej konfiguracjach, zaimportować certyfikat klienta administratora do przeglądarki i ponowne uruchomienie serwera Apache (puste hasło).'),
(91477, 226, 24, 'Po zapisaniu w formacie PDF, kliknij przycisk [Zobacz Logowanie], aby sprawdzić błędy.'),
(91478, 227, 24, 'Po zapisaniu pliku tekstowym (s), kliknij przycisk [Zobacz Logowanie], aby sprawdzić błędy.'),
(91479, 228, 24, 'Po zapisaniu partii, kliknij przycisk [Zobacz Logowanie], aby sprawdzić błędy.'),
(91480, 230, 24, 'Po informacje są prawidłowo wprowadzone, kliknij przycisk Zapisz.'),
(91481, 232, 24, 'Opieka planowanie'),
(91482, 233, 24, 'Ponownie'),
(91483, 234, 24, 'Wiek'),
(91484, 235, 24, 'Wiek przez'),
(91485, 236, 24, 'Kategoria Wiekowa'),
(91486, 237, 24, 'Dane Wiek jest poza zakresem.'),
(91487, 238, 24, 'Format wyświetlania wieku'),
(91488, 239, 24, 'Format wiek "wieku od" nie jest prawidłowy'),
(91489, 240, 24, 'Format wiek "wieku do" nie jest prawidłowy'),
(91490, 241, 24, 'Wiek od'),
(91491, 242, 24, 'Wiek w latach Zmian formatu wyświetlania'),
(91492, 243, 24, 'Maks. Wiek'),
(91493, 244, 24, 'Min. Wiek'),
(91494, 245, 24, 'Zakres Wieku'),
(91495, 247, 24, 'Kolumny Aging:'),
(91496, 249, 24, 'Albański'),
(91497, 250, 24, 'Alkohol'),
(91498, 251, 24, 'Spożycie alkoholu'),
(91499, 253, 24, 'Liczba alarmów'),
(91500, 255, 24, 'Alarmy'),
(91501, 258, 24, 'Społeczność'),
(91502, 259, 24, 'Wszystko'),
(91503, 260, 24, 'WSZYSTKO'),
(91504, 261, 24, 'Wszystko (Zestawiony format A)'),
(91505, 262, 24, 'Wszystko (Zestawiony format B)'),
(91506, 263, 24, 'Wszystkie (narastająco)'),
(91507, 266, 24, 'Wszystkie kategorie'),
(91508, 268, 24, 'Wszystkie kody'),
(91509, 269, 24, 'Wszystkie dni'),
(91510, 270, 24, 'Wydarzenie całodniowe'),
(91511, 271, 24, 'Wszystkie dane demograficzne, z pola wyszukiwania i powielania czekiem'),
(91512, 272, 24, 'Wszystkie oddziały'),
(91513, 273, 24, 'Wszystkie schorzenia/problemy'),
(91514, 274, 24, 'Wszystkie języki dopuszczone'),
(91515, 276, 24, 'Całość lub część imienia'),
(91516, 277, 24, 'Całość lub część nazwiska'),
(91517, 278, 24, 'Całość lub część organizacji'),
(91518, 280, 24, 'Wszystkie produkty'),
(91519, 281, 24, 'Wszyscy lekarze'),
(91520, 282, 24, 'Wszystkie Korekta i ujemne:'),
(91521, 283, 24, 'Wszystkie tematy'),
(91522, 284, 24, 'Wszyscy użytkownicy'),
(91523, 285, 24, 'Uczulony/a'),
(91524, 286, 24, 'Alergie'),
(91525, 287, 24, 'Alergie:'),
(91526, 288, 24, 'Alergia'),
(91527, 289, 24, 'Import Allergy pomyślnie'),
(91528, 291, 24, 'Reakcja alergiczna'),
(91529, 294, 24, 'Przeznaczyć'),
(91530, 295, 24, 'Pozwól'),
(91531, 296, 24, 'Pozwól, aby wszystkie dostępne języki były dostępne dla użytkownika podczas logowania.'),
(91532, 297, 24, 'Umożliwić tworzenie roszczeń zawierających diagnozę, ale nie procedury i opłaty. Większość klinik nie chcą tego.'),
(91533, 298, 24, 'Pozwól Debugowanie język'),
(91534, 299, 24, 'Pozwól na wiadomości email'),
(91535, 300, 24, 'Pozwalasz na wiadomości email?'),
(91536, 301, 24, 'Pozwalasz na email?'),
(91537, 302, 24, 'Pozwól Encounter roszczeń'),
(91538, 303, 24, 'Umożliwienie wymiany informacji zdrowotnej'),
(91539, 304, 24, 'Zezwala na dostępnianie informacji o szczepieniach'),
(91540, 305, 24, 'Zezwala na wykorzystanie rejestru szczepień'),
(91541, 306, 24, 'Pozwól na wiadomości pocztowe'),
(91542, 308, 24, 'Włącz dostęp do portalu pacjenta'),
(91543, 309, 24, 'Pozwól na SMSy'),
(91544, 310, 24, 'Pozwalasz na wiadomości tekstowe SMS?'),
(91545, 311, 24, 'Pozwól złożone zdarzenia do uaktywnione natychmiast?'),
(91546, 312, 24, 'Zgadzasz się na kontakt telefoniczny?'),
(91547, 313, 24, 'Pozwól użytkownikom publikować wydarzenia globalne'),
(91548, 314, 24, 'Pozwól użytkownikom publikować kalendarze osobiste'),
(91549, 315, 24, 'Zgoda na wiadomości głosowe'),
(91550, 316, 24, 'Dopuszczalne'),
(91551, 317, 24, 'Dopuszczalne języki'),
(91552, 318, 24, 'Dozwolony(c)'),
(91553, 323, 24, 'już istnieje'),
(91554, 324, 24, 'już istnieje.'),
(91555, 325, 24, 'Jest już w użyciu - wybierz inny identyfikator'),
(91556, 326, 24, 'Jest już w użyciu - wybierz inny tytuł'),
(91557, 327, 24, 'Adres alternatywny'),
(91558, 328, 24, 'zmień'),
(91559, 329, 24, 'Alternatywnie, można użyć strony wyszukiwania, aby przesłać elektroniczny przelewu (X12 835) pliku, które zostały otrzymane od zleceniodawcy lub Clearinghouse. Można to zrobić, klikając przycisk Przeglądaj i wybrać plik który chcesz przesłać, a następnie kliknij Wyszukiwanie Aby przesłać plik i wyświetlić odpowiednie faktury. W tym przypadku pozostałe parametry wymienione powyżej, a nie stosuje się jest ignorowany. Przesyłanie zapisuje plik, ale jeszcze nie przetwarza zawartość - który sporządzono oddzielnie, jak opisano poniżej.'),
(91560, 330, 24, 'AM'),
(91561, 331, 24, 'Program AM'),
(91562, 332, 24, 'AMC'),
(91563, 333, 24, 'AMC Tracking'),
(91564, 338, 24, 'Zmiany istniejącego listu'),
(91565, 343, 24, 'Amerykanin indyjski'),
(91566, 344, 24, 'Amerykanin indyjski i Alaska tubylec'),
(91567, 345, 24, 'AMEX'),
(91568, 346, 24, 'amharski'),
(91569, 347, 24, 'Kwota'),
(91570, 348, 24, 'ilość podawana'),
(91571, 349, 24, 'Opłaty wynoszą'),
(91572, 350, 24, 'Należność za wcześniejsze usługi'),
(91573, 351, 24, 'Należność za bieżącą wizytę'),
(91574, 352, 24, 'Kwota wpłacona'),
(91575, 353, 24, 'Kwota:'),
(91576, 354, 24, 'Kwota zapowiadane'),
(91577, 355, 24, 'Dla zdarzeń cyklicznych wymagane jest podanie daty zakończenia późniejszej od daty rozpoczęcia!'),
(91578, 357, 24, 'Wystąpił błąd podczas dumpingu internetowej LibreEHR drzewo katalogów'),
(91579, 358, 24, 'Wystąpił błąd podczas dumpingu phpGACL drzewo katalogów internetowych'),
(91580, 359, 24, 'Wystąpił błąd podczas dumpingu SQL-Ledger drzewo katalogów internetowych'),
(91581, 360, 24, 'Niepełne GCAC problem został stworzony i powiązane. Ktoś będzie musiał wypełnić później.'),
(91582, 362, 24, 'Nieoczekiwany błąd.'),
(91583, 363, 24, 'Wielka litera'),
(91584, 365, 24, 'i'),
(91585, 366, 24, 'I'),
(91586, 367, 24, 'i'),
(91587, 368, 24, 'i '),
(91588, 369, 24, 'i wszystkie podległe dane? Akcja będzie się zalogować'),
(91589, 370, 24, 'i modyfikator'),
(91590, 371, 24, 'i przetwarzane.'),
(91591, 372, 24, 'i zrestartuj serwer Apache.'),
(91592, 373, 24, 'a przyczyną jest'),
(91593, 374, 24, 'Anemia'),
(91594, 375, 24, 'Kostka'),
(91595, 376, 24, 'Kostka + pięta'),
(91596, 377, 24, 'Formularz oceny kostki'),
(91597, 378, 24, 'Problemy z kostką'),
(91598, 379, 24, 'Zesztywniające zapalenie stawów kręgosłupa'),
(91599, 380, 24, 'Zesztywniające zapalenie stawów kręgosłupa'),
(91600, 381, 24, 'Anoreksja'),
(91601, 382, 24, 'Inną rzeczą, jaką możesz zrobić, w oknie wysyłania żądania jest wtórna rozliczeniowych. W przypadku wybrania tej opcji przed zapisaniem, a następnie powództwo zostanie ponownie otwarty i kolejki na stronie płatności, i będą przetwarzane w następnym okresie rozliczeniowym.'),
(91602, 383, 24, 'przed'),
(91603, 384, 24, 'Anus nl, no odbytnicy tkliwość / masa'),
(91604, 385, 24, 'Niepokój'),
(91605, 386, 24, 'Dowolna'),
(91606, 387, 24, 'Dowolna kategoria'),
(91607, 388, 24, 'Którakolwiek część kodu lub jego opisu'),
(91608, 389, 24, 'Którakolwiek część nazwy specjalności'),
(91609, 390, 24, 'Którakolwiek część identyfikatora lub nazwy leku'),
(91610, 391, 24, 'Którakolwiek część identyfikatora lub nazwy szczepienia'),
(91611, 392, 24, 'Każda część nazwisko pacjenta, lub  "nazwisko, imię " lub  "XY "'),
(91612, 393, 24, 'Wszelkie inne istotne informacje'),
(91613, 394, 24, 'Klucz API do bramki SMS.'),
(91614, 395, 24, 'Bezdech'),
(91615, 396, 24, 'Wygląd'),
(91616, 397, 24, 'Wygląd.'),
(91617, 398, 24, 'Dodaj tę notatkę'),
(91618, 399, 24, 'Dodaj do istniejącej nototki'),
(91619, 400, 24, 'Dodaj do tej notatki'),
(91620, 401, 24, 'Dodaj do tej notatki'),
(91621, 402, 24, 'Appendektomia'),
(91622, 404, 24, 'Obowiązujące Pacjenci'),
(91623, 405, 24, 'Aplikacja'),
(91624, 406, 24, 'Nazwa aplikacji dla strony logowania i głównego tytułu okna.'),
(91625, 407, 24, 'Kod Receiver Aplikacja (GS03 - Jeśli puste ISA08 będą używane)'),
(91626, 408, 24, 'Zastosowanie Sender Code (GS02)'),
(91627, 409, 24, 'Tytuł aplikacji'),
(91628, 410, 24, 'Dotyczy postaci narządy i wykres wzrostu'),
(91629, 412, 24, 'Zastosuj zmiany do obecnego przypadku jedynie do tego i wszystkich zdarzeń przyszłych, lub do wszystkich wystąpień?'),
(91630, 413, 24, 'stosuje się do danego obszaru'),
(91631, 414, 24, 'stosować na skórę'),
(91632, 415, 24, 'Stosowanie'),
(91633, 416, 24, 'Zastosowaniu poprawki na miejscu'),
(91634, 417, 24, 'Wizyta'),
(91635, 418, 24, 'Data wizyty'),
(91636, 419, 24, 'Styl wyświetlania wizyt'),
(91637, 420, 24, 'Zasady przypominani o wizytach'),
(91638, 421, 24, 'Status wizyty'),
(91639, 422, 24, 'Statusy wizyt'),
(91640, 423, 24, 'Powołanie w ramach'),
(91641, 424, 24, 'Powołanie / Wydarzenie Kolor'),
(91642, 425, 24, 'Wizyty'),
(91643, 426, 24, 'Nominacje (zapis opcjonalny)'),
(91644, 427, 24, 'Nominacje (pisać wsome opcjonalnie)'),
(91645, 430, 24, 'Nominacje i napotyka'),
(91646, 431, 24, 'Raport wizyt'),
(91647, 432, 24, 'Nominacje-Encounters Zgłoś'),
(91648, 434, 24, 'Zatwierdź'),
(91649, 436, 24, 'Zatwierdzono'),
(91650, 437, 24, 'Zatwierdzony Administracja Wydarzenia'),
(91651, 441, 24, 'Nominacje'),
(91652, 442, 24, 'Kwi'),
(91653, 443, 24, 'Kwiecień'),
(91654, 444, 24, 'Arabski'),
(91655, 446, 24, 'Archiwum'),
(91656, 447, 24, 'Czy nazwy grup kontroli dostępu mają być tłumaczone?'),
(91657, 448, 24, 'Czy nazwy kategorii wizyt mają być tłumaczone?'),
(91658, 449, 24, 'Czy nazwy kategorii dokumentów mają być tłumaczone?'),
(91659, 450, 24, 'Czy dla tego typu stosuje się opłaty?');
INSERT INTO `lang_definitions` VALUES
(91660, 451, 24, 'Czy nagłówki notatek o pacjencie mają być tłumaczone?'),
(91661, 452, 24, 'Kody są przechowywane w zewnętrznych tabel SQL (0-nie, 1-ICD10, 2-SNOMED (RF1), 3-SNOMED (RF2))?'),
(91662, 453, 24, 'Czy jesteś gotowy, aby zakończyć nową GCAC problem dla tej wizyty?'),
(91663, 454, 24, 'Czy na pewno chcesz umieścić na dziś?'),
(91664, 455, 24, 'Czy na pewno chcesz zatwierdzić tezę wydarzenia?'),
(91665, 457, 24, 'Czy jesteś pewien, że chcesz, aby całkowicie usunąć ten formularz?'),
(91666, 459, 24, 'Czy na pewno chcesz usunąć ten ujawnienia?'),
(91667, 460, 24, 'Czy na pewno chcesz usunąć to wydarzenie?'),
(91668, 461, 24, 'Czy na pewno chcesz usunąć ten element z bazy danych?'),
(91669, 462, 24, 'Czy na pewno chcesz skasować tę notatkę?'),
(91670, 464, 24, 'Czy na pewno chcesz edytować wydarzenia dyplomowych?'),
(91671, 465, 24, 'Czy na pewno chcesz ukryć wydarzenia dyplomowych?'),
(91672, 467, 24, 'Czy na pewno chcesz, aby tezy wydarzeń?'),
(91673, 468, 24, 'Czy jesteś pewien, że chcesz usunąć całą grupę o nazwie'),
(91674, 469, 24, 'Czy na pewno chcesz usunąć całą listę'),
(91675, 470, 24, 'Czy na pewno chcesz usunąć w polu'),
(91676, 471, 24, 'Czy na pewno chcesz usunąć wybrane pola?'),
(91677, 472, 24, 'Jesteś pewien, że  ''d chcesz kontynuować pracy działań?'),
(91678, 473, 24, 'Powierzchnia nie określono'),
(91679, 474, 24, 'Ramię'),
(91680, 475, 24, 'armeński'),
(91681, 477, 24, 'Arytmia'),
(91682, 478, 24, 'Artretyzm'),
(91683, 479, 24, 'Arthritis / joint miecz diseas'),
(91684, 480, 24, 'Arthritis / joint miecz choroba'),
(91685, 481, 24, 'oś'),
(91686, 482, 24, 'Ashes Of'),
(91687, 484, 24, 'Asian'),
(91688, 487, 24, 'Przewidywane'),
(91689, 488, 24, 'Przypisany do'),
(91690, 489, 24, 'Asystent'),
(91691, 490, 24, 'Astma'),
(91692, 491, 24, 'w'),
(91693, 492, 24, 'Co najmniej jeden parametr wyszukiwania jest wymagana, jeśli wybierz Wszystkie.'),
(91694, 493, 24, 'Na trzeszczki'),
(91695, 494, 24, 'Na trzeszczki:'),
(91696, 495, 24, 'Athletic zespół'),
(91697, 496, 24, 'Athletic Zespół'),
(91698, 497, 24, 'Athletic / Uraz'),
(91699, 498, 24, 'Atna audytu certyfikat CA'),
(91700, 499, 24, 'Atna Audit gospodarz'),
(91701, 500, 24, 'Atna lokalnego audytora'),
(91702, 501, 24, 'Postage audytu Atna'),
(91703, 503, 24, 'Uwaga'),
(91704, 504, 24, 'Wiadomości'),
(91705, 506, 24, 'Silnik zapyta Adit CDR'),
(91706, 509, 24, 'Kopie Rejestrowanie inspekcji'),
(91707, 510, 24, 'Audyt rejestrowanie Różne'),
(91708, 511, 24, 'Audyt rejestrowanie utworu'),
(91709, 512, 24, 'Audyt rejestrowanie Rekord Pacjenta'),
(91710, 513, 24, 'Audyt rejestrowanie planowanie'),
(91711, 514, 24, 'Audyt rejestrowanie bezpieczeństwo administracja'),
(91712, 515, 24, 'Audyt rejestrowanie SELECT Query'),
(91713, 516, 24, 'Sie'),
(91714, 517, 24, 'Sierpień'),
(91715, 519, 24, 'Autoryzuj'),
(91716, 520, 24, 'Zezwoleń / uwagi'),
(91717, 523, 24, 'grupa autoryzacji'),
(91718, 524, 24, 'Stan autoryzacji'),
(91719, 525, 24, 'Zezwolenia'),
(91720, 526, 24, 'autoryzować'),
(91721, 527, 24, 'Autoryzacja - żadnych spotkań'),
(91722, 528, 24, 'Autoryzacja - Moje spotkania'),
(91723, 529, 24, 'Authorize.net'),
(91724, 530, 24, 'upoważniony'),
(91725, 531, 24, 'dozwolone jedynie'),
(91726, 532, 24, 'Auto Wyślij'),
(91727, 535, 24, 'Auto-Tworzenie nowych spotkań'),
(91728, 536, 24, 'Wygenerowane automatycznie'),
(91729, 537, 24, 'Automatyczne obliczenia środka (AMC)'),
(91730, 542, 24, 'Automatyczne obliczenia środka (AMC) Tracking'),
(91731, 543, 24, 'Zautomatyzowane Środki (AMC)'),
(91732, 544, 24, 'automatyczny'),
(91733, 546, 24, 'Automatycznie utworzy nowy termin spotkania, gdy status jest ustawiony na "@" (przyjechaliśmy).'),
(91734, 549, 24, 'Automobile Medyczny'),
(91735, 550, 24, 'zapisane automatycznie'),
(91736, 551, 24, 'dostępne kategorie'),
(91737, 552, 24, 'dostępne przedziały'),
(91738, 557, 24, 'Średnia miesięczna'),
(91739, 558, 24, 'Oderwanie / złamanie avulsion'),
(91740, 559, 24, 'Oderwanie kostki bocznej'),
(91741, 560, 24, 'Oderwanie przyśrodkowej malleolus '),
(91742, 561, 24, 'Świadomość-Based'),
(91743, 562, 24, 'pachowy'),
(91744, 565, 24, 'Notka Informacji i Dokumentacji'),
(91745, 566, 24, 'z powrotem'),
(91746, 567, 24, 'z powrotem'),
(91747, 568, 24, 'Powrót osiem wizyt'),
(91748, 569, 24, 'Powrót jedenaście wizyt'),
(91749, 570, 24, 'Powrót pięciu wizyt'),
(91750, 571, 24, 'Powrót cztery wizyty'),
(91751, 572, 24, 'Powrót dziewięć wizyt'),
(91752, 573, 24, 'Powrót jedna wizyta'),
(91753, 574, 24, 'z powrotem ból'),
(91754, 575, 24, 'Powrót Problemy'),
(91755, 576, 24, 'Powrót siedem wizyt'),
(91756, 577, 24, 'Powrót sześciu wizyt'),
(91757, 578, 24, 'operacji kręgosłupa'),
(91758, 579, 24, 'Powrót dziesięć wizyt'),
(91759, 580, 24, 'Powrót trzy wizyty'),
(91760, 581, 24, 'Powrót do strony Admin'),
(91761, 584, 24, 'Powrót do pacjenta'),
(91762, 585, 24, 'Powrót do użytkowników'),
(91763, 586, 24, 'Powrót do'),
(91764, 587, 24, 'Powrót dwanaście wizyt'),
(91765, 588, 24, 'Powrót dwie wizyty'),
(91766, 589, 24, 'tło Services'),
(91767, 590, 24, 'Tworzenie kopii zapasowych'),
(91768, 591, 24, 'Plik kopii zapasowej został utworzony. Będzie teraz wysyłać pobieranie.'),
(91769, 593, 24, 'BackUp powodzeniem podjęte w'),
(91770, 594, 24, 'Zła kontrola'),
(91771, 595, 24, 'złych długów'),
(91772, 596, 24, 'indonezyjski'),
(91773, 597, 24, 'Bal'),
(91774, 598, 24, 'Saldo'),
(91775, 599, 24, 'równoważyć'),
(91776, 600, 24, 'bilans Amt'),
(91777, 601, 24, 'Saldo należności'),
(91778, 603, 24, 'Weksle'),
(91779, 607, 24, 'Baza 5-cie (5.) Metarsal'),
(91780, 608, 24, 'Baza piątego (5.) Metarsal:'),
(91781, 611, 24, 'Roszczenie partia'),
(91782, 612, 24, 'Narzędzie komunikacji Batch'),
(91783, 613, 24, 'Wejście Płatność Batch'),
(91784, 614, 24, 'Płatności wsadowe'),
(91785, 615, 24, 'Przetwarzanie wsadowe rozpocząć; może to trochę potrwać.'),
(91786, 616, 24, 'Wyniki grupowe'),
(91787, 617, 24, 'BatchCom'),
(91788, 619, 24, 'bo id nie istnieje.'),
(91789, 620, 24, 'Początek'),
(91790, 621, 24, 'Rozpocznij od'),
(91791, 623, 24, 'Począwszy od daty doręczenia yyyy-mm-dd'),
(91792, 624, 24, 'Począwszy godzinę dzień imprez kalendarzowych.'),
(91793, 626, 24, 'odbijanie'),
(91794, 628, 24, 'bengalski'),
(91795, 630, 24, 'między'),
(91796, 633, 24, 'dwustronny'),
(91797, 634, 24, 'Dwustronna:'),
(91798, 636, 24, 'Data Bill:'),
(91799, 637, 24, 'Bill / Collect'),
(91800, 638, 24, 'Rozliczone'),
(91801, 640, 24, 'Rozliczenie'),
(91802, 641, 24, 'Billing (zapis opcjonalny)'),
(91803, 642, 24, 'Attn Billing'),
(91804, 644, 24, 'Kod rozliczeniowy dla żądanej usługi'),
(91805, 645, 24, 'kody bilingowe'),
(91806, 646, 24, 'Dane rozliczeniowe'),
(91807, 647, 24, 'Billing Department'),
(91808, 648, 24, 'Rozliczający'),
(91809, 649, 24, 'Informacje o płatności'),
(91810, 650, 24, 'Lokalizacja Billing'),
(91811, 655, 24, 'Menedżer Billing'),
(91812, 656, 24, 'Rozliczenie - uwagi'),
(91813, 657, 24, 'Uwaga rozliczeniowego dla '),
(91814, 658, 24, 'Uwaga rozliczeniowe:'),
(91815, 659, 24, 'Wyniki kolejki rozliczeniowe:'),
(91816, 660, 24, 'Zgłoś Billing'),
(91817, 661, 24, 'Stan Billing'),
(91818, 662, 24, 'Stan Billing = Unbilled'),
(91819, 663, 24, 'rozliczeniowych na '),
(91820, 665, 24, 'biopsja'),
(91821, 666, 24, 'Data urodzenia'),
(91822, 667, 24, 'Narodziny-24 miesięcy'),
(91823, 669, 24, 'czarny'),
(91824, 670, 24, 'czarny Lung'),
(91825, 671, 24, 'Czarny lub Afroamerykanin'),
(91826, 672, 24, 'Rak pęcherza moczowego'),
(91827, 673, 24, 'Zakażenia pęcherza'),
(91828, 674, 24, 'Puste formularze'),
(91829, 675, 24, 'krwawienia'),
(91830, 676, 24, 'martwego pola'),
(91831, 677, 24, 'wzdęcia'),
(91832, 678, 24, 'zablokowany'),
(91833, 679, 24, 'krew'),
(91834, 680, 24, 'Ciśnienie Krwi'),
(91835, 681, 24, 'Ciśnienie krwi'),
(91836, 682, 24, 'Krwawy nos'),
(91837, 683, 24, 'Niebieski krzyż niebieski tarcza'),
(91838, 684, 24, 'Niebieskie linie w tym raporcie są informacyjne. Czarne linie wskazują wcześniej istniejących informacji. Zielone linie pokazują zmiany, które zostały z powodzeniem zastosowane. Czerwone linie wskazują błędy, lub zmiany, które nie zostały zastosowane; te muszą być przetwarzane ręcznie. Obecnie zaprzeczył twierdzeniom i cofnięte płatności nie są obsługiwane automatycznie i tak pojawi się w kolorze czerwonym.'),
(91839, 685, 24, 'niewyraźne widzenie'),
(91840, 686, 24, 'BMI'),
(91841, 687, 24, 'Stan BMI'),
(91842, 689, 24, 'Region ciała'),
(91843, 690, 24, 'strony ciała'),
(91844, 691, 24, 'Strona ciała, jeśli dotyczy'),
(91845, 692, 24, 'Tenderness Bone:'),
(91846, 693, 24, 'Tenderness Bone: Medial kostki'),
(91847, 694, 24, 'Boolean'),
(91848, 696, 24, 'Dół'),
(91849, 697, 24, 'obu uszach'),
(91850, 698, 24, 'oboje uszu'),
(91851, 699, 24, 'dolny'),
(91852, 701, 24, 'BOX 10 Zatrudnienie związane A. '),
(91853, 702, 24, 'BOX 10 Accident Auto B. '),
(91854, 703, 24, 'BOX 10 C. Pozostałe Accident '),
(91855, 706, 24, 'BOX 15. Data choroby sam lub podobny (rrrr-mm-dd):'),
(91856, 708, 24, 'BOX 16. Data niezdolny do pracy od (rrrr-mm-dd):'),
(91857, 709, 24, 'BOX 16. Data niezdolny do pracy do (rrrr-mm-dd):'),
(91858, 710, 24, 'BOX 18. Hospitalizacja z data (rrrr-mm-dd): '),
(91859, 711, 24, 'BOX 18. Data Hospitalizacja do (rrrr-mm-dd): '),
(91860, 712, 24, 'BOX 20. Jest poza Lab wykorzystywane?'),
(91861, 713, 24, 'BOX 22. Kod ponownego Medicaid (ICD-9) '),
(91862, 714, 24, 'BOX 23. Przed Nr Authorization '),
(91863, 715, 24, 'BP'),
(91864, 716, 24, 'rozkurczowego'),
(91865, 717, 24, 'BP skurczowe'),
(91866, 719, 24, 'baryłek dziennie'),
(91867, 721, 24, 'bps'),
(91868, 722, 24, 'portugalski brazylijski'),
(91869, 723, 24, 'pierś'),
(91870, 724, 24, 'Biopsja piersi'),
(91871, 725, 24, 'Absolutorium piersi'),
(91872, 726, 24, 'choroby piersi'),
(91873, 727, 24, 'Egzamin piersi'),
(91874, 728, 24, 'Mass piersi'),
(91875, 730, 24, 'Brzmienie oddech:'),
(91876, 732, 24, 'broken Bones'),
(91877, 734, 24, 'Formularz oskrzeli'),
(91878, 735, 24, 'Znajdź'),
(91879, 736, 24, 'Poszukaj Record'),
(91880, 737, 24, 'Siniaki / krwiak'),
(91881, 739, 24, 'Wybrzuszenia prawo:'),
(91882, 741, 24, 'Pieczenie przy oddawaniu moczu'),
(91883, 742, 24, 'Pieczenie przy oddawaniu moczu'),
(91884, 744, 24, 'zajęty'),
(91885, 745, 24, 'ale jeszcze nie przetworzone.'),
(91886, 746, 24, 'pośladek'),
(91887, 747, 24, 'Pośladków + S.I.'),
(91888, 748, 24, 'przez'),
(91889, 749, 24, 'Przez'),
(91890, 750, 24, 'doustnie'),
(91891, 751, 24, 'Autor / Źródło'),
(91892, 752, 24, 'przez:'),
(91893, 753, 24, 'C'),
(91894, 754, 24, 'CA Certificate for verifying the RFC 5425 TLS syslog server.'),
(91895, 755, 24, 'Żywotność pamięci podręcznej (w sekundach)'),
(91896, 756, 24, 'Wyjściowy szablon cache?'),
(91897, 757, 24, 'Spożycie kawy'),
(91898, 758, 24, 'Kalendarz'),
(91899, 759, 24, 'Końcowa Godzina Kalendarza'),
(91900, 760, 24, 'Interwał Kalendarza'),
(91901, 761, 24, 'Ekran Kalendarza'),
(91902, 762, 24, 'Ustawienia Kalendarza'),
(91903, 763, 24, 'Początkowa Godzina Kalendarza'),
(91904, 764, 24, 'Kalendarz UI'),
(91905, 765, 24, 'Podgląd Kalendarza'),
(91906, 766, 24, 'Zadzwoń do addForm () idzie tutaj. Katowice'),
(91907, 767, 24, 'Kalorie'),
(91908, 768, 24, 'Kambodży'),
(91909, 769, 24, 'Camós'),
(91910, 774, 24, 'Anuluj'),
(91911, 775, 24, 'Anuluj zmiany'),
(91912, 776, 24, 'Anulowane'),
(91913, 777, 24, 'Rak'),
(91914, 778, 24, 'Screening Rak Cancer Screening Colon'),
(91915, 779, 24, 'Przesiewowych w kierunku raka: Mammografia'),
(91916, 780, 24, 'Przesiewowych w kierunku raka: Pap Smear'),
(91917, 781, 24, 'Przesiewowych w kierunku raka: Prostate Cancer Screening'),
(91918, 782, 24, 'Nie można dodać ten wpis, ponieważ już istnieje!'),
(91919, 783, 24, 'Nie można dodać / zaktualizować ten wpis bo duplikat już istnieje!'),
(91920, 784, 24, 'nie mogą być archiwizowane, ignorowane'),
(91921, 785, 24, 'nie mogą być konwertowane do formatu JPEG. Być może nie jest zainstalowany ImageMagick?'),
(91922, 786, 24, 'nie mogą być usunięte, zignorowane'),
(91923, 787, 24, 'nie może zostać wyświetlony, ponieważ jej typ inline nie jest obsługiwany przez przeglądarkę.'),
(91924, 788, 24, 'nie może być wyświetlany inline becuase jego typ nie jest obsługiwany przez przeglądarkę'),
(91925, 789, 24, 'nie może być wyświetlany inline becuase jego typ nie jest obsługiwany przez przeglądarkę.'),
(91926, 790, 24, 'Nie można utworzyć'),
(91927, 795, 24, 'Nie można znaleźć '),
(91928, 796, 24, 'Nie można odnaleźć pliku docelowego'),
(91929, 799, 24, 'Nie można znaleźć pacjenta z SQL-Ledger ID klienta'),
(91930, 800, 24, 'Nie można znaleźć odniesienie dokumentu PostScript w '),
(91931, 801, 24, 'Nie można znaleźć dostawcę z SQL-Ledger pracownika = '),
(91932, 802, 24, 'Nie można modyfikować Payments.Undistributed jest ujemna.'),
(91933, 803, 24, 'Nie można otworzyć '),
(91934, 804, 24, 'Nie może post dla Insurance.The Płacenie Podmiot wybrany jest cierpliwy.'),
(91935, 805, 24, 'Nie może post dla Patient.The Płatniczej wybranego podmiotu jest ubezpieczenie.'),
(91936, 806, 24, 'Nie można Opublikuj Payments.Undistributed jest ujemna.'),
(91937, 807, 24, 'Nie można odczytać'),
(91938, 808, 24, 'Nie można odczytać katalogu'),
(91939, 809, 24, 'Nie można zaktualizować, ponieważ nie jesteś edycji istniejącego wpisu!'),
(91940, 810, 24, 'kapitalizować'),
(91941, 812, 24, 'kapsułka'),
(91942, 813, 24, 'karta'),
(91943, 814, 24, 'Cewnikowanie serca'),
(91944, 815, 24, 'Echo serca'),
(91945, 816, 24, 'Cardiovascular'),
(91946, 821, 24, 'Chrząstka / chrzęstnych / disc szkoda'),
(91947, 822, 24, 'uszkodzenie chrząstki'),
(91948, 823, 24, 'Cartoid pulsacje nl, nl pedał impulsy'),
(91949, 824, 24, 'gotówka'),
(91950, 825, 24, 'gotówka'),
(91951, 826, 24, 'Rec Pobranie'),
(91952, 827, 24, 'Wpływy gotówkowe przez Dostawcę'),
(91953, 829, 24, 'operacji zaćmy'),
(91954, 830, 24, 'zaćma'),
(91955, 831, 24, 'Kategorie'),
(91956, 832, 24, 'Kategorie dla'),
(91957, 833, 24, 'Kategoria'),
(91958, 834, 24, 'kategoria'),
(91959, 835, 24, 'Kategoria '),
(91960, 836, 24, 'Szczegóły Kategoria'),
(91961, 837, 24, 'Kategoria Limits'),
(91962, 838, 24, 'Nazwa kategorii'),
(91963, 839, 24, 'Nazwa kategorii jest pusta'),
(91964, 840, 24, 'Kategoria / Nazwa'),
(91965, 841, 24, 'Kaukaski'),
(91966, 842, 24, 'Powoduje Wpływy Drukowanie Encounter / Primary Info Provider'),
(91967, 850, 24, 'CDR'),
(91968, 851, 24, 'Raporty priorytetu przetwarzania CDR'),
(91969, 852, 24, 'komórka'),
(91970, 853, 24, 'cell Phone'),
(91971, 855, 24, 'Numer telefonu komórkowego'),
(91972, 856, 24, 'Central Certyfikacja'),
(91973, 857, 24, 'Central / South American'),
(91974, 858, 24, 'Certificate Authority lokalizacja pliku crt nie może być pusty'),
(91975, 859, 24, 'Certificate Authority klucz lokalizacja pliku nie może być pusty'),
(91976, 860, 24, 'Certyfikat wysłać do RFC 5425 serwer TLS syslog.'),
(91977, 861, 24, 'Certyfikat użytkownika'),
(91978, 862, 24, 'Certyfikaty'),
(91979, 864, 24, 'ChampUS'),
(91980, 865, 24, 'ChampUSVA'),
(91981, 866, 24, 'zmiana'),
(91982, 867, 24, 'zmiana'),
(91983, 868, 24, 'Zmiana aktywności'),
(91984, 869, 24, 'Zmiana nie powiodło się! CouchDB połączyć błąd?'),
(91985, 870, 24, 'Zmiana w Vision'),
(91986, 871, 24, 'Zmiana w wizji'),
(91987, 872, 24, 'Zmień hasło'),
(91988, 874, 24, 'Zmieniono'),
(91989, 875, 24, 'Zmieniono jelita'),
(91990, 876, 24, 'Zmiana ID pacjenta do dokumentu'),
(91991, 877, 24, 'Charakterystyka'),
(91992, 878, 24, 'Pozostało znaków'),
(91993, 879, 24, 'opłata'),
(91994, 880, 24, 'regulacja ładowania'),
(91995, 881, 24, 'Naładuj Coded'),
(91996, 882, 24, 'opłaty'),
(91997, 883, 24, 'Wykres'),
(91998, 884, 24, 'aktywny Wykres'),
(91999, 885, 24, 'Doba Zgłoś Wykres Aktywność'),
(92000, 886, 24, 'Wykres ID'),
(92001, 887, 24, 'Wykres ID:'),
(92002, 889, 24, 'Działalność Chart'),
(92003, 890, 24, 'Wykres Note'),
(92004, 891, 24, 'Numer Chart'),
(92005, 892, 24, 'Miejsc składowania Wykres'),
(92006, 893, 24, 'Wykres Tracker'),
(92007, 894, 24, 'Wykres Trk'),
(92008, 895, 24, 'Wykresy Wyewidencjonowane'),
(92009, 896, 24, 'wykresy Out'),
(92010, 898, 24, 'sprawdzać'),
(92011, 899, 24, 'sprawdzać'),
(92012, 900, 24, 'Zaznacz wszystko'),
(92013, 902, 24, 'sprawdzić ilość'),
(92014, 903, 24, 'sprawdzić datę'),
(92015, 904, 24, 'Sprawdź różnice w tłumaczeniach z niestandardowej tabeli językowej.'),
(92016, 906, 24, 'Zamelduj się, aby'),
(92017, 907, 24, 'Sprawdź dane wejściowe'),
(92018, 909, 24, 'Sprawdź wyniki laboratoryjne'),
(92019, 910, 24, 'Sprawdź oznaczenie wskazuje recenzja'),
(92020, 911, 24, 'Sprawdź nr'),
(92021, 912, 24, 'Sprawdź numer'),
(92022, 915, 24, 'czek'),
(92023, 916, 24, 'Zaznacz pole wyboru, jeśli jest to zaszyfrowany plik'),
(92024, 917, 24, 'Sprawdź to, jeśli chcesz dostawców, aby zobaczyć wszystkie terminy domyślnie i nie tylko ich własne.'),
(92025, 918, 24, 'Sprawdź się stworzyć problem z tą diagnozą'),
(92026, 919, 24, 'Sprawdź / EOB Data:'),
(92027, 920, 24, 'Sprawdź / EOB nr:'),
(92028, 921, 24, 'Sprawdź / Ref Number'),
(92029, 922, 24, 'Sprawdź / Numer'),
(92030, 923, 24, 'lista wyboru'),
(92031, 924, 24, 'lista wyboru'),
(92032, 925, 24, 'w pole / text'),
(92033, 926, 24, 'W Checkbox / text'),
(92034, 928, 24, 'sprawdzone'),
(92035, 929, 24, 'Sprawdzone box = tak, puste = nie'),
(92036, 932, 24, 'Zamówienie'),
(92037, 933, 24, 'kontrolna'),
(92038, 934, 24, 'pierś'),
(92039, 935, 24, 'CTAB Chest'),
(92040, 936, 24, 'Ból w klatce piersiowej'),
(92041, 937, 24, 'Ból w klatce piersiowej:'),
(92042, 938, 24, 'Bóle w klatce piersiowej'),
(92043, 940, 24, 'Zm.'),
(92044, 942, 24, 'Chief Reklamacja'),
(92045, 943, 24, 'dziecko'),
(92046, 945, 24, 'Stan szczepień dla dzieci (CQM)'),
(92047, 946, 24, 'dreszcze'),
(92048, 947, 24, 'chiński'),
(92049, 948, 24, 'Chiński (uproszczony)'),
(92050, 949, 24, 'Chiński (tradycyjny)'),
(92051, 951, 24, 'Zgody/wybory'),
(92052, 952, 24, 'cholecystektomia'),
(92053, 954, 24, 'Cholecystestomy'),
(92054, 955, 24, 'Wybierz'),
(92055, 956, 24, 'Wybierz sekcję i kliknij element w nim, a następnie w drugiej części zobaczysz związane z nim pozycje jako podświetlone. Możesz kliknąć w tej sekcji, aby dodawać i usuwać relacje.'),
(92056, 957, 24, 'Wybierz kryteria'),
(92057, 959, 24, 'Wybierz z menu Plik'),
(92058, 960, 24, 'Wybierz z listy'),
(92059, 962, 24, 'Wybierz listę'),
(92060, 965, 24, 'Wybierz format wydruku dla tego raportu spotkań.'),
(92061, 967, 24, 'przewlekłe zapalenie oskrzeli'),
(92062, 968, 24, 'Przewlekłe bóle stawów'),
(92063, 969, 24, 'Przewlekła choroba nerek (PChN)'),
(92064, 970, 24, 'Przewlekłe zapalenie błony maziowej / wysięk / stawów / dna'),
(92065, 971, 24, 'Chronic / okresowe'),
(92066, 973, 24, 'Marskość wątroby'),
(92067, 974, 24, 'Marskość wątroby'),
(92068, 975, 24, 'Miasto'),
(92069, 976, 24, 'Nazwa miasta'),
(92070, 977, 24, 'Miasto, Województwo'),
(92071, 978, 24, 'Miasto, Województwo Kod pocztowy'),
(92072, 979, 24, 'Miasto / Województwo'),
(92073, 980, 24, 'twierdzić'),
(92074, 981, 24, 'twierdzić '),
(92075, 982, 24, 'dochodzić stan'),
(92076, 983, 24, 'Test roszczenia skończy działać'),
(92077, 984, 24, 'Typ roszczenia'),
(92078, 985, 24, 'Roszczenie zostało wygenerowane do pliku'),
(92079, 986, 24, 'Roszczenie zostało wygenerowane do pliku '),
(92080, 987, 24, 'roszczenia'),
(92081, 988, 24, 'klasyfikacja'),
(92082, 989, 24, 'Wyczyść'),
(92083, 990, 24, 'WYCZYŚĆ AKTYWNEGO PACJENTA'),
(92084, 991, 24, 'Wyczyść wszystko'),
(92085, 992, 24, 'Wyczyść Dane HL7'),
(92086, 993, 24, 'jasne uzasadnienie'),
(92087, 994, 24, 'Clear Cache Smarty'),
(92088, 995, 24, 'Informacje izba rozliczeniowa wymagane EDI 270 tworzenia partii.'),
(92089, 996, 24, 'Numer CLIA'),
(92090, 997, 24, 'Kliknij'),
(92091, 998, 24, 'Kliknij "wywóz" eksportowania Kategoria, podkategoria, element danych treści w pliku tekstowym. Jakiekolwiek podobieństwo tego pliku do pliku XML jest czysto przypadkowe. Otwarcia i zamknięcia tagi muszą być w tej samej linii, muszą być pisane małymi literami bez spacji. Importować, poszukaj pliku i kliknij przycisk "Importuj". Jeśli dane są całkowicie różne, że połączy się z istniejących danych. Jeśli są podobne nazwy pozycji, stara zostanie utrzymane, a nowy zapisany z numerem dodany do końca.'),
(92092, 999, 24, 'Kliknij miejsce na grafikę, aby dodać nową notatkę, kliknij go ponownie, aby ją usunąć'),
(92093, 1000, 24, 'Kliknij przycisk Pobierz certyfikat, aby pobrać certyfikaty w ssl.zip pliku'),
(92094, 1001, 24, 'kliknij po więcej'),
(92095, 1002, 24, 'Kliknij po więcej szczegółów'),
(92096, 1003, 24, 'Kliknij na podsumowaniu zamówienia'),
(92097, 1004, 24, 'Kliknij na wyniki'),
(92098, 1005, 24, 'Kliknij tutaj'),
(92099, 1006, 24, 'Kliknij tutaj, aby dodać nowego pacjenta.'),
(92100, 1007, 24, 'Kliknij tutaj, aby dodać nowy status szkody i zmiany edycji codzienną aktywność'),
(92101, 1008, 24, 'Kliknij tutaj, aby wybrać datę'),
(92102, 1009, 24, 'Kliknij tutaj, aby wybrać datę i godzinę'),
(92103, 1010, 24, 'Kliknij tutaj, aby wybrać datę rozpoczęcia'),
(92104, 1020, 24, 'kliknij tutaj, aby wyszukać'),
(92105, 1021, 24, 'Kliknij tutaj, aby zaktualizować priorytet, kategoria i nick ustawienia'),
(92106, 1022, 24, 'Kliknij tutaj, aby wyświetlić wszystkie.'),
(92107, 1023, 24, 'Kliknij tutaj, aby wyświetlić i wykres'),
(92108, 1025, 24, 'Kliknij tutaj, aby zobaczyć i wykres wszystkie narządy.'),
(92109, 1026, 24, 'Kliknij tutaj aby zobaczyć szczegóły pacjenta'),
(92110, 1027, 24, 'Kliknij tutaj, aby zobaczyć je wszystkie.'),
(92111, 1028, 24, 'Kliknij tutaj, aby zobaczyć / edytować więcej szczegółów'),
(92112, 1029, 24, 'Kliknij przycisk Instaluj, aby zainstalować wersji bazy danych z tej daty'),
(92113, 1030, 24, 'Kliknij na jednym z pól czasu by zwiększyć jego'),
(92114, 1031, 24, 'Kliknij nazwisko pacjenta otworzyć plik Pacjenta'),
(92115, 1032, 24, 'Kliknij Odśwież, aby zobaczyć wszystkie wyniki, lub proszę kryteriom wejściowych powyżej aby zobaczyć konkretne wyniki.'),
(92116, 1033, 24, 'Kliknij, aby dodać diagnozę'),
(92117, 1034, 24, 'Kliknij, aby dodać nowe elementy'),
(92118, 1035, 24, 'Kliknij, aby dodać nowe konsultacje'),
(92119, 1037, 24, 'Kliknij, aby pobrać'),
(92120, 1038, 24, 'Kliknij, aby edytować'),
(92121, 1039, 24, 'Kliknij, aby edytować opis'),
(92122, 1040, 24, 'Kliknij, aby edytować to wydarzenie'),
(92123, 1041, 24, 'Kliknij aby wygenerować raport'),
(92124, 1043, 24, 'Kliknij, aby wydrukować'),
(92125, 1044, 24, 'Kliknij, aby otrzymać (dodaj) nowa partia'),
(92126, 1045, 24, 'Kliknij, aby wybrać'),
(92127, 1046, 24, 'Kliknij, aby wybrać'),
(92128, 1047, 24, 'Kliknij, aby wybrać przemysł standardowy kod do tej procedury'),
(92129, 1048, 24, 'Kliknij, aby wybrać opcjonalny kod procedury'),
(92130, 1050, 24, 'Kliknij, aby wybrać lub zmienić kod CVX'),
(92131, 1051, 24, 'Kliknij, aby wybrać lub zmienić diagnozę'),
(92132, 1052, 24, 'Kliknij, aby wybrać lub zmienić kody serwisowe'),
(92133, 1053, 24, 'Kliknij, aby wybrać pacjenta'),
(92134, 1054, 24, 'Kliknij, aby wybrać kod związanych'),
(92135, 1055, 24, 'Kliknij, aby wybrać usługi do wykonania, jeśli wynik jest nieprawidłowy'),
(92136, 1056, 24, 'Kliknij, aby wybrać żądaną procedurę'),
(92137, 1057, 24, 'Kliknij, aby posortować'),
(92138, 1058, 24, 'Kliknij aby zobaczyć'),
(92139, 1059, 24, 'Kliknij, aby wyświetlić lub edytować'),
(92140, 1060, 24, 'Kliknij, by zobaczyć / edytować'),
(92141, 1061, 24, 'Kliknij przycisk Zmień, aby uaktualnić wersji bazy danych z tej daty'),
(92142, 1063, 24, 'Kliknij:'),
(92143, 1064, 24, 'Dni wygaśnięcia certyfikatu klienta'),
(92144, 1065, 24, 'Świadectwo okres klient walidacji'),
(92145, 1066, 24, 'Ważności certyfikatu klient powinien być podany numer.'),
(92146, 1067, 24, 'Copy Client'),
(92147, 1069, 24, 'Client medyczny Podsumowanie Historia'),
(92148, 1070, 24, 'Nazwa klienta'),
(92149, 1071, 24, 'Numer Klienta'),
(92150, 1072, 24, 'Client Profile - nowych klientów'),
(92151, 1073, 24, 'Client Profile - Unikalne Klienci'),
(92152, 1074, 24, 'Klienci'),
(92153, 1075, 24, 'Klinika'),
(92154, 1076, 24, 'Copy Clinic'),
(92155, 1077, 24, 'Klinika Daily Record'),
(92156, 1078, 24, 'ID Clinic'),
(92157, 1079, 24, 'kliniczny'),
(92158, 1080, 24, 'Kliniczne reguł decyzyjnych Alert Manager'),
(92159, 1081, 24, 'Historia kliniczna'),
(92160, 1083, 24, 'Plany badań klinicznych'),
(92161, 1084, 24, 'Kliniczne Środki jakości (CQM)'),
(92162, 1087, 24, 'Przypomnienia kliniczne'),
(92163, 1088, 24, 'Doniesienia kliniczne'),
(92164, 1089, 24, 'Clinical Kategoria Rule Action'),
(92165, 1090, 24, 'Clinical Rule Action Item'),
(92166, 1091, 24, 'Metod klinicznych reguły filtrowania'),
(92167, 1092, 24, 'Metod klinicznych docelowe Rule'),
(92168, 1093, 24, 'Zasady kliniczne'),
(92169, 1094, 24, 'Kliniczne Zasady przedziałach wiekowych'),
(92170, 1095, 24, 'Kliniczne Zasady Porównania'),
(92171, 1096, 24, 'Typy kliniczne Zasady Encounter'),
(92172, 1097, 24, 'Zasady kliniczne Przypomnienie Due Opcje'),
(92173, 1098, 24, 'Kliniczne Zasady Opcje inaktywacji Reminder'),
(92174, 1099, 24, 'Kliniczne Zasady Interwały Reminder'),
(92175, 1100, 24, 'Regulamin Metody kliniczne Reminder'),
(92176, 1101, 24, 'Zasady kliniczne Interwały docelowe'),
(92177, 1102, 24, 'kliniczne cele'),
(92178, 1103, 24, 'kliniczny termin'),
(92179, 1104, 24, 'kliniczny termin Kod (-y)'),
(92180, 1106, 24, 'lekarze'),
(92181, 1107, 24, 'Clone'),
(92182, 1108, 24, 'Clone Past wizyta'),
(92183, 1109, 24, 'zamknąć'),
(92184, 1111, 24, 'Zamknij okno'),
(92185, 1112, 24, 'zamknięty'),
(92186, 1113, 24, 'cm'),
(92187, 1114, 24, 'CMS 1500 Marginesy'),
(92188, 1118, 24, 'CMS ID'),
(92189, 1127, 24, 'CN2-12 bez zmian'),
(92190, 1128, 24, 'współfinansowane płatna'),
(92191, 1129, 24, 'Co Pay Paid'),
(92192, 1130, 24, 'CO-PAY'),
(92193, 1131, 24, 'Kod'),
(92194, 1132, 24, 'kod'),
(92195, 1133, 24, 'code Finder'),
(92196, 1134, 24, 'Kod musi być dwa małe litery'),
(92197, 1135, 24, 'Kod lub symbol wskazuje walutę'),
(92198, 1136, 24, 'Tekst code'),
(92199, 1138, 24, 'Typ kodu'),
(92200, 1141, 24, 'Rodzaje kodów'),
(92201, 1142, 24, 'Kod (-y)'),
(92202, 1143, 24, 'Coded'),
(92203, 1144, 24, 'Kody'),
(92204, 1145, 24, 'kodowanie'),
(92205, 1147, 24, 'Gra - żadnych spotkań (zapis, wsome opcjonalnie)'),
(92206, 1148, 24, 'Gra - Moje spotkania (zapis, wsome opcjonalnie)'),
(92207, 1149, 24, 'Kodowanie nie jest upoważniony'),
(92208, 1150, 24, 'kawa'),
(92209, 1152, 24, 'koasekuracja'),
(92210, 1153, 24, 'Coll w / o'),
(92211, 1154, 24, 'Rozwiń'),
(92212, 1155, 24, 'rozwiń'),
(92213, 1156, 24, 'Zwiń wszystko'),
(92214, 1157, 24, 'Zwiń wszystko'),
(92215, 1158, 24, 'zwinąć wszystko'),
(92216, 1160, 24, 'kolekcja data'),
(92217, 1161, 24, 'Kolekcje'),
(92218, 1162, 24, 'Kolekcje Zgłoś'),
(92219, 1163, 24, 'Rak jelita grubego'),
(92220, 1164, 24, 'Colon Cancer Screening'),
(92221, 1165, 24, 'Chirurgia raka okrężnicy'),
(92222, 1166, 24, 'kolonoskopia'),
(92223, 1167, 24, 'kolonoskopia'),
(92224, 1168, 24, 'kolor'),
(92225, 1169, 24, 'Kolor: Skrót'),
(92226, 1170, 24, 'kolumna'),
(92227, 1171, 24, 'kolumny'),
(92228, 1172, 24, 'Dużo Łączenie'),
(92229, 1173, 24, 'przecinek'),
(92230, 1174, 24, 'komentarz'),
(92231, 1175, 24, 'Komentarze'),
(92232, 1176, 24, 'Komentarze do tego wyniku lub zalecenia'),
(92233, 1177, 24, 'Komercyjne Insurance Co'),
(92234, 1178, 24, 'Commit Changes'),
(92235, 1180, 24, 'Komunikacja'),
(92236, 1182, 24, 'spółka'),
(92237, 1183, 24, 'Nazwa firmy'),
(92238, 1184, 24, 'zakończyć'),
(92239, 1186, 24, 'zakończony'),
(92240, 1188, 24, 'Zakończone?'),
(92241, 1190, 24, 'Powikłania przez operatora'),
(92242, 1191, 24, 'Powikłania aborcji'),
(92243, 1192, 24, 'Components'),
(92244, 1193, 24, 'Computer Aided Medical system zamawiania'),
(92245, 1194, 24, 'Wnioski'),
(92246, 1199, 24, 'Konfiguracja'),
(92247, 1200, 24, 'Konfiguracja Export / Import'),
(92248, 1202, 24, 'Apache i LibreEHR użyć po stronie klienta certyfikaty SSL.'),
(92249, 1203, 24, 'Skonfigurować Apache w użyciu klient certyfikaty SSL niepożądane'),
(92250, 1204, 24, 'Apache w użyciu protokołu HTTPS.'),
(92251, 1205, 24, 'Skonfiguruj LIBREEHR używać certyfikatów SSL Client boczne'),
(92252, 1208, 24, 'Potwierdź utworzenie nowego pacjenta'),
(92253, 1209, 24, 'Potwierdź nowe hasło'),
(92254, 1210, 24, 'Potwierdź Płatność'),
(92255, 1214, 24, 'wrodzony'),
(92256, 1215, 24, 'Conjuntiva uczniowie'),
(92257, 1217, 24, 'Połączenia'),
(92258, 1218, 24, 'stały'),
(92259, 1219, 24, 'nazwa stałej'),
(92260, 1220, 24, 'Stała nazwa jest pusta'),
(92261, 1221, 24, 'stałe'),
(92262, 1222, 24, 'zaparcie'),
(92263, 1223, 24, 'konstytucyjny'),
(92264, 1226, 24, 'Konsultacje Skrócony opis'),
(92265, 1227, 24, 'Dane kontaktowe'),
(92266, 1228, 24, 'Kontakt e-mail'),
(92267, 1229, 24, 'Kontakt adres e-mail'),
(92268, 1230, 24, 'Skontaktuj EMR bezpośrednie do subskrypcji usługi wiadomości bezpośrednich phiMail'),
(92269, 1231, 24, 'informacje kontaktowe'),
(92270, 1232, 24, 'soczewki kontaktowe'),
(92271, 1233, 24, 'Skontaktuj się Medical integracji informacji, LLC w http://mi-squared.com dla Lab Wymiany.'),
(92272, 1234, 24, 'Skontaktuj się Medical integracji informacji, LLC w http://mi-squared.com lub ZH zdrowotnej na http://zhservices.com subskrybowania usługi ERX'),
(92273, 1236, 24, 'nazwę kontaktu'),
(92274, 1237, 24, 'Osoba kontaktowa'),
(92275, 1239, 24, 'Kontaktowy numer telefonu'),
(92276, 1240, 24, 'Kontakt ZMG, LLC (zmghealth@gmail.com) subskrybowania usługi ERX'),
(92277, 1241, 24, 'zawierać co najmniej trzy z czterech następujących elementów:'),
(92278, 1242, 24, 'Nazwa grupy pojemnik'),
(92279, 1243, 24, 'zawartość'),
(92280, 1244, 24, 'zawartość'),
(92281, 1245, 24, 'kontekst'),
(92282, 1246, 24, 'Nazwa kontekstu można  ''t być pusty'),
(92283, 1247, 24, 'kontynuować'),
(92284, 1248, 24, 'Ciągłość Dokument Opieki (CCD)'),
(92285, 1249, 24, 'Ciągłość opieki Record (CCR)'),
(92286, 1250, 24, 'Klienci przeciwwskazania'),
(92287, 1251, 24, 'zapobieganie ciąży'),
(92288, 1252, 24, 'problemy Antykoncepcja'),
(92289, 1253, 24, 'Powikłania antykoncepcji (określić)'),
(92290, 1254, 24, 'metoda antykoncepcji'),
(92291, 1255, 24, 'Produkty antykoncepcyjne'),
(92292, 1256, 24, 'Usługi antykoncepcyjne wcześniej rozpoczął'),
(92293, 1257, 24, 'Antykoncepcja Początek'),
(92294, 1258, 24, 'ID Control'),
(92295, 1259, 24, 'Kontrola nr'),
(92296, 1261, 24, 'COPAY'),
(92297, 1262, 24, 'Copay'),
(92298, 1263, 24, 'CoPay'),
(92299, 1264, 24, 'Copay nie pozytywne'),
(92300, 1266, 24, 'Copays'),
(92301, 1267, 24, 'POChP'),
(92302, 1268, 24, 'Kopiowanie stron na wykresie pacjenta'),
(92303, 1269, 24, 'Kopiowanie wartości'),
(92304, 1270, 24, 'Kopiowanie pliku bazy danych. To zajmie trochę czasu ...'),
(92305, 1271, 24, 'Informacje o prawach autorskich'),
(92306, 1273, 24, 'Coronary artery bypass'),
(92307, 1274, 24, 'Coronary pomostów aortalno-wieńcowych (CABG)'),
(92308, 1275, 24, 'Poprawione'),
(92309, 1277, 24, 'sofa baza danych'),
(92310, 1278, 24, 'sofa baza danych połączenie nie powiodło się'),
(92311, 1279, 24, 'sofa baza danych'),
(92312, 1280, 24, 'sofa baza danych nazwa'),
(92313, 1281, 24, 'sofa baza danych nazwa gospodarz'),
(92314, 1282, 24, 'sofa baza danych nazwa hosta'),
(92315, 1308, 24, 'Kraj'),
(92316, 1310, 24, 'Lista krajów'),
(92317, 1313, 24, 'województwo'),
(92318, 1325, 24, 'krem'),
(92319, 1329, 24, 'Utwórz wydarzenie'),
(92320, 1330, 24, 'Utwórz i pobierz pełną kopię zapasową'),
(92321, 1332, 24, 'Utwórz kopię zapasową'),
(92322, 1334, 24, 'Utwórz certyfikat klienta'),
(92323, 1335, 24, 'Utwórz certyfikat SSL dla klienta'),
(92324, 1336, 24, 'Utwórz duplikat'),
(92325, 1340, 24, 'Utwórz nowego pacjenta'),
(92326, 1344, 24, 'Utwórz notatkę o pacjencie'),
(92327, 1346, 24, 'Utwórz wizytę'),
(92328, 1347, 24, 'Utworzono'),
(92329, 1351, 24, 'Autor'),
(92330, 1352, 24, 'kredyt'),
(92331, 1353, 24, 'Karta kredytowa'),
(92332, 1360, 24, 'Eksport do CSV'),
(92333, 1361, 24, 'Plik CSV'),
(92334, 1362, 24, 'Tabele CSV'),
(92335, 1364, 24, 'Kubański'),
(92336, 1365, 24, 'Liczba miejsc dziesiętnych w zapisie waluty'),
(92337, 1366, 24, 'Separator groszy dla waluty'),
(92338, 1368, 24, 'Separator tysiecy dla waluty'),
(92339, 1369, 24, 'Bieżące'),
(92340, 1370, 24, 'Bieżący Alkohol'),
(92341, 1372, 24, 'Bieżące kryteria'),
(92342, 1373, 24, 'Kolor podświetlenia bieżącego dnia'),
(92343, 1374, 24, 'Zacienienie bieżącego dnia'),
(92344, 1375, 24, 'Bieżąca nazwa pliku zmieniona do'),
(92345, 1377, 24, 'Bieżąca lokalizacja'),
(92346, 1378, 24, 'Bieżące leki'),
(92347, 1379, 24, 'Bieżące hasło'),
(92348, 1380, 24, 'Bieżący pacjent'),
(92349, 1386, 24, 'Obecnie aktywny'),
(92350, 1387, 24, 'Obecnie przetwarzany'),
(92351, 1393, 24, 'Indywidualne wprowadzanie'),
(92352, 1394, 24, 'Indywidualna Tabela'),
(92353, 1399, 24, 'Cykl'),
(92354, 1403, 24, 'czeski'),
(92355, 1407, 24, 'Data ur.'),
(92356, 1408, 24, 'codziennie'),
(92357, 1409, 24, 'Codzienne notatki'),
(92358, 1410, 24, 'duński'),
(92359, 1416, 24, 'Błąd danych'),
(92360, 1420, 24, 'Typ danych'),
(92361, 1421, 24, 'Baza danych'),
(92362, 1422, 24, 'Baza danych nie została zainstalowana.'),
(92363, 1423, 24, 'Poprawka do bazy danych'),
(92364, 1424, 24, 'Raport o bazie danych'),
(92365, 1425, 24, 'Zakończono upgrade bazy danych.'),
(92366, 1427, 24, 'Data'),
(92367, 1428, 24, 'DATA'),
(92368, 1431, 24, 'Data podania'),
(92369, 1432, 24, 'Data i godzina pobrania próbki'),
(92370, 1433, 24, 'Data i godzina obserwacji'),
(92371, 1435, 24, 'Data i godzina odbioru próbki'),
(92372, 1436, 24, 'Data nie może być późniejsza, niż dzisiaj'),
(92373, 1437, 24, 'Data pierwszego podania antykoncepcji'),
(92374, 1438, 24, 'Data utworzenia'),
(92375, 1439, 24, 'Data zgonu'),
(92376, 1440, 24, 'Data zniszczenia'),
(92377, 1441, 24, 'Format wyświetlania daty'),
(92378, 1452, 24, 'Data urodzenia'),
(92379, 1453, 24, 'Data urodzenia'),
(92380, 1454, 24, 'Data urodzenia'),
(92381, 1455, 24, 'Data wpisu'),
(92382, 1456, 24, 'Data obrażenia'),
(92383, 1458, 24, 'Data płatności rrrr-mm-dd'),
(92384, 1460, 24, 'Data odpowiedzi'),
(92385, 1461, 24, 'Data raportu'),
(92386, 1462, 24, 'Data usługi'),
(92387, 1463, 24, 'Data usługi'),
(92388, 1464, 24, 'Data usługi = Dzisiaj'),
(92389, 1466, 24, 'Data usługi:'),
(92390, 1467, 24, 'Data podpisu'),
(92391, 1486, 24, 'Dzień'),
(92392, 1487, 24, 'dzień'),
(92393, 1489, 24, 'Widok dnia'),
(92394, 1490, 24, 'Dni'),
(92395, 1492, 24, 'dni'),
(92396, 1493, 24, 'Dni'),
(92397, 1494, 24, 'dni temu'),
(92398, 1502, 24, 'DD/MM/RRRR'),
(92399, 1515, 24, 'Gru'),
(92400, 1517, 24, 'Grudzień'),
(92401, 1522, 24, 'Domyślne'),
(92402, 1526, 24, 'Domyślna siedziba'),
(92403, 1527, 24, 'Domyślny język'),
(92404, 1528, 24, 'Domyślny język, gdy nie udostępniono wyboru.'),
(92405, 1554, 24, 'Usuń'),
(92406, 1555, 24, 'usuń'),
(92407, 1557, 24, 'Usuń kategorię'),
(92408, 1560, 24, 'Usuń grupę'),
(92409, 1561, 24, 'Usuń listę'),
(92410, 1565, 24, 'Usuń wiersz'),
(92411, 1566, 24, 'Usuń zaznaczone'),
(92412, 1568, 24, 'Usuwanie poprawne.'),
(92413, 1569, 24, 'Usuń ten dokument.'),
(92414, 1570, 24, 'Usuń ten formularz.'),
(92415, 1571, 24, 'Usuń tę notatkę.'),
(92416, 1573, 24, 'Usuwanie poprawne.'),
(92417, 1574, 24, 'Usuwanie'),
(92418, 1582, 24, 'Demografia'),
(92419, 1590, 24, 'Dentystyczny'),
(92420, 1592, 24, 'Stomatologiczne'),
(92421, 1609, 24, 'Cel'),
(92422, 1631, 24, 'Diagnoza'),
(92423, 1632, 24, 'Diagnozy'),
(92424, 1633, 24, 'Diagnoza'),
(92425, 1634, 24, 'Kody diagnoz'),
(92426, 1636, 24, 'Data diagnoz'),
(92427, 1638, 24, 'Nazwa diagnoz'),
(92428, 1643, 24, 'Diagnoza:'),
(92429, 1667, 24, 'Wyłącz kalendarz'),
(92430, 1672, 24, 'Wyłącz phpMyAdmin'),
(92431, 1692, 24, 'Ujawnienia'),
(92432, 1733, 24, 'Rozwiedziony/a'),
(92433, 1759, 24, 'Czy kontynuować dodawanie tego pacjenta?'),
(92434, 1762, 24, 'Data ur.'),
(92435, 1763, 24, 'Data ur. niedostępna, jeśli to możliwe proszę wprowadź'),
(92436, 1767, 24, 'Nazwisko i podpis lekarza'),
(92437, 1768, 24, 'Dokument'),
(92438, 1769, 24, 'dokument'),
(92439, 1770, 24, 'Kategorie dokumentu'),
(92440, 1791, 24, 'Dokumenty'),
(92441, 1799, 24, 'Konkubent/a'),
(92442, 1830, 24, 'Dr'),
(92443, 1833, 24, 'Prawo jazdy #'),
(92444, 1834, 24, 'Leki'),
(92445, 1846, 24, 'Leki'),
(92446, 1880, 24, 'czas trwania'),
(92447, 1881, 24, 'Czas trwania'),
(92448, 1882, 24, 'holenderski'),
(92449, 1896, 24, 'EKG'),
(92450, 1904, 24, 'Edycja'),
(92451, 1905, 24, 'edycja'),
(92452, 1931, 24, 'ee the * GNU General Public License for more details. * * You should have received a copy of the GNU General Public License * along with this program; if not, write to the Free '),
(92453, 1937, 24, 'Łokieć'),
(92454, 1938, 24, 'Problemy z łokciem'),
(92455, 1943, 24, 'Raporty elektroniczne'),
(92456, 1949, 24, 'Email'),
(92457, 1951, 24, 'Adres Email'),
(92458, 1971, 24, 'Osoba kontaktowa'),
(92459, 1972, 24, 'Nazwisko osoby kontaktowej'),
(92460, 1973, 24, 'Telefon do osoby kontaktowej'),
(92461, 1980, 24, 'Tel. do os. kontaktowej'),
(92462, 1983, 24, 'Pracownik'),
(92463, 1984, 24, 'Pracodawca'),
(92464, 1985, 24, 'Adres pracodawcy'),
(92465, 1987, 24, 'Nazwa pracodawcy'),
(92466, 1988, 24, 'PUSTY'),
(92467, 1989, 24, 'Pusty'),
(92468, 2072, 24, 'Wizyta'),
(92469, 2073, 24, 'Wizyta'),
(92470, 2074, 24, 'wizyta'),
(92471, 2075, 24, 'Wizyta '),
(92472, 2088, 24, 'Historia wizyt'),
(92473, 2096, 24, 'incontro per visita in studio'),
(92474, 2108, 24, 'Statystyka wizyty'),
(92475, 2109, 24, 'Podsumowanie wizyty'),
(92476, 2110, 24, 'Wizytę opisano kodem'),
(92477, 2111, 24, 'Wizyta:'),
(92478, 2113, 24, 'Wizyty'),
(92479, 2114, 24, 'Wizyty i formularze'),
(92480, 2116, 24, 'Wizyta nie autoryzowana'),
(92481, 2117, 24, 'Raport z wizyt'),
(92482, 2118, 24, 'Sekcja wizyt'),
(92483, 2121, 24, 'Koniec'),
(92484, 2123, 24, 'Data końcowa'),
(92485, 2124, 24, 'Data końcowa'),
(92486, 2126, 24, 'Data końcowa powinna być większa od początkowej'),
(92487, 2127, 24, 'Data końcowa:'),
(92488, 2131, 24, 'Czas końcowy'),
(92489, 2141, 24, 'angielski'),
(92490, 2142, 24, 'angielski '),
(92491, 2143, 24, 'angielski (Indie)'),
(92492, 2144, 24, 'angielski (Standardowy)'),
(92493, 2165, 24, 'Wprowadź powyżej kryteria wyszukiwania'),
(92494, 2167, 24, 'pozycji'),
(92495, 2176, 24, 'Padaczka'),
(92496, 2181, 24, 'Wymaż'),
(92497, 2183, 24, 'Błąd'),
(92498, 2247, 24, 'Stały Pacjent'),
(92499, 2253, 24, 'Zdarzenie'),
(92500, 2273, 24, 'każdego'),
(92501, 2274, 24, 'Każdego'),
(92502, 2275, 24, 'co 3 godz.'),
(92503, 2276, 24, 'co 4 godz.'),
(92504, 2277, 24, 'co 5 godz.'),
(92505, 2278, 24, 'co 6 godz.'),
(92506, 2279, 24, 'co 8 godz.'),
(92507, 2280, 24, 'Co Czwarty'),
(92508, 2281, 24, 'Co Drugi'),
(92509, 2282, 24, 'Co Trzeci'),
(92510, 2286, 24, 'Wyniki badania'),
(92511, 2289, 24, 'Badanie'),
(92512, 2290, 24, 'Data Badania'),
(92513, 2294, 24, 'Za wyjątkiem'),
(92514, 2303, 24, 'Istnieje'),
(92515, 2306, 24, 'Rozwiń'),
(92516, 2307, 24, 'rozwiń'),
(92517, 2308, 24, 'Rozwiń Wszystko'),
(92518, 2311, 24, 'Podgląd Rozszerzony'),
(92519, 2313, 24, 'Koniec Ważności'),
(92520, 2314, 24, 'Data Ważności'),
(92521, 2315, 24, 'Koniec Ważności'),
(92522, 2316, 24, 'koniec ważności w'),
(92523, 2317, 24, 'Eksport'),
(92524, 2318, 24, 'Eksport jako CSV'),
(92525, 2332, 24, 'Zewnętrzny'),
(92526, 2336, 24, 'Ident. zewn'),
(92527, 2337, 24, 'Ident. zewn'),
(92528, 2338, 24, 'Ident. zewn'),
(92529, 2356, 24, 'Ośrodki'),
(92530, 2357, 24, 'Ośrodek'),
(92531, 2358, 24, 'ośrodek'),
(92532, 2372, 24, 'Ośrodek:'),
(92533, 2412, 24, 'Lut'),
(92534, 2413, 24, 'Luty'),
(92535, 2418, 24, 'Opłata'),
(92536, 2419, 24, 'opłata'),
(92537, 2423, 24, 'Opłaty'),
(92538, 2424, 24, 'Kobieta'),
(92539, 2459, 24, 'Nazwa pliku'),
(92540, 2461, 24, 'Pliki'),
(92541, 2468, 24, 'Filtr'),
(92542, 2471, 24, 'wyfiltrowane z'),
(92543, 2472, 24, 'filtry'),
(92544, 2473, 24, 'Filtry'),
(92545, 2474, 24, 'Końcowy'),
(92546, 2475, 24, 'Diagnoza końcowa'),
(92547, 2478, 24, 'Finansowa'),
(92548, 2484, 24, 'Znajdź'),
(92549, 2485, 24, 'Szukaj dostępnych'),
(92550, 2487, 24, 'Znajdź pacjenta'),
(92551, 2493, 24, 'ukończony'),
(92552, 2495, 24, 'Pierwszy'),
(92553, 2497, 24, 'Pierwszy dzień tygodnia'),
(92554, 2498, 24, 'Imię'),
(92555, 2499, 24, 'Imię'),
(92556, 2500, 24, 'Imię:'),
(92557, 2539, 24, 'dla'),
(92558, 2540, 24, 'Dla'),
(92559, 2555, 24, 'danych:'),
(92560, 2560, 24, 'Formularz'),
(92561, 2561, 24, 'Formularz'),
(92562, 2572, 24, 'Formularze'),
(92563, 2575, 24, 'Do przodu'),
(92564, 2587, 24, 'francuski'),
(92565, 2590, 24, 'Częstotliwość'),
(92566, 2593, 24, 'Pią'),
(92567, 2594, 24, 'Piątek'),
(92568, 2595, 24, 'Od'),
(92569, 2596, 24, 'OD'),
(92570, 2597, 24, 'od'),
(92571, 2599, 24, 'Od:'),
(92572, 2600, 24, 'Od: '),
(92573, 2619, 24, 'Imię i nazwisko'),
(92574, 2687, 24, 'niemiecki'),
(92575, 2700, 24, 'idź'),
(92576, 2701, 24, 'Idź'),
(92577, 2704, 24, 'Idź do'),
(92578, 2722, 24, 'grecki'),
(92579, 2739, 24, 'Dane opiekuna'),
(92580, 2768, 24, 'Głowa'),
(92581, 2778, 24, 'Utrata słuchu'),
(92582, 2779, 24, 'Zawał serca'),
(92583, 2784, 24, 'Operacja serca'),
(92584, 2785, 24, 'Przeszczep serca'),
(92585, 2786, 24, 'SERCE:'),
(92586, 2787, 24, 'Zgaga'),
(92587, 2791, 24, 'hebrajski'),
(92588, 2794, 24, 'Wzrost'),
(92589, 2796, 24, 'Pomoc'),
(92590, 2797, 24, 'pomoc'),
(92591, 2806, 24, 'Zapalenie wątroby A 1'),
(92592, 2807, 24, 'Zapalenie wątroby A 2'),
(92593, 2808, 24, 'Zapalenie wątroby B 1'),
(92594, 2809, 24, 'Zapalenie wątroby B 2'),
(92595, 2810, 24, 'Zapalenie wątroby B 3'),
(92596, 2811, 24, 'tutaj'),
(92597, 2822, 24, 'Ukryty'),
(92598, 2824, 24, 'Ukryj'),
(92599, 2825, 24, 'Ukryj szczegóły'),
(92600, 2828, 24, 'Ukryj menu'),
(92601, 2830, 24, 'Ukryj przypomnienia'),
(92602, 2831, 24, 'Pokaż/ukryj kolumny'),
(92603, 2833, 24, 'Wysoki'),
(92604, 2835, 24, 'hindi'),
(92605, 2840, 24, 'Otrzymano zawiadomienie o HIPAA'),
(92606, 2847, 24, 'Historia'),
(92607, 2855, 24, 'HIV'),
(92608, 2860, 24, 'hmol/l'),
(92609, 2865, 24, 'Główna'),
(92610, 2866, 24, 'Telefon domowy'),
(92611, 2867, 24, 'Numer telefonu domowego'),
(92612, 2868, 24, 'Czy bezdomny?'),
(92613, 2869, 24, 'Bezdomny, itp.'),
(92614, 2870, 24, 'Bezdomny, itp.'),
(92615, 2875, 24, 'Godzina'),
(92616, 2876, 24, 'Godziny'),
(92617, 2884, 24, 'HTML'),
(92618, 2892, 24, 'Nadpobudliwy'),
(92619, 2893, 24, 'Nadciśnienie'),
(92620, 2912, 24, 'Dokument tożsamości'),
(92621, 2936, 24, 'Ignoruj'),
(92622, 2942, 24, 'Szczepienie'),
(92623, 2949, 24, 'Rejestr szczepień'),
(92624, 2953, 24, 'Szczepienia'),
(92625, 2972, 24, 'Poprawiony'),
(92626, 2973, 24, 'w'),
(92627, 2974, 24, 'IN'),
(92628, 2978, 24, 'Dostępny'),
(92629, 3087, 24, 'Ubezpieczenie'),
(92630, 3088, 24, 'ubezpieczenie'),
(92631, 3091, 24, 'saldo ubezpieczenia'),
(92632, 3153, 24, 'Błędna nazwa użytkownika lub hasło'),
(92633, 3162, 24, 'Faktura'),
(92634, 3163, 24, 'faktura'),
(92635, 3166, 24, 'Data faktury'),
(92636, 3167, 24, 'Faktura bez daty'),
(92637, 3168, 24, 'Data faktury'),
(92638, 3198, 24, 'Czy PHP jest w trybie Safe Mode?'),
(92639, 3202, 24, 'Czy plik jest szyfrowany?'),
(92640, 3223, 24, 'Dolegliwości'),
(92641, 3224, 24, 'Dolegliwości (Urazy/Medyczne/Alergie)'),
(92642, 3225, 24, 'Dolegliwości (Urazy/Medyczne/Alergie)'),
(92643, 3226, 24, 'Dolegliwości i Wizyty'),
(92644, 3229, 24, 'Sekcja Dolegliwości'),
(92645, 3230, 24, 'włoski'),
(92646, 3238, 24, 'Sty'),
(92647, 3239, 24, 'Styczeń'),
(92648, 3240, 24, 'Japoński'),
(92649, 3241, 24, 'Żółtaczka'),
(92650, 3248, 24, 'Lip'),
(92651, 3249, 24, 'Lipiec'),
(92652, 3250, 24, 'Cze'),
(92653, 3251, 24, 'Czerwiec'),
(92654, 3253, 24, 'Tylko moje'),
(92655, 3265, 24, 'Słowa kluczowe'),
(92656, 3266, 24, 'kg'),
(92657, 3267, 24, 'kg/m^2'),
(92658, 3269, 24, 'Rak nerki'),
(92659, 3271, 24, 'Infekcja nerki'),
(92660, 3272, 24, 'Kamica nerkowa'),
(92661, 3273, 24, 'Transplantacja nerki'),
(92662, 3282, 24, 'Koreański'),
(92663, 3303, 24, 'Etykieta'),
(92664, 3304, 24, 'Etykieta nie może być pusta'),
(92665, 3308, 24, 'Etykiety'),
(92666, 3316, 24, 'Język'),
(92667, 3317, 24, 'Kod języka'),
(92668, 3321, 24, 'Nazwa języka'),
(92669, 3322, 24, 'Język:'),
(92670, 3325, 24, 'Ostatni'),
(92671, 3326, 24, 'Data ostatniej aktywności'),
(92672, 3343, 24, 'Ostatni miesiąc'),
(92673, 3344, 24, 'Nazwisko'),
(92674, 3345, 24, 'Nazwisko'),
(92675, 3346, 24, 'Nazwisko:'),
(92676, 3352, 24, 'Ostatnio zapisany'),
(92677, 3358, 24, 'Ostatnia wizyta'),
(92678, 3373, 24, 'Format pochodny'),
(92679, 3374, 24, 'Edytor formatów'),
(92680, 3375, 24, 'Grupy formatów'),
(92681, 3376, 24, 'Styl formatu'),
(92682, 3378, 24, 'Format dla wizyty'),
(92683, 3379, 24, 'Formaty wyjściowe'),
(92684, 3400, 24, 'Legenda:'),
(92685, 3401, 24, 'Długość'),
(92686, 3403, 24, 'Mniej niż'),
(92687, 3404, 24, 'Mniej niż lub równo'),
(92688, 3406, 24, 'List'),
(92689, 3407, 24, 'Generator listów'),
(92690, 3412, 24, 'Odpowiedzialność'),
(92691, 3413, 24, 'Odpowiedzialność medyczna'),
(92692, 3414, 24, 'Nr dow. os/prawa jazdy'),
(92693, 3438, 24, 'Lista'),
(92694, 3445, 24, 'Lista grup'),
(92695, 3446, 24, 'Lista ubezpieczycieli'),
(92696, 3448, 24, 'Lista pozycji nie może zaczynać się liczbą'),
(92697, 3449, 24, 'Lista pozycji zawierająca błędne znaki'),
(92698, 3451, 24, 'Lista list'),
(92699, 3452, 24, 'Nazwa Listy'),
(92700, 3453, 24, 'Lista nazw nie może zaczynać się liczbą'),
(92701, 3454, 24, 'Lista recept'),
(92702, 3458, 24, 'Listy'),
(92703, 3463, 24, 'Wczytaj kompedium'),
(92704, 3464, 24, 'Wczytaj definicje'),
(92705, 3470, 24, 'Wczytywanie'),
(92706, 3485, 24, 'Zablokowany'),
(92707, 3492, 24, 'Zalogowany'),
(92708, 3493, 24, 'Zalogowany'),
(92709, 3494, 24, 'Wyloguj'),
(92710, 3495, 24, 'Zalogowany'),
(92711, 3496, 24, 'Zalogowany jako'),
(92712, 3497, 24, 'Zalogowany jako: '),
(92713, 3498, 24, 'Wylogowany'),
(92714, 3499, 24, 'Logowanie'),
(92715, 3500, 24, 'Zaloguj'),
(92716, 3501, 24, 'zaloguj'),
(92717, 3505, 24, 'Wyloguj'),
(92718, 3506, 24, 'wyloguj'),
(92719, 3507, 24, 'Rejestry'),
(92720, 3508, 24, 'Przegląd rejestrów'),
(92721, 3511, 24, 'Partia'),
(92722, 3512, 24, 'Brak numeru partii'),
(92723, 3513, 24, 'Numer partii'),
(92724, 3514, 24, 'Niski'),
(92725, 3515, 24, 'Niski priorytet'),
(92726, 3517, 24, 'Najniższy priorytet'),
(92727, 3520, 24, 'LUNCH'),
(92728, 3521, 24, 'Lunch'),
(92729, 3524, 24, 'PŁUCA:'),
(92730, 3525, 24, 'Płuca:'),
(92731, 3534, 24, 'Główny'),
(92732, 3535, 24, 'Główny adres'),
(92733, 3548, 24, 'Mężczyzna'),
(92734, 3552, 24, 'Mammografia'),
(92735, 3553, 24, 'Zarządzaj'),
(92736, 3556, 24, 'Zarządzaj tłumaczeniami'),
(92737, 3557, 24, 'Zarządzanie'),
(92738, 3561, 24, 'Instrukcja'),
(92739, 3563, 24, 'Producent'),
(92740, 3565, 24, 'Mar'),
(92741, 3568, 24, 'Marzec'),
(92742, 3569, 24, 'Stan cywilny'),
(92743, 3576, 24, 'Żonaty/Zamężna'),
(92744, 3603, 24, 'Maj'),
(92745, 3611, 24, 'Pomiary'),
(92746, 3623, 24, 'Problemy zdrowotne'),
(92747, 3635, 24, 'Lek'),
(92748, 3636, 24, 'Lista Leków na Alergię'),
(92749, 3637, 24, 'Lista leków dla dolegiliwości'),
(92750, 3638, 24, 'Lista leków'),
(92751, 3640, 24, 'Leki'),
(92752, 3641, 24, 'Leki:'),
(92753, 3647, 24, 'Mężczyzna'),
(92754, 3648, 24, 'Mężczyzna i kobieta'),
(92755, 3649, 24, 'Tylko mężczyzna'),
(92756, 3651, 24, 'Menopauza'),
(92757, 3662, 24, 'Centrum wiadomości i przypomnień'),
(92758, 3671, 24, 'Wiadomości'),
(92759, 3679, 24, 'mg'),
(92760, 3687, 24, 'Drugie Imię'),
(92761, 3688, 24, 'Drugie imię'),
(92762, 3703, 24, 'Min'),
(92763, 3704, 24, 'min'),
(92764, 3705, 24, 'Minimalny wiek'),
(92765, 3708, 24, 'Minuta'),
(92766, 3709, 24, 'minuty'),
(92767, 3710, 24, 'Minuty'),
(92768, 3712, 24, 'Pozostałe'),
(92769, 3716, 24, 'Pozostałe'),
(92770, 3727, 24, 'ml'),
(92771, 3729, 24, 'mm/hg'),
(92772, 3734, 24, 'Tel kom.'),
(92773, 3753, 24, 'Pon'),
(92774, 3754, 24, 'Pon do Pt'),
(92775, 3756, 24, 'Poniedziałek'),
(92776, 3758, 24, 'Miesiąc'),
(92777, 3759, 24, 'miesiąc'),
(92778, 3760, 24, 'Widok miesiąca'),
(92779, 3761, 24, 'Miesiąc(e)'),
(92780, 3763, 24, 'Miesiące(-ęcy)'),
(92781, 3771, 24, 'Matka'),
(92782, 3772, 24, 'Imię matki'),
(92783, 3774, 24, 'Usta'),
(92784, 3775, 24, 'Przenieś'),
(92785, 3777, 24, 'W dół'),
(92786, 3779, 24, 'Przenieś do pacjenta'),
(92787, 3780, 24, 'Przenieś do...'),
(92788, 3781, 24, 'W górę'),
(92789, 3783, 24, 'Pan'),
(92790, 3785, 24, 'Pani'),
(92791, 3786, 24, 'Panna'),
(92792, 3810, 24, 'Mięsień'),
(92793, 3811, 24, 'Uraz mięśnia'),
(92794, 3812, 24, 'Zaburzenia mięśniowo-szkieletowe'),
(92795, 3821, 24, 'N/D'),
(92796, 3822, 24, 'n/d'),
(92797, 3823, 24, 'Nazwisko'),
(92798, 3836, 24, 'Nazwa/wartość'),
(92799, 3837, 24, 'Nazwisko:'),
(92800, 3844, 24, 'Narodowość'),
(92801, 3885, 24, 'Nigdy'),
(92802, 3888, 24, 'Nowy'),
(92803, 3889, 24, 'Nowy =>'),
(92804, 3892, 24, 'Nowa Alergia'),
(92805, 3894, 24, 'Nowe Spotkanie'),
(92806, 3895, 24, 'Nowe Kategorie'),
(92807, 3896, 24, 'Nowa Kategoria'),
(92808, 3898, 24, 'Nowa konsultacja'),
(92809, 3900, 24, 'Dodano nową definicję'),
(92810, 3901, 24, 'Nowy Dokument'),
(92811, 3902, 24, 'Nowe Dokumenty'),
(92812, 3904, 24, 'Nowa wizyta'),
(92813, 3905, 24, 'Nowa wizyta utworzona przez'),
(92814, 3906, 24, 'Fromularz nowej wizyty'),
(92815, 3907, 24, 'Nowa wizyta nie autoryzowana'),
(92816, 3910, 24, 'Nowy plik'),
(92817, 3911, 24, 'Nowe pliki'),
(92818, 3912, 24, 'Nowa grupa'),
(92819, 3918, 24, 'Nowe zamówienia'),
(92820, 3920, 24, 'Nowe hasło'),
(92821, 3921, 24, 'Nowy pacjent'),
(92822, 3922, 24, 'NOWY PACJENT'),
(92823, 3930, 24, 'Nowe wyszukiwanie'),
(92824, 3932, 24, 'Nowy użytkownik'),
(92825, 3934, 24, 'Nowa wizyta'),
(92826, 3935, 24, 'Nowy/Wyszukaj'),
(92827, 3962, 24, 'Następny'),
(92828, 3964, 24, 'Następny dzień'),
(92829, 3968, 24, 'Następny tydzień'),
(92830, 3971, 24, 'Pseudonim:'),
(92831, 3975, 24, 'Nie'),
(92832, 3976, 24, 'NIE'),
(92833, 3977, 24, 'Brak dostępu'),
(92834, 3983, 24, 'Brak spotkań.'),
(92835, 3992, 24, 'Brak diagnozy'),
(92836, 3993, 24, 'Nie znaleziono dokumentu'),
(92837, 3995, 24, 'Brak daty końcowej'),
(92838, 3998, 24, 'Brak zdarzeń'),
(92839, 4034, 24, 'Brak notatek'),
(92840, 4036, 24, 'Brak dostępnych przedziałów w tym zakresie dat.'),
(92841, 4053, 24, 'Brak wyników'),
(92842, 4055, 24, 'Brak wyników. Proszę zmienić kryteria wyszukiwania.'),
(92843, 4056, 24, 'Brak przypomnień'),
(92844, 4058, 24, 'Brak wyników'),
(92845, 4059, 24, 'Brak wyników'),
(92846, 4065, 24, 'Nie pokazuj'),
(92847, 4081, 24, 'Nie opłacone'),
(92848, 4089, 24, 'Brak'),
(92849, 4090, 24, 'brak'),
(92850, 4091, 24, 'brak zdefiniowanych'),
(92851, 4093, 24, 'Żaden z powyższych'),
(92852, 4097, 24, 'Zwykły'),
(92853, 4112, 24, 'norweski'),
(92854, 4115, 24, 'Nos'),
(92855, 4116, 24, 'Krwawienie z nosa'),
(92856, 4120, 24, 'Nie dozwolone'),
(92857, 4146, 24, 'nie znaleziono'),
(92858, 4148, 24, 'nie znaleziono!'),
(92859, 4177, 24, 'Brak pozycji'),
(92860, 4185, 24, 'Powiadomienie'),
(92861, 4188, 24, 'Powiadomienia'),
(92862, 4190, 24, 'Lis'),
(92863, 4191, 24, 'Listopad'),
(92864, 4193, 24, 'Drukuję'),
(92865, 4200, 24, 'Numer'),
(92866, 4239, 24, 'Występowanie'),
(92867, 4240, 24, 'Paź'),
(92868, 4241, 24, 'Październik'),
(92869, 4243, 24, 'z'),
(92870, 4244, 24, 'z ilości'),
(92871, 4247, 24, 'Notaki biurowe'),
(92872, 4248, 24, 'Wył'),
(92873, 4250, 24, 'Wizyta'),
(92874, 4267, 24, 'OK'),
(92875, 4270, 24, 'Stary'),
(92876, 4287, 24, 'Wł'),
(92877, 4288, 24, 'Od ręki'),
(92878, 4289, 24, 'Na zamówienie'),
(92879, 4290, 24, 'Na miejscu'),
(92880, 4297, 24, 'Wsparcie techniczne'),
(92881, 4299, 24, 'Tylko aktywne'),
(92882, 4303, 24, 'Tylko nieaktywne'),
(92883, 4304, 24, 'Tylko moje'),
(92884, 4313, 24, 'Początek/Data hospitalizacji'),
(92885, 4315, 24, 'Ups!'),
(92886, 4316, 24, 'Otwórz');
INSERT INTO `lang_definitions` VALUES
(92887, 4318, 24, 'Otwórz w nowym oknie'),
(92888, 4329, 24, 'Użytkownicy LibreEHR'),
(92889, 4336, 24, 'Opcjonalne'),
(92890, 4350, 24, 'Opcje'),
(92891, 4351, 24, 'Lub'),
(92892, 4352, 24, 'LUB'),
(92893, 4353, 24, 'lub wybierz'),
(92894, 4360, 24, 'Ustnie'),
(92895, 4363, 24, 'Typy i rezultaty zlecen'),
(92896, 4364, 24, 'Katalog zlecen'),
(92897, 4402, 24, 'Pozostały'),
(92898, 4403, 24, 'pozostały'),
(92899, 4420, 24, 'Pozostałe'),
(92900, 4424, 24, 'NDST'),
(92901, 4425, 24, 'Niedostępny (poza placówką)'),
(92902, 4427, 24, 'Wynik'),
(92903, 4451, 24, 'Ból'),
(92904, 4458, 24, 'Paraliż'),
(92905, 4463, 24, 'Partner'),
(92906, 4472, 24, 'Hasło'),
(92907, 4473, 24, 'Zmiana hasła'),
(92908, 4475, 24, 'Zmiana hasła zakończona powodzeniem.'),
(92909, 4486, 24, 'Hasło:'),
(92910, 4490, 24, 'Przeterminowane'),
(92911, 4491, 24, 'Przeterminowane'),
(92912, 4494, 24, 'Lista wizyt odbytych'),
(92913, 4495, 24, 'Wizyty odbyte'),
(92914, 4496, 24, 'Wizyty odbyte i dokumenty'),
(92915, 4514, 24, 'Pacjent'),
(92916, 4515, 24, 'pacjent'),
(92917, 4516, 24, 'PACJENT'),
(92918, 4517, 24, 'Adres pacjenta'),
(92919, 4518, 24, 'Brak adresu pacjenta'),
(92920, 4550, 24, 'Wyszukiwanie pacjentów'),
(92921, 4551, 24, 'Imię pacjenta'),
(92922, 4558, 24, 'Płeć pacjenta'),
(92923, 4561, 24, 'Historia pacjenta'),
(92924, 4587, 24, 'Problemy zdrowotne pacjenta'),
(92925, 4588, 24, 'Leki przepisane pacjentowi'),
(92926, 4589, 24, 'Nazwisko pacjenta'),
(92927, 4610, 24, 'Zażądaj dokumentacji medycznej'),
(92928, 4611, 24, 'Żądania dokumentacji medycznej'),
(92929, 4613, 24, 'Przypominacz dla pacjenta'),
(92930, 4614, 24, 'Wsadowe przetwarzanie przypominaczy pacjentów'),
(92931, 4615, 24, 'Priorytet procesu tworzącego przypominacze dla pacjentów'),
(92932, 4616, 24, 'Reguły dla przypominaczy dla pacjentów'),
(92933, 4619, 24, 'Przypominacze dla pacjentów'),
(92934, 4630, 24, 'Transakcje pacjenta'),
(92935, 4633, 24, 'Pacjent/Klient'),
(92936, 4634, 24, 'Pacjent:'),
(92937, 4636, 24, 'Pacjenci'),
(92938, 4638, 24, 'Zapłać'),
(92939, 4640, 24, 'Data płatności:'),
(92940, 4641, 24, 'Status płatności'),
(92941, 4642, 24, 'Odbiorca płatności'),
(92942, 4643, 24, 'Płatnik'),
(92943, 4644, 24, 'Rodzaj płatnika'),
(92944, 4647, 24, 'Płatność'),
(92945, 4648, 24, 'płatność'),
(92946, 4669, 24, 'PDF'),
(92947, 4677, 24, 'Oczekuje na wynik'),
(92948, 4678, 24, 'W oczekiwaniu na wynik'),
(92949, 4705, 24, 'Okres'),
(92950, 4718, 24, 'Apteka'),
(92951, 4729, 24, 'Telefon'),
(92952, 4740, 24, 'Światłowstręt'),
(92953, 4741, 24, 'Zdjęcia'),
(92954, 4768, 24, 'Plan'),
(92955, 4779, 24, 'Plan:'),
(92956, 4782, 24, 'Plany'),
(92957, 4900, 24, 'polski'),
(92958, 4917, 24, 'portugalski'),
(92959, 4918, 24, 'portugalski (Brazylia)'),
(92960, 4919, 24, 'portugalski (Europa)'),
(92961, 4938, 24, 'Kod Pocztowy'),
(92962, 4939, 24, 'Kod pocztowy'),
(92963, 4962, 24, 'Pref. kat'),
(92964, 4964, 24, 'Ustawienia'),
(92965, 4972, 24, 'Przedpłata'),
(92966, 4973, 24, 'Recepta'),
(92967, 4979, 24, 'Recepty'),
(92968, 4980, 24, 'Recepty i dawkowanie'),
(92969, 5001, 24, 'Poprzedni'),
(92970, 5003, 24, 'Poprzedni dzień'),
(92971, 5005, 24, 'Poprzedni miesiąc'),
(92972, 5007, 24, 'Cena'),
(92973, 5009, 24, 'Poziom cen'),
(92974, 5010, 24, 'Poziom cen:'),
(92975, 5011, 24, 'Ceny'),
(92976, 5027, 24, 'Drukuj'),
(92977, 5075, 24, 'Problem'),
(92978, 5110, 24, 'Typ procedury'),
(92979, 5113, 24, 'Procedura/Usługa'),
(92980, 5114, 24, 'Procedury'),
(92981, 5115, 24, 'Proces'),
(92982, 5129, 24, 'Produkt'),
(92983, 5132, 24, 'Produkty'),
(92984, 5134, 24, 'Prof.'),
(92985, 5136, 24, 'Rak prostaty'),
(92986, 5138, 24, 'Badanie prostaty'),
(92987, 5149, 24, 'Wpisz poprawny adres email'),
(92988, 5152, 24, 'Gab./Lekarz:'),
(92989, 5153, 24, 'ID gab./lekarza'),
(92990, 5154, 24, 'ID gab./lekarza'),
(92991, 5159, 24, 'Numer gab./lekarza'),
(92992, 5162, 24, 'Gab./Lekarz:'),
(92993, 5163, 24, 'Gabinety/Lekarze'),
(92994, 5245, 24, 'Rasa'),
(92995, 5246, 24, 'Rasa i poch etniczne'),
(92996, 5247, 24, 'Rasa/poch etniczne'),
(92997, 5270, 24, 'Przyczyna'),
(92998, 5272, 24, 'Przyczyna śmierci'),
(92999, 5276, 24, 'Przyczyna/Forma'),
(93000, 5317, 24, 'Dokumentacja'),
(93001, 5348, 24, 'Skierowania'),
(93002, 5350, 24, 'Skierowany przez'),
(93003, 5351, 24, 'Skierowany Przez'),
(93004, 5352, 24, 'Skierowany do'),
(93005, 5353, 24, 'Skierowujący'),
(93006, 5355, 24, 'Diagnoza Skierowującego'),
(93007, 5356, 24, 'Diagnoza skierowującego'),
(93008, 5358, 24, 'Polecający/Kierujący'),
(93009, 5363, 24, 'Odśwież'),
(93010, 5409, 24, 'Przypomnienie'),
(93011, 5413, 24, 'Przypomnienia'),
(93012, 5438, 24, 'Zdarzenie cykliczne'),
(93013, 5440, 24, 'Powt. się'),
(93014, 5446, 24, 'Raport'),
(93015, 5454, 24, 'Wyniki'),
(93016, 5463, 24, 'Raporty'),
(93017, 5485, 24, 'ZAREZERWOWANE'),
(93018, 5486, 24, 'Zarezerwowane'),
(93019, 5496, 24, 'Rozwiązany'),
(93020, 5515, 24, 'Ilość wyników na stronę'),
(93021, 5521, 24, 'Wróć do kalendarza'),
(93022, 5568, 24, 'Reguła'),
(93023, 5569, 24, 'Dodanie reguły'),
(93024, 5570, 24, 'Szczegóły reguły'),
(93025, 5572, 24, 'Edycja reguły'),
(93026, 5575, 24, 'Ustawienie reguły'),
(93027, 5578, 24, 'Reguły'),
(93028, 5580, 24, 'Konfiguracja reguł'),
(93029, 5581, 24, 'Uruchomiona komenda: '),
(93030, 5582, 24, 'Pęknięcie'),
(93031, 5583, 24, 'Rosyjski'),
(93032, 5601, 24, 'PESEL'),
(93033, 5609, 24, 'Ślina'),
(93034, 5617, 24, 'Sob'),
(93035, 5618, 24, 'Sob &amp; Nie'),
(93036, 5619, 24, 'Sobota'),
(93037, 5620, 24, 'Zapisz'),
(93038, 5621, 24, 'ZAPISZ'),
(93039, 5629, 24, 'Zapisz zmiany'),
(93040, 5630, 24, 'Zapisz formularz'),
(93041, 5631, 24, 'Zapisz szczepienie'),
(93042, 5632, 24, 'Zapisz nowe pole'),
(93043, 5633, 24, 'Zapisz nową grupę'),
(93044, 5634, 24, 'Zapisz nową listę'),
(93045, 5635, 24, 'Zapisz nowy szablon'),
(93046, 5648, 24, 'Skolioza'),
(93047, 5659, 24, 'Szukaj'),
(93048, 5661, 24, 'szukaj'),
(93049, 5662, 24, 'szukaj ponownie'),
(93050, 5663, 24, 'Przeszukaj wszystkie kolumny'),
(93051, 5664, 24, 'Szukaj wg:'),
(93052, 5665, 24, 'Szukaj'),
(93053, 5666, 24, 'Szukaj:'),
(93054, 5667, 24, 'Szukaj w'),
(93055, 5668, 24, 'Szukaj w'),
(93056, 5669, 24, 'Wyszukaj lub dodaj pacjenta'),
(93057, 5676, 24, 'Szukaj tekstu'),
(93058, 5678, 24, 'Szukaj/Dodaj'),
(93059, 5679, 24, 'Szukaj/Dodaj ubezpieczyciela'),
(93060, 5680, 24, 'Szukanie wizyt'),
(93061, 5681, 24, 'Poszukiwanie...'),
(93062, 5698, 24, 'Zabezpieczenia'),
(93063, 5699, 24, 'Wszystkie'),
(93064, 5708, 24, 'Wyb.'),
(93065, 5709, 24, 'Wybierz'),
(93066, 5710, 24, 'wybierz'),
(93067, 5715, 24, 'Wybierz użytkownika'),
(93068, 5716, 24, 'Wybierz wszystko'),
(93069, 5720, 24, 'Wybierz kategorię'),
(93070, 5727, 24, 'Wybierz datę'),
(93071, 5731, 24, 'Wybierz lek'),
(93072, 5732, 24, 'Wybierz leki'),
(93073, 5736, 24, 'Wybierz pole'),
(93074, 5737, 24, 'Wybierz pola'),
(93075, 5738, 24, 'Wybierz do druku'),
(93076, 5739, 24, 'Wybierz szczepienia'),
(93077, 5744, 24, 'Wybierz język'),
(93078, 5771, 24, 'Wyślij'),
(93079, 5772, 24, 'Wyślij przypomnienia'),
(93080, 5774, 24, 'Wysyłanie w toku'),
(93081, 5775, 24, 'Wyślij wiadomość'),
(93082, 5779, 24, 'Wyślij ten plik'),
(93083, 5780, 24, 'Wyślij ten komunikat'),
(93084, 5781, 24, 'Wysłany do'),
(93085, 5784, 24, 'Wysłany do wszystkich'),
(93086, 5788, 24, 'Nadawca'),
(93087, 5789, 24, 'ID nadawcy'),
(93088, 5790, 24, 'ID nadawcy (ISA06)'),
(93089, 5794, 24, 'Wrażliwości'),
(93090, 5795, 24, 'Istotność:'),
(93091, 5797, 24, 'Wysłano'),
(93092, 5812, 24, 'Wrz'),
(93093, 5813, 24, 'W separacji'),
(93094, 5814, 24, 'Wrzesień'),
(93095, 5847, 24, 'Przywróć domyślne'),
(93096, 5855, 24, 'Płeć'),
(93097, 5871, 24, 'Powienien zawierać dwie litery'),
(93098, 5872, 24, 'powienien zawierać 10 cyfr'),
(93099, 5873, 24, 'powinien zawierać wyłącznie 10 cyfr'),
(93100, 5874, 24, 'Ramię'),
(93101, 5875, 24, 'Ramię i obojczyk'),
(93102, 5876, 24, 'Problemy z ramieniem'),
(93103, 5877, 24, 'Pokaż'),
(93104, 5878, 24, 'Pokaż aktywne'),
(93105, 5880, 24, 'Pokaż wszystko'),
(93106, 5883, 24, 'Pokaż wszystkie transakcje'),
(93107, 5884, 24, 'Pokaż jako zajęty'),
(93108, 5889, 24, 'Pokaż dane szczegółowe'),
(93109, 5891, 24, 'Pokaż wykres'),
(93110, 5894, 24, 'Pokaż nieaktywne'),
(93111, 5896, 24, 'Pokaż menu'),
(93112, 5898, 24, 'Pokaż notatki'),
(93113, 5901, 24, 'Pokaż notatki pacjenta'),
(93114, 5905, 24, 'Pokaż przypomnienia'),
(93115, 5906, 24, 'Pokaż raport'),
(93116, 5915, 24, 'Wyświetla'),
(93117, 5920, 24, 'Bliźnięta'),
(93118, 5938, 24, 'Z poważaniem,'),
(93119, 5940, 24, 'Wolny/a'),
(93120, 5946, 24, 'Problemy z zatokami'),
(93121, 5947, 24, 'Operacja zatok'),
(93122, 5959, 24, 'Skóra'),
(93123, 5960, 24, 'Rak skóry'),
(93124, 5961, 24, 'Choroba skóry'),
(93125, 5970, 24, 'słowacki'),
(93126, 5978, 24, 'Bramka SMS'),
(93127, 5979, 24, 'Klucz API bramki SMS'),
(93128, 5980, 24, 'Klucz API bramki SMS'),
(93129, 5981, 24, 'Hasło bramki SMS'),
(93130, 5982, 24, 'Nazwa użytkownika bramki SMS'),
(93131, 5983, 24, 'Powiadomienia SMS'),
(93132, 5984, 24, 'Godziny powiadomień SMS'),
(93133, 6004, 24, 'Chrapanie'),
(93134, 6029, 24, 'Sortuj wg'),
(93135, 6030, 24, 'Sortuj Wg'),
(93136, 6048, 24, 'Źródło'),
(93137, 6049, 24, 'Plik źródłowy'),
(93138, 6050, 24, 'Ścieżka pliku źródłowego'),
(93139, 6057, 24, 'Źródło:'),
(93140, 6062, 24, 'hiszpański'),
(93141, 6111, 24, 'PESEL'),
(93142, 6112, 24, 'Zarządzanie certyfikatem SSL'),
(93143, 6113, 24, 'PESEL'),
(93144, 6124, 24, 'Start'),
(93145, 6128, 24, 'Data początkowa'),
(93146, 6131, 24, 'Data pocz:'),
(93147, 6132, 24, 'Data pocz:'),
(93148, 6133, 24, 'Czas początkowy'),
(93149, 6136, 24, 'Stan'),
(93150, 6151, 24, 'Statystyki'),
(93151, 6152, 24, 'Statystyczne'),
(93152, 6153, 24, 'Status'),
(93153, 6156, 24, 'Bez zmian'),
(93154, 6177, 24, 'Ulica'),
(93155, 6178, 24, 'Nr domu'),
(93156, 6179, 24, 'Ulica i numer'),
(93157, 6180, 24, 'Siła'),
(93158, 6185, 24, 'Udar mózgu'),
(93159, 6191, 24, 'Podkategoria'),
(93160, 6192, 24, 'podkategoria'),
(93161, 6198, 24, 'Zatwierdź'),
(93162, 6199, 24, 'zatwierdź'),
(93163, 6202, 24, 'Zapisz zdarzenie'),
(93164, 6203, 24, 'Zapisz formularz'),
(93165, 6205, 24, 'zatwierdzono'),
(93166, 6206, 24, 'Zatwierdzono przez'),
(93167, 6261, 24, 'Podsumowanie'),
(93168, 6265, 24, 'Nie'),
(93169, 6267, 24, 'Niedziela'),
(93170, 6290, 24, 'Zabiegi'),
(93171, 6291, 24, 'Chirurgia'),
(93172, 6292, 24, 'Lista dolegliwości chirurgicznych'),
(93173, 6300, 24, 'szwedzki'),
(93174, 6509, 24, 'Już istnieje otwarty wniosek o dostarczenie dokumentacji medycznej.'),
(93175, 6629, 24, 'Czw'),
(93176, 6630, 24, 'Czwartek'),
(93177, 6631, 24, 'Czwartek'),
(93178, 6638, 24, 'Czas'),
(93179, 6652, 24, 'Nazwa'),
(93180, 6658, 24, 'Do'),
(93181, 6659, 24, 'DO'),
(93182, 6660, 24, 'do'),
(93183, 6667, 24, 'Widok dla rozliczeń'),
(93184, 6684, 24, 'Aby połączyć to wizytę/konsultacje ze zgłoszoną dolegliwością, kliknij żądaną dolegliwość powyżej, aby podświetlić, a następnie kliknij przycisk [Zapisz]. Przytrzymaj klawisz [Ctrl], aby wybrać wiele problemów.'),
(93185, 6715, 24, 'Dzisiaj'),
(93186, 6716, 24, 'DZISIAJ'),
(93187, 6717, 24, 'dzisiaj'),
(93188, 6728, 24, 'Góra'),
(93189, 6792, 24, 'transakcje'),
(93190, 6793, 24, 'Transakcje'),
(93191, 6840, 24, 'Gruźlica'),
(93192, 6841, 24, 'Wto'),
(93193, 6843, 24, 'Wtorek'),
(93194, 6844, 24, 'Guz'),
(93195, 6845, 24, 'turecki'),
(93196, 6848, 24, 'dwa razy dziennie'),
(93197, 6851, 24, 'Typ'),
(93198, 6866, 24, 'Owrzodzenia'),
(93199, 6877, 24, 'Nieprzypisane'),
(93200, 6924, 24, 'do'),
(93201, 7015, 24, 'Pola użytkownika'),
(93202, 7049, 24, 'Użytkownik'),
(93203, 7055, 24, 'Użytkownik:'),
(93204, 7056, 24, 'Użytkownicy'),
(93205, 7062, 24, 'URLOP'),
(93206, 7063, 24, 'Urlop'),
(93207, 7107, 24, 'Pokaż logi'),
(93208, 7111, 24, 'Pokaż pacjenta'),
(93209, 7123, 24, 'Pokaż/Wydrukuj'),
(93210, 7133, 24, 'Kategoria wizyty:'),
(93211, 7134, 24, 'Data wizyty'),
(93212, 7135, 24, 'Data wizyty'),
(93213, 7137, 24, 'Historia formularzy'),
(93214, 7138, 24, 'Historia wizyt'),
(93215, 7140, 24, 'Wizyty'),
(93216, 7184, 24, 'Śro'),
(93217, 7185, 24, 'Środa'),
(93218, 7186, 24, 'Tydzień'),
(93219, 7187, 24, 'tydzień'),
(93220, 7188, 24, 'Widok tygodniowy'),
(93221, 7189, 24, 'Tygodni'),
(93222, 7192, 24, 'Tygodnie'),
(93223, 7193, 24, 'Waga'),
(93224, 7196, 24, 'Zmiana wagi ciała'),
(93225, 7197, 24, 'Utrata wagi ciała'),
(93226, 7199, 24, 'Witamy'),
(93227, 7212, 24, 'Biały'),
(93228, 7213, 24, 'Osoba'),
(93229, 7214, 24, 'Kto odpowiedział?'),
(93230, 7215, 24, 'Wdowiec/a'),
(93231, 7233, 24, 'Świadek'),
(93232, 7234, 24, 'tydz.'),
(93233, 7237, 24, 'Kobieta'),
(93234, 7240, 24, 'Praca'),
(93235, 7242, 24, 'Tel do zakł. pracy'),
(93236, 7243, 24, 'Tel do zakł. pracy'),
(93237, 7247, 24, 'dzień roboczy'),
(93238, 7252, 24, 'Pogorszenie'),
(93239, 7273, 24, 'x Anulowano'),
(93240, 7274, 24, 'x Anulowano'),
(93241, 7285, 24, 'Rok'),
(93242, 7286, 24, 'rok'),
(93243, 7287, 24, 'Widok lat'),
(93244, 7289, 24, 'Lat'),
(93245, 7290, 24, 'Lat lub miesięcy'),
(93246, 7292, 24, 'TAK'),
(93247, 7293, 24, 'Tak'),
(93248, 7294, 24, 'tak'),
(93249, 7295, 24, 'TAK!'),
(93250, 7298, 24, 'Tak/Nie'),
(93251, 7299, 24, 'Tak:'),
(93252, 7389, 24, 'Kod pocztowy'),
(93253, 7390, 24, 'Kod pocztowy'),
(93254, 7391, 24, 'Kod pocztowy/Kraj'),
(93255, 7397, 24, 'wiadomości email nie zostały wysłane'),
(93256, 7401, 24, 'Historia'),
(93257, 7407, 24, 'min'),
(93258, 7408, 24, 'nie znaleziono!'),
(93259, 7411, 24, 'do'),
(93260, 7415, 24, '! Wyszedł bez wizyty'),
(93261, 7418, 24, '# Problem z ubezp./płatnością'),
(93262, 7421, 24, '$ Rozliczono'),
(93263, 7424, 24, '% Anulowano < 24h'),
(93264, 7425, 24, '% Canceled < 24h '),
(93265, 7438, 24, '* Przypomniano'),
(93266, 7441, 24, '[+] Założono kartę'),
(93267, 7442, 24, '- Brak'),
(93268, 7443, 24, '-- Wszystko --'),
(93269, 7458, 24, '11-14'),
(93270, 7481, 24, 'co drugi'),
(93271, 7489, 24, 'co trzeci'),
(93272, 7504, 24, 'co czwarty'),
(93273, 7509, 24, 'co piąty'),
(93274, 7514, 24, 'co szósty'),
(93275, 7528, 24, '< W pokoju badań'),
(93276, 7529, 24, '> Wypisany'),
(93277, 7531, 24, '? Nie obecny'),
(93278, 7532, 24, '@ Pojawił się'),
(93279, 7533, 24, '[Zmień widok]'),
(93280, 7534, 24, '[Data ostatniej wizyty]'),
(93281, 7535, 24, '[Dni od ostatniej wizyty]'),
(93282, 7538, 24, '[nie zalecane]'),
(93283, 7539, 24, '[Ilość wizyt]'),
(93284, 7540, 24, '[Raporty]'),
(93285, 7541, 24, '[Wybierz wszystkie]'),
(93286, 7544, 24, '[Zobacz Logi]'),
(93287, 7545, 24, '[Raport do wydrukowania]'),
(93288, 7549, 24, '~ Spóźniony'),
(93289, 2167, 25, 'pozycji'),
(93290, 6638, 25, 'Czas'),
(93291, 6997, 25, 'Use Custom Immunisation List'),
(93292, 1, 26, 'Un'),
(93293, 2, 26, 'Numero assegno o identificativo pagamento'),
(93294, 3, 26, 'Un certificato del Client per l''utente admin'),
(93295, 4, 26, 'Un documento clinico è allegato'),
(93296, 5, 26, 'Un documento clinico è allegato.'),
(93297, 7, 26, 'E'' richiesto un distributore'),
(93298, 8, 26, 'Si dovrebbe aggiungere un modulo GCAC a questa visita.'),
(93299, 9, 26, 'Si richiede il numero del lotto'),
(93300, 10, 26, 'Si richiede il numero del lotto!'),
(93301, 11, 26, 'Lettera minuscola'),
(93302, 12, 26, 'Un numero'),
(93303, 14, 26, 'Esiste già un paziente con lo stesso ID'),
(93304, 15, 26, 'Esiste già un paziente con lo stesso nome'),
(93305, 16, 26, 'Esiste già un paziente con lo stesso CF'),
(93306, 17, 26, 'Un numero positivo mostrerà che molti appuntamenti passati su un widget nella schermata del sommario paziente(un numero negativo mostrerà gli appuntamenti passati nella videata sommario paziente).'),
(93307, 18, 26, 'Un numero positivo mostrerà che molti appuntamenti passati su un widget nella schermata del sommario paziente.'),
(93308, 19, 26, 'Una fonte di riferimento può essere specificata per ogni visita'),
(93309, 20, 26, 'Si richiede il relativo codice IPFF'),
(93310, 21, 26, 'Carattere speciale'),
(93311, 22, 26, 'Valore unico di identificazione per questo campo, non visibile all''utente'),
(93312, 23, 26, 'Oggi esiste già una visita per questo paziente. Clicca su Cancella per aprire, oppure OK per procedere alla creazione di una nuova visita'),
(93313, 24, 26, 'ante cibum'),
(93314, 25, 26, 'a.m.'),
(93315, 26, 26, 'A/F Giusto livello:'),
(93316, 27, 26, 'AB'),
(93317, 28, 26, 'Abbreviazione'),
(93318, 29, 26, 'Ascesso'),
(93319, 30, 26, 'Addominale'),
(93320, 31, 26, 'Capace di portare pesi per quattro passi'),
(93321, 32, 26, 'Anorm'),
(93322, 33, 26, 'ANORM1'),
(93323, 34, 26, 'Anormale'),
(93324, 35, 26, 'Esame del sangue anormale'),
(93325, 36, 26, 'Ipertricosi anomala'),
(93326, 37, 26, 'Mammogramma anormale'),
(93327, 39, 26, 'Aborto'),
(93328, 40, 26, 'Problemi di aborto'),
(93329, 41, 26, 'Metodo abortivo'),
(93330, 42, 26, 'Categorie relate ad aborto'),
(93331, 43, 26, 'Aborti'),
(93332, 44, 26, 'Informazioni calendario'),
(93333, 46, 26, 'Assenze per diagnosi'),
(93334, 47, 26, 'Accetta compito'),
(93335, 48, 26, 'Accetta pagamento per'),
(93336, 49, 26, 'Accetta pagamento per'),
(93337, 50, 26, 'Accetta compiti'),
(93338, 51, 26, 'Controllo d''accesso'),
(93339, 52, 26, 'Amministrazione elenchi dei controlli d''accesso'),
(93340, 53, 26, 'Accesso dati'),
(93341, 54, 26, 'Accesso non consentito'),
(93342, 55, 26, 'Accesso non autorizzato'),
(93343, 56, 26, 'Accedi al Portale del Paziente'),
(93344, 57, 26, 'Infortunio'),
(93345, 59, 26, 'Nome dell''account'),
(93346, 62, 26, 'Definizione dell''account'),
(93347, 64, 26, 'Dolori'),
(93348, 65, 26, 'Richiesta di conferma (ISA14'),
(93349, 66, 26, 'Conferme, licenze e certificazioni'),
(93350, 67, 26, 'ACL'),
(93351, 68, 26, 'Amministrazione ACL'),
(93352, 69, 26, 'Amministrazione ACL non autorizzata'),
(93353, 70, 26, 'ACL aggiornato con successo'),
(93354, 71, 26, 'Acne'),
(93355, 72, 26, 'Atto'),
(93356, 73, 26, 'Data Atto'),
(93357, 74, 26, 'Azione'),
(93358, 75, 26, 'Azioni'),
(93359, 77, 26, 'Attiva resoconti CCR/CCD'),
(93360, 78, 26, 'Attivo'),
(93361, 79, 26, 'Allarme attivo'),
(93362, 80, 26, 'Regole di attivazione allarme'),
(93363, 81, 26, 'Promemoria/Allarme attivi'),
(93364, 82, 26, 'Incontro attivo'),
(93365, 84, 26, 'Elenchi attivi'),
(93366, 85, 26, 'Paziente attivo'),
(93367, 86, 26, 'Piani attivi'),
(93368, 87, 26, 'Attività'),
(93369, 88, 26, 'Tipo di attività'),
(93370, 90, 26, 'Intossicazione acuta / Ritiro'),
(93371, 91, 26, 'Manifestazione acuta o condizione cronica'),
(93372, 92, 26, 'Acuto su cronico'),
(93373, 93, 26, 'aggiungi'),
(93374, 94, 26, 'Aggiungi'),
(93375, 95, 26, 'AGGIUNGI'),
(93376, 96, 26, 'Aggiungi un''Azienda'),
(93377, 98, 26, 'Aggiungi una Farmacia'),
(93378, 100, 26, 'aggiungi un evento per '),
(93379, 101, 26, 'Aggiungi come nuova nota'),
(93380, 102, 26, 'Aggiungi come Nuovo'),
(93381, 104, 26, 'Aggiungi Pulsanti'),
(93382, 105, 26, 'Aggiungi Pulsanti per caratteri speciali, testi che devono essere mostrati in cima all''editor per includerli nel testo con un cilck'),
(93383, 106, 26, 'Aggiungi come categoria'),
(93384, 107, 26, 'Aggiungi costante'),
(93385, 108, 26, 'Aggiungi Contesto'),
(93386, 109, 26, 'Aggiungi copagamento'),
(93387, 110, 26, 'Aggiungi Criteri'),
(93388, 111, 26, 'Aggiungi Pulsanti Personalizzati'),
(93389, 112, 26, 'Aggiungere diagnosi'),
(93390, 113, 26, 'Aggiungere farmaco'),
(93391, 114, 26, 'Aggiungere visita'),
(93392, 115, 26, 'Aggiungi incontro/note'),
(93393, 116, 26, 'Aggiungi Sede'),
(93394, 117, 26, 'Aggiungi Campo'),
(93395, 118, 26, 'Aggiungi le linee seguenti al file di configurazione di Apache'),
(93396, 119, 26, 'Aggiungi Gruppo'),
(93397, 120, 26, 'Aggiungi codice ICD'),
(93398, 121, 26, 'Aggiungi Immunizzazione'),
(93399, 122, 26, 'Aggiunte non autorizzate!'),
(93400, 123, 26, 'Aggiungi Problema'),
(93401, 124, 26, 'Aggiunta voce per tenere traccia'),
(93402, 125, 26, 'Aggiungi Lingua'),
(93403, 126, 26, 'Aggiungi Nuovo'),
(93404, 127, 26, 'Aggiungi nuovo'),
(93405, 128, 26, 'Aggiungi nuova categoria '),
(93406, 129, 26, 'Aggiungi nuovi certificati al file di configurazione di Apache'),
(93407, 130, 26, 'Aggiunta nuovo componente'),
(93408, 131, 26, 'Aggiunta nuovi componenti'),
(93409, 132, 26, 'Aggiungi Nuovo Gruppo'),
(93410, 133, 26, 'Aggiungi nuovo problema'),
(93411, 134, 26, 'Aggiungi nuovi lotto e transazione'),
(93412, 135, 26, 'Aggiungi Nuova Nota'),
(93413, 136, 26, 'Aggiungi nuova nota'),
(93414, 137, 26, 'Aggiungi Nuovo Partner'),
(93415, 138, 26, 'Aggiungi nuovo Paziente'),
(93416, 140, 26, 'Aggiungi Nota'),
(93417, 141, 26, 'Aggiungi Cartella Paziente'),
(93418, 142, 26, 'Aggiungi Prescrizione'),
(93419, 143, 26, 'Aggiungi Procedura'),
(93420, 144, 26, 'Aggiungi Numero Fornitore'),
(93421, 145, 26, 'Aggiungi Riabilit.'),
(93422, 146, 26, 'Aggiungi Regola'),
(93423, 147, 26, 'Aggiungi a'),
(93424, 148, 26, 'Aggiungi a Lista Medicazioni'),
(93425, 149, 26, 'Aggiungi Livello Top'),
(93426, 150, 26, 'Aggiungi Transazione'),
(93427, 151, 26, 'Aggiungi Utente'),
(93428, 152, 26, 'Aggiungi Utente a Gruppo'),
(93429, 153, 26, 'Aggiungi Modifica eRX'),
(93430, 154, 26, 'Aggiungi/Modifica Transazione Paziente'),
(93431, 155, 26, 'aggiunto'),
(93432, 156, 26, 'Aggiunta di dati personali non autorizzata'),
(93433, 157, 26, 'Aggiunta del prodotto per tenere traccia non riuscito'),
(93434, 158, 26, 'Sindrome di Addison'),
(93435, 159, 26, 'Sindrome di Addison'),
(93436, 160, 26, 'Attributi Aggiuntivi'),
(93437, 161, 26, 'Diagnosi Aggiuntiva:'),
(93438, 162, 26, 'Storia Aggiuntiva'),
(93439, 163, 26, 'Note storiche aggiuntive'),
(93440, 164, 26, 'Informazioni Aggiuntive'),
(93441, 165, 26, 'Laboratori Aggiuntivi'),
(93442, 166, 26, 'Note aggiuntive'),
(93443, 167, 26, 'Note aggiuntive per questo risultato o raccomandazione'),
(93444, 168, 26, 'Note aggiuntive:'),
(93445, 169, 26, 'Note aggiuntive: '),
(93446, 170, 26, 'Note aggiuntive a X-RAY/ Radiografia'),
(93447, 171, 26, 'Inoltre, il corrispondente statunitense SNOMED pacchetto di estensione può essere importato dopo aver installato l''Internazionale (versione inglese) SNOMED di rilascio'),
(93448, 172, 26, 'solo aggiunta'),
(93449, 173, 26, 'Indirizzario'),
(93450, 174, 26, 'Indirizzario'),
(93451, 175, 26, 'Indirizzo'),
(93452, 178, 26, 'Indirizzario'),
(93453, 179, 26, 'Campo indirizzo dell''azienda che fornisce questa procedura'),
(93454, 180, 26, 'Campo indirizzo per il distributore'),
(93455, 181, 26, 'Campo indirizzo per il venditore'),
(93456, 182, 26, 'Tipi di indirizzario'),
(93457, 183, 26, 'Etichetta indirizzo'),
(93458, 187, 26, 'Indirizzo 1'),
(93459, 188, 26, 'Indirizzo 2'),
(93460, 189, 26, 'DESTINATARIO'),
(93461, 190, 26, 'Mod.'),
(93462, 191, 26, 'Quantità di modifica'),
(93463, 192, 26, 'Modifica'),
(93464, 193, 26, 'Modifica'),
(93465, 194, 26, 'Modifica ammont.'),
(93466, 195, 26, 'Ragioni per la modifica'),
(93467, 196, 26, 'Valore di modifica per codice '),
(93468, 197, 26, 'Modifiche'),
(93469, 198, 26, 'Modifica ammin.'),
(93470, 199, 26, 'Ammin.'),
(93471, 200, 26, 'Email Amministratore'),
(93472, 201, 26, 'Somministrare via'),
(93473, 202, 26, 'Somministrato'),
(93474, 203, 26, 'Somministrato da'),
(93475, 204, 26, 'Somministrato in data'),
(93476, 205, 26, 'Sito amministrato'),
(93477, 206, 26, 'Amministrazione'),
(93478, 207, 26, 'Sito amministrato'),
(93479, 208, 26, 'Amministratori'),
(93480, 209, 26, 'gli Amministratori possono fare tutto'),
(93481, 210, 26, 'Data ammissione'),
(93482, 212, 26, 'Screening e Follow-Up del peso - Adulto'),
(93483, 213, 26, 'Screening e Follow-Up del peso - Adulto (CMQ)'),
(93484, 214, 26, 'Direttiva preliminare'),
(93485, 215, 26, 'Direttive preliminari'),
(93486, 216, 26, 'Avviso direttive preliminari'),
(93487, 218, 26, 'Avanzato'),
(93488, 219, 26, 'Suggerimento'),
(93489, 220, 26, 'Lontano'),
(93490, 221, 26, 'Effetto normale'),
(93491, 222, 26, 'Africani'),
(93492, 223, 26, 'Chiamate fuori orario'),
(93493, 224, 26, 'Dopo la migrazione dai vecchi meccanismi di password in cui le password vengono memorizzate nella tabella utenti senza salti è completo, questo flag deve essere impostato su false in modo che solo l''autenticazione con il nuovo metodo sia possibile'),
(93494, 225, 26, 'Dopo aver eseguito le configurazioni precedenti, importare il certificato di amministrazione client nel browser e riavviare il server Apache (password vuota)'),
(93495, 226, 26, 'Dopo il salvataggio in PDF, cliccare [Vedi log] per la verifica errori'),
(93496, 227, 26, 'Dopo il salvataggio dei file TEXT, cliccare [Vedi log] per la verifica errori'),
(93497, 228, 26, 'Dopo il salvataggio del lotto, cliccare [Vedi log] per la verifica errori'),
(93498, 229, 26, 'Dopo che la colonna Corrispondenza mostrerà l''ID paziente selezionato, o 0 per creare.'),
(93499, 230, 26, 'Dopo aver inserito l''informazione corretta cliccare il tasto Salva'),
(93500, 231, 26, 'Dopo aver caricato clicca il pulsante "Importa"'),
(93501, 232, 26, 'Pianificazione convalescenza'),
(93502, 233, 26, 'Nuovamente'),
(93503, 234, 26, 'Età'),
(93504, 235, 26, 'Età per'),
(93505, 236, 26, 'Categoria età'),
(93506, 237, 26, 'Dato età fuori intervallo'),
(93507, 238, 26, 'Visualizzazione formato età'),
(93508, 239, 26, 'Formato età per "età da" non valido'),
(93509, 240, 26, 'Formato età per "età fino a" non valido'),
(93510, 241, 26, 'Età da'),
(93511, 242, 26, 'Età in anni per visualizzare cambio formato'),
(93512, 243, 26, 'Età massima'),
(93513, 244, 26, 'Età minima'),
(93514, 245, 26, 'Intervallo età'),
(93515, 247, 26, 'Colonne età:'),
(93516, 248, 26, 'Akan'),
(93517, 249, 26, 'Albanese'),
(93518, 250, 26, 'Alcool'),
(93519, 251, 26, 'Consumo di alcool'),
(93520, 252, 26, 'Uso di alcool'),
(93521, 253, 26, 'Allarme su Conteggio'),
(93522, 255, 26, 'Allarmi'),
(93523, 258, 26, 'ALEUT'),
(93524, 259, 26, 'Tutto'),
(93525, 260, 26, 'TUTTO'),
(93526, 261, 26, 'Tutto (Raccolta in Formato A)'),
(93527, 262, 26, 'Tutto (Raccolta in Formato B)'),
(93528, 263, 26, 'Tutto (Cumulativo)'),
(93529, 265, 26, 'Tutti i calcoli di misura automatici (AMC)'),
(93530, 266, 26, 'Tutte le categorie'),
(93531, 267, 26, 'Tutte le misure di qualità clinica (CQM)'),
(93532, 268, 26, 'Tutti i codici'),
(93533, 269, 26, 'Tutta la giornata'),
(93534, 270, 26, 'Evento giornata intera'),
(93535, 271, 26, 'Tutti i campi anagrafici, con ricerca e controllo duplicazioni'),
(93536, 272, 26, 'Tutte le sedi'),
(93537, 273, 26, 'Tutte(i) Lesioni/Problemi/Questioni'),
(93538, 274, 26, 'Tutte le lingue permesse'),
(93539, 275, 26, 'Tutte le ufficiali misure di qualità clinica (CQM) Misura Gruppi'),
(93540, 276, 26, 'Tutto o parte del nome'),
(93541, 277, 26, 'Tutto o parte del cognome'),
(93542, 278, 26, 'Tutto o parte dell''organizzazione'),
(93543, 279, 26, 'Tutti i pazienti'),
(93544, 280, 26, 'Tutti i prodotti'),
(93545, 281, 26, 'Tutti i fornitori'),
(93546, 282, 26, 'Tutte le revisioni e i negativi:'),
(93547, 283, 26, 'Tutti gli argomenti'),
(93548, 284, 26, 'Tutti gli utenti'),
(93549, 285, 26, 'Allergico/a'),
(93550, 286, 26, 'Allergie'),
(93551, 287, 26, 'Allergie:'),
(93552, 288, 26, 'Allergia'),
(93553, 289, 26, 'Importazione Allergie completata con successo'),
(93554, 290, 26, 'Emissione elenco allergia'),
(93555, 291, 26, 'Reazione allergica'),
(93556, 294, 26, 'Allocare'),
(93557, 295, 26, 'Consenti'),
(93558, 296, 26, 'Permette tutte le lingue disponibili come scelta nel menu di login.'),
(93559, 297, 26, 'Permette la creazione di affermazioni contenenti diagnosi ma non procedure o addebiti. Molti ospedali non lo permettono.'),
(93560, 298, 26, 'Consenti il debug della lingua'),
(93561, 299, 26, 'Consenti email'),
(93562, 300, 26, 'Consenti messaggi email?'),
(93563, 301, 26, 'Consenti email?'),
(93564, 302, 26, 'Consenti notifiche visite'),
(93565, 303, 26, 'Consenti trasmissione di informazioni sanitarie'),
(93566, 304, 26, 'Consenti condivisione informazioni di immunizzazione'),
(93567, 305, 26, 'Consenti uso del registro immunizzazioni'),
(93568, 306, 26, 'Consenti messaggio email'),
(93569, 308, 26, 'Consenti il Portale paziente'),
(93570, 309, 26, 'Consenti SMS'),
(93571, 310, 26, 'Consenti SMS (messaggi di testo)?'),
(93572, 311, 26, 'Consenti l''attivazione istantanea degli eventi immessi?'),
(93573, 312, 26, 'Consenti messaggi telefonici?'),
(93574, 313, 26, 'Consenti agli utenti la pubblicazione di eventi globali'),
(93575, 314, 26, 'Consenti agli utenti di pubblicare calendari personali'),
(93576, 315, 26, 'Consenti messaggi vocali'),
(93577, 316, 26, 'Consentito'),
(93578, 317, 26, 'Lingue consentite'),
(93579, 318, 26, 'Consentito'),
(93580, 319, 26, 'Consente E-Sign sull''intero incontro'),
(93581, 320, 26, 'Consente E-Signing nei singoli forms'),
(93582, 321, 26, 'Mail consentite'),
(93583, 322, 26, 'Messaggi vocali consentiti'),
(93584, 323, 26, 'esiste già'),
(93585, 324, 26, 'esiste già'),
(93586, 325, 26, 'Già usato, scegliere un altro identificatore'),
(93587, 326, 26, 'Già usato, scegliere un altro titolo'),
(93588, 327, 26, 'Indirizzo alternativo'),
(93589, 328, 26, 'altera'),
(93590, 329, 26, 'Alternativamente, si può usare la pagina di ricerca per caricare un file di pagamento elettronico (X12 835) ottenuto dal pagante o ente sostitutivo. Puoi fare questo cliccando il bottone "Sfoglia" e selezionando il file da caricare, quindi cliccando "Cerca" per attuare il caricamento e mostrare il conto corrispondente. In questo caso gli altri parametri menzionati sopra non si applicano e sarnno ignorati. Il caricamento salva il file ma non processa ancora i suoi contenuti -- ciò è fatto separatamente come descritto sotto.'),
(93591, 330, 26, 'AM'),
(93592, 331, 26, 'Programma AM'),
(93593, 332, 26, 'AMC'),
(93594, 333, 26, 'Traccia AMC'),
(93595, 334, 26, 'AMC-2011'),
(93596, 335, 26, 'AMC-2014'),
(93597, 338, 26, 'Modificare la nota esistente'),
(93598, 339, 26, 'Modificato da'),
(93599, 340, 26, 'Stato modifiche'),
(93600, 341, 26, 'Modifiche'),
(93601, 342, 26, 'Modificati per'),
(93602, 343, 26, 'Indiano americano'),
(93603, 344, 26, 'Indiano americano o nativo dell''Alaska'),
(93604, 345, 26, 'AMEX'),
(93605, 346, 26, 'Amarico'),
(93606, 347, 26, 'Importo'),
(93607, 348, 26, 'Importo amministrato'),
(93608, 349, 26, 'Importo Spese'),
(93609, 350, 26, 'Importo per conto precedente'),
(93610, 351, 26, 'Importo per questa visita'),
(93611, 352, 26, 'Importo pagato'),
(93612, 353, 26, 'Importo:'),
(93613, 354, 26, 'Importo fatturato'),
(93614, 355, 26, 'La data di fine oltre la data di inizio è richiesta per gli eventi ripetuti!'),
(93615, 357, 26, 'Si è verificato un errore nel salvataggio delle directory di LibreEHR'),
(93616, 358, 26, 'Si è verificato un errore nel salvataggio delle directory di phpGACL'),
(93617, 359, 26, 'Si è verificato un errore nel salvataggio delle directory di SQL_Ledger'),
(93618, 360, 26, 'E'' stato creato e linkato un oggetto GCAC incompleto. E'' necessario completarlo in seguito.'),
(93619, 362, 26, 'Si è verificato un errore inatteso'),
(93620, 363, 26, 'Lettera maiuscola'),
(93621, 365, 26, 'e'),
(93622, 366, 26, 'E'),
(93623, 367, 26, 'e'),
(93624, 368, 26, 'e '),
(93625, 369, 26, 'e tutti i dati subordinati? Quest''azione sarà registrata'),
(93626, 370, 26, 'modificatore and'),
(93627, 371, 26, 'e processato.'),
(93628, 372, 26, 'e riavviare il server Apache.'),
(93629, 373, 26, 'e il motivo è'),
(93630, 374, 26, 'Anemia'),
(93631, 375, 26, 'Caviglia'),
(93632, 376, 26, 'Caviglia + tallone'),
(93633, 377, 26, 'Modello di valutazione caviglia'),
(93634, 378, 26, 'Problemi caviglia'),
(93635, 379, 26, 'Spondilite anchilosante'),
(93636, 380, 26, 'Spondilite anchilosante'),
(93637, 381, 26, 'Anoressia'),
(93638, 382, 26, 'Un''altra azione possibile nella finestra di immissione è la richiesta di fatturazione secondaria. Se si seleziona questa spunta prima del salvataggio, l''addebito originale sarà riaperto e accodato alla pagina di Fatturazione, e riprocessato nella nuova procedura di fatturazione.'),
(93639, 383, 26, 'ante'),
(93640, 384, 26, 'Ano normale, no masse o cedevolezze'),
(93641, 385, 26, 'Ansia'),
(93642, 386, 26, 'Qualunque'),
(93643, 387, 26, 'Qualunque categoria'),
(93644, 388, 26, 'Parte del codice desiderato o della sua descrizione'),
(93645, 389, 26, 'Parte della specializzazione desiderata'),
(93646, 390, 26, 'Parte del nome o dell''ID del farmaco'),
(93647, 391, 26, 'Parte del nome o dell''ID dell''immunizzazione'),
(93648, 392, 26, 'Parte del nome paziente, o "cognome,nome", o "X-Y"'),
(93649, 393, 26, 'Qualsiasi altra informazione rilevante'),
(93650, 394, 26, 'Chiave API per il Gateway SMS'),
(93651, 395, 26, 'Apnea'),
(93652, 396, 26, 'Aspetto'),
(93653, 397, 26, 'Aspetto:'),
(93654, 398, 26, 'Accoda questa nota'),
(93655, 399, 26, 'Accoda alla nota esistente'),
(93656, 400, 26, 'Accoda a questa nota'),
(93657, 401, 26, 'Accoda a questa nota'),
(93658, 402, 26, 'Appendicectomia'),
(93659, 403, 26, 'appendicectomia'),
(93660, 404, 26, 'Pazienti pertinenti'),
(93661, 405, 26, 'Applicazione'),
(93662, 406, 26, 'Nome dell''applicazione per la pagina di login e per il titolo della finestra principale'),
(93663, 407, 26, 'Applicazione codice ricezione (GS03 - Se vuoto verrà utilizzato ISA08)'),
(93664, 408, 26, 'Codice invio applicazione (GS02)'),
(93665, 409, 26, 'Titolo applicazione'),
(93666, 410, 26, 'Applica al modello parametri vitali e al diagramma di crescita'),
(93667, 411, 26, 'Applica al modello Vitali'),
(93668, 412, 26, 'Applica i cambiamenti al solo evento corrente, a questa e a tutte le occorrenze future o a tutte?'),
(93669, 413, 26, 'applicare all''area interessata'),
(93670, 414, 26, 'applicare sulla pelle'),
(93671, 415, 26, 'In applicazione'),
(93672, 416, 26, 'Applicazione patch al sito'),
(93673, 417, 26, 'Appuntamento'),
(93674, 418, 26, 'Data appuntamento'),
(93675, 419, 26, 'Stile visualizzazione appuntamenti'),
(93676, 420, 26, 'Regole Promemoria appuntamento'),
(93677, 421, 26, 'Stato appuntamenti'),
(93678, 422, 26, 'Stati appuntamenti'),
(93679, 423, 26, 'Appuntamento entro'),
(93680, 424, 26, 'Colore appuntamento/evento'),
(93681, 425, 26, 'Appuntamenti'),
(93682, 426, 26, 'Appuntamenti (scrittura facoltativa)'),
(93683, 427, 26, 'Appuntamenti (scrittura facoltativa)'),
(93684, 430, 26, 'Appuntamenti e Incontri'),
(93685, 431, 26, 'Resoconto appuntamenti'),
(93686, 432, 26, 'Resoconto Appuntamenti-Incontri'),
(93687, 434, 26, 'Approva'),
(93688, 435, 26, 'Approva il paziente da Paziente/Cliente->Importare->Attesa approvazione'),
(93689, 436, 26, 'Approvato'),
(93690, 437, 26, 'Amministrazione eventi approvati'),
(93691, 438, 26, 'Approvato con successo'),
(93692, 440, 26, 'Appunt.-Incontri'),
(93693, 441, 26, 'App.nti'),
(93694, 442, 26, 'Apr'),
(93695, 443, 26, 'Aprile'),
(93696, 444, 26, 'Arabo'),
(93697, 445, 26, 'Aragonese'),
(93698, 446, 26, 'Archivio'),
(93699, 447, 26, 'I nomi dei gruppi ad accesso controllato devono essere tradotti?'),
(93700, 448, 26, 'I nomi delle categorie di appuntamenti devono essere tradotti?'),
(93701, 449, 26, 'I nomi delle categorie di documenti devono essere tradotti?'),
(93702, 450, 26, 'Le tariffe vengono addebitate per questo tipo?'),
(93703, 451, 26, 'I titoli delle note paziente devono essere tradotti?'),
(93704, 452, 26, 'I codici memorizzati in tabelle SQL esterne (0-No, 1-ICD10, 2-SNOMED (RF1), 3-SNOMED (RF2))?'),
(93705, 453, 26, 'Si è preparati per completare una nuova GCAC per questa visita?'),
(93706, 454, 26, 'Sei sicuro di voler postare per oggi?'),
(93707, 455, 26, 'Sei sicuro di voler approvare questi eventi?'),
(93708, 457, 26, 'Sei sicuro di voler eliminare completamente questo modulo?'),
(93709, 458, 26, 'Sei sicuro di voler eliminare'),
(93710, 459, 26, 'Sei sicuro di voler eliminare questa informativa?'),
(93711, 460, 26, 'Sei sicuro di voler eliminare questo evento?'),
(93712, 461, 26, 'Sei sicuro di voler eliminare questo elemento dal database?'),
(93713, 462, 26, 'Sei sicuro di voler eliminare questa nota?'),
(93714, 464, 26, 'Sei sicuro di voler modificare questi eventi?'),
(93715, 465, 26, 'Sei sicuro di voler nascondere questi eventi?'),
(93716, 466, 26, 'Sei sicuro di voler trasmettere ancora?'),
(93717, 467, 26, 'Sei sicuro di voler vedere questi eventi?'),
(93718, 468, 26, 'Sei sicuro di voler eliminare l''intero gruppo chiamato'),
(93719, 469, 26, 'Sei sicuro di voler eliminare tutto l''elenco'),
(93720, 470, 26, 'Sei sicuro di voler eliminare il campo in'),
(93721, 471, 26, 'Sei sicuro di voler eliminare i campi selezionati?'),
(93722, 472, 26, 'Sei sicuro di voler continuare con queste azioni?'),
(93723, 473, 26, 'Area non specificata'),
(93724, 474, 26, 'Braccio'),
(93725, 475, 26, 'Armenia'),
(93726, 477, 26, 'Aritmia'),
(93727, 478, 26, 'Artrite'),
(93728, 479, 26, 'Artrite / degenerazione articolare'),
(93729, 480, 26, 'Artrite / degenerazione articolare'),
(93730, 481, 26, 'come'),
(93731, 482, 26, 'Come di'),
(93732, 483, 26, 'ASC'),
(93733, 484, 26, 'Asiatico'),
(93734, 485, 26, 'Assamese'),
(93735, 487, 26, 'Valutazione'),
(93736, 488, 26, 'Assegnato a'),
(93737, 489, 26, 'Assistente'),
(93738, 490, 26, 'Asma'),
(93739, 491, 26, 'alle'),
(93740, 492, 26, 'Se selezioni tutto, almeno un parametro di ricerca è richiesto.'),
(93741, 493, 26, 'Allo scafoide'),
(93742, 494, 26, 'Allo scafoide:'),
(93743, 495, 26, 'Squadra di atletica'),
(93744, 496, 26, 'Squadra di atletica'),
(93745, 497, 26, 'Lesione/Atletica'),
(93746, 498, 26, 'ATNA controllo certificato CA'),
(93747, 499, 26, 'ATNA controllo host'),
(93748, 500, 26, 'ATNA controllo certificato locale'),
(93749, 501, 26, 'ATNA controllo porta'),
(93750, 503, 26, 'Attenzione'),
(93751, 504, 26, 'Att. ne'),
(93752, 506, 26, 'Registrazione motore queries CDR'),
(93753, 507, 26, 'Registro di controllo antimanomissione'),
(93754, 508, 26, 'Registro di controllo antimanomissione report'),
(93755, 509, 26, 'Registrazione di controllo backup'),
(93756, 510, 26, 'Registrazione di controllo varie'),
(93757, 511, 26, 'Registrazione di controllo ordini'),
(93758, 512, 26, 'Registrazione di controllo accesso cartelle cliniche'),
(93759, 513, 26, 'Pianificazione del controllo di accesso'),
(93760, 514, 26, 'Registrazione di controllo di Amministrazione sicurezza'),
(93761, 515, 26, 'Seleziona la query del controllo di accesso'),
(93762, 516, 26, 'Ago'),
(93763, 517, 26, 'Agosto'),
(93764, 519, 26, 'Aut'),
(93765, 520, 26, 'Aut/note'),
(93766, 523, 26, 'Autorizzazioni di gruppo'),
(93767, 524, 26, 'Stato autorizzazione'),
(93768, 525, 26, 'Autorizzazioni'),
(93769, 526, 26, 'Autorizza'),
(93770, 527, 26, 'Autorizza - qualsiasi incontro'),
(93771, 528, 26, 'Autorizza - i miei incontri'),
(93772, 529, 26, 'Authorize.net'),
(93773, 530, 26, 'Autorizzato'),
(93774, 531, 26, 'Solo autorizzati'),
(93775, 532, 26, 'Invio automatico'),
(93776, 535, 26, 'Crea automaticamente nuovi incontri'),
(93777, 536, 26, 'Generato automaticamente'),
(93778, 537, 26, 'Calcoli delle misure automatici (AMC)'),
(93779, 538, 26, 'Calcoli delle misure automatici (AMC) - 2011'),
(93780, 539, 26, 'Calcoli delle misure automatici (AMC) - 2014'),
(93781, 542, 26, 'Calcoli delle misure automatici (AMC) monitoraggio'),
(93782, 543, 26, 'Misure automatiche (AMC)'),
(93783, 544, 26, 'Automatico'),
(93784, 546, 26, 'Crea automaticamente un nuovo incontro quando lo status dell''appuntamento è settato a "@" (arrivato).'),
(93785, 549, 26, 'Automobile Medica'),
(93786, 550, 26, 'salvato in automatico'),
(93787, 551, 26, 'Categorie disponibili'),
(93788, 552, 26, 'Tempi disponibili'),
(93789, 553, 26, 'Tracce disponibili'),
(93790, 554, 26, 'Avaric'),
(93791, 555, 26, 'Avery tipo etichette per la stampa di etichette di pazienti da popup a schermo nav sinistra'),
(93792, 556, 26, 'Avestan'),
(93793, 557, 26, 'Media Mensile'),
(93794, 558, 26, 'Avulsione/frattura avulsa'),
(93795, 559, 26, 'Avulsione del malleolo laterale'),
(93796, 560, 26, 'Avulsione del malleolo mediale '),
(93797, 561, 26, 'Basato sulla consapevolezza'),
(93798, 562, 26, 'Ascellare'),
(93799, 563, 26, 'Aymara'),
(93800, 564, 26, 'Azerbaijani'),
(93801, 565, 26, 'b.i.d(bis in die)'),
(93802, 566, 26, 'Indietro'),
(93803, 567, 26, 'indietro'),
(93804, 568, 26, 'Indietro di 8 visite'),
(93805, 569, 26, 'Indietro di 11 visite'),
(93806, 570, 26, 'Indietro di 5 visite'),
(93807, 571, 26, 'Indietro di 4 visite'),
(93808, 572, 26, 'Indietro di 9 visite'),
(93809, 573, 26, 'Indietro di 1 visita'),
(93810, 574, 26, 'Dolore alla schiena'),
(93811, 575, 26, 'Problemi alla schiena'),
(93812, 576, 26, 'Indietro di 7 visite'),
(93813, 577, 26, 'Indietro di 6 visite'),
(93814, 578, 26, 'Intervento alla schiena'),
(93815, 579, 26, 'Indietro di 10 visite'),
(93816, 580, 26, 'Indietro di 3 visite'),
(93817, 581, 26, 'Indietro alla pagina Admin'),
(93818, 582, 26, 'Torna alle visite'),
(93819, 583, 26, 'Torna al Paziente'),
(93820, 584, 26, 'Torna al Paziente'),
(93821, 585, 26, 'Torna agli utenti'),
(93822, 586, 26, 'Torna alla vista'),
(93823, 587, 26, 'Indietro di 12 visite'),
(93824, 588, 26, 'Indietro di 2 visite'),
(93825, 589, 26, 'Servizi in Background'),
(93826, 590, 26, 'Backup'),
(93827, 591, 26, 'Il file di Backup è stato creato. Ora sarà inviato.'),
(93828, 592, 26, 'Lista di Backup'),
(93829, 593, 26, 'Backup attuato con successo in'),
(93830, 594, 26, 'Assegno non buono'),
(93831, 595, 26, 'Debito insoluto'),
(93832, 596, 26, 'Bahasa Indonesia'),
(93833, 597, 26, 'Bal'),
(93834, 598, 26, 'Bilancio'),
(93835, 599, 26, 'bilancio'),
(93836, 600, 26, 'Ammont.dovuto'),
(93837, 601, 26, 'Saldo dovuto'),
(93838, 602, 26, 'Bambara'),
(93839, 603, 26, 'Assegno bancario'),
(93840, 604, 26, 'Etichetta Barcode'),
(93841, 605, 26, 'Tipo etichetta Barcode'),
(93842, 606, 26, 'Tipo di codice a barre per la stampa di etichette con codice a barre da popup a schermo di navigazione a sinistra.'),
(93843, 607, 26, 'Base del quinto Metarsale'),
(93844, 608, 26, 'Base del quinto Metarsale'),
(93845, 609, 26, 'Bashkir'),
(93846, 610, 26, 'Basque'),
(93847, 611, 26, 'Batch richiesta'),
(93848, 612, 26, 'Batch strumento di comunicazione'),
(93849, 613, 26, 'Batch entrata pagamenti'),
(93850, 614, 26, 'Batch pagamenti'),
(93851, 615, 26, 'Elaborazione batch avviata, l''operazione potrebbe richiedere un po ''.'),
(93852, 616, 26, 'Risultati Batch'),
(93853, 617, 26, 'BatchCom'),
(93854, 618, 26, 'Siate pazienti, alcuni file possono richiedere diversi minuti per essere elaborati!'),
(93855, 619, 26, 'perchè quell''id non esiste.'),
(93856, 620, 26, 'Inizio'),
(93857, 621, 26, 'Data inizio'),
(93858, 623, 26, 'Data inizio del servizio aaaa-mm-gg'),
(93859, 624, 26, 'Ora del giorno iniziale per gli eventi del calendario.'),
(93860, 625, 26, 'Belarusian'),
(93861, 626, 26, 'Ruttare'),
(93862, 628, 26, 'Bengalese'),
(93863, 629, 26, 'Bengali- Bangla'),
(93864, 630, 26, 'tra'),
(93865, 631, 26, 'Bidirezionale'),
(93866, 632, 26, 'Bihari'),
(93867, 633, 26, 'Bilaterale'),
(93868, 634, 26, 'Bilaterale:'),
(93869, 636, 26, 'Data Fattura:'),
(93870, 637, 26, 'Fattura/Raccolta'),
(93871, 638, 26, 'Fatturato'),
(93872, 640, 26, 'In fatturazione'),
(93873, 641, 26, 'Fatturazione(scrittura opzionale)'),
(93874, 642, 26, 'Att. ne fatturazione'),
(93875, 644, 26, 'Codice di fatturazione per il servizio richiesto'),
(93876, 645, 26, 'Codici fatturazione'),
(93877, 646, 26, 'Data fatturazione'),
(93878, 647, 26, 'Reaparto di fatturazione'),
(93879, 648, 26, 'Sede fatturazione'),
(93880, 649, 26, 'Informazioni di fatturazione'),
(93881, 650, 26, 'Località fatturazione'),
(93882, 655, 26, 'Gestore fatturazioni'),
(93883, 656, 26, 'Nota di fatturazione'),
(93884, 657, 26, 'Nota di fatturazione per '),
(93885, 658, 26, 'Nota di fatturazione:'),
(93886, 659, 26, 'Risultati della coda di fatturazione'),
(93887, 660, 26, 'Resoconto fatturazioni'),
(93888, 661, 26, 'Stato fatturazione'),
(93889, 662, 26, 'Stato fatturazione: Non fatturato'),
(93890, 663, 26, 'fatturare a '),
(93891, 665, 26, 'Biopsia'),
(93892, 666, 26, 'Data di Nascita'),
(93893, 667, 26, 'Nascita-24 mesi'),
(93894, 668, 26, 'Bislama'),
(93895, 669, 26, 'Nero'),
(93896, 670, 26, 'Polmone nero'),
(93897, 671, 26, 'Nero o Afro Americano'),
(93898, 672, 26, 'Cancro alla vescica'),
(93899, 673, 26, 'Infezione alla vescica'),
(93900, 674, 26, 'Modulo in bianco'),
(93901, 675, 26, 'Problemi di sanguinamento'),
(93902, 676, 26, 'Punti ciechi'),
(93903, 677, 26, 'Gonfiore/meteorismo'),
(93904, 678, 26, 'Bloccato'),
(93905, 679, 26, 'Sangue'),
(93906, 680, 26, 'Pressione sanguigna'),
(93907, 681, 26, 'Pressione sanguigna'),
(93908, 682, 26, 'Naso sanguinante'),
(93909, 683, 26, 'Schermo blu trasversale blu'),
(93910, 684, 26, 'Le linee blu in questo resoconto sono informative. Le linee nere mostrano una informazione precedentemente esistente. Le linee verdi mostrano i cambiamenti che sono stati apportati con successo. Le linee rosse indicano errori, o cambiamenti che non sono stati apportati; queste dovranno essere processate manualmente. Attualmente le richieste respinte e gli storni di pagamento non sono gestiti automaticaente e così appaiono in rosso.'),
(93911, 685, 26, 'Visione offuscata'),
(93912, 686, 26, 'BMI'),
(93913, 687, 26, 'Status BMI'),
(93914, 689, 26, 'Regione corporea'),
(93915, 690, 26, 'Sito corporeo'),
(93916, 691, 26, 'Sito corporeo, se applicabile'),
(93917, 692, 26, 'Dolori ossei'),
(93918, 693, 26, 'Dolori ossei: Malleolo mediale'),
(93919, 694, 26, 'Booleana'),
(93920, 695, 26, 'Bosnian'),
(93921, 696, 26, 'In basso'),
(93922, 697, 26, 'Entrambe le orecchie'),
(93923, 698, 26, 'entrambe le orecchie'),
(93924, 699, 26, 'In basso'),
(93925, 701, 26, 'BOX 10 A. Correlato al lavoro '),
(93926, 702, 26, 'BOX 10 B. Incidente d''auto '),
(93927, 703, 26, 'BOX 10 C. Altro incidente '),
(93928, 704, 26, 'BOX 14 qualificatore dati'),
(93929, 705, 26, 'BOX 15 altro qualificatore dati'),
(93930, 706, 26, 'BOX 15. Data di malattia uguale o simile (aaaa-mm-gg):'),
(93931, 707, 26, 'BOX 15. Data di malattia uguale o simile/Altra data (aaaa-mm-gg):'),
(93932, 708, 26, 'BOX 16. Data di inabilità al lavoro dal (aaaa-mm-gg):'),
(93933, 709, 26, 'BOX 16. Data inabilità al lavoro fino al (aaaa-mm-gg):'),
(93934, 710, 26, 'BOX 18. Data ospedalizzazione dal (aaaa-mm-gg): '),
(93935, 711, 26, 'BOX 18. Data ospedalizzazione fino al (aaaa-mm-gg): '),
(93936, 712, 26, 'BOX 20. Si è utilizzato un Laboratorio esterno?'),
(93937, 713, 26, 'BOX 22. Medicaid Codice ripresentazione (ICD-9) '),
(93938, 714, 26, 'BOX 23. Autorizzazione precedente Nr. '),
(93939, 715, 26, 'BP'),
(93940, 716, 26, 'BP Diastolica'),
(93941, 717, 26, 'BP Sistolica'),
(93942, 719, 26, 'Bpd'),
(93943, 721, 26, 'Bps'),
(93944, 722, 26, 'Potoghese Brasiliano'),
(93945, 723, 26, 'Seno'),
(93946, 724, 26, 'Biopsia al seno'),
(93947, 725, 26, 'Seno scarico'),
(93948, 726, 26, 'Malattia del seno'),
(93949, 727, 26, 'Esame mammario'),
(93950, 728, 26, 'Massa dei seni'),
(93951, 730, 26, 'Rumori respiratori:'),
(93952, 731, 26, 'Breton'),
(93953, 732, 26, 'Fratture'),
(93954, 733, 26, 'modulo rottura'),
(93955, 734, 26, 'Forma bronchitica'),
(93956, 735, 26, 'Consulta'),
(93957, 736, 26, 'Consulta i Record'),
(93958, 737, 26, 'Contusione/Ematoma'),
(93959, 738, 26, 'Bulgaro'),
(93960, 739, 26, 'Bulging di destra:'),
(93961, 740, 26, 'Burmese'),
(93962, 741, 26, 'Bruciore alla minzione'),
(93963, 742, 26, 'Bruciore alla minzione'),
(93964, 743, 26, 'Telefono aziendale'),
(93965, 744, 26, 'Occupato'),
(93966, 745, 26, 'ma non ancora processato.'),
(93967, 746, 26, 'Natica'),
(93968, 747, 26, 'Natica + S.I.'),
(93969, 748, 26, 'da'),
(93970, 749, 26, 'Da'),
(93971, 750, 26, 'per via orale'),
(93972, 751, 26, 'Da/Origine'),
(93973, 752, 26, 'Da:'),
(93974, 753, 26, 'C'),
(93975, 754, 26, 'Certificato CA per la verifica del RFC 5425 TLS syslog server.'),
(93976, 755, 26, 'Tempo di vita della Cache (in secondi)'),
(93977, 756, 26, 'Cache modelli output?'),
(93978, 757, 26, 'Consumo di caffeina'),
(93979, 758, 26, 'Agenda'),
(93980, 759, 26, 'Ora finale dell''Agenda'),
(93981, 760, 26, 'Intervallo dell''Agenda'),
(93982, 761, 26, 'Schermata Agenda'),
(93983, 762, 26, 'Specifiche Agenda'),
(93984, 763, 26, 'Ora iniziale del Agenda'),
(93985, 764, 26, 'UI dell''Agenda'),
(93986, 765, 26, 'Vista del Agenda'),
(93987, 766, 26, 'La chiamata a addForm() va qui.<br>'),
(93988, 767, 26, 'Calorie'),
(93989, 768, 26, 'Cambogiano'),
(93991, 774, 26, 'Annulla'),
(93992, 775, 26, 'Annulla i cambiamenti'),
(93993, 776, 26, 'Annullato'),
(93994, 777, 26, 'Cancro'),
(93995, 778, 26, 'Screening cancro: screening del cancro al colon'),
(93996, 779, 26, 'Screening cancro: mammografia'),
(93997, 780, 26, 'Screening cancro: pap test'),
(93998, 781, 26, 'Screening cancro: screening del cancro alla prostata'),
(93999, 782, 26, 'Non puoi aggiungere questo elemento perchè esiste già!'),
(94000, 783, 26, 'Non puoi aggiungere/aggiornare questo elemento perchè esiste già un duplicato!'),
(94001, 784, 26, 'non può essere archiviato, ignorato'),
(94002, 785, 26, 'non può essere convertito in JPEG. Forse ImageMagick non è installato?'),
(94003, 786, 26, 'non può essere eliminato, ignorato'),
(94004, 787, 26, 'non può essere mostrato in linea perchè il suo tipo non è supportato dal browser'),
(94005, 788, 26, 'non può essere mostrato in linea perchè il suo tipo non è supportato dal browser'),
(94006, 789, 26, 'non può essere mostrato in linea perchè il suo tipo non è supportato dal browser'),
(94007, 790, 26, 'Impossibile creare'),
(94008, 791, 26, 'Impossibile creare il file'),
(94009, 792, 26, 'Impossibile cancellare(dal server SFTP) il file'),
(94010, 793, 26, 'Impossibile cancellare il file'),
(94011, 794, 26, 'Impossibile determinare la destinazione del nome del file'),
(94012, 795, 26, 'Impossibile trovare '),
(94013, 796, 26, 'Non trovo il nome del file di destinazione'),
(94014, 799, 26, 'Impossibile trovare il paziente da SQL-Ledger cliente id'),
(94015, 800, 26, 'Impossibile trovare il documento di riferimento in postilla '),
(94016, 801, 26, 'Impossibile trovare il fornitore di SQL-Ledger dipendente = '),
(94017, 802, 26, 'Non è possibile modificare i pagamenti. Indistribuiti è negativo.'),
(94018, 803, 26, 'Impossibile aprire '),
(94019, 804, 26, 'Impossibile inviare all''assicurazione. L''entità pagante è il Paziente'),
(94020, 805, 26, 'Impossibile inviare al paziente. L''entità pagante è l''Assicurazione'),
(94021, 806, 26, 'Non è possibile registrare i pagamenti. Indistribuiti è negativo.'),
(94022, 807, 26, 'Impossibile leggere'),
(94023, 808, 26, 'Impossibile leggere la directory'),
(94024, 809, 26, 'Impossibile aggiornare perchè non stai aggiornando un elemento esistente!'),
(94025, 810, 26, 'Metti in lettere maiuscole'),
(94026, 811, 26, 'Tutto maiuscolo'),
(94027, 812, 26, 'capsula'),
(94028, 813, 26, 'Carta'),
(94029, 814, 26, 'Caterizzazione Cardiaca'),
(94030, 815, 26, 'Ecocardiogramma'),
(94031, 816, 26, 'Cardiovascolare'),
(94032, 821, 26, 'Cartilagine / condrale / danni al disco'),
(94033, 822, 26, 'Lesione cartilaginea'),
(94034, 823, 26, 'Pulsazioni carotidee'),
(94035, 824, 26, 'cassa'),
(94036, 825, 26, 'Cassa'),
(94037, 826, 26, 'Reg Cassa'),
(94038, 827, 26, 'Incassi dal fornitore'),
(94039, 828, 26, 'Catalan- Valencian'),
(94040, 829, 26, 'Intervento di cataratta'),
(94041, 830, 26, 'Cataratta'),
(94042, 831, 26, 'Categorie'),
(94043, 832, 26, 'Categorie per'),
(94044, 833, 26, 'Categoria'),
(94045, 834, 26, 'categoria'),
(94046, 835, 26, 'Categoria '),
(94047, 836, 26, 'Dettagli categoria'),
(94048, 837, 26, 'Limiti categoria'),
(94049, 838, 26, 'Nome categoria'),
(94050, 839, 26, 'Il nome della categoria è vuoto'),
(94051, 840, 26, 'Categoria/Titolo'),
(94052, 841, 26, 'Caucasico'),
(94053, 842, 26, 'Provoca incassi per la stampa Incontro / Info Fornitore primario'),
(94054, 846, 26, 'Approvare CCR'),
(94055, 847, 26, 'Revisione paziente CCR'),
(94056, 848, 26, 'Revisiona e approva CCR'),
(94057, 850, 26, 'CDR'),
(94058, 851, 26, 'CDR Reports priorità di elaborazione'),
(94059, 852, 26, 'Cell'),
(94060, 853, 26, 'Cellulare'),
(94061, 854, 26, 'Numero di cellulare'),
(94062, 855, 26, 'Numero di Celulare'),
(94063, 856, 26, 'Certificazione centrale');
INSERT INTO `lang_definitions` VALUES
(94064, 857, 26, 'Centro/Sud America'),
(94065, 858, 26, 'Il file crt del certificato dell''autorità non può essere vuoto'),
(94066, 859, 26, 'Il file key del certificato dell''autorità non può essere vuoto'),
(94067, 860, 26, 'Certificato da inviare al RFC 5425 TSL syslog server.'),
(94068, 861, 26, 'Cetificato dell''utente'),
(94069, 862, 26, 'Certificati'),
(94070, 863, 26, 'Chamorro'),
(94071, 864, 26, 'Campione US'),
(94072, 865, 26, 'Campione USVA'),
(94073, 866, 26, 'cambia'),
(94074, 867, 26, 'Cambia'),
(94075, 868, 26, 'Cambio attività'),
(94076, 869, 26, 'Modifica non riuscita! CouchDB collegare errore?'),
(94077, 870, 26, 'Cambiamento nella visione'),
(94078, 871, 26, 'Cambiamento nella visione'),
(94079, 872, 26, 'Cambio Password'),
(94080, 874, 26, 'Cambiato'),
(94081, 875, 26, 'Osso sostituito'),
(94082, 876, 26, 'Cambiare ID paziente per documento'),
(94083, 877, 26, 'Caratteristiche'),
(94084, 878, 26, 'Caratteri rimanenti'),
(94085, 879, 26, 'Spese'),
(94086, 880, 26, 'Aggiustamento spese'),
(94087, 881, 26, 'Codice spesa'),
(94088, 882, 26, 'Spese'),
(94089, 883, 26, 'Tabulato'),
(94090, 884, 26, 'Tabulato Attività'),
(94091, 885, 26, 'Tabulato resoconto Ingresso/uscita'),
(94092, 886, 26, 'ID Tabulato'),
(94093, 887, 26, 'ID Tabulato:'),
(94094, 888, 26, 'Tabulato etichetta'),
(94095, 889, 26, 'Tabulato dell''Attività della Sede'),
(94096, 890, 26, 'Nota al Tabulato'),
(94097, 891, 26, 'Numero del Tabulato'),
(94098, 892, 26, 'Tabella posizioni di memoria'),
(94099, 893, 26, 'Tracciatura tabelle'),
(94100, 894, 26, 'Tracciatura tabelle'),
(94101, 895, 26, 'Dati estratti'),
(94102, 896, 26, 'Dati usciti'),
(94103, 897, 26, 'Ceceno'),
(94104, 898, 26, 'Assegno'),
(94105, 899, 26, 'Assegno'),
(94106, 900, 26, 'Controlla tutto'),
(94107, 902, 26, 'Importo assegno'),
(94108, 903, 26, 'Data assegno'),
(94109, 904, 26, 'Controlla le differenze di traduzione con la tabella del linguaggio custom'),
(94110, 906, 26, 'Arrivo per'),
(94111, 907, 26, 'Verifica dati di ingresso'),
(94112, 908, 26, 'Spunta gli articoli da grafico'),
(94113, 909, 26, 'Controllo risultati di laboratorio'),
(94114, 910, 26, 'Segno di spunta indica recensione'),
(94115, 911, 26, 'Verifica n.'),
(94116, 912, 26, 'Verifica Numero'),
(94117, 915, 26, 'Pagamento per assegno'),
(94118, 916, 26, 'Spunta la casella se questo è un file criptato'),
(94119, 917, 26, 'Spunta questa se vuoi che gli eroganti vedano tutti gli appuntamenti e non solo i propri.'),
(94120, 918, 26, 'Verifica per creare risultato di questa diagnosi'),
(94121, 919, 26, 'Controllo/EOB data:'),
(94122, 920, 26, 'Controllo/EOB N.:'),
(94123, 921, 26, 'Assegno/Num rif.'),
(94124, 922, 26, 'Assegno/Numero di riferimento'),
(94125, 923, 26, 'Elenco di caselle di spunta'),
(94126, 924, 26, 'elenco di caselle di spunta'),
(94127, 925, 26, 'casella di spunta s/ testo'),
(94128, 926, 26, 'Casella di spunta s/ testo'),
(94129, 927, 26, 'Le caselle di controllo sopra indicano se si desidera rifiutare ed eliminare il file HL7.'),
(94130, 928, 26, 'Spuntato'),
(94131, 929, 26, 'Casella spuntata = si , vuota = no'),
(94132, 931, 26, 'Selezionando la casella di blocco si impedirà ulteriori modifiche in qualsiasi forma di questo incontro.'),
(94133, 932, 26, 'Cassa'),
(94134, 933, 26, 'Somma di controllo'),
(94135, 934, 26, 'Petto'),
(94136, 935, 26, 'Petto CTAB'),
(94137, 936, 26, 'Dolore al petto'),
(94138, 937, 26, 'Dolore al petto:'),
(94139, 938, 26, 'Dolori al petto'),
(94140, 940, 26, 'Chg'),
(94141, 941, 26, 'Chichewa- Chewa- Nyanja'),
(94142, 942, 26, 'Reclami responsabile'),
(94143, 943, 26, 'Figlio'),
(94144, 945, 26, 'Stato immunizzazione dell''infanzia (CQM)'),
(94145, 946, 26, 'Brividi'),
(94146, 947, 26, 'Cinese'),
(94147, 948, 26, 'Cinese(Semplificato)'),
(94148, 949, 26, 'Cinese(Tradizionale)'),
(94149, 950, 26, 'Chiropratico'),
(94150, 951, 26, 'Scelte'),
(94151, 952, 26, 'Colicistectomia'),
(94152, 953, 26, 'colicistectomia'),
(94153, 954, 26, 'Colicistectomia'),
(94154, 955, 26, 'Scegli'),
(94155, 956, 26, 'Scegli una sezione e clicca un elemento al suo interno; allora nell''altra sezione vedrai illuminarsi gli elementi correlati, e puoi cliccare in quella sezione per aggiungere e eliminare relazioni.'),
(94156, 957, 26, 'Scegli i criteri'),
(94157, 958, 26, 'Scegli sacrica o visualizza in linea'),
(94158, 959, 26, 'Scegliere File'),
(94159, 960, 26, 'Scegliere dalla lista'),
(94160, 961, 26, 'Scegli la direzione di pagina'),
(94161, 962, 26, 'Scegli l''elenco'),
(94162, 963, 26, 'Scegli la dimesione della carta'),
(94163, 964, 26, 'Scegli la lingua di preferenza del PDF'),
(94164, 965, 26, 'Scegli il formato di stampa per questa relazione di incontro.'),
(94165, 967, 26, 'Bronchite Cronica'),
(94166, 968, 26, 'Dolore articolare cronico'),
(94167, 969, 26, 'Dolore cronico al rene (CDK)'),
(94168, 970, 26, 'Sinovite cronica/effusione/dolore articolare/gotta'),
(94169, 971, 26, 'Cronico/Ricorrente'),
(94170, 972, 26, 'Chuvash'),
(94171, 973, 26, 'Cirrosi epatica'),
(94172, 974, 26, 'Cirrosi Epatica'),
(94173, 975, 26, 'Città'),
(94174, 976, 26, 'Nome città'),
(94175, 977, 26, 'Città, Provincia'),
(94176, 978, 26, 'Città, Provincia, CAP'),
(94177, 979, 26, 'Città/Provincia'),
(94178, 980, 26, 'Richiesta'),
(94179, 981, 26, 'Richiesta '),
(94180, 982, 26, 'Stato richieste'),
(94181, 983, 26, 'Il test della richiesta è stato completato'),
(94182, 984, 26, 'Tipo richiesta'),
(94183, 985, 26, 'La richiesta è stata generata nel file'),
(94184, 986, 26, 'La richiesta è stata generata nel file '),
(94185, 987, 26, 'Richiesta'),
(94186, 988, 26, 'Classificazione'),
(94187, 989, 26, 'Pulisci'),
(94188, 990, 26, 'CANCELLA PAZIENTE ATTIVO'),
(94189, 991, 26, 'Pulisci tutto'),
(94190, 992, 26, 'Pulisci i dati HL7'),
(94191, 993, 26, 'Pulisci giustificazione'),
(94192, 994, 26, 'Pulisci la cache Smarty'),
(94193, 995, 26, 'Info centro di smistamento necessaria per EDI 270 creazione di batch.'),
(94194, 996, 26, 'Numero CLIA'),
(94195, 997, 26, 'Clicca'),
(94196, 998, 26, 'Clicca "esporta" per esportare le Categorie, Subcategorie, Elementi, dati Contenuto in un file di testo. Qualsiasi similitudine di questo file con un file XML è puramente casuale. I tag di apertura e chiusura devono essere sulla stessa linea, in lettera minuscola e senza spazi. Per importare, scegli un file e clicca "importa". Se i dati sono completamente diversi, verrà effettuata l''unione con i dati esistenti. Se ci sono nomi identici, i vecchi saranno mantenuti e i nuovi saranno salvati con un numero alla fine.'),
(94197, 999, 26, 'Clicca un contrassegno sul disegno per aggiungere una nuova annotazione, cliccalo di nuovo per rimuoverlo.'),
(94198, 1000, 26, 'Clicca "Scarica Certificato" per scaricare i certificati nel file ssl.zip'),
(94199, 1001, 26, 'clicca per altri dati'),
(94200, 1002, 26, 'Clicca per maggiori dettagli'),
(94201, 1003, 26, 'Clicca per riepilogo dell''ordine'),
(94202, 1004, 26, 'Clicca per i risultati'),
(94203, 1005, 26, 'Clicca qui'),
(94204, 1006, 26, 'Clicca qui per aggiungere un nuovo paziente'),
(94205, 1007, 26, 'Clicca qui per aggiungere un cambiamento di stauts con nuova lesione e modificare l''attività giornaliera'),
(94206, 1008, 26, 'Clicca qui per scegliere una data'),
(94207, 1009, 26, 'Clicca qui per scegliere una data e un''ora'),
(94208, 1010, 26, 'Clicca qui per scegliere una data iniziale'),
(94209, 1011, 26, 'Clicca qui per scegliere ora la data'),
(94210, 1012, 26, 'Clicca qui per scegliere ora la data da'),
(94211, 1013, 26, 'Clicca qui per scegliere ora la data fino a'),
(94212, 1014, 26, 'Clicca qui per configurare questo modulo'),
(94213, 1016, 26, 'Clicca qui per disabilitare questo modulo'),
(94214, 1018, 26, 'Clicca qui per abilitare questo modulo'),
(94215, 1019, 26, 'Clicca qui per installare questo modulo'),
(94216, 1020, 26, 'clicca qui per cercare'),
(94217, 1021, 26, 'clicca qui per aggiornare le specifiche della priorità, categoria e soprannome'),
(94218, 1022, 26, 'Clicca qui per vedere tutto.'),
(94219, 1023, 26, 'Clicca qui per vedere e tracciare il grafico'),
(94220, 1024, 26, 'Clicca qui per visualizzare e tracciare il grafico di tutti i dati lab'),
(94221, 1025, 26, 'Clicca qui per vedere e tracciare il grafico di tutti i "Vitali".'),
(94222, 1026, 26, 'Clicca qui per vedere i dettagli del paziente'),
(94223, 1027, 26, 'Clicca qui per vederli tutti.'),
(94224, 1028, 26, 'Clicca qui per visualizzare / modificare ulteriori dettagli'),
(94225, 1029, 26, 'Clicca il pulsante Installa per installare la versione del database dalla data seguente'),
(94226, 1030, 26, 'Clicca su qualsiasi parte dell''ora per incrementarla'),
(94227, 1031, 26, 'Clicca sul nome del Paziente per aprire la sua scheda'),
(94228, 1032, 26, 'Clicca Rigenera per vedere tutti i risultati, o immetti criteri di ricerca per vedere risultati specifci.'),
(94229, 1033, 26, 'Clicca per aggiungere una diagnosi'),
(94230, 1034, 26, 'Clicca per aggiungere nuove compnenti'),
(94231, 1035, 26, 'Clicca per aggiungere una nuova consulatazione'),
(94232, 1036, 26, 'Clicca per scegliere diagnosi da giustificare.'),
(94233, 1037, 26, 'Clicca per scaricare'),
(94234, 1038, 26, 'Clicca per modificare'),
(94235, 1039, 26, 'Clicca per modificare la descizione'),
(94236, 1040, 26, 'Clicca per modificare questo evento'),
(94237, 1041, 26, 'Clicca per generare il report'),
(94238, 1042, 26, 'Clicca per abbinare il paziente'),
(94239, 1043, 26, 'Clicca per stampare'),
(94240, 1044, 26, 'Clicca per ricevere (aggiungere) un nuovo lotto'),
(94241, 1045, 26, 'Clicca per selezionare'),
(94242, 1046, 26, 'Clicca per Selezionare'),
(94243, 1047, 26, 'Clicca per selezionare un codice standard-commerciale per questa procedura'),
(94244, 1048, 26, 'Clicca per selezionare il codice di procedura opzionale'),
(94245, 1049, 26, 'Clicca per selezionare o cambiare codice'),
(94246, 1050, 26, 'Clicca per selezionare o cambiare il codice CVX'),
(94247, 1051, 26, 'Clicca per selezionare o cambiare le diagnosi'),
(94248, 1052, 26, 'Clicca per selezionare o cambiare i codici delle prestazioni'),
(94249, 1053, 26, 'Clicca per selezionare il paziente'),
(94250, 1054, 26, 'Clicca per selezionare il codice relativo'),
(94251, 1055, 26, 'Clicca per selezionare le prestazioni da attuare se questo risultato è anormale'),
(94252, 1056, 26, 'Clicca per selezionare la procedura desiderata'),
(94253, 1057, 26, 'Clicca per ordinare'),
(94254, 1058, 26, 'Clicca per vedere'),
(94255, 1059, 26, 'Clicca per vedere o modificare'),
(94256, 1060, 26, 'Clicca per vedere/modificare'),
(94257, 1061, 26, 'Clicca il pulsante Aggiorna per aggiornare la versione del database dalla data seguente'),
(94258, 1062, 26, 'Clicca dove indicato sopra per abbinare il paziente.'),
(94259, 1063, 26, 'Click:'),
(94260, 1064, 26, 'Giorni di scadenza del certificato Client'),
(94261, 1065, 26, 'Periodo di validità del certificato Client'),
(94262, 1066, 26, 'La validità del certificato Client dovrebbe essere un numero valido.'),
(94263, 1067, 26, 'Copia per Cliente'),
(94264, 1069, 26, 'Sommario della storia medica del cliente'),
(94265, 1070, 26, 'Nome Cliente'),
(94266, 1071, 26, 'Numero Cliente'),
(94267, 1072, 26, 'Profilo Cliente - Nuovi Clienti'),
(94268, 1073, 26, 'Profilo Cliente - Unici Clienti'),
(94269, 1074, 26, 'Clienti'),
(94270, 1075, 26, 'Ambulatorio'),
(94271, 1076, 26, 'Copia ambulatorio'),
(94272, 1077, 26, 'Registro giornaliero ambulatorio'),
(94273, 1078, 26, 'ID ambulatorio'),
(94274, 1079, 26, 'Ambulatoriale'),
(94275, 1080, 26, 'Gestore delle Regole di allarme per decisioni cliniche.'),
(94276, 1081, 26, 'Anamnesi clinica'),
(94277, 1083, 26, 'Piani clinici'),
(94278, 1084, 26, 'Misure di qualità clinica (CQM)'),
(94279, 1085, 26, 'Misure di qualità clinica (CQM) - 2011'),
(94280, 1086, 26, 'Misure di qualità clinica (CQM) - 2014'),
(94281, 1087, 26, 'Promemoria clinici'),
(94282, 1088, 26, 'Rapporti Clinici'),
(94283, 1089, 26, 'Categoria azione per la regola clinica'),
(94284, 1090, 26, 'Elemento azione per regola clinica'),
(94285, 1091, 26, 'Metodi filtro per la regola clinica'),
(94286, 1092, 26, 'Metodi obiettivo per la regola clinica'),
(94287, 1093, 26, 'Regole cliniche'),
(94288, 1094, 26, 'Regole cliniche Intervalli di Età'),
(94289, 1095, 26, 'Regole cliniche Confronti'),
(94290, 1096, 26, 'Regole cliniche Tipi di Incontro'),
(94291, 1097, 26, 'Regole cliniche Opzioni promemoria saldo'),
(94292, 1098, 26, 'Regole cliniche Opzioni di disattivazione promemoria'),
(94293, 1099, 26, 'Regole cliniche Intervalli per Promemoria'),
(94294, 1100, 26, 'Regole cliniche Metodi per Promemoria'),
(94295, 1101, 26, 'Regole cliniche Intervalli Obiettivi'),
(94296, 1102, 26, 'Obiettivi clinici'),
(94297, 1103, 26, 'Termine clinico'),
(94298, 1104, 26, 'Codice(i) termine(i) clinico(i)'),
(94299, 1106, 26, 'Clinici(medici)'),
(94300, 1107, 26, 'Clona'),
(94301, 1108, 26, 'Clona Visita passata'),
(94302, 1109, 26, 'Chiudi'),
(94303, 1110, 26, 'Chiudi Finestra'),
(94304, 1111, 26, 'chiudi finestra'),
(94305, 1112, 26, 'Chiuso/a'),
(94306, 1113, 26, 'cm'),
(94307, 1114, 26, 'Margini CMS 1500'),
(94308, 1115, 26, 'CMS 1500 formato modulo carta'),
(94309, 1116, 26, 'CMS 1500: formato Box 31'),
(94310, 1117, 26, 'CMS 1500: Dati nel Box 31(Firma)'),
(94311, 1118, 26, 'ID CMS'),
(94312, 1119, 26, 'CMS portale'),
(94313, 1120, 26, 'CMS accesso al portale'),
(94314, 1121, 26, 'CMS ID accesso al portale'),
(94315, 1122, 26, 'CMS portale non attivato!'),
(94316, 1123, 26, 'CMS Password del portale'),
(94317, 1124, 26, 'CMS Richiesta portale'),
(94318, 1125, 26, 'CMS indirizzo del sito del portale'),
(94319, 1126, 26, 'CMS Nome utente del portale'),
(94320, 1127, 26, 'CN2-12 intatto'),
(94321, 1128, 26, 'Copagamento'),
(94322, 1129, 26, 'Copagamento pagato'),
(94323, 1130, 26, 'COPAGAMENTO'),
(94324, 1131, 26, 'Codice'),
(94325, 1132, 26, 'codice'),
(94326, 1133, 26, 'Cercatore di codice'),
(94327, 1134, 26, 'Il codice deve essere di due lettere minuscole'),
(94328, 1135, 26, 'Codice o simbolo per indicare la moneta'),
(94329, 1136, 26, 'Codice testo'),
(94330, 1137, 26, 'Tipo di Codice'),
(94331, 1138, 26, 'tipo di codice'),
(94332, 1139, 26, 'Tipo di codice non trovato'),
(94333, 1140, 26, 'Tipo di codice non ancora definito'),
(94334, 1141, 26, 'Tipi di Codice'),
(94335, 1142, 26, 'Codice(i)'),
(94336, 1143, 26, 'Codificato'),
(94337, 1144, 26, 'Codici'),
(94338, 1145, 26, 'Codifica'),
(94339, 1146, 26, 'Codificazione (clicca per le istruzioni)'),
(94340, 1147, 26, 'Codifica - eventuali incontri (scrivere, qualche opzione)'),
(94341, 1148, 26, 'Codifica - i miei incontri (scrivere, qualche opzione)'),
(94342, 1149, 26, 'Codifica non autorizzata'),
(94343, 1150, 26, 'Caffè'),
(94344, 1151, 26, 'Utilizzo di caffè'),
(94345, 1152, 26, 'Coassicurazione'),
(94346, 1153, 26, 'Contrai t/s'),
(94347, 1154, 26, 'Contrai'),
(94348, 1155, 26, 'contrai'),
(94349, 1156, 26, 'Contrai Tutto'),
(94350, 1157, 26, 'Contrai tutto'),
(94351, 1158, 26, 'Contrai tutto'),
(94352, 1160, 26, 'Data Raccolta'),
(94353, 1161, 26, 'Raccolte'),
(94354, 1162, 26, 'Resoconto Raccolte'),
(94355, 1163, 26, 'Cancro al Colon'),
(94356, 1164, 26, 'Screening per Cancro al Colon'),
(94357, 1165, 26, 'Intervento per Cancro al Colon'),
(94358, 1166, 26, 'Colonoscopia'),
(94359, 1167, 26, 'colonoscopia'),
(94360, 1168, 26, 'Colore'),
(94361, 1169, 26, 'Colore:Abbr'),
(94362, 1170, 26, 'Colonna'),
(94363, 1171, 26, 'Colonne'),
(94364, 1172, 26, 'Combinazione Lotti'),
(94365, 1173, 26, 'Virgola'),
(94366, 1174, 26, 'Commento'),
(94367, 1175, 26, 'Commenti'),
(94368, 1176, 26, 'Commenti per questo risultato o raccomandazione'),
(94369, 1177, 26, 'Soc. Assicurazione Commerciale'),
(94370, 1178, 26, 'Assegna i Cambiamenti'),
(94371, 1179, 26, 'Comunicazione'),
(94372, 1180, 26, 'Comunicazioni'),
(94373, 1182, 26, 'Società'),
(94374, 1183, 26, 'Nome della Società'),
(94375, 1184, 26, 'Completa'),
(94376, 1186, 26, 'Completato'),
(94377, 1188, 26, 'Completato?'),
(94378, 1190, 26, 'Complicazioni da parte del fornitore servizi'),
(94379, 1191, 26, 'Complicanze di Aborto'),
(94380, 1192, 26, 'Componenti'),
(94381, 1193, 26, 'Computer Aided Medical Sistema di ordinazione'),
(94382, 1194, 26, 'Conclusioni'),
(94383, 1198, 26, 'Config'),
(94384, 1199, 26, 'Configurazione'),
(94385, 1200, 26, 'Esporta/Importa configurazione'),
(94386, 1201, 26, 'Configurazione salvata con successo'),
(94387, 1202, 26, 'Configura Apache e LibreEHR per usare i certificati SSL lato client'),
(94388, 1203, 26, 'Configura Apache per usare certificati SSL lato client'),
(94389, 1204, 26, 'Configura Apache per usare HTTPS'),
(94390, 1205, 26, 'Configura LIBREEHR per usare certificati SSL lato client'),
(94391, 1206, 26, 'Traccia configurazioni'),
(94392, 1207, 26, 'Traccia Configurazioni'),
(94393, 1208, 26, 'Conferma creazione Nuovo Paziente'),
(94394, 1209, 26, 'Conferma nuova password'),
(94395, 1210, 26, 'Conferma Pagamento'),
(94396, 1214, 26, 'Congenito(a)'),
(94397, 1215, 26, 'Congiuntiva, pupille'),
(94398, 1216, 26, 'Errore di connessione'),
(94399, 1217, 26, 'Connettori'),
(94400, 1218, 26, 'Costante'),
(94401, 1219, 26, 'nome della costante'),
(94402, 1220, 26, 'Il nome della costante è vuoto'),
(94403, 1221, 26, 'costanti'),
(94404, 1222, 26, 'Costipazione'),
(94405, 1223, 26, 'Costituzionale'),
(94406, 1226, 26, 'Breve Descrizione Consulto'),
(94407, 1227, 26, 'Contatto'),
(94408, 1228, 26, 'Email per contatto'),
(94409, 1229, 26, 'Indirizzo email per contatto'),
(94410, 1230, 26, 'Contattare EMR diretto per iscriversi al servizio phiMail diretto di messaggistica'),
(94411, 1231, 26, 'info contatto'),
(94412, 1232, 26, 'Lenti a contatto'),
(94413, 1233, 26, 'Contact Medical Information Integration, LLC at http://mi-squared.com for Lab Exchange Service.'),
(94414, 1234, 26, 'Contact Medical Information Integration, LLC at http://mi-squared.com or ZH Healthcare at http://zhservices.com for subscribing the eRx service'),
(94415, 1236, 26, 'Nome del contatto'),
(94416, 1237, 26, 'Persona per contatto'),
(94417, 1238, 26, 'Contatto telefonico'),
(94418, 1239, 26, 'Numero telefono contatto'),
(94419, 1240, 26, 'Contatta ZMG, LLC (zmghealth@gmail.com) per aderire al servizio eRX'),
(94420, 1241, 26, 'contiene tre o quattro elementi seguenti:'),
(94421, 1242, 26, 'Nome gruppo di contenitore'),
(94422, 1243, 26, 'Contenuto'),
(94423, 1244, 26, 'contenuto'),
(94424, 1245, 26, 'Contesto'),
(94425, 1246, 26, 'Il nome del contesto non può essere vuoto'),
(94426, 1247, 26, 'Continua'),
(94427, 1248, 26, 'Continuità del documento di cura (CCD)'),
(94428, 1249, 26, 'Continuità del registo di cura (CCR)'),
(94429, 1250, 26, 'Contra clienti'),
(94430, 1251, 26, 'Contraccezione'),
(94431, 1252, 26, 'Tematiche contraccezione'),
(94432, 1253, 26, 'Complicanze contraccettive (specificare)'),
(94433, 1254, 26, 'Metodo contraccettivo'),
(94434, 1255, 26, 'Prodotti contraccettivi'),
(94435, 1256, 26, 'Prestazioni per la contraccezionei iniziate precedentemente'),
(94436, 1257, 26, 'Inizio contraccettivi'),
(94437, 1258, 26, 'ID Controllo'),
(94438, 1259, 26, 'Controllo Nr.'),
(94439, 1261, 26, 'COPAGAMENTO'),
(94440, 1262, 26, 'Co-paga'),
(94441, 1263, 26, 'Co-Paga'),
(94442, 1264, 26, 'Co-paga non positivo'),
(94443, 1265, 26, 'Co-paga pagamento'),
(94444, 1266, 26, 'Copagamenti'),
(94445, 1267, 26, 'COPD'),
(94446, 1268, 26, 'Copia le pagine al Tabulato del paziente'),
(94447, 1269, 26, 'Copiare i valori'),
(94448, 1270, 26, 'Sto copiando il file del databse. Ci vorrà un po'' di tempo...'),
(94449, 1271, 26, 'Avviso di Copyright'),
(94450, 1272, 26, 'Cornish'),
(94451, 1273, 26, 'Bypass arteriocoronarico'),
(94452, 1274, 26, 'Intervento di bypass coronarico (CABG)'),
(94453, 1275, 26, 'Corretto'),
(94454, 1276, 26, 'Corsican'),
(94455, 1277, 26, 'CouchDB'),
(94456, 1278, 26, 'CouchDB Connessione fallita.'),
(94457, 1279, 26, 'CouchDB Database'),
(94458, 1280, 26, 'CouchDB nome Database'),
(94459, 1281, 26, 'CouchDB host'),
(94460, 1282, 26, 'CouchDB HostName'),
(94461, 1283, 26, 'CouchDB Log Enable'),
(94462, 1284, 26, 'CouchDB Password'),
(94463, 1285, 26, 'CouchDB Port'),
(94464, 1286, 26, 'CouchDB port'),
(94465, 1287, 26, 'CouchDB salvataggio fallito'),
(94466, 1288, 26, 'CouchDB UserName'),
(94467, 1289, 26, 'Tosse'),
(94468, 1290, 26, 'Tosse:'),
(94469, 1291, 26, 'impossibile connettersi al server'),
(94470, 1293, 26, 'impossibile aprire la tabella'),
(94471, 1294, 26, 'Non è stato possibile leggere il file'),
(94472, 1295, 26, 'Non è stato possibile leggere il file'),
(94473, 1296, 26, 'Non è stato possibile inviare la email per un problema del server '),
(94474, 1297, 26, 'Impossibile inviare e-mail a causa di un problema del server. '),
(94475, 1298, 26, 'Non è stato possibile creare la dir del backup:'),
(94476, 1299, 26, 'Non è stato possibile rimuovere la dir:'),
(94477, 1300, 26, 'Non è stato possibile rimuovere il vecchio file di backup:'),
(94478, 1301, 26, 'Non è stato possibile rimuovere il vecchio file di esportazione:'),
(94479, 1302, 26, 'Gestione Coumadin - Monitoraggio'),
(94480, 1303, 26, 'Assist. con metodo'),
(94481, 1304, 26, 'Assistenza'),
(94482, 1305, 26, 'Attività di assistenza'),
(94483, 1306, 26, 'DEFERIMENTO MODULO CONTATORE'),
(94484, 1307, 26, 'Contatore-deferimento'),
(94485, 1308, 26, 'Nazione'),
(94486, 1309, 26, 'Tipo di dato Nazione'),
(94487, 1310, 26, 'Elenco Nazioni'),
(94488, 1311, 26, 'Lista Paesi(scrivere, aggiungere solo opzionale)'),
(94489, 1312, 26, 'Il nome della nazione dovrebbe essere essere indicato da due lettere. (esempio: Italia è IT)'),
(94490, 1313, 26, 'contea'),
(94491, 1315, 26, 'Buono'),
(94492, 1318, 26, 'CPT'),
(94493, 1319, 26, 'Codice CPT'),
(94494, 1320, 26, 'Codici CPT'),
(94495, 1321, 26, 'CPT4 Procedura/Servizio'),
(94496, 1322, 26, 'CPTII misure delle prestazioni'),
(94497, 1323, 26, 'CQM'),
(94498, 1324, 26, 'Cricchiolii:'),
(94499, 1325, 26, 'crema'),
(94500, 1326, 26, 'Crea un certificato SSL lato Client per ciascun utente o macchina client.'),
(94501, 1327, 26, 'Crea un certificato SSL lato Client o per l''utente o per l''hostname client'),
(94502, 1328, 26, 'Crea una nuova traccia'),
(94503, 1329, 26, 'Crea un Evento'),
(94504, 1330, 26, 'Crea e scarica un backup completo'),
(94505, 1331, 26, 'Crea e modifica traccie'),
(94506, 1332, 26, 'Crea backup'),
(94507, 1333, 26, 'Crea batch'),
(94508, 1334, 26, 'Crea Certificato Client'),
(94509, 1335, 26, 'Crea i certificati SSL lato Client'),
(94510, 1336, 26, 'Crea duplicato'),
(94511, 1337, 26, 'Crea incontro'),
(94512, 1338, 26, 'Crea backup Registro eventi'),
(94513, 1339, 26, 'Crea Nuova Tematica'),
(94514, 1340, 26, 'Crea Nuovo paziente'),
(94515, 1341, 26, 'Crea nuova Traccia'),
(94516, 1342, 26, 'Crea le credenziali del Portale Offsite'),
(94517, 1343, 26, 'Crea le credenziali del Portale Onsite'),
(94518, 1344, 26, 'Crea Nota paziente'),
(94519, 1345, 26, 'Crea il certificato di autorità SSL e i certificati del Server'),
(94520, 1346, 26, 'Crea Visita'),
(94521, 1347, 26, 'Creato'),
(94522, 1348, 26, 'Crea file di esportazione'),
(94523, 1349, 26, 'Creazione nuova traccia fallita'),
(94524, 1350, 26, 'La creazione di questo file sulla macchina remota non è riuscita'),
(94525, 1351, 26, 'Creatore'),
(94526, 1352, 26, 'credito'),
(94527, 1353, 26, 'Carta di Credito'),
(94528, 1354, 26, 'Crediti'),
(94529, 1355, 26, 'Cree'),
(94530, 1356, 26, 'Criteri'),
(94531, 1357, 26, 'Croatian'),
(94532, 1358, 26, 'Morbo di Crohn'),
(94533, 1359, 26, 'Morbo di Crohn'),
(94534, 1360, 26, 'Esporta CSV'),
(94535, 1361, 26, 'File CSV'),
(94536, 1362, 26, 'Tabelle CVS'),
(94537, 1363, 26, 'CU.MM(Millimetri cubi)'),
(94538, 1364, 26, 'Cubano'),
(94539, 1365, 26, 'Posti decimali della moneta'),
(94540, 1366, 26, 'Simbolo del punto decimale per la moneta'),
(94541, 1367, 26, 'Indicatore di moneta'),
(94542, 1368, 26, 'Separatore delle migliaia per la moneta'),
(94543, 1369, 26, 'Attuale'),
(94544, 1370, 26, 'Alcool attuale'),
(94545, 1371, 26, 'consultazione attuale'),
(94546, 1372, 26, 'Criteri attuali'),
(94547, 1373, 26, 'Colore del giorno evidenziato attuale'),
(94548, 1374, 26, 'Fumatore quotidiano attuale'),
(94549, 1375, 26, 'Il nome dle file corrente è stato cambiato in'),
(94550, 1376, 26, 'Hash attuale'),
(94551, 1377, 26, 'Collocazione attuale'),
(94552, 1378, 26, 'Farmaci attuali'),
(94553, 1379, 26, 'Password attuale'),
(94554, 1380, 26, 'Paziente attuale'),
(94555, 1381, 26, 'Solo Pt Attuale'),
(94556, 1382, 26, 'Droghe ricreazionali attuali'),
(94557, 1383, 26, 'Fumatore saltuario attuale'),
(94558, 1385, 26, 'Valore attuale'),
(94559, 1386, 26, 'Attualmente attivo'),
(94560, 1387, 26, 'Attualmente in esecuzione'),
(94561, 1388, 26, 'Attualmente non ci sono sedi.'),
(94562, 1389, 26, 'Sindrome di Cushing'),
(94563, 1390, 26, 'Sindrome di Cushing'),
(94564, 1392, 26, 'Personalizzato'),
(94565, 1393, 26, 'Input personalizzato?'),
(94566, 1394, 26, 'Tabella personalizzazione'),
(94567, 1396, 26, 'Codice CVX'),
(94568, 1397, 26, 'Codice mappa CVX'),
(94569, 1398, 26, 'Immunizzazione CVX'),
(94570, 1399, 26, 'Ciclo'),
(94571, 1400, 26, 'CYP'),
(94572, 1401, 26, 'Fattore CYP'),
(94573, 1402, 26, 'Report CYP'),
(94574, 1403, 26, 'Ceco'),
(94575, 1404, 26, 'D'),
(94576, 1405, 26, 'D&C'),
(94577, 1406, 26, 'D&E'),
(94578, 1407, 26, 'D.di N.'),
(94579, 1408, 26, 'Giornaliero'),
(94580, 1409, 26, 'registrazione giornaliera'),
(94581, 1410, 26, 'Danese'),
(94582, 1411, 26, 'La stessa versione dei dati è già presente nel database, vi preghiamo di cambiare il codice e / o descrizione'),
(94583, 1412, 26, 'La stessa versione dei dati è già presente nel database, vi preghiamo di cambiare la costante del nome'),
(94584, 1413, 26, 'Colonne dati'),
(94585, 1416, 26, 'Errore dati'),
(94586, 1417, 26, 'Dati da'),
(94587, 1419, 26, 'dati di tutti gli incontri finora'),
(94588, 1420, 26, 'Tipo dati'),
(94589, 1421, 26, 'Database'),
(94590, 1422, 26, 'Database non installato.'),
(94591, 1423, 26, 'Patch database'),
(94592, 1424, 26, 'Reporting database'),
(94593, 1425, 26, 'Aggiornamento database concluso.'),
(94594, 1426, 26, 'Il numero di colonne deve essere da 1 a 999'),
(94595, 1427, 26, 'Data'),
(94596, 1428, 26, 'DATA'),
(94597, 1429, 26, 'Data e ora Somministrato'),
(94598, 1431, 26, 'Data somministrato'),
(94599, 1432, 26, 'Data e ora della raccolta dei campioni'),
(94600, 1433, 26, 'Data e ora di questa osservazione'),
(94601, 1435, 26, 'Data e ora in cui il campione è stato raccolto'),
(94602, 1436, 26, 'La data non può essere maggiore di Oggi'),
(94603, 1437, 26, 'Data delle prestazioni contraccettive fornite inizialmente'),
(94604, 1438, 26, 'Data creazione'),
(94605, 1439, 26, 'Data decesso'),
(94606, 1440, 26, 'Data distrutta'),
(94607, 1441, 26, 'Formato di visione della data'),
(94608, 1442, 26, 'Il formato della data per "fine appuntamento" non è valido'),
(94609, 1443, 26, 'Il formato della data per "inizio appuntamento" non è valido'),
(94610, 1444, 26, 'Il formato per "Prossimo Appuntamento" non è valido'),
(94611, 1445, 26, 'Il formato per "non visto dal" non è valido'),
(94612, 1446, 26, 'Il formato per "visto dal" non è valido'),
(94613, 1447, 26, 'Data di immunizzazione dichiarazioni e informazioni fornite'),
(94614, 1448, 26, 'Data mancante per il codice '),
(94615, 1449, 26, 'Criteri master date'),
(94616, 1450, 26, 'Data del deposito bancario aaaa-mm-gg'),
(94617, 1451, 26, 'Data di fatturazione'),
(94618, 1452, 26, 'Data di Nascita'),
(94619, 1453, 26, 'Data di nascita'),
(94620, 1454, 26, 'Data DI Nascita'),
(94621, 1455, 26, 'Data di immissione'),
(94622, 1456, 26, 'Data della Lesione'),
(94623, 1458, 26, 'Data del pagamento aaaa-mm-gg'),
(94624, 1459, 26, 'Data della consultazione'),
(94625, 1460, 26, 'Data della replica'),
(94626, 1461, 26, 'Data del Report'),
(94627, 1462, 26, 'Data della prestazione'),
(94628, 1463, 26, 'Data della prestazione'),
(94629, 1464, 26, 'Data della Prestazione = Oggi'),
(94630, 1465, 26, 'Data della prestazione mm/gg/aaaa'),
(94631, 1466, 26, 'Data della Prestazione:'),
(94632, 1467, 26, 'Data Della Firma'),
(94633, 1468, 26, 'Data di cambiamento di stato'),
(94634, 1469, 26, 'Data di questo ordine'),
(94635, 1470, 26, 'Data di questo rapporto'),
(94636, 1471, 26, 'Data dichiarazione VIS'),
(94637, 1472, 26, 'Data ordinata'),
(94638, 1474, 26, 'Selettore Data'),
(94639, 1475, 26, 'Selettore data'),
(94640, 1476, 26, 'Data Invio'),
(94641, 1477, 26, 'Data del messaggio inviato'),
(94642, 1478, 26, 'Data Ora'),
(94643, 1479, 26, 'Il valore della data non può essere in bianco'),
(94644, 1480, 26, 'Data/Appt'),
(94645, 1481, 26, 'Data/Note'),
(94646, 1482, 26, 'Data/Ultime note'),
(94647, 1483, 26, 'Data/Ora'),
(94648, 1484, 26, 'Data:'),
(94649, 1485, 26, 'Data messaggio di log'),
(94650, 1486, 26, 'Giorno'),
(94651, 1487, 26, 'giorno'),
(94652, 1489, 26, 'Vista giorno'),
(94653, 1490, 26, 'Giorno(i)'),
(94654, 1491, 26, 'Giorno(i) M-F'),
(94655, 1492, 26, 'giorni'),
(94656, 1493, 26, 'Giorni'),
(94657, 1494, 26, 'giorni fa'),
(94658, 1495, 26, 'Giorni e giochi senza risposta'),
(94659, 1496, 26, 'Giorni dall''ultimo incontro'),
(94660, 1497, 26, 'Giorni mancanti'),
(94661, 1498, 26, 'Giorni per colonna:'),
(94662, 1500, 26, 'Giorni/Col:'),
(94663, 1501, 26, 'DB installato'),
(94664, 1502, 26, 'GG/MM/AAAA'),
(94665, 1503, 26, 'De-Identificazione'),
(94666, 1504, 26, 'Processo di de-identificazione completato'),
(94667, 1505, 26, 'Il processo di de-identificazione è in corso'),
(94668, 1506, 26, 'Il processo di de-identificazione è iniziato ed è in corso in background'),
(94669, 1507, 26, 'I dati de-identificati potrebbero essere incompleti'),
(94670, 1508, 26, 'I file di de-identificazione saranno salvati in'),
(94671, 1509, 26, 'DEA'),
(94672, 1511, 26, 'Non udente'),
(94673, 1512, 26, 'Informazione di debug'),
(94674, 1514, 26, 'Debugging'),
(94675, 1515, 26, 'Dic'),
(94676, 1516, 26, 'DECEDUTO'),
(94677, 1517, 26, 'Dicembre'),
(94678, 1518, 26, 'Libbre decimali o libbre e once separati da # (per esempio 5 # 4)'),
(94679, 1519, 26, 'Rifiutato di specificare'),
(94680, 1520, 26, 'Deducibile'),
(94681, 1521, 26, 'Met. Deducibile'),
(94682, 1522, 26, 'Default'),
(94683, 1523, 26, 'Vista Agenda di Defautl'),
(94684, 1524, 26, 'ID del modulo incontro di default'),
(94685, 1526, 26, 'Sede di default'),
(94686, 1527, 26, 'Lingua di default'),
(94687, 1528, 26, 'Lingua di default in assenza di scelta o permessi'),
(94688, 1529, 26, 'Elenco di default (scrittura, solo-aggiunte opzionali)'),
(94689, 1530, 26, 'Metodo di default'),
(94690, 1531, 26, 'Giorni di scadenza password di default'),
(94691, 1532, 26, 'Periodo di validità della password in giorni. 0 significa che questa caratteristica è disabilitata.'),
(94692, 1533, 26, 'Paese predefinito del paziente'),
(94693, 1535, 26, 'Priorità predefinita'),
(94694, 1536, 26, 'Erogante predefinito'),
(94695, 1537, 26, 'Intervallo predefinito'),
(94696, 1538, 26, 'Motivo della visita predefinito'),
(94697, 1540, 26, 'Parametri predefiniti'),
(94698, 1541, 26, 'Stato di default del checkbox nuova finestra nell''elenco pazienti.'),
(94699, 1542, 26, 'Impaginazione di default'),
(94700, 1546, 26, 'Unità di default'),
(94701, 1547, 26, 'Valore di default'),
(94702, 1548, 26, 'Magazzino di default'),
(94703, 1549, 26, 'Partner di default X12'),
(94704, 1550, 26, 'Default/Globale'),
(94705, 1551, 26, 'Canc'),
(94706, 1552, 26, 'canc'),
(94707, 1553, 26, 'Recidiva ritardata (> 12 Mesi)'),
(94708, 1554, 26, 'Elimina'),
(94709, 1555, 26, 'elimina'),
(94710, 1556, 26, 'Elimina le categorie con ID: '),
(94711, 1557, 26, 'Elimina la categoria'),
(94712, 1559, 26, 'Eliminazione fallita!'),
(94713, 1560, 26, 'Elimina il gruppo'),
(94714, 1561, 26, 'Elimina l''elenco'),
(94715, 1562, 26, 'Elimina le pagine'),
(94716, 1563, 26, 'Elimina paziente, incontro, modulo, tematica, pagamento, fattura o transazione'),
(94717, 1565, 26, 'Elimina la riga'),
(94718, 1566, 26, 'Elimina gli elementi selezionati'),
(94719, 1567, 26, 'Elimina gli elementi richiesti'),
(94720, 1568, 26, 'Eliminazione riuscita.'),
(94721, 1569, 26, 'Elimina questo documento'),
(94722, 1570, 26, 'Elimina questo modulo'),
(94723, 1571, 26, 'Elimina questa nota'),
(94724, 1572, 26, 'Eliminazione riuscita'),
(94725, 1573, 26, 'Eliminazione riuscita.'),
(94726, 1574, 26, 'Eliminazione'),
(94727, 1575, 26, 'L''eliminazione di questo evento non può essere annullata. Non può essere recuperata una volta eliminata. Sei sicuro di voler cancellare questo evento?'),
(94728, 1576, 26, 'Consegna confermata'),
(94729, 1577, 26, 'La consegna non è consentita all''indirizzo diretto specificato.'),
(94730, 1578, 26, 'La consegna non è al momento consentita all''indirizzo diretto specificato.'),
(94731, 1579, 26, 'La consegna del documento clinico allegato è stata richiesta dal paziente.'),
(94732, 1580, 26, 'La consegna del documento clinico allegato è stata richiesta dal paziente.'),
(94733, 1581, 26, 'Demenza'),
(94734, 1582, 26, 'Demografica'),
(94735, 1583, 26, 'Demografica (scrittura,solo aggiunte opzionale)'),
(94736, 1585, 26, 'Criteri filtro Demografica'),
(94737, 1586, 26, 'Demografica non autorizzata'),
(94738, 1587, 26, 'Demografica non autorizzata.'),
(94739, 1588, 26, 'Negato'),
(94740, 1589, 26, 'Denominatore'),
(94741, 1590, 26, 'Dentale'),
(94742, 1591, 26, 'Lista Tematica Dentale'),
(94743, 1592, 26, 'Tematica dentale'),
(94744, 1593, 26, 'Moduli di dipendenza'),
(94745, 1594, 26, 'Problemi di dipendenza'),
(94746, 1595, 26, 'A seconda del tipo di disegno di legge che si sta testando vedrete HCFA come uscita su una pagina vuota per le fatture HCFA, vedrete molte righe di testo un po ''confuso e informazioni se si sta testando un reclamo X12. Questo testo confuso è il formato EDI X12 4010A. Di tanto in tanto vedrete strani caratteri che assomigliano a tessere o squiglies, questi sono caratteri di controllo come feed pagina e sono normali.'),
(94747, 1596, 26, 'Data deposito'),
(94748, 1597, 26, 'La data del deposito non può essere maggiore di Oggi'),
(94749, 1598, 26, 'Data deposito:'),
(94750, 1599, 26, 'Depresso'),
(94751, 1600, 26, 'Depressione'),
(94752, 1601, 26, 'DESC'),
(94753, 1602, 26, 'Descrizione'),
(94754, 1603, 26, 'descrizione'),
(94755, 1604, 26, 'Descrizione è un testo predefinito'),
(94756, 1605, 26, 'Descrizione dell''Informativa'),
(94757, 1606, 26, 'Descrizione di questa procedura o del codice risultato'),
(94758, 1607, 26, 'Traduzione della Descrizione'),
(94759, 1608, 26, 'Nome del file desiderato'),
(94760, 1609, 26, 'Destinazione'),
(94761, 1610, 26, 'Nome del file destinazione'),
(94762, 1611, 26, 'Distruggere Lotto'),
(94763, 1612, 26, 'Sto distruggendo...'),
(94764, 1613, 26, 'Distrutto'),
(94765, 1614, 26, 'Farmaci distrutti'),
(94766, 1615, 26, 'Resoconto Farmaci distrutti'),
(94767, 1616, 26, 'Dettaglio'),
(94768, 1617, 26, 'Dettagli'),
(94769, 1619, 26, 'Anormalità dello sviluppo'),
(94770, 1620, 26, 'Diabete'),
(94771, 1621, 26, 'Diabete mellito'),
(94772, 1622, 26, 'Diabete: Gestione della pressione sanguigna (CQM)'),
(94773, 1623, 26, 'Diabete: Esame occhio'),
(94774, 1624, 26, 'Diabete: Esame occhio (CQM)'),
(94775, 1625, 26, 'Diabete: Esame piede'),
(94776, 1626, 26, 'Diabete: Esame piede (CQM)'),
(94777, 1627, 26, 'Diabete: HbA1c scarso controllo (CQM)'),
(94778, 1628, 26, 'Diabete: Emoglobina A1C'),
(94779, 1629, 26, 'Diabete: LDL Gestione e Controllo (CQM)'),
(94780, 1630, 26, 'Diabete: Microalbumina nelle urine'),
(94781, 1631, 26, 'Diag'),
(94782, 1632, 26, 'Diagnosi'),
(94783, 1633, 26, 'Diagnosi'),
(94784, 1634, 26, 'Codice Diagnosi'),
(94785, 1635, 26, 'Codici Diagnosi'),
(94786, 1636, 26, 'Data Diagnosi'),
(94787, 1637, 26, 'La diagnosi deve essere codificata all''interno di un incontro collegato'),
(94788, 1638, 26, 'Nome Diagnosi'),
(94789, 1639, 26, 'Resoconto Diagnosi'),
(94790, 1640, 26, 'Rapporto diagnosi'),
(94791, 1641, 26, 'Solo rapporto diagnosi'),
(94792, 1642, 26, 'Titolo Diagnosi'),
(94793, 1643, 26, 'Diagnosi:'),
(94794, 1644, 26, 'Diagnosi: '),
(94795, 1645, 26, 'Test diagnostici:'),
(94796, 1646, 26, 'Chiama'),
(94797, 1647, 26, 'Diaframmi / Cappucci'),
(94798, 1648, 26, 'Diarrea'),
(94799, 1650, 26, 'Dettato'),
(94800, 1651, 26, 'Dettato: '),
(94801, 1652, 26, 'Hai ricevuto una copia dell''Avviso HIPPA'),
(94802, 1653, 26, 'Diffuso:'),
(94803, 1654, 26, 'Firmato digitalmente'),
(94804, 1657, 26, 'Mail diretta'),
(94805, 1658, 26, 'Log messaggi diretti'),
(94806, 1659, 26, 'Messaggi diretti ricevuti.'),
(94807, 1660, 26, 'I messaggi diretti non sono al momento disponibili.'),
(94808, 1661, 26, 'Invio messaggi diretti fallito.'),
(94809, 1663, 26, 'Nome Direttore'),
(94810, 1664, 26, 'Eliminazione directory fallita; continuare.'),
(94811, 1665, 26, 'Disabilità'),
(94812, 1666, 26, 'Disabile'),
(94813, 1667, 26, 'Disabilita Agenda'),
(94814, 1668, 26, 'Disattiva tracciatura tabella'),
(94815, 1669, 26, 'Disabilita Immunizzazioni'),
(94816, 1670, 26, 'Disabilita la vecchi ametrica dei Vitali'),
(94817, 1672, 26, 'Disabilita phpMyAdmin'),
(94818, 1673, 26, 'Disabilita Prescrizioni'),
(94819, 1674, 26, 'Disabilita Gruppi Utenti'),
(94820, 1675, 26, 'disabilitato'),
(94821, 1676, 26, 'Disabilitato'),
(94822, 1677, 26, 'Beneficiario disabile sotto i 65 anni con grande gruppo piano sanitario'),
(94823, 1678, 26, 'DISC'),
(94824, 1679, 26, 'Scartare'),
(94825, 1680, 26, 'Scartato'),
(94826, 1681, 26, 'Scarico'),
(94827, 1682, 26, 'Scarico dall''uretra'),
(94828, 1684, 26, 'Scarico destro'),
(94829, 1685, 26, 'Scarico destro:'),
(94830, 1688, 26, 'Dimesso'),
(94831, 1689, 26, 'info Informativa'),
(94832, 1690, 26, 'Tipo Informativa'),
(94833, 1691, 26, 'Tipi Informativa'),
(94834, 1692, 26, 'Informative'),
(94835, 1694, 26, 'Sconto'),
(94836, 1695, 26, 'Importo sconto'),
(94837, 1696, 26, 'Livello di sconto'),
(94838, 1697, 26, 'Percentuale di sconto'),
(94839, 1698, 26, 'Sconti  a partire da piani finianziari'),
(94840, 1699, 26, 'Sconti in fase di check-out sono inseriti come somme di denaro, al contrario di percentuale.'),
(94841, 1700, 26, 'Risultato discreto'),
(94842, 1701, 26, 'Malattia'),
(94843, 1702, 26, 'Dislocazione'),
(94844, 1703, 26, 'Disp #'),
(94845, 1704, 26, 'Dispaccio'),
(94846, 1705, 26, 'Dispaccio documento ricevuto'),
(94847, 1706, 26, 'Dispensato'),
(94848, 1707, 26, 'Mostra dichiarazioni anticipate nella pagina demografici.'),
(94849, 1708, 26, 'Mostra i documenti'),
(94850, 1709, 26, 'Visualizzare le date di eventi in blocco?'),
(94851, 1710, 26, 'Formato di visualizzazione per i pesi degli Stati Uniti'),
(94852, 1711, 26, 'Mostrare quanti eventi?'),
(94853, 1713, 26, 'Visualizza posizione nel blocco?'),
(94854, 1714, 26, 'Mostrare il nome'),
(94855, 1715, 26, 'Mostrare l''agenda?'),
(94856, 1718, 26, 'Mostro gli eventi di oggi nel blocco?'),
(94857, 1719, 26, 'Mostro l''argomento nel blocco'),
(94858, 1720, 26, 'Mostro i prossimi appuntamenti nel blocco?'),
(94859, 1721, 26, 'Colonne mostrate'),
(94860, 1722, 26, 'Sto mostrando il seguente numero di informative più recenti:'),
(94861, 1723, 26, 'Sto mostrando il seguente numero di note più recenti'),
(94862, 1724, 26, 'Sto mostrando il seguente numero di note più recenti:'),
(94863, 1725, 26, 'Distribuzione'),
(94864, 1726, 26, 'Distribuzioni'),
(94865, 1727, 26, 'Distributore'),
(94866, 1728, 26, 'Divehi- Dhivehi- Maldivian-'),
(94867, 1729, 26, 'Diverticolite'),
(94868, 1730, 26, 'Intervento per diverticolite'),
(94869, 1731, 26, 'Diverticolite'),
(94870, 1732, 26, 'Intervento per diverticolite'),
(94871, 1733, 26, 'Divorziato(a)'),
(94872, 1734, 26, 'Vertigini:'),
(94873, 1735, 26, 'Non cambiare'),
(94874, 1737, 26, 'Non visualizzare allergie caricate ultimamente'),
(94875, 1739, 26, 'Non visualizzare farmaci caricati ultimamente'),
(94876, 1742, 26, 'Non mostrare il calendario'),
(94877, 1744, 26, 'Non mettere in inventario o vendere alcun prodotto'),
(94878, 1745, 26, 'Non è richiesto che le note siano autorizzate'),
(94879, 1746, 26, 'Non riesumare l''ordine'),
(94880, 1747, 26, 'non salvare'),
(94881, 1748, 26, 'non sostituire'),
(94882, 1749, 26, 'non fare nulla'),
(94883, 1751, 26, 'Vuoi veramente eliminare'),
(94884, 1752, 26, 'Vuoi veramente eliminare la selezione?'),
(94885, 1753, 26, 'Vuoi veramente eliminare questo gruppo'),
(94886, 1754, 26, 'Vuoi veramente eliminare?'),
(94887, 1755, 26, 'Vuoi continuare?'),
(94888, 1756, 26, 'Vuoi eliminare questo?'),
(94889, 1757, 26, 'Vuoi eliminare?'),
(94890, 1758, 26, 'Vuoi rimuovere questo record?'),
(94891, 1759, 26, 'Vuoi continuare ad aggiungere questo paziente?'),
(94892, 1760, 26, 'Vuoi continuare con il nuovo nome?'),
(94893, 1761, 26, 'Vuoi eliminare DEFINITIVAMENTE questa registrazione di immunizzazione?'),
(94894, 1762, 26, 'DN'),
(94895, 1763, 26, 'DN mancante, se possibile inseriscila'),
(94896, 1764, 26, 'Doc.ti'),
(94897, 1765, 26, 'Dottore'),
(94898, 1766, 26, 'Dottore:'),
(94899, 1767, 26, 'Nome del dottore e firma'),
(94900, 1768, 26, 'Documento'),
(94901, 1769, 26, 'documento'),
(94902, 1770, 26, 'Categorie documenti'),
(94903, 1771, 26, 'La categoria del documento per i risultati di laboratorio non esiste'),
(94904, 1772, 26, 'Nome della categoria del documento per la memorizzazione dei risultati di laboratorio ricevute elettronicamente.'),
(94905, 1774, 26, 'Categoria documento o Scarta'),
(94906, 1775, 26, 'Il documento non può essere spostato al paziente con id'),
(94907, 1777, 26, 'Data del documento'),
(94908, 1778, 26, 'Data del documento e Informativa aggiornata con successo'),
(94909, 1779, 26, 'ID del documento'),
(94910, 1780, 26, 'Documento spostato alla nuova categoria'),
(94911, 1781, 26, 'Documento spostato al paziente con id'),
(94912, 1783, 26, 'Il documento ha superato il controllo di integrità'),
(94913, 1784, 26, 'Metodo di archiviazione documento'),
(94914, 1785, 26, 'Il documento è stato rinominato con successo.'),
(94915, 1786, 26, 'Documento etichettato per l''incontro con successo'),
(94916, 1787, 26, 'Gestione documentale dei modelli'),
(94917, 1788, 26, 'Modelli documento'),
(94918, 1789, 26, 'Documento(i)'),
(94919, 1790, 26, 'Documento / Archivio immagine'),
(94920, 1791, 26, 'Documenti'),
(94921, 1792, 26, 'Documenti (scrittura solo-aggiunte opzionali)'),
(94922, 1794, 26, 'DOE'),
(94923, 1796, 26, 'non corrisponde al numero di incontro PV1'),
(94924, 1797, 26, 'non sembra valido'),
(94925, 1798, 26, 'Questo tipo consente codici correlati?'),
(94926, 1799, 26, 'Convivente'),
(94927, 1800, 26, 'Non salvare'),
(94928, 1801, 26, 'Non salvare'),
(94929, 1802, 26, 'Non salvare i cambiamenti'),
(94930, 1803, 26, 'Fatto'),
(94931, 1804, 26, 'Realizzato con:'),
(94932, 1805, 26, 'Fatto. Ora verrà inviato il download.'),
(94933, 1806, 26, 'DOS'),
(94934, 1807, 26, 'Dosaggio'),
(94935, 1809, 26, 'doppio clic per modificare'),
(94936, 1810, 26, 'Visione doppia'),
(94937, 1811, 26, 'Scarica'),
(94938, 1814, 26, 'Scarica comunque'),
(94939, 1815, 26, 'Scaricare file di fatturazione, inviare alla contabilità e contrassegnare come fatturato'),
(94940, 1817, 26, 'Scarica i Certificati'),
(94941, 1818, 26, 'Scarica i dati di configurazione'),
(94942, 1819, 26, 'Carica modello documento per questo paziente e visita'),
(94943, 1820, 26, 'scarica il file criptato'),
(94944, 1823, 26, 'Scarica Offsite Portal file di connessione'),
(94945, 1824, 26, 'Scarica o Elimina il modello'),
(94946, 1825, 26, 'Scarica PDF'),
(94947, 1827, 26, 'Scarica le dichiarazioni selezionate'),
(94948, 1828, 26, 'Controllo Dr'),
(94949, 1829, 26, 'Visita Dr'),
(94950, 1830, 26, 'Dr.'),
(94951, 1831, 26, 'Trascina per spostare'),
(94952, 1832, 26, 'Dribblare'),
(94953, 1833, 26, 'Patente di guida o ID dello stato'),
(94954, 1834, 26, 'Farmaco'),
(94955, 1835, 26, 'Trova farmaci'),
(94956, 1836, 26, 'Forme del farmaco'),
(94957, 1837, 26, 'ID del farmaco mancante!'),
(94958, 1838, 26, 'Intervalli farmaco'),
(94959, 1839, 26, 'Inventario farmaci'),
(94960, 1840, 26, 'Nome farmaco'),
(94961, 1841, 26, 'Vie farmaco'),
(94962, 1845, 26, 'Unità farmaco'),
(94963, 1846, 26, 'Farmaci'),
(94964, 1847, 26, 'Farmaci e prodotti'),
(94965, 1848, 26, 'Bocca secca'),
(94966, 1849, 26, 'DSMIV Diagnosi'),
(94967, 1850, 26, 'DT 1'),
(94968, 1851, 26, 'DT 2'),
(94969, 1852, 26, 'DT 3'),
(94970, 1853, 26, 'DT 4'),
(94971, 1854, 26, 'DT 5'),
(94972, 1855, 26, 'DTaP 1'),
(94973, 1856, 26, 'DTaP 2'),
(94974, 1857, 26, 'DTaP 3'),
(94975, 1858, 26, 'DTaP 4'),
(94976, 1859, 26, 'DTaP 5'),
(94977, 1860, 26, 'Debito'),
(94978, 1861, 26, 'Data del debito'),
(94979, 1862, 26, 'Data del debito mm/gg/aaaa o aaaa/mm/gg'),
(94980, 1863, 26, 'Data debito:'),
(94981, 1864, 26, 'Debito ins'),
(94982, 1865, 26, 'Debito Parz.'),
(94983, 1866, 26, 'Debiti a breve'),
(94984, 1867, 26, 'Status debito'),
(94985, 1868, 26, 'Aggiornamento status debito'),
(94986, 1869, 26, 'Dumping LibreEHR database'),
(94987, 1870, 26, 'Dumping LibreEHR web directory tree'),
(94988, 1871, 26, 'Dumping phpGACL database'),
(94989, 1872, 26, 'Dumping phpGACL web directory tree'),
(94990, 1873, 26, 'Dumping SQL-Ledger database'),
(94991, 1874, 26, 'Dumping SQL-Ledger web directory tree'),
(94992, 1875, 26, 'Controllo dupl'),
(94993, 1876, 26, 'ID duplicato nella linea'),
(94994, 1877, 26, 'Nome duplicato nella linea'),
(94995, 1878, 26, 'ATTENZIONE DUPLICAZIONE'),
(94996, 1879, 26, 'Potere durevole di avvocato'),
(94997, 1880, 26, 'durata'),
(94998, 1881, 26, 'Durata'),
(94999, 1882, 26, 'Olandese'),
(95000, 1883, 26, 'Dx Rep'),
(95001, 1884, 26, 'Disfagia'),
(95002, 1885, 26, 'Dispnea'),
(95003, 1886, 26, 'Disuria'),
(95004, 1887, 26, 'Dzongkha'),
(95005, 1888, 26, 'E-prescrizione?'),
(95006, 1889, 26, 'E-Reports'),
(95007, 1890, 26, 'e-Rx'),
(95008, 1892, 26, 'e-Rx Rinnovo'),
(95009, 1893, 26, 'Ogni destinatario deve impostare i propri messaggi come completati.'),
(95010, 1894, 26, 'Prima occorrenza (< 2 mesi)'),
(95011, 1895, 26, 'Orecchie'),
(95012, 1896, 26, 'ECG'),
(95013, 1897, 26, 'Sinistri'),
(95014, 1898, 26, 'Edema'),
(95015, 1899, 26, 'Storico edi'),
(95016, 1900, 26, 'Storico EDI'),
(95017, 1901, 26, 'Storico EDI (con tasse) per memorizzare e interpretare i file di risposta sinistri EDI'),
(95018, 1902, 26, 'EDI-271 carico file'),
(95019, 1903, 26, 'EDI-271 risposta carico file'),
(95020, 1904, 26, 'Modifica'),
(95021, 1905, 26, 'modifica'),
(95022, 1906, 26, 'Modifica Allergie'),
(95023, 1907, 26, 'Modifica Categorie'),
(95024, 1908, 26, 'Modifica Definizioni'),
(95025, 1909, 26, 'Modifica definizioni'),
(95026, 1910, 26, 'Modifica Diagnosi per'),
(95027, 1911, 26, 'Modifica Informativa'),
(95028, 1912, 26, 'Modifica Sedi'),
(95029, 1913, 26, 'Modifica Sede'),
(95030, 1914, 26, 'Modifica Informazioni sede'),
(95031, 1915, 26, 'Strumento specifico di modifica utente informazioni'),
(95032, 1916, 26, 'Modifica file in'),
(95033, 1917, 26, 'Modifica modulo'),
(95034, 1918, 26, 'Modifica Parametri globali'),
(95035, 1919, 26, 'Modifica non autorizzata!'),
(95036, 1920, 26, 'Modifica layout'),
(95037, 1921, 26, 'Modifica elenco'),
(95038, 1922, 26, 'Modifica Pagamento'),
(95039, 1923, 26, 'Modifica Struttura'),
(95040, 1924, 26, 'Modifica Utente'),
(95041, 1925, 26, 'Modifica Paramentri utente'),
(95042, 1926, 26, 'Modifica i tuoi dati inseriti'),
(95043, 1927, 26, 'Modifica fallita'),
(95044, 1928, 26, 'Istruzione'),
(95045, 1929, 26, 'Data istruzione'),
(95046, 1930, 26, 'Materiali istruzione per'),
(95047, 1931, 26, 'Leggi la *GNU General Public License per maggiori dettagli.** Dovresti aver ricevuto una copia della GNU General Public License* in allegato a questo programma: diversamente scrivi alla Free (ndt: Software Foundation?) '),
(95048, 1932, 26, 'Data effettiva'),
(95049, 1934, 26, 'Efficacia'),
(95050, 1935, 26, 'EIN'),
(95051, 1936, 26, 'Eiaculazioni'),
(95052, 1937, 26, 'Gomito'),
(95053, 1938, 26, 'Problemi al gomito'),
(95054, 1939, 26, 'Elettronico'),
(95055, 1942, 26, 'Mandati elettronici'),
(95056, 1943, 26, 'Reports Elettronico'),
(95057, 1944, 26, 'Ammissibilità'),
(95058, 1945, 26, 'Ammissibilità 270 domanda batch'),
(95059, 1946, 26, 'Risposta ammissibilità'),
(95060, 1947, 26, 'Condizione di ammissibilità per il vaccino per i bambini forniti di vaccino'),
(95061, 1948, 26, 'Idoneo'),
(95062, 1949, 26, 'Email'),
(95063, 1950, 26, 'email'),
(95064, 1951, 26, 'Indirizzo Email'),
(95065, 1952, 26, 'Manca indirizzo Email'),
(95066, 1953, 26, 'Indirizzo email del mittente per i promemoria al paziente. Le repliche ai promemoria al paziente saranno dirette a questo indirizzo. E'' importante usare un indirizzo dal dominio della tua clinica per evitare che i promemoria finiscano nelle cartelle di spam della posta.'),
(95067, 1954, 26, 'Indirizzo email, se alcuno, per ricevere notifiche amministrative.'),
(95068, 1955, 26, 'Indirizzo email, se alcuno, per ricevere messaggi di attivazione utente per ingresso di emergenza.'),
(95069, 1956, 26, 'Autore email'),
(95070, 1957, 26, 'Email da Batchcom'),
(95071, 1958, 26, 'Notifica email'),
(95072, 1959, 26, 'Ore per la Notifica via Email'),
(95073, 1960, 26, 'Report notifica Email'),
(95074, 1961, 26, 'Email inviata prima'),
(95075, 1962, 26, 'Mittente email'),
(95076, 1963, 26, 'Email inviata'),
(95077, 1964, 26, 'Email inviata a'),
(95078, 1965, 26, 'Oggetto dell''email'),
(95079, 1966, 26, 'Testo dell''email, tag utilizzabili ***NAME*** , p.es. Gentile Sig. ***NAME***'),
(95080, 1967, 26, 'Testo dell''email, tag utilizzabili ***NAME*** , p.es. Gentile Sig. ***NAME***{{Non tradurre ***NAME*** questo elemento è una costante.}}'),
(95081, 1968, 26, 'Metodo di trasporto dell''email'),
(95082, 1969, 26, 'l''email è stata inviata al seguente indirizzo'),
(95083, 1971, 26, 'Contatto di emergenza'),
(95084, 1972, 26, 'Persona da contattare in caso di emergenza'),
(95085, 1973, 26, 'Numero telefonico per contatto di emergenza'),
(95086, 1974, 26, 'Contraccezione di emergenza'),
(95087, 1975, 26, 'Ingresso di Emergenza'),
(95088, 1976, 26, 'E'' stato scelto l''Ingresso di Emergenza di ACL. L''utente è ancora in stato attivo, disattiva l''utente e attivalo di nuovo quando richiesto durante situazioni di emergenza. Visita Amminitrazione->Utenti per l''attivazione o disattivazione.'),
(95089, 1977, 26, 'L''email di attivazione per l''Ingresso di Emergenza cirdolerà soltanto se sono configurati i seguenti parametri in interface/globals.php'),
(95090, 1978, 26, 'Indirizzo Ingresso di emergenza'),
(95091, 1979, 26, 'Ingresso di Emergenza l''utente può fare tutto'),
(95092, 1980, 26, 'Telefono di emergenza'),
(95093, 1981, 26, 'Emozionali / Comportamentali Condizioni e complicanze'),
(95094, 1982, 26, 'Enfisema'),
(95095, 1983, 26, 'Impiegato'),
(95096, 1984, 26, 'Datore di lavoro'),
(95097, 1985, 26, 'Indirizzo Datore di lavoro'),
(95098, 1986, 26, 'Dati Datore di lavoro'),
(95099, 1987, 26, 'Nome Datore di lavoro'),
(95100, 1988, 26, 'VUOTO'),
(95101, 1989, 26, 'Vuoto'),
(95102, 1990, 26, 'Valore vuoto nella Password non consentito'),
(95103, 1991, 26, 'Valore vuoto in "Ora email"'),
(95104, 1992, 26, 'Valore vuoto in "Mittente email"'),
(95105, 1993, 26, 'Valore vuoto in "Oggetto email"'),
(95106, 1994, 26, 'Valore vuoto in "Testo email"'),
(95107, 1995, 26, 'Valore vuoto in "Nome del provider"'),
(95108, 1996, 26, 'Valore vuoto in "Password"'),
(95109, 1997, 26, 'Valore vuoto in "Ora SMS"'),
(95110, 1998, 26, 'Valore vuoto in "Testo SMS"'),
(95111, 1999, 26, 'Valore vuoto in "Nome utente"'),
(95112, 2001, 26, 'Abilita'),
(95113, 2006, 26, 'Abilita i suggeirmenti AMC'),
(95114, 2007, 26, 'Abilita AMC Rapporto itemizzazione'),
(95115, 2008, 26, 'Abilita i resoconti AMC'),
(95116, 2009, 26, 'Abilita tracciatura AMC'),
(95117, 2010, 26, 'Abilita modifiche presentate'),
(95118, 2011, 26, 'Abilita revisione ATNA'),
(95119, 2012, 26, 'Abilita crittazione log di registrazione'),
(95120, 2013, 26, 'Abilita registrazione di controllo'),
(95121, 2014, 26, 'Abilita storico accessi e l''autenticazione del nodo (ATNA).');
INSERT INTO `lang_definitions` VALUES
(95122, 2015, 26, 'Abilita i resoconti dei Calcoli delle misure automatizzati (AMC)'),
(95123, 2016, 26, 'Abilita il client SSL'),
(95124, 2017, 26, 'Abilita i certificati SSL di autenticazione client.'),
(95125, 2019, 26, 'Abilita le regole di decisione clinica (CDR)'),
(95126, 2022, 26, 'Abilita i resoconti di Misura della Qualità Clinica (CQM)'),
(95127, 2023, 26, 'Abilita l''apertura automativa della finestra dei promemoria clinici'),
(95128, 2024, 26, 'Abilita il widget dei promemoria clicnici'),
(95129, 2025, 26, 'Abilita il portale CMS'),
(95130, 2026, 26, 'Abilita CQM rapporto itemizzazione'),
(95131, 2027, 26, 'Abilita i resoconti CQM'),
(95132, 2028, 26, 'Abilita cronologia EDI nel menù di sinistra'),
(95133, 2030, 26, 'Abilita Tariffe nel menu a sinistra'),
(95134, 2031, 26, 'Abilita il supporto Hylafax'),
(95135, 2033, 26, 'Attiva messaggio di stato di importazione per NewCrop ERX'),
(95136, 2034, 26, 'Abilita Itemizzazione del rapporto AMC'),
(95137, 2035, 26, 'Abilita Itemizzazione del rapporto CQM'),
(95138, 2036, 26, 'Abilita Itemizzazione delle regole standard dei report regole cliniche'),
(95139, 2037, 26, 'Abilita il Lab Exchange'),
(95140, 2038, 26, 'Abilita levetta di blocco'),
(95141, 2039, 26, 'Abilita log di upload / download di documenti di CouchDB'),
(95142, 2040, 26, 'Abilita la scrittura dei log di tutte le interrogazioni SQL di tipo SELECT.'),
(95143, 2041, 26, 'Abilita la scrittura dei log delle attività correlate ai backup.'),
(95144, 2042, 26, 'Abilita la scrittura delle relative attività di backup.'),
(95145, 2043, 26, 'Abilita la scrittura dei log delle attività miscellanee.'),
(95146, 2044, 26, 'Abilita la scrittura dei logdelle attività di prescrizione.'),
(95147, 2045, 26, 'Abilita la scrittura dei log delle modificazioni dei record del paziente.'),
(95148, 2046, 26, 'Abiolita la scrittura dei log delle attività di compilazione dell''agenda.'),
(95149, 2047, 26, 'Abbilita la scrittura dei log delle attività di sicurezza e amministrazione.'),
(95150, 2049, 26, 'Abilita i servizi NewCrop e Rx'),
(95151, 2051, 26, 'Abilita il Portale Paziente Offsite'),
(95152, 2052, 26, 'Abilita il Portale Paziente Offsite.'),
(95153, 2053, 26, 'Abilita il Portale Paziente Onsite'),
(95154, 2055, 26, 'Abilita il Portale Paziente Onsite.'),
(95155, 2056, 26, 'Abilita il widget per i promemoria al paziente'),
(95156, 2057, 26, 'Abilita phiMail servizio di messaggi diretti'),
(95157, 2058, 26, 'Abilita il suggerimento dei dati richiesti per i Calcoli automatici delle misure (AMC)'),
(95158, 2060, 26, 'Abilita i resoconti del monitoraggio della data per i Calcoli automatici delle misure (AMC)'),
(95159, 2061, 26, 'Abilita il supporto per lo scanner'),
(95160, 2062, 26, 'Abilita il report standard di itemizzazione'),
(95161, 2063, 26, 'Abilitare il supporto per l''open source WordPress Portal da Sunset Sistemi'),
(95162, 2064, 26, 'Abilitare il Medical Information Integration, LLC Lab Service Exchange.'),
(95163, 2065, 26, 'Abilita il supporto LibreEHR per il servizio Scambio LLC Lab'),
(95164, 2066, 26, 'Abilita l''autenticazione certificato dell''utente'),
(95165, 2067, 26, 'Abilita il servizio ZMG, LLC eRx'),
(95166, 2068, 26, 'abilitato'),
(95167, 2070, 26, 'Abilita il vecchio pannello "Costi" per inserire codici e pagamenti. Non raccomandato, usare invece il Foglio Parcelle.'),
(95168, 2071, 26, 'Inc'),
(95169, 2072, 26, 'Inctr'),
(95170, 2073, 26, 'Incontro'),
(95171, 2074, 26, 'incontro'),
(95172, 2075, 26, 'Incontro '),
(95173, 2076, 26, 'incontrare ricoverato acuto o ED'),
(95174, 2080, 26, 'dati incontro'),
(95175, 2081, 26, 'Data incontro'),
(95176, 2084, 26, 'Registro incontro EDI'),
(95177, 2086, 26, 'Moduli Incontro'),
(95178, 2087, 26, 'incontro per valutazione salute e comportamento'),
(95179, 2088, 26, 'Storico degli Incontri'),
(95180, 2089, 26, 'ID incontro'),
(95181, 2090, 26, 'incontro per influenza'),
(95182, 2091, 26, 'Numero incontro'),
(95183, 2093, 26, 'incontro di scarico infermieristico'),
(95184, 2094, 26, 'incontro struttura di cura'),
(95185, 2095, 26, 'incontro per terapia occupazionale'),
(95186, 2096, 26, 'incontro per visita in studio'),
(95187, 2097, 26, 'incontro paziente esterno'),
(95188, 2098, 26, 'incontro ambulatoriale w / PCP & Ostetricia e Ginecologia'),
(95189, 2099, 26, 'Dimensione pagina incontri'),
(95190, 2100, 26, 'Pagamento incontro'),
(95191, 2101, 26, 'incontro per gravidanza'),
(95192, 2102, 26, 'incontro di medicina preventiva - consulenza individuale'),
(95193, 2103, 26, 'incontro di medicina preventiva - per pz dai 40 anni in poi'),
(95194, 2104, 26, 'incontro di medicina preventiva consulenza di gruppo'),
(95195, 2105, 26, 'incontro di medicina preventiva consulenza preventiva altre prestazioni'),
(95196, 2106, 26, 'incontro di medicina preventiva prestazioni per dai 18 anni in poi'),
(95197, 2107, 26, 'incontro psichiatrico & psicologico'),
(95198, 2108, 26, 'Statistiche incontri'),
(95199, 2109, 26, 'Riassunto incontri'),
(95200, 2110, 26, 'L''incontro è stato codificato'),
(95201, 2111, 26, 'Incontro:'),
(95202, 2112, 26, 'Incontro: incontro pz. ricov. non-acuto, pz esterno, o oftalmologia'),
(95203, 2113, 26, 'Incontri'),
(95204, 2114, 26, 'Incontri & Moduli'),
(95205, 2115, 26, 'Incontri &amp; Moduli'),
(95206, 2116, 26, 'Incontri non autorizzati'),
(95207, 2117, 26, 'Resoconto Incontri'),
(95208, 2118, 26, 'Sezione Incontri'),
(95209, 2120, 26, 'Cifratura'),
(95210, 2121, 26, 'Fine'),
(95211, 2122, 26, 'Fine (aaa-mm-gg) '),
(95212, 2123, 26, 'Data Fine'),
(95213, 2124, 26, 'Data fine'),
(95214, 2126, 26, 'La data di fine deve essere maggiore della data inizio'),
(95215, 2127, 26, 'Data Fine:'),
(95216, 2130, 26, 'Fine del report'),
(95217, 2131, 26, 'Ora fine'),
(95218, 2132, 26, 'Malattia renale in stadio terminale beneficiario in MCP con il piano del gruppo del datore di lavoro'),
(95219, 2133, 26, 'Data conclusione del servizio aaaa-mm-gg'),
(95220, 2134, 26, 'Fine DOS gg/mm/aaaa, se si desidera inserire un intervallo'),
(95221, 2135, 26, 'Ora finale del giorno per gli eventi dell''agenda.'),
(95222, 2136, 26, 'Endo anormale del sangue'),
(95223, 2137, 26, 'Endocrino'),
(95224, 2138, 26, 'Endoscopia'),
(95225, 2141, 26, 'Inglese'),
(95226, 2142, 26, 'Inglese '),
(95227, 2143, 26, 'Inglese (indiano)'),
(95228, 2144, 26, 'Inglese (standard)'),
(95229, 2145, 26, 'Comando enscript usato da Hylafax.'),
(95230, 2146, 26, 'Accertarsi che LibreEHR abbia i privilegi di scrittura nella directory'),
(95231, 2147, 26, 'ENT fuoriuscita'),
(95232, 2148, 26, 'ENT dolore'),
(95233, 2149, 26, 'Inserisci un codice diagnosi per escludere tutte le fatture che non lo contengono'),
(95234, 2150, 26, 'Inserisci modifica ...'),
(95235, 2151, 26, 'Inserisci il corpo della lettera qui'),
(95236, 2152, 26, 'Inserisci password root del Database'),
(95237, 2153, 26, 'Inserisci l''username root'),
(95238, 2154, 26, 'Inserisci la diagnosi'),
(95239, 2155, 26, 'Inserisci i farmaci'),
(95240, 2156, 26, 'Inserisci incontro'),
(95241, 2157, 26, 'Inserisci numero incontro'),
(95242, 2158, 26, 'Inserisci le immunizzazioni'),
(95243, 2159, 26, 'Inserisci la chiave'),
(95244, 2160, 26, 'Inserisci novi dati'),
(95245, 2161, 26, 'Inserisci il nuovo Stato'),
(95246, 2162, 26, 'Inserisci indirizzo diretto destinatario(i)'),
(95247, 2163, 26, 'Iserisci il codice LOINC per questa procedura'),
(95248, 2164, 26, 'Inserisci il codice di re-identificazione'),
(95249, 2165, 26, 'Inserisci sopra i criteri di ricerca'),
(95250, 2166, 26, 'Inserite per errore'),
(95251, 2167, 26, 'voci'),
(95252, 2168, 26, 'Ambientale'),
(95253, 2169, 26, 'EOB immissione dati'),
(95254, 2170, 26, 'EOB Scrittura - Rimesse elettroniche'),
(95255, 2171, 26, 'EOB Scrittura - Istruzioni'),
(95256, 2172, 26, 'EOB Scrittura - Fattura'),
(95257, 2173, 26, 'EOB Scrittura - Nota paziente'),
(95258, 2174, 26, 'EOB Scrittura - Ricerca'),
(95259, 2176, 26, 'Epilessia'),
(95260, 2178, 26, 'ERA'),
(95261, 2179, 26, 'Files ERA'),
(95262, 2180, 26, 'Pubblicazione ERA'),
(95263, 2181, 26, 'Elimina'),
(95264, 2182, 26, 'Erezioni'),
(95265, 2183, 26, 'Errore'),
(95266, 2184, 26, 'ERRORE'),
(95267, 2185, 26, 'Errore di conferma ricevuta dei risultati del lab'),
(95268, 2187, 26, 'Errore nella ricezione dei risultati dal Network Lab Exchange'),
(95269, 2188, 26, 'Errore nella sellezione del "Genere"'),
(95270, 2189, 26, 'Errore nella selezioni di "HIPAA"'),
(95271, 2190, 26, 'Errore nella selezione del "Processo"'),
(95272, 2191, 26, 'Errore nella selezione del "Gateway SMS"'),
(95273, 2192, 26, 'Errore nella selezione di "Ordina per"'),
(95274, 2193, 26, 'Errore nella compressione del file gzip: '),
(95275, 2194, 26, 'Errore nella opzione SI o NO'),
(95276, 2195, 26, 'Errore nell''apertura per la lettura del file scaricato'),
(95277, 2196, 26, 'File di elaborazione errori'),
(95278, 2197, 26, 'Errore di caricamento elaborazione'),
(95279, 2198, 26, 'Errore rimozione messaggio'),
(95280, 2199, 26, 'Errore nel recupero dei risultati dal Network Lab Exchange'),
(95281, 2200, 26, 'Errore nel recupero dei valori.'),
(95282, 2201, 26, 'Errore nel salvataggio del documento'),
(95283, 2202, 26, 'Errore nell''assegnare il file dei privilegi all''utente LibreEHR.'),
(95284, 2205, 26, 'errore nella registrazione del modulo!'),
(95285, 2206, 26, 'Errore nel salvataggio sul file'),
(95286, 2208, 26, 'Errore nella scrittura del file'),
(95287, 2209, 26, 'Errore(i) rilevato(i) da nuovi risultati'),
(95288, 2210, 26, 'Errore, il file non esiste'),
(95289, 2211, 26, 'ERRORE, impossibile raccogliere i dati dal server'),
(95290, 2212, 26, 'Errore, impossibile creare un certificato del client'),
(95291, 2213, 26, 'Errore, impossibile creare il certificato admin.p12'),
(95292, 2214, 26, 'Errore, impossibile creare il certificato Certificate Authority'),
(95293, 2215, 26, 'Errore, impossibile creare il certificato del Server'),
(95294, 2216, 26, 'Errore, impossibile aprire il file'),
(95295, 2217, 26, 'Errore, l''Autenticazione del certificato utente non è abilitata in LibreEHR'),
(95296, 2218, 26, 'Errore. Devi installare il modulo Archive/Tar.php'),
(95297, 2219, 26, 'ERRORE: non si è potuto aprire table.sql, modulo deteriorato?'),
(95298, 2220, 26, 'Errore: ID duplicato nella linea'),
(95299, 2221, 26, 'Erroe: nome duplicato nella linea'),
(95300, 2222, 26, 'ERRORE: Campo'),
(95301, 2223, 26, 'ERRORE: Modulo PHP ZipArchive mancante'),
(95302, 2224, 26, 'ERRORE: Nessuna directory di importazione ICD'),
(95303, 2225, 26, 'Errore: le password non corrispondono. Controlla il testo inserito.'),
(95304, 2226, 26, 'Errore: le password non corrispondono. Controlla il testo inserito.'),
(95305, 2227, 26, 'Errore: Il file non esiste'),
(95306, 2228, 26, 'ERRORE: La variabile che segue contiene caratteri non validi'),
(95307, 2229, 26, 'ERRORE: Impossibile copiare il file'),
(95308, 2230, 26, 'Errore: Impossibile creare l''archivio scaricabile'),
(95309, 2231, 26, 'ERRORE: Impossibile creare l''archivio ZIP.'),
(95310, 2232, 26, 'ERRORE: Impossibile estrerre il file.'),
(95311, 2233, 26, 'ERRORE: Impossibile caricare il file nel database.'),
(95312, 2234, 26, 'ERRORE: Impossibile assegnare il numero di versione.'),
(95313, 2235, 26, 'Errori'),
(95314, 2236, 26, 'Status dell''account eRx'),
(95315, 2237, 26, 'Log eRx'),
(95316, 2238, 26, 'Nome ERX'),
(95317, 2239, 26, 'Password ERX'),
(95318, 2240, 26, 'Ruolo ERX'),
(95319, 2241, 26, 'Utente ERX'),
(95320, 2242, 26, 'Eritema:'),
(95321, 2243, 26, 'eSign'),
(95322, 2244, 26, 'eSign Log'),
(95323, 2245, 26, 'Eschimese'),
(95324, 2246, 26, 'Esperanto'),
(95325, 2247, 26, 'Paziente stabilizzato'),
(95326, 2248, 26, 'Estone'),
(95327, 2249, 26, 'Etnia'),
(95328, 2250, 26, 'Etnia o Razza'),
(95329, 2251, 26, 'Elenco Etnie-Razze (scrittura, solo aggiunte opzionali)'),
(95330, 2252, 26, 'ETIN'),
(95331, 2253, 26, 'Evento'),
(95332, 2254, 26, 'Inizio Evento'),
(95333, 2255, 26, 'Categoria Evento'),
(95334, 2256, 26, 'Data Evento'),
(95335, 2257, 26, 'Descrizione Evento'),
(95336, 2258, 26, 'Dettagli Evento'),
(95337, 2259, 26, 'L''evento non si ripete'),
(95338, 2260, 26, 'Durata Evento'),
(95339, 2261, 26, 'Durata Evento in minuti'),
(95340, 2262, 26, 'Costo Evento'),
(95341, 2263, 26, 'Luogo Evento'),
(95342, 2264, 26, 'L''Evento si ripete ogni'),
(95343, 2265, 26, 'L''Evento si ripete il'),
(95344, 2266, 26, 'Ora di inizio Evento'),
(95345, 2267, 26, 'Titolo Evento'),
(95346, 2268, 26, 'Titolo Evento'),
(95347, 2269, 26, 'Evento del sito web'),
(95348, 2270, 26, 'Eventi'),
(95349, 2271, 26, 'Eventi per'),
(95350, 2272, 26, 'Eventi aperti in una nuova finestra'),
(95351, 2273, 26, 'ogni'),
(95352, 2274, 26, 'Ogni'),
(95353, 2275, 26, 'ogni 3 ore'),
(95354, 2276, 26, 'ogni 4 ore'),
(95355, 2277, 26, 'ogni 5 ore'),
(95356, 2278, 26, 'ogni 6 ore'),
(95357, 2279, 26, 'ogni 8 ore'),
(95358, 2280, 26, 'Ogni Quarto'),
(95359, 2281, 26, 'Qualsiasi Altro'),
(95360, 2282, 26, 'Ogni Terzo'),
(95361, 2283, 26, 'Ogni, ogni altro, ogni 3.o, ecc.'),
(95362, 2284, 26, 'Pecora'),
(95363, 2285, 26, 'Risultati esame e test'),
(95364, 2286, 26, 'Risultati esame'),
(95365, 2289, 26, 'Effettuazione esame'),
(95366, 2290, 26, 'Data effettuazione esame'),
(95367, 2291, 26, 'Esempio'),
(95368, 2292, 26, 'Esempi'),
(95369, 2293, 26, 'Esami/Test'),
(95370, 2294, 26, 'Eccetto'),
(95371, 2295, 26, 'Pianto eccessivo'),
(95372, 2296, 26, 'Pazienti esclusi'),
(95373, 2297, 26, 'Esclusione'),
(95374, 2298, 26, 'Organizzazione esclusiva fornitore (EPO)'),
(95375, 2299, 26, 'Formato carta esecutivo'),
(95376, 2300, 26, 'Esercizio'),
(95377, 2301, 26, 'Schemi di Esercizio'),
(95378, 2302, 26, 'Schemi di esercizio'),
(95379, 2303, 26, 'Esiste'),
(95380, 2304, 26, 'Esci da Amministrazione'),
(95381, 2305, 26, 'Esp'),
(95382, 2306, 26, 'Espandi'),
(95383, 2307, 26, 'espandi'),
(95384, 2308, 26, 'Espandi Tutto'),
(95385, 2311, 26, 'Vista espansa'),
(95386, 2312, 26, 'Ci si attendeva che form_encounter.pid fosse '),
(95387, 2313, 26, 'Scadenza'),
(95388, 2314, 26, 'Data Scadenza'),
(95389, 2315, 26, 'Scade'),
(95390, 2316, 26, 'scade entro'),
(95391, 2317, 26, 'Esporta'),
(95392, 2318, 26, 'Esporta come CSV'),
(95393, 2319, 26, 'Esporta Configurazione'),
(95394, 2322, 26, 'Esporta Demografica del paziente'),
(95395, 2323, 26, 'Esporta il Resoconto PQRI'),
(95396, 2325, 26, 'Esporta la selezione come CSV'),
(95397, 2326, 26, 'Esporta la selezione alle Collezioni'),
(95398, 2327, 26, 'Esporta a CSV'),
(95399, 2328, 26, 'Esporta al sistema di fatturazione esterno'),
(95400, 2329, 26, 'Esposizione ai Paesi Esteri'),
(95401, 2330, 26, 'Esposizione ai Paesi Esteri'),
(95402, 2331, 26, 'Tenpo stimato per la raccolta'),
(95403, 2332, 26, 'Esterno'),
(95404, 2334, 26, 'Caricamento dati esterni'),
(95405, 2335, 26, 'Utilità di importazione database esterno'),
(95406, 2336, 26, 'ID esterno'),
(95407, 2337, 26, 'Id esterno'),
(95408, 2338, 26, 'Identificatore esterno'),
(95409, 2339, 26, 'Solo esterno'),
(95410, 2342, 26, 'Riferimento esterno'),
(95411, 2343, 26, 'Riferimento di followups esterni'),
(95412, 2344, 26, 'Riferimento esterno?'),
(95413, 2345, 26, 'Riferimenti esterni'),
(95414, 2346, 26, 'Estrai il file zip'),
(95415, 2347, 26, 'Sto estraendo il file. Questo prenderà un po'' di tempo'),
(95416, 2348, 26, 'Essudato:'),
(95417, 2349, 26, 'Irritazione dell''occhio'),
(95418, 2350, 26, 'Dolore all''occhio'),
(95419, 2351, 26, 'Occhio arrossato'),
(95420, 2352, 26, 'Occhi'),
(95421, 2353, 26, 'F'),
(95422, 2354, 26, 'F/H Problemi al sangue'),
(95423, 2355, 26, 'F/H Irsutismo femminile'),
(95424, 2356, 26, 'Sedi'),
(95425, 2357, 26, 'Sede'),
(95426, 2358, 26, 'sede'),
(95427, 2359, 26, 'Amministrazione Sede'),
(95428, 2360, 26, 'Città Sede'),
(95429, 2361, 26, 'Codice Sede'),
(95430, 2362, 26, 'Codice nazione Sede'),
(95431, 2363, 26, 'Fax Sede'),
(95432, 2364, 26, 'Nome Sede'),
(95433, 2365, 26, 'NPI Sede'),
(95434, 2366, 26, 'Telefono Sede'),
(95435, 2367, 26, 'Sede informazioni specifiche dell''utente'),
(95436, 2368, 26, 'Stato Sede'),
(95437, 2369, 26, 'Via Sede'),
(95438, 2370, 26, 'CAP Sede'),
(95439, 2372, 26, 'Sede:'),
(95440, 2373, 26, 'GUASTO'),
(95441, 2374, 26, 'fallito(a)'),
(95442, 2375, 26, 'Fallito(a)'),
(95443, 2376, 26, 'Pazienti falliti'),
(95444, 2377, 26, 'Aggiunta del paziente al portale fallita'),
(95445, 2378, 26, 'Impossibile calcolare un nome di file unico'),
(95446, 2379, 26, 'Creazione fallita'),
(95447, 2380, 26, 'Impossibile creare la cartella temporanea. CouchDB non funzionerà.'),
(95448, 2382, 26, 'Fallito.'),
(95449, 2383, 26, 'fallimento'),
(95450, 2384, 26, 'Fallimento'),
(95451, 2385, 26, 'AVVISO DI GUASTO: Impossibile inviare messaggio diretto.'),
(95452, 2390, 26, 'Storia familiare'),
(95453, 2391, 26, 'Storia familiare del Glaucoma'),
(95454, 2392, 26, 'Storia familiare:'),
(95455, 2394, 26, 'Pagamento della famiglia'),
(95456, 2395, 26, 'Grandezza famiglia'),
(95457, 2396, 26, 'Immaginazione'),
(95458, 2397, 26, 'Faroese'),
(95459, 2398, 26, 'Persiano'),
(95460, 2400, 26, 'Padre'),
(95461, 2401, 26, 'Storia del padre'),
(95462, 2402, 26, 'Affaticamento'),
(95463, 2403, 26, 'Affaticato'),
(95464, 2404, 26, 'Fax'),
(95465, 2405, 26, 'Conteggio fax'),
(95466, 2406, 26, 'Numero fax'),
(95467, 2408, 26, 'Fax/Scan'),
(95468, 2409, 26, 'Fax in ingresso'),
(95469, 2410, 26, 'Fax in uscita'),
(95470, 2411, 26, 'Cartteristiche'),
(95471, 2412, 26, 'Feb'),
(95472, 2413, 26, 'Febbraio'),
(95473, 2414, 26, 'FECA'),
(95474, 2415, 26, 'Federal Drug ID'),
(95475, 2416, 26, 'Federal EIN'),
(95476, 2417, 26, 'Federal Tax ID'),
(95477, 2418, 26, 'Parcella'),
(95478, 2419, 26, 'parcella'),
(95479, 2420, 26, 'La parcella non è consentita'),
(95480, 2421, 26, 'Foglio Parcelle'),
(95481, 2422, 26, 'Opzioni folgio parcelle'),
(95482, 2423, 26, 'Parcelle'),
(95483, 2424, 26, 'Femminile'),
(95484, 2425, 26, 'Femminile AP'),
(95485, 2426, 26, 'Preservativi femminili'),
(95486, 2427, 26, 'Femminile G'),
(95487, 2428, 26, 'Femminile LC'),
(95488, 2429, 26, 'Femminile P'),
(95489, 2430, 26, 'Sintomi femminili'),
(95490, 2431, 26, 'Femminile VSC'),
(95491, 2432, 26, 'Recupero'),
(95492, 2433, 26, 'Recupero seguente file dal portale'),
(95493, 2434, 26, 'Febbre'),
(95494, 2435, 26, 'Febbre:'),
(95495, 2436, 26, 'Problemi al sangue'),
(95496, 2437, 26, 'Fibromi'),
(95497, 2438, 26, 'Campo'),
(95498, 2439, 26, 'Il "nome" del campo non può essere NULL'),
(95499, 2441, 26, 'Tipo di campo da usare per la nazione datore di lavoro o sottoscrittore nella demografica.'),
(95500, 2442, 26, 'Tipo di campo da usare per lo stato del datore di lavoro o sottoscrittore nella demografica.'),
(95501, 2443, 26, 'Campo(i) mancante(i)!'),
(95502, 2446, 26, 'Fijian'),
(95503, 2447, 26, 'File'),
(95504, 2448, 26, 'file nella directory Documentation per apprendere come automatizzare il processo di creazione del log dei backup'),
(95505, 2449, 26, 'collocazione del file'),
(95506, 2450, 26, 'Gestione del file'),
(95507, 2453, 26, 'Privilegio del file garantito all''utente LibreEHR.'),
(95508, 2454, 26, 'Recupero file da CouchDB non riuscito'),
(95509, 2455, 26, 'Spazio file'),
(95510, 2456, 26, 'File da caricare'),
(95511, 2457, 26, 'File da Caricare'),
(95512, 2458, 26, 'Un file con lo stesso nome esiste già in:'),
(95513, 2459, 26, 'Nome file'),
(95514, 2460, 26, 'Il nome del file deve finire con ".pdf"'),
(95515, 2461, 26, 'File'),
(95516, 2462, 26, 'Filippino'),
(95517, 2463, 26, 'Compila qualcuna delle righe successive.'),
(95518, 2464, 26, 'Compila questo solo se stai inviando una notifica email ai pazienti'),
(95519, 2465, 26, 'Compila i valori successivi'),
(95520, 2467, 26, 'Compila la riga'),
(95521, 2468, 26, 'Filtro'),
(95522, 2469, 26, 'Filtro per Costanti'),
(95523, 2470, 26, 'Filtro per Definizioni'),
(95524, 2471, 26, 'filtrato da'),
(95525, 2472, 26, 'filtri'),
(95526, 2473, 26, 'Filtri'),
(95527, 2474, 26, 'Finale'),
(95528, 2475, 26, 'Diagnosi finale'),
(95529, 2476, 26, 'Diagnosi finale dello specialista'),
(95530, 2478, 26, 'Bilancio'),
(95531, 2479, 26, 'Data chiusura bilancio (aaaa-mm-gg)'),
(95532, 2480, 26, 'Resoconto Bilancio - tutto'),
(95533, 2481, 26, 'Resoconto Bilancio - miei incontri'),
(95534, 2482, 26, 'Data revisione Bilancio'),
(95535, 2483, 26, 'Riepilogo finanziario Codice di servizio'),
(95536, 2484, 26, 'Trova'),
(95537, 2485, 26, 'Trova disponibile'),
(95538, 2486, 26, 'Trova appuntamenti disponibili'),
(95539, 2487, 26, 'Trova Paziente'),
(95540, 2488, 26, 'Trova materiale per l''istruzione del paziente'),
(95541, 2489, 26, 'Sto cercando'),
(95542, 2490, 26, 'Sto cercando per specialista'),
(95543, 2491, 26, 'Bene'),
(95544, 2492, 26, 'Concludi pagamenti'),
(95545, 2493, 26, 'finito'),
(95546, 2494, 26, 'Finnish'),
(95547, 2495, 26, 'Primo'),
(95548, 2497, 26, 'Primo giorno della settimana'),
(95549, 2498, 26, 'Nome'),
(95550, 2499, 26, 'Nome'),
(95551, 2500, 26, 'Nome:'),
(95552, 2501, 26, 'Prima visita o consulto'),
(95553, 2502, 26, 'Nome Cognome'),
(95554, 2503, 26, 'Fitness'),
(95555, 2504, 26, 'livello forma fisica'),
(95556, 2505, 26, 'Livello di forma fisica, per questo giocatore in questo giorno'),
(95557, 2506, 26, 'Test forma fisica'),
(95558, 2507, 26, 'Idoneità a giocare'),
(95559, 2508, 26, 'Correggere le date incontri - qualsiasi incontro'),
(95560, 2509, 26, 'Correggere questo'),
(95561, 2510, 26, 'FL'),
(95562, 2511, 26, 'Flatulenza'),
(95563, 2512, 26, 'Flusso'),
(95564, 2514, 26, 'Influenza stagionale'),
(95565, 2515, 26, 'Influenza Stagionale'),
(95566, 2516, 26, 'Vaccinazione antiinfluenzale'),
(95567, 2517, 26, 'Problema di fluido e elettrolita'),
(95568, 2518, 26, 'FMS'),
(95569, 2519, 26, 'Formato carta'),
(95570, 2520, 26, 'Segui manualmente'),
(95571, 2521, 26, 'Seguire queste istruzioni per l''installazione o l''aggiornamento del database seguente'),
(95572, 2522, 26, 'Follow Up'),
(95573, 2524, 26, 'Motivo del Follow Up'),
(95574, 2525, 26, 'La seguente è una nuova costante custom:'),
(95575, 2526, 26, 'La seguente è una nuova lingua custom:'),
(95576, 2527, 26, 'La seguente è una nuova definizione (Lingua, Costante, Definizione):'),
(95577, 2528, 26, 'In seguito righe del registro di controllo che sono state manomesse'),
(95578, 2529, 26, 'Prestazioni di Follow Up'),
(95579, 2530, 26, 'Fallowup specificati'),
(95580, 2531, 26, 'Intolleranza al cibo'),
(95581, 2532, 26, 'Piede'),
(95582, 2533, 26, 'Problemi al piede'),
(95583, 2534, 26, 'Piede:'),
(95584, 2535, 26, 'Lesioni da Football (amer.)'),
(95585, 2536, 26, 'Lesione da Football'),
(95586, 2537, 26, 'Resoconto Lesioni da Football (amer.)'),
(95587, 2538, 26, 'Tipo di calzatura'),
(95588, 2539, 26, 'per'),
(95589, 2540, 26, 'Per'),
(95590, 2541, 26, 'Per codice'),
(95591, 2543, 26, 'Per indicazioni sugli incontri'),
(95592, 2544, 26, 'Per esempio:'),
(95593, 2545, 26, 'For HCFA 02/12 Box 15 is Other Date with a qualifier to specify what the date indicates'),
(95594, 2546, 26, 'For HCFA 02/12 Onset date specified on the Encounter Form needs a qualifier'),
(95595, 2547, 26, 'per fattura'),
(95596, 2548, 26, 'Solo per Medicare, costringe il fornitore di riferimento per essere lo stesso come fornitore di rappresentazione.'),
(95597, 2549, 26, 'per OBR metti numero di ordine'),
(95598, 2550, 26, 'per paziente'),
(95599, 2552, 26, 'Per organismo di cui / Specialista'),
(95600, 2553, 26, 'Per il passato'),
(95601, 2554, 26, 'per variabile'),
(95602, 2555, 26, 'per:'),
(95603, 2556, 26, 'Forza l''apertura del widget fatturazione'),
(95604, 2557, 26, 'Forza la creazione di un nuovo paziente'),
(95605, 2558, 26, 'Forza visualizzazione'),
(95606, 2559, 26, 'Avambraccio'),
(95607, 2560, 26, 'Modulo'),
(95608, 2561, 26, 'modulo'),
(95609, 2562, 26, 'Modulo elementi non trovati'),
(95610, 2563, 26, 'Modulo firmato con successo'),
(95611, 2564, 26, 'Formato'),
(95612, 2565, 26, 'formato'),
(95613, 2566, 26, 'Formato per visualizzare età'),
(95614, 2567, 26, 'Formato scorretto per NDC'),
(95615, 2568, 26, 'Formato usato per mostrare la maggior parte delle date.'),
(95616, 2569, 26, 'Formato usato per mostrare la maggior parte delle volte.'),
(95617, 2570, 26, 'Resoconto formattato'),
(95618, 2571, 26, 'Ex fumatore'),
(95619, 2572, 26, 'Moduli'),
(95620, 2573, 26, 'Amministrazione Moduli'),
(95621, 2575, 26, 'Inoltrare'),
(95622, 2576, 26, 'Pagine inoltrate via Fax'),
(95623, 2577, 26, 'Inoltrato'),
(95624, 2579, 26, 'Quarto'),
(95625, 2581, 26, 'Frattura'),
(95626, 2582, 26, 'Frattura alla navicula'),
(95627, 2583, 26, 'Frattura malleolo laterale'),
(95628, 2584, 26, 'Frattura malleolo mediale'),
(95629, 2585, 26, 'Frattura, base del quinto metatarsale'),
(95630, 2586, 26, 'Supporto struttura necessario'),
(95631, 2587, 26, 'Francese'),
(95632, 2588, 26, 'Francese (Canadese)'),
(95633, 2589, 26, 'Francese (Standard)'),
(95634, 2590, 26, 'Frequenza'),
(95635, 2591, 26, 'Raffreddori frequenti'),
(95636, 2592, 26, 'Infermità frequenti'),
(95637, 2593, 26, 'Ven'),
(95638, 2594, 26, 'Venerdì'),
(95639, 2595, 26, 'Da'),
(95640, 2596, 26, 'DA'),
(95641, 2597, 26, 'da'),
(95642, 2598, 26, 'La data iniziale non può essere successiva alla data finale'),
(95643, 2599, 26, 'Da:'),
(95644, 2600, 26, 'Da: '),
(95645, 2601, 26, 'FROM_CITY'),
(95646, 2602, 26, 'FROM_EMAIL'),
(95647, 2603, 26, 'FROM_FNAME'),
(95648, 2604, 26, 'FROM_LNAME'),
(95649, 2605, 26, 'FROM_MNAME'),
(95650, 2606, 26, 'FROM_PHONE'),
(95651, 2607, 26, 'FROM_PHONECELL'),
(95652, 2608, 26, 'FROM_POSTAL'),
(95653, 2609, 26, 'FROM_STATE'),
(95654, 2610, 26, 'FROM_STREET'),
(95655, 2611, 26, 'FROM_TITLE'),
(95656, 2612, 26, 'FROM_VALEDICTORY'),
(95657, 2613, 26, 'Sportello'),
(95658, 2614, 26, 'Ricevute da Sportello'),
(95659, 2615, 26, 'Resoconto ricevute da sportello'),
(95660, 2616, 26, 'Ricevimento anteriore'),
(95661, 2617, 26, 'Frontale destro:'),
(95662, 2618, 26, 'Fula- Fulah- Pulaar- Pular'),
(95663, 2619, 26, 'Nome completo'),
(95664, 2620, 26, 'Percorso completo alla directory contenente l''eseguibile MySQL'),
(95665, 2621, 26, 'Percorso completo alla directory contenente l''eseguibile Perl'),
(95666, 2622, 26, 'Percorso completo alla directory del log dell''evento backup'),
(95667, 2623, 26, 'Percorso completo alla directory usata per i file temporanei'),
(95668, 2624, 26, 'Full Play'),
(95669, 2625, 26, 'Addestramento completo'),
(95670, 2626, 26, 'Pagamento completato'),
(95671, 2631, 26, 'Futuro'),
(95672, 2633, 26, 'G'),
(95673, 2634, 26, 'G/DL'),
(95674, 2635, 26, 'Galician'),
(95675, 2636, 26, 'Condizione cistifellea'),
(95676, 2637, 26, 'Calcoli biliari'),
(95677, 2638, 26, 'Periodo partita'),
(95678, 2639, 26, 'Partite'),
(95679, 2640, 26, 'Partite mancanti'),
(95680, 2641, 26, 'partite/eventi'),
(95681, 2642, 26, 'Partite/Eventi mancanti'),
(95682, 2643, 26, 'Ganda'),
(95683, 2644, 26, 'Gastrite'),
(95684, 2645, 26, 'Dolore gastrico'),
(95685, 2646, 26, 'Gastrointestinale'),
(95686, 2647, 26, 'Resoconto statistiche GCAC'),
(95687, 2648, 26, 'Stat GCAC'),
(95688, 2649, 26, 'Modulo visita GCAC mancante'),
(95689, 2650, 26, 'Genere'),
(95690, 2651, 26, 'Genere '),
(95691, 2652, 26, 'Generale'),
(95692, 2653, 26, 'Elenco generale edizione'),
(95693, 2655, 26, 'Categoria Servizio generale'),
(95694, 2656, 26, 'Genera'),
(95695, 2657, 26, 'Genera e scarica CMS 1500 sinistri cartacei'),
(95696, 2658, 26, 'Genera e scarica HCFA 1500 sinistri cartacei'),
(95697, 2659, 26, 'Genera e scarica'),
(95698, 2660, 26, 'Genera e scarica X12 sinistri degli incontri batch'),
(95699, 2663, 26, 'Genera e trasmetti elettronicamente le prescrizioni permesse.'),
(95700, 2664, 26, 'Genera CMS 1500'),
(95701, 2665, 26, 'Genera CMS 1500 in formato PDF'),
(95702, 2666, 26, 'Geenra CMS 15000 in formato TEXT'),
(95703, 2667, 26, 'Genera HCFA'),
(95704, 2668, 26, 'Genera fattura'),
(95705, 2669, 26, 'Genera lettera'),
(95706, 2670, 26, 'Geenra lettera concernente '),
(95707, 2671, 26, 'Genera resoconto PQRI (Metodo A)'),
(95708, 2672, 26, 'Genera resoconto PQRI (Metodo A) - 2011'),
(95709, 2673, 26, 'Genera resoconto PQRI (Metodo E)'),
(95710, 2674, 26, 'Genera resoconto PQRI (Metodo E) - 2011'),
(95711, 2677, 26, 'Genera resoconto'),
(95712, 2678, 26, 'Genera nome utente e password per'),
(95713, 2679, 26, 'Genera X12'),
(95714, 2680, 26, 'Genera incontro X12'),
(95715, 2682, 26, 'Generato il'),
(95716, 2683, 26, 'Genera'),
(95717, 2684, 26, 'Genitourinario'),
(95718, 2686, 26, 'Georgian'),
(95719, 2687, 26, 'Tedesco'),
(95720, 2691, 26, 'Preleva HL7'),
(95721, 2692, 26, 'Glaucoma'),
(95722, 2693, 26, 'Storico familiare Glaucoma'),
(95723, 2694, 26, 'Globale'),
(95724, 2696, 26, 'ID globale'),
(95725, 2697, 26, 'Parametri globali'),
(95726, 2698, 26, 'Globali'),
(95727, 2699, 26, 'MG/DL'),
(95728, 2700, 26, 'vai'),
(95729, 2701, 26, 'Vai'),
(95730, 2704, 26, 'Vai a'),
(95731, 2705, 26, 'Vai alla settimana del'),
(95732, 2706, 26, 'Vai a Oggi'),
(95733, 2707, 26, 'Obiettivo A'),
(95734, 2708, 26, 'Obiettivi e metodi'),
(95735, 2709, 26, 'Obiettivo B'),
(95736, 2710, 26, 'Obiettivo C'),
(95737, 2711, 26, 'Grado della lesione'),
(95738, 2712, 26, 'Grado:'),
(95739, 2713, 26, 'grammi'),
(95740, 2714, 26, 'Gran Totale'),
(95741, 2715, 26, 'Grandi Totali'),
(95742, 2718, 26, 'Visualizzabile graficamente'),
(95743, 2720, 26, 'maggiore di'),
(95744, 2721, 26, 'maggiore o uguale a'),
(95745, 2722, 26, 'Greco'),
(95746, 2723, 26, 'Greco, moderno'),
(95747, 2724, 26, 'Gruppo'),
(95748, 2725, 26, 'Nome del Gruppo'),
(95749, 2726, 26, 'I nomi dei gruppi non possono essere in bianco'),
(95750, 2727, 26, 'I nomi dei gruppi non possono cominciare con numeri o spazi.'),
(95751, 2728, 26, 'I nomi dei gruppi non possono cominciare con numeri.'),
(95752, 2729, 26, 'Numero del gruppo'),
(95753, 2730, 26, 'Pagamento del Gruppo'),
(95754, 2731, 26, 'Gruppo:'),
(95755, 2732, 26, 'Nomegruppo'),
(95756, 2733, 26, 'Gruppi e controlli di accesso'),
(95757, 2734, 26, 'Tabulato della crescita'),
(95758, 2735, 26, 'Tabulato-Crescita'),
(95759, 2736, 26, 'gocce'),
(95760, 2737, 26, 'Guamanian'),
(95761, 2738, 26, 'Guaraní'),
(95762, 2739, 26, 'Nome del tutore'),
(95763, 2740, 26, 'Gujarati'),
(95764, 2741, 26, 'Esame ginecologico'),
(95765, 2742, 26, 'h'),
(95766, 2743, 26, 'h.s.(hora somni)'),
(95767, 2744, 26, 'H/O Epatiti'),
(95768, 2745, 26, 'è stato eliminata con successo. Qualsiasi categoria se presente è stata spostata sotto'),
(95769, 2746, 26, 'Ematoma / contusione'),
(95770, 2747, 26, 'Stato HAI(Hospital-acquired infection)'),
(95771, 2748, 26, 'Haitian- Haitian Creole'),
(95772, 2750, 26, 'Mano + dita'),
(95773, 2751, 26, 'Problemi alla mano'),
(95774, 2752, 26, 'Hard Disk'),
(95775, 2753, 26, 'Con/senza difficoltà'),
(95776, 2754, 26, 'è stato collegato alla visita'),
(95777, 2755, 26, 'è scaduto'),
(95778, 2756, 26, 'Hash'),
(95779, 2757, 26, 'L''hash di questo file non esisteva. E'' stato genenrato un nuovo hash.'),
(95780, 2758, 26, 'L''hash non corrisponde. L''integrità dei dati è stata compromessa.'),
(95781, 2759, 26, 'Hausa'),
(95782, 2760, 26, 'Hawaiano'),
(95783, 2761, 26, 'Attività Rischiose'),
(95784, 2762, 26, 'Attività rischiose'),
(95785, 2763, 26, 'margine sinistro in punti dell''HCFA'),
(95786, 2764, 26, 'Margini dell''HCFA'),
(95787, 2765, 26, 'margine superiore in punti dell''HCFA'),
(95788, 2766, 26, 'HCPCS procedura/Servizio'),
(95789, 2767, 26, 'lui PostCalendar '),
(95790, 2768, 26, 'Testa'),
(95791, 2769, 26, 'Circ Testa'),
(95792, 2770, 26, 'Circonferenza della testa'),
(95793, 2771, 26, 'Mal di testa'),
(95794, 2772, 26, 'Mal di testa'),
(95795, 2773, 26, 'operazioni di assistenza sanitaria'),
(95796, 2774, 26, 'operazioni di assistenza sanitaria'),
(95797, 2775, 26, 'Centro medico / Clinica'),
(95798, 2776, 26, 'Organizzazione per il mantenimento della salute'),
(95799, 2777, 26, 'Organizzazione per il mantenimento della salute'),
(95800, 2778, 26, 'Perdita dell''udito'),
(95801, 2779, 26, 'Attacco cardiaco'),
(95802, 2780, 26, 'Malattia cardiaca'),
(95803, 2781, 26, 'Scompenso cardiaco'),
(95804, 2782, 26, 'Problema cardiaco'),
(95805, 2783, 26, 'Problemi cardiaci'),
(95806, 2784, 26, 'Chirurgia cardiaca'),
(95807, 2785, 26, 'Trapianto cardiaco'),
(95808, 2786, 26, 'CUORE:'),
(95809, 2787, 26, 'Pirosi'),
(95810, 2788, 26, 'Caldo o Freddo'),
(95811, 2789, 26, 'Caldo O Freddo'),
(95812, 2790, 26, 'Fumatore di tabacco pesante'),
(95813, 2791, 26, 'Ebraico'),
(95814, 2792, 26, 'Ebraico (moderno)'),
(95815, 2793, 26, 'HEENT'),
(95816, 2794, 26, 'Altezza'),
(95817, 2795, 26, 'Altezza/Lunghezza'),
(95818, 2796, 26, 'Aiuto'),
(95819, 2797, 26, 'aiuto'),
(95820, 2798, 26, 'Ematemesi'),
(95821, 2799, 26, 'Ematochezia'),
(95822, 2800, 26, 'Ematologico'),
(95823, 2801, 26, 'Ematuria'),
(95824, 2802, 26, 'Emoglobina'),
(95825, 2803, 26, 'Emoglobina A1C'),
(95826, 2804, 26, 'Emottisi'),
(95827, 2805, 26, 'Epatite'),
(95828, 2806, 26, 'Epatite A 1'),
(95829, 2807, 26, 'Epatite A 2'),
(95830, 2808, 26, 'Epatite B 1'),
(95831, 2809, 26, 'Epatite B 2'),
(95832, 2810, 26, 'Epatite B 3'),
(95833, 2811, 26, 'qui'),
(95834, 2812, 26, 'Herero'),
(95835, 2813, 26, 'Riparazione ernia'),
(95836, 2814, 26, 'Disco erniatico'),
(95837, 2815, 26, 'Herpes'),
(95838, 2816, 26, 'Titubanza'),
(95839, 2817, 26, 'Ehi tu. sei stato qui per '),
(95840, 2818, 26, 'Hib 1'),
(95841, 2819, 26, 'Hib 2'),
(95842, 2820, 26, 'Hib 3'),
(95843, 2821, 26, 'Hib 4'),
(95844, 2822, 26, 'Nascosto'),
(95845, 2823, 26, 'Amministrazione eventi nascosti'),
(95846, 2824, 26, 'Nascondi'),
(95847, 2825, 26, 'Nascondi dettagli'),
(95848, 2826, 26, 'Nascondi E-Sign vuoti nel log del Report'),
(95849, 2827, 26, 'Nascondi le opzioni di cifratura/decifratura nella gestione documento'),
(95850, 2828, 26, 'Nascondi menu'),
(95851, 2830, 26, 'Nascondi promemoria'),
(95852, 2831, 26, 'Nascondi/Scopri Colonne'),
(95853, 2833, 26, 'Alto'),
(95854, 2834, 26, 'Pressione sanguigna alta'),
(95855, 2835, 26, 'Indi'),
(95856, 2836, 26, 'Anca + inguine'),
(95857, 2837, 26, 'Anca e inguine'),
(95858, 2838, 26, 'Problemi all''anca'),
(95859, 2839, 26, 'Protesi d''anca'),
(95860, 2840, 26, 'HIPAA notifica ricevuta'),
(95861, 2841, 26, 'Hiri Motu'),
(95862, 2842, 26, 'Irsutismo/Smagliature'),
(95863, 2843, 26, 'Ispanico'),
(95864, 2844, 26, 'Ispanico - Altri (nati in US)'),
(95865, 2845, 26, 'Ispanico - Altri (nati fuori US)'),
(95866, 2846, 26, 'Ispanico o Latino'),
(95867, 2847, 26, 'Storico'),
(95868, 2848, 26, 'Data storico'),
(95869, 2849, 26, 'Dati storici'),
(95870, 2851, 26, 'Storico Murmure'),
(95871, 2852, 26, 'Storico non autorizzato'),
(95872, 2853, 26, 'Storico soffio al cuore'),
(95873, 2854, 26, 'Accessi'),
(95874, 2855, 26, 'HIV'),
(95875, 2858, 26, 'HL7 visualizzatore'),
(95876, 2860, 26, 'HMOL/L'),
(95877, 2861, 26, 'Hmong'),
(95878, 2862, 26, 'Tieni premuto [Ctrl] per selezione o deselezione multipla'),
(95879, 2863, 26, 'Tieni premuto Ctrl per selezionare elementi multipli'),
(95880, 2864, 26, 'Tieni premuto Ctrl per selezione squadre multiple'),
(95881, 2865, 26, 'Home'),
(95882, 2866, 26, 'Telefono abitazione'),
(95883, 2867, 26, 'Numero telefono abitazione'),
(95884, 2868, 26, 'Senza tetto o simili?'),
(95885, 2869, 26, 'Senza tetto, etc'),
(95886, 2870, 26, 'Senza tetto, etc'),
(95887, 2871, 26, 'Hooks(Ganci)'),
(95888, 2872, 26, 'Nome dell''Host'),
(95889, 2873, 26, 'Il nome dell''Host non può essere vuoto'),
(95890, 2875, 26, 'Ora'),
(95891, 2876, 26, 'Ore'),
(95892, 2878, 26, 'Quando è avvenuta la lesione?'),
(95893, 2879, 26, 'Quando è avvenuta la lesione?:'),
(95894, 2880, 26, 'Quando hanno sentito parlare di noi'),
(95895, 2881, 26, 'Per quanti mesi richiedi gli eventi futuri?'),
(95896, 2882, 26, 'HPI(High Pressure Injection):'),
(95897, 2883, 26, 'HT'),
(95898, 2884, 26, 'HTML'),
(95899, 2885, 26, 'HTML Output?'),
(95900, 2886, 26, 'Collegamento https al supporto LibreEHR per il servizio scambio Lab LLC.'),
(95901, 2887, 26, 'Ungherese'),
(95902, 2888, 26, 'Directory Hylafax'),
(95903, 2889, 26, 'Comando enscript Hylafax'),
(95904, 2890, 26, 'Server Hylafax'),
(95905, 2891, 26, 'Hostname del server Hylafax'),
(95906, 2892, 26, 'Iperattivo'),
(95907, 2893, 26, 'Ipertensione'),
(95908, 2894, 26, 'Ipertensione: Misura della pressione sanguigna'),
(95909, 2895, 26, 'Ipertensione: Misura della pressione sanguigna (CQM)'),
(95910, 2896, 26, 'Ipertiroidismo'),
(95911, 2897, 26, 'Ipertiroidismo'),
(95912, 2898, 26, 'Isterectomia'),
(95913, 2899, 26, 'Io'),
(95914, 2900, 26, 'Sono occupato in questo periodo.'),
(95915, 2901, 26, 'Non ho il permesso di leggere '),
(95916, 2902, 26, 'ICD'),
(95917, 2903, 26, 'ICD10 diagnosi'),
(95918, 2904, 26, 'ICD10 Procedure/Servizi'),
(95919, 2905, 26, 'ICD9'),
(95920, 2906, 26, 'ICD9 diagnosi'),
(95921, 2907, 26, 'ICD9 Procedure/Servizi'),
(95922, 2908, 26, 'Icelandic'),
(95923, 2909, 26, 'ID'),
(95924, 2910, 26, 'Id'),
(95925, 2911, 26, 'ID non può essere in bianco'),
(95926, 2912, 26, 'ID Carta'),
(95927, 2913, 26, 'IDays'),
(95928, 2914, 26, 'identificato come'),
(95929, 2915, 26, 'identificatore(una parola)'),
(95930, 2916, 26, 'Codice identificativo'),
(95931, 2917, 26, 'Tempo di attesa in secondi per il timeout della sessione'),
(95932, 2918, 26, 'Ido'),
(95933, 2919, 26, 'se tutti i dati per tutte le colonne sono completi per questo modulo'),
(95934, 2920, 26, 'Se si sta usando la motivazione della fatturazione inserisci il tipo di codice diagnostico.'),
(95935, 2921, 26, 'se inserito, seleziona solo quelli che avevano avuto questa prestazione'),
(95936, 2922, 26, 'se è un nome, qualsiasi parte del cognome o del cognome,nome'),
(95937, 2923, 26, 'se pagato da'),
(95938, 2924, 26, 'se la persona è deceduta, allora inserisci la data di morte.'),
(95939, 2925, 26, 'se si utilizza SMTP, il nome dell''host o l''indirizzo IP'),
(95940, 2926, 26, 'se si utilizza SMTP, il numero della porta TCP (tipicamente 25).'),
(95941, 2927, 26, 'se disoccupato inserisci Studente'),
(95942, 2928, 26, 'Se AMG è selezionata per la visualizzazione età, passare a solo anni quando i pazienti di età superiore a questo valore in anni'),
(95943, 2929, 26, 'Se si cambia indirizzo per ruolo e-RX sulle ricette mediche elettroniche, può influenzare il flusso di lavoro sulle ricette mediche elettroniche. Se dovete affrontare qualsiasi difficoltà, contattare il fornitore sulle ricette mediche elettroniche.'),
(95944, 2931, 26, 'Se si è scelto di caricare rimesse elettroniche, quindi la finestra di ricerca si è visualizza di nuovo con le fatture corrispondenti dal file X12. È possibile fare clic su uno di questi numeri di fattura (come descritto di seguito), se si desidera effettuare qualche correzione prima che le informazioni rimessa viene applicato. Per applicare le modifiche, fare clic sul pulsante ERA Elabora il file in fondo alla pagina. Questo produrrà una nuova finestra con una relazione dettagliata.'),
(95945, 2932, 26, 'Se è stata inserita una data di pagamento nella pagina di ricerca, questa verrà annullata dalla data di registrazione dei pagamenti e delle rettifiche che sono altrimenti presi dal file di X12. Questo può essere utile per la creazione di report, se si desidera che le ricevute di notifica utilizzino la data di registrazione, piuttosto che lae compagniae di assicurazione. Si noti che questo influenzerà anche le date dei pagamenti precedenti e le regolazioni che vengono messe in rivendicazioni secondarie.'),
(95946, 2933, 26, 'se vuoi cambiare i tipi di dati, o aggiungere righe e colonne'),
(95947, 2934, 26, 'se vuoi aggiornare il database, allora colloca il file zip del database nella seguente directory'),
(95948, 2935, 26, 'Igbo'),
(95949, 2936, 26, 'Ignora'),
(95950, 2937, 26, 'Malattia(e)'),
(95951, 2938, 26, 'IM'),
(95952, 2941, 26, 'Servizio di Imaging'),
(95953, 2942, 26, 'Immunizzazione'),
(95954, 2943, 26, 'Codice Immunizzazione'),
(95955, 2945, 26, 'Data Immunizzazione'),
(95956, 2946, 26, 'Immunizzazione Data di scadenza'),
(95957, 2947, 26, 'Numero del Lotto Immunizzazione'),
(95958, 2948, 26, 'Produttore Immunizzazione'),
(95959, 2949, 26, 'Registro Immunizzazioni'),
(95960, 2950, 26, 'Report Immunizzazioni'),
(95961, 2951, 26, 'Prestazione di Immunizzazione'),
(95962, 2952, 26, 'Titolo Immunizzazione'),
(95963, 2953, 26, 'Immunizzazioni'),
(95964, 2954, 26, 'Immunizza'),
(95965, 2955, 26, 'Immunologico'),
(95966, 2956, 26, 'Impianti'),
(95967, 2957, 26, 'Importa'),
(95968, 2961, 26, 'Importa il certificato nel browser'),
(95969, 2962, 26, 'Importa Configurazione'),
(95970, 2963, 26, 'Importazione differita di time-to-live'),
(95971, 2964, 26, 'Importa Paziente'),
(95972, 2965, 26, 'Importa Demografica Paziente'),
(95973, 2966, 26, 'Codici importanti'),
(95974, 2967, 26, 'IMPORTANTE: Questo strumento di upload è solo per il caricamento di documenti su pazienti che non sono ancora entrati nel sistema. Per caricare i file per i pazienti che già sono stati inseriti nel sistema, si prega di utilizzare lo strumento di caricamento legata all''interno della schermata di Sommario Paziente.'),
(95975, 2969, 26, 'Importato dalla Contabilità'),
(95976, 2972, 26, 'Migliorato'),
(95977, 2973, 26, 'dentro'),
(95978, 2974, 26, 'DENTRO'),
(95979, 2975, 26, 'in cascun occhio'),
(95980, 2976, 26, 'nell''occhio sinistro'),
(95981, 2977, 26, 'nella narice'),
(95982, 2978, 26, 'In Studio'),
(95983, 2979, 26, 'nell''occhio destro'),
(95984, 2980, 26, 'dentro casa'),
(95985, 2981, 26, 'Inattivo'),
(95986, 2982, 26, 'Giorni inattivi'),
(95987, 2983, 26, 'Inbox'),
(95988, 2986, 26, 'Includi somma di controllo'),
(95989, 2987, 26, 'Includi Completati'),
(95990, 2988, 26, 'Inculdi Utenti inattivi'),
(95991, 2989, 26, 'Includi non categorizzati'),
(95992, 2990, 26, 'Includi Dati non strutturati'),
(95993, 2991, 26, 'Includi Vitali'),
(95994, 2992, 26, 'Includi i dati Vitali?'),
(95995, 2993, 26, 'Inclusione'),
(95996, 2994, 26, 'Entrata'),
(95997, 2995, 26, 'Risultati in arrivo che richiedono attenzione:'),
(95998, 2996, 26, 'Incompleto'),
(95999, 2997, 26, 'Trattamento aborto incompleto'),
(96000, 2998, 26, 'Incontinenza'),
(96001, 2999, 26, 'Incorporare i risultati del test clinico di laboratorio nel certificato EHR come dati strutturati.'),
(96002, 3000, 26, 'Password errata!'),
(96003, 3001, 26, 'aumentato:'),
(96004, 3002, 26, 'Copertura assicurativa'),
(96005, 3003, 26, 'Indeterminato'),
(96006, 3004, 26, 'Indiano'),
(96007, 3005, 26, 'Indica anormalità'),
(96008, 3006, 26, 'Indica se questa tematica è attualmente attiva'),
(96009, 3008, 26, 'Indicatore di uso specializzato'),
(96010, 3009, 26, 'Pazienti indigenti'),
(96011, 3010, 26, 'Resoconto pazienti indigenti'),
(96012, 3011, 26, 'Indigenti'),
(96013, 3013, 26, 'Indonesian'),
(96014, 3014, 26, 'Aborto indotto'),
(96015, 3016, 26, 'non ammissibile'),
(96016, 3017, 26, 'Infezione/Ascesso'),
(96017, 3018, 26, 'Infezioni'),
(96018, 3019, 26, 'Cons. Infert.'),
(96019, 3020, 26, 'Infertilità'),
(96020, 3021, 26, 'Influenza 1'),
(96021, 3022, 26, 'Influenza 2'),
(96022, 3023, 26, 'Immunizzazione Influenza per pazienti di età >= 50 anni'),
(96023, 3024, 26, 'Immunizzazione Influenza per pazienti di età >= 50 anni (CQM)'),
(96024, 3025, 26, 'Vaccino influenzale'),
(96025, 3026, 26, 'Info'),
(96026, 3027, 26, 'Info test 1'),
(96027, 3028, 26, 'Info test 2'),
(96028, 3029, 26, 'Info test 3'),
(96029, 3030, 26, 'Info test 4'),
(96030, 3031, 26, 'Info test 5'),
(96031, 3032, 26, 'Info test 6'),
(96032, 3034, 26, 'inalazioni'),
(96033, 3035, 26, 'inalazioni'),
(96034, 3036, 26, 'Trattamento iniziale'),
(96035, 3037, 26, 'Utente Iniziale'),
(96036, 3038, 26, 'Les/Riab'),
(96037, 3039, 26, 'Iniettabile'),
(96038, 3040, 26, 'Iniezione'),
(96039, 3041, 26, 'Parte del corpo lesa'),
(96040, 3042, 26, 'Lesione esterna'),
(96041, 3043, 26, 'Lesione'),
(96042, 3044, 26, 'Meccanismo di lesione'),
(96043, 3045, 26, 'Resoconto rassegna lesioni'),
(96044, 3046, 26, 'Sorveglianza lesione'),
(96045, 3047, 26, 'Tipo lesione'),
(96046, 3048, 26, 'Correlato alla lesione/malattia'),
(96047, 3049, 26, 'In linea'),
(96048, 3050, 26, 'Input non inizia con un segmento MSH'),
(96049, 3051, 26, 'Campi di input'),
(96050, 3052, 26, 'INR'),
(96051, 3053, 26, 'Ins 1'),
(96052, 3054, 26, 'Ins 1 o ins 3'),
(96053, 3055, 26, 'Ins Indirizzi'),
(96054, 3056, 26, 'Ins modifica'),
(96055, 3057, 26, 'Ins accorpamento'),
(96056, 3058, 26, 'Ins codice'),
(96057, 3059, 26, 'Ins Gruppo'),
(96058, 3060, 26, 'Ins Nome'),
(96059, 3061, 26, 'Ins pagato in eccesso'),
(96060, 3062, 26, 'Ins Polizza'),
(96061, 3063, 26, 'Ins rimborso'),
(96062, 3064, 26, 'Ins Sommario'),
(96063, 3065, 26, 'Ins1'),
(96064, 3066, 26, 'Ins2'),
(96065, 3067, 26, 'Ins3'),
(96066, 3068, 26, 'Inserire'),
(96067, 3069, 26, 'Inserimento fallito '),
(96068, 3070, 26, 'Inserisci vecchi eventi nelle tabelle'),
(96069, 3072, 26, 'Insonnia'),
(96070, 3073, 26, 'Ispeziona il log'),
(96071, 3074, 26, 'Ispezione'),
(96072, 3075, 26, 'Instabilità / Sublussazione'),
(96073, 3076, 26, 'INSTALLA'),
(96074, 3077, 26, 'Installa'),
(96075, 3078, 26, 'Installa il Set di codice'),
(96076, 3079, 26, 'installa DB'),
(96077, 3080, 26, 'Release installata'),
(96078, 3081, 26, 'Date istruzioni'),
(96079, 3082, 26, 'Istruzione'),
(96080, 3084, 26, 'Istruzioni:'),
(96081, 3085, 26, 'Inventario insufficiente per ID del prodotto'),
(96082, 3086, 26, 'Diabete insulino dipendente'),
(96083, 3087, 26, 'Assicurazione'),
(96084, 3088, 26, 'Assicurazione'),
(96085, 3091, 26, 'Saldo assicurazione'),
(96086, 3092, 26, 'Bilancio assicurativo dovuto'),
(96087, 3093, 26, 'Comp di Assicuazione'),
(96088, 3094, 26, 'Compagnie di Assicurazione'),
(96089, 3095, 26, 'Compagnia di Assicurazione'),
(96090, 3096, 26, 'Cerca/Aggiungi Compagnia di Assicurazione'),
(96091, 3098, 26, 'Data assicurazione'),
(96092, 3099, 26, 'Informazioni di Assicurazione nel file'),
(96093, 3100, 26, 'Numeri di Assicuazione'),
(96094, 3101, 26, 'Pagamento Assicurazione'),
(96095, 3103, 26, 'Fornitore Assicurazione'),
(96096, 3104, 26, 'Tipi di assicurazione'),
(96097, 3105, 26, 'Assicurazioni'),
(96098, 3106, 26, 'Assicurato'),
(96099, 3107, 26, 'Conclusione Presa in carico'),
(96100, 3108, 26, 'Data Presa in carico'),
(96101, 3109, 26, 'Declino intellettivo'),
(96102, 3110, 26, 'Interlingua'),
(96103, 3111, 26, 'Interlingue'),
(96104, 3113, 26, 'Errore interno - non è stata selezionata nessuna pagina!'),
(96105, 3114, 26, 'Errore interno - ID del paziente non fornito!'),
(96106, 3115, 26, 'Errore interno nell''accedere al file caricato!'),
(96107, 3116, 26, 'Errore interno!'),
(96108, 3117, 26, 'Errore interno, non specificato alcun ID droga!'),
(96109, 3118, 26, 'Errore interno: MSH-10 non trovato'),
(96110, 3119, 26, 'Errore interno: reclamo '),
(96111, 3120, 26, 'Erroe interno: incontro '''),
(96112, 3121, 26, 'Errore interno: pid o incontro mancante.'),
(96113, 3122, 26, 'Errore interno: non sembra affatto essere in un incontro!'),
(96114, 3123, 26, 'Identificatore interno (pid)'),
(96115, 3126, 26, 'Referenti interni'),
(96116, 3127, 26, 'Tempo interno Raccolta'),
(96117, 3128, 26, 'Tassa internazionale'),
(96118, 3129, 26, 'Interprete'),
(96119, 3130, 26, 'Necessario Interprete?'),
(96120, 3131, 26, 'Malattia interstiziale del polmone'),
(96121, 3132, 26, 'Intervallo'),
(96122, 3133, 26, 'Intervallo (minuti)'),
(96123, 3134, 26, 'Intervallo tra i controlli di messaggi (impostato a zero per controlli solo manuali)'),
(96124, 3135, 26, 'Intervento'),
(96125, 3136, 26, 'Intervento previsto'),
(96126, 3137, 26, 'Intolleranza'),
(96127, 3139, 26, 'intramuscolare'),
(96128, 3140, 26, 'endovenosamente'),
(96129, 3141, 26, 'Introduzione'),
(96130, 3142, 26, 'Inuktitut'),
(96131, 3143, 26, 'Inupiaq'),
(96132, 3144, 26, 'Carattere non valido in'),
(96133, 3146, 26, 'Tipo di codifica dati incapsulati non valido'),
(96134, 3147, 26, 'Lunghezza non valida per'),
(96135, 3148, 26, 'Carattere non-numerico invalido in'),
(96136, 3149, 26, 'Pagatore non valido o mancante nell''origine per il codice '),
(96137, 3150, 26, 'Indirizzo del destinatario non valido. Riprova.'),
(96138, 3151, 26, 'Codici Prestazioni non validi'),
(96139, 3152, 26, 'Designazione origine non valida "'),
(96140, 3153, 26, 'Username o password non validi'),
(96141, 3154, 26, 'AmmontInv'),
(96142, 3155, 26, 'Inventario'),
(96143, 3156, 26, 'Attività di Inventario'),
(96144, 3157, 26, 'Giacenze e vendite di prodotti farmacologici e non'),
(96145, 3158, 26, 'Gicenze e vendite dei soli farmaci'),
(96146, 3159, 26, 'La giacenza non è disponibile per questo ordine.'),
(96147, 3160, 26, 'Elenco giacenze'),
(96148, 3161, 26, 'Transazioni di giacenze'),
(96149, 3162, 26, 'Fattura'),
(96150, 3163, 26, 'fattura'),
(96151, 3164, 26, 'Saldo della fattura'),
(96152, 3165, 26, 'Il saldo della fattura non può essere postato. Nessun incontro creato.'),
(96153, 3166, 26, 'Data fattura'),
(96154, 3167, 26, 'La fattura non ha la data!'),
(96155, 3168, 26, 'Numero fattura'),
(96156, 3169, 26, 'Numero di riferimento fattura'),
(96157, 3170, 26, 'Numero di riferimento fattura pool, se utilizzato'),
(96158, 3171, 26, 'N.riferimento fattura cassa comune'),
(96159, 3172, 26, 'N.Rif.Ft cassa comune'),
(96160, 3173, 26, 'Fattura:'),
(96161, 3174, 26, 'IPPF'),
(96162, 3175, 26, 'IPPF Aborto'),
(96163, 3176, 26, 'IPPF contraccezione'),
(96164, 3177, 26, 'IPPF SRH Dati per'),
(96165, 3178, 26, 'IPPF Report statistiche'),
(96166, 3179, 26, 'IPPF Stati'),
(96167, 3180, 26, 'IPV 1'),
(96168, 3181, 26, 'IPV 2'),
(96169, 3182, 26, 'IPV 3'),
(96170, 3183, 26, 'IPV 4'),
(96171, 3184, 26, 'Irish'),
(96172, 3185, 26, 'Battito cardiaco irregolare'),
(96173, 3186, 26, 'Irritabilità'),
(96174, 3187, 26, 'Irritazione'),
(96175, 3188, 26, 'è una versione diversa di lingua del seguente database'),
(96176, 3189, 26, 'è una versione diversa del seguente database'),
(96177, 3190, 26, 'è una versione più recente del database seguente'),
(96178, 3191, 26, 'è richiesto un campo'),
(96179, 3192, 26, 'è un nodo radice e non può essere eliminato.'),
(96180, 3193, 26, 'è un''estensione del database seguente'),
(96181, 3194, 26, 'È ok per mappare questi codici CVX a vaccinazioni già esistenti?'),
(96182, 3195, 26, 'è fuori luogo o sconosciuto'),
(96183, 3197, 26, 'non è valido (decimali o frazioni sono OK)'),
(96184, 3198, 26, 'PHP sta usando Safe Mode?'),
(96185, 3200, 26, 'Il testo del layout del modulo deve essere tradotto?'),
(96186, 3201, 26, 'Il testo degli elenchi deve essere tradotto?'),
(96187, 3202, 26, 'Il File è criptato?'),
(96188, 3203, 26, 'È questo un tipo di termine clinico con codice?'),
(96189, 3204, 26, 'Questa è un tipo di diagnosi?'),
(96190, 3205, 26, 'È questo un tipo di problema medico con codice?'),
(96191, 3206, 26, 'È questo un tipo di medicazione?'),
(96192, 3207, 26, 'Questo è un tipo di procedura/servizio?'),
(96193, 3208, 26, 'Questo è attivo?'),
(96194, 3209, 26, 'Questo è un tipo di codice attivo?'),
(96195, 3210, 26, 'Questo è un tipo di codice usato nei sinistri?'),
(96196, 3211, 26, 'Va tutto bene?'),
(96197, 3212, 26, 'Questo tipo è nascosto nel foglio parcella?'),
(96198, 3213, 26, 'è questo utilizzando tabelle sql esterne? se si, scegli il formato'),
(96199, 3214, 26, 'è troppo lungo'),
(96200, 3215, 26, 'ISO 639-2 Code'),
(96201, 3216, 26, 'Tematica'),
(96202, 3217, 26, 'tematica'),
(96203, 3218, 26, 'Data Tematica'),
(96204, 3219, 26, 'ID Tematica'),
(96205, 3220, 26, 'Titolo Tematica'),
(96206, 3221, 26, 'Tipo di Tematica'),
(96207, 3222, 26, 'Tipi di Tematiche'),
(96208, 3223, 26, 'Tematiche'),
(96209, 3224, 26, 'Tematiche (Lesioni/Mediche/Allergie)'),
(96210, 3225, 26, 'Tematiche (Lesioni/Mediche/Allergie):'),
(96211, 3226, 26, 'Tematiche e Incontri'),
(96212, 3227, 26, 'Tematiche e Incontri per'),
(96213, 3228, 26, 'Tematiche non autorizzate'),
(96214, 3229, 26, 'Sezione Tematiche'),
(96215, 3230, 26, 'Italiano'),
(96216, 3231, 26, 'elemento'),
(96217, 3232, 26, 'elemento'),
(96218, 3233, 26, 'elementi'),
(96219, 3234, 26, 'caricamento degli elementi fallito'),
(96220, 3235, 26, 'IU/L'),
(96221, 3236, 26, 'IUD'),
(96222, 3237, 26, 'IV'),
(96223, 3238, 26, 'Gen'),
(96224, 3239, 26, 'Gennaio'),
(96225, 3240, 26, 'Giapponese'),
(96226, 3241, 26, 'Ittero'),
(96227, 3242, 26, 'Javanese'),
(96228, 3243, 26, 'Descrizione lavoro');
INSERT INTO `lang_definitions` VALUES
(96229, 3244, 26, 'ID Lavoro'),
(96230, 3245, 26, 'Dislocazion articolari'),
(96231, 3246, 26, 'Dolore articolare'),
(96232, 3247, 26, 'Distorsioni articolari'),
(96233, 3248, 26, 'Lug'),
(96234, 3249, 26, 'Luglio'),
(96235, 3250, 26, 'Giu'),
(96236, 3251, 26, 'Giugno'),
(96237, 3252, 26, 'Appena sotto il controllo informazione c''è un''area blu nella quale puoi inserire i tuoi parametri di ricerca. Puoi cercare per nome, numero del tabulato, numero dlel''incontro o data della prestazione, o qualsiasi combinazione di questi. Puoi anche selezionare se vuoi vedere tutte le fatture, le fatture aperte, o soltanto quelle che sono da saldare (da paziente). Clicca il pulsante Cerca per attivare la ricerca.'),
(96238, 3253, 26, 'Solo i propri'),
(96239, 3254, 26, 'Motivazione voci'),
(96240, 3255, 26, 'Giustifica'),
(96241, 3256, 26, 'Giustifica/Salva'),
(96242, 3257, 26, 'J{{Justify Header}}'),
(96243, 3258, 26, 'k, ecco il resto'),
(96244, 3259, 26, 'Kalaallisut, Greenlandic'),
(96245, 3260, 26, 'Kannada'),
(96246, 3261, 26, 'Kanuri'),
(96247, 3262, 26, 'Kashmiri'),
(96248, 3263, 26, 'Kazakh'),
(96249, 3264, 26, 'Chiave'),
(96250, 3265, 26, 'Parole chiave'),
(96251, 3266, 26, 'kg'),
(96252, 3267, 26, 'kg/m^2'),
(96253, 3268, 26, 'Khmer'),
(96254, 3269, 26, 'Cancro al rene'),
(96255, 3270, 26, 'Insufficienza renale'),
(96256, 3271, 26, 'Infezione renale'),
(96257, 3272, 26, 'Calcoli renali'),
(96258, 3273, 26, 'Trapianto di rene'),
(96259, 3274, 26, 'Kikuyu, Gikuyu'),
(96260, 3275, 26, 'Kinyarwanda'),
(96261, 3276, 26, 'Kirundi'),
(96262, 3277, 26, 'Ginocchio'),
(96263, 3278, 26, 'Problemi al ginocchio'),
(96264, 3279, 26, 'Sostituzione ginocchio'),
(96265, 3280, 26, 'Komi'),
(96266, 3281, 26, 'Kongo'),
(96267, 3282, 26, 'Coreano'),
(96268, 3283, 26, 'Kurdish'),
(96269, 3284, 26, 'Kwanyama, Kuanyama'),
(96270, 3285, 26, 'Kyrgyz'),
(96271, 3286, 26, 'Lab'),
(96272, 3287, 26, 'Documenti Lab'),
(96273, 3288, 26, 'Indirizzo del sito Lab Exchange'),
(96274, 3289, 26, 'ID del sito Lab Exchange'),
(96275, 3290, 26, 'Lab Exchange Token ID'),
(96276, 3291, 26, 'Ordini Lab'),
(96277, 3292, 26, 'panoramica Lab'),
(96278, 3293, 26, 'Panoramica Lab'),
(96279, 3294, 26, 'Lab stato richiesta'),
(96280, 3295, 26, 'Resoconto Lab'),
(96281, 3296, 26, 'Risutato Lab'),
(96282, 3297, 26, 'Risultati Lab'),
(96283, 3298, 26, 'Nome categoria risultati Lab'),
(96284, 3299, 26, 'Resoconto Risultati lab'),
(96285, 3300, 26, 'Servizio Lab'),
(96286, 3301, 26, 'Risultati test Lab'),
(96287, 3302, 26, 'Lab/File'),
(96288, 3303, 26, 'Etichetta'),
(96289, 3304, 26, 'L''etichetta non può essere in bianco'),
(96290, 3305, 26, 'C.nne Etichette'),
(96291, 3306, 26, 'Etichetta per questo tipo'),
(96292, 3307, 26, 'Colonne Etichette deve essere un numero tra 1 e 999'),
(96293, 3308, 26, 'Etichette'),
(96294, 3311, 26, 'Laboratori'),
(96295, 3312, 26, 'Lacerazione / condizioni della pellle'),
(96296, 3313, 26, 'Lacerazione/abrasione'),
(96297, 3315, 26, 'Panorama'),
(96298, 3316, 26, 'Lingua'),
(96299, 3317, 26, 'Codice Lingua'),
(96300, 3318, 26, 'Aggiunta definizione Lingua'),
(96301, 3319, 26, 'Strumento di interfaccia Lingua'),
(96302, 3320, 26, 'Elenco Lingue (scrittura,additiva opzionale)'),
(96303, 3321, 26, 'Nome della Lingua'),
(96304, 3322, 26, 'Lingua:'),
(96305, 3323, 26, 'Lao'),
(96306, 3324, 26, 'Laoziano'),
(96307, 3325, 26, 'Ultimo'),
(96308, 3326, 26, 'Data Ultima attività'),
(96309, 3327, 26, 'Ultima Appendicectomia'),
(96310, 3328, 26, 'Data ultima fattura:'),
(96311, 3329, 26, 'Ultimo esame del seno'),
(96312, 3330, 26, 'Utlimo anno del calendario'),
(96313, 3331, 26, 'Ultimo intervento di cataratta'),
(96314, 3332, 26, 'Ultima colicistectomia'),
(96315, 3333, 26, 'Ultimo incontro'),
(96316, 3334, 26, 'Ultimo esame Ginecologico'),
(96317, 3335, 26, 'Ultimo intervento al cuore'),
(96318, 3336, 26, 'Ultima riparazione di ernia'),
(96319, 3337, 26, 'Ultima sostituzione dell''anca'),
(96320, 3338, 26, 'Ultima Isterectomia'),
(96321, 3339, 26, 'Ultima sostituzione del ginocchio'),
(96322, 3340, 26, 'Ultimo livello di Fatturato'),
(96323, 3341, 26, 'Ultima mammografia'),
(96324, 3342, 26, 'Ultimo periodo di mestruazioni'),
(96325, 3343, 26, 'Ultimo mese'),
(96326, 3344, 26, 'Cognome'),
(96327, 3345, 26, 'cognome'),
(96328, 3346, 26, 'Cognome:'),
(96329, 3347, 26, 'Ultimo esame fisico'),
(96330, 3348, 26, 'Ultimo esame prostatico'),
(96331, 3349, 26, 'Ultimo esame del retto'),
(96332, 3350, 26, 'Ultima revisione'),
(96333, 3351, 26, 'Ultima prestazione iniziata alle'),
(96334, 3352, 26, 'Ultimo salvataggio'),
(96335, 3353, 26, 'Ultima Sigmoide/Colonscopia'),
(96336, 3355, 26, 'Ultima tonsillectomia'),
(96337, 3356, 26, 'Ultimo aggiornamento da'),
(96338, 3357, 26, 'Utlima verifica il'),
(96339, 3358, 26, 'Ultima visita'),
(96340, 3359, 26, 'Ultimi raggi X'),
(96341, 3360, 26, 'Recidiva tardiva (2-12 Mesi)'),
(96342, 3361, 26, 'Malleolo Laterale'),
(96343, 3362, 26, 'Malleolo laterale:'),
(96344, 3363, 26, 'Lateralità'),
(96345, 3364, 26, 'Lateralità di questa procedura, se applicabile'),
(96346, 3365, 26, 'spostato lateralmente PMI:'),
(96347, 3367, 26, 'Ultima visita o consulto'),
(96348, 3368, 26, 'Latin'),
(96349, 3369, 26, 'Latvian'),
(96350, 3372, 26, 'Layout'),
(96351, 3373, 26, 'Layout di base'),
(96352, 3374, 26, 'Layout Editor'),
(96353, 3375, 26, 'gruppi layout'),
(96354, 3376, 26, 'Stile Layout'),
(96355, 3378, 26, 'Layout-base per il form visite'),
(96356, 3379, 26, 'Layouts'),
(96357, 3380, 26, 'libra'),
(96358, 3381, 26, 'libre'),
(96359, 3382, 26, 'LDL'),
(96360, 3383, 26, 'lascia in bianco se ancora attivo'),
(96361, 3384, 26, 'Lascia in bianco per mantenere Il nome del file originale'),
(96362, 3385, 26, 'Lascia in bianco per mantenere non modificata la password'),
(96363, 3386, 26, 'Lascia messaggio tramite'),
(96364, 3387, 26, 'Lascia il modulo'),
(96365, 3388, 26, 'Lasciando la pass frase in bianco il documento non verrà criptato'),
(96366, 3390, 26, 'Sinistra'),
(96367, 3391, 26, 'Orecchio Sinistro'),
(96368, 3392, 26, 'orecchio sinistro'),
(96369, 3393, 26, 'Margine sinistro (mm)'),
(96370, 3394, 26, 'Sinistra:'),
(96371, 3395, 26, 'Sinistra: '),
(96372, 3396, 26, 'Dolore alla gamba/Crampi'),
(96373, 3397, 26, 'Legale'),
(96374, 3399, 26, 'Formato carta legale'),
(96375, 3400, 26, 'Legenda:'),
(96376, 3401, 26, 'Lunghezza'),
(96377, 3402, 26, 'Lunghezza del modificatore, 0 se nessuna'),
(96378, 3403, 26, 'Minore di'),
(96379, 3404, 26, 'Minore o uguale a'),
(96380, 3405, 26, 'Infomazioni bassa-privacy (scrittura, solo aggiunte opzionali)'),
(96381, 3406, 26, 'Lettera'),
(96382, 3407, 26, 'Generatore di Lettere'),
(96383, 3408, 26, 'Formato carta da lettera'),
(96384, 3409, 26, 'Intestazione che il dottore firma'),
(96385, 3410, 26, 'Intestazione che il paziente firma'),
(96386, 3411, 26, 'Livello di urgenza'),
(96387, 3412, 26, 'Affidabilità'),
(96388, 3413, 26, 'Affidabilità medica'),
(96389, 3414, 26, 'Licenza/ID'),
(96390, 3419, 26, 'LicensedPrescriber Cognome'),
(96391, 3420, 26, 'LicensedPrescriber NPI'),
(96392, 3421, 26, 'LicensedPrescriber UPIN'),
(96393, 3423, 26, 'Stile di vita'),
(96394, 3424, 26, 'Status stile di vita'),
(96395, 3425, 26, 'Legamento strappo o distorsione'),
(96396, 3426, 26, ' Fumatore di tabacco leggero'),
(96397, 3427, 26, 'Limburgish, Limburgan, Limburger'),
(96398, 3428, 26, 'Limite Di Eventi'),
(96399, 3429, 26, 'limito'),
(96400, 3430, 26, 'Lingala'),
(96401, 3431, 26, 'Collegamento'),
(96402, 3432, 26, 'Collegamento al paziente'),
(96403, 3433, 26, 'Collegato'),
(96404, 3434, 26, 'Documento collegato'),
(96405, 3435, 26, 'Ordine di procedura collegato'),
(96406, 3436, 26, 'collegato al documento'),
(96407, 3437, 26, 'collegato all''ordine di procedura'),
(96408, 3438, 26, 'Elenco'),
(96409, 3439, 26, 'Elenco a discesa'),
(96410, 3440, 26, 'elenco a discesa'),
(96411, 3441, 26, 'elenco a discesa s/agg'),
(96412, 3442, 26, 'elenco a discesa s/agg'),
(96413, 3443, 26, 'Editor di elenco'),
(96414, 3444, 26, 'Elenco incontri'),
(96415, 3445, 26, 'Elenco gruppi'),
(96416, 3446, 26, 'Elenco Compagnie assicurative'),
(96417, 3448, 26, 'Un elenco di elementi non può cominciare con un numero'),
(96418, 3449, 26, 'L''elenco degli elementi contiene carattere(i) illegale(i)'),
(96419, 3451, 26, 'Elenco degli elenchi'),
(96420, 3452, 26, 'Nome dell''elenco'),
(96421, 3453, 26, 'I nomi degli elenchi non posssono cominciare con un numero.'),
(96422, 3454, 26, 'Elenco Prescrizioni'),
(96423, 3455, 26, 'Elenco utilizzato dalla soprastante opzione Tipo di dati nazione.'),
(96424, 3456, 26, 'Elenco utilizzato dalla soprastante opzione Tipo di dati stato.'),
(96425, 3457, 26, 'Porta di ascolto del server syslog 5425 TLS RFC.'),
(96426, 3458, 26, 'Elenchi'),
(96427, 3459, 26, 'Lituano'),
(96428, 3460, 26, 'Testamento'),
(96429, 3461, 26, 'LLL:'),
(96430, 3462, 26, 'LMP'),
(96431, 3463, 26, 'Carico Compendio'),
(96432, 3464, 26, 'Carica Definizioni'),
(96433, 3465, 26, 'Carica configurazione LAB'),
(96434, 3466, 26, 'Carica opzioni di domande OE'),
(96435, 3467, 26, 'Carica definizioni ordine'),
(96436, 3468, 26, 'Carica richieste ordini in entrata'),
(96437, 3469, 26, 'LOAD SUCCESSFUL. Codici inseriti'),
(96438, 3470, 26, 'STO CARICANDO'),
(96439, 3471, 26, 'Sto caricando i file nel database. Ci vorrà un po'' di tempo'),
(96440, 3472, 26, 'LOC'),
(96441, 3473, 26, 'Locale'),
(96442, 3474, 26, 'Contenuto locale'),
(96443, 3475, 26, 'File di sistema locale'),
(96444, 3476, 26, 'Locale'),
(96445, 3477, 26, 'Località'),
(96446, 3478, 26, 'Collocazione'),
(96447, 3479, 26, 'collocazione della macchina libreehr e potrebbe contenere dati sensibili, così si raccomanda di eliminare manualmente i file dopo il suo uso'),
(96448, 3480, 26, 'Collocazione di questo lotto'),
(96449, 3481, 26, 'Collocazione non specificata'),
(96450, 3482, 26, 'Collocazione dove Hylafax immagazzina i fax.'),
(96451, 3483, 26, 'Collocazione dove sono immagazzinate le scansioni.'),
(96452, 3484, 26, 'Collocazione:'),
(96453, 3485, 26, 'Blocca'),
(96454, 3486, 26, 'Bloccare un modulo e-signed individualmente'),
(96455, 3487, 26, 'Bloccare e-signed incontri e i loro moduli'),
(96456, 3488, 26, 'Bloccare?'),
(96457, 3489, 26, 'Bloccato'),
(96458, 3492, 26, 'Ingresso'),
(96459, 3493, 26, 'Log in'),
(96460, 3494, 26, 'Uscita'),
(96461, 3495, 26, 'Entrato'),
(96462, 3496, 26, 'Entrato come'),
(96463, 3497, 26, 'Entrato come: '),
(96464, 3498, 26, 'Uscito.'),
(96465, 3499, 26, 'Accesso'),
(96466, 3500, 26, 'Login'),
(96467, 3501, 26, 'login'),
(96468, 3502, 26, 'Nome del Login per WordPress per l''accesso al portale come utente'),
(96469, 3503, 26, 'Login all''host remoto'),
(96470, 3504, 26, 'Il login a questo host remoto è fallito'),
(96471, 3505, 26, 'Uscita'),
(96472, 3506, 26, 'uscita'),
(96473, 3507, 26, 'Logs'),
(96474, 3508, 26, 'Visore dei Logs'),
(96475, 3510, 26, 'cercare'),
(96476, 3511, 26, 'Lotto'),
(96477, 3512, 26, 'ID del Lotto mancante!'),
(96478, 3513, 26, 'Numero del Lotto'),
(96479, 3514, 26, 'basso'),
(96480, 3515, 26, 'Bassa priorità'),
(96481, 3516, 26, 'Parte inferiore della gamba'),
(96482, 3517, 26, 'Priorità più bassa'),
(96483, 3518, 26, 'Luba-Katanga'),
(96484, 3519, 26, 'Colonna lombare'),
(96485, 3520, 26, 'PRANZO'),
(96486, 3521, 26, 'Pranzo'),
(96487, 3522, 26, 'Cancro al polmone'),
(96488, 3523, 26, 'Intervento per cancro al polmone'),
(96489, 3524, 26, 'POLMONI:'),
(96490, 3525, 26, 'Polmoni:'),
(96491, 3526, 26, 'Lupus'),
(96492, 3527, 26, 'Luxembourgish, Letzeburgesch'),
(96493, 3528, 26, 'M'),
(96494, 3529, 26, 'MA categoria'),
(96495, 3530, 26, 'MA il cliente accetta l''aborto'),
(96496, 3531, 26, 'MA statistiche'),
(96497, 3532, 26, 'Macedonian'),
(96498, 3533, 26, 'Posta Inviata'),
(96499, 3534, 26, 'Principale'),
(96500, 3535, 26, 'Indirizzo Principale'),
(96501, 3536, 26, 'Parte sup. della schermata del pannello principale'),
(96502, 3537, 26, 'Mantieni attivo l''elenco delle allergie ai farmaci.'),
(96503, 3538, 26, 'Mantieni attivo l''elenco dei farmaci.'),
(96504, 3539, 26, 'Mantieni un elenco aggiornato dei problemi delle diagnosi correnti e attive'),
(96505, 3540, 26, 'Esegui le modifiche alle ategorie correnti'),
(96506, 3541, 26, 'Fissa un nuovo appuntamento per'),
(96507, 3542, 26, 'Sii certo "'),
(96508, 3543, 26, 'Rendere i file di testo in batch per il caricamento di scambio di informazioni e segnerà come fatturati'),
(96509, 3544, 26, 'Malagasy'),
(96510, 3545, 26, 'Malessere:'),
(96511, 3546, 26, 'Malay'),
(96512, 3547, 26, 'Malayalam'),
(96513, 3548, 26, 'Maschio'),
(96514, 3549, 26, 'Preservativi maschili'),
(96515, 3550, 26, 'Maschio VSC'),
(96516, 3551, 26, 'Maltese'),
(96517, 3552, 26, 'Mammografia'),
(96518, 3553, 26, 'gestire'),
(96519, 3554, 26, 'Gestione Hooks(Ganci)'),
(96520, 3555, 26, 'Gestione moduli'),
(96521, 3556, 26, 'Gestione traduzioni'),
(96522, 3557, 26, 'Gestione'),
(96523, 3558, 26, 'Dati obbligatori e specifici'),
(96524, 3559, 26, 'Dati obbligatori o solo specifici, controllo dupl., no ricerca'),
(96525, 3560, 26, 'Dati obbligatori o solo specifici, controllo dupl., e ricerca'),
(96526, 3561, 26, 'Manuale'),
(96527, 3562, 26, 'Scrittura manuale'),
(96528, 3563, 26, 'Produttore'),
(96529, 3564, 26, 'Manx'),
(96530, 3565, 26, 'Mar'),
(96531, 3567, 26, 'Marathi (Marāṭhī)'),
(96532, 3568, 26, 'Marzo'),
(96533, 3569, 26, 'Stato Civile'),
(96534, 3570, 26, 'Segna come fatturato'),
(96535, 3571, 26, 'Segna come fatturato ma salta la fatturazione'),
(96536, 3572, 26, 'Segna come cancellato'),
(96537, 3573, 26, 'Segna come non pagato'),
(96538, 3574, 26, 'Segna questo report come recensione'),
(96539, 3575, 26, 'Segna come cancellato'),
(96540, 3576, 26, 'Sposato'),
(96541, 3577, 26, 'Marshallese'),
(96542, 3578, 26, 'Maschera'),
(96543, 3579, 26, 'Mashera per il Numero di fattura'),
(96544, 3580, 26, 'Maschera per gli IDs del paziente'),
(96545, 3581, 26, 'Maschera per gli IDs dei prodotti'),
(96546, 3582, 26, 'Combaciare'),
(96547, 3583, 26, 'Caso di corrispondenza'),
(96548, 3584, 26, 'Corrispondenza trovata'),
(96549, 3590, 26, 'Matrice'),
(96550, 3591, 26, 'Max'),
(96551, 3592, 26, 'numero di file massimo raggiunto - ricarica i nomi sottostanti'),
(96552, 3594, 26, 'Mascellare destro:'),
(96553, 3595, 26, 'Età massima'),
(96554, 3596, 26, 'Massimo caratteri'),
(96555, 3597, 26, 'Massimo tempo di inattività in secondi prima di logout. Il valore predefinito è 7200 (2 ore).'),
(96556, 3600, 26, 'Massimo inventario ragionevole, 0 se non applicabile'),
(96557, 3601, 26, 'Dimesione massima'),
(96558, 3602, 26, 'Dimesione massima (inserendo 0 permetterà qualsiasi dimensione)'),
(96559, 3603, 26, 'Maggio'),
(96560, 3604, 26, 'MC'),
(96561, 3605, 26, 'mcg'),
(96562, 3607, 26, 'Significa nessuna delle ultime tre password sono consentite quando si cambia una password.'),
(96563, 3609, 26, 'Misura gruppo di codice'),
(96564, 3611, 26, 'Misurazione'),
(96565, 3612, 26, 'Malleolo mediale'),
(96566, 3613, 26, 'Aiuto medico'),
(96567, 3614, 26, 'Medico'),
(96568, 3615, 26, 'Aborto medico'),
(96569, 3616, 26, 'Amministrazione medica'),
(96570, 3617, 26, 'Storia medica'),
(96571, 3618, 26, 'problemi di natura medica'),
(96572, 3619, 26, 'problemi di natura medica'),
(96573, 3620, 26, 'Problema medico'),
(96574, 3621, 26, 'Problema Medico'),
(96575, 3622, 26, 'Lista dei problemi Medici'),
(96576, 3623, 26, 'Problemi medici'),
(96577, 3624, 26, 'Cartella clinica'),
(96578, 3625, 26, 'Cartella clinica #'),
(96579, 3626, 26, 'Cartelle cliniche'),
(96580, 3627, 26, 'Cartelle cliniche inviate'),
(96581, 3629, 26, 'Riepilogo medico dato'),
(96582, 3630, 26, 'Sistema medico'),
(96583, 3631, 26, 'Tipo di medico'),
(96584, 3632, 26, 'Medica / Cronologia (scrittura, aggiungere solo opzionale)'),
(96585, 3633, 26, 'Assistenza sanitaria statale Parte B'),
(96586, 3634, 26, 'Assistenza sanitaria statale Parte B'),
(96587, 3635, 26, 'Medicazione/Farmaci'),
(96588, 3636, 26, 'Rendere i file di testo in batch per il caricamento di di scambio di informazioni e segnerà come fatturati'),
(96589, 3637, 26, 'Lista problemi delle medicazioni'),
(96590, 3638, 26, 'Lista medicazioni/Farmaci'),
(96591, 3639, 26, 'Riconciliazione farmaci eseguita?'),
(96592, 3640, 26, 'Medicazioni/Farmaci'),
(96593, 3641, 26, 'Medicazioni/Farmaci:'),
(96594, 3642, 26, 'Unità farmaci'),
(96595, 3643, 26, 'Medio'),
(96596, 3644, 26, 'MedlinePlus Connect'),
(96597, 3645, 26, 'Membro Associazione Report Statistiche'),
(96598, 3646, 26, 'Problemi mnestici'),
(96599, 3647, 26, 'Uomo'),
(96600, 3648, 26, 'Uomo e Donna'),
(96601, 3649, 26, 'Soltanto Uomo'),
(96602, 3650, 26, 'Menarca'),
(96603, 3651, 26, 'Menopausa'),
(96604, 3652, 26, 'Flusso mestruale'),
(96605, 3653, 26, 'Frequenza mestruale'),
(96606, 3654, 26, 'Malattia mentale'),
(96607, 3655, 26, 'Menu Text'),
(96608, 3656, 26, 'Menu'),
(96609, 3657, 26, 'Unisci'),
(96610, 3658, 26, 'Unione completa.'),
(96611, 3659, 26, 'Unire i pazienti'),
(96612, 3661, 26, 'Messaggio'),
(96613, 3662, 26, 'Messaggio e Centro promemoria'),
(96614, 3663, 26, 'Il contenuto del messaggio non è testo semplice, così è stato conservato come un documento.'),
(96615, 3664, 26, 'Messaggio dal paziente'),
(96616, 3665, 26, 'Messaggio inviato'),
(96617, 3666, 26, 'Stato del messaggio'),
(96618, 3667, 26, 'Titolo del Messaggio'),
(96619, 3668, 26, 'Messaggio al paziente'),
(96620, 3669, 26, 'Tipo del messaggio'),
(96621, 3670, 26, 'MESSAGGIO:'),
(96622, 3671, 26, 'Messaggi'),
(96623, 3672, 26, 'Messaggi inviati oggi'),
(96624, 3673, 26, 'Metodo'),
(96625, 3674, 26, 'Metodo e Prodotto specifico'),
(96626, 3675, 26, 'Metodo per l''invio delle email in uscita.'),
(96627, 3676, 26, 'Metodo di distruzione'),
(96628, 3677, 26, 'Mexican/MexAmer/Chicano'),
(96629, 3679, 26, 'mg'),
(96630, 3680, 26, 'mg/1cc'),
(96631, 3681, 26, 'mg/2cc'),
(96632, 3682, 26, 'mg/3cc'),
(96633, 3683, 26, 'mg/4cc'),
(96634, 3684, 26, 'mg/5cc'),
(96635, 3685, 26, 'GM/DL'),
(96636, 3686, 26, 'mezzo'),
(96637, 3687, 26, 'Secondo Nome'),
(96638, 3688, 26, 'Secondo nome'),
(96639, 3690, 26, 'Prescrittore DEA di medio livello'),
(96640, 3691, 26, 'Nome del prescrittore di medio livello'),
(96641, 3692, 26, 'Cognome del prescrittore di medio livello'),
(96642, 3693, 26, 'Prefisso del prescrittore di medio livello'),
(96643, 3694, 26, 'UPIN del prescrittore di medio livello'),
(96644, 3695, 26, 'Aspetto'),
(96645, 3696, 26, 'Lavoratore migrante o stagionale?'),
(96646, 3697, 26, 'Migrante/Stagionale'),
(96647, 3698, 26, 'Mil/CU.MM (cm cubo)'),
(96648, 3701, 26, 'MIME Type'),
(96649, 3702, 26, 'Tipo Mime'),
(96650, 3703, 26, 'Min'),
(96651, 3704, 26, 'min'),
(96652, 3705, 26, 'Età minima'),
(96653, 3706, 26, 'Minore sforzo comune + / - sinovite'),
(96654, 3708, 26, 'Minuto'),
(96655, 3709, 26, 'minuti'),
(96656, 3710, 26, 'Minuti'),
(96657, 3712, 26, 'Varie'),
(96658, 3713, 26, 'Opzioni di fatturazione varie'),
(96659, 3714, 26, 'Opzioni di fatturazione varie per HCFA-1500'),
(96660, 3715, 26, 'Opzioni di fatturazione varie per HCFA'),
(96661, 3716, 26, 'Miscellanea'),
(96662, 3717, 26, 'Mancante'),
(96663, 3718, 26, 'mancante'),
(96664, 3719, 26, 'Manca un campo richiesto'),
(96665, 3720, 26, 'Tariffa mancante'),
(96666, 3721, 26, 'Mancano solo i Mods'),
(96667, 3722, 26, 'Mancante o non valido'),
(96668, 3723, 26, 'PID mancante'),
(96669, 3724, 26, 'Data resoconto mancante'),
(96670, 3725, 26, 'Manca lo slash dopo il pagante nel sorgente per il codice '),
(96671, 3726, 26, 'Misto'),
(96672, 3727, 26, 'ml'),
(96673, 3728, 26, 'MM/GG/AAAA'),
(96674, 3729, 26, 'mm/hg'),
(96675, 3730, 26, 'mmHg'),
(96676, 3731, 26, 'MMR 1'),
(96677, 3732, 26, 'MMR 2'),
(96678, 3733, 26, 'Cellulare'),
(96679, 3734, 26, 'Tel. Cellulare'),
(96680, 3735, 26, 'Mod'),
(96681, 3738, 26, 'Priorità moderata'),
(96682, 3740, 26, 'Moderata/Bassa priorità'),
(96683, 3741, 26, 'Modificatore'),
(96684, 3742, 26, 'Modificatori'),
(96685, 3743, 26, 'Modificare'),
(96686, 3745, 26, 'Modifica Pagamenti'),
(96687, 3746, 26, 'ModLength'),
(96688, 3747, 26, 'Modulo'),
(96689, 3748, 26, 'Directory del modulo non trovata'),
(96690, 3749, 26, 'Installazione Modulo'),
(96691, 3750, 26, 'Nome Modulo'),
(96692, 3751, 26, 'Il nome del Modulo esiste già'),
(96693, 3752, 26, 'Moduli'),
(96694, 3753, 26, 'Lun'),
(96695, 3754, 26, 'Lun fino a Ven'),
(96696, 3755, 26, 'Lun, Mer &amp; Ven'),
(96697, 3756, 26, 'Lunedì'),
(96698, 3757, 26, 'Mongolian'),
(96699, 3758, 26, 'Mese'),
(96700, 3759, 26, 'mese'),
(96701, 3760, 26, 'Vista del Mese'),
(96702, 3761, 26, 'Mese(i)'),
(96703, 3762, 26, 'Entrata mensile'),
(96704, 3763, 26, 'Mesi'),
(96705, 3765, 26, 'Trovati più di 100 record. Restringi i criteri di ricerca.'),
(96706, 3766, 26, 'Trovati più di 50 risultati, rendi più specifica la ricerca.'),
(96707, 3767, 26, 'La maggior parte delle intestazioni di colonna è possibile fare clic per cambiarne l''ordinamento'),
(96708, 3768, 26, 'Più recenti dal'),
(96709, 3769, 26, 'I più recenti dati di laboratorio:'),
(96710, 3770, 26, 'Vitali più recenti il:'),
(96711, 3771, 26, 'Madre'),
(96712, 3772, 26, 'Nome della Madre'),
(96713, 3773, 26, 'Storia della Madre'),
(96714, 3774, 26, 'Bocca'),
(96715, 3775, 26, 'Sposta'),
(96716, 3776, 26, 'Sposta Documento nella Categoria:'),
(96717, 3777, 26, 'Sposta giù'),
(96718, 3778, 26, 'Spostamento fallito!'),
(96719, 3779, 26, 'Sposta al Paziente'),
(96720, 3780, 26, 'Sposta nel...'),
(96721, 3781, 26, 'Sposta su'),
(96722, 3782, 26, 'Spostare'),
(96723, 3783, 26, 'Sig.'),
(96724, 3784, 26, 'MRN (pid)'),
(96725, 3785, 26, 'Sig.ra'),
(96726, 3786, 26, 'Sig.na'),
(96727, 3787, 26, 'MSH-11'),
(96728, 3788, 26, 'MSH-3.1'),
(96729, 3789, 26, 'MSH-4.1'),
(96730, 3790, 26, 'MSH-5.1'),
(96731, 3791, 26, 'MSH-6.1'),
(96732, 3793, 26, 'MSH.8 tipo di messaggio non valido'),
(96733, 3794, 26, 'Codice MSP'),
(96734, 3795, 26, 'Deposito codici MSP'),
(96735, 3796, 26, 'Strumento Multi Lingua'),
(96736, 3797, 26, 'Aree multiple'),
(96737, 3798, 26, 'Più file possono essere caricati contemporaneamente selezionandoli con CTRL + clic o Maiusc + clic.'),
(96738, 3799, 26, 'Lotti multipli'),
(96739, 3800, 26, 'Modificatori multipli possono essere separati da due punti o spazi, massimo di 4 (M1: M2: M3: M4)'),
(96740, 3801, 26, 'Lista multipla di selezione'),
(96741, 3802, 26, 'Multirazziale'),
(96742, 3803, 26, 'Soffio:'),
(96743, 3804, 26, 'Dolore musc'),
(96744, 3805, 26, 'Dolori musc'),
(96745, 3806, 26, 'Arrossamento musc'),
(96746, 3807, 26, 'Rigidità musc'),
(96747, 3808, 26, 'Gonfiore musc'),
(96748, 3809, 26, 'Musc caldo'),
(96749, 3810, 26, 'Muscolo'),
(96750, 3811, 26, 'Lesione muscolare'),
(96751, 3812, 26, 'Muscoloscheletrico'),
(96752, 3813, 26, 'Deve essere vuoto se non si usa l''autenticazione SMTP'),
(96753, 3814, 26, 'Reciprocamente definito'),
(96754, 3815, 26, 'MVA'),
(96755, 3818, 26, 'Io stesso'),
(96756, 3820, 26, 'Māori'),
(96757, 3821, 26, 'N/D'),
(96758, 3822, 26, 'n/d'),
(96759, 3823, 26, 'Nome'),
(96760, 3825, 26, 'Nome (clicca per ulteriori)'),
(96761, 3826, 26, 'Nome 1'),
(96762, 3827, 26, 'Nome 2'),
(96763, 3828, 26, 'Nome e titolo di Amministratore immunizzazione'),
(96764, 3829, 26, 'Nome in EMR'),
(96765, 3830, 26, 'Name must be like codetype_code_language.pdf, for example icd9_274.11_en.pdf'),
(96766, 3831, 26, 'Nome dell''Evento'),
(96767, 3832, 26, 'Nome della Compagnia di assicurazione'),
(96768, 3833, 26, 'Nome del fornitore'),
(96769, 3834, 26, 'Nome del mittente del promemoria per il paziente'),
(96770, 3835, 26, 'Traduzione del nome'),
(96771, 3836, 26, 'Nome/Valore'),
(96772, 3837, 26, 'Nome:'),
(96773, 3838, 26, 'NARICI:'),
(96774, 3839, 26, 'NARICI: destra normale'),
(96775, 3840, 26, 'Mucosa nasale rosa, linea mediana del setto'),
(96776, 3841, 26, 'Note Nazionali'),
(96777, 3842, 26, 'Configura Note Nazionali'),
(96778, 3843, 26, 'Sostituire pulsante Note Nazionali'),
(96779, 3844, 26, 'Nazionalità'),
(96780, 3845, 26, 'NationNotes'),
(96781, 3846, 26, 'Carico dati del nativo'),
(96782, 3847, 26, 'Nativo delle Haway o altre isole del Pacifico'),
(96783, 3851, 26, 'Nauru'),
(96784, 3852, 26, 'Nausea'),
(96785, 3853, 26, 'Navajo, Navaho'),
(96786, 3854, 26, 'Navigazione'),
(96787, 3855, 26, 'Area di navigazione include i moduli incontro'),
(96788, 3856, 26, 'Area di navigazione utilizza tutta l''altezza del frame'),
(96789, 3857, 26, 'Area di navigazione moduli visita'),
(96790, 3858, 26, 'Ampiezza dell''Area navigazione'),
(96791, 3859, 26, 'Il menu navigazione è costituito da coppie di pulsanti radio'),
(96792, 3860, 26, 'Il menu navigazione è una vista ad albero'),
(96793, 3861, 26, 'Navigazione usa un menu ad espansione'),
(96794, 3862, 26, 'NDC(National Drug Code)'),
(96795, 3863, 26, 'Data NDC'),
(96796, 3864, 26, 'Numero NDC'),
(96797, 3865, 26, 'Ndonga'),
(96798, 3866, 26, 'Collo'),
(96799, 3867, 26, 'Problemi al collo'),
(96800, 3868, 26, 'Collo flessibile'),
(96801, 3869, 26, 'Occorre inserire una descrizione'),
(96802, 3870, 26, 'Occorre inserire un valore di ritorno'),
(96803, 3871, 26, 'Occorre inserire un identificatore'),
(96804, 3872, 26, 'Occorre inserire un titolo'),
(96805, 3873, 26, 'Occorre inserire Aut'),
(96806, 3874, 26, 'Occorre inseire Motivazione'),
(96807, 3875, 26, 'Occorre fatturazione secondaria'),
(96808, 3876, 26, 'Negativo'),
(96809, 3877, 26, 'Negativi'),
(96810, 3879, 26, 'Nepali'),
(96811, 3880, 26, 'Lesione del nervo'),
(96812, 3881, 26, 'Condizione neurale/danno al nervo'),
(96813, 3882, 26, 'Neuro Intorpidimento'),
(96814, 3883, 26, 'Neuro Debolezza'),
(96815, 3884, 26, 'Neurologico'),
(96816, 3885, 26, 'Mai'),
(96817, 3886, 26, 'Mai Alcohol'),
(96818, 3887, 26, 'Mai Fumatore'),
(96819, 3888, 26, 'Nuovo'),
(96820, 3889, 26, 'Nuovo =>'),
(96821, 3890, 26, 'Nuovi accettatori'),
(96822, 3892, 26, 'Nuova Allegia'),
(96823, 3893, 26, 'Nuova richiesta di modifica'),
(96824, 3894, 26, 'Nuovo Appuntamento'),
(96825, 3895, 26, 'Nuove Categorie'),
(96826, 3896, 26, 'Nuova Categoria'),
(96827, 3897, 26, 'Nuovi Clienti'),
(96828, 3898, 26, 'Nuova Consulenza'),
(96829, 3899, 26, 'Nuova coltura'),
(96830, 3900, 26, 'Nuova definizione del set aggiunta'),
(96831, 3901, 26, 'Nuovo Documento'),
(96832, 3902, 26, 'Nuovi documenti'),
(96833, 3904, 26, 'Nuovo Incontro'),
(96834, 3905, 26, 'Creato nuovo incontro con id'),
(96835, 3906, 26, 'Modulo Nuovo Incontro'),
(96836, 3907, 26, 'Nuovi incontri non autorizzati'),
(96837, 3908, 26, 'Nuovo Inc.'),
(96838, 3909, 26, 'Informazione nuova sede'),
(96839, 3910, 26, 'Nuovo file'),
(96840, 3911, 26, 'Nuovi file'),
(96841, 3912, 26, 'Nuovo Gruppo'),
(96842, 3913, 26, 'Informazione Nuovo Gruppo'),
(96843, 3914, 26, 'Nuovo Les/Status'),
(96844, 3916, 26, 'Nuovo Limite di eventi'),
(96845, 3917, 26, 'Nuovo Elenco'),
(96846, 3918, 26, 'Nuovi Ordini'),
(96847, 3919, 26, 'Nuovo Paragrafo'),
(96848, 3920, 26, 'Nuova Password'),
(96849, 3921, 26, 'Nuovo Paziente'),
(96850, 3922, 26, 'NUOVO PAZIENTE'),
(96851, 3923, 26, 'Incontro Nuovo Paziente'),
(96852, 3924, 26, 'Modulo Nuovo Paziente'),
(96853, 3925, 26, 'ID Nuovo Paziente'),
(96854, 3926, 26, 'Nuovo Pagamento'),
(96855, 3927, 26, 'Nuovo accesso al portale'),
(96856, 3928, 26, 'Nuovo Pt'),
(96857, 3929, 26, 'Nuovo risultato dal Lab Exchange'),
(96858, 3930, 26, 'Nuova Ricerca'),
(96859, 3931, 26, 'Nuovi Inserimenti'),
(96860, 3932, 26, 'Nuovo Utente'),
(96861, 3933, 26, 'Nuovo valore'),
(96862, 3934, 26, 'Nuova Visita'),
(96863, 3935, 26, 'Nuovo/Cerca'),
(96864, 3936, 26, 'Stato account Nuovo Gruppo'),
(96865, 3937, 26, 'Admin Nuovo Gruppo'),
(96866, 3938, 26, 'NewCrop chiamata fallita'),
(96867, 3939, 26, 'NewCrop Medico'),
(96868, 3940, 26, 'NewCrop eRx Account Id'),
(96869, 3944, 26, 'NewCrop eRx nome'),
(96870, 3945, 26, 'NewCrop eRx Partner nome'),
(96871, 3946, 26, 'NewCrop eRx Password'),
(96872, 3947, 26, 'NewCrop eRX Ruolo'),
(96873, 3948, 26, 'NewCrop eRx Ruolo'),
(96874, 3949, 26, 'NewCrop eRx indirizzo del sito'),
(96875, 3950, 26, 'NewCrop eRx SOAP Request Time-To-Live for Allergies'),
(96876, 3951, 26, 'NewCrop eRx SOAP Request Time-To-Live for Medications'),
(96877, 3954, 26, 'NewCrop eRx indirizzo del servizio Web'),
(96878, 3955, 26, 'NewCrop Gestore'),
(96879, 3956, 26, 'NewCrop MedEntry'),
(96880, 3957, 26, 'NewCrop prescrittore di medio livello'),
(96881, 3958, 26, 'NewCrop Infermiere'),
(96882, 3959, 26, 'NewCrop Medico supervisore'),
(96883, 3960, 26, 'Recente'),
(96884, 3961, 26, 'Giornale'),
(96885, 3962, 26, 'Successivo'),
(96886, 3964, 26, 'Giorno Successivo'),
(96887, 3965, 26, 'Mese Successivo'),
(96888, 3966, 26, 'Mese successivo (mantieni per il menu)'),
(96889, 3967, 26, 'Prossima esecuzione programmata'),
(96890, 3968, 26, 'Settimana Successiva'),
(96891, 3969, 26, 'Anno successivo (mantieni per il menu)'),
(96892, 3970, 26, 'Soprannome'),
(96893, 3971, 26, 'Soprannome'),
(96894, 3973, 26, 'Sudorazione notturna'),
(96895, 3974, 26, 'Nl ext genitali, mucosa vag, cervice'),
(96896, 3975, 26, 'No'),
(96897, 3976, 26, 'NO'),
(96898, 3977, 26, 'Nessun accesso'),
(96899, 3978, 26, 'Nessun promemoria paziente attivo'),
(96900, 3979, 26, 'No adenopatia (richieste due aree)'),
(96901, 3980, 26, 'Nessun tipo di motivo trovato per la rimodulazione di'),
(96902, 3981, 26, 'Nessuna sensibilità pelvica / masse'),
(96903, 3982, 26, 'Nessuna richiesta di modifica disponibile'),
(96904, 3983, 26, 'Nessun Appuntamento'),
(96905, 3984, 26, 'Nessun registro di controllo manomissioni rilevato nell''intervallo di date selezionato.'),
(96906, 3985, 26, 'Nessun sistema di fatturazione è attualmente attivo'),
(96907, 3986, 26, 'Nessuna fattura trovata da includere nell''esportazione OFX'),
(96908, 3987, 26, 'Nessuna fattura trovata da includere nell''esportazione OFX<br>'),
(96909, 3989, 26, 'Non è stato specificato alcun codice!'),
(96910, 3990, 26, 'Nessuna configurazione definita per questo modulo'),
(96911, 3992, 26, 'Nessuna Diagnosi'),
(96912, 3993, 26, 'Nessun Documento trovato'),
(96913, 3994, 26, 'Non è stato possibile creare alcun incontro'),
(96914, 3995, 26, 'Nessuna data di fine'),
(96915, 3996, 26, 'Nessuna immissione trovata, usa il modulo sotto per aggiungere una immissione'),
(96916, 3997, 26, 'Nessun errore trovato'),
(96917, 3998, 26, 'Nessun Evento'),
(96918, 4000, 26, 'Nessun file organizzato per l''installazione'),
(96919, 4001, 26, 'Non è stato selezionato alcun gruppo'),
(96920, 4002, 26, 'Nessuna Ernia'),
(96921, 4003, 26, 'Nessun Hooks(Ganci) disponibili per questo modulo'),
(96922, 4004, 26, 'Nessun Hooks(Ganci) abilitati per questo modulo'),
(96923, 4005, 26, 'Nessuna Lesione/Malattia'),
(96924, 4006, 26, 'Non trovata alcuna compagnia assicurativa'),
(96925, 4007, 26, 'Nessuno problemi'),
(96926, 4008, 26, 'Nessuno problemi in questo incontro.'),
(96927, 4009, 26, 'Nessun elemento sotto la categoria selezionata'),
(96928, 4010, 26, 'Non è stato selezionato alcun elemento!'),
(96929, 4024, 26, 'Nessun dato Lab documentato.'),
(96930, 4025, 26, 'Nessun file di log esistente per la data selezionata'),
(96931, 4027, 26, 'Non ci sono masse, sensibilità'),
(96932, 4028, 26, 'Non trovato alcun record Paziente corrispondente al codice di Re Identificazione fornito'),
(96933, 4029, 26, 'Nessuna corrispondenza trovata. Prova a cercare di nuovo.'),
(96934, 4030, 26, 'Nessuna corrispondenza trovata.'),
(96935, 4031, 26, 'Nessuna corrispondenza trovata. Creo il nuovo paziente adesso?'),
(96936, 4032, 26, 'Non ha prodotto risultati'),
(96937, 4033, 26, 'Nessun nuovo risultato trovato'),
(96938, 4034, 26, 'Nessuna nota'),
(96939, 4035, 26, 'Nessuna organomegalia'),
(96940, 4036, 26, 'Non è stata trovata alcuna apertura per questo periodo.'),
(96941, 4037, 26, 'Nessun altro numero di telefono elencato'),
(96942, 4038, 26, 'nessun parametro selezionato'),
(96943, 4039, 26, 'Non trovato alcun partner'),
(96944, 4040, 26, 'Non si è trovato alcun record con i criteri di selezione forniti'),
(96945, 4041, 26, 'Non si è trovato alcun record con il cosice di Re-identificazione fornito'),
(96946, 4042, 26, 'Assenza di edema periferico'),
(96947, 4043, 26, 'Nessuna Farmacia trovata'),
(96948, 4044, 26, 'Nessuna Prescrizione trovata'),
(96949, 4045, 26, 'Non presenta malattie/lesioni'),
(96950, 4046, 26, 'Nessuna immissione precedente.'),
(96951, 4047, 26, 'Nessuna attività principale selezionata nella lista struttura'),
(96952, 4048, 26, 'Nessun incontri precedenti.'),
(96953, 4049, 26, 'Non ci sono procedure in questo incontro.'),
(96954, 4051, 26, 'Nessun fornitore trovato'),
(96955, 4052, 26, 'Non ci sono rash o lesioni anomale'),
(96956, 4053, 26, 'Nessun record trovato'),
(96957, 4055, 26, 'Nessun record trovato. Espandi i criteri di ricerca.'),
(96958, 4056, 26, 'Non ci sono promemoria'),
(96959, 4057, 26, 'Nessun Risltato trovato, per i criteri di ricerca soprastanti.'),
(96960, 4058, 26, 'Nessun Risultato'),
(96961, 4059, 26, 'Nessun risultato trovato'),
(96962, 4060, 26, 'Nessun Risultato trovato con la ricerca'),
(96963, 4061, 26, 'Nessun risultato trovato, riprova.'),
(96964, 4062, 26, 'Nessun risultato, prova di nuovo.'),
(96965, 4063, 26, 'Nessun risultato, prova di nuovo.'),
(96966, 4064, 26, 'Nessun settaggio disponibile per questo modulo'),
(96967, 4065, 26, 'Non mostrare'),
(96968, 4066, 26, 'nessuna firma nel file'),
(96969, 4067, 26, 'Nessuna dolorabilità sinusale:'),
(96970, 4068, 26, 'Non ci sono fossette della pelle o noduli della mammella'),
(96971, 4069, 26, 'NOME DEL CONTESTO SENZA TITOLO'),
(96972, 4070, 26, 'Nessuna tabella selezionata! Seleziona tabella.'),
(96973, 4071, 26, 'Non ci sono dolorabilità testicolari, masse'),
(96974, 4072, 26, 'Non si eccita o non si solleva'),
(96975, 4073, 26, 'Nessuna traccia selezionata'),
(96976, 4074, 26, 'Nessuna traccia è stata documentata.'),
(96977, 4075, 26, 'Nessuna Visita'),
(96978, 4076, 26, 'Non è stato documentato nulla per i Vitali'),
(96979, 4077, 26, 'No, Annulla'),
(96980, 4078, 26, 'No-Guasto Assicurazione primaria in automatico'),
(96981, 4079, 26, 'No:'),
(96982, 4080, 26, 'Nicturia'),
(96983, 4081, 26, 'Non Pagato'),
(96984, 4082, 26, 'Nessun Report segnalato'),
(96985, 4083, 26, 'Lasione non specifica'),
(96986, 4084, 26, 'Non-elettronico'),
(96987, 4085, 26, 'Diabete non isulino dipendente'),
(96988, 4086, 26, 'Non-assicurato'),
(96989, 4087, 26, 'Non-SRH Medical'),
(96990, 4088, 26, 'Non-SRH Non-Medical'),
(96991, 4089, 26, 'Nessuno'),
(96992, 4090, 26, 'nessuno'),
(96993, 4091, 26, 'Niente di definito'),
(96994, 4092, 26, 'Nulla è stato documentato'),
(96995, 4093, 26, 'Nessuno dei soprastanti'),
(96996, 4094, 26, 'Nessuna delle riga di distribuzione superiore può essere completamente vuota.'),
(96997, 4095, 26, 'Diabete non insulino dipendente'),
(96998, 4096, 26, 'Norm.'),
(96999, 4097, 26, 'Normale'),
(97000, 4098, 26, 'Normale BL'),
(97001, 4099, 26, 'Esame Cardico Normale:'),
(97002, 4100, 26, 'Esame Cardico Normale: '),
(97003, 4101, 26, 'Esame polmonare normale:'),
(97004, 4102, 26, 'Esame polmonare normale: '),
(97005, 4103, 26, 'Visita in studio normale'),
(97006, 4104, 26, 'Orofaringe normale:'),
(97007, 4105, 26, 'Destro normale'),
(97008, 4106, 26, 'Destro normale:'),
(97009, 4107, 26, 'visualizzazione normale'),
(97010, 4108, 26, 'normale:'),
(97011, 4109, 26, 'Normalmente questo dovrebbe essere controllato. Non legato al controllo degli accessi.'),
(97012, 4110, 26, 'North Ndebele'),
(97013, 4111, 26, 'Northern Sami'),
(97014, 4112, 26, 'Norvegese'),
(97015, 4113, 26, 'Norwegian Bokmål'),
(97016, 4114, 26, 'Norwegian Nynorsk'),
(97017, 4115, 26, 'Naso'),
(97018, 4116, 26, 'Epistassi'),
(97019, 4117, 26, 'non una lettera o numero'),
(97020, 4119, 26, 'Non tutti i campi sono richesti per ogni codice o tipo di codice.'),
(97021, 4120, 26, 'Non Consentito'),
(97022, 4121, 26, 'Non è consentito eliminare il gruppo Amministratori'),
(97023, 4122, 26, 'Non Consentito Modificare'),
(97024, 4123, 26, 'Non è permesso disattivare tutti gli oggetti di protezione'),
(97025, 4124, 26, 'Non è consentito disattivare qualsiasi cosa, da ACL amministratori'),
(97026, 4125, 26, 'Non è consentito rimuovere l''utente amministratore dal gruppo Administrators'),
(97027, 4126, 26, 'Non è consentito rimuovere questo utente dal gruppo Administrators'),
(97028, 4127, 26, 'Non applicabile'),
(97029, 4128, 26, 'Non autorizzato ad accedere al modulo PostCalendar'),
(97030, 4129, 26, 'Non autorizzato'),
(97031, 4130, 26, 'Non Autorizzato'),
(97032, 4131, 26, 'Non autorizzato per questa squadra!'),
(97033, 4132, 26, 'Non autorizzato per questa squadra.'),
(97034, 4133, 26, 'Non autorizzato a gestire gli utenti!'),
(97035, 4134, 26, 'Non autorizzato a firmare i risultati'),
(97036, 4135, 26, 'Non Disponibile'),
(97037, 4137, 26, 'Non fatturato'),
(97038, 4138, 26, 'Non controllato'),
(97039, 4139, 26, 'Non controllato'),
(97040, 4140, 26, 'Non codificato'),
(97041, 4141, 26, 'Non dovuto'),
(97042, 4143, 26, 'Non Esaminato'),
(97043, 4144, 26, 'Non Esaminato:'),
(97044, 4145, 26, 'Non Esaminato: '),
(97045, 4146, 26, 'non trovato'),
(97046, 4148, 26, 'non trovato!'),
(97047, 4149, 26, 'Non ispanico o latino'),
(97048, 4150, 26, 'Non installato'),
(97049, 4151, 26, 'Non Installato'),
(97050, 4152, 26, 'Non visto dal'),
(97051, 4153, 26, 'Non inviato'),
(97052, 4154, 26, 'Non ancora inviato'),
(97053, 4155, 26, 'Non Specificato'),
(97054, 4156, 26, 'Non Specificato.'),
(97055, 4157, 26, 'Nota'),
(97056, 4158, 26, 'Codici nota'),
(97057, 4159, 26, 'Nota che dopo aver cliccato Installa saranno necessari 5-10 minuti per completare il processo'),
(97058, 4160, 26, 'Nota che dopo aver cliccato Aggiorna saranno necessari 5-10 minuti per completare il processo'),
(97059, 4161, 26, 'Si noti che la registrazione di controllo deve essere attivato al di sopra'),
(97060, 4162, 26, 'Tipo di Nota'),
(97061, 4163, 26, 'Nota: ore 12.00 è PM, non AM'),
(97062, 4164, 26, 'NOTA: Importazione di dati esterni può richiedere più di un''ora a seconda della configurazione hardware. Per esempio, una delle tabelle di dati contengono i RxNorm superiore a 6 milioni di righe.'),
(97063, 4165, 26, 'NOTA: Solo la Release Biennale Internazionale rilasciata di SNOMED è attualmente supportata'),
(97064, 4166, 26, 'NOTA: Solo la versione completa RxNorm mensile è attualmente supportata'),
(97065, 4168, 26, 'Nota: Questo codice non è stato inserito da un utente autorizzato. Solo i codici autorizzati possono essere caricati sull''Open Medical Billing Network per essere processati. Se desideri caricare questi codici, seleziona un utente autorizzato qui.'),
(97066, 4170, 26, 'NOTA: Il caricamento di file con nomi duplicati provoca la ridenominzione automatica (per esempio file.jpg diventerà file.1.jpg). I nomi dei file sono considerati unici per paziente, non per categoria.'),
(97067, 4171, 26, 'NOTA: il caricamento di file con nomi duplicati provoca la ridenominzione automatica. Per esempio ''<i>file.jpg</i>'' diventerà ''<i>file.1.jpg</i>''. I nomi dei file sono considerati unici per paziente, non per categoria.'),
(97068, 4172, 26, 'Note'),
(97069, 4173, 26, 'Note - qualsiasi incontro (scrittura,aggiungi opzionale)'),
(97070, 4174, 26, 'Note - i miei incontri (scrittura,aggiungi opzionale)'),
(97071, 4175, 26, 'Note non autorizzate'),
(97072, 4176, 26, 'Niente in sospeso da approvare'),
(97073, 4177, 26, 'Nessuna Registrazione'),
(97074, 4179, 26, 'Niente da importare per le Allergie'),
(97075, 4180, 26, 'Niente da importare per le Prescrizioni'),
(97076, 4181, 26, 'Ancora niente da mostrare'),
(97077, 4182, 26, 'Non è stato selezionato nulla'),
(97078, 4183, 26, 'Notizia ricevuta'),
(97079, 4184, 26, 'AVVISO:: PostCalendar Inserimento/Modifica'),
(97080, 4185, 26, 'Notifica'),
(97081, 4186, 26, 'Indirizzo email per notifiche'),
(97082, 4188, 26, 'Notifiche'),
(97083, 4189, 26, 'Notificare l''amministratore circa l''Inserimento/Modifica evento?'),
(97084, 4190, 26, 'Nov'),
(97085, 4191, 26, 'Novembre'),
(97086, 4192, 26, 'Sto inviando per:'),
(97087, 4193, 26, 'Sto stampando'),
(97088, 4194, 26, 'Ora stampo $stm_count dichiarazioni e aggiornamenti incontri.'),
(97089, 4195, 26, 'Ora stampo $stm_count dichiarazioni e aggiornamenti fatture.'),
(97090, 4196, 26, 'Ora stampo $stm_count dichiarazioni; gli incontri non verranno aggiornati'),
(97091, 4197, 26, 'Ora stampo $stm_count dichiarazioni; le fatture non verranno aggiornate'),
(97092, 4198, 26, 'NPI'),
(97093, 4199, 26, 'NQF'),
(97094, 4200, 26, 'Numero'),
(97095, 4201, 26, 'Numero di laboratori'),
(97096, 4204, 26, 'Numero di colonne della vista per anno.'),
(97097, 4211, 26, 'Numero di giorni che il certificato client è valido.'),
(97098, 4213, 26, 'Numero di cifre dopo il punto decimale per la moneta, di solito 0 o 2.'),
(97099, 4214, 26, 'Numero di incontri da mostrare per pagina.'),
(97100, 4215, 26, 'Numero di partite o eventi mancante, se alcuno'),
(97101, 4216, 26, 'Numero di ore di anticipo per inviare notifiche email.'),
(97102, 4217, 26, 'Numero di ore di anticipo per inviare notifiche telefoniche.'),
(97103, 4218, 26, 'Numero di ore di anticipo per inviare notifiche SMS.'),
(97104, 4221, 26, 'Numero di colonne per la cronologia'),
(97105, 4222, 26, 'Numero di pazienti da visualizzare per pagina nella lista pazienti'),
(97106, 4223, 26, 'Torpore'),
(97107, 4224, 26, 'Numeratore'),
(97108, 4225, 26, 'Ordine di visualizzazione numerico'),
(97109, 4226, 26, 'Nuosu'),
(97110, 4227, 26, 'Nutrizione'),
(97111, 4228, 26, 'Nutritivo'),
(97112, 4229, 26, 'O.A.F.V.'),
(97113, 4230, 26, 'O2 Sat'),
(97114, 4231, 26, 'Obesità I'),
(97115, 4232, 26, 'Obesità II'),
(97116, 4233, 26, 'Obesità III'),
(97117, 4234, 26, 'Obiettivo'),
(97118, 4236, 26, 'Occitan'),
(97119, 4237, 26, 'Occupazione'),
(97120, 4239, 26, 'Evento'),
(97121, 4240, 26, 'Ott'),
(97122, 4241, 26, 'Ottobre'),
(97123, 4242, 26, 'OD'),
(97124, 4243, 26, 'di'),
(97125, 4244, 26, 'di quantità'),
(97126, 4245, 26, 'di compresse'),
(97127, 4246, 26, 'del mese ogni'),
(97128, 4247, 26, 'Note Ofc'),
(97129, 4248, 26, 'Spento'),
(97130, 4249, 26, 'Note in studio'),
(97131, 4250, 26, 'Visita in studio'),
(97132, 4251, 26, 'Grppi Misure (CQM) Misure della qualità clinica Ufficiale'),
(97133, 4252, 26, 'Link https del Portale Paziente offsite'),
(97134, 4253, 26, 'Link https del Portale Paziente offsite(Link paziente)'),
(97135, 4254, 26, 'Password del Portale Paziente offsite'),
(97136, 4255, 26, 'Password del Portale Paziente offsite (lascia in bianco se non registrato)'),
(97137, 4256, 26, 'ID del Portale Paziente offsite'),
(97138, 4257, 26, 'ID del Portale Paziente offsite (lascia in bianco se non registrato)'),
(97139, 4258, 26, 'Indirizzo del sito Portale Paziente offsite'),
(97140, 4259, 26, 'Indirizzo del sito Portale Paziente offsite(Link paziente)'),
(97141, 4260, 26, 'Nome utente del Portale Paziente'),
(97142, 4261, 26, 'Nome utente del Portale Paziente (lascia in bianco se non registrato)'),
(97143, 4262, 26, 'Offsite Portal web Service Failed'),
(97144, 4263, 26, 'Progenie'),
(97145, 4264, 26, 'Storia della progenie'),
(97146, 4265, 26, 'pomata'),
(97147, 4266, 26, 'Ojibwe, Ojibwa'),
(97148, 4267, 26, 'OK'),
(97149, 4268, 26, 'OK per chiudere queste altre finestre?'),
(97150, 4269, 26, 'OK per collegare il problema del GCAC'),
(97151, 4270, 26, 'Vecchio'),
(97152, 4271, 26, 'Old Church Slavonic, Church Slavonic, Old Bulgarian'),
(97153, 4272, 26, 'Vecchi Clienti'),
(97154, 4273, 26, 'Nessuna vecchia frattura/malconsolidamento'),
(97155, 4274, 26, 'Layout vecchia maniera senza menu a sinistra'),
(97156, 4275, 26, 'Modulo statico vecchia maniera senza ricerca o controllo duplicati'),
(97157, 4276, 26, 'Vecchio'),
(97158, 4277, 26, 'Ometti'),
(97159, 4278, 26, 'Ometti circonferenza'),
(97160, 4279, 26, 'Ometti informazione datore di lavoro nella demografica pazienti'),
(97161, 4280, 26, 'Ometti datori di lavoro'),
(97162, 4281, 26, 'Ometti il modulo, via e intervallo che diventano parte del dosaggio'),
(97163, 4282, 26, 'Ometti assicurazione e alcune altre cose dal modulo democrafica'),
(97164, 4283, 26, 'Omettere gli utenti interni?'),
(97165, 4284, 26, 'Ometti il metodo di pagamento dal pannello co-pagamento'),
(97166, 4285, 26, 'omettere di auto assegnare'),
(97167, 4286, 26, 'acceso'),
(97168, 4287, 26, 'Acceso'),
(97169, 4288, 26, 'Alla mano'),
(97170, 4289, 26, 'Su ordinazione'),
(97171, 4290, 26, 'Sul posto'),
(97172, 4291, 26, 'Una volta che lo strumento Attività principale è impostato, non dovrebbe essere modificato. Modifica della struttura influenzerà il funzionamento in NewCrop sulle ricette mediche elettroniche.'),
(97173, 4292, 26, 'Dopo aver cambiato la password dovrai effettuare nuovamente l''ingresso.'),
(97174, 4297, 26, 'Supporto online'),
(97175, 4298, 26, 'Collegamento al supporto online'),
(97176, 4299, 26, 'Solo Attivi'),
(97177, 4300, 26, 'Applicabile solo se il provider o lista fascicolata è stato scelto sopra. PRIMARIA seleziona solo i pazienti che il provider è il fornitore primario. INCONTRO seleziona tutti i pazienti che il provider ha visto.'),
(97178, 4302, 26, 'solo se luogo di fatturazione'),
(97179, 4303, 26, 'Solo Inattivi'),
(97180, 4304, 26, 'Solo i propri'),
(97181, 4305, 26, 'Visualizza solo i codici di segnalazione di diagnosi'),
(97182, 4306, 26, 'Visualizza solo codice servizio di Reporting Finanza codicificati'),
(97183, 4307, 26, 'Caricare solo prescrizioni attive'),
(97184, 4309, 26, 'Insorgenza di sintomi attuali o Malattia'),
(97185, 4310, 26, 'Insorgenza della malattia:'),
(97186, 4311, 26, 'Insorgenza della malattia: '),
(97187, 4312, 26, 'Insorgenza di Gonfiore:'),
(97188, 4313, 26, 'Data arrivo in ospedale:'),
(97189, 4314, 26, 'Indirizzo del sito del Portale Paziente onsite'),
(97190, 4315, 26, 'Oops!'),
(97191, 4316, 26, 'Aperto'),
(97192, 4318, 26, 'Apri in una nuova finestra'),
(97193, 4319, 26, 'Apri paziente'),
(97194, 4321, 26, 'Apri la visita di oggi'),
(97195, 4322, 26, 'LibreEHR ha già configurato il Certificate Authority.'),
(97196, 4323, 26, 'LibreEHR Categoria Applicazione'),
(97197, 4324, 26, 'Aggiornamento Database di LibreEHR'),
(97198, 4325, 26, 'Aggiornamento Database di LibreEHR per la de-identificazione'),
(97199, 4326, 26, 'LibreEHR non riconosce il file in ingresso nella directory contrib. Questo è più probabile perché è necessario configurare la release nella tabella supported_external_dataloads nel database MySQL.'),
(97200, 4327, 26, 'LibreEHR deve essere configurato per usare i certificati prima che si possano creare i certificati client.'),
(97201, 4328, 26, 'LibreEHR richiede Javascript per attuare l''autenticazione dell''utente.'),
(97202, 4329, 26, 'Utenti LibreEHR'),
(97203, 4330, 26, 'Aperture'),
(97204, 4332, 26, 'Oftalmico'),
(97205, 4333, 26, 'Opzione'),
(97206, 4334, 26, 'Opzione per salvare metodo di archiviazione dei documenti.'),
(97207, 4335, 26, 'Opzioni di supporto alla giacenza e vendita di prodotti'),
(97208, 4336, 26, 'Opzionale'),
(97209, 4337, 26, 'Nome di categoria facoltativo per una immagine della ID Card visibile dalla pagina riassunto paziente.'),
(97210, 4338, 26, 'Nome di categoria facoltativo per le foto visibili dalla pagina riassunto paziente.'),
(97211, 4339, 26, 'Nome di categoria facoltativo di un documento collegato dalla pagina riassunto paziente. Consente di vedere le loro ID Card cliccando sul nome del paziente'),
(97212, 4340, 26, 'Intervallo facoltativo di default per immissione manuale dei risultati'),
(97213, 4341, 26, 'Unità facoltativa di default per immissione manuale dei risultati'),
(97214, 4342, 26, 'Nome destinazione opzionale'),
(97215, 4343, 26, 'Nome farmaco opzionale, usare % come carattere jolly'),
(97216, 4344, 26, 'Nome o codice immunizzazione opzionale, usare % come jolly'),
(97217, 4345, 26, 'Informazioni opzionali circa questo evento'),
(97218, 4346, 26, 'Numero lotto opzionale, usare % come carattere jolly'),
(97219, 4347, 26, 'ID numerico paziente, opzionale'),
(97220, 4348, 26, 'Codice procedura opzionale'),
(97221, 4349, 26, 'Procedura opzionale/codice servizio'),
(97222, 4350, 26, 'Opzioni'),
(97223, 4351, 26, 'O'),
(97224, 4352, 26, 'O'),
(97225, 4353, 26, 'o scegli'),
(97226, 4354, 26, 'o clicca e trascina per una selezione più veloce.'),
(97227, 4356, 26, 'o fuori per'),
(97228, 4357, 26, 'oppure seleziona dall''inventario'),
(97229, 4358, 26, 'o Maiuscolo-click per diminuire'),
(97230, 4359, 26, 'O carica il file ERA:'),
(97231, 4360, 26, 'Orale'),
(97232, 4361, 26, 'Mucosa orale rosa, gola chiara'),
(97233, 4362, 26, 'Ordine'),
(97234, 4363, 26, 'Tipi di ordine e risultati'),
(97235, 4364, 26, 'Catalogo ordine'),
(97236, 4365, 26, 'Data dell''Ordine'),
(97237, 4366, 26, 'Descrizione ordine'),
(97238, 4367, 26, 'Modulo Ordine'),
(97239, 4368, 26, 'ID Ordine'),
(97240, 4369, 26, 'Ordine deve essere un numero tra 1 e 999'),
(97241, 4370, 26, 'Nome dell''Ordine'),
(97242, 4371, 26, 'Priorità dell''Ordine'),
(97243, 4372, 26, 'Processore ordine'),
(97244, 4373, 26, 'Risultati ordine'),
(97245, 4374, 26, 'Stato Ordine'),
(97246, 4375, 26, 'Stati Ordine'),
(97247, 4376, 26, 'Sommario Ordine'),
(97248, 4377, 26, 'Tracce ordine'),
(97249, 4378, 26, 'Tipo di Ordine'),
(97250, 4380, 26, 'Tipo di Ordine/Risultato'),
(97251, 4381, 26, 'Ordinato'),
(97252, 4382, 26, 'Ordinato da'),
(97253, 4383, 26, 'Procedura Ordine'),
(97254, 4384, 26, 'Fornitore ordinazione'),
(97255, 4385, 26, 'Percorso Ordine'),
(97256, 4386, 26, 'Lesione all''organo'),
(97257, 4387, 26, 'Organizzazione'),
(97258, 4388, 26, 'Nome Organizzazione'),
(97259, 4389, 26, 'Nome dell''unità organizzativa'),
(97260, 4390, 26, 'Organizzazioni'),
(97261, 4391, 26, 'Orientato x 3'),
(97262, 4392, 26, 'Originale'),
(97263, 4393, 26, 'Checksum originale'),
(97264, 4394, 26, 'Oriya'),
(97265, 4395, 26, 'Oromo'),
(97266, 4396, 26, 'OROFARINGE: '),
(97267, 4397, 26, 'Ortopnea'),
(97268, 4398, 26, 'OS'),
(97269, 4399, 26, 'Osteoartrite'),
(97270, 4400, 26, 'Ossetian, Ossetic'),
(97271, 4401, 26, 'Osteopatia'),
(97272, 4402, 26, 'Altro'),
(97273, 4403, 26, 'altro'),
(97274, 4404, 26, 'Altro (specificare)'),
(97275, 4405, 26, 'Altro - Specificato'),
(97276, 4406, 26, 'Altro programma federale'),
(97277, 4407, 26, 'Altro HCFA'),
(97278, 4408, 26, 'Altra lesione non altrimenti specificata'),
(97279, 4409, 26, 'Altra responsabilità civile è primaria'),
(97280, 4410, 26, 'altro mese'),
(97281, 4411, 26, 'Altro programma non federale'),
(97282, 4412, 26, 'Altre Note'),
(97283, 4413, 26, 'Altri Sintomi Pertinenti'),
(97284, 4414, 26, 'Altri Sintomi Pertinenti:'),
(97285, 4415, 26, 'Altre risp pz'),
(97286, 4416, 26, 'Altro stress/sopra le lesioni'),
(97287, 4417, 26, 'Altro intervento'),
(97288, 4418, 26, 'Altro/Aborto correlato generico'),
(97289, 4420, 26, 'Altri'),
(97290, 4421, 26, 'altrimenti distruggerai i riferimenti a/da altri dati esistenti'),
(97291, 4422, 26, 'Regole caviglie di Ottawa'),
(97292, 4423, 26, 'OU'),
(97293, 4424, 26, 'FUORI ufficio'),
(97294, 4425, 26, 'Fuori ufficio'),
(97295, 4426, 26, 'Competenza in uscita'),
(97296, 4427, 26, 'Esito'),
(97297, 4428, 26, 'Outlook'),
(97298, 4429, 26, 'Tipo di uscita'),
(97299, 4430, 26, 'Stato generale di dimissione'),
(97300, 4431, 26, 'IN RITARDO'),
(97301, 4432, 26, 'Abuso'),
(97302, 4433, 26, 'Panoramica'),
(97303, 4434, 26, 'Sovrappeso'),
(97304, 4435, 26, 'Sovrascrivi scelta HIPAA'),
(97305, 4437, 26, 'Saturazione Ossigeno'),
(97306, 4438, 26, 'oz'),
(97307, 4439, 26, 'P'),
(97308, 4440, 26, 'p.c.'),
(97309, 4441, 26, 'p.m.'),
(97310, 4442, 26, 'p.r.n.'),
(97311, 4443, 26, 'Delle Isole del Pacifico'),
(97312, 4444, 26, 'Pediatrico'),
(97313, 4445, 26, 'Pagina'),
(97314, 4446, 26, 'Pagine'),
(97315, 4447, 26, 'Pagato'),
(97316, 4448, 26, 'Importo pagato che allocherai'),
(97317, 4449, 26, 'Ammontare pagato'),
(97318, 4450, 26, 'Pagato Via'),
(97319, 4451, 26, 'Dolore'),
(97320, 4453, 26, 'Palpitazione'),
(97321, 4454, 26, 'Panjabi, Punjabi'),
(97322, 4455, 26, 'Pap-Test'),
(97323, 4456, 26, 'Carta'),
(97324, 4457, 26, 'Dimesione carta'),
(97325, 4458, 26, 'Paralisi'),
(97326, 4459, 26, 'Genitore'),
(97327, 4461, 26, 'Analizzare HL7'),
(97328, 4463, 26, 'Partner'),
(97329, 4464, 26, 'Nome del partner'),
(97330, 4466, 26, 'Pashto, Pushto'),
(97331, 4467, 26, 'Frase chiave');
INSERT INTO `lang_definitions` VALUES
(97332, 4468, 26, 'Frase chiave per decrittare il documento'),
(97333, 4469, 26, 'Pazienti pregressi'),
(97334, 4470, 26, 'Allarme passivo'),
(97335, 4471, 26, 'Regole di allarme passivo'),
(97336, 4472, 26, 'Password'),
(97337, 4473, 26, 'Modifica Password'),
(97338, 4474, 26, 'Password modificata con successo'),
(97339, 4475, 26, 'Password modificata con successo.'),
(97340, 4476, 26, 'La Password non soddisfa i requisiti minimi e deve contenere almeno tre dei quattro elementi seguenti: un numero, una lettera minuscola, una lettera maiuscola, un carattere speciale (non una lettera o un numero).'),
(97341, 4477, 26, 'Periodo di grazia dalla scadenza della password'),
(97342, 4479, 26, 'Password per Gateway Phone. Servizio Automatizzato VOIP fornito da Maviq. Si prega di visitare http://signup.maviq.com per ulteriori informazioni.'),
(97343, 4480, 26, 'Password per il Gateway SMS'),
(97344, 4481, 26, 'Password per il Gateway SMS.'),
(97345, 4482, 26, 'Password dell''utente sopra'),
(97346, 4483, 26, 'La sicurezza delle password è stata recentemente aggiornata'),
(97347, 4484, 26, 'Password per connettersi al CouchDB'),
(97348, 4485, 26, 'Password troppo corta. Minimo 8 caratteri richiesti.'),
(97349, 4486, 26, 'Password:'),
(97350, 4487, 26, 'La Password non coincide!'),
(97351, 4488, 26, 'Appuntamenti scaduti'),
(97352, 4489, 26, 'Mostra Widget appuntamenti scaduti'),
(97353, 4490, 26, 'Scaduti'),
(97354, 4491, 26, 'Scaduti'),
(97355, 4492, 26, 'Intervallo scaduto(Promemoria clinici)'),
(97356, 4493, 26, 'Intervallo scaduto(Promemoria pazienti)'),
(97357, 4494, 26, 'Elenco incontri precedenti'),
(97358, 4495, 26, 'Incontri precedenti'),
(97359, 4496, 26, 'Incontri e Documenti precedenti'),
(97360, 4497, 26, 'Incontri precedenti per'),
(97361, 4498, 26, 'Incolla dati HL7'),
(97362, 4499, 26, 'Incolla i dati da importare nell''area sottostante:'),
(97363, 4500, 26, 'Pat'),
(97364, 4502, 26, 'Patch'),
(97365, 4508, 26, 'Path for Event Log Backup'),
(97366, 4509, 26, 'Path to CA Certificate File'),
(97367, 4510, 26, 'Path to CA Key File'),
(97368, 4511, 26, 'Path to MySQL Binaries'),
(97369, 4512, 26, 'Path to Perl Binaries'),
(97370, 4513, 26, 'Path to Temporary Files'),
(97371, 4514, 26, 'Paziente'),
(97372, 4515, 26, 'paziente'),
(97373, 4516, 26, 'PAZIENTE'),
(97374, 4517, 26, 'Indirizzo Paziente'),
(97375, 4518, 26, 'L''indirizzo del paziente è mancante'),
(97376, 4521, 26, 'Allergie del paziente'),
(97377, 4522, 26, 'Allergie del Paziente'),
(97378, 4523, 26, 'Appuntamento del Paziente'),
(97379, 4524, 26, 'Bilancio del paziente'),
(97380, 4525, 26, 'Paziente Saldo dovuto'),
(97381, 4528, 26, 'ID Tabulato Paziente'),
(97382, 4529, 26, 'Checkout paziente'),
(97383, 4530, 26, 'Checkout paziente '),
(97384, 4531, 26, 'Città del Paziente'),
(97385, 4532, 26, 'Manca la città del paziente'),
(97386, 4533, 26, 'Comunicazione al Paziente inviata'),
(97387, 4534, 26, 'Comunicazione al Paziente Inviata'),
(97388, 4535, 26, 'Nazione del Paziente'),
(97389, 4536, 26, 'Manca il Paese del paziente. Inoltre non è stato settato di default il Paese del paziente nei settaggi globali'),
(97390, 4537, 26, 'Copertura paziente'),
(97391, 4539, 26, 'Dati del Paziente'),
(97392, 4541, 26, 'Manca la data di nascita del paziente'),
(97393, 4542, 26, 'Dettagli del Paziente'),
(97394, 4543, 26, 'Nasc. Paziente'),
(97395, 4544, 26, 'Documento del Paziente'),
(97396, 4545, 26, 'Educazione del Paziente'),
(97397, 4546, 26, 'Materiali per l''Educazione del Paziente'),
(97398, 4547, 26, 'Incontro Paziente'),
(97399, 4548, 26, 'Modulo incontro Paziente'),
(97400, 4549, 26, 'Incontri Paziente'),
(97401, 4550, 26, 'Trova Paziente'),
(97402, 4551, 26, 'Nome del Paziente'),
(97403, 4553, 26, 'Manca il nome del paziente'),
(97404, 4558, 26, 'Sesso del Paziente'),
(97405, 4559, 26, 'Manca il sesso del paziente'),
(97406, 4560, 26, 'Il Paziente non ha autorizzato il Portale paziente'),
(97407, 4561, 26, 'Storico del Paziente'),
(97408, 4562, 26, 'Storico / Stile di vita del Paziente'),
(97409, 4563, 26, 'Telefono Casa Paziente'),
(97410, 4564, 26, 'ID Paziente'),
(97411, 4565, 26, 'Id paziente'),
(97412, 4566, 26, 'ID carta Paziente'),
(97413, 4567, 26, 'ID nome categoria Paziente'),
(97414, 4568, 26, 'Immunizzazione Paziente'),
(97415, 4569, 26, 'Informazione del Paziente'),
(97416, 4570, 26, 'Instruzioni del Paziente'),
(97417, 4571, 26, 'Distribuzione assicurativa paziente'),
(97418, 4572, 26, 'Report distribuzione assicurativa del paziente'),
(97419, 4573, 26, 'Tematiche Paziente'),
(97420, 4574, 26, 'Tipo di etichetta per il paziente'),
(97421, 4575, 26, 'Cognome del Paziente'),
(97422, 4577, 26, 'Manca il cognome del paziente'),
(97423, 4581, 26, 'Elenco dei Pazienti'),
(97424, 4582, 26, 'Lista colonne paziente'),
(97425, 4584, 26, 'Lista nuova finestra paziente'),
(97426, 4585, 26, 'Lista dimensione pagina paziente'),
(97427, 4586, 26, 'Revisione errori Paziente'),
(97428, 4587, 26, 'Problemi Medici del Paziente'),
(97429, 4588, 26, 'Medicazioni del Paziente'),
(97430, 4589, 26, 'Nome del Paziente'),
(97431, 4590, 26, 'Nome e Indirizzo del Paziente'),
(97432, 4593, 26, 'Nome del Paziente Richiesto'),
(97433, 4595, 26, 'Nota del Paziente'),
(97434, 4596, 26, 'Tipi di Nota del Paziente'),
(97435, 4597, 26, 'Note del Paziente'),
(97436, 4598, 26, 'Note Paziente (scrittura,aggiungi opzionale)'),
(97437, 4599, 26, 'Numero del Paziente'),
(97438, 4600, 26, 'Pagamento del Paziente'),
(97439, 4602, 26, 'Nome categoria foto Paziente'),
(97440, 4603, 26, 'Portale del Paziente'),
(97441, 4604, 26, 'problema di connessione al portale del paziente'),
(97442, 4605, 26, 'Il Portale del Paziente è spento'),
(97443, 4606, 26, 'Login del Portale del Paziente'),
(97444, 4607, 26, 'Indirizzo web del Portale del Paziente'),
(97445, 4608, 26, 'Resoconto stampato del Paziente'),
(97446, 4609, 26, 'Resoconto stampato del Paziente'),
(97447, 4610, 26, 'Richiesta di record del Paziente'),
(97448, 4611, 26, 'Richiesta di record del Paziente'),
(97449, 4613, 26, 'Promemoria Paziente'),
(97450, 4614, 26, 'Batch job promemoria paziente'),
(97451, 4615, 26, 'Paziente Promemoria Creazione elaborazione prioritaria'),
(97452, 4616, 26, 'Regole per i Promemoria al Paziente'),
(97453, 4617, 26, 'Email mittente Promemoria al Paziente'),
(97454, 4618, 26, 'Nome mittente Promemoria al Paziente'),
(97455, 4619, 26, 'Promemoria al Paziente'),
(97456, 4620, 26, 'Resoconto Paziente'),
(97457, 4621, 26, 'Richiesta del Paziente'),
(97458, 4622, 26, 'Record Medici richiesti dal Paziente'),
(97459, 4623, 26, 'Risultati del Paziente'),
(97460, 4624, 26, 'Stile della ricerca del paziente'),
(97461, 4625, 26, 'Schermata Cerca/Aggiungi Paziente'),
(97462, 4626, 26, 'Specifiche del Paziente'),
(97463, 4627, 26, 'Stato del Paziente'),
(97464, 4629, 26, 'Sommario del Paziente'),
(97465, 4630, 26, 'Transazioni del Paziente'),
(97466, 4631, 26, 'CAP del Paziente'),
(97467, 4632, 26, 'pazienti nel database che corrispondono alla informazione demografica che hai fornito.'),
(97468, 4633, 26, 'Paziente/Cliente'),
(97469, 4634, 26, 'Paziente:'),
(97470, 4635, 26, 'IDPaziente'),
(97471, 4636, 26, 'Pazienti'),
(97472, 4637, 26, 'Pazienti elaborati'),
(97473, 4638, 26, 'Pagare'),
(97474, 4639, 26, 'Prestare attenzione alle caselle di controllo "Fatto con". Dopo che le assicurazioni sono state contrassegnate, cominceremo chiedendo al paziente di pagare la quota rimanente, se non si riesce a segnare tutte le assicurazioni, l''importo residuo non sarà raccolto.Anche se vi è un equilibrio che il paziente deve pagare, è bene impostare la data di scadenza in modo appropriato, in quanto questo influenzerà la lingua che appare sulle dichiarazioni dei pazienti.'),
(97475, 4640, 26, 'Data pagamento'),
(97476, 4641, 26, 'Status pagamento'),
(97477, 4642, 26, 'Nome beneficiario'),
(97478, 4643, 26, 'Pagante'),
(97479, 4644, 26, 'Tipo del pagante'),
(97480, 4645, 26, 'Sta pagando'),
(97481, 4646, 26, 'Entità che paga'),
(97482, 4647, 26, 'Pagamento'),
(97483, 4648, 26, 'pagamento'),
(97484, 4649, 26, 'Codice rimodulazione pagamento'),
(97485, 4650, 26, 'pagamento contro'),
(97486, 4651, 26, 'Importo pagamento'),
(97487, 4652, 26, 'L''importo del pagamento deve essere numerico'),
(97488, 4653, 26, 'Categoria Pagamento'),
(97489, 4654, 26, 'Data Pagamento'),
(97490, 4655, 26, 'pagamento registrato il'),
(97491, 4656, 26, 'Pagamento da'),
(97492, 4657, 26, 'Gateway di pagamento'),
(97493, 4658, 26, 'Pagamento da'),
(97494, 4659, 26, 'Elenco pagamenti'),
(97495, 4660, 26, 'Metodo Pagamento'),
(97496, 4661, 26, 'Pagamenti ordinati per'),
(97497, 4662, 26, 'Status Pagamenti'),
(97498, 4663, 26, 'Tipo Pagamento'),
(97499, 4664, 26, 'Valore pagamento per il codice '),
(97500, 4665, 26, 'Pagamenti'),
(97501, 4667, 26, 'PCP'),
(97502, 4668, 26, 'Pct (%) di righe'),
(97503, 4669, 26, 'PDF'),
(97504, 4670, 26, 'PDF Download Dichiarazioni selezionate'),
(97505, 4671, 26, 'Linguaggio PDF'),
(97506, 4672, 26, 'Bacino e Glutei'),
(97507, 4673, 26, 'Pemfigo'),
(97508, 4674, 26, 'Pendente'),
(97509, 4675, 26, 'Approvazioni in sospeso'),
(97510, 4676, 26, 'F/U pendente'),
(97511, 4677, 26, 'Followup pendente'),
(97512, 4678, 26, 'Risultati del followup pendenti'),
(97513, 4679, 26, 'Ordini pendenti'),
(97514, 4680, 26, 'Res pendente'),
(97515, 4681, 26, 'Revisione pendente'),
(97516, 4682, 26, 'In attesa di conteggio Rx'),
(97517, 4684, 26, 'Pennington Firm LibreEHR v'),
(97518, 4685, 26, 'Ulcera Peptica'),
(97519, 4686, 26, 'Per incontro'),
(97520, 4687, 26, 'al minuto'),
(97521, 4688, 26, 'Via Nasale'),
(97522, 4689, 26, 'via nasale'),
(97523, 4690, 26, 'Via Orale'),
(97524, 4691, 26, 'via orale'),
(97525, 4692, 26, 'Via rettale'),
(97526, 4693, 26, 'via rettale'),
(97527, 4694, 26, 'Per cento'),
(97528, 4697, 26, 'Percentile'),
(97529, 4698, 26, 'Perforazione destra:'),
(97530, 4699, 26, 'Attua la ricerca'),
(97531, 4700, 26, 'Attua questa azione'),
(97532, 4701, 26, 'Percentuale della performance'),
(97533, 4703, 26, 'Esecuzione di struttura di laboratorio'),
(97534, 4705, 26, 'Punto'),
(97535, 4706, 26, 'Periodo in giorni durante il quale un utente può effettuare l''ingresso con una password scaduta.'),
(97536, 4707, 26, 'assistenza perioperatoria'),
(97537, 4708, 26, 'Periferico(a)'),
(97538, 4709, 26, 'Permetti salto password'),
(97539, 4710, 26, 'Persiano'),
(97540, 4711, 26, 'Persian (Farsi)'),
(97541, 4712, 26, 'Persona'),
(97542, 4713, 26, 'Personalizza'),
(97543, 4714, 26, 'PG'),
(97544, 4715, 26, 'Farm'),
(97545, 4716, 26, 'Pharm Com Count'),
(97546, 4717, 26, 'Farmacie'),
(97547, 4718, 26, 'Farmacia'),
(97548, 4719, 26, 'Dispensario della farmacia'),
(97549, 4720, 26, 'Pneumotorace'),
(97550, 4721, 26, 'phiMail Allow CCD Send'),
(97551, 4722, 26, 'phiMail Allow CCR Send'),
(97552, 4723, 26, 'phiMail controllo intervallo messaggi (minuti)'),
(97553, 4724, 26, 'phiMail notifica utente'),
(97554, 4725, 26, 'phiMail Password'),
(97555, 4726, 26, 'phiMail indirizzo del server'),
(97556, 4727, 26, 'phiMail nome utente'),
(97557, 4729, 26, 'Telefono'),
(97558, 4730, 26, 'Elenco choamate telefoniche'),
(97559, 4731, 26, 'Report lista chiamate telefoniche'),
(97560, 4732, 26, 'Cellulare'),
(97561, 4733, 26, 'Password per Gateway Telefonico'),
(97562, 4734, 26, 'URL del Gateway Telefonico'),
(97563, 4735, 26, 'Nome utente per il Gateway Telefonico'),
(97564, 4736, 26, 'Telefono abitazione'),
(97565, 4737, 26, 'Ore per la Notifica via Telefono'),
(97566, 4738, 26, 'Numero di Telefono'),
(97567, 4739, 26, 'Numero di telefono'),
(97568, 4740, 26, 'Fotofobia'),
(97569, 4741, 26, 'Foto'),
(97570, 4742, 26, 'PHP compresso'),
(97571, 4743, 26, 'Il modulo CURL PHP dovrebbe essere abilitato sul server.'),
(97572, 4744, 26, 'PHP estratto'),
(97573, 4745, 26, 'I controlli di accesso php-GACL sono disabilitati'),
(97574, 4746, 26, 'PHP-gacl non è installato'),
(97575, 4747, 26, 'Esame fisico'),
(97576, 4749, 26, 'Richiesta medica'),
(97577, 4750, 26, 'Firma del medico'),
(97578, 4752, 26, 'Medici'),
(97579, 4753, 26, 'scelta'),
(97580, 4754, 26, 'Scelta'),
(97581, 4755, 26, 'Scegli un tema CSS'),
(97582, 4756, 26, 'PID'),
(97583, 4757, 26, 'PID (malattia infiammatoria pelvica)'),
(97584, 4758, 26, 'Dimensione pillola'),
(97585, 4759, 26, 'Pillole'),
(97586, 4760, 26, 'Colloca il file zip del database nella seguente directory se si vuole  installare'),
(97587, 4761, 26, 'Colloca il file zip del database ICD10 nella seguente directory'),
(97588, 4762, 26, 'Colloca il file zip del database ICD9 nella seguente directory'),
(97589, 4763, 26, 'Colloca il file zip del database RxNormal nella seguente directory'),
(97590, 4764, 26, 'Colloca il file zip del database Snomed nella seguente directory'),
(97591, 4765, 26, 'Segnaposto'),
(97592, 4766, 26, 'Segnaposto (Mantiene in bianco le ACL)'),
(97593, 4767, 26, 'Solo testo'),
(97594, 4768, 26, 'Piano'),
(97595, 4771, 26, 'Nome del Piano'),
(97596, 4775, 26, 'Piano prestabilito'),
(97597, 4779, 26, 'Piano:'),
(97598, 4782, 26, 'Piani'),
(97599, 4784, 26, 'Giocatore'),
(97600, 4785, 26, 'Posizione di gioco'),
(97601, 4786, 26, 'Si pega di telefona se qualcuna delle informatìzioni soprastanti non è corretta'),
(97602, 4787, 26, 'Cambiare la Password.'),
(97603, 4788, 26, 'Scegli un file'),
(97604, 4789, 26, 'Scegli un paziente'),
(97605, 4790, 26, 'Scegli dall''elenco una selezione valida.'),
(97606, 4791, 26, 'Scegli una selezione valida.'),
(97607, 4792, 26, 'Scegli un valore per'),
(97608, 4793, 26, 'Scegli sopra un intervallo di criteri, e clicca Refresh per vedere i risultati'),
(97609, 4794, 26, 'Scegli il file appropriato formattato EDI-271'),
(97610, 4795, 26, 'Clicca il pulsante Scarica per scaricare i data De-identificati'),
(97611, 4796, 26, 'Clicca il pulsante Scarica per scaricare i data Re-identificati'),
(97612, 4797, 26, 'Chiudi questa finestra.'),
(97613, 4798, 26, 'Confronta il nuvo nome'),
(97614, 4800, 26, 'Per favore correggi il valore(i) prima di procedere!'),
(97615, 4801, 26, 'Si prega di creare la seguente directory prima di procedere'),
(97616, 4802, 26, 'Non accettare questa prescrizione a meno che non sia stata ricevuta via facsimile'),
(97617, 4803, 26, 'Non accettare questa prescrizione a meno che non sia stata ricevuta via facsimile'),
(97618, 4804, 26, 'Non usare il pulsante di stop o ricarica del browser mentre sta funzoinando questa pagina a meno che non siano passati più di 10 minuti, così non causerai l''arresto del processo sul server non consumerai risorse non necessarie.'),
(97619, 4805, 26, 'ATTIVARE ESTENSIONE CURL'),
(97620, 4806, 26, 'ATTIVARE ESTENSIONE OPENSSL'),
(97621, 4807, 26, 'ATTIVARE ESTENSIONE SOAP'),
(97622, 4808, 26, 'ATTIVARE ESTENSIONE XML'),
(97623, 4809, 26, 'Inserisci la data dell''ultima revisione.'),
(97624, 4810, 26, 'Inserisci una data.'),
(97625, 4811, 26, 'Si prega di inserire una data di scadenza'),
(97626, 4812, 26, 'Inserire un messaggio'),
(97627, 4813, 26, 'Inserisci un importo monetario usando soltanto numeri e un punto decimale.'),
(97628, 4814, 26, 'Inserisci una Nuova Password'),
(97629, 4815, 26, 'Inserisci un titolo!'),
(97630, 4816, 26, 'Inserisci, sopra,  un valido indirizzo diretto.'),
(97631, 4817, 26, 'Si prega di inserire almeno il nome dell''elemento'),
(97632, 4818, 26, 'Si prega di inserire almeno il nome della traccia'),
(97633, 4819, 26, 'Inserisci il corretto codice di Re-identificazione'),
(97634, 4820, 26, 'Inserire fine data maggiore di inizio data!'),
(97635, 4821, 26, 'Inserisci una nuova stringa di ricerca'),
(97636, 4822, 26, 'Inserisci il corretto codice di Re-identificazione'),
(97637, 4823, 26, 'Inserisci la password'),
(97638, 4824, 26, 'Compila il numero di assegno'),
(97639, 4825, 26, 'Si prega di compilare il Check/Ref Number'),
(97640, 4826, 26, 'Compila la data'),
(97641, 4827, 26, 'Compila l''importo del pagamento'),
(97642, 4828, 26, 'Compila la categoria del pagamento'),
(97643, 4829, 26, 'Compila il pagamento Da'),
(97644, 4830, 26, 'Compila l''Invia alla Data'),
(97645, 4831, 26, 'Compilali prima di continuare'),
(97646, 4832, 26, 'Indica il motivo della visita'),
(97647, 4833, 26, 'Inserisci, sopra, i criteri di ricerca, e clic su Invia per far partire il report.'),
(97648, 4834, 26, 'Inserisci i soprastanti criteri di ricerca, e clicca Invia per vedere i risultati.'),
(97649, 4835, 26, 'Inserisci i criteri di ricerca soprastanti, e clicca Invia per vedere i risulati. (I risultati saranno mostrati in una finestra di tipo pop up)'),
(97650, 4836, 26, 'Effettua nuovamente l''ingresso.'),
(97651, 4837, 26, 'Si noti che questo può durare parecchio tempo, fino a diversi minuti, durante questo tempo il browser potrebbe sembrare non attivo ma generare una fattura è un processo complesso e il tuo browser è semplicemente in attesa di maggiori informazioni.'),
(97652, 4838, 26, 'Nota: usando lettere maiuscole e minuscole si identificano costanti diverse ed è consentita qualsiasi stringa.'),
(97653, 4839, 26, 'Usare soltanto caratteri alfabetici senza spazi'),
(97654, 4840, 26, 'Usa solo caratteri alfabetici senza spazi.'),
(97655, 4841, 26, 'Paga questo importo'),
(97656, 4842, 26, 'Si prega di inserire i file di installazione nella directory seguente'),
(97657, 4843, 26, 'Si prega di fare riferimento al'),
(97658, 4844, 26, 'Ridefinisci la password.'),
(97659, 4845, 26, 'Riavvia il server apache prima di iniziare la de-identificazione'),
(97660, 4846, 26, 'Per favore vedi il PDF allegato.'),
(97661, 4847, 26, 'Si prega selezionare'),
(97662, 4849, 26, 'Seleziona una lingua'),
(97663, 4850, 26, 'Seleziona un Paziente'),
(97664, 4851, 26, 'Si prega di selezionare una funzione di primaria entità affari con la ''partita IVA'' come ID struttura fiscale. Se sei un professionista individuale, utilizzare il Codice Fiscale. Questo è usato per identificare voi nel sistema NewCrop.'),
(97665, 4853, 26, 'Si prega di selezionare un fornitore di procedura'),
(97666, 4854, 26, 'Si prega di selezionare un destinatario'),
(97667, 4855, 26, 'Seleziona una data di inizio e di fine'),
(97668, 4856, 26, 'Si prega di selezionare un destinatario valido'),
(97669, 4857, 26, 'Si prega selezionare il gruppo attivo'),
(97670, 4858, 26, 'Si prega di selezionare un motivo di adeguamento per il codice '),
(97671, 4859, 26, 'Seleziona un evento'),
(97672, 4860, 26, 'Seleziona qualche opzione di ricerca.'),
(97673, 4863, 26, 'Seleziona almeno una prescrizione!'),
(97674, 4864, 26, 'Seleziona l''incontro'),
(97675, 4865, 26, 'Seleziona le pagine che desideri copiare o inoltrare:'),
(97676, 4866, 26, 'Seleziona il metodo di pagamento'),
(97677, 4867, 26, 'Seleziona il tipo di pagamento'),
(97678, 4868, 26, 'Seleziona la categoria di visita'),
(97679, 4869, 26, 'Selezionare il partner X12, richiesto per creare il batch 270'),
(97680, 4870, 26, 'Si prega di impostare'),
(97681, 4871, 26, 'Assegna di nuovo 0 alla variabile de_identification_config'),
(97682, 4873, 26, 'Devi riavviare il processo di De-Identificazione'),
(97683, 4874, 26, 'Aggiorna il database LibreEHR per includere le procedure, funzioni e tabelle per la De-Identificazione'),
(97684, 4875, 26, 'Per maggiori dettagli guarda la tabella dei log degli errori della De-Identificazione'),
(97685, 4876, 26, 'Visita tra un po'' di tempo la schermata della De-Identificazione'),
(97686, 4877, 26, 'Visita tra un po'' di tempo la schermata della Re-Identificazione'),
(97687, 4878, 26, 'Visita la schermata tra un po'' di tempo'),
(97688, 4879, 26, 'Plot item'),
(97689, 4880, 26, 'Plot selected Items'),
(97690, 4881, 26, 'Plurale'),
(97691, 4882, 26, 'PM'),
(97692, 4883, 26, 'Programma PM'),
(97693, 4884, 26, 'Metodo Pgmt'),
(97694, 4885, 26, 'PND'),
(97695, 4886, 26, 'Pneumococco Coniugato 1'),
(97696, 4887, 26, 'Pneumococco Coniugato 2'),
(97697, 4888, 26, 'Pneumococco Coniugato 3'),
(97698, 4889, 26, 'Pneumococco Coniugato 4'),
(97699, 4890, 26, 'Vaccino per Pneumococco'),
(97700, 4891, 26, 'Vaccinazione per Pneumococco'),
(97701, 4892, 26, 'Polmonite stato vaccinale per gli anziani'),
(97702, 4893, 26, 'Polmonite stato vaccinale per gli anziani (CQM)'),
(97703, 4894, 26, 'Podologica'),
(97704, 4895, 26, 'Podologia'),
(97705, 4896, 26, 'Punto di servizio (POS)'),
(97706, 4897, 26, 'Regola'),
(97707, 4898, 26, 'Regola Nr'),
(97708, 4899, 26, 'Numero regola'),
(97709, 4900, 26, 'Polacco'),
(97710, 4901, 26, 'Polidipsia'),
(97711, 4902, 26, 'Polipo'),
(97712, 4903, 26, 'Poliuria'),
(97713, 4904, 26, 'Scarso appetito'),
(97714, 4905, 26, 'Cattiva circolazione'),
(97715, 4906, 26, 'Scarso udito'),
(97716, 4907, 26, 'Per vedere questi resoconti è necessario abilitare le finestre popup'),
(97717, 4908, 26, 'Riempio l''anno con gli eventi?'),
(97718, 4909, 26, 'Popup'),
(97719, 4910, 26, 'Portale'),
(97720, 4911, 26, 'Attività del portale'),
(97721, 4912, 26, 'ID portale'),
(97722, 4913, 26, 'ID del portale non combacia con quello richiesto dal portale!'),
(97723, 4914, 26, 'Manca la password del portale'),
(97724, 4915, 26, 'Richieste al portale'),
(97725, 4916, 26, 'Verticale'),
(97726, 4917, 26, 'Portoghese'),
(97727, 4918, 26, 'Portoghese (Brasiliano)'),
(97728, 4919, 26, 'Portoghese (Europeo)'),
(97729, 4920, 26, 'Codice POS'),
(97730, 4921, 26, 'Posizione'),
(97731, 4922, 26, 'Positivo'),
(97732, 4923, 26, 'Positivi'),
(97733, 4925, 26, 'Messaggio per'),
(97734, 4926, 26, 'Gocciolamento nasale'),
(97735, 4927, 26, 'Pagamenti posticipati'),
(97736, 4928, 26, 'Portchirurgico'),
(97737, 4929, 26, 'Posta alla contabilità e contrassegnare come fatturato'),
(97738, 4930, 26, 'Invio alla data'),
(97739, 4931, 26, 'Invio alla data non può essere maggiore di Oggi'),
(97740, 4932, 26, 'Messaggio Per data deve essere maggiore della data Financial Close.'),
(97741, 4933, 26, 'Cure post-aborto'),
(97742, 4934, 26, 'Contraccezione post-aborto'),
(97743, 4935, 26, 'Consulenza post-aborto'),
(97744, 4936, 26, 'Followup post-aborto'),
(97745, 4937, 26, 'Postale'),
(97746, 4938, 26, 'Codice Postale'),
(97747, 4939, 26, 'Codice postale'),
(97748, 4941, 26, 'PostCalendar'),
(97749, 4942, 26, 'PostCalendar Administration'),
(97750, 4943, 26, 'PostCalendar Category Settings'),
(97751, 4944, 26, 'PostCalendar Global Settings'),
(97752, 4945, 26, 'Inviato il'),
(97753, 4946, 26, 'Data di invio'),
(97754, 4947, 26, 'Pos{{Abbreviation for Position}}'),
(97755, 4948, 26, 'Powered by'),
(97756, 4949, 26, 'PPE + Prev Med/Surg Hx'),
(97757, 4950, 26, 'PQRI'),
(97758, 4951, 26, 'PQRI Registry ID'),
(97759, 4952, 26, 'PQRI Registry Name'),
(97760, 4953, 26, 'Pratica'),
(97761, 4954, 26, 'Impostazioni predefinite Pratica'),
(97762, 4955, 26, 'Impostazioni pratica'),
(97763, 4956, 26, 'Professionista/Medico'),
(97764, 4957, 26, 'Pre Partecipazione di valutazione'),
(97765, 4958, 26, 'Pre-pagato'),
(97766, 4959, 26, 'Anticipo'),
(97767, 4960, 26, 'Consulto pre-aborto'),
(97768, 4961, 26, 'Consulenza pre-aborto'),
(97769, 4962, 26, 'Pref Cat'),
(97770, 4963, 26, 'Preferenza'),
(97771, 4964, 26, 'Preferenze'),
(97772, 4965, 26, 'Categoria evento preferita'),
(97773, 4966, 26, 'Lingua preferita'),
(97774, 4967, 26, 'Farmacia preferita'),
(97775, 4968, 26, 'Fornitore Organizzazione preferito (PPO)'),
(97776, 4969, 26, 'Test Gravid'),
(97777, 4970, 26, 'Preliminare'),
(97778, 4971, 26, 'Preparazione per eseguire il report'),
(97779, 4972, 26, 'Pre-pagato'),
(97780, 4973, 26, 'Prescrizione'),
(97781, 4974, 26, 'la prescrizione ha raggiunto i suoi limiti di'),
(97782, 4975, 26, 'Storico Prescrizioni'),
(97783, 4976, 26, 'Importazione della Storico Prescrizioni completato regolarmente'),
(97784, 4977, 26, 'Etichetta Prescrizione'),
(97785, 4978, 26, 'Resoconto Prescrizione'),
(97786, 4979, 26, 'Prescrizioni'),
(97787, 4980, 26, 'Prescrizioni e dispense'),
(97788, 4981, 26, 'Prescrizioni e deferimenti ad altri'),
(97789, 4982, 26, 'Prescrizioni e/o rinvii di specialista'),
(97790, 4983, 26, 'Resoconto Prescrizioni'),
(97791, 4984, 26, 'Prescrizioni/Rinvii'),
(97792, 4985, 26, 'Presente'),
(97793, 4986, 26, 'Presentazione Reclamo'),
(97794, 4987, 26, 'Presentazione problema(i)'),
(97795, 4988, 26, 'Premi Continua per proseguire'),
(97796, 4989, 26, 'Diagnosi presunta'),
(97797, 4990, 26, 'Diagnosi presunta dallo specialista'),
(97798, 4991, 26, 'Prec'),
(97799, 4992, 26, 'Prev Med/Surg Hx'),
(97800, 4993, 26, 'Mese prec. (vecchio per il menu)'),
(97801, 4994, 26, 'Anno prec. (vecchio per il menu)'),
(97802, 4995, 26, 'Cura preventiva'),
(97803, 4996, 26, 'Prevenzione di riabilitazione'),
(97804, 4998, 26, 'Anteprima Evento'),
(97805, 5000, 26, 'Anteprima di'),
(97806, 5001, 26, 'Precedente'),
(97807, 5002, 26, 'Consulti precedenti'),
(97808, 5003, 26, 'Giorno precedente'),
(97809, 5004, 26, 'Precedente Storico/Screening'),
(97810, 5005, 26, 'Mese precedente'),
(97811, 5006, 26, 'Settimana precedente'),
(97812, 5007, 26, 'Prezzo'),
(97813, 5008, 26, 'Prezzo attualizzazione'),
(97814, 5009, 26, 'Livello di prezzo'),
(97815, 5010, 26, 'Livello di prezzo:'),
(97816, 5011, 26, 'Prezzi'),
(97817, 5012, 26, 'Primario'),
(97818, 5013, 26, 'Affari soggetto principale'),
(97819, 5014, 26, 'Gli affari del soggetto principale ID oneriviene usato come ID account NewCrop sulle ricette mediche. La modifica della struttura influenzerà il funzionamento in NewCrop.'),
(97820, 5022, 26, 'Ass. primaria'),
(97821, 5023, 26, 'Assicurazione primaria'),
(97822, 5024, 26, 'Data assicurazione primaria'),
(97823, 5025, 26, 'Fornitore assicurazione primaria'),
(97824, 5026, 26, 'Fornitore primario'),
(97825, 5027, 26, 'Stampa'),
(97826, 5028, 26, 'Stampa (HTML)'),
(97827, 5029, 26, 'Stampa (PDF)'),
(97828, 5030, 26, 'Stampa modifiche'),
(97829, 5031, 26, 'Stampa ogni incontro'),
(97830, 5032, 26, 'Stampa modulo vuoto di rinvio'),
(97831, 5033, 26, 'Comando di stampa'),
(97832, 5034, 26, 'Data di stampa'),
(97833, 5038, 26, 'Stampa lista intera'),
(97834, 5039, 26, 'Formato stampa'),
(97835, 5040, 26, 'Stampa quattro pannelli'),
(97836, 5042, 26, 'Stampa messaggio'),
(97837, 5043, 26, 'Stampa multipla'),
(97838, 5044, 26, 'Stampa multipla al fax'),
(97839, 5045, 26, 'Stampa nome, firma e data.'),
(97840, 5046, 26, 'Stampa le note'),
(97841, 5047, 26, 'Stampa pagina 1'),
(97842, 5048, 26, 'Stampa pagina 2'),
(97843, 5049, 26, 'Stampa etichetta indirizzi paziente'),
(97844, 5051, 26, 'Stampare le ricevute Fornitore'),
(97845, 5052, 26, 'Stampa il record'),
(97846, 5053, 26, 'Stampa Dichiarazioni selezionate'),
(97847, 5054, 26, 'Stampa record veloci'),
(97848, 5056, 26, 'Stampa questo incontro'),
(97849, 5057, 26, 'Stampa questa nota'),
(97850, 5058, 26, 'Stampa Questa Nota'),
(97851, 5060, 26, 'Stampa al fax'),
(97852, 5061, 26, 'Stama la vista'),
(97853, 5062, 26, 'stampabile'),
(97854, 5063, 26, 'Versione stampabile'),
(97855, 5064, 26, 'Stampato'),
(97856, 5066, 26, 'Risultati della stampa:'),
(97857, 5067, 26, 'Stampa saltata; vedi test di uscita a'),
(97858, 5068, 26, 'Stampa saltata; vedi test di uscita a '),
(97859, 5069, 26, 'Prior Aut'),
(97860, 5070, 26, 'Modulo Prior Autorizzazione'),
(97861, 5071, 26, 'Prior Visit'),
(97862, 5072, 26, 'Priorità'),
(97863, 5073, 26, 'Priorità '),
(97864, 5074, 26, 'Privato'),
(97865, 5075, 26, 'Problema'),
(97866, 5076, 26, 'Problema DX'),
(97867, 5077, 26, 'Elenco Problemi'),
(97868, 5078, 26, 'Problemi'),
(97869, 5079, 26, 'Problemi/Tematiche'),
(97870, 5080, 26, 'Proc Bat'),
(97871, 5081, 26, 'Proc Cat'),
(97872, 5082, 26, 'Proc Load'),
(97873, 5083, 26, 'Proc Rev in attesa'),
(97874, 5084, 26, 'Proc Prov'),
(97875, 5085, 26, 'Proc Res'),
(97876, 5086, 26, 'Procedura'),
(97877, 5087, 26, 'Procedura per Siti corporei'),
(97878, 5088, 26, 'Procedura per Risultati Booleani'),
(97879, 5089, 26, 'Codice della Procedura'),
(97880, 5090, 26, 'Codici di procedura'),
(97881, 5091, 26, 'Procedura per Lateralità'),
(97882, 5092, 26, 'Nome Procedura'),
(97883, 5093, 26, 'Ordine di procedura'),
(97884, 5094, 26, 'Ordine di procedura'),
(97885, 5095, 26, 'Ordine di procedura per'),
(97886, 5097, 26, 'Ordini di procedura e Reports'),
(97887, 5098, 26, 'Procedura di selezione'),
(97888, 5099, 26, 'Fornitore di procedura'),
(97889, 5100, 26, 'Fornitore di procedura'),
(97890, 5101, 26, 'Fornitori di procedure'),
(97891, 5102, 26, 'Report di procedura'),
(97892, 5103, 26, 'Procedura Rapporto stato'),
(97893, 5104, 26, 'Risultato anomalo nella procedura'),
(97894, 5105, 26, 'Procedura Rapporto stato'),
(97895, 5106, 26, 'Risultati procedura'),
(97896, 5107, 26, 'Percorsi procedura'),
(97897, 5108, 26, 'Procedura dei tipi di campione'),
(97898, 5109, 26, 'Report statistiche di procedura'),
(97899, 5110, 26, 'Tipo di procedura'),
(97900, 5111, 26, 'Tipi di procedura'),
(97901, 5112, 26, 'Unità di procedura'),
(97902, 5113, 26, 'Procedura/Servizio'),
(97903, 5114, 26, 'Procedure'),
(97904, 5115, 26, 'Elabora'),
(97905, 5116, 26, 'Elaborare e inviare promemoria'),
(97906, 5117, 26, 'Elaborare il file ERA'),
(97907, 5118, 26, 'Elaborare il nuovo file per registro CSV'),
(97908, 5119, 26, 'Elaborare i promemoria'),
(97909, 5120, 26, 'Il processo richiede un pò di tempo'),
(97910, 5121, 26, 'Elaborato'),
(97911, 5122, 26, 'Elaborato da'),
(97912, 5123, 26, 'Elaborato in data'),
(97913, 5124, 26, 'elaborazione completata con successo'),
(97914, 5125, 26, 'Sto elaborando'),
(97915, 5126, 26, 'Elaborazione e invio promemoria ai pazienti'),
(97916, 5127, 26, 'Elaborazione promemoria pazienti'),
(97917, 5128, 26, 'Tempo elaborazione'),
(97918, 5129, 26, 'Prodotto'),
(97919, 5130, 26, 'Prodotto metodo contraccettivo'),
(97920, 5131, 26, 'Produzione'),
(97921, 5132, 26, 'Prodotti'),
(97922, 5133, 26, 'Prodotti ma non farmaci da prescrizione e senza modelli'),
(97923, 5134, 26, 'Prof.'),
(97924, 5135, 26, 'Note sul Progresso'),
(97925, 5136, 26, 'Cancro alla prostata'),
(97926, 5137, 26, 'Screening del cancro alla prostata'),
(97927, 5138, 26, 'Esame della prostata'),
(97928, 5139, 26, 'Problemi alla prostata'),
(97929, 5140, 26, 'Prostata e/o ingross., noduli, molle'),
(97930, 5141, 26, 'Protocollo'),
(97931, 5142, 26, 'Inserisci il percorso assoluto'),
(97932, 5143, 26, 'Inserisci il percorso assoluto del file'),
(97933, 5145, 26, 'Fornisce riassunti clinici per i pazienti per ciascuna visita in studio'),
(97934, 5146, 26, 'Fornisce ai pazienti una copia elettronica con informazioni sul loro stato di salute (inclusi i risultati dei test diagnostici, elenco dei problemi, elenco dei farmaci, allergie), su rchiesta.'),
(97935, 5147, 26, 'Fornire i pazienti con tempestivo accesso elettronico alle loro informazioni sanitarie (compresi i risultati di laboratorio, lista problema, elenchi farmaci, allergie farmaci) entro quattro giorni lavorativi delle informazioni di cui dispone la PE.'),
(97936, 5148, 26, 'Fornire i record al paziente per la visita'),
(97937, 5149, 26, 'Inserisci un indirizzo email valido'),
(97938, 5150, 26, 'E'' stato fornito il riassunto clinico?'),
(97939, 5151, 26, 'Sono state fornite le risorse educative?'),
(97940, 5152, 26, 'Operatore'),
(97941, 5153, 26, 'Id Operatore'),
(97942, 5154, 26, 'ID Operatore'),
(97943, 5155, 26, 'ID Operatore presso la struttura specificata'),
(97944, 5156, 26, 'Errori di corrispondenza dell''operatore'),
(97945, 5159, 26, 'Numero Operatore'),
(97946, 5160, 26, 'Relazione operatore'),
(97947, 5162, 26, 'Operatore:'),
(97948, 5163, 26, 'Operatori'),
(97949, 5164, 26, 'Operatore NPI'),
(97950, 5165, 26, 'Gli operatori vedono l''intera agenda'),
(97951, 5166, 26, 'Opr'),
(97952, 5167, 26, 'PSA'),
(97953, 5168, 26, 'Psoriasi'),
(97954, 5169, 26, 'Diagnosi psic.'),
(97955, 5170, 26, 'Farmaco psic.'),
(97956, 5171, 26, 'Psichiatrico'),
(97957, 5172, 26, 'Breve relazione psichiatrica'),
(97958, 5173, 26, 'Diagnosi psichiatrica'),
(97959, 5174, 26, 'Esame psichiatrico'),
(97960, 5175, 26, 'Storia psichiatrica'),
(97961, 5176, 26, 'Presa in carico psichiatrica'),
(97962, 5177, 26, 'Farmaco psichiatrico'),
(97963, 5178, 26, 'Pz %'),
(97964, 5179, 26, 'Pz Note'),
(97965, 5180, 26, 'Pz Note/Aut'),
(97966, 5181, 26, 'Pz sovrapag'),
(97967, 5182, 26, 'Pz Pagato'),
(97968, 5183, 26, 'Pz Richiesta Rec'),
(97969, 5184, 26, 'Pz rimborso'),
(97970, 5185, 26, 'Pz dimesso'),
(97971, 5186, 26, 'Pz Resoconto'),
(97972, 5187, 26, 'Pz Studente, oppure lascia vuoto'),
(97973, 5188, 26, 'PT_CITY'),
(97974, 5189, 26, 'PT_DOB'),
(97975, 5190, 26, 'PT_EMAIL'),
(97976, 5191, 26, 'PT_FNAME'),
(97977, 5192, 26, 'PT_LNAME'),
(97978, 5193, 26, 'PT_MNAME'),
(97979, 5194, 26, 'PT_PHONE_CELL'),
(97980, 5195, 26, 'PT_PHONE_HOME'),
(97981, 5196, 26, 'PT_POSTAL'),
(97982, 5197, 26, 'PT_SSN'),
(97983, 5198, 26, 'PT_STATE'),
(97984, 5199, 26, 'PT_STREET'),
(97985, 5201, 26, 'Pubblico'),
(97986, 5203, 26, 'Servizio Sanitario Pubblico (PHS) o altro ente federale'),
(97987, 5204, 26, 'Portoricano'),
(97988, 5205, 26, 'Polmonare'),
(97989, 5206, 26, 'Battito'),
(97990, 5207, 26, 'Punjabi'),
(97991, 5208, 26, 'Acquista'),
(97992, 5209, 26, 'Acquista/Restituisci'),
(97993, 5210, 26, 'Acquisti'),
(97994, 5211, 26, 'P{{Justify Header}}'),
(97995, 5212, 26, 'Pāli'),
(97996, 5213, 26, 'q.3h'),
(97997, 5214, 26, 'q.4h'),
(97998, 5215, 26, 'q.5h'),
(97999, 5216, 26, 'q.6h'),
(98000, 5217, 26, 'q.8h'),
(98001, 5218, 26, 'q.d.'),
(98002, 5219, 26, 'q.i.d.'),
(98003, 5220, 26, 'QOH (quantità in giacenza)'),
(98004, 5221, 26, 'QOH è inferiore a utilizzo mensile'),
(98005, 5222, 26, 'Qtà'),
(98006, 5223, 26, 'QTA'),
(98007, 5224, 26, 'Qualità'),
(98008, 5225, 26, 'Misure di qualità (CQM)'),
(98009, 5226, 26, 'Quantità'),
(98010, 5227, 26, 'Quantità per NDC (National drug code)'),
(98011, 5228, 26, 'Quantità in giacenza'),
(98012, 5229, 26, 'quantità non sembra utilizzabile'),
(98013, 5230, 26, 'Quechua'),
(98014, 5231, 26, 'Punto Interrogativo'),
(98015, 5232, 26, 'Coda per HCFA processo batch'),
(98016, 5233, 26, 'Coda per HCFA processo batch'),
(98017, 5234, 26, 'Coda per UB-92 processo batch'),
(98018, 5235, 26, 'Coda per UB-92 processo batch e stampa'),
(98019, 5236, 26, 'In coda'),
(98020, 5237, 26, 'Amministrazione Eventi in coda'),
(98021, 5238, 26, 'In coda da'),
(98022, 5240, 26, 'Amministrazione Inserimenti in coda'),
(98023, 5241, 26, 'Smettere'),
(98024, 5242, 26, 'Smettere di bere alcool'),
(98025, 5243, 26, 'R'),
(98026, 5244, 26, 'RA per il paziente, di incontro, o traccia'),
(98027, 5245, 26, 'Razza'),
(98028, 5246, 26, 'Razza ed Etnicità'),
(98029, 5247, 26, 'Razza/Etnicità'),
(98030, 5248, 26, 'Radio'),
(98031, 5249, 26, 'Pulsanti radio'),
(98032, 5251, 26, 'Intervallo'),
(98033, 5252, 26, 'eruzioni cutanee'),
(98034, 5253, 26, 'Tasso'),
(98035, 5254, 26, 'Ratio'),
(98036, 5255, 26, 'Raw Report'),
(98037, 5256, 26, 'Re-Identificazione'),
(98038, 5257, 26, 'Il processo di Re-Identificazione è completato'),
(98039, 5258, 26, 'Il processo di Re-Identificazione è in corso'),
(98040, 5259, 26, 'I file di Re-Identificazione saranno salvati in'),
(98041, 5260, 26, 'Ri-Lesione?'),
(98042, 5261, 26, 'Ri-Apri'),
(98043, 5262, 26, 'Ri-aperto'),
(98044, 5263, 26, 'Reazione'),
(98045, 5264, 26, 'Reazioni'),
(98046, 5265, 26, 'Lettura'),
(98047, 5267, 26, 'Solo lettura per storico'),
(98048, 5268, 26, 'Nome reale'),
(98049, 5269, 26, 'Veramente cancellato'),
(98050, 5270, 26, 'Motivo'),
(98051, 5271, 26, 'Motivo del decesso'),
(98052, 5272, 26, 'Motivo della morte'),
(98053, 5274, 26, 'Motivo di rinvio'),
(98054, 5275, 26, 'Motivo della visita'),
(98055, 5276, 26, 'Motivo/Modulo'),
(98056, 5277, 26, 'Ricevuta'),
(98057, 5278, 26, 'Ricevuta di pagamento'),
(98058, 5279, 26, 'Ricevuta generata'),
(98059, 5280, 26, 'Rapporto Ricevute per metodo di pagamento'),
(98060, 5281, 26, 'Sommario ricevute'),
(98061, 5282, 26, 'Ricevuto'),
(98062, 5283, 26, 'Ricevuto da'),
(98063, 5284, 26, 'Fax ricevuti'),
(98064, 5285, 26, 'Ricevuto, non rivisto'),
(98065, 5286, 26, 'Ricevuto, non rivisto'),
(98066, 5287, 26, 'Ricevente'),
(98067, 5288, 26, 'ID Ricevente'),
(98068, 5289, 26, 'ID Ricevente (ISA08)'),
(98069, 5290, 26, 'ID Qualificatore Ricevente (ISA07)'),
(98070, 5291, 26, 'IDs ricevente'),
(98071, 5292, 26, 'Le utlime tre password non sono consentite'),
(98072, 5293, 26, 'Destinatario'),
(98073, 5294, 26, 'L''elenco destinatari è vuoto'),
(98074, 5295, 26, 'Nome Destinatario'),
(98075, 5296, 26, 'Destinatario dell''Informativa'),
(98076, 5297, 26, 'Destinatario richiesto a meno che lo stato sia fatto'),
(98077, 5298, 26, 'Raccomandazione'),
(98078, 5299, 26, 'Raccomandazione per il Follow Up'),
(98079, 5300, 26, 'Raccomandazioni'),
(98080, 5301, 26, 'Raccomandazioni e trattamento'),
(98081, 5302, 26, 'Raccomandazioni dello specialista'),
(98082, 5303, 26, 'Registra'),
(98083, 5304, 26, 'Il record esiste già'),
(98084, 5310, 26, 'Registra e tabula i cambiamenti i cambiamenti nei segni Vitali'),
(98085, 5311, 26, 'Registra la Demografica'),
(98086, 5312, 26, 'Registra Informativa'),
(98087, 5313, 26, 'Registro attività fisica'),
(98088, 5314, 26, 'Registra pagamento'),
(98089, 5315, 26, 'Registra data di richiesta'),
(98090, 5316, 26, 'Record abitudine al fumo per i pazienti di 13 anni o più vecchi.'),
(98091, 5317, 26, 'Records'),
(98092, 5318, 26, 'record trovati'),
(98093, 5319, 26, 'record trovati.'),
(98094, 5320, 26, 'Uso di droga ricreazionale'),
(98095, 5321, 26, 'Droghe ricreazionali'),
(98096, 5322, 26, 'Rettale'),
(98097, 5323, 26, 'Esame rettale'),
(98098, 5324, 26, 'rettalmente'),
(98099, 5325, 26, 'Reindirizzamento'),
(98100, 5326, 26, 'Rossore'),
(98101, 5327, 26, 'ridotto:'),
(98102, 5328, 26, 'Riferimento'),
(98103, 5329, 26, 'Riferimento di'),
(98104, 5330, 26, 'Data riferimento'),
(98105, 5331, 26, 'Riferimento a'),
(98106, 5332, 26, 'Riferimento classificazione (livello di rischio)'),
(98107, 5333, 26, 'Campo di riferimento dei risultati'),
(98108, 5334, 26, 'Motivo del riferimento'),
(98109, 5335, 26, 'Referente'),
(98110, 5336, 26, 'Referente nome e firma'),
(98111, 5337, 26, 'Referente'),
(98112, 5338, 26, 'Competenza di'),
(98113, 5339, 26, 'Scheda competenza'),
(98114, 5340, 26, 'Data competenza'),
(98115, 5341, 26, 'Modulo competenza'),
(98116, 5342, 26, 'MODULO COMPETENZA'),
(98117, 5343, 26, 'ID Competenza'),
(98118, 5345, 26, 'Fonte competenza'),
(98119, 5346, 26, 'Fonte competenza per gli incontri'),
(98120, 5347, 26, 'Competenza delle'),
(98121, 5348, 26, 'Referenze'),
(98122, 5349, 26, 'Report referenze'),
(98123, 5350, 26, 'Riferito da'),
(98124, 5351, 26, 'Riferito da'),
(98125, 5352, 26, 'Riferito a'),
(98126, 5353, 26, 'Referente'),
(98127, 5354, 26, 'Indirizzo referente'),
(98128, 5355, 26, 'Diagnosi referente'),
(98129, 5356, 26, 'Diagnosi referente'),
(98130, 5357, 26, 'Medico di riferimento e pratica'),
(98131, 5358, 26, 'Fornitore referente'),
(98132, 5359, 26, 'Ricarica'),
(98133, 5360, 26, 'Ricariche'),
(98134, 5361, 26, 'ricariche'),
(98135, 5362, 26, 'Riflessi normali'),
(98136, 5363, 26, 'Aggiornare'),
(98137, 5365, 26, 'Aggiornamento promemoria'),
(98138, 5368, 26, 'Ha rifiutato di Indicare'),
(98139, 5369, 26, 'reg_re'),
(98140, 5370, 26, 'registra'),
(98141, 5371, 26, 'Registra'),
(98142, 5372, 26, 'Registrato'),
(98143, 5373, 26, 'registrato'),
(98144, 5374, 26, 'Moduli registrati'),
(98145, 5375, 26, 'Data registrazione'),
(98146, 5376, 26, 'Modulo registrazione'),
(98147, 5377, 26, 'Riabilitazione'),
(98148, 5379, 26, 'Respinto'),
(98149, 5380, 26, 'Potenziale recidiva'),
(98150, 5381, 26, 'Correlato a'),
(98151, 5382, 26, 'Correlato'),
(98152, 5383, 26, 'Tematica correlata'),
(98153, 5384, 26, 'Note paziente correlate'),
(98154, 5385, 26, 'Relazione(i)/Figli'),
(98155, 5386, 26, 'Relazioni'),
(98156, 5387, 26, 'Relazione'),
(98157, 5388, 26, 'Ordine relativo di questa entità'),
(98158, 5389, 26, 'Parenti'),
(98159, 5390, 26, 'Pressione consanguinei'),
(98160, 5391, 26, 'Cancro consanguinei'),
(98161, 5392, 26, 'Diabete consanguinei'),
(98162, 5393, 26, 'Epilessia consanguinei'),
(98163, 5394, 26, 'Cuore consanguinei'),
(98164, 5395, 26, 'Salute mentale consanguinei'),
(98165, 5396, 26, 'Colpo apoplettico consanguinei'),
(98166, 5397, 26, 'Suicidi consanguinei'),
(98167, 5398, 26, 'Tubercolosi consanguinei'),
(98168, 5399, 26, 'Il collegamento alle credenziali sanitarie mancano in questo account utente'),
(98169, 5400, 26, 'ID collegamento sanitario'),
(98170, 5402, 26, 'Data di rilascio'),
(98171, 5403, 26, 'Religione'),
(98172, 5406, 26, 'Nuovo login'),
(98173, 5407, 26, 'Promem'),
(98174, 5408, 26, 'Ricorda la sede selezionata'),
(98175, 5409, 26, 'Promemoria'),
(98176, 5410, 26, 'Intervalli dei promemoria'),
(98177, 5411, 26, 'Promemoria non ancora inviato'),
(98178, 5412, 26, 'Promemoria inviato il'),
(98179, 5413, 26, 'Promemoria'),
(98180, 5414, 26, 'Mandato di'),
(98181, 5415, 26, 'Host remoto'),
(98182, 5416, 26, 'Rimuovi'),
(98183, 5419, 26, 'Rimuovi il gruppo'),
(98184, 5420, 26, 'Rimuovi il modulo del gruppo'),
(98185, 5421, 26, 'Rimuove il supporto per le immunizzazioni'),
(98186, 5422, 26, 'Rimuove il suporto per phpMyAdmin'),
(98187, 5423, 26, 'Rimuove il supporto per le prescrizioni'),
(98188, 5425, 26, 'Rimuove la funzione di tracciato grafico'),
(98189, 5426, 26, 'Calcoli renali'),
(98190, 5427, 26, 'Rinomina'),
(98191, 5428, 26, 'Rinomina il gruppo'),
(98192, 5429, 26, 'Rendering'),
(98193, 5430, 26, 'Fornitore Rendering'),
(98194, 5431, 26, 'Numero fornitore di Rendering'),
(98195, 5432, 26, 'Riordina'),
(98196, 5433, 26, 'Riordina a'),
(98197, 5434, 26, 'Il punto di riordino è stato raggiunto'),
(98198, 5435, 26, 'Punto di riordino, 0 non applicabile'),
(98199, 5436, 26, 'Rip'),
(98200, 5437, 26, 'Ripetere nuova password'),
(98201, 5438, 26, 'Evento ripetuto'),
(98202, 5439, 26, 'Info sulle ripetizioni:'),
(98203, 5440, 26, 'Ripetizioni'),
(98204, 5441, 26, 'SOSTITUIRE'),
(98205, 5442, 26, 'Sostituire lintero set di codici'),
(98206, 5443, 26, 'Sostituire'),
(98207, 5444, 26, 'Data dellla risposta'),
(98208, 5445, 26, 'Risposta da'),
(98209, 5446, 26, 'Resoconto'),
(98210, 5447, 26, 'Resoconto - Clinico'),
(98211, 5449, 26, 'Resoconto per'),
(98212, 5451, 26, 'Relazione finale (Abbandono Cura Data)'),
(98213, 5452, 26, 'La relazione è stata inviata al paziente'),
(98214, 5453, 26, 'Report storico/risultati'),
(98215, 5454, 26, 'Risultati del report'),
(98216, 5455, 26, 'Report risultati/storico'),
(98217, 5456, 26, 'Avvio rapporto (Assunto cura Data)'),
(98218, 5457, 26, 'Stato report'),
(98219, 5458, 26, 'Totale report'),
(98220, 5459, 26, 'Report/Scheda'),
(98221, 5460, 26, 'Refertabile'),
(98222, 5461, 26, 'Segnalato'),
(98223, 5462, 26, 'Data segnalazione'),
(98224, 5463, 26, 'Resoconti'),
(98225, 5465, 26, 'Descrizione richiesta'),
(98226, 5466, 26, 'ID richiesto mancante!'),
(98227, 5467, 26, 'Richiesta ignorata - elaborazione delle richieste è già in esecuzione!'),
(98228, 5469, 26, 'Stato richiesta'),
(98229, 5470, 26, 'Tipo richiesta'),
(98230, 5471, 26, 'Il tipo di richiesta non è implementato'),
(98231, 5472, 26, 'Richiesto da'),
(98232, 5473, 26, 'Data richiesta'),
(98233, 5474, 26, 'Prestazione richiesta'),
(98234, 5475, 26, 'Richiedere una password forte'),
(98235, 5476, 26, 'Richiedere una password unica'),
(98236, 5477, 26, 'Richiesto(a)'),
(98237, 5478, 26, 'Copagamento richiesto'),
(98238, 5479, 26, 'Manca il campo richiesto: scegli il file EDI-271 da caricare.'),
(98239, 5480, 26, 'Campo richiesto mancante: inserisci il nome'),
(98240, 5481, 26, 'Campo richiesto mancante: inserisci il cognome'),
(98241, 5482, 26, 'Campo richiesto mancante: inserisci il nome utente'),
(98242, 5483, 26, 'Campi richiesti'),
(98243, 5484, 26, 'Requisiti'),
(98244, 5485, 26, 'RISERVATO'),
(98245, 5486, 26, 'Riservato'),
(98246, 5487, 26, 'Riservato al fine di definire il Tempo programmato di vancanza'),
(98247, 5488, 26, 'Riservato per definire quando un erogante non è disponibile per successivi appuntamenti.'),
(98248, 5489, 26, 'Riservato per definire quando un evento non si è verificato come specificato.'),
(98249, 5490, 26, 'Riservato per definire quando un erogante potrebbe avere appuntamenti successivi.'),
(98250, 5491, 26, 'Resetta'),
(98251, 5492, 26, 'Resetta le credenziali del portale Offsite'),
(98252, 5493, 26, 'Resetta le credenziali del portale Onsite'),
(98253, 5495, 26, 'Resn'),
(98254, 5496, 26, 'Risolto'),
(98255, 5497, 26, 'Respirazione'),
(98256, 5498, 26, 'Sforzo respiratorio naturale'),
(98257, 5499, 26, 'Respiratorio'),
(98258, 5501, 26, 'Limitare utenti non autorizzati ai servizi di pianificazione stabiliti in utente admin.'),
(98259, 5502, 26, 'Restringi gli utenti alla sede'),
(98260, 5503, 26, 'Addestramento riservato'),
(98261, 5504, 26, 'Risultato'),
(98262, 5505, 26, 'Nome risultato'),
(98263, 5506, 26, 'Stato risultati'),
(98264, 5507, 26, 'Mancano lo status risultati o anormalità'),
(98265, 5508, 26, 'Risultato, usare % come un carattere jolly'),
(98266, 5509, 26, 'Risultati'),
(98267, 5510, 26, 'Risutati e'),
(98268, 5511, 26, 'Risultati trovati per la Ricerca'),
(98269, 5512, 26, 'Gruppo Risultati'),
(98270, 5513, 26, 'Solo risultati'),
(98271, 5514, 26, 'Percorso risultati'),
(98272, 5515, 26, 'Risultati per pagina'),
(98273, 5516, 26, 'Risultati/Dettagli'),
(98274, 5517, 26, 'Esame retinico'),
(98275, 5518, 26, 'Retratto a destra:'),
(98276, 5519, 26, 'Ritorno'),
(98277, 5520, 26, 'Ritorna sopra alla parte con il pagamento'),
(98278, 5521, 26, 'Ritorna all''agenda'),
(98279, 5522, 26, 'Ritorna al report risultati'),
(98280, 5523, 26, 'Torna a questa pagina e sarete in grado di completare il processo di installazione di ICD10  cliccando sull''intestazione della sezione ICD10'),
(98281, 5524, 26, 'Torna a questa pagina e sarete in grado di completare il processo di installazione di ICD9  cliccando sull''intestazione della sezione ICD9'),
(98282, 5525, 26, 'Torna a questa pagina e sarete in grado di completare il processo di installazione di RxNorm  cliccando sull''intestazione della sezione RXNORM'),
(98283, 5526, 26, 'Torna a questa pagina e sarete in grado di completare il processo di installazione di snomed  cliccando sull''intestazione della sezione SNOMED'),
(98284, 5527, 26, 'Valore restituito'),
(98285, 5528, 26, 'Visita di ritorno'),
(98286, 5529, 26, 'Ritornato a giocare'),
(98287, 5530, 26, 'Riutilizzo delle tre password precedenti non ammessi!'),
(98288, 5531, 26, 'Revisione'),
(98289, 5532, 26, 'Revisione & approvazione'),
(98290, 5534, 26, 'Recensione di PMH:'),
(98291, 5535, 26, 'Rassegna dei Sistemi'),
(98292, 5536, 26, 'Rassegna dei Sistemi Caselle'),
(98293, 5537, 26, 'Rivisto'),
(98294, 5538, 26, 'Revisione'),
(98295, 5539, 26, 'Artrite reumatoide'),
(98296, 5540, 26, 'Artrite reumatoide'),
(98297, 5541, 26, 'Destro(a)'),
(98298, 5542, 26, 'Orecchio destro'),
(98299, 5543, 26, 'orecchio destro'),
(98300, 5544, 26, 'Margine Destro (mm)'),
(98301, 5545, 26, 'Destro(a):'),
(98302, 5546, 26, 'Ronzio alle orecchie'),
(98303, 5547, 26, 'Ronzio alle orecchie'),
(98304, 5549, 26, 'Fattori di rischio'),
(98305, 5550, 26, 'Livello di rischio'),
(98306, 5551, 26, 'RLL:'),
(98307, 5552, 26, 'ROM'),
(98308, 5553, 26, 'Rumeno'),
(98309, 5554, 26, 'Romansh'),
(98310, 5560, 26, 'Rosa (giocatori)'),
(98311, 5561, 26, 'Via'),
(98312, 5562, 26, 'Via di somministrazione (se applicabile)'),
(98313, 5563, 26, 'Instradato'),
(98314, 5564, 26, 'Righe'),
(98315, 5565, 26, 'RRR senza MOR'),
(98316, 5566, 26, 'Massaggio:'),
(98317, 5567, 26, 'Massaggi:'),
(98318, 5568, 26, 'Regola'),
(98319, 5569, 26, 'Aggiungi regola'),
(98320, 5570, 26, 'Dettaglio regola'),
(98321, 5572, 26, 'Modifica regola'),
(98322, 5575, 26, 'Set regola'),
(98323, 5576, 26, 'Set di regole e piano SET scelte non sono coerenti. Correggi e invia di nuovo.'),
(98324, 5578, 26, 'Regole'),
(98325, 5580, 26, 'Configurazione regole'),
(98326, 5581, 26, 'Comando in esecuzione: '),
(98327, 5582, 26, 'Rottura/Ernia'),
(98328, 5583, 26, 'Russo'),
(98329, 5584, 26, 'Rx'),
(98330, 5585, 26, 'RX'),
(98331, 5586, 26, 'Rx margine inferiore (px)'),
(98332, 5587, 26, 'Abilita rx DEA #'),
(98333, 5588, 26, 'Abilita rx NPI'),
(98334, 5589, 26, 'Abilita rx stato Lic. #'),
(98335, 5590, 26, 'Rx margine sinistro (px)'),
(98336, 5591, 26, 'Dimensione carta Rx'),
(98337, 5592, 26, 'Rx margine destro (px)'),
(98338, 5593, 26, 'Visualizza Rx DEA #'),
(98339, 5594, 26, 'Visualizza Rx NPI'),
(98340, 5595, 26, 'Visualizza Rx stato Lic. #'),
(98341, 5596, 26, 'Rx Margine superiore (px)'),
(98342, 5597, 26, 'RXCUI Medicazione'),
(98343, 5598, 26, 'RxNorm'),
(98344, 5599, 26, 'Database RxNorm'),
(98345, 5600, 26, 'S'),
(98346, 5601, 26, 'S.S.'),
(98347, 5602, 26, 'S3:'),
(98348, 5603, 26, 'S4:'),
(98349, 5604, 26, 'SA * * Per leggere la licenza leggi docs/license.txt o visita * http://www.gnu.org/copyleft/gpl.html * */ //========================================================================= // '),
(98350, 5605, 26, 'Vendita'),
(98351, 5606, 26, 'Vendite'),
(98352, 5607, 26, 'Vendite per articolo'),
(98353, 5608, 26, 'Vendite per Report dei prodotti'),
(98354, 5609, 26, 'Saliva'),
(98355, 5610, 26, 'Stesso giorno'),
(98356, 5611, 26, 'Samoano'),
(98357, 5612, 26, 'Campione'),
(98358, 5613, 26, 'Tipo sanzione'),
(98359, 5614, 26, 'Sango'),
(98360, 5615, 26, 'Sanskrit (Saṁskṛta)'),
(98361, 5616, 26, 'Sardinian'),
(98362, 5617, 26, 'Sab'),
(98363, 5618, 26, 'Sab &amp; Dom'),
(98364, 5619, 26, 'Sabato'),
(98365, 5620, 26, 'Salva'),
(98366, 5621, 26, 'SALVA'),
(98367, 5622, 26, 'Salva e chiudi'),
(98368, 5623, 26, 'Salva e cancella richiesta'),
(98369, 5624, 26, 'Salva e distribuisci'),
(98370, 5625, 26, 'Salva e trasmetti'),
(98371, 5626, 26, 'Salva come nuovo'),
(98372, 5627, 26, 'Salva come nuova nota'),
(98373, 5628, 26, 'Salva le configurazioni del certificato'),
(98374, 5629, 26, 'Salva i cambiamenti'),
(98375, 5630, 26, 'Salva il modulo'),
(98376, 5631, 26, 'Salva Immunizzazione'),
(98377, 5632, 26, 'Salva il nuovo campo'),
(98378, 5633, 26, 'Salva il nuovo gruppo'),
(98379, 5634, 26, 'Salva il nuovo elenco'),
(98380, 5635, 26, 'Salva il nuovo aspetto'),
(98381, 5636, 26, 'Salva selezioni di omissione'),
(98382, 5637, 26, 'Salva la demografica del paziente'),
(98383, 5638, 26, 'Salvataggio riuscito per ID grafico'),
(98384, 5639, 26, 'Salva la transazione'),
(98385, 5640, 26, 'Salvato correttamente'),
(98386, 5641, 26, 'Scansito'),
(98387, 5642, 26, 'Nota incontro scansita'),
(98388, 5643, 26, 'Directory della scanner'),
(98389, 5644, 26, 'Scanner In'),
(98390, 5645, 26, 'Programmare'),
(98391, 5646, 26, 'Programma Servizi:'),
(98392, 5647, 26, 'NOTE SCUOLA'),
(98393, 5648, 26, 'Scoliosi'),
(98394, 5649, 26, 'Scottish Gaelic- Gaelic'),
(98395, 5650, 26, 'Screening / Testing'),
(98396, 5651, 26, 'SE'),
(98397, 5652, 26, 'Indirizzo SE'),
(98398, 5653, 26, 'Città SE'),
(98399, 5654, 26, 'Paese SE'),
(98400, 5655, 26, 'Località SE'),
(98401, 5656, 26, 'CAP SE'),
(98402, 5657, 26, 'Stato SE'),
(98403, 5658, 26, 'CAP SE'),
(98404, 5659, 26, 'Cerca'),
(98405, 5661, 26, 'cerca'),
(98406, 5662, 26, 'cerca di nuovo'),
(98407, 5663, 26, 'Cerca in tutte le colonne'),
(98408, 5664, 26, 'Carca per:'),
(98409, 5665, 26, 'Cerca'),
(98410, 5666, 26, 'Cerca:'),
(98411, 5667, 26, 'Cerca In'),
(98412, 5668, 26, 'Cerca in'),
(98413, 5669, 26, 'Cerca o Aggiungi Paziente'),
(98414, 5670, 26, 'Cerca pagamento'),
(98415, 5671, 26, 'Risultati della ricerca'),
(98416, 5672, 26, 'Risultati della ricerca:'),
(98417, 5673, 26, 'Cerca i selezionati'),
(98418, 5674, 26, 'La stringa ricercata non corrisponde con l''elenco nel database'),
(98419, 5675, 26, 'La stringa ricercata dovrebbe avere almeno tre caratteri'),
(98420, 5676, 26, 'Cerca testo'),
(98421, 5677, 26, 'Cerca gli eventi'),
(98422, 5678, 26, 'Cerca/Aggiungi'),
(98423, 5679, 26, 'Cerca/Aggiungi Assicuratore'),
(98424, 5680, 26, 'Cerca appuntamenti'),
(98425, 5681, 26, 'Ricerca in corso...'),
(98426, 5682, 26, 'Uso delle Cinture di sicurezza'),
(98427, 5683, 26, 'Uso delle cinture di sicurezza'),
(98428, 5684, 26, 'Secondo'),
(98429, 5687, 26, 'Secondario(a)'),
(98430, 5688, 26, 'Assicurazione secondaria'),
(98431, 5689, 26, 'Data assicurazione secondaria'),
(98432, 5690, 26, 'Fornitore assicurazione secondaria'),
(98433, 5691, 26, 'Tipo assistenza sanitaria secondaria'),
(98434, 5693, 26, 'ID sezione');
INSERT INTO `lang_definitions` VALUES
(98435, 5694, 26, 'ID sezione e Nome non possono essere vuoti'),
(98436, 5695, 26, 'Nome sezione'),
(98437, 5696, 26, 'Sezione salvata con successo'),
(98438, 5698, 26, 'Sicurezza'),
(98439, 5699, 26, 'Vedi tutto'),
(98440, 5700, 26, 'Vedi autorizzazioni'),
(98441, 5701, 26, 'Vedi Tabulato-Crescita'),
(98442, 5702, 26, 'Vedere i messaggi dalla ultima serie di domande generate'),
(98443, 5704, 26, 'Visto dal'),
(98444, 5705, 26, 'Nome del segmento'),
(98445, 5706, 26, 'Segments Batch Claim'),
(98446, 5707, 26, 'Convulsioni'),
(98447, 5708, 26, 'Sel'),
(98448, 5709, 26, 'Seleziona'),
(98449, 5710, 26, 'seleziona'),
(98450, 5711, 26, 'Seleziona il Componente'),
(98451, 5712, 26, 'Seleziona un Contesto'),
(98452, 5713, 26, 'Selezionare una percentuale delle righe o seleziona le date'),
(98453, 5714, 26, 'Selezionare un intervallo di tempo'),
(98454, 5715, 26, 'Seleziona un Utente'),
(98455, 5716, 26, 'Selziona Tutto'),
(98456, 5717, 26, 'Seleziona la data di modifica'),
(98457, 5718, 26, 'Seleziona le modifiche di stampa'),
(98459, 5720, 26, 'Seleziona una categoria'),
(98460, 5721, 26, 'Seleziona le preferenze di comunicazione'),
(98461, 5722, 26, 'Seleziona le caselle di spunta corrispondenti da eliminare'),
(98462, 5723, 26, 'Seleziona i criteri da rimuovere'),
(98463, 5724, 26, 'Seleziona la tabella CSV'),
(98464, 5725, 26, 'Seleziona i dati che si richiede siano de-identificati'),
(98465, 5726, 26, 'Seleziona i dati da includere tra i dati de-identificati'),
(98466, 5727, 26, 'Seleziona la data'),
(98467, 5728, 26, 'Seleziona la squadra desiderata'),
(98468, 5729, 26, 'Seleziona diagnosi'),
(98469, 5730, 26, 'Seleziona le diagnosi per la richiesta di de-identificazione'),
(98470, 5731, 26, 'Seleziona droga'),
(98471, 5732, 26, 'Seleziona droghe'),
(98472, 5733, 26, 'Seleziona le droghe per la richiesta di de-identificazione'),
(98473, 5734, 26, 'Seleziona il file EDI-271'),
(98474, 5735, 26, 'Seleziona incontri'),
(98475, 5736, 26, 'Seleziona il campo'),
(98476, 5737, 26, 'Seleziona i campi'),
(98477, 5738, 26, 'Seleziona per la stampa'),
(98478, 5739, 26, 'Seleziona Immunizzazioni'),
(98479, 5740, 26, 'Seleziona le immunizzazioni per la richiesta di de-identificazione'),
(98480, 5741, 26, 'Seleziona l''assicurazione, scrivendo'),
(98481, 5742, 26, 'Seleziona la Tematica'),
(98482, 5743, 26, 'Seleziona gli articolli'),
(98483, 5744, 26, 'Seleziona la lingua'),
(98484, 5745, 26, 'Seleziona una voce'),
(98485, 5746, 26, 'Selezionare uno o più codici di diagnosi per giustificare il servizio'),
(98486, 5747, 26, 'Seleziona uno o più file per il caricamento'),
(98487, 5748, 26, 'Seleziona output'),
(98488, 5750, 26, 'Seleziona richiesta da'),
(98489, 5752, 26, 'Seleziona fonte'),
(98490, 5753, 26, 'Seleziona il Template'),
(98491, 5754, 26, 'Seleziona gli elementi della configurazione da esportare'),
(98492, 5755, 26, 'Selezionare il problema principale responsabile per eventuali eventi persi in questo giorno'),
(98493, 5756, 26, 'Selezionare per stampare le etichette di indirizzo dei pazienti da popup a schermo nav sinistra.'),
(98494, 5757, 26, 'Seleziona traccia'),
(98495, 5759, 26, 'Seleziona Utente'),
(98496, 5760, 26, 'Selziona gli utenti dall''elenco a discesa'),
(98497, 5761, 26, 'Seleziona quali lingue, se alcuna, può essere scelta all''ingresso. (pertinente solo se il precedente Consentite tutte le lingue è disattivato)'),
(98498, 5762, 26, 'Seleziona Si per confermare l''eliminazione del gruppo'),
(98499, 5765, 26, 'Selezionato'),
(98500, 5766, 26, 'Incontro selezionato'),
(98501, 5767, 26, 'La selezione di questo creerà un messaggio che deve essere elaborato da ogni destinatario singolarmente (non si tratta di un''attività di gruppo).'),
(98502, 5768, 26, 'Se stesso'),
(98503, 5769, 26, 'Pagato da se stesso'),
(98504, 5771, 26, 'Invia'),
(98505, 5772, 26, 'Invia un sollecito datato'),
(98506, 5773, 26, 'Invia un sollecito'),
(98507, 5774, 26, 'Invio in corso'),
(98508, 5775, 26, 'Invia Messaggio'),
(98509, 5776, 26, 'Invia solleciti Batch'),
(98510, 5777, 26, 'Invia promemoria per pazienti per la preferenza del paziente per il trattamento preventivo/follow up di cura.'),
(98511, 5778, 26, 'Invia Sommari con Riferimenti'),
(98512, 5779, 26, 'Invia questo file'),
(98513, 5780, 26, 'Invia questo messaggio'),
(98514, 5781, 26, 'Invia a'),
(98515, 5784, 26, 'Invia a tutti'),
(98516, 5786, 26, 'Invia al portale'),
(98517, 5787, 26, 'Invia al Portale'),
(98518, 5788, 26, 'Mittente'),
(98519, 5789, 26, 'ID mittente'),
(98520, 5790, 26, 'ID mittente (ISA06)'),
(98521, 5791, 26, 'ID Qualificatore mittente (ISA05)'),
(98522, 5792, 26, 'IDs Mittente'),
(98523, 5793, 26, 'Invio a'),
(98524, 5794, 26, 'Sensibilità'),
(98525, 5795, 26, 'Sensibilità:'),
(98526, 5796, 26, 'Esame sensoriale normale'),
(98527, 5797, 26, 'Inviato'),
(98528, 5798, 26, 'Invio - Confermato'),
(98529, 5799, 26, 'Inviato da, lascia vuoto per tutti'),
(98530, 5800, 26, 'Inviato da:'),
(98531, 5801, 26, 'Data invio'),
(98532, 5802, 26, 'Elementi inviati'),
(98533, 5803, 26, 'Inviate le registrazioni mediche?'),
(98534, 5804, 26, 'Inviato con successo'),
(98535, 5807, 26, 'inviato alla stampante.'),
(98536, 5808, 26, 'Inviato a, lascia vuoto per tutti'),
(98537, 5809, 26, 'Inviato a:'),
(98538, 5810, 26, 'Inviato, ma la consegna non è confermata.'),
(98539, 5811, 26, 'Inviato, non ricevuto'),
(98540, 5812, 26, 'Sett'),
(98541, 5813, 26, 'Separato'),
(98542, 5814, 26, 'Settembre'),
(98543, 5815, 26, 'Seq'),
(98544, 5816, 26, 'Sequenza'),
(98545, 5817, 26, 'Serbian'),
(98546, 5818, 26, 'Serv Rep'),
(98547, 5819, 26, 'Il server sembra offline'),
(98548, 5820, 26, 'Messaggio del Server:'),
(98549, 5821, 26, 'Prestazione'),
(98550, 5822, 26, 'Categoria della prestazione'),
(98551, 5823, 26, 'Codice della prestazione'),
(98552, 5824, 26, 'Codice di servizio di Reporting Finanziario'),
(98553, 5825, 26, 'Codici delle prestazioni'),
(98554, 5826, 26, 'Data della prestazione'),
(98555, 5827, 26, 'Data della prestazione:'),
(98556, 5829, 26, 'Luogo della prestazione'),
(98557, 5830, 26, 'Nome servizio'),
(98558, 5831, 26, 'Prestazione fornito da specialista'),
(98559, 5832, 26, 'Servizio di Reporting'),
(98560, 5833, 26, 'Solo servizio di reporting'),
(98561, 5834, 26, 'Prestazioni'),
(98562, 5835, 26, 'Prestazioni per categoria'),
(98563, 5836, 26, 'Prestazioni fornite'),
(98564, 5837, 26, 'Prestazioni Fornite'),
(98565, 5838, 26, 'Prestazioni/Prodotti'),
(98566, 5839, 26, 'Tipo di sessione'),
(98567, 5840, 26, 'Assegna'),
(98568, 5841, 26, 'Implementa un cookie di sede per ricordare la sede selezionata tra un ingresso e un altro'),
(98569, 5842, 26, 'Imposta come Completato'),
(98570, 5843, 26, 'Impostare la priorità di elaborazione per i report basati su motori CDR.'),
(98571, 5844, 26, 'Impostare la priorità di elaborazione per la creazione di promemoria per i pazienti (in modalità clinica completa).'),
(98572, 5845, 26, 'Assegna a questo il percorso completo assoluto. Per la creazione certificato SSL del client per l''HTTPS.'),
(98573, 5846, 26, 'Imposta per'),
(98574, 5847, 26, 'Assegna come default'),
(98575, 5848, 26, 'Assegno il numero di versione al database...'),
(98576, 5849, 26, 'Parametri'),
(98577, 5851, 26, 'Emicrania severa'),
(98578, 5853, 26, 'Severità del dolore'),
(98579, 5854, 26, 'Severità del dolore:'),
(98580, 5855, 26, 'Sesso'),
(98581, 5856, 26, 'Malattia trasmessa sessulamente'),
(98582, 5857, 26, 'SFTP'),
(98583, 5858, 26, 'Sha-1 Hash'),
(98584, 5859, 26, 'Condivisione'),
(98585, 5860, 26, 'Comando della shell per la stampa dal server.'),
(98586, 5862, 26, 'Shona'),
(98587, 5863, 26, 'Breve descrizione'),
(98588, 5864, 26, 'Dispnea'),
(98589, 5865, 26, 'Dspnea'),
(98590, 5866, 26, 'Dispnea 2'),
(98591, 5867, 26, 'Shot Record'),
(98592, 5868, 26, 'Shot Record al:'),
(98593, 5869, 26, 'Deve essere Abilitato'),
(98594, 5870, 26, 'Deve essere del tipo nnnnn-nnnn-nn'),
(98595, 5871, 26, 'Deve essere di due lettere'),
(98596, 5872, 26, 'deve contenere 10 cifre'),
(98597, 5873, 26, 'deve contenere soltanto 10 cifre'),
(98598, 5874, 26, 'Spalla'),
(98599, 5875, 26, 'Spalla + clavicola'),
(98600, 5876, 26, 'Problemi alla spalla'),
(98601, 5877, 26, 'Mostra'),
(98602, 5878, 26, 'Mostra attivo'),
(98603, 5880, 26, 'Mostra tutto'),
(98604, 5881, 26, 'Mostra tutte le procedure'),
(98605, 5883, 26, 'Mostra tutte le transazioni'),
(98606, 5884, 26, 'Mostra come occupato'),
(98607, 5885, 26, 'Mostra solo autorizzati'),
(98608, 5886, 26, 'Mostra ore disponibili'),
(98609, 5887, 26, 'Mostra sia metrico che US (l''unità principale è metrica)'),
(98610, 5888, 26, 'Mostra sia US che metrico (l''unità principale è US)'),
(98611, 5889, 26, 'Mostra i dettagli'),
(98612, 5890, 26, 'Mostrare solo gli errori?'),
(98613, 5891, 26, 'Mostra grafico'),
(98614, 5892, 26, 'Mostra testo sospeso dell''evento al passaggio del mouse?'),
(98615, 5893, 26, 'Mostrare quanri eventi sulle pagine di amministrazione?'),
(98616, 5894, 26, 'Mostra inattivo'),
(98617, 5896, 26, 'Mostra menu'),
(98618, 5897, 26, 'Mostra solo metrica'),
(98619, 5898, 26, 'Mostra le note'),
(98620, 5900, 26, 'Mostra solo le procedure non omesse'),
(98621, 5901, 26, 'Mostra le note pazienti'),
(98622, 5902, 26, 'Mostra libbre e once'),
(98623, 5903, 26, 'Mostra libbre come valore decimale'),
(98624, 5904, 26, 'Mostra completo principale'),
(98625, 5905, 26, 'Mostra promemoria'),
(98626, 5906, 26, 'Mostra resoconto'),
(98627, 5907, 26, 'Mostra ricerca/inserire link nel blocco?'),
(98628, 5910, 26, 'Visualizza il modulo personalizzato di stato per il widget elenco aggiuntivo (vi chiederà titolo e abbreviazione).'),
(98629, 5911, 26, 'Mostra questa categoria nella schermata di riepilogo paziente, anche se non sono stati inseriti problemi per questa categoria.'),
(98630, 5912, 26, 'Mostra traccia storica'),
(98631, 5913, 26, 'Mostra solo non fatturati'),
(98632, 5914, 26, 'Mostra solo sistema US'),
(98633, 5915, 26, 'Mostrare'),
(98634, 5916, 26, 'Mostra risultati'),
(98635, 5918, 26, 'Storia dei fratelli'),
(98636, 5920, 26, 'Fratelli'),
(98637, 5921, 26, 'Cellule falciformi'),
(98638, 5922, 26, 'Sig'),
(98639, 5923, 26, 'Rettoscopia/Colonscopia'),
(98640, 5924, 26, 'Firma'),
(98641, 5925, 26, 'Firma i risultati di laboratorio (scrittura, aggiungere solo opzionale)'),
(98642, 5926, 26, 'Firma i risultati'),
(98643, 5927, 26, 'Firma'),
(98644, 5928, 26, 'Firmato sul File'),
(98645, 5929, 26, 'Firma:'),
(98646, 5930, 26, 'Rx firmato'),
(98647, 5932, 26, 'Gonfiore significativo:'),
(98648, 5933, 26, 'Semplificato'),
(98649, 5934, 26, 'Co-Pagamento semplificato'),
(98650, 5935, 26, 'Demografica semplificata'),
(98651, 5936, 26, 'Prescrizioni semplificate'),
(98652, 5937, 26, 'Fin dal'),
(98653, 5938, 26, 'Distinti saluti,'),
(98654, 5939, 26, 'Sindhi'),
(98655, 5940, 26, 'Celibe/Nubile'),
(98656, 5941, 26, 'Elenco a selezione singola'),
(98657, 5942, 26, 'Elenco a selezione singola con la possibilità di aggiungere all''elenco'),
(98658, 5943, 26, 'Singolare'),
(98659, 5944, 26, 'Sinhala'),
(98660, 5945, 26, 'Sinhala, Sinhalese'),
(98661, 5946, 26, 'Problemi del seno'),
(98662, 5947, 26, 'Chirurgia al seno'),
(98663, 5948, 26, 'CONSISTENZA DEL SENO:'),
(98664, 5949, 26, 'Sinusite'),
(98665, 5950, 26, 'Sito'),
(98666, 5951, 26, 'ID Sito'),
(98667, 5952, 26, 'ID Sito per il Medical Information Integration, LLC Lab Service Exchange.'),
(98668, 5953, 26, 'ID Sito per il supporto LLC Lab Service Exchange LibreEHR.'),
(98669, 5956, 26, 'Dimensione'),
(98670, 5957, 26, 'La dimensione deve essere un numero tra 1 e 999'),
(98671, 5958, 26, 'Dimensione/Elenco'),
(98672, 5959, 26, 'Cute'),
(98673, 5960, 26, 'Cancro alla pelle'),
(98674, 5961, 26, 'Malattia della pelle'),
(98675, 5962, 26, 'Cute Altro'),
(98676, 5963, 26, 'Salta l''autorizzazione delle Note del Paziente'),
(98677, 5964, 26, 'Salta la sezione'),
(98678, 5965, 26, 'Salto di SQL-Ledger deposito - non implementato per server Windows'),
(98679, 5967, 26, 'modelli di sonno'),
(98680, 5968, 26, 'modelli di sonno'),
(98681, 5969, 26, 'Sonno'),
(98682, 5970, 26, 'Slovacco'),
(98683, 5971, 26, 'Slovene'),
(98684, 5972, 26, 'Sm debt w/o'),
(98685, 5973, 26, 'Smarty Cache è stata cancellata'),
(98686, 5974, 26, 'Fumatore status corrente sconosciuto'),
(98687, 5976, 26, 'Status fumo'),
(98688, 5977, 26, 'Aut SMS'),
(98689, 5978, 26, 'Gateway SMS'),
(98690, 5979, 26, 'chiave API per il Gateway SMS'),
(98691, 5980, 26, 'Chiave API per il Gateway SMS'),
(98692, 5981, 26, 'Password per il Gateway SMS'),
(98693, 5982, 26, 'Username per il Gateway SMS'),
(98694, 5983, 26, 'Notifica SMS'),
(98695, 5984, 26, 'Ore per la Notifica via SMS'),
(98696, 5985, 26, 'Invia SMS prima della'),
(98697, 5986, 26, 'SMS inviato'),
(98698, 5987, 26, 'Testo SMS, Tag utilizzabili: ***NAME***, ***PROVIDER***, ***DATE***, ***STARTTIME***, ***ENDTIME***<br> p.es. Gentile Sig. ***NAME***'),
(98699, 5988, 26, 'SMS/Parametri Allarme Email'),
(98700, 5989, 26, 'Password SMTP per l''autenticazione'),
(98701, 5992, 26, 'Hostname del server SMTP'),
(98702, 5993, 26, 'Numero Porta del server SMTP'),
(98703, 5994, 26, 'Utente SMTP per l''autenticazione'),
(98704, 5995, 26, 'SNOMED'),
(98705, 5996, 26, 'SNOMED (RF1) Clinical Term'),
(98706, 5997, 26, 'SNOMED (RF1) Diagnosis'),
(98707, 5998, 26, 'SNOMED (RF1) Procedure'),
(98708, 5999, 26, 'SNOMED (RF2) Diagnosis'),
(98709, 6000, 26, 'SNOMED Clinical Term'),
(98710, 6001, 26, 'SNOMED Database'),
(98711, 6002, 26, 'SNOMED Diagnosis'),
(98712, 6003, 26, 'SNOMED Procedure'),
(98713, 6004, 26, 'Russare'),
(98714, 6005, 26, 'SOAP'),
(98715, 6006, 26, 'Difficoltà sociali'),
(98716, 6009, 26, 'Storico sociale:'),
(98717, 6010, 26, 'Numero sicurezza sociale (US)'),
(98718, 6011, 26, 'soluzione'),
(98719, 6012, 26, 'Somali'),
(98720, 6013, 26, 'Contesto somatico'),
(98721, 6014, 26, 'Alcune autorizzazioni non sono state mostrate. Clicca qui per vederle tutte'),
(98722, 6015, 26, 'Alcuni codici non sono stati mostrati.'),
(98723, 6016, 26, 'Alcuni incontri non sono stati nostrati. Clicca qui per vederli tutti.'),
(98724, 6017, 26, 'Si sono verificati alcuni errori durante il processo di de-identificazione'),
(98725, 6018, 26, 'Alcune note non sono state mostrate'),
(98726, 6019, 26, 'Alcune note di ufficio non sono state visualizzate. Clicca qui per visualizzare tutto.'),
(98727, 6020, 26, 'alcune parole'),
(98728, 6021, 26, 'Qualcun altro ha appena cambiato questa visita. Si prega di annullare questa pagina e riprovare.'),
(98729, 6023, 26, 'Qualcosa è andata male. Prova di nuovo.'),
(98730, 6024, 26, 'Intervallo debito in scadenza (promemoria Medico)'),
(98731, 6025, 26, 'Intervallo debito in scadenza (promemoria Paziente)'),
(98732, 6026, 26, 'Gola infiammata'),
(98733, 6027, 26, 'Spiacente nessun appuntamento fissato'),
(98734, 6028, 26, 'Spiacente, c''è stato un problema nel caricare il file'),
(98735, 6029, 26, 'Ordina per'),
(98736, 6030, 26, 'Ordina Per'),
(98737, 6031, 26, 'Ordina per Checksum'),
(98738, 6032, 26, 'Ordina per Commenti'),
(98739, 6033, 26, 'Ordina per Cont Utente'),
(98740, 6034, 26, 'Ordina per data'),
(98741, 6035, 26, 'Ordina per data/ora'),
(98742, 6036, 26, 'Ordina per eventi'),
(98743, 6037, 26, 'Ordina per gruppi'),
(98744, 6038, 26, 'Ordina per nuovo Checksum'),
(98745, 6039, 26, 'Ordina per vecchio Checksum'),
(98746, 6040, 26, 'Ordinaper IDPaziente'),
(98747, 6041, 26, 'Ordina per successo'),
(98748, 6042, 26, 'Ordina per manomissione data/ora'),
(98749, 6043, 26, 'Ordina per utente'),
(98750, 6044, 26, 'Ordinaper vaccino'),
(98751, 6045, 26, 'Ordina decrescente'),
(98752, 6046, 26, 'Ordinai risultati per'),
(98753, 6047, 26, 'Ordina crescente'),
(98754, 6048, 26, 'Origine'),
(98755, 6049, 26, 'File origine'),
(98756, 6050, 26, 'Percorso del file origine'),
(98757, 6051, 26, 'L''origine manca del codice '),
(98758, 6052, 26, 'Lotto origine'),
(98759, 6054, 26, 'Origine paziente'),
(98760, 6055, 26, 'Origine paziente non ha DOB(data di nascita)'),
(98761, 6056, 26, 'Origine paziente non trovata'),
(98762, 6057, 26, 'Origine:'),
(98763, 6058, 26, 'South Ndebele'),
(98764, 6059, 26, 'Southern Sotho'),
(98765, 6060, 26, 'Spazio'),
(98766, 6061, 26, 'SPAZIO'),
(98767, 6062, 26, 'Spagnolo'),
(98768, 6063, 26, 'Spagnolo (Latino Americano)'),
(98769, 6064, 26, 'Spagnolo (Spagna)'),
(98770, 6065, 26, 'Spanish- Castilian'),
(98771, 6066, 26, 'I caratteri speciali non sono ammessi'),
(98772, 6067, 26, 'Trattamento speciale per il modulo Funzioni vitali'),
(98773, 6068, 26, 'Specialista'),
(98774, 6069, 26, 'Nome specialista e firma'),
(98775, 6071, 26, 'Specialità'),
(98776, 6072, 26, 'Sistemi di Specialità'),
(98777, 6073, 26, 'Specialità:'),
(98778, 6074, 26, 'Specifico(a)'),
(98779, 6075, 26, 'Applicazione specifica'),
(98780, 6076, 26, 'Prestazione per la contraccezione specifica'),
(98781, 6077, 26, 'Risultato specifico'),
(98782, 6078, 26, 'Prestazione specifica'),
(98783, 6079, 26, 'Specificato'),
(98784, 6080, 26, 'Specifica il formato per i codici. # = cifra, * = qualsiasi carattere. Vuoto se non usato.'),
(98785, 6081, 26, 'Specifica il formato per i codici. # = cifra, @ = alfanumerico, * = qualsiasi carattere. Vuoto se non usato.'),
(98786, 6082, 26, 'Specifica il formato dei numeri di riferimento del conto. # = cifra, * = qualsiasi carattere. Vuoto se non usato.'),
(98787, 6083, 26, 'Specifica il formato dei numeri di riferimento del conto. # = cifra, @ = alfanumerico, * = qualsiasi carattere. Vuoto se non usato.'),
(98788, 6084, 26, 'Specifica il formato per i campi dei prodotti NDC. # = cifra, * = qualsiasi carattere. Vuoto se non usato.'),
(98789, 6085, 26, 'Specifica il formato per i campi dei prodotti NDC. # = cifra, @ = alfanumerico, * = qualsiasi carattere. Vuoto se non usato.'),
(98790, 6086, 26, 'Specifica il formato per l''ID del paziente esterno. # = cifra, * = qualsiasi carattere. Vuoto se non usato.'),
(98791, 6087, 26, 'Specifica il formato per l''ID del paziente esterno. # = cifra, @ = alfanumerico, * = qualsiasi carattere. Vuoto se non usato.'),
(98792, 6088, 26, 'Campione'),
(98793, 6089, 26, 'Campione numero/Identificativo'),
(98794, 6090, 26, 'Tipo di campione'),
(98795, 6092, 26, 'Dettato a voce'),
(98796, 6093, 26, 'Spermicida'),
(98797, 6094, 26, 'Splenectomia'),
(98798, 6095, 26, 'Moglie'),
(98799, 6096, 26, 'Storia della moglie'),
(98800, 6097, 26, 'Espettorato'),
(98801, 6098, 26, 'Espettorato:'),
(98802, 6099, 26, 'SQ'),
(98803, 6100, 26, 'sql'),
(98804, 6102, 26, 'Squadra'),
(98805, 6103, 26, 'Composizione squadra'),
(98806, 6104, 26, 'Squadre'),
(98807, 6105, 26, 'SRH'),
(98808, 6106, 26, 'SRH - Pianificazione famigliare'),
(98809, 6107, 26, 'SRH - Senza Pianificazione famigliare'),
(98810, 6108, 26, 'SRH Riferimenti'),
(98811, 6109, 26, 'SRH modulo visita'),
(98812, 6110, 26, 'Srv data'),
(98813, 6111, 26, 'SS'),
(98814, 6112, 26, 'Amministrazione certificato SSL'),
(98815, 6113, 26, 'SSN'),
(98816, 6114, 26, 'Stabilità'),
(98817, 6115, 26, 'Comunicati stampa'),
(98818, 6116, 26, 'Standard'),
(98819, 6117, 26, 'Codice standard'),
(98820, 6118, 26, 'Misure standard'),
(98821, 6119, 26, 'Misure standard (Avvisi attivi)'),
(98822, 6120, 26, 'Misure standard (Avvisi passivi)'),
(98823, 6121, 26, 'Misure standard (Promemoria pazienti)'),
(98824, 6122, 26, 'Nome standard'),
(98825, 6123, 26, 'Standard, semplificato: unico titolo, data di inizio, commenti e una casella di controllo attiva; nessuna diagnosi, occorrenza, data di scadenza, indicato - da o campi sportivi. , Infortunio da sport'),
(98826, 6124, 26, 'Inizio'),
(98827, 6125, 26, 'Inizio (aaaa-mm-gg): '),
(98828, 6126, 26, 'Avvia un altro report'),
(98829, 6128, 26, 'Data inizio'),
(98830, 6129, 26, 'Data di inizio in questa clinica'),
(98831, 6130, 26, 'La data di inizio non dovrebbe essere maggiore della data di fine'),
(98832, 6131, 26, 'Data inizio:'),
(98833, 6132, 26, 'Data Inizio:'),
(98834, 6133, 26, 'Ora di inizio'),
(98835, 6134, 26, 'Data iniziale'),
(98836, 6135, 26, 'stat'),
(98837, 6136, 26, 'Stato'),
(98838, 6137, 26, 'Stato tipo di dati'),
(98839, 6138, 26, 'State Lic. #'),
(98840, 6139, 26, 'Stato licenza numero'),
(98841, 6140, 26, 'Elenco degli stati'),
(98842, 6141, 26, 'Lista Stato (scrivere, aggiungere solo opzionale)'),
(98843, 6142, 26, 'Stato Lista Widget Campi personalizzati'),
(98844, 6143, 26, 'Stato o Provincia'),
(98845, 6144, 26, 'Stato/Località'),
(98846, 6145, 26, 'Stato/Comune'),
(98847, 6146, 26, 'RIEPILOGO'),
(98848, 6147, 26, 'estratti conto e fatture di aggiornamento.'),
(98849, 6148, 26, 'Riepiloghi inviati:'),
(98850, 6149, 26, 'riepiloghi, le fatture non verranno aggiornate.'),
(98851, 6150, 26, 'Testo statico'),
(98852, 6151, 26, 'Statistica'),
(98853, 6152, 26, 'Statistiche'),
(98854, 6153, 26, 'Status'),
(98855, 6154, 26, 'Stato ammissione'),
(98856, 6155, 26, 'Stato della richiesta'),
(98857, 6156, 26, 'Status quo'),
(98858, 6158, 26, 'STD/AIDS Couns'),
(98859, 6159, 26, 'Resilienza e condizionamento'),
(98860, 6163, 26, 'Procedura per caricare CCR XML'),
(98861, 6164, 26, 'Procedura per installare il database DSM IV'),
(98862, 6165, 26, 'Procedura per installare il database ICD 10'),
(98863, 6166, 26, 'Procedura per installare il database ICD 9'),
(98864, 6167, 26, 'Procedura per installare il database RxNorm'),
(98865, 6168, 26, 'Procedura per installare il database Snomed'),
(98866, 6169, 26, 'rigidità delle articolazioni'),
(98867, 6170, 26, 'Rigidezza'),
(98868, 6171, 26, 'Archivio mesi'),
(98869, 6172, 26, 'Dolori alla stomaco'),
(98870, 6173, 26, 'Stop'),
(98871, 6174, 26, 'Hash memorizzato'),
(98872, 6175, 26, 'Sforzo del muscolo'),
(98873, 6176, 26, 'Fluire'),
(98874, 6177, 26, 'Via'),
(98875, 6178, 26, 'Indirizzo via'),
(98876, 6179, 26, 'Via e numero'),
(98877, 6180, 26, 'Forza'),
(98878, 6181, 26, 'Forza e condizionamento'),
(98879, 6182, 26, 'Streptococco gola'),
(98880, 6183, 26, 'Frattura da stress'),
(98881, 6184, 26, 'Test dello stress'),
(98882, 6185, 26, 'Colpo'),
(98883, 6186, 26, 'Password forte significa almeno 8 caratteri, e con almeno 3 dei seguenti: un numero, una lettera minuscola, una lettera maiuscola, un carattere speciale.'),
(98884, 6187, 26, 'Stile'),
(98885, 6188, 26, 'Stile del modulo usato per aggiungere nuovi pazienti'),
(98886, 6189, 26, 'Sub-categoria'),
(98887, 6190, 26, 'Sub-totale'),
(98888, 6191, 26, 'Subcategoria'),
(98889, 6192, 26, 'subcategoria'),
(98890, 6193, 26, 'sottocutaneamente'),
(98891, 6194, 26, 'Oggetto'),
(98892, 6195, 26, 'Soggettivo'),
(98893, 6196, 26, 'Sublinguale'),
(98894, 6197, 26, 'sublinguale'),
(98895, 6198, 26, 'Invia'),
(98896, 6199, 26, 'invia'),
(98897, 6200, 26, 'Invia tutto il contenuto'),
(98898, 6201, 26, 'Invia'),
(98899, 6202, 26, 'Invia evento'),
(98900, 6203, 26, 'invia modulo'),
(98901, 6204, 26, 'Invia il contenuto selezionato'),
(98902, 6205, 26, 'Inviato da EDI accesso numero (PER06)'),
(98903, 6206, 26, 'Inviato da'),
(98904, 6207, 26, 'Inviato da EDI accesso numero (PER06)'),
(98905, 6208, 26, 'Sottoscrittore'),
(98906, 6209, 26, 'Indirizzo sottoscrittore'),
(98907, 6210, 26, 'Città sottoscrittore'),
(98908, 6211, 26, 'Paese sottoscrittore'),
(98909, 6212, 26, 'Data di nascita sottoscrittore'),
(98910, 6213, 26, 'Datore di lavoro sottoscrittore'),
(98911, 6214, 26, 'Datore di lavoro sottoscrittore (SE)'),
(98912, 6215, 26, 'Indirizzo datore di lavoro sottoscrittore'),
(98913, 6216, 26, 'Città datore di lavoro sottoscrittore'),
(98914, 6217, 26, 'Nazione datore di lavoro sottoscrittore'),
(98915, 6218, 26, 'Stato datore di lavoro sottoscrittore'),
(98916, 6219, 26, 'Paese datore di lavoro sottoscrittore'),
(98917, 6220, 26, 'Codice postale datore di lavoro sottoscrittore'),
(98918, 6221, 26, 'Codice postale datore di lavoro sottoscrittore'),
(98919, 6222, 26, 'Nome sottoscrittore'),
(98920, 6223, 26, 'Cognome sottoscrittore'),
(98921, 6224, 26, 'Secondo nome sottoscrittore'),
(98922, 6225, 26, 'Telefono sottoscrittore'),
(98923, 6226, 26, 'Relazioni sottoscrittore'),
(98924, 6227, 26, 'La relazione del sottoscrittore non è sua ma il nome è lo stesso! Va bene comunque?'),
(98925, 6228, 26, 'La relazione del sottoscrittore non è sua ma il SS è lo stesso! Va bene comunque?'),
(98926, 6229, 26, 'La relazione del sottoscrittore è sua ma il nome è diverso! Va bene comunque?'),
(98927, 6230, 26, 'La relazione del sottoscrittore è sua ma il SS è lo diverso! Va bene comunque?'),
(98928, 6231, 26, 'Sesso sottoscrittore'),
(98929, 6232, 26, 'SS sottoscrittore'),
(98930, 6233, 26, 'Stato sottoscrittore'),
(98931, 6234, 26, 'CAP sottoscrittore'),
(98932, 6235, 26, 'Telefono sottoscrittore'),
(98933, 6237, 26, 'Sostituzione'),
(98934, 6238, 26, 'sostituzione consentita'),
(98935, 6240, 26, 'Successo'),
(98936, 6241, 26, 'successo'),
(98937, 6242, 26, 'Conferma ricevimento riuscito dei risultati di laboratorio'),
(98938, 6243, 26, 'Ottenimento con successo dei risultati di laboratorio'),
(98939, 6244, 26, 'Recupero con successo dei risultai di laboratorio'),
(98940, 6246, 26, 'Categoria aggiunta con successo'),
(98941, 6247, 26, 'aggiunto(a) con successo alla categoria.'),
(98942, 6248, 26, 'Eliminato con successo'),
(98943, 6249, 26, 'Importato con successo i dettagli. Approvare il paziente dallo schermo in attesa di approvazione'),
(98944, 6250, 26, 'Installato il database con successo.'),
(98945, 6251, 26, 'Il database seguente è stato installato con successo'),
(98946, 6252, 26, 'Modificato con successo'),
(98947, 6253, 26, 'Salvataggio riuscito. Vuoi allocarlo?'),
(98948, 6254, 26, 'Salvataggio riuscito. Vuoi ripartirlo?'),
(98949, 6256, 26, 'registrato con successo.'),
(98950, 6257, 26, 'Aggiornamento del database riuscito.'),
(98951, 6258, 26, 'Il database seguente è stato aggiornato con successo'),
(98952, 6259, 26, 'con successo.'),
(98953, 6260, 26, 'Suicidio'),
(98954, 6261, 26, 'Sommario'),
(98955, 6262, 26, 'Sommario di'),
(98956, 6265, 26, 'Dom'),
(98957, 6266, 26, 'Sundanese'),
(98958, 6267, 26, 'Domenica'),
(98959, 6268, 26, 'Superbill'),
(98960, 6269, 26, 'Codici Superbill'),
(98961, 6270, 26, 'Amministrazione codici Superbill'),
(98962, 6271, 26, 'Report Superbill'),
(98963, 6272, 26, 'Superbill/Foglio pagamento'),
(98964, 6273, 26, 'Superbills'),
(98965, 6274, 26, 'Superbills, a volte indicato come incontro moduli o slitta Itinerario, sono una parte essenziale della maggior parte delle pratiche mediche.'),
(98966, 6275, 26, 'Superutente'),
(98967, 6276, 26, 'Supervisione'),
(98968, 6278, 26, 'Supervisione Medico DEA'),
(98969, 6279, 26, 'Nome Supervisione Medico'),
(98970, 6280, 26, 'Cognome Supervisione Medico'),
(98971, 6281, 26, 'Supervisione Medico NPI'),
(98972, 6282, 26, 'Supervisione Medico UPIN'),
(98973, 6283, 26, 'Nome struttura fornitore'),
(98974, 6284, 26, 'Supporto eventi del calendario che si applicano a più provider'),
(98975, 6285, 26, 'Supporto esportazione/importazione dei dati di configurazione tramite la pagina Backup.'),
(98976, 6286, 26, 'Supporto Multi-Fornitori Eventi'),
(98977, 6288, 26, 'Supporta solo cifratura/decifratura TrpleDES'),
(98978, 6289, 26, 'Tipo di superficie'),
(98979, 6290, 26, 'Chirurghi'),
(98980, 6291, 26, 'Chirurgia'),
(98981, 6292, 26, 'Emissione lista chirurgica'),
(98982, 6293, 26, 'Sospeso'),
(98983, 6294, 26, 'sospensione'),
(98984, 6295, 26, 'Data Svc'),
(98985, 6296, 26, 'Data Svc:'),
(98986, 6297, 26, 'Swahili'),
(98987, 6298, 26, 'Swati'),
(98988, 6299, 26, 'Sudorazione:'),
(98989, 6300, 26, 'Svedese'),
(98990, 6301, 26, 'Gonfiore'),
(98991, 6302, 26, 'Gonfiore destro'),
(98992, 6303, 26, 'Articolazioni gonfie'),
(98993, 6304, 26, 'Ingrossamento dei linfonodi'),
(98994, 6305, 26, 'Simbolo usato come punto decimale per la moneta. Non usato se i posti decimali sono 0.'),
(98995, 6306, 26, 'Simbolo usato per separare le migliaia nella moneta.'),
(98996, 6307, 26, 'Sintomi'),
(98997, 6308, 26, 'Sincronizza'),
(98998, 6309, 26, 'Sincronizza le traduzioni con la tabella custom della lingua.'),
(98999, 6310, 26, 'Nuova costante custom sincronizzata:'),
(99000, 6311, 26, 'Nuova lingua custom sincronizzata:'),
(99001, 6312, 26, 'Nuova definizione sincronizzata (Lingua, Costante, Definizione):'),
(99002, 6313, 26, 'Sincope'),
(99003, 6314, 26, 'Sorveglianza sindromica'),
(99004, 6315, 26, 'Sorveglianza sindromica - Tematiche non riportate'),
(99005, 6316, 26, 'Relazione di Sorveglianza sindromica'),
(99006, 6317, 26, 'Sinovite, contusione, borsite'),
(99007, 6318, 26, 'Sistema'),
(99008, 6322, 26, 'T'),
(99009, 6323, 26, 't.i.d.'),
(99010, 6324, 26, 'T.V.'),
(99011, 6325, 26, 'Tabella'),
(99012, 6327, 26, 'Creazione della tabella fallita'),
(99013, 6328, 26, 'Aggiornamento Tabella fallito'),
(99014, 6329, 26, 'Tabelle'),
(99015, 6330, 26, 'compressa'),
(99016, 6331, 26, 'Tag per incontro'),
(99017, 6332, 26, 'Tagalog'),
(99018, 6333, 26, 'Tahitian'),
(99019, 6334, 26, 'Tajik'),
(99020, 6335, 26, 'Prendere'),
(99021, 6336, 26, 'Prendere l''assicurazione dalla casella a tendina'),
(99022, 6337, 26, 'Prendere il pagamento dalla casella a tendina'),
(99023, 6338, 26, 'programma di recupero'),
(99024, 6339, 26, 'prende tempo'),
(99025, 6340, 26, 'Area di navigazione in alto'),
(99026, 6341, 26, 'Tamil'),
(99027, 6342, 26, 'Data manomissione'),
(99028, 6343, 26, 'Tampered Checksum'),
(99029, 6344, 26, 'Destinazione e origine DOB(data nascita) non corrispondono'),
(99030, 6345, 26, 'Destinazione e origine pid non possono essere la stessa cosa!'),
(99031, 6346, 26, 'Destinazione e origine SSN non corrispondono'),
(99032, 6347, 26, 'Data destinazione'),
(99033, 6348, 26, 'Destinazione paziente'),
(99034, 6349, 26, 'Il paziente di destinazione non ha DOB(data di nascita)'),
(99035, 6350, 26, 'Destinazione paziente non trovata'),
(99036, 6351, 26, 'Obiettivo/Azione di gruppo'),
(99037, 6352, 26, 'Tatar'),
(99038, 6354, 26, 'ID imposta'),
(99039, 6355, 26, 'Aliquota d''imposta'),
(99040, 6356, 26, 'Imposte'),
(99041, 6357, 26, 'Tassonomia'),
(99042, 6358, 26, 'Td'),
(99043, 6359, 26, 'Squadra infortuni: presentazione'),
(99044, 6360, 26, 'Elenco squadra'),
(99045, 6361, 26, 'Visualizza elenco squadra'),
(99046, 6362, 26, 'Squadra/Equipe'),
(99047, 6363, 26, 'Tel'),
(99048, 6364, 26, 'Prefisso telefonico nazione'),
(99049, 6365, 26, 'Telugu'),
(99050, 6366, 26, 'Temp'),
(99051, 6367, 26, 'Sede Temp'),
(99052, 6368, 26, 'Metodo Temp'),
(99053, 6369, 26, 'Temperatura'),
(99054, 6370, 26, 'Modello'),
(99055, 6371, 26, 'Nome modello'),
(99056, 6372, 26, 'Il nome del modello non può partire con un numero.'),
(99057, 6373, 26, 'Modello:'),
(99058, 6374, 26, 'Modelli'),
(99059, 6375, 26, 'Arteria temporale'),
(99060, 6376, 26, 'Lesione al tendine'),
(99061, 6377, 26, 'Tendinite/osis/borsite'),
(99062, 6378, 26, 'Rif.N.Fattura provvisiorio'),
(99063, 6379, 26, 'Terziario'),
(99064, 6380, 26, 'Terza assicurazione'),
(99065, 6381, 26, 'Data terzassicurazione'),
(99066, 6382, 26, 'Fornitore terza assicurazione'),
(99067, 6383, 26, 'Test di programmazione'),
(99068, 6384, 26, 'Test di sistema'),
(99069, 6385, 26, 'Testo'),
(99070, 6386, 26, 'Testo Diagnosi'),
(99071, 6387, 26, 'Campo testo'),
(99072, 6393, 26, 'Data-testo'),
(99073, 6394, 26, 'data-testo'),
(99074, 6395, 26, 'Area di testo'),
(99075, 6396, 26, 'area di testo'),
(99076, 6397, 26, 'Casella di testo'),
(99077, 6398, 26, 'casella di testo'),
(99078, 6399, 26, 'Elenco di caselle di testo'),
(99079, 6400, 26, 'elenco di caselle di testo'),
(99080, 6401, 26, 'Tahilandese'),
(99081, 6402, 26, 'Grazie'),
(99082, 6403, 26, 'Grazie di averci preferito'),
(99083, 6404, 26, 'Il pulsante "Pulisci" rimuoverà tutte le annotazioni.'),
(99084, 6405, 26, 'La dichiarazione di cui sopra è fallita'),
(99085, 6406, 26, 'Il certificato del server SSL Apache e chiave pubblica'),
(99086, 6407, 26, 'Il cetificato dell''Autorità di certificazione'),
(99087, 6408, 26, 'La richiesta del file: '),
(99088, 6409, 26, 'La compatibilità organizzata del pacchetto estensioni US SNOMED è già stato installato.'),
(99089, 6410, 26, 'La corrispndente chiave privata'),
(99090, 6411, 26, 'Il test di integrità dei dati non è riuscito per il presente modulo'),
(99091, 6413, 26, 'La negazione è il codice'),
(99092, 6414, 26, 'La negazione di gruppo è il codice'),
(99093, 6415, 26, 'Il modulo di destinazione era chiuso'),
(99094, 6416, 26, 'Il modulo di destinazione era chiuso; non posso agire sulla tua slezione.'),
(99095, 6417, 26, 'L''entità di eseguire questa procedura'),
(99096, 6418, 26, 'Il PE, ospedale ammissibile o CAH che riceve un paziente da un altro contesto di cura o il fornitore di cure o crede che un incontro è rilevante dovrebbe eseguire la riconciliazione farmaci.'),
(99097, 6421, 26, 'Il PE, ospedale o CAH chi transizioni il loro paziente ad un altro contesto di cura o il fornitore di cure o riferisce il loro paziente ad un altro fornitore di cure ammissibile dovrebbero fornire sintesi dei record di cura per ogni transizione di cura e rinvio.'),
(99098, 6422, 26, 'Gli eventi sono stati approvati.'),
(99099, 6423, 26, 'Gli eventi sono stati nascosti.'),
(99100, 6424, 26, 'I dati esportati appaiono nella seguente area di testo. puoi copiarli e incollarli in un email o altra destinazione desiderata.'),
(99101, 6426, 26, 'I dati esportati appaiono nella seguente area di testo. puoi copiarli e incollarli in un email o altra destinazione desiderata.'),
(99102, 6427, 26, 'I dati esportati appaiono nella seguente area di testo. puoi copiarli e incollarli in un email o altra destinazione desiderata.'),
(99103, 6428, 26, 'Il file non può essere salvato nel CouchDB'),
(99104, 6429, 26, 'Non si è potuto rinominare con successo il file, questo errore usualmente è dovuto a problemi di permessi sul sistema di memorizzazione.'),
(99105, 6430, 26, 'Il file non può essere memorizzato con successo, questo errore è di solito correlato a problemi di autorizzazioni sul sistema di archiviazione'),
(99106, 6431, 26, 'Il primo ("target") grafico è quello che è considerato il più completo e preciso.Dati demografici e le sessioni per le assicurazioni verranno mantenute.'),
(99107, 6433, 26, 'Il primo passo è quello di aprire un account con il sito web Unified Medical Language System'),
(99108, 6434, 26, 'E'' stato aggiunto il seguente evento di calendario:'),
(99109, 6435, 26, 'E'' stato modificato il seguente evento di calendario:'),
(99110, 6436, 26, 'Le seguenti categorie saranno rimosse dall''elenco delle categorie'),
(99111, 6437, 26, 'E'' stata installata la seguente release del database'),
(99112, 6438, 26, 'I seguenti documenti sono stati allegati al presente messaggio diretto:'),
(99113, 6439, 26, 'E'' stato caricato il seguente file EDI'),
(99114, 6440, 26, 'E'' attivato il seguente login di emergenza per l''utente:'),
(99115, 6441, 26, 'Sono avvenuti i seguenti errori'),
(99116, 6442, 26, 'Il campo seguente ha un valore non valido'),
(99117, 6444, 26, 'Sono richiesti i seguenti campi'),
(99118, 6446, 26, 'I campi seguenti sonos stati compilati per inviare la richiesta.'),
(99119, 6447, 26, 'Le seguenti lingue internazionali rilasciate di SNOMED sono supportate'),
(99120, 6448, 26, 'I seguenti problemi hanno gli stessi codici di diagnosi. Questioni dell''incontro non verranno aggiornate. Si prega di utilizzare, invece, l''interfaccia di incontro.'),
(99121, 6449, 26, 'L''hostname della macchina archivio di controllo ATNA.'),
(99122, 6450, 26, 'La finestra iniziale è la pagina di ricerca delle fatture. In testa puoi entrare una origine (p.es. un numero di assegno), la data di pagamento e l''ammontare dell''assegno. Il motivo per cui l''origine e la data di pagamento sono così è che non devi entrarli più e più volte per ciascuna richiesta. L''ammontare che inserisci decrescerà per ogni fattura che è parte del pagamento, e sperbilmente finirà con zero quando hai finito.'),
(99123, 6451, 26, 'La directory di installazione ha bisogno di essere creata.'),
(99124, 6452, 26, 'La versione di SNOMED internazionale installata non è compatibile con il pacchetto preparato US Extension SNOMED.'),
(99125, 6453, 26, 'La versione di SNOMED Internazionale installata non è aggiornata e non è compatibile con il file US Extension SNOMED preparato.'),
(99126, 6454, 26, 'La versione installata e i file organizzati sono gli stessi.'),
(99127, 6455, 26, 'La versione installata è una versione più recente rispetto ai file organizzato.'),
(99128, 6456, 26, 'L''etichetta che appare all''utente sul modulo'),
(99129, 6457, 26, 'La lunghezza non dovrebbe eccedere il seguente numero di caratteri'),
(99130, 6458, 26, 'La fusione non sia avvia finchè SSN e DOB per i due grafici sono identici. DOBs non possono essere vuoti.'),
(99131, 6459, 26, 'Il messaggio non può essere inviato in questo momento.'),
(99132, 6460, 26, 'La nuova categoria sarà una subcategoria di '),
(99133, 6461, 26, 'La nuova password non può essere la stessa dell''attuale password'),
(99134, 6462, 26, 'I campi della nuova password non sono gli stessi.'),
(99135, 6463, 26, 'Il numero di file organizzati non è corretto. Posizionare solo i file che si desidera installare/aggiornare.'),
(99136, 6464, 26, 'Il numero di file organizzati non è corretto. Posizionare solo i file che si desidera installare/aggiornare.'),
(99137, 6465, 26, 'La pagina verrà reindirizzata alla Demografica. È possibile modificare il campo del paese e fare clic su fino al nuovo NewCrop.'),
(99138, 6466, 26, 'La password deve essere di almeno otto caratteri, e dovrebbe'),
(99139, 6467, 26, 'La password inserita non è corretta'),
(99140, 6468, 26, 'La richiesta di registrazione del paziente è stata registrata.'),
(99141, 6469, 26, 'I promemoria dei pazienti sono stati inviati'),
(99142, 6470, 26, 'I promemoria dei pazienti sono stati aggiornati'),
(99143, 6471, 26, 'Il paziente non è stato registrato in questo modulo'),
(99144, 6472, 26, 'Il pagamento inviato non può andare sotto questa data. Questo assicura che dopo aver emesso il resoconto finale nessuno invii per date precedenti.'),
(99145, 6473, 26, 'Il portale ha dati per questo paziente e formulario. Caricare ora?'),
(99146, 6474, 26, 'Il feed di dati raw di rilascio può essere ottenuto da'),
(99147, 6475, 26, 'Le restanti informazioni seguenti si applicano solo se stai inviando manualmente, o se stai facendo correzioni manuali.'),
(99148, 6476, 26, 'Il documento richiesto non è presente nella posizione prevista sul filesystem o non ci sono autorizzazioni sufficienti per accedervi'),
(99149, 6477, 26, 'Il documento richiesto non è presente nella collocazione attesa sul filesystem oppure non ci sono sufficienti permessi per accedervi.'),
(99150, 6479, 26, 'Il secondo grafico ("origine") avrà le sue sezioni demografia, cronologia e assicurazioni scartati. Gli altri suoi dati saranno uniti nel grafico di destinazione.'),
(99151, 6480, 26, 'Le colonne Origine e Data sono copiate dalla prima pagina, così normalemente non le dovrai toccare. Puoi mettere un ammontare di pagamento nella colonna Paga, una rimodulazione dell''importo nella colonna Rimodula, o entrambe. Puoi anche cliccare la "W" sulla destra per calcolare automaticamente una valore rimodulazione che emetta il promemoria del costo per quell''elemento della linea.'),
(99152, 6481, 26, 'Le date di rilascio dei file organizzati non sono tutti della stessa versione.'),
(99153, 6482, 26, 'Le revisioni dei file organizzati non sono tutti della stessa versione.'),
(99154, 6483, 26, 'Il pacchetto organizzato US Extension SNOMED può essere installato soltanto dopo aver installato il pacchetto di SNOMED internazionale.'),
(99155, 6484, 26, 'La granularità del tempo dell''agenda e il più piccolo intervallo in minuti per la durata di un appuntamento (slot).'),
(99156, 6485, 26, 'La traduzione dell''etichetta che apparirà nela lingua corrente'),
(99157, 6486, 26, 'La traduzione del Titolo che apparirà nella lingua corrente'),
(99158, 6487, 26, 'La traduzione della descrizione nella lingua corrente'),
(99159, 6488, 26, 'Le tabelle delle traduzioni sono sincronizzate'),
(99160, 6489, 26, 'Il tipo di questa entità'),
(99161, 6490, 26, 'Il codice specifico del ventitore identificante questa procedura o risultato'),
(99162, 6491, 26, 'Il file X12, nonché i rapporti di output HTML risultante vengono archiviati nell''"era" della directory di installazione LibreEHR principale. Si vuole fare riferimento a questi archivi di volta in volta. L''URL è'),
(99163, 6492, 26, 'Il file zip contine i seguenti elementi'),
(99164, 6493, 26, 'Tema'),
(99165, 6494, 26, 'Poi la fornitura di dati raw di rilascio può essere ottenuto da'),
(99166, 6495, 26, 'Terapia iniettiva'),
(99167, 6496, 26, 'Ci sono'),
(99168, 6497, 26, 'Attualmente non ci sono prescrizioni.'),
(99169, 6498, 26, 'Ci sono errori nel tuo inserimento. Sono descritti d seguito.'),
(99170, 6499, 26, 'Ci sono più pazienti con login al portale'),
(99171, 6500, 26, 'Non ci sono grafici estratti.'),
(99172, 6501, 26, 'Non ci sono informative registrate per questo paziente.'),
(99173, 6502, 26, 'Non ci sono nuovi inserimenti'),
(99174, 6503, 26, 'Non ci sono note sul file per questo paziente.'),
(99175, 6504, 26, 'Non ci sono transazioni sul file per questo paziente.'),
(99176, 6505, 26, 'C''è stato un errore di posta elettronica nell''invio a'),
(99177, 6506, 26, 'C''è già una categoria denominata'),
(99178, 6507, 26, 'C''è già una subcategoria denominata'),
(99179, 6508, 26, 'C''è già un elemento denominato'),
(99180, 6509, 26, 'C''è già una richiesta di record del paziente aperta.'),
(99181, 6510, 26, 'Non vi è alcuna voce COA per conto AR '),
(99182, 6511, 26, 'Non vi è alcuna voce COA per conto di cassa '),
(99183, 6512, 26, 'Non vi è alcuna voce COA per conto economico '),
(99184, 6513, 26, 'Non c''è un paziente corrente'),
(99185, 6514, 26, 'Non ci sono contenuti locali per questo argomento.'),
(99186, 6515, 26, 'Non ci sono corrispondenze per la fattura id'),
(99187, 6516, 26, 'Non ci sono corrispondenze per la fattura id= '),
(99188, 6517, 26, 'Non vi è alcuna voce componenti per i servizi di ID '),
(99189, 6518, 26, 'Non vi è alcun paziente con login al portale'),
(99190, 6519, 26, 'C''è stato un errore nell''invio del messaggio.'),
(99191, 6520, 26, 'C''è stato un errore mentre elaboravo la richiesta.'),
(99192, 6521, 26, 'E'' sfuggito un ERRORE in LibreEHR alla seguente stringa'),
(99193, 6522, 26, 'Questi sono i link 2012'),
(99194, 6523, 26, 'Inspessito a destra:'),
(99195, 6524, 26, 'Coscia'),
(99196, 6525, 26, 'Coscia + tendine'),
(99197, 6526, 26, 'Cose di back office che si possono solo leggere'),
(99198, 6527, 26, 'Cose di back office che si possono leggere e inserire, ma non modificare'),
(99199, 6528, 26, 'Cose di back office che si possono leggere e modificare'),
(99200, 6529, 26, 'Cose di back office che si possono leggere e modificare parzialmente'),
(99201, 6530, 26, 'Le cose che i medici possono solo leggere'),
(99202, 6531, 26, 'Le cose che i medici possono leggere e inserire, ma non modificare'),
(99203, 6532, 26, 'Le cose che i medici possono leggere e modificare'),
(99204, 6533, 26, 'Le cose che i medici possono leggere e modificare parzialmente'),
(99205, 6534, 26, 'Cose che lo sportello può solo leggere'),
(99206, 6535, 26, 'Cose che lo sportello può leggere e inserire ma non modificare'),
(99207, 6536, 26, 'Cose che lo sportello può leggere e modificare'),
(99208, 6537, 26, 'Cose che lo sportello può leggere e modificare parzialmente'),
(99209, 6538, 26, 'Cose che i medici possono solo leggere'),
(99210, 6539, 26, 'Cose che i medici possono leggere e inserire ma non modificare'),
(99211, 6540, 26, 'Cose che i medici possono leggere e modificare'),
(99212, 6541, 26, 'Cose che i medici possono leggere e modificare parzialmente'),
(99213, 6542, 26, 'Terzo'),
(99214, 6544, 26, 'Questa azione NON PUO'' essere annullata.'),
(99215, 6545, 26, 'Questa azione non può essere annullata.'),
(99216, 6547, 26, 'Questa azione sarà registrata nei log.'),
(99217, 6549, 26, 'Questo slot appuntamento è già utilizzato, usare comunque?'),
(99218, 6550, 26, 'Questo slot appuntamento non è disponibile, si prega di sceglierne un altro.'),
(99219, 6551, 26, 'Questo anno dell''agenda'),
(99220, 6552, 26, 'Questa richiesta è stata annullata.'),
(99221, 6553, 26, 'Questa richiesta è stata chiusa.'),
(99222, 6554, 26, 'Questa richiesta è stata respinta. Motivo:'),
(99223, 6555, 26, 'Questa richiesta è stata inoltrata a livello successivo.'),
(99224, 6556, 26, 'Questo tipo di codice non acetta relazioni.'),
(99225, 6557, 26, 'Questo contesto contiene categorie, che saranno eliminate. Vuoi ancora continuare?'),
(99226, 6558, 26, 'Questo determina come gli appuntamenti sono mostrati sul calendario'),
(99227, 6559, 26, 'Questo determina lo schema di colore per gli appuntamenti'),
(99228, 6561, 26, 'Questo Incontro'),
(99229, 6562, 26, 'Questo incontro è stato fatturato. Se avete bisogno di cambiare, deve essere riaperta.'),
(99230, 6563, 26, 'Questo incontro è bloccato. Non puoi aggiungere un nuovo formulario'),
(99231, 6564, 26, 'Questa caratteristica non è ancora disponibile'),
(99232, 6565, 26, 'Questa caratteristica è molto sperimentale e non testata completamente. Usala a tuo rischio!'),
(99233, 6566, 26, 'Qusto numero di fattura è stato cambiato in '),
(99234, 6569, 26, 'Questa è la tabella che confluirà nel grafico principale e quindi cancellato.'),
(99235, 6571, 26, 'Questa è la tabella principale che deve ricevere i dati uniti.'),
(99236, 6572, 26, 'questa posizione'),
(99237, 6573, 26, 'Questo messaggio non viene salvato automaticamente. Copiare e salvarlo a seconda dei casi per il contenuto.'),
(99238, 6574, 26, 'Questo modulo è utilizzato da '),
(99239, 6575, 26, 'Questo modulo è in modo test. Il database non sarà cambiato.'),
(99240, 6576, 26, 'Questo modulo promuove un inserimento efficiente di dati EOB.'),
(99241, 6577, 26, 'Questo mese alla Data'),
(99242, 6578, 26, 'Questo ordine è stato trasmesso in'),
(99243, 6579, 26, 'Questa pagina consente di esaminare ciascuno dei dataloads supportati esterni che è possibile installare e aggiornare. Ogni sezione di seguito può essere espanso facendo clic sull''intestazione della sezione per esaminare lo stato della base di dati di particolare interesse.'),
(99244, 6580, 26, 'Questa pagina è disattivata per motivi di sicurezza.'),
(99245, 6581, 26, 'Questa pagina includerà in linea la pagina di ingresso,così che non dovrai cliccare per il re-ingresso ogni volta.'),
(99246, 6582, 26, 'Questo paziente non ha attività.'),
(99247, 6583, 26, 'Questo ID del paziente è già in uso!'),
(99248, 6584, 26, 'Questo prodotto consente solo un lotto per magazzino.'),
(99249, 6585, 26, 'Questo protocollo non è implementato'),
(99250, 6586, 26, 'Questo rapporto attualmente funziona solo per i codici ICD9.'),
(99251, 6591, 26, 'Questo passaggio genererà un file che dovrai salvare per usi futuri. Il file non può essere generato di nuovo. Vuoi procedere?'),
(99252, 6592, 26, 'Questo utente non è un membro di alcun gruppo'),
(99253, 6593, 26, 'L''utente riceverà la notifica di nuovi messaggi in arrivo diretti'),
(99254, 6594, 26, 'Questa utility è sperimentale. Eseguire il backup del database e documenti prima di utilizzarlo!'),
(99255, 6595, 26, 'Questa visita dà inizio all''uso di un nuovo contraccettivo'),
(99256, 6596, 26, 'Questa visita avrà bisogno di un servizio di GCAC modulo, rinvio o una procedura.'),
(99257, 6597, 26, 'Questo era il modulo Vitali più vecchio, ora deprecato.'),
(99258, 6598, 26, 'Questa settimana alla Data'),
(99259, 6600, 26, 'Questo attiverà la segnalazione CCR (Continuity of Record Care) e CCD (Continuità del documento Care).'),
(99260, 6602, 26, 'Questo consentirà la selezione del debugging della lingua (''dummy'').'),
(99261, 6605, 26, 'Questo sarà un "ciclo di prova" senza aggiornamenti dei dati fisici.'),
(99262, 6606, 26, 'Questo creerà un backup in formato tar inviandolo al tuo browser così che tu possa salvarlo'),
(99263, 6607, 26, 'Questo disattiverà la caratteristica di criptare decriptare documenti, e la nasconderà nella Interfaccia Utente.'),
(99264, 6613, 26, 'Questo forzerà il widget delle fatturazioni nella schermata Sommario Paziente a essere sempre aperto.'),
(99265, 6616, 26, 'Questo vi permette di unire due tabelle pazienti in uno. E'' utile quando un paziente è stato duplicato per errore. Se ciò accade spesso, riparare le vostre procedure di ufficio - non eseguire questa routine!'),
(99266, 6617, 26, 'Ciò non vi impedirà di andare al sito di prescrizioni elettroniche.'),
(99267, 6619, 26, 'Questo userà un elenco immunizzazioni personalizzato piuttosto che l''elenco immunizzazioni standard CVX'),
(99268, 6622, 26, 'Colonna toracica'),
(99269, 6623, 26, 'Thous/CU.MM'),
(99270, 6625, 26, 'Gola'),
(99271, 6626, 26, 'Cancro alla gola'),
(99272, 6627, 26, 'Intervento per cancro alla gola'),
(99273, 6628, 26, 'Trombosi/Stroke'),
(99274, 6629, 26, 'Gio'),
(99275, 6630, 26, 'Giovedì'),
(99276, 6631, 26, 'Giovedì'),
(99277, 6632, 26, 'Tiroide normale'),
(99278, 6633, 26, 'Problemi alla tiroide'),
(99279, 6634, 26, 'TIA'),
(99280, 6636, 26, 'TID'),
(99281, 6638, 26, 'Ora'),
(99282, 6639, 26, 'Formato di presentazione dell''ora'),
(99283, 6640, 26, 'Incremento temporale da aggiungere (minuti 1-60)'),
(99284, 6641, 26, 'Selezione dell''ora'),
(99285, 6642, 26, 'Lo slot di tempo è aperto, salvare l''evento'),
(99286, 6647, 26, 'Ora dell''evento fissata'),
(99287, 6648, 26, 'Matrice tempi (N/D)'),
(99288, 6649, 26, 'Testo e timestamp'),
(99289, 6650, 26, 'TIN'),
(99290, 6651, 26, 'Tinnito'),
(99291, 6652, 26, 'Titolo'),
(99292, 6653, 26, 'Titolo V'),
(99293, 6654, 26, 'Le ColTit devono essere un numero tra 1 e 999'),
(99294, 6655, 26, 'Titoli'),
(99295, 6656, 26, 'TM''S:'),
(99296, 6657, 26, 'TMs/EAMs/EE, ext nose'),
(99297, 6658, 26, 'A'),
(99298, 6659, 26, 'A'),
(99299, 6660, 26, 'al percorso assoluto del file'),
(99300, 6661, 26, 'al percorso assoluto del file'),
(99301, 6662, 26, 'Per aggiunger note clicca '),
(99302, 6663, 26, 'Per aggiunger note, clicca qui'),
(99303, 6664, 26, 'Per l''area interessata'),
(99304, 6665, 26, 'Per l''area interessata'),
(99305, 6666, 26, 'Per aprire automaticamente il modulo specificato. Alcune squadre sportive qui usano football_injury_audit'),
(99306, 6667, 26, 'Alla vista Fatturazione'),
(99307, 6668, 26, 'alla categoria'),
(99308, 6669, 26, 'Alla vista Clinica'),
(99309, 6670, 26, 'Al copagamento'),
(99310, 6672, 26, 'Per raddoppiare'),
(99311, 6673, 26, 'Per Dems'),
(99312, 6674, 26, 'Per disabilitare i certificati SSL lato Client, commenta le linee sopradette nel file di configurazione di Apache e setta'),
(99313, 6675, 26, 'Per disabilitare l''HTTPS, commenta le linee sopradette nel file di configurazione di Apache e riavvia il server Apache'),
(99314, 6676, 26, 'Per abiitare i certificati ssl lato Client'),
(99315, 6677, 26, 'Per abilitare i certificati di autentificazione SSL lato Client, dovrebbe essere abilitato l''HTTPS'),
(99316, 6678, 26, 'Per abilitare solo l''HTTPS, effettua i sopraddetti cambiamenti e riavvia il server Apache. Se vuoi configurare anche i certificati lato Client, configurali nella prossima sezione.'),
(99317, 6679, 26, 'Alla cifr'),
(99318, 6680, 26, 'Al filtro per sesso'),
(99319, 6681, 26, 'Allo storico'),
(99320, 6682, 26, 'Alle tematiche'),
(99321, 6683, 26, 'Per collegare questo incontro/consulto a una tematica esistente, clicca il '),
(99322, 6684, 26, 'Per collegare questo incontro/consulto a una tematica esistente, clicca la tematica desiderata soprastante per illuminarla e quindi clicca [Salva. Tieni premuto il pulsante [Ctrl] per selezionare più tematiche.'),
(99323, 6685, 26, 'per entrare di nuovo');
INSERT INTO `lang_definitions` VALUES
(99324, 6686, 26, 'Per registrare le informative, clicca'),
(99325, 6687, 26, 'per l''esecuzione'),
(99326, 6688, 26, 'Per settare l''accesso https con autentificazione certicata del client, fai quanto segue'),
(99327, 6689, 26, 'Alla Pelle'),
(99328, 6690, 26, 'alla pelle'),
(99329, 6691, 26, 'a questa visita?'),
(99330, 6693, 26, 'A:'),
(99331, 6694, 26, 'A: '),
(99332, 6695, 26, 'TO_CITY'),
(99333, 6696, 26, 'TO_FAX'),
(99334, 6697, 26, 'TO_FNAME'),
(99335, 6698, 26, 'TO_LNAME'),
(99336, 6699, 26, 'TO_MNAME'),
(99337, 6700, 26, 'TO_ORGANIZATION'),
(99338, 6703, 26, 'TO_POSTAL'),
(99339, 6704, 26, 'TO_STATE'),
(99340, 6705, 26, 'TO_STREET'),
(99341, 6706, 26, 'TO_TITLE'),
(99342, 6707, 26, 'TO_VALEDICTORY'),
(99343, 6708, 26, 'Tabacco'),
(99344, 6709, 26, 'Tabacco Cessazione Intervento'),
(99345, 6710, 26, 'Tabacco Cessazione Intervento (CQM)'),
(99346, 6712, 26, 'Uso tabacco'),
(99347, 6713, 26, 'Valutazione uso del tabacco (CQM)'),
(99348, 6714, 26, 'Valutazione uso del tabacco (CQM)'),
(99349, 6715, 26, 'Oggi'),
(99350, 6716, 26, 'OGGI'),
(99351, 6717, 26, 'oggi'),
(99352, 6718, 26, 'Saldoi di oggi'),
(99353, 6719, 26, 'Spesae di oggi'),
(99354, 6720, 26, 'Data di oggi'),
(99355, 6721, 26, 'Eventi di oggi'),
(99356, 6723, 26, 'ID Token per il Medical Information Integration, LLC Lab Service Exchange.'),
(99357, 6724, 26, 'ID Token per il supporto LLC Lab Service Exchange LibreEHR.'),
(99358, 6726, 26, 'Tonsillectomia'),
(99359, 6728, 26, 'In alto'),
(99360, 6730, 26, 'Argomento'),
(99361, 6731, 26, 'Totale'),
(99362, 6732, 26, 'totale'),
(99363, 6733, 26, 'Totale azioni attive'),
(99364, 6734, 26, 'Totale dei promemoria attivi dopo l''aggiornamento'),
(99365, 6735, 26, 'Totale dei promemoria attivi prima dell''aggiornamento'),
(99366, 6737, 26, 'Totale importo dovuto'),
(99367, 6738, 26, 'Totale importo pagato'),
(99368, 6739, 26, 'Totale saldo dovuto'),
(99369, 6740, 26, 'Spesa totale'),
(99370, 6741, 26, 'Totale spese'),
(99371, 6742, 26, 'Totale clienti'),
(99372, 6743, 26, 'Costo totale'),
(99373, 6744, 26, 'Il totale della ripartizione per il seguente numero di assegno non è completo'),
(99374, 6745, 26, 'Entrate totali'),
(99375, 6746, 26, 'Totale dei promemoria inviati via email falliti'),
(99376, 6747, 26, 'Totale dei promemoria inviati via telefono falliti'),
(99377, 6748, 26, 'Totale per'),
(99378, 6749, 26, 'Totale per '),
(99379, 6750, 26, 'Totale per categoria'),
(99380, 6751, 26, 'Totale dei promemoria non attivati'),
(99381, 6752, 26, 'Totale dei nuovi promemoria'),
(99382, 6753, 26, 'Numero totale appuntamenti'),
(99383, 6755, 26, 'Numero totale di Immunizzazioni'),
(99384, 6756, 26, 'Numero totale di Tematiche'),
(99385, 6758, 26, 'Numero totale di Pazienti'),
(99386, 6760, 26, 'Saldo totale paziente'),
(99387, 6761, 26, 'Totale Pazienti'),
(99388, 6764, 26, 'Totale Record trovati'),
(99389, 6765, 26, 'Totale SRH & Pianificazione familiare'),
(99390, 6766, 26, 'Totale dei promemoria inviati con successo via email'),
(99391, 6767, 26, 'Totale dei promemoria inviati con successo via telefono'),
(99392, 6770, 26, 'Totale dei promemoria non cambiati'),
(99393, 6771, 26, 'Totale dei promemoria non inviati dopo il processo di invio'),
(99394, 6772, 26, 'Totale dei promemoria non inviati dopo l''aggiornamento'),
(99395, 6773, 26, 'Totale dei promemoria non inviati prima del processo di invio'),
(99396, 6774, 26, 'Totale dei promemoria non inviati prima dell''aggiornamento'),
(99397, 6775, 26, 'Totale dei promemoria aggiornati'),
(99398, 6776, 26, 'Totali'),
(99399, 6777, 26, 'Totali per'),
(99400, 6778, 26, 'Totali per '),
(99401, 6780, 26, 'to{{range}}'),
(99402, 6785, 26, 'Tipo Addestramento'),
(99403, 6786, 26, 'Transaz'),
(99404, 6787, 26, 'Transazione'),
(99405, 6788, 26, 'transazione'),
(99406, 6789, 26, 'Transazione fallita, quantità insufficiente nel lotto destinazione'),
(99407, 6790, 26, 'Transazione fallita, la quantità è minore di zero'),
(99408, 6791, 26, 'Tipo di transazione'),
(99409, 6792, 26, 'transazioni'),
(99410, 6793, 26, 'Transazioni'),
(99411, 6794, 26, 'Transazioni (scrittura opzionale)'),
(99412, 6795, 26, 'Transazioni/Riferimenti'),
(99413, 6797, 26, 'Trasferimento'),
(99414, 6798, 26, 'Data trasferimento'),
(99415, 6799, 26, 'Trasferimento fallito, quantità insufficiente nel lotto di origine'),
(99416, 6800, 26, 'Sommario trasferimento'),
(99417, 6801, 26, 'Trasferito a'),
(99418, 6804, 26, 'Trasferimenti'),
(99419, 6806, 26, 'Transizione/Trasferimento di cura?'),
(99420, 6807, 26, 'Traduci Controlli di Accesso dei Gruppi'),
(99421, 6808, 26, 'Traduci Categorie Appuntamenti'),
(99422, 6809, 26, 'Traduci Categorie Documento'),
(99423, 6810, 26, 'Traduci i Layout'),
(99424, 6811, 26, 'Traduci Elenchi'),
(99425, 6812, 26, 'Traduci Titoli nota paziente'),
(99426, 6813, 26, 'traduci questo'),
(99427, 6814, 26, 'Traduzione'),
(99428, 6815, 26, 'Traduzioni'),
(99429, 6816, 26, 'Trasmettere'),
(99430, 6817, 26, 'Trasmissione fallita'),
(99431, 6818, 26, 'Trasmettere agli ordini selezionati'),
(99432, 6819, 26, 'Trauma'),
(99433, 6820, 26, 'Trattamento:'),
(99434, 6822, 26, 'Obiettivi del trattamento'),
(99435, 6823, 26, 'Piano di trattamento'),
(99436, 6824, 26, 'Pianificazione del trattamento'),
(99437, 6825, 26, 'Trattamento ricevuto'),
(99438, 6826, 26, 'Trattamento:'),
(99439, 6827, 26, 'Trattamento: '),
(99440, 6828, 26, 'Tendenza'),
(99441, 6829, 26, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) ); $month_value'),
(99442, 6830, 26, 'Punto di innesco / scomparto sindrome / DOMS / crampi'),
(99443, 6831, 26, 'Trimalleolare'),
(99444, 6832, 26, 'Tronco e addome'),
(99445, 6835, 26, 'Tentativo di creare utenti con nome utente esistente!'),
(99446, 6837, 26, 'tsp'),
(99447, 6839, 26, 'TTS'),
(99448, 6840, 26, 'Tubercolosi'),
(99449, 6841, 26, 'Mar'),
(99450, 6842, 26, 'Mart &amp; Giov'),
(99451, 6843, 26, 'Martedì'),
(99452, 6844, 26, 'Tumore'),
(99453, 6845, 26, 'Turco'),
(99454, 6848, 26, 'due volte al dì'),
(99455, 6850, 26, 'Membrana timpanica'),
(99456, 6851, 26, 'Tipo'),
(99457, 6852, 26, 'Tipo di Id o Nome. Minimo 3 caratteri (incluso gli spazi)'),
(99458, 6853, 26, 'Tipi di colonne mostrate per i risultati della ricerca paziente'),
(99459, 6854, 26, 'Tipo di informativa'),
(99460, 6855, 26, 'Tipo di eventi'),
(99461, 6856, 26, 'Tipo di layout dello schermo'),
(99462, 6857, 26, 'Scrivi o scansiona qui l''identificatore del paziente'),
(99463, 6858, 26, 'Inserisci il tuo messaggio qui'),
(99464, 6859, 26, 'Tipi di Ordini e Risultati'),
(99465, 6864, 26, 'Codici UCSMC forniti dall''Università di Calgary Centro di Medicina Sportiva'),
(99466, 6865, 26, 'Ucraino'),
(99467, 6866, 26, 'Ulcerazioni'),
(99468, 6867, 26, 'Colite ulcerosa'),
(99469, 6868, 26, 'Ulcere:'),
(99470, 6871, 26, 'Impossibile creare'),
(99471, 6874, 26, 'Non in grado di corrispondere il pagamento in ar_activity'),
(99472, 6876, 26, 'Non applicato'),
(99473, 6877, 26, 'Non assegnato'),
(99474, 6878, 26, 'Non autorizzato'),
(99475, 6879, 26, 'Accesso non autorizzto alla e-Prescrizione'),
(99476, 6880, 26, 'Accesso non autorizzato.'),
(99477, 6881, 26, 'Non fatturato'),
(99478, 6882, 26, 'Solo non fatturati'),
(99479, 6884, 26, 'sottolinguale'),
(99480, 6885, 26, 'Sottopeso'),
(99481, 6886, 26, 'Non diagnosticato'),
(99482, 6887, 26, 'NON DISTRIBUITO'),
(99483, 6888, 26, 'non distribuito'),
(99484, 6889, 26, 'e non distribuito'),
(99485, 6890, 26, 'Annulla disdetta'),
(99486, 6892, 26, 'Clienti unici'),
(99487, 6893, 26, 'Identificatore leggibile per questo tipo'),
(99488, 6894, 26, 'Nuovi Clienti unici'),
(99489, 6895, 26, 'Identificatore numerico unico per questo tipo'),
(99490, 6896, 26, 'Pazienti visti una volta'),
(99491, 6897, 26, 'Resoconto Pazienti visti una volta'),
(99492, 6898, 26, 'Paz.v. una volta'),
(99493, 6899, 26, 'Unità'),
(99494, 6900, 26, 'Unità'),
(99495, 6901, 26, 'unità'),
(99496, 6902, 26, 'Unità applicabili ai valori dei risultati'),
(99497, 6903, 26, 'Unità per Modulo Visite'),
(99498, 6904, 26, 'Unità deve essere un numero'),
(99499, 6905, 26, 'Unità non definita'),
(99500, 6906, 26, 'Unità/L'),
(99501, 6907, 26, 'Non noto'),
(99502, 6910, 26, 'Non noto se mai fumatore'),
(99503, 6911, 26, 'Sconosciuto o N/D'),
(99504, 6912, 26, 'User id sconosciuto:'),
(99505, 6913, 26, 'scollegare paziente'),
(99506, 6914, 26, 'Compagnia assicurativa senza nome'),
(99507, 6915, 26, 'Non registrato'),
(99508, 6918, 26, 'Deseleziona tutto'),
(99509, 6919, 26, 'Non selezionato'),
(99510, 6920, 26, 'Non specificato'),
(99511, 6921, 26, 'non strutturato'),
(99512, 6922, 26, 'il caricamento del file database NON è SUPPORTATO'),
(99513, 6924, 26, 'fino'),
(99514, 6925, 26, 'archiviazione prematura'),
(99515, 6926, 26, 'Non usato'),
(99516, 6927, 26, 'UOR'),
(99517, 6928, 26, 'Fino a'),
(99518, 6929, 26, 'Prossimi Appuntamenti'),
(99519, 6930, 26, 'Prossimi Eventi'),
(99520, 6931, 26, 'Aggiorna'),
(99521, 6932, 26, 'aggiorna'),
(99522, 6933, 26, 'Aggiornamento attivo'),
(99523, 6934, 26, 'Aggiorna files'),
(99524, 6935, 26, 'Aggiorna info'),
(99525, 6936, 26, 'Aggiorna elenco'),
(99526, 6937, 26, 'Aggiorna il numero del provider'),
(99527, 6938, 26, 'Aggiorna gli elementi selezionati'),
(99528, 6939, 26, 'Aggiorna le seguenti variabili nel file'),
(99529, 6940, 26, 'Aggiorna le informazioni utente.'),
(99530, 6942, 26, 'L''aggiornamento della democrafica non è autorizzato.'),
(99531, 6943, 26, 'Aggiornamento di default della configurazione globale'),
(99532, 6944, 26, 'Aggiornamento indicatori di versione'),
(99533, 6945, 26, 'AGGIORNA'),
(99534, 6946, 26, 'Aggiorna'),
(99535, 6947, 26, 'Aggiorna il Database'),
(99536, 6948, 26, 'Aggiorna il Database di LibreEHR per includere Procedure, Funzioni e tabelle necessarie al processo di De-identificazione'),
(99537, 6949, 26, 'L''aggiormamento continuerà'),
(99538, 6950, 26, 'UPIN'),
(99539, 6951, 26, 'Carica'),
(99540, 6954, 26, 'Carica i dati di configurazione'),
(99541, 6955, 26, 'Carica Documento'),
(99542, 6956, 26, 'Caricamento fallito!'),
(99543, 6957, 26, 'Carica immagine in'),
(99544, 6958, 26, 'Carica il file importato:'),
(99545, 6960, 26, 'Carico elaborato con successo'),
(99546, 6961, 26, 'Resoconto caricamento'),
(99547, 6963, 26, 'Carico questo file:'),
(99548, 6964, 26, 'Cliccando su un numero di fattura la "finestra di registrazione manuale" appare. Qui è possibile modificare la data di scadenza e le note per la fattura, selezionare l''utente per il quale stai scrivendo, e selezionare le assicurazioni per la quale tutti i pagamenti previsti sono stati ricevuti. La cosa più importante, per ciascun codice di fatturazione per il quale è stato addebitato un importo, è possibile inserire le informazioni di pagamento e di regolazione.'),
(99549, 6965, 26, 'Al momento della ricerca si sono presentati con una lista delle fatture. È possibile fare clic su uno dei numeri di fattura per aprire una seconda finestra, che è la pagina di immissione dati per la registrazione manuale. Si può anche fare clic sul nome di un paziente se si desidera inserire una nota che il personale front office vedrà quando viene controllato il paziente, ed è possibile selezionare le fatture da visualizzare sulle dichiarazioni dei pazienti e stampare tali dichiarazioni.'),
(99550, 6966, 26, 'braccio superiore'),
(99551, 6968, 26, 'Urgenza'),
(99552, 6970, 26, 'Urina'),
(99553, 6971, 26, 'Gocciolamento di urina'),
(99554, 6972, 26, 'Frequenza urinaria'),
(99555, 6973, 26, 'Esitazione a urinare'),
(99556, 6974, 26, 'Microalbumina urina'),
(99557, 6975, 26, 'Fuoriuscita urina'),
(99558, 6976, 26, 'Urgenza urinaria'),
(99559, 6977, 26, 'URL'),
(99560, 6979, 26, 'URL per il supporto LibreEHR.'),
(99561, 6981, 26, 'URL per il gateway in fonia. Servizio automatico VOIP fornito da Maviq. Per maggiori informazioni viisita http://signup.maviq.com'),
(99562, 6985, 26, 'Utilizzo'),
(99563, 6986, 26, 'Indicatore di uso (ISA15)'),
(99564, 6987, 26, 'Utilizzare % solo in un campo per ordinare solo su quella colonna'),
(99565, 6988, 26, 'Usare il formato del tempo 24 ore?'),
(99566, 6990, 26, 'Utilizzare la tecnologia certificata EHR per identificare specifici del paziente e di fornire risorse educative tali risorse per il paziente se necessario.'),
(99567, 6991, 26, 'Usa pannello costi'),
(99568, 6992, 26, 'Utilizzare CPOE per gli ordini di farmaci immessi direttamente da qualsiasi operatore sanitario abilitato che può inserire gli ordini in cartella clinica per stato, linee guida locali e professionale.'),
(99569, 6997, 26, 'Usa elenco personalizzato Immunizzazione'),
(99570, 6999, 26, 'Usa un intervallo di dati'),
(99571, 7000, 26, 'Usa Default'),
(99572, 7001, 26, 'Usare l''opzione Elimina per rimuovere.'),
(99573, 7002, 26, 'Usare lo stile della data internazionale?'),
(99574, 7003, 26, 'Usare nome del file sorgente'),
(99575, 7004, 26, 'Usare i campi seguenti per un acquisto o trasferimento.'),
(99576, 7005, 26, 'Usare questa caratteristica solo per siti installati ex novo. '),
(99577, 7006, 26, 'Usare argomenti?'),
(99578, 7007, 26, 'Utente'),
(99579, 7009, 26, 'Utente / Gruppo'),
(99580, 7010, 26, 'Amministrazione Utente'),
(99581, 7011, 26, 'Amministrazione Utenti e Sedi'),
(99582, 7012, 26, 'Amministrazione Utenti e Gruppi'),
(99583, 7014, 26, 'Autenticazione certificata dell''Utente disabilitata'),
(99584, 7015, 26, 'Definito dall''utente'),
(99585, 7016, 26, 'Area11 definita dall''utente'),
(99586, 7017, 26, 'Area12 definita dall''utente'),
(99587, 7018, 26, 'Campo definito dal'),
(99588, 7019, 26, 'Elenco 1 definito dall''utente'),
(99589, 7020, 26, 'Elenco 2 definito dall''utente'),
(99590, 7021, 26, 'Elenco 3 definito dall''utente'),
(99591, 7022, 26, 'Elenco 4 definito dall''utente'),
(99592, 7023, 26, 'Elenco 5 definito dall''utente'),
(99593, 7024, 26, 'Elenco 6 definito dall''utente'),
(99594, 7025, 26, 'Elenco 7 definito dall''utente'),
(99595, 7026, 26, 'Testo 1 definito dall''utente'),
(99596, 7027, 26, 'Testo 2 definito dall''utente'),
(99597, 7028, 26, 'Testo 3 definito dall''utente'),
(99598, 7029, 26, 'Testo 4 definito dall''utente'),
(99599, 7030, 26, 'Testo 5 definito dall''utente'),
(99600, 7031, 26, 'Testo 6 definito dall''utente'),
(99601, 7032, 26, 'Testo 7 definito dall''utente'),
(99602, 7033, 26, 'Testo 8 definito dall''utente'),
(99603, 7034, 26, 'Nome dell''utente'),
(99604, 7037, 26, 'Accesso utente (Se 03 sopra, altrimenti lasciare spazi) (ISA02)'),
(99605, 7038, 26, 'Accesso utente indicatore di richiesta (ISA01 ~ uso 00 o 03)'),
(99606, 7039, 26, 'Manuale Utente'),
(99607, 7040, 26, 'Iscrizione Utente'),
(99608, 7041, 26, 'Nome dell''Utente'),
(99609, 7042, 26, 'Il nome utente o il nome Host non possono essere vuoti'),
(99610, 7043, 26, 'Nome utente o nome Host'),
(99611, 7044, 26, 'Password utente (ISA04 ~ 01 se sopra, altrimenti lasciare spazi)'),
(99612, 7045, 26, 'Password utente richiesto Indicator (ISA03 ~ uso 00 o 01)'),
(99613, 7046, 26, 'Parametri Utente'),
(99614, 7047, 26, 'Parametri specifici dell''utente'),
(99615, 7048, 26, 'Utente(i) nuova password'),
(99616, 7049, 26, 'Nome utente'),
(99617, 7051, 26, 'Username per il gateway in fonia. Servizio automatizzato fornito da Maviq. Per maggiori informazioni visitare http://signup.maviq.com'),
(99618, 7052, 26, 'Nome utente per il Gateway SMS.'),
(99619, 7053, 26, 'Nome utente per il Gateway SMS.'),
(99620, 7054, 26, 'Nome utente per connessione al CouchDB'),
(99621, 7055, 26, 'Nome utente:'),
(99622, 7056, 26, 'Utenti'),
(99623, 7057, 26, 'Amministrazione Utenti/Gruppi/Logs'),
(99624, 7058, 26, 'usa il formato php <a href="http://php.net/strftime">strftime</a>'),
(99625, 7059, 26, 'UTIs'),
(99626, 7062, 26, 'VACANZA'),
(99627, 7063, 26, 'Vacanza'),
(99628, 7064, 26, 'Vaccino'),
(99629, 7065, 26, 'Anello vaginale'),
(99630, 7066, 26, 'Commiato'),
(99631, 7067, 26, 'convalida'),
(99632, 7068, 26, 'Valore'),
(99633, 7069, 26, 'Valore 1'),
(99634, 7070, 26, 'Valore 2'),
(99635, 7072, 26, 'Il valore dovrebbe essere numerico'),
(99636, 7073, 26, 'Var1'),
(99637, 7074, 26, 'Var2'),
(99638, 7075, 26, 'variabile a uno per l''esecuzione di de-identificazione di aggiornamento script'),
(99639, 7076, 26, 'Varicella 1'),
(99640, 7077, 26, 'Varicella 2'),
(99641, 7078, 26, 'Vene Varicose'),
(99642, 7079, 26, 'Condizione vascolare'),
(99643, 7080, 26, 'Lesione vascolare'),
(99644, 7081, 26, 'Chirurgia vascolare'),
(99645, 7083, 26, 'Venditore'),
(99646, 7084, 26, 'Versione'),
(99647, 7085, 26, 'Vertigine'),
(99648, 7086, 26, 'Amministrazione veterani'),
(99649, 7087, 26, 'Piano amministrazione veterani'),
(99650, 7088, 26, 'VFC'),
(99651, 7089, 26, 'Vietnamita'),
(99652, 7090, 26, 'vedi'),
(99653, 7091, 26, 'Vista'),
(99654, 7092, 26, 'Vedi Allergie'),
(99655, 7093, 26, 'Vedere il file x12-835 ERA'),
(99656, 7094, 26, 'Vedere testo batch claim x12'),
(99657, 7097, 26, 'Vedi Resoconto completo Paziente'),
(99658, 7098, 26, 'Vedere tabelle CSV'),
(99659, 7100, 26, 'Vedi documento'),
(99660, 7101, 26, 'Vedi incontro'),
(99661, 7102, 26, 'Vedere testo ERA x12'),
(99662, 7103, 26, 'Vedere eventi in una finestra popup?'),
(99663, 7104, 26, 'Strumento di visualizzazione delle informazioni utente specifico'),
(99664, 7106, 26, 'Vedere il file locale x12'),
(99665, 7107, 26, 'Visualizza registro'),
(99666, 7108, 26, 'Vista pagina 1'),
(99667, 7109, 26, 'Vista pagina 2'),
(99668, 7110, 26, 'Mostra promemoria passati e futuri'),
(99669, 7111, 26, 'Vista Paziente'),
(99670, 7116, 26, 'Vedi Incontri correlati'),
(99671, 7117, 26, 'Visualizza Report'),
(99672, 7118, 26, 'Visualizza il file README'),
(99673, 7121, 26, 'Vedi/Modifica Allergie'),
(99674, 7122, 26, 'Vedi/Modifica Tematiche'),
(99675, 7123, 26, 'Viedi/Stampa'),
(99676, 7124, 26, 'Vista:'),
(99677, 7125, 26, 'VISA'),
(99678, 7126, 26, 'VISA/MC/AMEX/Dis'),
(99679, 7127, 26, 'Danno viscerale/trauma/intervento'),
(99680, 7133, 26, 'Categoria della Visita'),
(99681, 7134, 26, 'Data della Visita'),
(99682, 7135, 26, 'Data della Visita'),
(99683, 7137, 26, 'Moduli Visita'),
(99684, 7138, 26, 'Storico Visite'),
(99685, 7140, 26, 'Visite'),
(99686, 7141, 26, 'Visite dal:'),
(99687, 7142, 26, 'Segni Vitali'),
(99688, 7143, 26, 'Vitali'),
(99689, 7144, 26, 'Vitali (Metrici)'),
(99690, 7145, 26, 'Opzioni per il modulo Vitali'),
(99691, 7146, 26, 'Voce'),
(99692, 7147, 26, 'Voce inviata'),
(99693, 7149, 26, 'Vomito'),
(99694, 7151, 26, 'W'),
(99695, 7152, 26, 'Circ vita'),
(99696, 7153, 26, 'Circonfernza in vita'),
(99697, 7154, 26, 'In attesa'),
(99698, 7155, 26, 'Entrata'),
(99699, 7157, 26, 'Walt Pennington'),
(99700, 7158, 26, 'Magazzino'),
(99701, 7159, 26, 'Magazzino massimo, 0 se non applicabile'),
(99702, 7160, 26, 'Magazzino minimo. 0 se non applicabile'),
(99703, 7161, 26, 'Magazzini'),
(99704, 7162, 26, 'Caldo'),
(99705, 7163, 26, 'Attenzione'),
(99706, 7164, 26, 'ATTENZIONE'),
(99707, 7166, 26, 'Attenzione: Numero assegno già esistente nel database'),
(99708, 7167, 26, 'Attenzione, il paziente ha codici ambigui nella lista dei problemi!'),
(99709, 7168, 26, 'Attenzione: E'' oggi già stata creata una visita per questo paziente!'),
(99710, 7169, 26, 'ATTENZIONE: Se si utilizza la versione 2012-10-31 spagnolo, notate bene che dovete decomprimerlo una volta prima di metterlo in contrib / SNOMED (questo è perché il file è stato rilasciato  "double-zip ").'),
(99711, 7170, 26, 'Attenzione: l''ID paziente non è unico!'),
(99712, 7171, 26, 'ATTENZIONE: Questo sovrascriverà le informazioni della configurazione con i dati del file caricato!'),
(99713, 7173, 26, 'Avvisi di Attenzione'),
(99714, 7175, 26, 'è stato già caricato'),
(99715, 7176, 26, 'non è stato trovato'),
(99716, 7177, 26, 'E'' gradito l''invito al pagamento di conti dovuti'),
(99717, 7178, 26, 'abbiamo visto il vostro paziente in precedenza per la valutazione e il trattamento presso il nostro ambulatorio psichiatria. Grazie per questo rinvio.'),
(99718, 7179, 26, 'Debolezza'),
(99719, 7181, 26, 'Ricerca Web'),
(99720, 7182, 26, 'Sito Web'),
(99721, 7183, 26, 'Collegamento al sito web del Portale Paziente Onsite.'),
(99722, 7184, 26, 'Mer'),
(99723, 7185, 26, 'Mercoledì'),
(99724, 7186, 26, 'Settimana'),
(99725, 7187, 26, 'settimana'),
(99726, 7188, 26, 'Vista Settimana'),
(99727, 7189, 26, 'Settimana(e)'),
(99728, 7190, 26, 'Esposizione settimanale'),
(99729, 7191, 26, 'settimane'),
(99730, 7192, 26, 'Settimane'),
(99731, 7193, 26, 'Peso'),
(99732, 7194, 26, 'Valutazione del peso e counseling a bambini e adolescenti'),
(99733, 7195, 26, 'Valutazione del peso e counseling a bambini e adolescenti (CMQ)'),
(99734, 7196, 26, 'Cambiamento del Peso'),
(99735, 7197, 26, 'Perdita di Peso'),
(99736, 7198, 26, 'Clinica della perdita di peso'),
(99737, 7199, 26, 'Benvenuto'),
(99738, 7202, 26, 'Cosa bisogna conteggiare?'),
(99739, 7203, 26, 'Respiro affannoso:'),
(99740, 7204, 26, 'Dispnea'),
(99741, 7205, 26, 'Dispnea:'),
(99742, 7208, 26, 'Dove si possono trovare le scansioni correlate o i documenti cartacei?'),
(99743, 7209, 26, 'Se assicurato'),
(99744, 7211, 26, 'Colpo di frusta'),
(99745, 7212, 26, 'Bianca'),
(99746, 7213, 26, 'Chi'),
(99747, 7214, 26, 'Chi ha risposto?'),
(99748, 7215, 26, 'Vedovo(a)'),
(99749, 7216, 26, 'Larghezza'),
(99750, 7217, 26, 'Larghezza in pixel del frame di navigazione sinistro'),
(99751, 7221, 26, 'Se selezionati:'),
(99752, 7222, 26, 'col vecchio nome'),
(99753, 7224, 26, 'A chi possiamo lasciare messaggi?'),
(99754, 7225, 26, 'Trattenuto'),
(99755, 7226, 26, 'entro qualche ora'),
(99756, 7227, 26, 'entro qualche ora:'),
(99757, 7228, 26, 'entro qualche minuto'),
(99758, 7229, 26, 'entro qualche minuto:'),
(99759, 7230, 26, 'Senza servizi'),
(99760, 7231, 26, 'Senza fornitore'),
(99761, 7232, 26, 'Senza Aggiornamento'),
(99762, 7233, 26, 'Testimonianza'),
(99763, 7234, 26, 'sett.'),
(99764, 7235, 26, 'WNL'),
(99765, 7237, 26, 'Donna'),
(99766, 7238, 26, 'Solo donne'),
(99767, 7240, 26, 'Lavoro'),
(99768, 7241, 26, 'NOTE LAVORO'),
(99769, 7242, 26, 'Telefono Lavoro'),
(99770, 7243, 26, 'Numero telefono lavoro'),
(99771, 7244, 26, 'Correlato al lavoro?'),
(99772, 7245, 26, 'Lavoro/Studio/Hobby'),
(99773, 7246, 26, 'Nota Lavoro/Scuola'),
(99774, 7247, 26, 'giono lavorativo'),
(99775, 7248, 26, 'Risarcimento operaio/i'),
(99776, 7249, 26, 'Piano sanitario risarcimento operai'),
(99777, 7250, 26, 'Vecchi lavoratori o coniuge del lavoratore, con piano del gruppo sanitario'),
(99778, 7251, 26, 'Lavorando ... questo può richiedere un minuto.'),
(99779, 7252, 26, 'Peggio'),
(99780, 7253, 26, 'Vuoi l''importo del saldo da applicare su Account Globale?'),
(99781, 7254, 26, 'Vuoi marcarlo come cancellato?'),
(99782, 7255, 26, 'Vuoi allocarlo?'),
(99783, 7256, 26, 'Vuoi annullare la ripartizione per questo paziente?'),
(99784, 7257, 26, 'Vuoi eliminare la ripartizione del pagamento?'),
(99785, 7258, 26, 'Vuoi eliminare i pagamenti?'),
(99786, 7259, 26, 'Vuoi modificare e completare i pagamenti?'),
(99787, 7260, 26, 'Vuoi modificare i pagamenti?'),
(99788, 7261, 26, 'Vuoi inviare e completare i pagamenti?'),
(99789, 7262, 26, 'Vuoi inviare i pagamenti?'),
(99790, 7263, 26, 'Vuoi salvare?'),
(99791, 7264, 26, 'Polso'),
(99792, 7265, 26, 'Polso e mano'),
(99793, 7266, 26, 'Problemi al polso'),
(99794, 7267, 26, 'scrittura'),
(99795, 7268, 26, 'Cancellare'),
(99796, 7270, 26, 'Imponente'),
(99797, 7271, 26, 'WT'),
(99798, 7273, 26, 'x Cancellato'),
(99799, 7274, 26, 'x Cancellato'),
(99800, 7275, 26, 'Raggi-X'),
(99801, 7276, 26, 'Interpretazione RAGGI-X:'),
(99802, 7277, 26, 'Interpretazione Raggi-X:'),
(99803, 7278, 26, 'solo X12: sostituzione reclamo '),
(99804, 7279, 26, 'X12 Partner'),
(99805, 7280, 26, 'X12 Partners'),
(99806, 7281, 26, 'x12 Text'),
(99807, 7284, 26, 'A'),
(99808, 7285, 26, 'Anno'),
(99809, 7286, 26, 'anno'),
(99810, 7287, 26, 'Vista Annuale'),
(99811, 7288, 26, 'Anno(i)'),
(99812, 7289, 26, 'Anni'),
(99813, 7290, 26, 'Anni o mesi'),
(99814, 7291, 26, 'Anni, mesi e giorni'),
(99815, 7292, 26, 'SI'),
(99816, 7293, 26, 'Si'),
(99817, 7294, 26, 'si'),
(99818, 7295, 26, 'SI!'),
(99819, 7296, 26, 'Si, Elimina e traccia nel log'),
(99820, 7298, 26, 'Si/No'),
(99821, 7299, 26, 'Si:'),
(99822, 7300, 26, 'Yiddish'),
(99823, 7303, 26, 'Stai per sostituire definitivamente il template esistente. Sei sicuro di voler continuare?'),
(99824, 7304, 26, 'Sei nel periodo grazia per l''ingresso. Cambia la password prima'),
(99825, 7305, 26, 'Non ti è consentito eliminare questo evento'),
(99826, 7306, 26, 'Non ti è consentito modificare questo evento'),
(99827, 7307, 26, 'Non hai l''autorizzazione per questo'),
(99828, 7308, 26, 'Non sei autorizzato ad accedere a questa squadra.'),
(99829, 7309, 26, 'Non sei autorizzato ad aggiungere/modificare tematiche'),
(99830, 7310, 26, 'Non sei autorizzato a fissare appuntamenti'),
(99831, 7311, 26, 'Non sei autorizzato a vedere questo incontro'),
(99832, 7312, 26, 'Stai scrivendo nei confronti di un vecchio incontro?'),
(99833, 7313, 26, 'Non puoi accedere a questa funzione direttamente'),
(99834, 7314, 26, 'Non puoi accedere a questa pagina direttamente'),
(99835, 7315, 26, 'Non puoi aggiungere un valore vuoto come categoria!'),
(99836, 7316, 26, 'Non puoi aggiungere un valore vuoto come subcategoria!'),
(99837, 7317, 26, 'Non puoi aggiungere un valore in bianco per un elemento!'),
(99838, 7318, 26, 'Non puoi inserire una data futura on un valore di completato pari a SI'),
(99839, 7319, 26, 'Non hai scelto alcuna azione.'),
(99840, 7320, 26, 'Non hai accesso alla vista/modifica di questa nota'),
(99841, 7321, 26, 'Hai tentato di alterare un contenuto bloccato. Rimuovi il blocco se vuoi fare questo. Per sbloccare, rimuovi la linea, ''/*lock::*/'''),
(99842, 7322, 26, 'Sei uscito con successo.'),
(99843, 7323, 26, 'Puoi caricare solo file di tipo .txt'),
(99844, 7324, 26, 'Opzionalmente è possibile caricare i risultati HL7 da un file'),
(99845, 7325, 26, 'Puoi mettere qui un testo come reclamo di defautl nel modulo Incontro Nuovo Paziente.'),
(99846, 7326, 26, 'Devi inserire una frase chiave per criptare il documento'),
(99847, 7327, 26, 'È necessario inserire la propria password per modificare le password degli utenti. Lascia in bianco per mantenere la password invariata.'),
(99848, 7329, 26, 'Devi prima selezionare o aggiungere un paziente.'),
(99849, 7330, 26, 'Devi prima selezionare o creare un incontro.'),
(99850, 7331, 26, 'Devi selezionare una categoria di visite.'),
(99851, 7332, 26, 'Devi selezionare una categoria di visite.'),
(99852, 7333, 26, 'Devi selezionare qualche campo per continuare.'),
(99853, 7334, 26, 'Si dovrebbe eseguire questo test se questa affermazione sembra generare con successo, ma il file di reclamo effettivo non contiene tutti i dati o solo una parte incompiuta della quantità di dati che essa dovrebbe contenere. E'' ovvio, con affermazioni HCFA perché sono leggibili, con X12 afferma che è un processo più difficile determinare se l''affermazione è propriamente completa.'),
(99854, 7335, 26, 'Dovresti scegliere almeno un contesto'),
(99855, 7336, 26, 'Dovresti scegliere almeno un fornitore'),
(99856, 7339, 26, 'La data di fine non è valida'),
(99857, 7340, 26, 'L''evento è stato eliminato.'),
(99858, 7341, 26, 'L''evento è stato modificato.'),
(99859, 7342, 26, 'L''evento è stato inserito.'),
(99860, 7343, 26, 'Il file è troppo grande'),
(99861, 7345, 26, 'Il nome dell''elenco è stato modificato per rispettare i requisiti di denominazione'),
(99862, 7346, 26, 'Il tuo messaggio è stato inviato per la consegna ai'),
(99863, 7347, 26, 'Il nome per questa categoria, procedura o risultato'),
(99864, 7348, 26, 'La tua Password'),
(99865, 7349, 26, 'La tua password è scaduta. Si prega di cambiarla.'),
(99866, 7350, 26, 'La tua password scade il'),
(99867, 7351, 26, 'La tua password scade oggi. Cambia la tua password.'),
(99868, 7353, 26, 'La configurazione PostCalendar è stata reimpostata per utilizzare le impostazioni predefinite.'),
(99869, 7354, 26, 'La configurazione PostCalendar è stata aggiornata.'),
(99870, 7355, 26, 'La frequenza di ripetizione deve essere almeno 1'),
(99871, 7356, 26, 'La frequenza di ripetizione deve essere almeno 1'),
(99872, 7357, 26, 'La data di inizio è maggiore della data di fine'),
(99873, 7358, 26, 'La data di inizio non è valida'),
(99874, 7359, 26, 'L''inserimento è fallito'),
(99875, 7360, 26, 'aaaa-mm-gg'),
(99876, 7361, 26, 'AAAA-MM-GG'),
(99877, 7362, 26, 'aaaa-mm-gg data associata a questo documento'),
(99878, 7363, 26, 'aaaa-mm-gg data distrutta'),
(99879, 7364, 26, 'aaaa-mm-gg data di nascita'),
(99880, 7365, 26, 'aaaa-mm-gg Data di Nascita'),
(99881, 7366, 26, 'aaaa-mm-gg data di scadenza'),
(99882, 7367, 26, 'aaaa-mm-gg Data di insorgenza o di ospedalizzazione'),
(99883, 7368, 26, 'aaaa-mm-gg data di insorgenza, intervento chirurgico o inizio di farmaci'),
(99884, 7369, 26, 'aaaa-mm-gg data di acquisto o di trasferimento'),
(99885, 7370, 26, 'aaaa-mm-gg data di guarigione o di fine del farmaco'),
(99886, 7371, 26, 'aaaa-mm-gg Data di ritorno a giocare'),
(99887, 7372, 26, 'aaaa-mm-gg data della prestazione'),
(99888, 7373, 26, 'aaaa-mm-gg data di questa lettera'),
(99889, 7374, 26, 'aaaa-mm-gg data del ritorno in campo'),
(99890, 7375, 26, 'aaaa-mm-gg data del documento'),
(99891, 7376, 26, 'aaaa-mm-gg data dell''evento o data di inizio'),
(99892, 7381, 26, 'aaaa-mm-gg hh:mm:ss'),
(99893, 7382, 26, 'aaaa-mm-gg (24) Ore:minuti'),
(99894, 7383, 26, 'aaaa-mm-gg ultima data di questo evento.'),
(99895, 7387, 26, 'Zero'),
(99896, 7389, 26, 'CAP'),
(99897, 7390, 26, 'Codice Postale'),
(99898, 7391, 26, 'CAP/Nazione'),
(99899, 7392, 26, 'Zulu'),
(99900, 7393, 26, ' ma era '),
(99901, 7394, 26, ' Impossibile accedere.'),
(99902, 7395, 26, 'Vuoi veramente eliminare'),
(99903, 7396, 26, 'Farmaco'),
(99904, 7397, 26, 'email non inviate'),
(99905, 7398, 26, 'da'),
(99906, 7399, 26, 'è stato creato. '),
(99907, 7400, 26, 'è stato riaperto.'),
(99908, 7401, 26, 'Storico'),
(99909, 7402, 26, 'non è un numero'),
(99910, 7403, 26, 'è pronto per ri-fatturazione.'),
(99911, 7404, 26, 'LLL:'),
(99912, 7405, 26, 'Lot'),
(99913, 7406, 26, 'Riferimento originale n. della medicazione '),
(99914, 7407, 26, 'min'),
(99915, 7408, 26, 'non trovato!'),
(99916, 7409, 26, 'Peculiarità in molti browser possono significare che l''uscita di sotto entra nel vostro schermo a scatti improvvisi e che ci sono lunghe pause di alcuni secondi in cui appare come se le cose potrebbero essere arrestato. Questo non è il caso, alla fine vedrete uscita uscendo riga per riga. Ci può essere una sequenza di numeri che appaiono qui sotto, questo sta ad indicare che, anche se non altro può essere visualizzato non vi è attività in corso. Questi numeri sono inframmezzati con il contenuto della fatturazione e che è normale.'),
(99917, 7410, 26, 'la prescrizione ha raggiunto i suoi limiti di'),
(99918, 7411, 26, 'fino'),
(99919, 7412, 26, 'aggornamento fallito, non presente nel database?'),
(99920, 7413, 26, 'è stato segnato come fatturato soltanto.'),
(99921, 7414, 26, 'è stato accodato con successo.'),
(99922, 7415, 26, '! Left w/o visit'),
(99923, 7416, 26, '" per codice '),
(99924, 7417, 26, '" È'' selezionata nelle impostazioni PostCalendar!'),
(99925, 7418, 26, '# Ins/fin issue'),
(99926, 7419, 26, '# di compresse:'),
(99927, 7420, 26, '$'),
(99928, 7421, 26, '$ Coding done'),
(99929, 7422, 26, '$label (yyyy-mm-dd): '),
(99930, 7423, 26, '%'),
(99931, 7424, 26, '% Annullato < 24h'),
(99932, 7425, 26, '% Annullato < 24h '),
(99933, 7426, 26, 'dovrebbe esistere ma non è così.'),
(99934, 7427, 26, '(% corrisponde a qualsiasi stringa, _ corrisponde a qualsiasi carattere)'),
(99935, 7428, 26, '([ctrl] + clic per selezionare più destinatari)'),
(99936, 7429, 26, '(Indietro)'),
(99937, 7430, 26, '(Clicca per modificare)'),
(99938, 7431, 26, '(L''invio delle email è immediato, mentre Il VOIP automatico è inviato al fornitore del servizio per ulteriore elaborazione)'),
(99939, 7432, 26, '(Altro)'),
(99940, 7433, 26, '(Nuovo Paziente)'),
(99941, 7434, 26, '(Note e Autorizzazioni)'),
(99942, 7435, 26, '(Note Paziente)'),
(99943, 7436, 26, '(Seleziona una di queste, o scrivi un nuovo titolo)'),
(99944, 7437, 26, '(Maiusc.)Click o trascina per cambiare il valore'),
(99945, 7438, 26, '* Promemoria fatto'),
(99946, 7439, 26, '** Sposta gli interventi alle Tematiche!!'),
(99947, 7440, 26, '*Richiesto'),
(99948, 7441, 26, '+ Chart pulled'),
(99949, 7442, 26, '- Nessuno'),
(99950, 7443, 26, '-- Tutto --'),
(99951, 7444, 26, '--Seleziona Ruolo--'),
(99952, 7445, 26, '.'),
(99953, 7446, 26, '0'),
(99954, 7447, 26, '0-10'),
(99955, 7448, 26, '0-24'),
(99956, 7451, 26, '1'),
(99957, 7452, 26, '1 = Nord America. Vedi http://www.wtng.info/ per un elenco degli altri codici nazionali.'),
(99958, 7453, 26, '1 giorno da ora'),
(99959, 7454, 26, '1 mese da ora'),
(99960, 7455, 26, '1 settimana da ora'),
(99961, 7456, 26, '1 anno da ora'),
(99962, 7457, 26, '1.Riposo 2.Ghiaccio per due giorni 3 Compressione, mantieni il bendaggio a meno che il piede non sviluppi insensibilità o colore pallido. 4.Tieni piede e gamba in alto'),
(99963, 7458, 26, '11-14'),
(99964, 7459, 26, '12 hr'),
(99965, 7460, 26, '15-19'),
(99966, 7462, 26, '2'),
(99967, 7463, 26, '2 giorni da ora'),
(99968, 7464, 26, '2 mesi da ora'),
(99969, 7465, 26, '2 settimane da ora'),
(99970, 7466, 26, '2 anni da ora'),
(99971, 7467, 26, '2-20 anni'),
(99972, 7468, 26, '20-24'),
(99973, 7477, 26, '2111-13'),
(99974, 7478, 26, '24 hr'),
(99975, 7479, 26, '25+'),
(99976, 7480, 26, '25-29'),
(99977, 7481, 26, '2°'),
(99978, 7482, 26, '3 giorni da ora'),
(99979, 7483, 26, '3 mesi'),
(99980, 7484, 26, '3 mesi da ora'),
(99981, 7485, 26, '3 volte al dì'),
(99982, 7486, 26, '3 settimane da ora'),
(99983, 7487, 26, '30-34'),
(99984, 7488, 26, '35-39'),
(99985, 7489, 26, '3°'),
(99986, 7490, 26, '4 giorni da ora'),
(99987, 7491, 26, '4 mesi'),
(99988, 7492, 26, '4 mesi da ora'),
(99989, 7493, 26, '4 volte al dì'),
(99990, 7494, 26, '4 settimane da ora'),
(99991, 7495, 26, '40-44'),
(99992, 7496, 26, '45+'),
(99993, 7497, 26, '465.9, URI'),
(99994, 7498, 26, '466,0, bronchite acuta, NAS'),
(99995, 7499, 26, '486,0, polmonite, acuta'),
(99996, 7500, 26, '491,21, riacutizzazioni BPCO'),
(99997, 7501, 26, '491,8, Bronchite, cronica'),
(99998, 7502, 26, '493,92, asma, Exac acuta.'),
(99999, 7503, 26, '496.0, COPD'),
(100000, 7504, 26, '4°'),
(100001, 7505, 26, '5 giorni da ora'),
(100002, 7506, 26, '5 mesi da ora'),
(100003, 7507, 26, '5 settimane da ora'),
(100004, 7508, 26, '519,7, broncospasmo'),
(100005, 7509, 26, '5°'),
(100006, 7510, 26, '6 giorni da ora'),
(100007, 7511, 26, '6 mesi'),
(100008, 7512, 26, '6 mesi da ora'),
(100009, 7513, 26, '6 settimane da ora'),
(100010, 7514, 26, '6°'),
(100011, 7515, 26, '7 mesi da ora'),
(100012, 7516, 26, '8 mesi da ora'),
(100013, 7517, 26, '824,0 frattura, malleolo mediale, chiuso'),
(100014, 7518, 26, '824,2 frattura, malleolo laterale, chiuso'),
(100015, 7519, 26, '824,6 Frattura, Trimalleolar, chiuso'),
(100016, 7520, 26, '825,32 Frattura, dello scafoide (caviglia)'),
(100017, 7521, 26, '825,35 Frattura, Base del quinto (5 °) del metatarso'),
(100018, 7522, 26, '845,00 Distorsione alla caviglia NOS'),
(100019, 7523, 26, '845,01 distorsione mediale (deltoide) Lig.'),
(100020, 7524, 26, '845,02 Distorsione, perone calcaneare'),
(100021, 7525, 26, '9 mesi da ora'),
(100022, 7526, 26, '99212 Stabilizzato - Senza complicazioni'),
(100023, 7527, 26, '99213 Stabilizzato - Bassa complessità'),
(100024, 7528, 26, '< In sala esami'),
(100025, 7529, 26, '> Uscito(a)'),
(100026, 7530, 26, '?'),
(100027, 7531, 26, '? Non mostrare'),
(100028, 7532, 26, '@ Arrivato'),
(100029, 7533, 26, '[Cambia vista]'),
(100030, 7534, 26, '[Data dell''ultimo incontro]'),
(100031, 7535, 26, '[Giorni dall''ultimo incontro]'),
(100032, 7536, 26, '[EOBs]'),
(100033, 7537, 26, '[Export OFX]'),
(100034, 7538, 26, '[non raccomandato]'),
(100035, 7539, 26, '[Numero di Incontri]'),
(100036, 7540, 26, '[Resoconti]'),
(100037, 7541, 26, '[Seleziona Tutto]'),
(100038, 7542, 26, '[SQL-Ledger]'),
(100039, 7543, 26, '[Avvio processo batch]'),
(100040, 7544, 26, '[Vedi Log]'),
(100041, 7545, 26, '[Vedi resoconto stampabile]'),
(100042, 7546, 26, '_PC_DUR_HOURS'),
(100043, 7547, 26, '_PC_DUR_MINUTES'),
(100044, 7548, 26, '_PC_LOCALE'),
(100045, 7549, 26, '- Arrivato in ritardo'),
(100046, 1, 27, 'एक'),
(100047, 2, 27, 'एक चेक नंबर या claim नंबर भुगतान की पहचान के लिए'),
(100048, 3, 27, 'एक client certificate computer व्यवस्थापक के लिए'),
(100049, 5, 27, 'एक नैदानिक ​​दस्तावेज संलग्न है'),
(100050, 7, 27, 'एक वितरक की आवश्यकता है'),
(100051, 8, 27, 'एक GCAC visit फार्म इस visit के लिए जोड़ा जाना चाहिए.'),
(100052, 9, 27, 'एक lot नंबर की आवश्यकता है'),
(100053, 10, 27, 'एक lot नंबर की आवश्यकता है!'),
(100054, 11, 27, 'एक छोटा अक्षर'),
(100055, 12, 27, 'एक नंबर'),
(100056, 14, 27, 'इस आईडी के साथ एक मरीज ​​पहले से ही मौजूद है.'),
(100057, 15, 27, 'इस नाम के साथ एक मरीज ​​पहले से ही मौजूद है.'),
(100058, 16, 27, 'इस SS के साथ एक मरीज ​​पहले से ही मौजूद है.'),
(100059, 19, 27, 'एक सिफ़ारिश प्रत्येक visit के लिए निर्दिष्ट की जा सकती है.'),
(100060, 20, 27, 'एक संबंधित IPPF कोड की आवश्यकता है!'),
(100061, 21, 27, 'एक विशेष character'),
(100062, 22, 27, 'इस क्षेत्र को पहचान करने के लिए एक अनूठा मूल्य, उपयोगकर्ता नहीं देख सकते हैं'),
(100063, 25, 27, 'प्रात:'),
(100064, 27, 27, 'ए बी'),
(100065, 28, 27, 'संक्षेप'),
(100066, 30, 27, 'उदर'),
(100067, 31, 27, 'वजन चार कदम (4) को सहन करने में सक्षम'),
(100068, 32, 27, 'असामान्य'),
(100069, 33, 27, 'असामान्य 1'),
(100070, 34, 27, 'असामान्य'),
(100071, 35, 27, 'असामान्य रक्त परीक्षण'),
(100072, 36, 27, 'असामान्य बाल विकास'),
(100073, 37, 27, 'असामान्य मेम्मोग्राम'),
(100074, 39, 27, 'गर्भपात'),
(100075, 40, 27, 'गर्भपात संबंधित समस्याएं'),
(100076, 41, 27, 'गर्भपात विधि'),
(100077, 42, 27, 'गर्भपात संबंधी श्रेणियाँ'),
(100078, 43, 27, 'गर्भपात'),
(100079, 44, 27, 'कैलेंडर के बारे में'),
(100080, 46, 27, 'डायग्नोसिस द्वारा absences'),
(100081, 47, 27, 'आवंटित कार्य स्वीकार करें'),
(100082, 48, 27, 'के लिए भुगतान स्वीकार'),
(100083, 49, 27, 'के लिए भुगतान स्वीकार'),
(100084, 50, 27, 'आवंटित कार्य स्वीकार करें'),
(100085, 51, 27, 'एक्सेस नियंत्रण'),
(100086, 52, 27, 'एक्सेस नियंत्रण सूची का प्रशासन'),
(100087, 54, 27, 'अनुमति नहीं'),
(100088, 55, 27, 'प्रवेश अनधिकृत'),
(100089, 56, 27, 'अपने रोगी पोर्टल को एक्सेस करिये'),
(100090, 59, 27, 'खातेदार का नाम'),
(100091, 62, 27, 'अच्कोउन्तिंग'),
(100092, 64, 27, 'दर्द'),
(100093, 65, 27, 'आभार का अनुरोध( (आई एश ए14)'),
(100094, 66, 27, 'अच्क्नोव्लेद्ग्मेंट्स, लाइसेंसिंग और प्रमाणन'),
(100095, 67, 27, 'ए सी ल'),
(100096, 68, 27, 'ए सि ल प्रशासन'),
(100097, 69, 27, 'ए सि ल प्रशासन की अनुमति नहीं है'),
(100098, 71, 27, 'मुँहासा'),
(100099, 72, 27, 'कार्य'),
(100100, 73, 27, 'कार्य की तारीख'),
(100101, 74, 27, 'कार्रवाई'),
(100102, 75, 27, 'कार्रवाई'),
(100103, 77, 27, 'सीसीआर / सीसीडी रिपोर्टिंग सक्रिय करना'),
(100104, 78, 27, 'सक्रिय'),
(100105, 79, 27, 'सक्रिय चेतावनी'),
(100106, 80, 27, 'सक्रिय चेतावनी नियम'),
(100107, 81, 27, 'सक्रिय चेतावनियाँ / अनुस्मारक'),
(100108, 82, 27, 'सक्रिय भेंट'),
(100109, 84, 27, 'सक्रिय सूचियाँ'),
(100110, 85, 27, 'सक्रिय रोगी'),
(100111, 86, 27, 'सक्रिय योजनाएं'),
(100112, 87, 27, 'हलचल'),
(100113, 88, 27, 'गतिविधि प्रकार'),
(100114, 90, 27, 'तीव्र नशा / आहरण'),
(100115, 92, 27, 'पुरानी पर तीव्र'),
(100116, 93, 27, 'जोड़ें'),
(100117, 94, 27, 'जोड़ें'),
(100118, 95, 27, 'जोड़ें'),
(100119, 96, 27, 'एक कंपनी जोड़ें'),
(100120, 98, 27, 'एक फार्मेसी जोड़ें'),
(100121, 100, 27, 'के लिए एक घटना जोड़ें '),
(100122, 101, 27, 'एक नई टिप्पणी के रूप में जोड़ें'),
(100123, 102, 27, 'नए रूप में जोड़ें'),
(100124, 104, 27, 'बटन जोड़ें'),
(100125, 105, 27, 'Add Buttons for Special Chars,Texts to be Displayed on Top of the Editor for inclusion to the text on a Click'),
(100126, 106, 27, 'श्रेणी जोड़ें'),
(100127, 107, 27, 'स्थिर जोड़ें'),
(100128, 108, 27, 'संदर्भ जोड़ें'),
(100129, 109, 27, 'copay जोड़ें'),
(100130, 110, 27, 'मापदंड जोड़ें'),
(100131, 111, 27, 'पसंदीदा बटन जोड़ें'),
(100132, 112, 27, 'निदान जोड़ें'),
(100133, 113, 27, 'दवा जोड़ें'),
(100134, 114, 27, 'भेंट जोड़ें'),
(100135, 115, 27, 'भेंट/टिप्पणी जोड़ें'),
(100136, 116, 27, 'सुविधा केंद्र जोड़ें'),
(100137, 117, 27, 'क्षेत्र जोड़ें'),
(100138, 118, 27, 'अपाचे विन्यास फ़ाइल में निम्नलिखित लाइनें जोड़ें'),
(100139, 119, 27, 'समूह जोड़ें'),
(100140, 120, 27, 'आईसीडी कोड जोड़ें'),
(100141, 121, 27, 'टीकाकरण जोड़ें'),
(100142, 122, 27, 'जोडना अधिकृत नहीं है!'),
(100143, 123, 27, 'अंक जोड़ें'),
(100144, 125, 27, 'भाषा जोड़ें'),
(100145, 126, 27, 'नए जोड़ें'),
(100146, 127, 27, 'नए जोड़ें'),
(100147, 128, 27, 'नई श्रेणी जोड़ें: '),
(100148, 129, 27, 'अपाचे विन्यास फाइल के लिए नया प्रमाणपत्र जोड़ें'),
(100149, 132, 27, 'नया समूह जोड़ें'),
(100150, 134, 27, 'नया लॉट और लेन - देन जोड़ें'),
(100151, 135, 27, 'नई टिप्पणी जोड़ें'),
(100152, 136, 27, 'नई टिप्पणी जोड़ें'),
(100153, 137, 27, 'नया साथी जोड़ें'),
(100154, 140, 27, 'टिप्पणी जोड़ें'),
(100155, 141, 27, 'रोगी रिकॉर्ड जोड़ें'),
(100156, 142, 27, 'पर्चे जोड़ें'),
(100157, 143, 27, 'प्रक्रिया जोड़ें'),
(100158, 144, 27, 'प्रदाता का नंबर जोड़ें'),
(100159, 145, 27, 'पुनर्वसन जोड़ें'),
(100160, 146, 27, 'नियम जोड़ें'),
(100161, 147, 27, 'में जोड़ें'),
(100162, 148, 27, 'दवा सूची में जोड़ें'),
(100163, 149, 27, 'शीर्ष स्तर जोड़ें'),
(100164, 150, 27, 'लेन - देन जोड़ें'),
(100165, 151, 27, 'उपयोगकर्ता का नाम जोड़ें'),
(100166, 152, 27, 'उपयोगकर्ता को समूह में जोड़ें'),
(100167, 153, 27, 'जोड़ें / संपादित करें eRx'),
(100168, 154, 27, 'रोगी लेनदेन जोड़ें/संपादित करें'),
(100169, 155, 27, 'जोड़ा गया'),
(100170, 156, 27, 'जनसांख्यिकी जोड़ना अधिकृत नहीं है'),
(100171, 158, 27, 'एडिसन Syndrom'),
(100172, 159, 27, 'एडिसन सिंड्रोम'),
(100173, 160, 27, 'अतिरिक्त विशेषताओं'),
(100174, 161, 27, 'अतिरिक्त निदान:'),
(100175, 162, 27, 'अतिरिक्त इतिहास'),
(100176, 163, 27, 'अतिरिक्त इतिहास टिप्पणी'),
(100177, 164, 27, 'अतिरिक्त जानकारी'),
(100178, 165, 27, 'अतिरिक्त लैब्स'),
(100179, 166, 27, 'अतिरिक्त टिप्पणी'),
(100180, 167, 27, 'इस परिणाम या सिफारिश के लिए अतिरिक्त टिप्पणी'),
(100181, 168, 27, 'अतिरिक्त टिप्पणी'),
(100182, 169, 27, 'अतिरिक्त टिप्पणी '),
(100183, 170, 27, 'अतिरिक्त एक्स - रे नोट्स:'),
(100184, 171, 27, 'Additionally, the corresponding US Snomed Extension Package can be imported separately after installing the International (English version) Snomed Release'),
(100185, 172, 27, 'केवल जोड़ें'),
(100186, 173, 27, 'पता पुस्तिका'),
(100187, 174, 27, 'पता पुस्तिका'),
(100188, 175, 27, 'पता'),
(100189, 178, 27, 'पता पुस्तिका'),
(100190, 179, 27, 'इस प्रक्रिया कर रही कंपनी के लिए पता पुस्तिका प्रवेश'),
(100191, 180, 27, 'वितरक के लिए पता पुस्तिका प्रवेश'),
(100192, 181, 27, 'विक्रेता के लिए पता पुस्तिका प्रवेश'),
(100193, 182, 27, 'पता पुस्तिका प्रकार'),
(100194, 187, 27, 'पता 1'),
(100195, 188, 27, 'पता 2'),
(100196, 189, 27, 'पाने वाला'),
(100197, 190, 27, 'समायोजन'),
(100198, 191, 27, 'समायोजन राशि'),
(100199, 192, 27, 'समायोजित करें'),
(100200, 193, 27, 'समायोजन'),
(100201, 194, 27, 'समायोजन राशि'),
(100202, 195, 27, 'समायोजन कारण'),
(100203, 196, 27, 'कोड के लिए समायोजन मूल्य '),
(100204, 197, 27, 'समायोजन'),
(100205, 198, 27, 'प्रशासक समायोजित'),
(100206, 199, 27, 'प्रशासन'),
(100207, 200, 27, 'प्रशासनिक ईमेल एड्रेस'),
(100208, 201, 27, 'के माध्यम प्रशासन'),
(100209, 202, 27, 'प्रशासित'),
(100210, 203, 27, 'द्वारा प्रशासित'),
(100211, 205, 27, 'प्रशासित स्थल का'),
(100212, 206, 27, 'प्रशासन'),
(100213, 207, 27, 'प्रशासन साइट'),
(100214, 208, 27, 'प्रशासक'),
(100215, 209, 27, 'प्रशासक कुछ भी कर सकते हैं'),
(100216, 210, 27, 'तिथि एडमिट'),
(100217, 212, 27, 'वयस्क वजन जांच और अनुवर्ती'),
(100218, 213, 27, 'वयस्क वजन जांच और अनुवर्ती (CQM)'),
(100219, 214, 27, 'अग्रिम निर्देशक'),
(100220, 215, 27, 'अग्रिम निर्देशों के'),
(100221, 216, 27, 'अग्रिम निर्देशों की चेतावनी'),
(100222, 218, 27, 'उन्नत'),
(100223, 219, 27, 'परामर्श'),
(100224, 221, 27, 'सामान्य को प्रभावित'),
(100225, 223, 27, 'घंटे कॉल के बाद'),
(100226, 224, 27, 'After migration from the old password mechanisms where passwords are stored in the users table without salt is complete, this flag should be set to false so that only authentication by the new method is possible'),
(100227, 225, 27, 'After performing above configurations, import the admin client certificate to the browser and restart Apache server (empty password).'),
(100228, 226, 27, 'पीडीऍफ़ सेव करने के बाद, ऐरर चेक करने के लिये view logs को क्लिक करे'),
(100229, 227, 27, 'टेक्स्ट सेव करने के बाद, ऐरर चेक करने के लिये [View Log] को क्लिक करे'),
(100230, 228, 27, 'अपने बैच सहेजने के बाद, त्रुटियों की जाँच करने के लिए [View Log] क्लिक करें.'),
(100231, 230, 27, 'जानकारी सही ढंग से प्रवेश करने के बाद, Save बटन क्लिक करें.'),
(100232, 232, 27, 'देखभाल के बाद योजना'),
(100233, 233, 27, 'पुन'),
(100234, 234, 27, 'उम्र'),
(100235, 235, 27, 'के द्वारा उम्र'),
(100236, 236, 27, 'आयु श्रेणी'),
(100237, 237, 27, 'उम्र डेटा सीमा से बाहर है.'),
(100238, 238, 27, 'उम्र प्रदर्शन स्वरूप'),
(100239, 239, 27, 'से उम्र के लिए आयु स्वरूप मान्य नहीं है'),
(100240, 240, 27, 'तक की उम्र के लिए आयु स्वरूप मान्य नहीं है'),
(100241, 241, 27, 'से उम्र'),
(100242, 242, 27, 'प्रदर्शन स्वरूप परिवर्तन के लिए वर्ष में आयु'),
(100243, 243, 27, 'आयु अधिकतम'),
(100244, 244, 27, 'उम्र मिनट'),
(100245, 245, 27, 'आयु सीमा'),
(100246, 247, 27, 'उम्र के कॉलम:'),
(100247, 249, 27, 'अल्बानियन'),
(100248, 250, 27, 'शराब'),
(100249, 251, 27, 'शराब का सेवन'),
(100250, 253, 27, 'चेतावनी गणना'),
(100251, 255, 27, 'चेतावनियाँ');
INSERT INTO `lang_definitions` VALUES
(100252, 258, 27, 'ALEUT'),
(100253, 259, 27, 'सब'),
(100254, 260, 27, 'समस्त'),
(100255, 261, 27, 'सभी (Collated स्वरूप ए)'),
(100256, 262, 27, 'सभी (Collated स्वरूप बी)'),
(100257, 263, 27, 'सभी (संचयी)'),
(100258, 266, 27, 'सभी श्रेणियाँ'),
(100259, 268, 27, 'सभी संहिताएं'),
(100260, 269, 27, 'सारे दिन'),
(100261, 270, 27, 'सारे दिन का इवेंट'),
(100262, 271, 27, 'सभी जनसांख्यिकी क्षेत्रों,खोज और दोहराव की जांच के साथ'),
(100263, 272, 27, 'सारी सुविधाओं'),
(100264, 273, 27, 'सभी चोट लगने की घटनाएं / समस्याएँ / मुद्दे'),
(100265, 274, 27, 'सारी भाषाओ की अनुमति है'),
(100266, 276, 27, 'पहला नाम का हिस्सा या पूरा'),
(100267, 277, 27, 'अंतिम नाम का हिस्सा या पूरा'),
(100268, 278, 27, 'संगठन नाम का हिस्सा या पूरा'),
(100269, 280, 27, 'सारे उत्पादों'),
(100270, 281, 27, 'सारे providers'),
(100271, 282, 27, 'सब की समीक्षा की और सब नकारात्मक:'),
(100272, 283, 27, 'सारे विषयों'),
(100273, 284, 27, 'सारे उपयोगकर्ताओं'),
(100274, 285, 27, 'एलर्जी'),
(100275, 286, 27, 'एलर्जी'),
(100276, 287, 27, 'एलर्जी:'),
(100277, 288, 27, 'एलर्जी'),
(100278, 289, 27, 'एलर्जी आयात सफलतापूर्वक पूरा'),
(100279, 290, 27, 'एलर्जी समस्या सूची'),
(100280, 291, 27, 'एलर्जी रिएक्शन'),
(100281, 294, 27, 'आबंटित करें'),
(100282, 295, 27, 'अनुमति दें'),
(100283, 296, 27, 'लॉग इन पर मेनू पर विकल्प के रूप में सभी उपलब्ध भाषाओं की अनुमति दें.'),
(100284, 297, 27, 'प्रक्रियाओं या शुल्क नहीं बल्कि निदान युक्त दावों के निर्माण की अनुमति दें. अधिकांश क्लीनिक यह नहीं चाहता.'),
(100285, 298, 27, 'भाषा डीबगिंग की अनुमति दें'),
(100286, 299, 27, 'ईमेल की अनुमति दें'),
(100287, 300, 27, 'ईमेल संदेशों को अनुमति दें?'),
(100288, 301, 27, 'ईमेल की अनुमति दें?'),
(100289, 302, 27, 'दावा मुठभेड़ की अनुमति दें'),
(100290, 303, 27, 'स्वास्थ्य सूचना एक्सचेंज की अनुमति दें'),
(100291, 304, 27, 'टीकाकरण की जानकारी साझा करने की अनुमति दें'),
(100292, 305, 27, 'प्रतिरक्षण रजिस्ट्री उपयोग की अनुमति दें'),
(100293, 306, 27, 'मेल संदेश की अनुमति दें'),
(100294, 308, 27, 'रोगी पोर्टल की अनुमति दें'),
(100295, 309, 27, 'एसएमएस की अनुमति दें'),
(100296, 310, 27, 'एसएमएस (पाठ संदेश) की अनुमति दें?'),
(100297, 311, 27, 'प्रस्तुत घटनाओं तुरन्त सक्रिय किए जाने की अनुमति दें?'),
(100298, 312, 27, 'टेलीफोन संदेशों को अनुमति दें?'),
(100299, 313, 27, 'उपयोगकर्ताओं को वैश्विक घटनाक्रम प्रकाशित करने की अनुमति दें'),
(100300, 314, 27, 'उपयोगकर्ताओं को व्यक्तिगत कैलेंडर को प्रकाशित करने की अनुमति दें'),
(100301, 315, 27, 'वॉयस संदेश की अनुमति दें'),
(100302, 316, 27, 'अनुमति दे दी'),
(100303, 317, 27, 'अनुमति दी भाषाएँ'),
(100304, 318, 27, 'अनुमति दी (ग)'),
(100305, 323, 27, 'पहले से मौजूद है'),
(100306, 324, 27, 'पहले से ही मौजूद है.'),
(100307, 325, 27, 'पहले से ही इस्तेमाल किया, किसी अन्य पहचानकर्ता का चयन करें'),
(100308, 326, 27, 'पहले से ही इस्तेमाल किया, किसी अन्य शीर्षक का चयन करें'),
(100309, 327, 27, 'वैकल्पिक पता'),
(100310, 328, 27, 'बदलना'),
(100311, 329, 27, 'Alternatively, you may use the search page to upload an electronic remittance (X12 835) file that you have obtained from your payer or clearinghouse. You can do this by clicking the Browse button and selecting the file to upload, and then clicking Search to perform the upload and display the corresponding invoices. In this case the other parameters mentioned above do not apply and will be ignored. Uploading saves the file but does not yet process its contents -- that is done separately as described below.'),
(100312, 330, 27, 'पूर्वाह्न'),
(100313, 331, 27, 'पूर्वाह्न कार्यक्रम'),
(100314, 332, 27, 'एएमसी'),
(100315, 333, 27, 'एएमसी ट्रैकिंग'),
(100316, 338, 27, 'मौजूदा नोट में संशोधन'),
(100317, 343, 27, 'अमेरिकी भारतीय'),
(100318, 344, 27, 'अमेरिकी भारतीय या अलास्का मूल निवासी'),
(100319, 346, 27, 'अम्हरी (भाषा)'),
(100320, 347, 27, 'राशि'),
(100321, 348, 27, 'प्रशासित राशि'),
(100322, 349, 27, 'राशि'),
(100323, 350, 27, 'बकाया राशि'),
(100324, 351, 27, 'इश जांच कि राशि'),
(100325, 352, 27, 'प्रदाय राशि'),
(100326, 353, 27, 'राशि:'),
(100327, 354, 27, 'राशि बिल किया'),
(100328, 355, 27, 'बाद में शुरू की तारीख से एक समापन दिनांक, दोहराया घटनाओं के लिए आवश्यक है!'),
(100329, 357, 27, 'LibreEHR वेब डायरेक्टरी ट्री डंपिंग समय एक त्रुटि हुई'),
(100330, 358, 27, 'PhpGACL वेब डायरेक्टरी ट्री डंपिंग समय एक त्रुटि हुई'),
(100331, 359, 27, 'SQL लेजर वेब डायरेक्टरी ट्री डंपिंग समय एक त्रुटि हुई'),
(100332, 360, 27, 'एक अधूरा GCAC मुद्दा बनाया और जोड़ा गया है. किसी को बाद में इसे पूरा करने की आवश्यकता होगी.'),
(100333, 362, 27, 'एक अनपेक्षित त्रुटि हुई है.'),
(100334, 363, 27, 'एक अपरकेस अक्षर'),
(100335, 365, 27, 'और'),
(100336, 366, 27, 'और'),
(100337, 367, 27, 'और'),
(100338, 368, 27, 'और '),
(100339, 369, 27, 'और सभी अधीनस्थ डेटा? इस क्रिया को लॉग इन किया जाएगा'),
(100340, 370, 27, 'और संशोधक'),
(100341, 371, 27, 'और संसाधित.'),
(100342, 372, 27, 'और Apache सर्वर को पुनरारंभ करें.'),
(100343, 373, 27, 'और कारण है'),
(100344, 374, 27, 'रक्ताल्पता'),
(100345, 375, 27, 'टखना'),
(100346, 376, 27, 'टखने + एड़ी'),
(100347, 377, 27, 'टखने मूल्यांकन प्रपत्र'),
(100348, 378, 27, 'टखने की समस्याएं'),
(100349, 379, 27, 'अचलताकारक Sondlilitis'),
(100350, 380, 27, 'अचलताकारक Spondlilitis'),
(100351, 381, 27, 'अरुचि'),
(100352, 382, 27, 'Another thing you can do in the posting window is request secondary billing. If you select this checkbox before saving, then the original claim will be re-opened and queued on the Billing page, and will be processed during the next billing run.'),
(100353, 383, 27, 'पूर्व'),
(100354, 384, 27, 'गुदा nl, नहीं मलाशय कोमलता / जन'),
(100355, 385, 27, 'चिंता'),
(100356, 386, 27, 'कोई भी'),
(100357, 387, 27, 'कोई भी श्रेणी'),
(100358, 388, 27, 'वांछित कोड या उसके वर्णन के किसी भी भाग'),
(100359, 389, 27, 'वांछित विशेषता के किसी भी भाग'),
(100360, 390, 27, 'दवा आईडी या नशीली दवाओं के नाम का कोई भी हिस्सा'),
(100361, 391, 27, 'प्रतिरक्षण आईडी या टीकाकरण के नाम का कोई भी हिस्सा'),
(100362, 392, 27, 'रोगी नाम का कोई भी हिस्सा, या  "पिछले, पहले ", या  "XY "'),
(100363, 393, 27, 'कोई भी अन्य प्रासंगिक जानकारी'),
(100364, 394, 27, 'एसएमएस गेटवे के लिए API का चाबी.'),
(100365, 395, 27, 'श्वासरोध'),
(100366, 396, 27, 'उपस्थिति'),
(100367, 397, 27, 'सूरत:'),
(100368, 398, 27, 'इस नोट को जोड़ें'),
(100369, 399, 27, 'मौजूदा नोट को जोड़ें'),
(100370, 400, 27, 'इस नोट को जोड़ें'),
(100371, 401, 27, 'इस नोट को जोड़ें'),
(100372, 402, 27, 'उपांत्र - उच्छेदन'),
(100373, 404, 27, 'मरीजों को लागू'),
(100374, 405, 27, 'आवेदन'),
(100375, 406, 27, 'प्रवेश पृष्ठ और मुख्य विंडो शीर्षक के लिए आवेदन नाम.'),
(100376, 407, 27, 'आवेदन रिसीवर संहिता (GS03 - खाली ISA08 उपयोग किया जाएगा)'),
(100377, 408, 27, 'आवेदन प्रेषक संहिता (GS02)'),
(100378, 409, 27, 'आवेदन शीर्षक'),
(100379, 410, 27, 'नब्ज फार्म और ग्रोथ चार्ट पर लागू होता है'),
(100380, 411, 27, 'नब्ज फार्म पर लागू होता है'),
(100381, 412, 27, 'केवल इस और भविष्य की सभी घटनाओं के लिए, या सभी घटनाओं को वर्तमान घटना में परिवर्तन लागू करें?'),
(100382, 413, 27, 'प्रभावित क्षेत्र के लिए लागू'),
(100383, 414, 27, 'त्वचा के लिए लागू'),
(100384, 415, 27, 'लागू करना'),
(100385, 416, 27, 'साइट पर पैच लागू करना'),
(100386, 417, 27, 'नियुक्ति'),
(100387, 418, 27, 'नियुक्ति तिथि'),
(100388, 419, 27, 'नियुक्ति प्रदर्शन शैली'),
(100389, 420, 27, 'नियुक्ति अनुस्मारक नियम'),
(100390, 421, 27, 'नियुक्ति स्थिति'),
(100391, 422, 27, 'नियुक्ति स्थितियां'),
(100392, 423, 27, 'भीतर नियुक्ति'),
(100393, 424, 27, 'नियुक्ति / घटना का रंग'),
(100394, 425, 27, 'नियुक्ति'),
(100395, 426, 27, 'नियुक्ति (वैकल्पिक लिखने)'),
(100396, 427, 27, 'नियुक्ति (लिखने, wsome वैकल्पिक)'),
(100397, 430, 27, 'नियुक्ति और मुठभेड़ों'),
(100398, 431, 27, 'नियुक्ति रिपोर्ट'),
(100399, 432, 27, 'नियुक्तियों मुठभेड़ों की रिपोर्ट'),
(100400, 434, 27, 'स्वीकृत करें'),
(100401, 436, 27, 'स्वीकृत किया'),
(100402, 437, 27, 'स्वीकृत किया घटनाक्रम प्रशासन'),
(100403, 440, 27, 'Appt-मुठभेड़'),
(100404, 441, 27, 'Appts'),
(100405, 442, 27, 'अप्रैल'),
(100406, 443, 27, 'अप्रैल'),
(100407, 444, 27, 'अरबी भाषा'),
(100408, 446, 27, 'संग्रह'),
(100409, 447, 27, 'क्या एसीएल समूह नामों का अनुवाद किया जाना है?'),
(100410, 448, 27, 'क्या नियुक्ति श्रेणी नामों का अनुवाद किया जाना है?'),
(100411, 449, 27, 'क्या दस्तावेज़ श्रेणी नामों का अनुवाद किया जाना है?'),
(100412, 450, 27, 'क्या इस प्रकार के लिए शुल्क चार्ज किया जाता है ?'),
(100413, 451, 27, 'क्या रोगी नोट खिताब का अनुवाद किया जाना हैं ?'),
(100414, 452, 27, 'क्या कोड बाहरी एसक्यूएल टेबल (0 -NO, 1 - ICD10 , 2 SNOMED ( RF1 ) , 3 SNOMED ( RF2 ) ) में संग्रहीत कर रहे हैं?'),
(100415, 453, 27, 'क्या आप इस यात्रा के लिए एक नया GCAC मुद्दे को पूरा करने के लिए तैयार हैं?'),
(100416, 454, 27, 'क्या आप आज के लिए पोस्ट करने के लिए सहमत है?'),
(100417, 455, 27, 'क्या आप इन घटनाओं को मंजूरी देना चाहते हैं?'),
(100418, 457, 27, 'क्या आप पूरी तरह से इस फार्म को दूर करना चाहते हैं ?'),
(100419, 459, 27, 'क्या आप इस खुलासे को हटाना चाहते हैं?'),
(100420, 460, 27, 'क्या आप इस घटना को हटाना चाहते हैं?'),
(100421, 461, 27, 'क्या आप डेटाबेस से इस आइटम को हटाना चाहते हैं?'),
(100422, 462, 27, 'क्या आप इस नोट को हटाना चाहते हैं?'),
(100423, 464, 27, 'क्या आप इन घटनाओं को संपादित करना चाहते हैं ?'),
(100424, 465, 27, 'क्या आप इन घटनाओं को छिपाने चाहते हैं?'),
(100425, 467, 27, 'क्या आप इन घटनाओं को देखने चाहते हैं?'),
(100426, 468, 27, 'क्या आप पूरे नाम समूह को नष्ट करना चाहते हैं'),
(100427, 469, 27, 'क्या आप पूरी सूची को हटाना चाहते हैं'),
(100428, 470, 27, 'क्या आप क्षेत्र को नष्ट करना चाहते हैं'),
(100429, 471, 27, 'क्या आप चयनित क्षेत्रों को नष्ट करना चाहते हैं?'),
(100430, 472, 27, 'यदि आप इन कार्यों को जारी रखना चाहते है?'),
(100431, 473, 27, 'क्षेत्र निर्दिष्ट नहीं'),
(100432, 474, 27, 'बांह'),
(100433, 475, 27, 'आर्मीनियाई'),
(100434, 477, 27, 'arrythmia'),
(100435, 478, 27, 'गठिया'),
(100436, 479, 27, 'गठिया / DEGEN संयुक्त diseas'),
(100437, 480, 27, 'गठिया / DEGEN संयुक्त रोग'),
(100438, 481, 27, 'जैसा'),
(100439, 482, 27, 'के रूप में'),
(100440, 484, 27, 'एशियाई'),
(100441, 487, 27, 'मूल्यांकन'),
(100442, 488, 27, 'को सौंपा'),
(100443, 489, 27, 'सहायक'),
(100444, 490, 27, 'दमा'),
(100445, 491, 27, 'में'),
(100446, 492, 27, 'आप सभी का चयन करें तो कम से कम एक खोज पैरामीटर जरूरी है.'),
(100447, 493, 27, 'Navicular में'),
(100448, 494, 27, ': Navicular में'),
(100449, 495, 27, 'एथलेटिक टीम'),
(100450, 496, 27, 'एथलेटिक टीम'),
(100451, 497, 27, 'एथलेटिक/चोट'),
(100452, 498, 27, 'Atna ऑडिट सीए प्रमाणपत्र'),
(100453, 499, 27, 'Atna ऑडिट मेजबान'),
(100454, 500, 27, 'Atna ऑडिट स्थानीय प्रमाण पत्र'),
(100455, 501, 27, 'Atna ऑडिट बंदरगाह'),
(100456, 503, 27, 'ध्यान'),
(100457, 504, 27, 'ध्यान'),
(100458, 506, 27, 'ऑडिट सीडीआर इंजन प्रश्न'),
(100459, 509, 27, 'ऑडिट लॉगिंग बैकअप'),
(100460, 510, 27, 'ऑडिट विविध लॉगिंग'),
(100461, 511, 27, 'ऑडिट लॉगिंग आदेश'),
(100462, 512, 27, 'ऑडिट लॉगिंग रोगी रिकॉर्ड'),
(100463, 513, 27, 'ऑडिट लॉगिंग निर्धारण'),
(100464, 514, 27, 'ऑडिट लॉगिंग सुरक्षा प्रशासन'),
(100465, 515, 27, 'ऑडिट लॉगिंग चुनिए प्रश्न'),
(100466, 516, 27, 'अगस्त'),
(100467, 517, 27, 'अगस्त'),
(100468, 519, 27, 'प्रमाणीकरण'),
(100469, 520, 27, 'प्रमाणन / नोट्स'),
(100470, 523, 27, 'प्राधिकरण समूह'),
(100471, 524, 27, 'प्राधिकरण स्थिति'),
(100472, 525, 27, 'प्राधिकरण'),
(100473, 526, 27, 'अधिकार देना'),
(100474, 527, 27, 'अधिकृत करें - किसी भी मुठभेड़ों'),
(100475, 528, 27, 'अधिकृत - मेरे मुठभेड़ों'),
(100476, 529, 27, 'Authorize.net'),
(100477, 530, 27, 'अधिकृत'),
(100478, 531, 27, 'केवल अधिकृत'),
(100479, 532, 27, 'स्वचालित भेजें'),
(100480, 535, 27, 'नई मुठभेड़ों स्वचालित बनाएँ'),
(100481, 536, 27, 'स्वचालित जनित'),
(100482, 537, 27, 'स्वचालित उपाय गणना (एएमसी)'),
(100483, 542, 27, 'स्वचालित उपाय गणना (एएमसी) ट्रैकिंग'),
(100484, 543, 27, 'स्वचालित उपाय (एएमसी)'),
(100485, 544, 27, 'स्वचालित'),
(100486, 546, 27, 'स्वचालित रूप से एक नया मुठभेड़ बनाना जब नियुक्ति स्थिति "@" (आ गया). सेट किया जाता है.'),
(100487, 549, 27, 'मोटर वाहन चिकित्सा'),
(100488, 550, 27, 'स्वतः सहेजा'),
(100489, 551, 27, 'उपलब्ध श्रेणियों'),
(100490, 552, 27, 'उपलब्ध टाइम्स'),
(100491, 557, 27, 'औसत मासिक'),
(100492, 558, 27, 'अलगाव / अलगाव फ्रैक्चर'),
(100493, 559, 27, 'अलगाव पार्श्व malleolus'),
(100494, 560, 27, 'अलगाव औसत दर्जे malleolus '),
(100495, 561, 27, 'जागरूकता आधारित'),
(100496, 562, 27, 'कांख - संबंधी'),
(100497, 565, 27, 'दिन में दो बार'),
(100498, 566, 27, 'वापस जाएँ'),
(100499, 567, 27, 'वापस जाएँ'),
(100500, 568, 27, 'वापस जाएँ आठ दौरा'),
(100501, 569, 27, 'वापस जाएँ ग्यारह दौरा'),
(100502, 570, 27, 'वापस जाएँ पांच दौरा'),
(100503, 571, 27, 'वापस जाएँ चार दौरों'),
(100504, 572, 27, 'वापस जाएँ नौ दौरा'),
(100505, 573, 27, 'वापस जाएँ से एक यात्रा'),
(100506, 574, 27, 'पीठ दर्द'),
(100507, 575, 27, 'पीठ की समस्याएं'),
(100508, 576, 27, 'वापस जाएँ सात दौरा'),
(100509, 577, 27, 'वापस जाएँ छह दौरा'),
(100510, 578, 27, 'सर्जरी पर वापस जाएँ'),
(100511, 579, 27, 'वापस जाएँ दस दौरा'),
(100512, 580, 27, 'वापस जाएँ तीन दौरों'),
(100513, 581, 27, 'व्यवस्थापक पृष्ठ पर वापस'),
(100514, 584, 27, 'मरीज जानकारी पर वापस'),
(100515, 585, 27, 'उपयोगकर्ता पर वापस'),
(100516, 586, 27, 'दृश्य पर वापस'),
(100517, 587, 27, 'वापस जाएँ बारह दौरा'),
(100518, 588, 27, 'वापस जाएँ दो यात्राओं'),
(100519, 589, 27, 'पृष्ठभूमि सेवाएं'),
(100520, 590, 27, 'बैकअप'),
(100521, 591, 27, 'बैकअप फ़ाइल बना दिया गया है. अब डाउनलोड भेज देंगे.'),
(100522, 593, 27, 'सफलतापूर्वक में लिया बैकअप'),
(100523, 594, 27, 'बुरा चेक'),
(100524, 595, 27, 'डूबत कर्ज'),
(100525, 596, 27, 'बहासा इंडोनेशिया'),
(100526, 597, 27, 'शेष'),
(100527, 598, 27, 'शेष'),
(100528, 599, 27, 'शेष'),
(100529, 600, 27, 'शेष राशि'),
(100530, 601, 27, 'शेष रकम'),
(100531, 603, 27, 'बैंक ड्राफ्ट'),
(100532, 607, 27, 'पांचवीं के बेस (5) Metarsal'),
(100533, 608, 27, 'पांचवें (5) Metarsal का आधार:'),
(100534, 611, 27, 'बैच दावा'),
(100535, 612, 27, 'बैच संचार उपकरण'),
(100536, 613, 27, 'बैच भुगतान एंट्री'),
(100537, 614, 27, 'बैच भुगतान'),
(100538, 615, 27, 'बैच संसाधन शुरू किया, इसमें कुछ समय लग सकता है.'),
(100539, 616, 27, 'बैच परिणाम'),
(100540, 617, 27, 'BatchCom'),
(100541, 619, 27, 'क्योंकि वह आईडी मौजूद नहीं है'),
(100542, 620, 27, 'प्रारंभ करना'),
(100543, 621, 27, 'प्रारंभ तिथि'),
(100544, 623, 27, 'सेवा शुरुआत की तारीख yyyy-mm-dd'),
(100545, 624, 27, 'दिन के घंटे की शुरुआत कैलेंडर की घटनाओं के लिए'),
(100546, 626, 27, 'डकार'),
(100547, 628, 27, 'बंगाली'),
(100548, 630, 27, 'के बीच'),
(100549, 633, 27, 'द्विपक्षीय'),
(100550, 634, 27, 'द्विपक्षीय:'),
(100551, 636, 27, 'बिल की तारीख:'),
(100552, 637, 27, 'बिल / लीजिए'),
(100553, 638, 27, 'बिल भेजा'),
(100554, 640, 27, 'बिलिंग'),
(100555, 641, 27, 'बिलिंग (वैकल्पिक लिखने)'),
(100556, 642, 27, 'बिलिंग ध्यान दें'),
(100557, 644, 27, 'निवेदित सेवा के लिए बिलिंग कोड'),
(100558, 645, 27, 'बिलिंग कोड'),
(100559, 646, 27, 'बिलिंग डाटा'),
(100560, 647, 27, 'बिलिंग विभाग'),
(100561, 648, 27, 'बिलिंग सुविधा'),
(100562, 649, 27, 'बिलिंग जानकारी'),
(100563, 650, 27, 'बिलिंग स्थान'),
(100564, 655, 27, 'बिलिंग प्रबंधक'),
(100565, 656, 27, 'बिलिंग नोट'),
(100566, 657, 27, 'के लिए बिलिंग नोट '),
(100567, 658, 27, 'बिलिंग नोट:'),
(100568, 659, 27, 'बिलिंग कतार परिणाम:'),
(100569, 660, 27, 'बिलिंग की रिपोर्ट'),
(100570, 661, 27, 'बिलिंग स्थिति'),
(100571, 662, 27, 'बिलिंग स्थिति = unbilled'),
(100572, 663, 27, 'के लिए बिल '),
(100573, 665, 27, 'बायोप्सी'),
(100574, 666, 27, 'जन्म तिथि'),
(100575, 667, 27, 'जन्म - 24 महीने'),
(100576, 669, 27, 'काला'),
(100577, 670, 27, 'ब्लैक लंग'),
(100578, 671, 27, 'काले या अफ्रीकी अमेरिकी'),
(100579, 672, 27, 'मूत्राशय कैंसर'),
(100580, 673, 27, 'मूत्राशय में संक्रमण'),
(100581, 674, 27, 'खाली फार्म'),
(100582, 675, 27, 'रक्त स्राव समस्याएं'),
(100583, 676, 27, 'ब्लाइंड स्पॉट'),
(100584, 677, 27, 'सूजन'),
(100585, 678, 27, 'अवरोधित'),
(100586, 679, 27, 'खून'),
(100587, 680, 27, 'रक्तचाप'),
(100588, 681, 27, 'रक्तचाप'),
(100589, 682, 27, 'खूनी नाक'),
(100590, 683, 27, 'ब्लू क्रॉस ब्लू शील्ड'),
(100591, 684, 27, 'Blue lines in this report are informational. Black lines show previously existing information. Green lines show changes that were successfully applied. Red lines indicate errors, or changes that were not applied; these must be processed manually. Currently denied claims and payment reversals are not handled automatically and so will appear in red.'),
(100592, 685, 27, 'धुंधला विजन'),
(100593, 686, 27, 'बीएमआई'),
(100594, 687, 27, 'बीएमआई स्थिति'),
(100595, 689, 27, 'शारीरिक क्षेत्र'),
(100596, 690, 27, 'शरीर साइट'),
(100597, 691, 27, 'शरीर साइट, यदि लागू हो'),
(100598, 692, 27, 'अस्थि कोमलता:'),
(100599, 693, 27, 'अस्थि कोमलता: औसत दर्जे Malleolus'),
(100600, 694, 27, 'बूलियन'),
(100601, 696, 27, 'bot'),
(100602, 697, 27, 'दोनों कान'),
(100603, 698, 27, 'दोनों कानों'),
(100604, 699, 27, 'तल'),
(100605, 701, 27, 'बॉक्स 10 ए रोजगार संबंधित '),
(100606, 702, 27, 'बॉक्स 10 बी वाहन दुर्घटना '),
(100607, 703, 27, 'बॉक्स 10 सी. अन्य दुर्घटना '),
(100608, 706, 27, 'बॉक्स 15. एक या समान बीमारी की तिथि (yyyy-mm-dd):'),
(100609, 708, 27, 'बॉक्स 16. (Yyyy-mm-dd) से काम करने में असमर्थ दिनांक:'),
(100610, 709, 27, 'बॉक्स 16. (Yyyy-mm-dd) तक काम करने में असमर्थ दिनांक:'),
(100611, 710, 27, 'बॉक्स 18. से अस्पताल में भर्ती होने की तारीख (yyyy-mm-dd): '),
(100612, 711, 27, 'बॉक्स 18. तक अस्पताल में भर्ती तिथि (yyyy-mm-dd): '),
(100613, 712, 27, 'बॉक्स 20. बाहर लैब का उपयोग किया है?'),
(100614, 713, 27, 'बॉक्स 22. मेडिकेड resubmission संहिता (आईसीडी -9) '),
(100615, 714, 27, 'बॉक्स 23. पूर्व प्राधिकरण नंबर '),
(100616, 715, 27, 'रक्तचाप'),
(100617, 716, 27, 'रक्तचाप डायस्टोलिक'),
(100618, 717, 27, 'रक्तचाप सिस्टोलिक'),
(100619, 719, 27, 'बीपीडी'),
(100620, 721, 27, 'बीपीएस'),
(100621, 722, 27, 'ब्राजील पुर्तगाली'),
(100622, 723, 27, 'स्तन'),
(100623, 724, 27, 'स्तन बायोप्सी'),
(100624, 725, 27, 'स्तन निर्वहन'),
(100625, 726, 27, 'स्तन रोग'),
(100626, 727, 27, 'स्तन परीक्षा'),
(100627, 728, 27, 'स्तन मास'),
(100628, 730, 27, 'सांस ध्वनि:'),
(100629, 732, 27, 'टूटी हड्डी'),
(100630, 734, 27, 'ब्रोंकाइटिस पर्चा'),
(100631, 735, 27, 'ब्राउज़ करें'),
(100632, 736, 27, 'रिकार्ड के लिए ब्राउज़ करें'),
(100633, 737, 27, 'रक्तगुल्म/चोट'),
(100634, 739, 27, 'राइट उभार:'),
(100635, 741, 27, 'पेशाब के साथ जलन'),
(100636, 742, 27, 'पेशाब के साथ जलन'),
(100637, 744, 27, 'व्यस्त'),
(100638, 745, 27, 'लेकिन अभी तक क्रियान्वित नहीं.'),
(100639, 746, 27, 'कूल्हे'),
(100640, 747, 27, 'कूल्हे + एस.आई.'),
(100641, 748, 27, 'द्वारा'),
(100642, 749, 27, 'द्वारा'),
(100643, 750, 27, 'मुंह से'),
(100644, 751, 27, 'स्रोत/द्वारा'),
(100645, 752, 27, 'द्वारा:'),
(100646, 753, 27, 'सी'),
(100647, 754, 27, 'सीए प्रमाणपत्र आरएफसी 5425 टीएलएस syslog सर्वर की पुष्टि करने के लिए'),
(100648, 755, 27, 'Cache लाइफटाइम (सेकंड में)'),
(100649, 756, 27, 'Cache टेम्पलेट उत्पादन?'),
(100650, 757, 27, 'कैफीन की खपत'),
(100651, 758, 27, 'कैलेंडर'),
(100652, 759, 27, 'कैलेंडर समाप्त घंटे'),
(100653, 760, 27, 'कैलेंडर अंतराल'),
(100654, 761, 27, 'कैलेंडर स्क्रीन'),
(100655, 762, 27, 'कैलेंडर सेटिंग्स'),
(100656, 763, 27, 'कैलेंडर शुरू घंटे'),
(100657, 764, 27, 'कैलेंडर UI'),
(100658, 765, 27, 'कैलेंडर देखें'),
(100659, 766, 27, '(AddForm) को बुलाओ यहाँ जाता है <br>'),
(100660, 767, 27, 'कैलोरी'),
(100661, 768, 27, 'कम्बोडियन'),
(100663, 774, 27, 'रद्द करें'),
(100664, 775, 27, 'परिवर्तनों को निरस्त करें'),
(100665, 776, 27, 'रद्द'),
(100666, 777, 27, 'कैंसर'),
(100667, 778, 27, 'कैंसर स्क्रीनिंग: पेट के कैंसर स्क्रीनिंग'),
(100668, 779, 27, 'कैंसर स्क्रीनिंग: मैमोग्राम'),
(100669, 780, 27, 'कैंसर स्क्रीनिंग: पैप स्मियर'),
(100670, 781, 27, 'कैंसर स्क्रीनिंग: प्रोस्टेट कैंसर स्क्रीनिंग'),
(100671, 782, 27, 'प्रविष्टि नहीं जोड़ सकते हैं क्योंकि यह पहले से ही मौजूद है'),
(100672, 783, 27, 'प्रविष्टि जोड़ / अपडेट नहीं कर सकते क्योंकि एक डुप्लीकेट पहले से मौजूद है'),
(100673, 784, 27, 'संग्रहीत नहीं किया जा सकता नजरअंदाज कर दिया.'),
(100674, 785, 27, 'जेपीईजी में परिवर्तित नहीं किया जा सकता . शायद ImageMagick स्थापित नहीं है ?'),
(100675, 786, 27, 'हटाया नहीं जा सकता , नजरअंदाज कर दिया.'),
(100676, 787, 27, 'इनलाइन प्रदर्शित नहीं किया जा सकता है क्योंकि इस तरह के प्रकार ब्राउज़र द्वारा समर्थित नहीं है .'),
(100677, 788, 27, 'इनलाइन प्रदर्शित नहीं किया जा सकता है क्योंकि इस तरह के प्रकार ब्राउज़र द्वारा समर्थित नहीं है .'),
(100678, 789, 27, 'इनलाइन प्रदर्शित नहीं किया जा सकता है क्योंकि इस तरह के प्रकार ब्राउज़र द्वारा समर्थित नहीं है .'),
(100679, 790, 27, 'नहीं बना सकता'),
(100680, 795, 27, 'नहीं मिल सकता '),
(100681, 796, 27, 'एक गंतव्य फ़ाइल नाम नहीं खोज सके'),
(100682, 799, 27, 'एसक्यूएल खाताबही ग्राहक आईडी से मरीज ​​को नहीं खोज सके'),
(100683, 800, 27, 'में उपसंहार दस्तावेज़ संदर्भ नहीं मिल सकता है '),
(100684, 801, 27, 'एसक्यूएल खाताबही कर्मचारी से प्रदाता नहीं खोज सके '),
(100685, 802, 27, 'Payments. संशोधित नहीं कर सकते Undistributed नकारात्मक है .'),
(100686, 803, 27, 'नहीं खोल सकता '),
(100687, 804, 27, 'Insurance पोस्ट नहीं कर सकते.चयनित रोगी पैसे भर रहे है.'),
(100688, 805, 27, 'चयनित Patient के लिए पोस्ट नहीं कर सकते.बीमा कंपनी पैसे भर रहे है.'),
(100689, 806, 27, 'Payments पोस्ट नहीं कर सकते Undistributed नकारात्मक है .'),
(100690, 807, 27, 'पढ़ा नहीं जा सकता'),
(100691, 808, 27, 'निर्देशिका पढ़ा नहीं जा सकता'),
(100692, 809, 27, 'अद्यतन नहीं कर सकता क्योंकि आप मौजूदा प्रविष्टि संपादन नहीं कर रहे हैं !'),
(100693, 810, 27, 'कैपिटलाइज़'),
(100694, 812, 27, 'कैप्सूल'),
(100695, 813, 27, 'कार्ड'),
(100696, 814, 27, 'कार्डियक कैथेटेराइज़ेशन'),
(100697, 815, 27, 'कार्डिएक इको'),
(100698, 816, 27, 'कार्डियोवास्कुलर'),
(100699, 821, 27, 'उपास्थि / उपास्थिपरक / डिस्क क्षति'),
(100700, 822, 27, 'उपास्थि चोट'),
(100701, 823, 27, 'Cartoid स्पंदन nl, पेडल दालों nl'),
(100702, 824, 27, 'नकद'),
(100703, 825, 27, 'नकद'),
(100704, 826, 27, 'नकद प्राप्तियां'),
(100705, 827, 27, 'प्रदाता द्वारा नकद प्राप्तियां'),
(100706, 829, 27, 'मोतियाबिंद सर्जरी'),
(100707, 830, 27, 'मोतियाबिंद'),
(100708, 831, 27, 'श्रेणियाँ'),
(100709, 832, 27, 'के लिए श्रेणियाँ'),
(100710, 833, 27, 'श्रेणी'),
(100711, 834, 27, 'श्रेणी'),
(100712, 835, 27, 'श्रेणी '),
(100713, 836, 27, 'श्रेणी विवरण'),
(100714, 837, 27, 'श्रेणी सीमाएं'),
(100715, 838, 27, 'श्रेणी नाम'),
(100716, 839, 27, 'श्रेणी नाम खाली है'),
(100717, 840, 27, 'श्रेणी / शीर्षक'),
(100718, 841, 27, 'कोकेशियान'),
(100719, 842, 27, 'प्राप्तियों को मुठभेड़ / प्राथमिक प्रदाता की जानकारी प्रिंट करने के लिए मजबूर करता है'),
(100720, 850, 27, 'सीडीआर'),
(100721, 851, 27, 'सीडीआर प्रसंस्करण प्राथमिकता रिपोर्ट'),
(100722, 852, 27, 'मोबाइल फ़ोन'),
(100723, 853, 27, 'मोबाइल फ़ोन'),
(100724, 855, 27, 'सेल फोन नंबर'),
(100725, 856, 27, 'केन्द्रीय प्रमाणन'),
(100726, 857, 27, 'केन्द्रीय / दक्षिण अमेरिका'),
(100727, 858, 27, 'प्रमाणपत्र प्राधिकार CRT फ़ाइल स्थान खाली नहीं हो सकता'),
(100728, 859, 27, 'प्रमाणपत्र प्राधिकरण चाबी फ़ाइल स्थान खाली नहीं हो सकता'),
(100729, 860, 27, 'आरएफसी 5425 टीएलएस syslog सर्वर को भेजने के लिए प्रमाण पत्र.'),
(100730, 861, 27, 'प्रमाणपत्र प्रयोक्ता'),
(100731, 862, 27, 'प्रमाण पत्र'),
(100732, 864, 27, 'ChampUS'),
(100733, 865, 27, 'ChampUSVA'),
(100734, 866, 27, 'परिवर्तन'),
(100735, 867, 27, 'परिवर्तन'),
(100736, 868, 27, 'गतिविधि बदलें'),
(100737, 869, 27, 'बदलें विफल रहा है! CouchDB कनेक्ट त्रुटि?'),
(100738, 870, 27, 'दृष्टि में बदलें'),
(100739, 871, 27, 'दृष्टि में बदलें'),
(100740, 872, 27, 'पासवर्ड बदलें'),
(100741, 874, 27, 'बदली गई'),
(100742, 875, 27, 'बदल गया आंत्र'),
(100743, 876, 27, 'दस्तावेज़ के लिए रोगी आईडी बदल रहा है'),
(100744, 877, 27, 'विशेषताएँ'),
(100745, 878, 27, 'वर्ण शेष'),
(100746, 879, 27, 'प्रभार'),
(100747, 880, 27, 'प्रभारी समायोजन'),
(100748, 881, 27, 'Coded प्रभार'),
(100749, 882, 27, 'प्रभार'),
(100750, 883, 27, 'चार्ट'),
(100751, 884, 27, 'चार्ट गतिविधि'),
(100752, 885, 27, 'चार्ट Check-in/out गतिविधि रिपोर्ट'),
(100753, 886, 27, 'चार्ट आईडी'),
(100754, 887, 27, 'चार्ट आईडी'),
(100755, 889, 27, 'चार्ट स्थान गतिविधि'),
(100756, 890, 27, 'चार्ट नोट'),
(100757, 891, 27, 'चार्ट संख्या'),
(100758, 892, 27, 'चार्ट संग्रहण स्थान'),
(100759, 893, 27, 'चार्ट ट्रैकर'),
(100760, 894, 27, 'चार्ट TRK'),
(100761, 895, 27, 'चार्ट चेक आउट'),
(100762, 896, 27, 'चार्ट आउट'),
(100763, 898, 27, 'चेक'),
(100764, 899, 27, 'चेक'),
(100765, 900, 27, 'सभी की जाँच करें'),
(100766, 902, 27, 'राशि की जांच करें'),
(100767, 903, 27, 'तिथि की जांच करें'),
(100768, 904, 27, 'कस्टम भाषा तालिका के साथ अनुवाद के मतभेद के लिए जाँच करें.'),
(100769, 906, 27, 'जांच करें'),
(100770, 907, 27, 'इनपुट डाटा की जांच करें'),
(100771, 909, 27, 'लैब परिणाम की जाँच करें'),
(100772, 910, 27, 'जाँच का निशान समीक्षा का संकेत है.'),
(100773, 911, 27, 'चेक नंबर'),
(100774, 912, 27, 'चेक नंबर'),
(100775, 915, 27, 'चेक भुगतान'),
(100776, 916, 27, 'यह एक एन्क्रिप्टेड फ़ाइल है तो बॉक्स चेक करें'),
(100777, 917, 27, 'प्रदाताओं को डिफ़ॉल्ट सभी नियुक्तियों दिखाने के लिए और ना की सिर्फ अपने मत की, आप यह चेक करें.'),
(100778, 918, 27, 'इस निदान से समस्या पैदा करने के लिए बॉक्स चेक करें'),
(100779, 919, 27, 'चेक/EOB तिथि'),
(100780, 920, 27, 'चेक/EOB नंबर'),
(100781, 921, 27, 'चेक/संदर्भ संख्या'),
(100782, 922, 27, 'चेक/संदर्भ संख्या'),
(100783, 923, 27, 'चेकबॉक्स सूची'),
(100784, 924, 27, 'चेकबॉक्स सूची'),
(100785, 925, 27, 'चेकबॉक्स w / टेक्स्ट'),
(100786, 926, 27, 'चेकबॉक्स w / टेक्स्ट'),
(100787, 928, 27, 'जाँच की'),
(100788, 929, 27, 'जाँच बॉक्स = हाँ, खाली = नहीं'),
(100789, 932, 27, 'जांच'),
(100790, 933, 27, 'checksum'),
(100791, 934, 27, 'छाती'),
(100792, 935, 27, 'छाती CTAB'),
(100793, 936, 27, 'सीने में दर्द'),
(100794, 937, 27, 'सीने में दर्द:'),
(100795, 938, 27, 'सीने में दर्द'),
(100796, 940, 27, 'Chg'),
(100797, 942, 27, 'मुख्य शिकायत'),
(100798, 943, 27, 'बच्चा'),
(100799, 945, 27, 'बचपन प्रतिरक्षण स्थिति (CQM)'),
(100800, 946, 27, 'ठंड लगना'),
(100801, 947, 27, 'चीनी'),
(100802, 948, 27, 'चीनी (सरलीकृत)'),
(100803, 949, 27, 'चीनी (पारंपरिक)'),
(100804, 951, 27, 'विकल्प'),
(100805, 952, 27, 'ऑपरेशन द्वारा पित्ताशय को काट कर निकाल देना'),
(100806, 954, 27, 'ऑपरेशन द्वारा पित्ताशय को काट कर निकाल देना'),
(100807, 955, 27, 'चुनें'),
(100808, 956, 27, 'एक अनुभाग चुनें और इसके भीतर एक आइटम क्लिक करें, तो दूसरे भाग में आप संबंधित वस्तुओं पर प्रकाश डाला देखेंगे, और आप रिश्ते जोड़ने के लिए और नष्ट करने के लिए अनुभाग में क्लिक करें.'),
(100809, 957, 27, 'मानदंड चुनें'),
(100810, 959, 27, 'फ़ाइल चुनें'),
(100811, 960, 27, 'सूची से चुनें'),
(100812, 962, 27, 'सूची चुनें'),
(100813, 965, 27, 'इस मुठभेड़ रिपोर्ट के लिए प्रिंट प्रारूप चुनें.'),
(100814, 967, 27, 'क्रोनिक ब्रोन्काइटिस'),
(100815, 968, 27, 'क्रोनिक जोड़ों का दर्द'),
(100816, 969, 27, 'क्रोनिक किडनी रोग (सीकेडी)'),
(100817, 970, 27, 'क्रोनिक synovitis / बहाव / जोड़ों के दर्द / गाउट'),
(100818, 971, 27, 'आवर्तक / क्रोनिक'),
(100819, 973, 27, 'यकृद्दाल्युदर'),
(100820, 974, 27, 'यकृद्दाल्युदर'),
(100821, 975, 27, 'शहर'),
(100822, 976, 27, 'शहर का नाम'),
(100823, 977, 27, 'शहर, राज्य'),
(100824, 978, 27, 'शहर, राज्य ज़िप'),
(100825, 979, 27, 'शहर / राज्य'),
(100826, 980, 27, 'दावा'),
(100827, 981, 27, 'दावा '),
(100828, 982, 27, 'दावा स्थिति'),
(100829, 983, 27, 'दावा परीक्षण पूरा कर लिया है'),
(100830, 984, 27, 'दावा प्रकार'),
(100831, 985, 27, 'दावा दाखिल करने के लिए उत्पन्न किया गया'),
(100832, 986, 27, 'दावा दाखिल करने के लिए उत्पन्न किया गया '),
(100833, 987, 27, 'दावा'),
(100834, 988, 27, 'वर्गीकरण'),
(100835, 989, 27, 'साफ़'),
(100836, 990, 27, 'स्पष्ट सक्रिय रोगी'),
(100837, 991, 27, 'सभी साफ़'),
(100838, 992, 27, 'स्पष्ट HL7 के डाटा'),
(100839, 993, 27, 'स्पष्ट औचित्य'),
(100840, 994, 27, 'स्पष्ट समझदार cache'),
(100841, 995, 27, 'क्लीयरिंग हाउस की जानकारी ईडीआई 270 बैच के निर्माण के लिए जरूरी है.'),
(100842, 996, 27, 'CLIA संख्या'),
(100843, 997, 27, 'क्लिक करें'),
(100844, 998, 27, 'Click ''export'' to export your Category, Subcategory, Item, Content data to a text file. Any resemblance of this file to an XML file is purely coincidental. The opening and closing tags must be on the same line, they must be lowercase with no spaces. To import, browse for a file and click ''import''. If the data is completely different, it will merge with your existing data. If there are similar item names, The old one will be kept and the new one saved with a number added to the end.'),
(100845, 999, 27, 'एक नई टिप्पणी जोड़ने के लिए ग्राफिक पर एक जगह क्लिक करें, इसे निकालने के लिए इसे फिर से क्लिक करें'),
(100846, 1000, 27, 'ssl.zip फ़ाइल में प्रमाण पत्र डाउनलोड करने के लिए प्रमाणपत्र डाउनलोड क्लिक करें'),
(100847, 1001, 27, 'अधिक जानकारी के लिए क्लिक करें'),
(100848, 1002, 27, 'अधिक जानकारी के लिए क्लिक करें'),
(100849, 1003, 27, 'आदेश सारांश के लिए क्लिक करें'),
(100850, 1004, 27, 'परिणामों के लिए क्लिक करें'),
(100851, 1005, 27, 'यहां क्लिक करें'),
(100852, 1006, 27, 'एक नए मरीज ​​को जोड़ने के लिए यहां क्लिक करें.'),
(100853, 1007, 27, 'नई चोट परिवर्तन की स्थिति जोड़ने के लिए और दैनिक गतिविधियों को संपादित करने के लिए यहाँ क्लिक करें'),
(100854, 1008, 27, 'एक तिथि का चयन करने के लिए यहां क्लिक करें'),
(100855, 1009, 27, 'एक तारीख और समय का चयन करने के लिए यहां क्लिक करें'),
(100856, 1010, 27, 'एक शुरुआत की तारीख चुनने के लिए यहां क्लिक करें'),
(100857, 1020, 27, 'खोज करने के लिए यहाँ क्लिक करें'),
(100858, 1021, 27, 'प्राथमिकता, वर्ग और उपनाम सेटिंग को अपडेट करने के लिए यहां क्लिक करें'),
(100859, 1022, 27, 'सभी को देखने के लिए यहां क्लिक करें.'),
(100860, 1023, 27, 'दृश्य और ग्राफ के लिए यहां क्लिक करें'),
(100861, 1025, 27, 'सभी नब्ज देखने और ग्राफ के लिए यहां क्लिक करें.'),
(100862, 1026, 27, 'रोगी विवरण देखने के लिए यहां क्लिक करें'),
(100863, 1027, 27, 'उन सब को देखने के लिए यहां क्लिक करें.'),
(100864, 1028, 27, 'अधिक विवरण देखने / संपादित करने के लिए यहां क्लिक करें'),
(100865, 1029, 27, 'निम्नलिखित तारीख से डेटाबेस रिलीज स्थापित करने के लिए स्थापित बटन पर क्लिक करें'),
(100866, 1030, 27, 'इसे बढ़ाने के लिए किसी भी समय भागों पर क्लिक करें'),
(100867, 1031, 27, 'रोगी फ़ाइल खोलने के लिए रोगी का नाम क्लिक करें'),
(100868, 1032, 27, 'सभी परिणाम देखने के लिए ताज़ा बटन क्लिक करें. विशिष्ट परिणामों देखने के लिए ऊपर खोज मापदंड input करें.'),
(100869, 1033, 27, 'एक निदान जोड़ने के लिए क्लिक करें');
INSERT INTO `lang_definitions` VALUES
(100870, 1034, 27, 'नए घटकों को जोड़ने के लिए क्लिक करें'),
(100871, 1035, 27, 'नए परामर्श जोड़ने के लिए क्लिक करें'),
(100872, 1037, 27, 'डाउनलोड करने के लिए क्लिक करें'),
(100873, 1038, 27, 'संपादित करने के लिए क्लिक करें'),
(100874, 1039, 27, 'विवरण को संपादित करने के लिए क्लिक करें'),
(100875, 1040, 27, 'इस घटना को संपादित करने के लिए क्लिक करें'),
(100876, 1041, 27, 'रिपोर्ट उत्पन्न करने के लिए क्लिक करें'),
(100877, 1043, 27, 'मुद्रित करने के लिए क्लिक करें'),
(100878, 1044, 27, 'नया(जोड़) लॉट प्राप्त करने के लिए क्लिक करें'),
(100879, 1045, 27, 'चुनने के लिए क्लिक करें'),
(100880, 1046, 27, 'चुनने के लिए क्लिक करें'),
(100881, 1047, 27, 'इस प्रक्रिया के लिए एक उद्योग मानक कोड को चुनने के लिए क्लिक करें'),
(100882, 1048, 27, 'वैकल्पिक प्रक्रिया कोड को चुनने के लिए क्लिक करें'),
(100883, 1050, 27, 'CVX कोड का चयन करने या बदलने के लिए क्लिक करें'),
(100884, 1051, 27, 'निदान का चयन करने या बदलने के लिए क्लिक करें'),
(100885, 1052, 27, 'सेवा कोड का चयन करने या बदलने के लिए क्लिक करें'),
(100886, 1053, 27, 'रोगी को चुनने के लिए क्लिक करें'),
(100887, 1054, 27, 'संबंधित कोड को चुनने के लिए क्लिक करें'),
(100888, 1055, 27, 'अगर यह परिणाम असामान्य है तो सेवाएं प्रदर्शन करने के लिए क्लिक करें'),
(100889, 1056, 27, 'वांछित प्रक्रिया को चुनने के लिए क्लिक करें'),
(100890, 1057, 27, 'सॉर्ट करने के लिए क्लिक करें'),
(100891, 1058, 27, 'देखने के लिए क्लिक करें'),
(100892, 1059, 27, 'देखने या संपादित करने के लिए क्लिक करें'),
(100893, 1060, 27, 'देखने या संपादित करने के लिए क्लिक करें'),
(100894, 1061, 27, 'निम्नलिखित तारीख से डेटाबेस रिहाई नवीनीकृत करने के लिए अपग्रेड बटन क्लिक करें'),
(100895, 1063, 27, 'क्लिक करें:'),
(100896, 1064, 27, 'क्लाइंट प्रमाणपत्र समाप्ति दिन'),
(100897, 1065, 27, 'क्लाइंट प्रमाणपत्र की मान्यता अवधि'),
(100898, 1066, 27, 'क्लाइंट प्रमाणपत्र वैधता एक वैध संख्या होनी चाहिए.'),
(100899, 1067, 27, 'ग्राहकों का कॉपी'),
(100900, 1069, 27, 'ग्राहकों का चिकित्सा के इतिहास सारांश'),
(100901, 1070, 27, 'ग्राहक का नाम'),
(100902, 1071, 27, 'हमारे ग्राहकों का नंबर'),
(100903, 1072, 27, 'ग्राहक प्रोफाइल - नए ग्राहकों को'),
(100904, 1073, 27, 'ग्राहक प्रोफाइल - अद्वितीय ग्राहक'),
(100905, 1074, 27, 'ग्राहक'),
(100906, 1075, 27, 'क्लिनिक'),
(100907, 1076, 27, 'क्लिनिक कॉपी'),
(100908, 1077, 27, 'क्लिनिक डेली रिकॉर्ड'),
(100909, 1078, 27, 'क्लिनिक आईडी'),
(100910, 1079, 27, 'नैदानिक'),
(100911, 1080, 27, 'क्लीनिकल निर्णय नियम चेतावनी प्रबंधक'),
(100912, 1081, 27, 'क्लीनिकल इतिहास'),
(100913, 1083, 27, 'क्लीनिकल योजनाएं'),
(100914, 1084, 27, 'क्लीनिकल गुणवत्ता उपाय (CQM)'),
(100915, 1087, 27, 'क्लीनिकल अनुस्मारक'),
(100916, 1088, 27, 'क्लीनिकल रिपोर्टें'),
(100917, 1089, 27, 'क्लीनिकल नियम कार्रवाई श्रेणी'),
(100918, 1090, 27, 'क्लीनिकल नियम कार्रवाई आइटम'),
(100919, 1091, 27, 'क्लीनिकल नियम फ़िल्टर के तरीके'),
(100920, 1092, 27, 'क्लीनिकल नियम लक्षित तरीके'),
(100921, 1093, 27, 'क्लीनिकल नियम'),
(100922, 1094, 27, 'क्लीनिकल नियम उम्र अंतराल'),
(100923, 1095, 27, 'क्लीनिकल नियम तुलना'),
(100924, 1096, 27, 'क्लीनिकल नियम मुठभेड़ प्रकार'),
(100925, 1097, 27, 'क्लीनिकल नियम अनुस्मारक लंबित विकल्प'),
(100926, 1098, 27, 'क्लीनिकल नियम अनुस्मारक निष्क्रियता विकल्प'),
(100927, 1099, 27, 'क्लीनिकल नियम अनुस्मारक अंतराल'),
(100928, 1100, 27, 'क्लीनिकल नियम अनुस्मारक तरीके'),
(100929, 1101, 27, 'क्लीनिकल नियम लक्षित अंतराल'),
(100930, 1102, 27, 'क्लीनिकल लक्ष्य'),
(100931, 1103, 27, 'क्लीनिकल अवधि'),
(100932, 1104, 27, 'क्लीनिकल अवधि संहिता (ओं)'),
(100933, 1106, 27, 'चिकित्सकों के लिए'),
(100934, 1107, 27, 'क्लोन'),
(100935, 1108, 27, 'पिछले भेंट क्लोन करें'),
(100936, 1109, 27, 'बंद करें'),
(100937, 1111, 27, 'खिड़की बन्द कीजिये'),
(100938, 1112, 27, 'बंद'),
(100939, 1113, 27, 'से.मी.'),
(100940, 1114, 27, 'सीएमएस 1500 मार्जिन्स'),
(100941, 1118, 27, 'सीएमएस आईडी'),
(100942, 1127, 27, 'CN2 -12 बरकरार'),
(100943, 1128, 27, 'सह- पे'),
(100944, 1129, 27, 'सह- पे भुगतान किया'),
(100945, 1130, 27, 'सह- पे'),
(100946, 1131, 27, 'कोड'),
(100947, 1132, 27, 'कोड'),
(100948, 1133, 27, 'कोड खोजक'),
(100949, 1134, 27, 'कोड दो अक्षर लोअरकेस होना चाहिए'),
(100950, 1135, 27, 'मुद्रा संकेत करने के लिए कोड या प्रतीक'),
(100951, 1136, 27, 'कोड पाठ'),
(100952, 1138, 27, 'कोड प्रकार'),
(100953, 1141, 27, 'कोड प्रकार'),
(100954, 1142, 27, 'कोड्स'),
(100955, 1143, 27, 'कोडित किया'),
(100956, 1144, 27, 'कोड्स'),
(100957, 1145, 27, 'कोडिंग'),
(100958, 1147, 27, 'कोडिंग - किसी मुठभेड़ों (लिखने, wsome वैकल्पिक)'),
(100959, 1148, 27, 'कोडिंग - मेरे मुठभेड़ों (लिखने, wsome वैकल्पिक)'),
(100960, 1149, 27, 'कोडिंग अधिकृत नहीं'),
(100961, 1150, 27, 'कॉफ़ी'),
(100962, 1152, 27, 'सहबीमा'),
(100963, 1153, 27, 'Coll w / ओ'),
(100964, 1154, 27, 'संकुचित करें'),
(100965, 1155, 27, 'संकुचित करें'),
(100966, 1156, 27, 'सभी संकुचित करें'),
(100967, 1157, 27, 'सभी संकुचित करें'),
(100968, 1158, 27, 'सभी संकुचित करें'),
(100969, 1160, 27, 'संग्रह की तिथि'),
(100970, 1161, 27, 'संग्रह'),
(100971, 1162, 27, 'संग्रह रिपोर्ट'),
(100972, 1163, 27, 'पेट के कैंसर'),
(100973, 1164, 27, 'पेट के कैंसर स्क्रीनिंग'),
(100974, 1165, 27, 'पेट के कैंसर सर्जरी'),
(100975, 1166, 27, 'बृहदांत्रदर्शन'),
(100976, 1167, 27, 'बृहदांत्रदर्शन'),
(100977, 1168, 27, 'रंग'),
(100978, 1169, 27, 'रंग: Abbr'),
(100979, 1170, 27, 'कॉलम'),
(100980, 1171, 27, 'कॉलम'),
(100981, 1172, 27, 'संयोजन लॉट'),
(100982, 1173, 27, 'अल्पविराम'),
(100983, 1174, 27, 'टिप्पणी'),
(100984, 1175, 27, 'टिप्पणियां'),
(100985, 1176, 27, 'यह परिणाम या सिफारिश के लिए टिप्पणियाँ'),
(100986, 1177, 27, 'वाणिज्यिक बीमा कंपनी'),
(100987, 1178, 27, 'परिवर्तन कमेटी'),
(100988, 1180, 27, 'संचार'),
(100989, 1182, 27, 'कंपनी'),
(100990, 1183, 27, 'कंपनी का नाम'),
(100991, 1184, 27, 'पूरा'),
(100992, 1186, 27, 'पूरा'),
(100993, 1188, 27, 'पूरे किए?'),
(100994, 1190, 27, 'सेवा प्रदाता द्वारा जटिलताओं'),
(100995, 1191, 27, 'गर्भपात की जटिलताओं'),
(100996, 1192, 27, 'अवयव'),
(100997, 1193, 27, 'कंप्यूटर एडेड मेडिकल आदेश सिस्टम'),
(100998, 1194, 27, 'निष्कर्ष'),
(100999, 1199, 27, 'विन्यास'),
(101000, 1200, 27, 'विन्यास निर्यात / आयात'),
(101001, 1202, 27, 'ग्राहक साइड का SSL प्रमाणपत्र का उपयोग करने के लिए अपाचे और LibreEHR विन्यस्त करें.'),
(101002, 1203, 27, 'ग्राहक साइड SSL प्रमाणपत्र का उपयोग करने के लिए अपाचे कॉन्फ़िगर करें.'),
(101003, 1204, 27, 'HTTPS का उपयोग करने के लिए अपाचे कॉन्फ़िगर करें.'),
(101004, 1205, 27, 'ग्राहक साइड SSL प्रमाणपत्र का उपयोग करने के लिए LIBREEHR कॉन्फ़िगर करें.'),
(101005, 1208, 27, 'नई रोगी बनाने के लिए पुष्टि'),
(101006, 1209, 27, 'नए पासवर्ड की पुष्टि'),
(101007, 1210, 27, 'भुगतान की पुष्टि'),
(101008, 1214, 27, 'जन्मजात'),
(101009, 1215, 27, 'Conjuntiva, पुतली'),
(101010, 1217, 27, 'कनेक्टर्स'),
(101011, 1218, 27, 'स्थिर'),
(101012, 1219, 27, 'स्थिर नाम'),
(101013, 1220, 27, 'स्थिर नाम रिक्त है'),
(101014, 1221, 27, 'स्थिरांक'),
(101015, 1222, 27, 'कब्ज'),
(101016, 1223, 27, 'संवैधानिक'),
(101017, 1226, 27, 'परामर्श संक्षिप्त विवरण'),
(101018, 1227, 27, 'संपर्क'),
(101019, 1228, 27, 'ईमेल संपर्क'),
(101020, 1229, 27, 'ईमेल पता'),
(101021, 1230, 27, 'PhiMail प्रत्यक्ष संदेश सेवा की सदस्यता के लिए ईएमआर प्रत्यक्ष संपर्क करें'),
(101022, 1231, 27, 'संपर्क जानकारी'),
(101023, 1232, 27, 'सम्पर्क लेंस'),
(101024, 1233, 27, 'लैब विनिमय सेवा के लिए http://mi-squared.com मेडिकल इन्फोर्मेशन इंटीग्रेशन, LLC संपर्क करें.'),
(101025, 1234, 27, 'eRX सेवा सदस्यता लेने के लिए ZH हेल्थकेयर http://zhservices.com या http://mi-squared.com मेडिकल इन्फोर्मेशन इंटीग्रेशन, LLC संपर्क करें'),
(101026, 1236, 27, 'संपर्क नाम'),
(101027, 1237, 27, 'संपर्क व्यक्ति'),
(101028, 1239, 27, 'फोन नंबर संपर्क'),
(101029, 1240, 27, 'ERX सेवा सदस्यता लेने के लिए संपर्क ZMG, LLC (zmghealth@gmail.com)'),
(101030, 1241, 27, 'चार निम्नलिखित आइटम के कम से कम तीन होते हैं:'),
(101031, 1242, 27, 'कंटेनर समूह का नाम'),
(101032, 1243, 27, 'सामग्री'),
(101033, 1244, 27, 'सामग्री'),
(101034, 1245, 27, 'प्रसंग'),
(101035, 1246, 27, 'प्रसंग नाम खाली नहीं हो सकता'),
(101036, 1247, 27, 'जारी'),
(101037, 1248, 27, 'केयर दस्तावेज़ की निरंतरता (सीसीडी)'),
(101038, 1249, 27, 'केयर रिकार्ड की निरंतरता (सीसीआर)'),
(101039, 1250, 27, 'कॉन्ट्रा ग्राहकों'),
(101040, 1251, 27, 'कंट्रसेपशन'),
(101041, 1252, 27, 'गर्भनिरोध मुद्दे'),
(101042, 1253, 27, 'गर्भनिरोधक जटिलता (बताएं)'),
(101043, 1254, 27, 'गर्भनिरोधक विधि'),
(101044, 1255, 27, 'गर्भनिरोधक उत्पाद'),
(101045, 1256, 27, 'गर्भ निरोधक सेवाओं को पहले से शुरू'),
(101046, 1257, 27, 'निरोधकों प्रारंभ'),
(101047, 1258, 27, 'नियंत्रण आईडी'),
(101048, 1259, 27, 'नियंत्रण नंबर'),
(101049, 1261, 27, 'सह-पे'),
(101050, 1262, 27, 'सह-पे'),
(101051, 1263, 27, 'सह-पे'),
(101052, 1264, 27, 'सह-पे सकारात्मक नहीं'),
(101053, 1266, 27, 'सह-पे'),
(101054, 1267, 27, 'सीओपीडी'),
(101055, 1268, 27, 'रोगी चार्ट के लिए पृष्ठ कॉपी करें'),
(101056, 1269, 27, 'कॉपी मूल्यों'),
(101057, 1270, 27, 'डेटाबेस फाइल कॉपी कर रहा है. कुछ समय ले जाएगा ...'),
(101058, 1271, 27, 'कॉपीराइट सूचना'),
(101059, 1273, 27, 'कोरोनरी धमनी बाईपास'),
(101060, 1274, 27, 'कोरोनरी धमनी बाइपास ग्राफ़्ट (CABG)'),
(101061, 1275, 27, 'सुधारा'),
(101062, 1277, 27, 'CouchDB'),
(101063, 1278, 27, 'CouchDB के कनेक्शन विफल.'),
(101064, 1279, 27, 'CouchDB के डाटाबेस'),
(101065, 1280, 27, 'CouchDB के डेटाबेस का नाम'),
(101066, 1281, 27, 'CouchDB के मेजबान'),
(101067, 1282, 27, 'CouchDB होस्टनाम'),
(101068, 1283, 27, 'CouchDB के प्रवेश सक्षम'),
(101069, 1284, 27, 'CouchDB पासवर्ड'),
(101070, 1285, 27, 'CouchDB के पोर्ट'),
(101071, 1286, 27, 'CouchDB के पोर्ट'),
(101072, 1288, 27, 'CouchDB उपयोगकर्ता नाम'),
(101073, 1289, 27, 'खाँसी:'),
(101074, 1290, 27, 'खाँसी:'),
(101075, 1294, 27, 'फ़ाइल नहीं पढ़ सका'),
(101076, 1296, 27, 'ईमेल नहीं भेजा जा सका,कारण एक सर्वर की समस्या '),
(101077, 1297, 27, 'ईमेल नहीं भेजा जा सका,कारण एक सर्वर की समस्या '),
(101078, 1298, 27, 'बैकअप निर्देशिका नहीं बना सका:'),
(101079, 1299, 27, 'निर्देशिका हटा नहीं सका:'),
(101080, 1300, 27, 'पुराने बैकअप फ़ाइल हटा नहीं सका:'),
(101081, 1301, 27, 'पुराने निर्यात फ़ाइल हटा नहीं सका:'),
(101082, 1302, 27, 'Coumadin प्रबंधन - INR निगरानी'),
(101083, 1303, 27, 'विधि द्वारा परामर्श'),
(101084, 1304, 27, 'परामर्श'),
(101085, 1305, 27, 'परामर्श गतिविधियों'),
(101086, 1306, 27, 'जवाबी रेफरल फार्म'),
(101087, 1307, 27, 'जवाबी रेफरल'),
(101088, 1308, 27, 'देश'),
(101089, 1309, 27, 'देश डेटा प्रकार'),
(101090, 1310, 27, 'देश सूची'),
(101091, 1311, 27, 'देश सूची (लिखने, addonly वैकल्पिक)'),
(101092, 1312, 27, 'देश का नाम दो अक्षरों में प्रतिनिधित्व होना चाहिए. (उदाहरण: यूनाइटेड स्टेट्स यूएस है)'),
(101093, 1313, 27, 'काउंटी'),
(101094, 1315, 27, 'कूपन'),
(101095, 1318, 27, 'CPT'),
(101096, 1319, 27, 'CPT कोड'),
(101097, 1320, 27, 'CPT कोड'),
(101098, 1321, 27, 'CPT4 प्रक्रिया / सेवा'),
(101099, 1322, 27, 'CPTII प्रदर्शन मापने के'),
(101100, 1323, 27, 'CQM'),
(101101, 1324, 27, 'crackles:'),
(101102, 1325, 27, 'क्रीम'),
(101103, 1326, 27, 'प्रत्येक उपयोगकर्ता या ग्राहक मशीन के लिए एक क्लाइंट साइड SSL प्रमाणपत्र बनाएं.'),
(101104, 1327, 27, 'एक उपयोगकर्ता या होस्ट नाम के लिए एक क्लाइंट साइड SSL प्रमाणपत्र बनाएं.'),
(101105, 1329, 27, 'एक घटना बनाएँ'),
(101106, 1330, 27, 'पूर्ण बैकअप बनाएँ और डाउनलोड करें'),
(101107, 1332, 27, 'बैकअप बनाएँ'),
(101108, 1333, 27, 'बैच बनाएँ'),
(101109, 1334, 27, 'क्लाइंट प्रमाणपत्र बनाएं'),
(101110, 1335, 27, 'क्लाइंट साइड SSL प्रमाणपत्र बनाएं'),
(101111, 1336, 27, 'डुप्लिकेट बनाएँ'),
(101112, 1338, 27, 'Eventlog बैकअप बनाएँ'),
(101113, 1339, 27, 'नया मुद्दा बनाएं'),
(101114, 1340, 27, 'नई रोगी बनाएँ'),
(101115, 1342, 27, 'Offsite पोर्टल पहचान बनाएं'),
(101116, 1343, 27, 'ऑनसाइट पोर्टल पहचान बनाएं'),
(101117, 1344, 27, 'रोगी नोट बनाएँ'),
(101118, 1345, 27, 'SSL प्रमाणपत्र प्राधिकरण और सर्वर प्रमाण पत्र बनाएँ.'),
(101119, 1346, 27, 'भेंट बनाएँ'),
(101120, 1347, 27, 'बनाया गया'),
(101121, 1348, 27, 'निर्यात फ़ाइल बना रहा है'),
(101122, 1350, 27, 'रिमोट होस्ट पर यह फ़ाइल बनाने में विफल रहा है'),
(101123, 1351, 27, 'प्रजापति'),
(101124, 1352, 27, 'क्रेडिट'),
(101125, 1353, 27, 'क्रेडिट कार्ड'),
(101126, 1354, 27, 'क्रेडिट'),
(101127, 1356, 27, 'मापदंड'),
(101128, 1358, 27, 'Crohn  का रोग'),
(101129, 1359, 27, 'Crohns रोग'),
(101130, 1360, 27, 'सीएसवी निर्यात'),
(101131, 1361, 27, 'CSV फाइल'),
(101132, 1362, 27, 'CSV टेबल्स'),
(101133, 1363, 27, 'CU.MM'),
(101134, 1364, 27, 'क्यूबा'),
(101135, 1365, 27, 'मुद्रा दशमलव स्थान'),
(101136, 1366, 27, 'मुद्रा दशमलव बिंदु प्रतीक'),
(101137, 1367, 27, 'मुद्रा Designator'),
(101138, 1368, 27, 'मुद्रा हजारों विभाजक'),
(101139, 1369, 27, 'वर्तमान'),
(101140, 1370, 27, 'वर्तमान शराब'),
(101141, 1371, 27, 'वर्तमान परामर्श'),
(101142, 1372, 27, 'वर्तमान मानदंड'),
(101143, 1373, 27, 'वर्तमान दिन उजागर रंग'),
(101144, 1374, 27, 'वर्तमान में हर दिन धूम्रपान'),
(101145, 1375, 27, 'वर्तमान फ़ाइल नाम बदल गया था'),
(101146, 1376, 27, 'वर्तमान हैश'),
(101147, 1377, 27, 'वर्तमान स्थान'),
(101148, 1378, 27, 'वर्तमान दवाएं'),
(101149, 1379, 27, 'वर्तमान पासवर्ड'),
(101150, 1380, 27, 'वर्तमान रोगी'),
(101151, 1382, 27, 'वर्तमान मनोरंजनात्मक औषध'),
(101152, 1383, 27, 'वर्तमान में कुछ दिन धूम्रपान'),
(101153, 1386, 27, 'वर्तमान में सक्रिय'),
(101154, 1387, 27, 'वर्तमान में चल रहा है'),
(101155, 1388, 27, 'वर्तमान में सुविधाएं नहीं हैं.'),
(101156, 1389, 27, 'सिंड्रोम कुशिंग'),
(101157, 1390, 27, 'सिंड्रोम कुशिंग'),
(101158, 1392, 27, 'रिवाज'),
(101159, 1393, 27, 'कस्टम इनपुट?'),
(101160, 1394, 27, 'कस्टम तालिका'),
(101161, 1396, 27, 'CVX कोड'),
(101162, 1397, 27, 'CVX कोड मैपिंग'),
(101163, 1398, 27, 'CVX टीकाकरण'),
(101164, 1399, 27, 'चक्र'),
(101165, 1400, 27, 'CYP'),
(101166, 1401, 27, 'CYP फैक्टर'),
(101167, 1402, 27, 'CYP रिपोर्ट'),
(101168, 1403, 27, 'चेक देश'),
(101169, 1404, 27, 'डी'),
(101170, 1405, 27, 'डी एंड सी'),
(101171, 1406, 27, 'डी और ई'),
(101172, 1407, 27, 'D.O.B.'),
(101173, 1408, 27, 'दैनिक'),
(101174, 1409, 27, 'डेली रिकॉर्ड'),
(101175, 1410, 27, 'डेनिश'),
(101176, 1411, 27, 'एक जैसे डेटा डेटाबेस में पहले से ही है, कोड / या वर्णन बदलें'),
(101177, 1412, 27, 'एक जैसे डेटा डेटाबेस में पहले से ही है, कृपया स्थिर नाम बदलें'),
(101178, 1413, 27, 'डेटा कॉलम'),
(101179, 1416, 27, 'डेटा त्रुटि'),
(101180, 1420, 27, 'डेटा प्रकार'),
(101181, 1421, 27, 'डेटाबेस'),
(101182, 1422, 27, 'डाटाबेस स्थापित नहीं है.'),
(101183, 1423, 27, 'डाटाबेस पैच'),
(101184, 1424, 27, 'डेटाबेस रिपोर्टिंग'),
(101185, 1425, 27, 'डेटाबेस नवीनीकरण समाप्त हो गया.'),
(101186, 1426, 27, 'DataCols 1 और 999 के बीच में होनी चाहिए'),
(101187, 1427, 27, 'तिथि'),
(101188, 1428, 27, 'तिथि'),
(101189, 1429, 27, 'दिनांक और समय प्रशासित'),
(101190, 1431, 27, 'प्रशासित तिथि'),
(101191, 1432, 27, 'नमूना संग्रह की तिथि और समय'),
(101192, 1433, 27, 'इस अवलोकन की तिथि और समय'),
(101193, 1435, 27, 'तिथि और समय नमूना एकत्र किया गया था'),
(101194, 1436, 27, 'तिथि आज से बड़ी नहीं हो सकती'),
(101195, 1437, 27, 'शुरू तिथि गर्भनिरोधक सेवाएं प्रदान की'),
(101196, 1438, 27, 'तिथि निर्माण'),
(101197, 1439, 27, 'मृतक तिथि'),
(101198, 1440, 27, 'तिथि तबाह'),
(101199, 1441, 27, 'तिथि प्रदर्शन स्वरूप'),
(101200, 1442, 27, 'नियुक्ति अंत के लिए तिथि प्रारूप मान्य नहीं है'),
(101201, 1443, 27, 'नियुक्ति प्रारंभ के लिए तिथि प्रारूप मान्य नहीं है'),
(101202, 1444, 27, 'अगले नियुक्ति के लिए तिथि प्रारूप मान्य नहीं है'),
(101203, 1445, 27, 'के बाद से नहीं देखा के लिए तिथि प्रारूप मान्य नहीं है'),
(101204, 1446, 27, 'जब से देखा के लिए तिथि प्रारूप मान्य नहीं है'),
(101205, 1447, 27, 'तिथि प्रतिरक्षण सूचना वक्तव्य निश्चित'),
(101206, 1448, 27, 'कोड के लिए तिथि लापता '),
(101207, 1449, 27, 'तिथि मास्टर मानदंड'),
(101208, 1450, 27, 'बैंक जमा YYYY-MM-DD की तिथि'),
(101209, 1451, 27, 'बिलिंग की तिथि'),
(101210, 1452, 27, 'जन्म तिथि'),
(101211, 1453, 27, 'जन्म तिथि'),
(101212, 1454, 27, 'जन्म तिथि'),
(101213, 1455, 27, 'प्रवेश की तिथि'),
(101214, 1456, 27, 'चोट की तिथि'),
(101215, 1458, 27, 'भुगतान YYYY-MM-DD की तिथि'),
(101216, 1459, 27, 'सिफ़ारिश की तिथि'),
(101217, 1460, 27, 'उत्तर की तिथि'),
(101218, 1461, 27, 'रिपोर्ट की तिथि'),
(101219, 1462, 27, 'सेवा की तिथि'),
(101220, 1463, 27, 'सेवा की तिथि'),
(101221, 1464, 27, 'आज = सर्विस की तिथि'),
(101222, 1465, 27, 'सेवा dd / mm / yyyy की तिथि'),
(101223, 1466, 27, 'सेवा की तिथि:'),
(101224, 1467, 27, 'हस्ताक्षर की तिथि'),
(101225, 1468, 27, 'स्थिति को बदलने की तिथि'),
(101226, 1469, 27, 'इस आदेश की तिथि'),
(101227, 1470, 27, 'इस रिपोर्ट की तिथि'),
(101228, 1471, 27, 'VIS बयान की तिथि'),
(101229, 1472, 27, 'तिथि आदेश दिया'),
(101230, 1475, 27, 'तिथि चयनकर्ता'),
(101231, 1476, 27, 'भेजा गया तिथि'),
(101232, 1477, 27, 'तिथि संदेश भेजा गया था'),
(101233, 1479, 27, 'तिथि मान रिक्त नहीं हो सकता.'),
(101234, 1480, 27, 'तिथि / Appt'),
(101235, 1481, 27, 'तिथि / नोट्स'),
(101236, 1482, 27, 'तिथि / अंतिम की नोट्स'),
(101237, 1483, 27, 'तिथि / समय'),
(101238, 1484, 27, 'तिथि'),
(101239, 1485, 27, 'संदेश लॉग तिथि'),
(101240, 1486, 27, 'दिन'),
(101241, 1487, 27, 'दिन'),
(101242, 1489, 27, 'दिन देखें'),
(101243, 1490, 27, 'दिन'),
(101244, 1491, 27, 'दिन सोमवार - शुक्रवार'),
(101245, 1492, 27, 'दिन'),
(101246, 1493, 27, 'दिन'),
(101247, 1494, 27, 'दिन पहले'),
(101248, 1495, 27, 'दिन और खेल छूटे'),
(101249, 1496, 27, 'पिछले मुठभेड़ से दिन'),
(101250, 1497, 27, 'छूटे दिन'),
(101251, 1498, 27, 'प्रति दिन कॉलम'),
(101252, 1500, 27, 'दिन/Col:'),
(101253, 1501, 27, 'DB स्थापित'),
(101254, 1502, 27, 'DD / MM / YYYY'),
(101255, 1503, 27, 'De Identification'),
(101256, 1504, 27, 'De Identification की प्रक्रिया पूरी हो गई'),
(101257, 1505, 27, 'De Identification की प्रक्रिया चल रही है'),
(101258, 1506, 27, 'De Identification की प्रक्रिया शुरू कर दिई और पृष्ठभूमि में चल रही है'),
(101259, 1507, 27, 'De Identification डेटा शायद पूरा नहीं'),
(101260, 1508, 27, 'में De Identification फ़ाइल सहेजा जाएगा'),
(101261, 1509, 27, 'डीईए'),
(101262, 1511, 27, 'बहरा'),
(101263, 1512, 27, 'डिबग जानकारी'),
(101264, 1514, 27, 'डीबगिंग'),
(101265, 1515, 27, 'दिसम्बर'),
(101266, 1516, 27, 'स्वर्गीय'),
(101267, 1517, 27, 'दिसंबर'),
(101268, 1518, 27, 'दशमलव पाउंड या पाउंड और औंस # द्वारा अलग (जैसे 5 # 4)'),
(101269, 1520, 27, 'कटौती योग्य'),
(101270, 1521, 27, 'कटौती योग्य मुलाकात'),
(101271, 1522, 27, 'डिफ़ॉल्ट'),
(101272, 1523, 27, 'डिफ़ॉल्ट कैलेंडर देखें'),
(101273, 1524, 27, 'डिफ़ॉल्ट मुठभेड़ पर्चा आईडी'),
(101274, 1526, 27, 'डिफ़ॉल्ट सुविधा'),
(101275, 1527, 27, 'डिफ़ॉल्ट भाषा'),
(101276, 1528, 27, 'डिफ़ॉल्ट भाषा यदि कोई अन्य की अनुमति नहीं है या चुना नहीं जाता है.'),
(101277, 1529, 27, 'डिफ़ॉल्ट सूची (, addonly वैकल्पिक लिखने)'),
(101278, 1530, 27, 'डिफ़ॉल्ट विधि'),
(101279, 1531, 27, 'डिफ़ॉल्ट पासवर्ड समाप्त दिन'),
(101280, 1532, 27, 'डिफ़ॉल्ट पासवर्ड समाप्त अवधि दिन में. 0 इसका मतलब है सुविधा अक्षम है.'),
(101281, 1533, 27, 'डिफ़ॉल्ट रोगी देश'),
(101282, 1535, 27, 'डिफ़ॉल्ट प्राथमिकता'),
(101283, 1536, 27, 'डिफ़ॉल्ट प्रदाता'),
(101284, 1537, 27, 'डिफ़ॉल्ट सीमा'),
(101285, 1538, 27, 'भेंट के लिए डिफ़ॉल्ट कारण'),
(101286, 1540, 27, 'डिफ़ॉल्ट सेटिंग'),
(101287, 1541, 27, 'रोगी सूची में नई विंडो चेकबॉक्स की डिफ़ॉल्ट स्थिति.'),
(101288, 1542, 27, 'डिफ़ॉल्ट टेम्पलेट'),
(101289, 1546, 27, 'डिफ़ॉल्ट इकाइयों'),
(101290, 1547, 27, 'डिफ़ॉल्ट मूल्य'),
(101291, 1548, 27, 'डिफ़ॉल्ट वेयरहाउस'),
(101292, 1549, 27, 'डिफ़ॉल्ट X 12 साथी'),
(101293, 1550, 27, 'डिफ़ॉल्ट / ग्लोबल'),
(101294, 1551, 27, 'को हटाएँ'),
(101295, 1552, 27, 'को हटाएँ'),
(101296, 1553, 27, 'विलंबित पुनरावर्तन (> 12 मो)'),
(101297, 1554, 27, 'को हटाएँ'),
(101298, 1555, 27, 'हटाना'),
(101299, 1556, 27, 'आईडी (s) के साथ श्रेणियाँ हटाएँ: '),
(101300, 1557, 27, 'श्रेणी को हटाएँ'),
(101301, 1559, 27, 'को हटाएँ विफल रहा है!'),
(101302, 1560, 27, 'समूह को हटाएँ'),
(101303, 1561, 27, 'सूची को हटाएँ'),
(101304, 1562, 27, 'पृष्ठों को हटाएँ'),
(101305, 1563, 27, 'रोगी, मुठभेड़, फार्म, अंक, दस्तावेज, भुगतान, बिलिंग या लेनदेन हटाएं'),
(101306, 1565, 27, 'पंक्ति हटाएँ'),
(101307, 1566, 27, 'चयनित आइटम हटाएं'),
(101308, 1568, 27, 'को हटाएँ सफल.'),
(101309, 1569, 27, 'इस दस्तावेज़ को हटाएं'),
(101310, 1570, 27, 'इस फार्म को हटाएँ'),
(101311, 1571, 27, 'इस नोट को हटाएं'),
(101312, 1573, 27, 'सफलतापूर्वक नष्ट कर दिया.'),
(101313, 1574, 27, 'हटा रहा है!'),
(101314, 1575, 27, 'इस घटना को एक बार हटाया तो पूर्ववत नहीं किया जा सकता, वह चला गया है, यह ठीक नहीं किया जा सकता! क्या आप इस घटना को हटाना चाहते हैं?'),
(101315, 1576, 27, 'वितरण की पुष्टि'),
(101316, 1578, 27, 'वर्तमान निर्दिष्ट पते पर प्रत्यक्ष वितरण की अनुमति नहीं है!'),
(101317, 1580, 27, 'संलग्न नैदानिक ​​दस्तावेज़ का वितरण, रोगी द्वारा अनुरोध किया गया था!'),
(101318, 1581, 27, 'मनोभ्रंश'),
(101319, 1582, 27, 'जनसांख्यिकी'),
(101320, 1583, 27, 'जनसांख्यिकी (, addonly वैकल्पिक लिखने)'),
(101321, 1585, 27, 'जनसांख्यिकी फ़िल्टर मापदंड'),
(101322, 1586, 27, 'जनसांख्यिकी अधिकृत नहीं.'),
(101323, 1587, 27, 'जनसांख्यिकी अधिकृत नहीं.'),
(101324, 1588, 27, 'से इनकार किया'),
(101325, 1589, 27, 'भाजक'),
(101326, 1590, 27, 'दंत चिकित्सा'),
(101327, 1591, 27, 'दंत चिकित्सा समस्या सूची'),
(101328, 1592, 27, 'दंत चिकित्सा मुद्दों पर'),
(101329, 1595, 27, 'Depending on the type of bill you are testing you will see HCFA like output on a blank page for HCFA bills, you will see many lines of somewhat garbled text and information if you are testing an X12 claim. That garbled text is the X12 EDI 4010A format. Occasionally you will see odd characters that look like dominoes or squiglies, these are control characters such as page feeds and are normal.'),
(101330, 1596, 27, 'जमा तिथि'),
(101331, 1597, 27, 'जमा तिथि आज से बड़ी नहीं हो सकती'),
(101332, 1598, 27, 'जमा तिथि:'),
(101333, 1599, 27, 'अवसादग्रस्त'),
(101334, 1600, 27, 'अवसाद'),
(101335, 1602, 27, 'विवरण'),
(101336, 1603, 27, 'विवरण'),
(101337, 1605, 27, 'प्रकटीकरण का विवरण'),
(101338, 1606, 27, 'इस प्रक्रिया या परिणाम कोड का विवरण'),
(101339, 1607, 27, 'विवरण अनुवाद'),
(101340, 1609, 27, 'गंतव्य'),
(101341, 1610, 27, 'गंतव्य फ़ाइलनाम'),
(101342, 1611, 27, 'लॉट नष्ट'),
(101343, 1612, 27, 'नष्ट ...'),
(101344, 1613, 27, 'नष्ट कर दिया'),
(101345, 1614, 27, 'दवाओं को नष्ट कर दिया!'),
(101346, 1615, 27, 'दवाओं की रिपोर्ट को नष्ट कर दिया!'),
(101347, 1616, 27, 'विवरण'),
(101348, 1617, 27, 'विवरण'),
(101349, 1619, 27, 'विकासात्मक विषमता'),
(101350, 1620, 27, 'मधुमेह'),
(101351, 1621, 27, 'बहुमूत्ररोग'),
(101352, 1622, 27, 'मधुमेह: रक्तचाप प्रबंधन (CQM)'),
(101353, 1623, 27, 'मधुमेह: नेत्र परीक्षा'),
(101354, 1624, 27, 'मधुमेह: नेत्र परीक्षा (CQM)'),
(101355, 1625, 27, 'मधुमेह: पैर परीक्षा'),
(101356, 1626, 27, 'मधुमेह: पैर परीक्षा (CQM)'),
(101357, 1627, 27, 'मधुमेह: एचबीए 1 सी खराब नियंत्रण (CQM)'),
(101358, 1628, 27, 'मधुमेह: हीमोग्लोबिन ए 1 सी'),
(101359, 1629, 27, 'मधुमेह: एलडीएल प्रबंधन और नियंत्रण (CQM)'),
(101360, 1630, 27, 'मधुमेह: मूत्र में Microalbumin'),
(101361, 1631, 27, 'निदान'),
(101362, 1632, 27, 'निदान'),
(101363, 1633, 27, 'निदान'),
(101364, 1634, 27, 'निदान कोड'),
(101365, 1636, 27, 'निदान तिथि'),
(101366, 1637, 27, 'निदान एक जुड़े हुए मुठभेड़ में कोडित किया जाना चाहिए'),
(101367, 1638, 27, 'निदान का नाम'),
(101368, 1639, 27, 'निदान की रिपोर्ट'),
(101369, 1640, 27, 'निदान रिपोर्टिंग'),
(101370, 1641, 27, 'केवल निदान रिपोर्टिंग'),
(101371, 1642, 27, 'निदान शीर्षक'),
(101372, 1643, 27, 'निदान:'),
(101373, 1644, 27, 'निदान: '),
(101374, 1645, 27, 'नैदानिक टेस्ट:'),
(101375, 1646, 27, 'डायल'),
(101376, 1647, 27, 'Diaphragms / कैप्स'),
(101377, 1648, 27, 'दस्त'),
(101378, 1650, 27, 'श्रुतलेख'),
(101379, 1651, 27, 'श्रुतलेख: '),
(101380, 1652, 27, 'आपने HIPAA नोटिस की एक प्रति प्राप्त किया है?'),
(101381, 1653, 27, 'फैलाना:'),
(101382, 1654, 27, 'डिजिटली हस्ताक्षरित'),
(101383, 1657, 27, 'प्रत्यक्ष मेल'),
(101384, 1658, 27, 'प्रत्यक्ष संदेश लॉग'),
(101385, 1659, 27, 'प्रत्यक्ष संदेश प्राप्त किया.'),
(101386, 1660, 27, 'प्रत्यक्ष संदेश सेवा वर्तमान में अनुपलब्ध है.'),
(101387, 1661, 27, 'प्रत्यक्ष संदेश भेजने में विफलता .'),
(101388, 1663, 27, 'निर्देशक का नाम'),
(101389, 1664, 27, 'निर्देशिका हटाना विफल, जारी है.'),
(101390, 1665, 27, 'विकलांगता'),
(101391, 1667, 27, 'कैलेंडर निष्क्रिय करें'),
(101392, 1668, 27, 'चार्ट ट्रैकर निष्क्रिय करें'),
(101393, 1669, 27, 'टीकाकरण निष्क्रिय करें'),
(101394, 1670, 27, 'निष्क्रिय करें पुराने मीट्रिक नब्ज पर्चा'),
(101395, 1672, 27, 'phpMyAdmin निष्क्रिय करें'),
(101396, 1673, 27, 'नुस्खे निष्क्रिय करें'),
(101397, 1674, 27, 'उपयोगकर्ता समूह निष्क्रिय करें'),
(101398, 1675, 27, 'निष्क्रिय कर दिया'),
(101399, 1676, 27, 'निष्क्रिय कर दिया'),
(101400, 1677, 27, 'बड़े समूह स्वास्थ्य योजना(LGHP) के 65 साल से कम उम्र के लाभार्थी निष्क्रिय करें!'),
(101401, 1678, 27, 'DISC'),
(101402, 1681, 27, 'निर्वहन'),
(101403, 1682, 27, 'मूत्रमार्ग से निर्वहन'),
(101404, 1684, 27, 'राइट निर्वहन'),
(101405, 1685, 27, 'राइट निर्वहन:'),
(101406, 1688, 27, 'छुट्टी दे दी'),
(101407, 1689, 27, 'प्रकटीकरण जानकारी'),
(101408, 1690, 27, 'प्रकटीकरण के प्रकार'),
(101409, 1691, 27, 'प्रकटीकरण के प्रकार'),
(101410, 1692, 27, 'खुलासे'),
(101411, 1694, 27, 'छूट'),
(101412, 1695, 27, 'छूट राशि'),
(101413, 1696, 27, 'सबसे कम स्तर'),
(101414, 1697, 27, 'छूट के प्रतिशत'),
(101415, 1698, 27, 'मौद्रिक मात्रा में छूट'),
(101416, 1699, 27, 'चेकआउट समय में छूट,धन राशि के रूप में दर्ज कर रहे हैं, प्रतिशत के रूप में नहीं!'),
(101417, 1700, 27, 'असतत नतीजे'),
(101418, 1701, 27, 'रोग'),
(101419, 1702, 27, 'विस्थापन'),
(101420, 1703, 27, 'disp #'),
(101421, 1704, 27, 'भेजना'),
(101422, 1705, 27, 'तक भेजने के प्राप्त दस्तावेज'),
(101423, 1706, 27, 'तिरस्कृत'),
(101424, 1707, 27, 'जनसांख्यिकी पेज में अग्रिम निर्देश प्रदर्शित करें!'),
(101425, 1709, 27, 'घटना ब्लॉक में दिनांक प्रदर्शित करें?'),
(101426, 1710, 27, 'अमेरिका तौल स्वरूप प्रदर्शित करें'),
(101427, 1711, 27, 'कितने घटनाओं को प्रदर्शित करें?'),
(101428, 1713, 27, 'ब्लॉक में स्थान प्रदर्शित करें?'),
(101429, 1714, 27, 'प्रदर्शन नाम'),
(101430, 1715, 27, 'कैलेंडर प्रदर्शित करें?'),
(101431, 1718, 27, 'आज के घटनाओं को ब्लॉक में प्रदर्शित करें?'),
(101432, 1719, 27, 'ब्लॉक में विषय दिखायें?'),
(101433, 1720, 27, 'ब्लॉक में आगामी घटनाएँ दिखायें?'),
(101434, 1721, 27, 'दिखाए गए कॉलम'),
(101435, 1722, 27, 'सबसे हाल ही में के खुलासे की निम्नलिखित संख्या प्रदर्शित हो रही हैं.'),
(101436, 1723, 27, 'सबसे हाल ही में के नोट्स की निम्नलिखित संख्या प्रदर्शित हो रही हैं'),
(101437, 1724, 27, 'सबसे हाल ही में के नोट्स की निम्नलिखित संख्या प्रदर्शित हो रही हैं'),
(101438, 1725, 27, 'वितरण'),
(101439, 1726, 27, 'वितरण'),
(101440, 1727, 27, 'वितरक'),
(101441, 1729, 27, 'विपुटीप्रदाह'),
(101442, 1730, 27, 'विपुटीप्रदाह सर्जरी'),
(101443, 1731, 27, 'विपुटीप्रदाह'),
(101444, 1732, 27, 'विपुटीप्रदाह सर्जरी'),
(101445, 1733, 27, 'तलाकशुदा'),
(101446, 1734, 27, 'चक्कर आना:'),
(101447, 1735, 27, 'न बदलें'),
(101448, 1737, 27, 'NewCrop पर अपलोड की एलर्जी प्रदर्शित नहीं करें'),
(101449, 1739, 27, 'NewCrop पर अपलोड की दवाएं प्रदर्शित नहीं करें'),
(101450, 1742, 27, 'कैलेंडर प्रदर्शित नहीं करें.'),
(101451, 1744, 27, 'कोई भी उत्पाद बेचना नहीं और इनवेंटरी नहीं करें'),
(101452, 1745, 27, 'रोगी नोटों को प्रमाणित होने की आवश्यकता नहीं है'),
(101453, 1746, 27, 'आदेश पुनर्जीवित नहीं करो'),
(101454, 1747, 27, 'न सहेजें'),
(101455, 1748, 27, 'स्थानापन्न मत करें'),
(101456, 1749, 27, 'कुछ न करो'),
(101457, 1751, 27, 'आप वास्तव में मिटाना चाहते हैं'),
(101458, 1752, 27, 'आप वास्तव में चयन को हटाना चाहते हैं?'),
(101459, 1753, 27, 'आप वास्तव में इस समूह को हटाना चाहते हैं'),
(101460, 1755, 27, 'क्या आप जारी रखना चाहते हैं?'),
(101461, 1756, 27, 'आप वाकई इसे हटाना चाहते हैं?'),
(101462, 1757, 27, 'आप हटाना चाहते हैं?'),
(101463, 1758, 27, 'आप इस रिकॉर्ड को दूर करना चाहते हैं?'),
(101464, 1759, 27, 'आप नए रोगी जोड़ना जारी रखना चाहते हैं?'),
(101465, 1760, 27, 'आप नए नाम के साथ जारी रखना चाहते हैं?'),
(101466, 1761, 27, 'आप स्थायी रूप से इस प्रतिरक्षण रिकॉर्ड को नष्ट करना चाहते हैं?'),
(101467, 1762, 27, 'जन्म तिथि'),
(101468, 1763, 27, 'जन्म तिथि यदि संभव हो तो कृपया, दर्ज करें!'),
(101469, 1764, 27, 'दस्तावेज़'),
(101470, 1765, 27, 'चिकित्सक'),
(101471, 1766, 27, 'डॉक्टर:'),
(101472, 1767, 27, 'डॉक्टर का नाम और हस्ताक्षर'),
(101473, 1768, 27, 'दस्तावेज़'),
(101474, 1769, 27, 'दस्तावेज़'),
(101475, 1770, 27, 'दस्तावेज़ श्रेणियाँ'),
(101476, 1775, 27, 'दस्तावेज़ रोगी आईडी पे स्थानांतरित नहीं किया जा सकता है!'),
(101477, 1777, 27, 'दस्तावेज़ तिथि'),
(101478, 1778, 27, 'दस्तावेज की तारीख और मुद्दा सफलतापूर्वक अपडेट'),
(101479, 1779, 27, 'दस्तावेज़ ID'),
(101480, 1780, 27, 'दस्तावेज नई श्रेणी में ले जाया गया'),
(101481, 1781, 27, 'दस्तावेज़ रोगी आईडी में ले जाया गया'),
(101482, 1783, 27, 'दस्तावेज़ अखंडता जांच पारित कर दिया.'),
(101483, 1784, 27, 'दस्तावेज़ संग्रहण विधि'),
(101484, 1785, 27, 'दस्तावेज़ को सफलतापूर्वक नाम दिया.'),
(101485, 1790, 27, 'दस्तावेज / इमेजिंग स्टोर'),
(101486, 1791, 27, 'दस्तावेज'),
(101487, 1792, 27, 'दस्तावेज़ (, addonly वैकल्पिक लिखने)'),
(101488, 1794, 27, 'DOE'),
(101489, 1796, 27, 'PV1 मुठभेड़ संख्या मेल नहीं खाता'),
(101490, 1797, 27, 'मान्य नहीं लगता'),
(101491, 1798, 27, 'इस प्रकार संबंधित कोड की अनुमति है?'),
(101492, 1799, 27, 'घरेलू साथी'),
(101493, 1800, 27, 'नहीं सहेजें'),
(101494, 1801, 27, 'नहीं सहेजें'),
(101495, 1802, 27, 'परिवर्तन नहीं सहेजें'),
(101496, 1803, 27, 'पूर्ण'),
(101497, 1804, 27, 'हो गया:'),
(101498, 1805, 27, 'हो गया. अब डाउनलोड भेज देंगे.'),
(101499, 1806, 27, 'DOS'),
(101500, 1807, 27, 'खुराक'),
(101501, 1809, 27, 'संपादित करने के लिए डबल क्लिक करें'),
(101502, 1810, 27, 'व्दिगुण दृष्टि'),
(101503, 1811, 27, 'डाउनलोड'),
(101504, 1814, 27, 'वैसे भी डाउनलोड करें'),
(101505, 1815, 27, 'बिलिंग फ़ाइल डाउनलोड करें लेखांकन मे पोस्ट करें और बिल भेजा मार्क करें!'),
(101506, 1817, 27, 'प्रमाणपत्र डाउनलोड करें'),
(101507, 1818, 27, 'डाउनलोड विन्यास डेटा'),
(101508, 1820, 27, 'एन्क्रिप्टेड फाइल को डाउनलोड करें'),
(101509, 1825, 27, 'डाउनलोड पीडीएफ'),
(101510, 1827, 27, 'चयनित विवरण डाउनलोड करें'),
(101511, 1828, 27, 'डॉ. जाँचें'),
(101512, 1829, 27, 'डॉ. भेंट'),
(101513, 1830, 27, 'डॉ.'),
(101514, 1831, 27, 'शिफ्ट के लिए खींचें'),
(101515, 1832, 27, 'ड्रिब्लिंग'),
(101516, 1833, 27, 'चालक लाइसेंस या राज्य आईडी'),
(101517, 1834, 27, 'दवा'),
(101518, 1835, 27, 'दवा खोजक'),
(101519, 1836, 27, 'दवा फॉर्म्स'),
(101520, 1837, 27, 'दवा आईडी लापता!'),
(101521, 1838, 27, 'दवा अंतराल'),
(101522, 1839, 27, 'दवा सूची'),
(101523, 1840, 27, 'दवा का नाम');
INSERT INTO `lang_definitions` VALUES
(101524, 1841, 27, 'दवा मार्ग'),
(101525, 1845, 27, 'दवा इकाइयों'),
(101526, 1846, 27, 'दवा'),
(101527, 1847, 27, 'दवा और उत्पाद'),
(101528, 1848, 27, 'शुष्क मुँह'),
(101529, 1849, 27, 'DSMIV निदान'),
(101530, 1850, 27, 'डीटी 1'),
(101531, 1851, 27, 'डीटी 2'),
(101532, 1852, 27, 'डीटी 3'),
(101533, 1853, 27, 'डीटी 4'),
(101534, 1854, 27, 'डीटी 5'),
(101535, 1855, 27, 'DTaP 1'),
(101536, 1856, 27, 'DTaP 2'),
(101537, 1857, 27, 'DTaP 3'),
(101538, 1858, 27, 'DTaP 4'),
(101539, 1859, 27, 'DTaP 5'),
(101540, 1860, 27, 'देय'),
(101541, 1861, 27, 'देय तिथि'),
(101542, 1862, 27, 'देय तारीख dd / mm / yyyy या YYYY-MM-DD'),
(101543, 1863, 27, 'देय तिथि:'),
(101544, 1864, 27, 'देय बीमा'),
(101545, 1865, 27, 'देय रोगी'),
(101546, 1866, 27, 'जल्द ही देय'),
(101547, 1867, 27, 'देय स्थिति'),
(101548, 1868, 27, 'देय स्थिति अपडेट'),
(101549, 1869, 27, 'LibreEHR डेटाबेस डम्पिंग'),
(101550, 1870, 27, 'LibreEHR वेब निर्देशिका वृक्ष डम्पिंग'),
(101551, 1871, 27, 'PhpGACL डेटाबेस डम्पिंग'),
(101552, 1872, 27, 'PhpGACL वेब निर्देशिका वृक्ष डम्पिंग'),
(101553, 1873, 27, 'एसक्यूएल लेजर डेटाबेस डम्पिंग'),
(101554, 1874, 27, 'डम्पिंग एसक्यूएल लेजर वेब निर्देशिका वृक्ष'),
(101555, 1875, 27, 'दोहराया जाँच'),
(101556, 1876, 27, 'लाइन पर दोहराया आईडी'),
(101557, 1877, 27, 'लाइन पर दोहराया नाम'),
(101558, 1878, 27, 'दोहराव चेतावनी'),
(101559, 1879, 27, 'वकील के टिकाऊ शक्ति'),
(101560, 1880, 27, 'अवधि'),
(101561, 1881, 27, 'अवधि'),
(101562, 1882, 27, 'डच देश'),
(101563, 1883, 27, 'Dx Rep'),
(101564, 1884, 27, 'निगलने में कठिनाई'),
(101565, 1885, 27, 'श्वासकष्ट:'),
(101566, 1886, 27, 'मूत्रकृच्छता सम्बन्धी'),
(101567, 1888, 27, 'ई पर्चे?'),
(101568, 1889, 27, 'ई की रिपोर्ट'),
(101569, 1890, 27, 'ई Rx'),
(101570, 1892, 27, 'ई Rx नवीकरण'),
(101571, 1893, 27, 'प्रत्येक प्राप्तकर्ता,अपने स्वयं के संदेशों को पूरा हो गया के रूप में सेट कर दे'),
(101572, 1894, 27, 'प्रारंभिक पुनरावृत्ति (<2 मो)'),
(101573, 1895, 27, 'कान'),
(101574, 1896, 27, 'ईसीजी'),
(101575, 1897, 27, 'eClaims'),
(101576, 1898, 27, 'सूजन'),
(101577, 1899, 27, 'ईडीआई इतिहास'),
(101578, 1900, 27, 'ईडीआई इतिहास'),
(101579, 1901, 27, 'ईडीआई इतिहास (शुल्क मे) ईडीआई दावा प्रतिक्रिया फ़ाइल भंडारण और व्याख्या के लिए!'),
(101580, 1902, 27, 'ईडीआई-271 फाइल अपलोड'),
(101581, 1903, 27, 'ईडीआई-271 रिस्पांस फाइल अपलोड'),
(101582, 1904, 27, 'संपादित करें'),
(101583, 1905, 27, 'संपादित करें'),
(101584, 1906, 27, 'संपादित करें एलर्जी'),
(101585, 1907, 27, 'संपादित करें श्रेणियाँ'),
(101586, 1908, 27, 'संपादित करें परिभाषाएँ'),
(101587, 1909, 27, 'संपादित करें परिभाषाएँ'),
(101588, 1910, 27, 'के लिए संपादित करें निदान'),
(101589, 1911, 27, 'संपादित करें प्रकटीकरण'),
(101590, 1912, 27, 'संपादित करें सुविधाएं'),
(101591, 1913, 27, 'संपादित करें सुविधा'),
(101592, 1914, 27, 'संपादित करें सुविधा सूचना'),
(101593, 1915, 27, 'संपादित करें सुविधा उपयोगकर्ता विशिष्ट जानकारी'),
(101594, 1916, 27, 'संपादित करें फ़ाइल में'),
(101595, 1917, 27, 'संपादित करें फार्म'),
(101596, 1918, 27, 'संपादित करें वैश्विक सेटिंग्स'),
(101597, 1919, 27, 'संपादन अधिकृत नहीं है!'),
(101598, 1920, 27, 'संपादित करें लेआउट'),
(101599, 1921, 27, 'संपादित करें सूची'),
(101600, 1922, 27, 'संपादित करें पेमेंट'),
(101601, 1923, 27, 'संपादित करें संरचना'),
(101602, 1924, 27, 'उपयोगकर्ता संपादित करें'),
(101603, 1925, 27, 'उपयोगकर्ता सेटिंग्स संपादित करें'),
(101604, 1928, 27, 'शिक्षा'),
(101605, 1929, 27, 'शिक्षा तिथि'),
(101606, 1931, 27, 'अधिक जानकारी के लिए * जीएनयू जनरल पब्लिक लाइसेंस ee. ** आपको इस कार्यक्रम के साथ साथ जीएनयू जनरल पब्लिक लाइसेंस * की एक प्रतिलिपि प्राप्त हुई होगी, नहीं तो, नि: शुल्क के लिए लिख '),
(101607, 1932, 27, 'प्रभावी तिथि'),
(101608, 1934, 27, 'प्रभाव'),
(101609, 1935, 27, 'ईआईऍन'),
(101610, 1936, 27, 'ejaculations'),
(101611, 1937, 27, 'कोहनी'),
(101612, 1938, 27, 'कोहनी की समस्याएं'),
(101613, 1939, 27, 'इलेक्ट्रोनिक'),
(101614, 1942, 27, 'इलेक्ट्रॉनिक remits'),
(101615, 1943, 27, 'इलेक्ट्रॉनिक रिपोर्टें'),
(101616, 1944, 27, 'पात्रता'),
(101617, 1945, 27, 'पात्रता 270 बैच की जाँच'),
(101618, 1946, 27, 'पात्रता प्रतिक्रिया'),
(101619, 1947, 27, 'बच्चों के वैक्सीन की आपूर्ति के लिए पात्रता स्थिति'),
(101620, 1948, 27, 'पात्र'),
(101621, 1949, 27, 'ईमेल'),
(101622, 1951, 27, 'ईमेल का पता'),
(101623, 1953, 27, 'रोगी अनुस्मारक के लिए प्रेषक का ईमेल पता. रोगी अनुस्मारक के उत्तरों को इस पते पर भेज दिया जाएगा.अपने क्लिनिक के डोमेन से एक पते का उपयोग करना आवश्यक है. यह रोगी अनुस्मारक को जंक मेल फोल्डर में जाने से रोकने में मदद करता है!'),
(101624, 1954, 27, 'ईमेल पता, यदि कोई हो, प्रशासनिक सूचनाएं प्राप्त करने के लिए.'),
(101625, 1955, 27, 'ईमेल पता, यदि कोई हो, आपातकालीन लॉगिन उपयोगकर्ता सक्रियण संदेश प्राप्त करने के लिए.'),
(101626, 1956, 27, 'ईमेल प्रमाणीकरण'),
(101627, 1957, 27, 'Batchcom से ईमेल'),
(101628, 1958, 27, 'ईमेल सूचना'),
(101629, 1959, 27, 'ईमेल सूचना के घंटे'),
(101630, 1960, 27, 'ईमेल सूचना रिपोर्ट'),
(101631, 1961, 27, 'ईमेल पहले भेजा गया'),
(101632, 1962, 27, 'ईमेल प्रेषक'),
(101633, 1963, 27, 'ईमेल भेजा गया'),
(101634, 1964, 27, 'ईमेल भेजा'),
(101635, 1965, 27, 'ईमेल विषय'),
(101636, 1966, 27, 'ईमेल पाठ, उपयोगी टैग: *** नाम ***, यानी प्रिय *** नाम ***'),
(101637, 1967, 27, 'ईमेल पाठ, उपयोगी टैग: *** नाम ***, यानी प्रिय *** नाम *** {. {अनुवाद नहीं है *** नाम *** यह निरंतर के तत्वों}}'),
(101638, 1968, 27, 'ईमेल परिवहन विधि'),
(101639, 1969, 27, 'ईमेल निम्न पते पर भेजा गया था'),
(101640, 1971, 27, 'आपातकालीन संपर्क'),
(101641, 1972, 27, 'आपातकालीन संपर्क अधिकारी'),
(101642, 1973, 27, 'आपातकालीन संपर्क फोन नंबर'),
(101643, 1974, 27, 'आपातकालीन गर्भनिरोधक'),
(101644, 1975, 27, 'इमरजेंसी प्रवेश'),
(101645, 1976, 27, 'इमरजेंसी लॉग इन एसीएल चुना है.अब भी उपयोगकर्ता सक्रिय स्थिति में है, उपयोगकर्ता को निष्क्रिय करें और आपात स्थितियों के दौरान जरूरत पड़ने पर ही सक्रिय करें.सक्रिय या निष्क्रिय करने के लिए के लिए प्रशासन> उपयोगकर्ता मे जाएँ!'),
(101646, 1977, 27, 'इमरजेंसी लॉग इन सक्रियकरण ईमेल परिचालित किया जाएगा जब केवल इंटरफेस / globals.php फ़ाइल में निम्न सेटिंग्स कॉन्फ़िगर किया जाता है!'),
(101647, 1978, 27, 'इमरजेंसी लॉग इन ईमेल पता'),
(101648, 1979, 27, 'इमरजेंसी लॉग इन उपयोगकर्ता कुछ भी कर सकते हैं'),
(101649, 1980, 27, 'आपातकालीन फोन'),
(101650, 1981, 27, 'भावनात्मक / व्यवहार स्थितियां और जटिलताएं'),
(101651, 1982, 27, 'वातस्फीति'),
(101652, 1983, 27, 'कर्मचारी'),
(101653, 1984, 27, 'नियोक्ता'),
(101654, 1985, 27, 'नियोक्ता पता'),
(101655, 1986, 27, 'नियोक्ता डाटा'),
(101656, 1987, 27, 'नियोक्ता का नाम'),
(101657, 1988, 27, 'खाली'),
(101658, 1989, 27, 'खाली'),
(101659, 1990, 27, 'खाली पासवर्ड की अनुमति नहीं'),
(101660, 1991, 27, 'ईमेल घंटे में खाली मूल्य'),
(101661, 1992, 27, 'ईमेल प्रेषक में खाली मूल्य'),
(101662, 1993, 27, 'ईमेल विषय में खाली मूल्य'),
(101663, 1994, 27, 'ईमेल पाठ में खाली मूल्य'),
(101664, 1995, 27, 'प्रदाता का नाम में खाली मूल्य'),
(101665, 1996, 27, 'पासवर्ड में खाली मूल्य'),
(101666, 1997, 27, 'एसएमएस घंटे में खाली मूल्य'),
(101667, 1998, 27, 'एसएमएस पाठ में खाली मूल्य'),
(101668, 1999, 27, 'उपयोगकर्ता नाम में खाली मूल्य'),
(101669, 2006, 27, 'एएमसी उत्साह सक्रिय करें'),
(101670, 2008, 27, 'एएमसी रिपोर्टिंग सक्रिय करें'),
(101671, 2009, 27, 'एएमसी ट्रैकिंग सक्रिय करें'),
(101672, 2011, 27, 'ATNA अंकेक्षण सक्रिय करें'),
(101673, 2013, 27, 'ऑडिट लॉगिंग सक्रिय करें'),
(101674, 2014, 27, 'ऑडिट ट्रेल और नोड प्रमाणीकरण (ATNA)सक्रिय करें'),
(101675, 2015, 27, 'स्वचालित उपाय गणना सक्रिय करें(एएमसी) रिपोर्टिंग'),
(101676, 2016, 27, 'क्लाएंट एसएसएल सक्रिय करें'),
(101677, 2017, 27, 'ग्राहक एसएसएल प्रमाणपत्र प्रमाणन को सक्रिय करें'),
(101678, 2019, 27, 'नैदानिक ​​निर्णय नियम सक्रिय करें (सीडीआर)'),
(101679, 2022, 27, '(CQM) रिपोर्टिंग क्लीनिकल गुणवत्ता के उपाय सक्रिय करें'),
(101680, 2023, 27, 'क्लीनिकल अनुस्मारक पॉपअप सक्रिय करें'),
(101681, 2024, 27, 'क्लीनिकल अनुस्मारक विजेट सक्रिय करें'),
(101682, 2027, 27, 'CQM रिपोर्टिंग सक्रिय करें'),
(101683, 2028, 27, 'बाएँ मेनू में ईडीआई इतिहास सक्रिय करें'),
(101684, 2030, 27, 'बाएँ मेनू में फीस सक्रिय करें'),
(101685, 2031, 27, 'Hylafax समर्थन सक्रिय करें'),
(101686, 2033, 27, 'NewCrop ERX के लिए आयात स्थिति संदेश सक्रिय करें'),
(101687, 2037, 27, 'लैब विनिमय सक्रिय करें'),
(101688, 2039, 27, 'CouchDB में दस्तावेज़ अपलोड / डाउनलोड करने के लिए लॉग सक्रिय करें'),
(101689, 2040, 27, 'सभी SQL चयन प्रश्नों की लॉगिंग सक्रिय करें'),
(101690, 2041, 27, 'बैकअप से संबंधित गतिविधियों की लॉगिंग सक्रिय करें'),
(101691, 2042, 27, 'सीडीआर इंजन प्रश्नों की लॉगिंग सक्रिय करें'),
(101692, 2043, 27, 'विविध गतिविधियों की लॉगिंग सक्रिय करें'),
(101693, 2044, 27, 'गतिविधियों आदेश देने की लॉगिंग सक्रिय करें'),
(101694, 2045, 27, 'रोगी रिकॉर्ड संशोधनों की लॉगिंग सक्रिय करें'),
(101695, 2046, 27, 'समय निर्धारण गतिविधियों की लॉगिंग सक्रिय करें'),
(101696, 2047, 27, 'सुरक्षा और प्रशासन की गतिविधियों की लॉगिंग सक्रिय करें'),
(101697, 2049, 27, 'NewCrop ERX सेवा सक्रिय करें'),
(101698, 2051, 27, 'Offsite रोगी पोर्टल सक्रिय करें'),
(101699, 2052, 27, 'Offsite रोगी पोर्टल सक्रिय करें'),
(101700, 2053, 27, 'Onsite रोगी पोर्टल सक्रिय करें'),
(101701, 2055, 27, 'Onsite रोगी पोर्टल सक्रिय करें'),
(101702, 2056, 27, 'रोगी अनुस्मारक विजेट सक्षम करें'),
(101703, 2057, 27, 'PhiMail प्रत्यक्ष संदेश सेवा सक्रिय करें'),
(101704, 2058, 27, 'स्वचालित उपाय गणना (एएमसी) के लिए आवश्यक डेटा के लिए उत्साह सक्रिय करें'),
(101705, 2060, 27, 'स्वचालित उपाय गणना के लिए ट्रैकिंग तिथि (एएमसी) की रिपोर्टिंग सक्रिय करें'),
(101706, 2061, 27, 'स्कैनर समर्थन सक्रिय करें'),
(101707, 2064, 27, 'मैडिकल इन्फोर्मेशन इंटीग्रेशन, LLC लैब विनिमय सेवा को सक्रिय करें'),
(101708, 2065, 27, 'LibreEHR समर्थन LLC लैब विनिमय सेवा को सक्रिय करें'),
(101709, 2066, 27, 'उपयोगकर्ता प्रमाणपत्र प्रमाणीकरण सक्रिय करें'),
(101710, 2067, 27, 'ZMG, LLC ERX सेवा सक्रिय करें'),
(101711, 2068, 27, 'सक्रिय किया'),
(101712, 2070, 27, 'Enables the old Charges panel for entering billing codes and payments. Not recommended, use the Fee Sheet instead.'),
(101713, 2071, 27, 'मुठभेड़'),
(101714, 2072, 27, 'मुठभेड़'),
(101715, 2073, 27, 'मुठभेड़'),
(101716, 2074, 27, 'मुठभेड़'),
(101717, 2075, 27, 'मुठभेड़ '),
(101718, 2076, 27, 'मुठभेड़ एक्यूट inpatient या ED'),
(101719, 2081, 27, 'मुठभेड़ तिथि'),
(101720, 2084, 27, 'मुठभेड़ ईडीआई रिकॉर्ड'),
(101721, 2086, 27, 'मुठभेड़ फॉर्म्स'),
(101722, 2087, 27, 'मुठभेड़ स्वास्थ्य और व्यवहार मूल्यांकन'),
(101723, 2088, 27, 'मुठभेड़ इतिहास'),
(101724, 2089, 27, 'मुठभेड़ आईडी'),
(101725, 2090, 27, 'मुठभेड़ इन्फ्लूएंजा'),
(101726, 2091, 27, 'मुठभेड़ संख्या'),
(101727, 2093, 27, 'मुठभेड़ नर्सिंग छुट्टी के'),
(101728, 2094, 27, 'मुठभेड़ नर्सिंग सुविधा'),
(101729, 2095, 27, 'मुठभेड़ व्यावसायिक चिकित्सा'),
(101730, 2096, 27, 'मुठभेड़ कार्यालय का दौरा'),
(101731, 2097, 27, 'मुठभेड़ आउट पेशेंट'),
(101732, 2098, 27, 'मुठभेड़ आउट पेशेंट डब्ल्यू / पीसीपी और OBGYN'),
(101733, 2099, 27, 'मुठभेड़ पृष्ठ आकार'),
(101734, 2100, 27, 'मुठभेड़ भुगतान'),
(101735, 2101, 27, 'मुठभेड़ गर्भावस्था'),
(101736, 2102, 27, 'मुठभेड़ निवारक चिकित्सा - व्यक्तिगत परामर्श'),
(101737, 2103, 27, 'मुठभेड़ निवारक चिकित्सा 40 और पुराने'),
(101738, 2104, 27, 'मुठभेड़ निवारक चिकित्सा समूह के परामर्श'),
(101739, 2105, 27, 'मुठभेड़ निवारक चिकित्सा अन्य सेवाएं'),
(101740, 2106, 27, 'मुठभेड़ निवारक चिकित्सा सेवाओं 18 और पुराने'),
(101741, 2107, 27, 'मुठभेड़ मनोरोग और मनोवैज्ञानिक'),
(101742, 2108, 27, 'मुठभेड़ के आँकड़े'),
(101743, 2109, 27, 'मुठभेड़ सारांश'),
(101744, 2110, 27, 'मुठभेड़ कोडित था'),
(101745, 2111, 27, 'मुठभेड़:'),
(101746, 2112, 27, 'मुठभेड़: मुठभेड़ अतीव्र inpt, आउट पेशेंट, या नेत्र विज्ञान के'),
(101747, 2113, 27, 'मुठभेड़'),
(101748, 2114, 27, 'मुठभेड़ और प्रपत्र'),
(101749, 2115, 27, 'मुठभेड़ और प्रपत्र'),
(101750, 2116, 27, 'अधिकृत नहीं मुठभेड़'),
(101751, 2117, 27, 'मुठभेड़ की रिपोर्ट'),
(101752, 2118, 27, 'मुठभेड़ धारा'),
(101753, 2120, 27, 'एन्क्रिप्शन'),
(101754, 2121, 27, 'अंत'),
(101755, 2122, 27, 'अंत (YYYY-MM-DD): '),
(101756, 2123, 27, 'अंत तिथि'),
(101757, 2124, 27, 'अंतिम तिथि'),
(101758, 2126, 27, 'अंतिम तिथि प्रारम्भ तिथि से अधिक होनी चाहिए'),
(101759, 2127, 27, 'अंत तिथि:'),
(101760, 2131, 27, 'अंत समय'),
(101761, 2132, 27, 'कार्यदाता समूह योजना के साथ MCP में अंत मंच वृक्क रोग के लाभार्थी'),
(101762, 2133, 27, 'सेवा समाप्त होने की तिथि YYYY-MM-DD'),
(101763, 2134, 27, 'खत्म होने वाली DOS dd / mm / yyyy, एक सीमा में प्रवेश करने के लिए!'),
(101764, 2135, 27, 'कैलेंडर की घटनाओं के लिए दिन के समाप्त घंटे.'),
(101765, 2136, 27, 'Endo असामान्य रक्त'),
(101766, 2137, 27, 'अंत: स्त्रावी'),
(101767, 2138, 27, 'अंत: दर्शन'),
(101768, 2141, 27, 'अंग्रेज़ी'),
(101769, 2142, 27, 'अंग्रेज़ी '),
(101770, 2143, 27, 'अंग्रेजी (भारतीय)'),
(101771, 2144, 27, 'अंग्रेजी (मानक)'),
(101772, 2145, 27, 'Hylafax द्वारा इस्तेमाल किया Enscript आदेश.'),
(101773, 2146, 27, 'LibreEHR के लिए निर्देशिका में लिखने के विशेषाधिकार सुनिश्चित करें!'),
(101774, 2147, 27, 'इ एन टी निर्वहन'),
(101775, 2148, 27, 'इ एन टी दर्द'),
(101776, 2149, 27, 'इसको समाहित नहीं करने वाले सभी चालान बाहर करने के लिए एक निदान कोड दर्ज करें!'),
(101777, 2151, 27, 'यहाँ शरीर के अक्षर दर्ज करें'),
(101778, 2152, 27, 'डाटाबेस रूट पासवर्ड दर्ज करें'),
(101779, 2153, 27, 'डाटाबेस जड़ उपयोगकर्ता नाम दर्ज करें'),
(101780, 2154, 27, 'निदान दर्ज करें'),
(101781, 2155, 27, 'दवा दर्ज करें'),
(101782, 2156, 27, 'मुठभेड़ दर्ज करें'),
(101783, 2157, 27, 'मुठभेड़ संख्या दर्ज करें'),
(101784, 2158, 27, 'टीकाकरण दर्ज करें'),
(101785, 2159, 27, 'कुंजी दर्ज करें'),
(101786, 2161, 27, 'नए राज्य दर्ज करें'),
(101787, 2162, 27, 'प्राप्तकर्ता का  ''प्रत्यक्ष पता दर्ज करें'),
(101788, 2164, 27, 'पुनः पहचान कोड दर्ज करें'),
(101789, 2165, 27, 'ऊपर अपने खोज मापदंड दर्ज करें'),
(101790, 2166, 27, 'त्रुटि में दर्ज किया'),
(101791, 2167, 27, 'प्रविष्टियों'),
(101792, 2168, 27, 'पर्यावरण'),
(101793, 2169, 27, 'EOB डाटा एंट्री'),
(101794, 2170, 27, 'EOB पोस्टिंग - इलेक्ट्रॉनिक प्रेषण'),
(101795, 2171, 27, 'EOB पोस्टिंग - निर्देश'),
(101796, 2172, 27, 'EOB पोस्टिंग - चालान'),
(101797, 2173, 27, 'EOB पोस्टिंग - रोगी नोट'),
(101798, 2174, 27, 'EOB पोस्टिंग - खोज'),
(101799, 2176, 27, 'मिर्गी'),
(101800, 2178, 27, 'ERA'),
(101801, 2179, 27, 'ERA फ़ाइलें'),
(101802, 2180, 27, 'ERA पोस्टिंग'),
(101803, 2181, 27, 'मिटाना'),
(101804, 2182, 27, 'इरेक्शन'),
(101805, 2183, 27, 'त्रुटि'),
(101806, 2185, 27, 'प्रयोगशाला के परिणाम प्राप्त होने की त्रुटि की पुष्टि'),
(101807, 2187, 27, 'लैब एक्सचेंज नेटवर्क से प्रयोगशाला के परिणाम प्राप्त करने में त्रुटि'),
(101808, 2188, 27, 'लिंग चयन में त्रुटि'),
(101809, 2189, 27, 'HIPAA चयन में त्रुटि'),
(101810, 2190, 27, 'प्रक्रिया चयन में त्रुटि'),
(101811, 2191, 27, 'एसएमएस गेटवे चयन में त्रुटि'),
(101812, 2192, 27, 'छंटनी करें चयन में त्रुटि'),
(101813, 2193, 27, 'फ़ाइल का gzip संपीड़न में त्रुटि: '),
(101814, 2194, 27, 'हाँ या नहीं विकल्प में त्रुटि'),
(101815, 2195, 27, 'अपलोड की गई फ़ाइल पढ़ने के लिए खोलने में त्रुटि'),
(101816, 2196, 27, 'फ़ाइल प्रक्रिया में त्रुटि'),
(101817, 2197, 27, 'अपलोड प्रक्रिया में त्रुटि'),
(101818, 2198, 27, 'त्रुटि संदेश हटा रहा है'),
(101819, 2199, 27, 'लैब एक्सचेंज नेटवर्क से परिणाम पाने में त्रुटि'),
(101820, 2200, 27, 'मूल्यों को पुन: प्राप्त करने में त्रुटि.'),
(101821, 2202, 27, 'LibreEHR उपयोगकर्ता के लिए फ़ाइल विशेषाधिकार देने में त्रुटि.'),
(101822, 2205, 27, 'फॉर्म पंजीकरण करने के दौरान त्रुटि!'),
(101823, 2206, 27, 'फ़ाइल सहेजने के दौरान त्रुटि.'),
(101824, 2208, 27, 'फ़ाइल लिखने के दौरान त्रुटि'),
(101825, 2209, 27, 'त्रुटि (ओं) नए परिणामों का सामना करते समय.'),
(101826, 2210, 27, 'त्रुटि, फ़ाइल मौजूद नहीं है'),
(101827, 2211, 27, 'त्रुटि, सर्वर से डाटा एकत्र करने में असमर्थ'),
(101828, 2212, 27, 'त्रुटि, क्लाइंट प्रमाण पत्र नहीं बना सके.'),
(101829, 2213, 27, 'त्रुटि, admin.p12 प्रमाण पत्र नहीं बना सके.'),
(101830, 2214, 27, 'त्रुटि, प्रमाणपत्र प्राधिकार प्रमाण पत्र नहीं बना सके.'),
(101831, 2215, 27, 'त्रुटि, सर्वर प्रमाणपत्र बनाने में असमर्थ.'),
(101832, 2216, 27, 'त्रुटि, को खोलने में असमर्थ फ़ाइल'),
(101833, 2217, 27, 'त्रुटि, उपयोगकर्ता प्रमाणपत्र प्रमाणीकरण LibreEHR में सक्षम नहीं है'),
(101834, 2218, 27, 'त्रुटि. आप संग्रह / Tar.php PHP मॉड्यूल स्थापित करने की जरूरत है.'),
(101835, 2219, 27, 'त्रुटि: table.sql, टूटे फार्म को नहीं खोल सकता है?'),
(101836, 2220, 27, 'त्रुटि: लाइन पर आईडी दोहराया'),
(101837, 2221, 27, 'त्रुटि: लाइन पर नाम दोहराया'),
(101838, 2222, 27, 'त्रुटि: फील्ड'),
(101839, 2223, 27, 'त्रुटि: ZipArchive php मॉड्यूल लापता'),
(101840, 2224, 27, 'त्रुटि: आईसीडी आयात निर्देशिका नहीं.'),
(101841, 2225, 27, 'त्रुटि: पासवर्ड मेल नहीं खाते. अपनी टाइपिंग की जांच करें.'),
(101842, 2226, 27, 'त्रुटि: पासवर्ड मेल नहीं खाते. अपनी टाइपिंग की जांच करें.'),
(101843, 2227, 27, 'त्रुटि: फ़ाइल मौजूद नहीं है'),
(101844, 2228, 27, 'त्रुटि: निम्नलिखित चर का अमान्य वर्ण हैं'),
(101845, 2229, 27, 'त्रुटि: फाइल कॉपी करने में असमर्थ.'),
(101846, 2230, 27, 'त्रुटि: नया संग्रह बनाने में असमर्थ'),
(101847, 2231, 27, 'त्रुटि: ज़िप संग्रह बनाने में असमर्थ.'),
(101848, 2232, 27, 'त्रुटि: फ़ाइल निकालने में असमर्थ.'),
(101849, 2233, 27, 'त्रुटि: डेटाबेस में फ़ाइल लोड करने में असमर्थ.'),
(101850, 2234, 27, 'त्रुटि: संस्करण संख्या निर्धारित करने में असमर्थ.'),
(101851, 2235, 27, 'त्रुटियाँ'),
(101852, 2236, 27, 'ERX खाते की स्थिति'),
(101853, 2237, 27, 'ERX लॉग्स'),
(101854, 2238, 27, 'ERX नाम'),
(101855, 2239, 27, 'ERX पारण'),
(101856, 2240, 27, 'ERX भूमिका'),
(101857, 2241, 27, 'ERX उपयोगकर्ता'),
(101858, 2242, 27, 'पर्विल:'),
(101859, 2245, 27, 'एस्किमो'),
(101860, 2247, 27, 'स्थापित रोगी'),
(101861, 2248, 27, 'एस्तोनियावासी'),
(101862, 2249, 27, 'नस्ल'),
(101863, 2250, 27, 'नस्ल या जाति'),
(101864, 2251, 27, 'नस्ल रेस सूची (लिखना addonly, वैकल्पिक )'),
(101865, 2252, 27, 'ETIN'),
(101866, 2253, 27, 'घटना'),
(101867, 2254, 27, 'घटना शुरू होती है'),
(101868, 2255, 27, 'घटना श्रेणी'),
(101869, 2256, 27, 'घटना दिनांक'),
(101870, 2257, 27, 'घटना विवरण'),
(101871, 2258, 27, 'घटना विवरण'),
(101872, 2259, 27, 'घटना दोहराया नहीं करता'),
(101873, 2260, 27, 'घटना अवधि'),
(101874, 2261, 27, 'मिनटों में घटना की अवधि'),
(101875, 2262, 27, 'घटना का शुल्क'),
(101876, 2263, 27, 'घटना स्थान'),
(101877, 2264, 27, 'घटना दोहराता है हर'),
(101878, 2265, 27, 'घटना इस पर दोहराता है'),
(101879, 2266, 27, 'घटना का समय शुरू'),
(101880, 2267, 27, 'घटना शीर्षक'),
(101881, 2268, 27, 'घटना शीर्षक'),
(101882, 2269, 27, 'घटना वेबसाइट'),
(101883, 2270, 27, 'घटनाक्रम'),
(101884, 2271, 27, 'के लिए घटनाक्रम'),
(101885, 2272, 27, 'घटनाक्रम नए विंडो में खुलेगा'),
(101886, 2273, 27, 'हर'),
(101887, 2274, 27, 'हर'),
(101888, 2275, 27, 'हर 3 घंटे'),
(101889, 2276, 27, 'हर 4 घंटे'),
(101890, 2277, 27, 'हर 5 घंटे'),
(101891, 2278, 27, 'हर 6 घंटे'),
(101892, 2279, 27, 'हर 8 घंटे'),
(101893, 2280, 27, 'हर चौथे'),
(101894, 2281, 27, 'हर दूसरे'),
(101895, 2282, 27, 'हर तीसरे'),
(101896, 2283, 27, 'हर, हर दूसरे, हर 3, आदि'),
(101897, 2285, 27, 'परीक्षा और परीक्षा परिणाम'),
(101898, 2286, 27, 'परीक्षा परिणाम'),
(101899, 2289, 27, 'परीक्षा'),
(101900, 2290, 27, 'परीक्षा तिथि'),
(101901, 2291, 27, 'उदाहरण'),
(101902, 2292, 27, 'उदाहरण'),
(101903, 2293, 27, 'परीक्षा / टेस्ट'),
(101904, 2294, 27, 'को छोड़कर'),
(101905, 2295, 27, 'अत्यधिक फाड़'),
(101906, 2296, 27, 'निकाले गए मरीजों को'),
(101907, 2297, 27, 'अपवर्जन'),
(101908, 2298, 27, 'विशेष प्रदाता संगठन (ईपीओ)'),
(101909, 2299, 27, 'कार्यकारी पेपर आकार'),
(101910, 2300, 27, 'व्यायाम'),
(101911, 2301, 27, 'व्यायाम पैटर्न्स'),
(101912, 2302, 27, 'व्यायाम पैटर्न'),
(101913, 2303, 27, 'मौजूद'),
(101914, 2304, 27, 'प्रशासन की ओर से बाहर निकलें'),
(101915, 2305, 27, 'विस्तृत करें'),
(101916, 2306, 27, 'विस्तृत करें'),
(101917, 2307, 27, 'विस्तृत करें'),
(101918, 2308, 27, 'सभी का विस्तार'),
(101919, 2311, 27, 'विस्तारित देखें'),
(101920, 2312, 27, 'form_encounter.pid होने की उम्मीद '),
(101921, 2313, 27, 'समाप्ति'),
(101922, 2314, 27, 'समय समाप्ति तिथि'),
(101923, 2315, 27, 'समाप्त हो रहा'),
(101924, 2316, 27, 'में समाप्त हो रहा है'),
(101925, 2317, 27, 'निर्यात'),
(101926, 2318, 27, 'सीएसवी के रूप में निर्यात'),
(101927, 2319, 27, 'निर्यात विन्यास'),
(101928, 2322, 27, 'निर्यात रोगी जनसांख्यिकी'),
(101929, 2323, 27, 'निर्यात PQRI रिपोर्ट'),
(101930, 2325, 27, 'सीएसवी के रूप में चयनित निर्यात'),
(101931, 2326, 27, 'संग्रह के लिए चयनित निर्यात'),
(101932, 2327, 27, 'सीएसवी निर्यात'),
(101933, 2328, 27, 'बाहरी बिलिंग प्रणाली के लिए निर्यात'),
(101934, 2329, 27, 'विदेशी देशों के लिए एक्सपोजर'),
(101935, 2330, 27, 'विदेशी देशों के लिए एक्सपोजर'),
(101936, 2331, 27, 'एक्सटेंशन समय एकत्रित'),
(101937, 2332, 27, 'बाहरी'),
(101938, 2334, 27, 'बाहरी डेटा लोड'),
(101939, 2335, 27, 'बाहरी डेटाबेस आयात उपयोगिता'),
(101940, 2336, 27, 'बाहरी आईडी'),
(101941, 2337, 27, 'बाहरी आईडी'),
(101942, 2338, 27, 'बाहरी पहचानकर्ता'),
(101943, 2339, 27, 'विदेश केवल'),
(101944, 2342, 27, 'बाहरी सिफ़ारिश'),
(101945, 2343, 27, 'बाहरी सिफ़ारिश followups'),
(101946, 2344, 27, 'बाहरी सिफ़ारिश?'),
(101947, 2345, 27, 'बाहरी सिफ़ारिशों के'),
(101948, 2346, 27, 'Zip फ़ाइल निकालें'),
(101949, 2347, 27, 'फ़ाइल निकाल रहा है. यह कुछ समय लगेगा ...'),
(101950, 2348, 27, 'पीब:'),
(101951, 2349, 27, 'आंख में जलन'),
(101952, 2350, 27, 'आंख में दर्द'),
(101953, 2351, 27, 'आँख लालिमा'),
(101954, 2352, 27, 'आंखें'),
(101955, 2353, 27, 'एफ'),
(101956, 2354, 27, 'एफ / एच रक्त की समस्याएं'),
(101957, 2355, 27, 'एफ / एच महिला Hirsutism / striae'),
(101958, 2356, 27, 'सुविधाएं'),
(101959, 2357, 27, 'सुविधा'),
(101960, 2358, 27, 'सुविधा'),
(101961, 2359, 27, 'सुविधा प्रशासन'),
(101962, 2360, 27, 'सुविधा शहर'),
(101963, 2361, 27, 'सुविधा कोड'),
(101964, 2362, 27, 'सुविधा देश कोड'),
(101965, 2363, 27, 'सुविधा फैक्स'),
(101966, 2364, 27, 'सुविधा नाम'),
(101967, 2365, 27, 'सुविधा NPI'),
(101968, 2366, 27, 'सुविधा फोन'),
(101969, 2367, 27, 'सुविधा उपयोगकर्ता विशिष्ट जानकारी'),
(101970, 2368, 27, 'सुविधा राज्य'),
(101971, 2369, 27, 'सुविधा स्ट्रीट'),
(101972, 2370, 27, 'सुविधा पिन'),
(101973, 2372, 27, 'सुविधा:'),
(101974, 2373, 27, 'विफल'),
(101975, 2374, 27, 'विफल'),
(101976, 2375, 27, 'विफल'),
(101977, 2380, 27, 'अस्थायी फ़ोल्डर बनाने में विफल. CouchDB काम नहीं करेगा.'),
(101978, 2382, 27, 'विफल.'),
(101979, 2383, 27, 'विफलता'),
(101980, 2390, 27, 'पारिवारिक इतिहास'),
(101981, 2391, 27, 'ग्लूकोमा का पारिवारिक इतिहास'),
(101982, 2392, 27, 'पारिवारिक इतिहास:'),
(101983, 2394, 27, 'पारिवारिक भुगतान'),
(101984, 2395, 27, 'परिवार का आकार'),
(101985, 2396, 27, 'पसंद'),
(101986, 2398, 27, 'फारसी'),
(101987, 2400, 27, 'पिता'),
(101988, 2402, 27, 'थकान'),
(101989, 2403, 27, 'थका हुआ'),
(101990, 2404, 27, 'फैक्स'),
(101991, 2405, 27, 'फैक्स गणना'),
(101992, 2406, 27, 'फैक्स नंबर'),
(101993, 2408, 27, 'फैक्स / स्कैन'),
(101994, 2409, 27, 'फ़ैक्स अंदर'),
(101995, 2410, 27, 'फ़ैक्स बाहर'),
(101996, 2411, 27, 'विशेषताएँ'),
(101997, 2412, 27, 'फरवरी'),
(101998, 2413, 27, 'फरवरी'),
(101999, 2414, 27, 'FECA'),
(102000, 2415, 27, 'फेडरल ड्रग आईडी'),
(102001, 2416, 27, 'फेडरल ईआईऍन'),
(102002, 2417, 27, 'फेडरल कर आईडी'),
(102003, 2418, 27, 'शुल्क'),
(102004, 2419, 27, 'शुल्क'),
(102005, 2420, 27, 'शुल्क की अनुमति नहीं है'),
(102006, 2421, 27, 'शुल्क पत्रक'),
(102007, 2422, 27, 'शुल्क पत्रक विकल्प'),
(102008, 2423, 27, 'शुल्क'),
(102009, 2424, 27, 'महिला'),
(102010, 2425, 27, 'महिला एपी'),
(102011, 2426, 27, 'महिला कंडोम'),
(102012, 2427, 27, 'महिला जी'),
(102013, 2428, 27, 'महिला LC'),
(102014, 2429, 27, 'महिला P'),
(102015, 2430, 27, 'महिला लक्षण'),
(102016, 2431, 27, 'महिला VSC'),
(102017, 2434, 27, 'बुखार'),
(102018, 2435, 27, 'बुखार:'),
(102019, 2436, 27, 'एफ एच रक्त की समस्याएं'),
(102020, 2437, 27, 'फाइब्रॉएड'),
(102021, 2441, 27, 'जनसांख्यिकी में नियोक्ता या ग्राहक के देश के लिए उपयोग करने के लिए फ़ील्ड प्रकार.'),
(102022, 2442, 27, 'जनसांख्यिकी में नियोक्ता या ग्राहक के राज्य के लिए उपयोग करने के लिए फ़ील्ड प्रकार.'),
(102023, 2443, 27, 'फील्ड (ओं) लापता हैं!'),
(102024, 2447, 27, 'फ़ाइल'),
(102025, 2448, 27, 'लॉग बैकअप बनाने की प्रक्रिया को स्वचालित कैसे करें यह जानने के लिए प्रलेखन निर्देशिका में फाइल!'),
(102026, 2449, 27, 'फ़ाइल स्थान'),
(102027, 2450, 27, 'फ़ाइल प्रबंधन'),
(102028, 2453, 27, 'फ़ाइल का विशेषाधिकार LibreEHR उपयोगकर्ता के लिए दीया गया.'),
(102029, 2454, 27, 'CouchDB से फ़ाइल पुनर्प्राप्ति विफल रहा'),
(102030, 2455, 27, 'फ़ाइल कक्ष'),
(102031, 2456, 27, 'अपलोड करने के लिए फ़ाइल'),
(102032, 2457, 27, 'अपलोड करने के लिए फ़ाइल'),
(102033, 2458, 27, 'उसी नाम के साथ फ़ाइल पहले से ही स्थान पर मौजूद है:'),
(102034, 2459, 27, 'फाईल का नाम'),
(102035, 2461, 27, 'फ़ाइलें'),
(102036, 2462, 27, 'फिलिपिनो देश'),
(102037, 2463, 27, 'नीचे की पंक्ति में से कोई भी भरें.'),
(102038, 2464, 27, 'यहां भरें अगर आप रोगियों को ईमेल सूचना भेज रहे हैं!'),
(102039, 2465, 27, 'नीचे दिए गए मूल्यों में भरें'),
(102040, 2467, 27, 'पंक्ति भरें.'),
(102041, 2468, 27, 'फिल्टर'),
(102042, 2469, 27, 'स्थिरांक के लिए फ़िल्टर'),
(102043, 2470, 27, 'परिभाषा के लिए फ़िल्टर'),
(102044, 2471, 27, 'से फ़िल्टर किया'),
(102045, 2472, 27, 'फिल्टर'),
(102046, 2473, 27, 'फ़िल्टर'),
(102047, 2474, 27, 'अंतिम'),
(102048, 2475, 27, 'अंतिम निदान'),
(102049, 2476, 27, 'विशेषज्ञ द्वारा अंतिम निदान'),
(102050, 2478, 27, 'वित्तीय'),
(102051, 2479, 27, 'वित्तीय बंद तिथि (YYYY-MM-DD)'),
(102052, 2480, 27, 'वित्तीय रिपोर्टिंग - कुछ भी'),
(102053, 2481, 27, 'वित्तीय रिपोर्टिंग - मेरे मुठभेड़ों के'),
(102054, 2482, 27, 'वित्तीय समीक्षा दिनांक'),
(102055, 2483, 27, 'सेवा संहिता द्वारा वित्तीय सारांश'),
(102056, 2484, 27, 'खोजें'),
(102057, 2485, 27, 'उपलब्ध खोजें'),
(102058, 2486, 27, 'उपलब्ध नियुक्तियों खोजें'),
(102059, 2487, 27, 'रोगी खोजें'),
(102060, 2488, 27, 'रोगी शिक्षा सामग्री खोजें'),
(102061, 2489, 27, 'निष्कर्ष'),
(102062, 2490, 27, 'विशेषज्ञ द्वारा निष्कर्ष'),
(102063, 2491, 27, 'जुर्माना'),
(102064, 2492, 27, 'भुगतान समाप्त'),
(102065, 2493, 27, 'समाप्त'),
(102066, 2495, 27, 'पहला'),
(102067, 2497, 27, 'सप्ताह का पहला दिन'),
(102068, 2498, 27, 'पहला नाम'),
(102069, 2499, 27, 'पहला नाम'),
(102070, 2500, 27, 'पहला नाम:'),
(102071, 2503, 27, 'स्वास्थ्य'),
(102072, 2504, 27, 'स्वास्थ्य स्तर'),
(102073, 2505, 27, 'इस दिन पर इस खिलाड़ी के लिए फिटनेस स्तर'),
(102074, 2507, 27, 'खेलने के लिए फिटनेस'),
(102075, 2508, 27, 'मुठभेड़ तिथियाँ तय करें - किसी भी मुठभेड़ों के'),
(102076, 2509, 27, 'इसे ठीक करें'),
(102077, 2510, 27, 'FL'),
(102078, 2511, 27, 'पेट फूलना'),
(102079, 2512, 27, 'प्रवाह'),
(102080, 2514, 27, 'फ्लू के मौसम'),
(102081, 2515, 27, 'फ्लू के मौसम'),
(102082, 2516, 27, 'फ्लू टीकाकरण'),
(102083, 2517, 27, 'तरल और इलेक्ट्रोलाइट समस्या'),
(102084, 2518, 27, 'FMS'),
(102085, 2519, 27, 'फोलियो पेपर आकार'),
(102086, 2520, 27, 'मैन्युअल रूप से पालन करें'),
(102087, 2521, 27, 'निम्नलिखित डेटाबेस को स्थापित करने या उन्नयन करने के लिए इन निर्देशों का पालन करें'),
(102088, 2522, 27, 'फ़ॉलोअप'),
(102089, 2524, 27, 'फ़ॉलोअप कारण'),
(102090, 2525, 27, 'के बाद एक नए कस्टम स्थिर है:'),
(102091, 2526, 27, 'के बाद एक नए कस्टम भाषा है:'),
(102092, 2527, 27, 'के बाद एक नई परिभाषा (भाषा, लगातार, परिभाषा) है:'),
(102093, 2529, 27, 'फॉलोअप सेवाएँ'),
(102094, 2530, 27, 'फ़ॉलोअप के संकेत'),
(102095, 2531, 27, 'खाद्य असहिष्णुता'),
(102096, 2532, 27, 'पैर'),
(102097, 2533, 27, 'पैर की समस्याओं के'),
(102098, 2534, 27, 'पैर:'),
(102099, 2535, 27, 'फुटबॉल चोट लगने की घटनाएं'),
(102100, 2536, 27, 'फुटबॉल चोट'),
(102101, 2537, 27, 'फुटबॉल चोट रिपोर्ट'),
(102102, 2538, 27, 'जूते के प्रकार'),
(102103, 2539, 27, 'के लिए'),
(102104, 2540, 27, 'के लिए'),
(102105, 2541, 27, 'कोड के लिए'),
(102106, 2543, 27, 'मुठभेड़ दावों के लिए'),
(102107, 2544, 27, 'उदाहरण के लिए:'),
(102108, 2547, 27, 'चालान के लिए'),
(102109, 2548, 27, 'Medicare के लिए केवल, जिक्र प्रदाता और प्रतिपादन प्रदाता के रूप एक ही होने पर मजबूर करता है.'),
(102110, 2549, 27, 'OBR placer क्रम संख्या के लिए'),
(102111, 2552, 27, 'Referred संगठन / चिकित्सक के लिए'),
(102112, 2553, 27, 'अतीत के लिए'),
(102113, 2554, 27, 'चर के लिए'),
(102114, 2555, 27, 'के लिए:'),
(102115, 2556, 27, 'जबरदस्ती बिलिंग विजेट ओपन करो'),
(102116, 2557, 27, 'जबरदस्ती नए रोगी बनाएँ'),
(102117, 2558, 27, 'जबरदस्ती दिखाएँ'),
(102118, 2559, 27, 'प्रकोष्ठ'),
(102119, 2560, 27, 'प्रपत्र'),
(102120, 2561, 27, 'प्रपत्र'),
(102121, 2564, 27, 'प्रारूप'),
(102122, 2565, 27, 'प्रारूप'),
(102123, 2566, 27, 'उम्र प्रदर्शन के लिए प्रारूप'),
(102124, 2567, 27, 'एनडीसी के लिए गलत प्रारूप'),
(102125, 2568, 27, 'प्रारूप ज्यादातर तिथियाँ प्रदर्शित करने के लिए इस्तेमाल किया.'),
(102126, 2569, 27, 'प्रारूप ज्यादातर समय प्रदर्शित करने के लिए इस्तेमाल किया.'),
(102127, 2570, 27, 'प्रारूपित रिपोर्ट'),
(102128, 2571, 27, 'पुराना धूम्रपान करनेवाला'),
(102129, 2572, 27, 'फार्म'),
(102130, 2573, 27, 'फार्म प्रशासन'),
(102131, 2575, 27, 'आगे'),
(102132, 2576, 27, 'फैक्स के जरिए फॉरवर्ड पन्ने'),
(102133, 2577, 27, 'अग्रेषित किया'),
(102134, 2579, 27, 'चौथा'),
(102135, 2581, 27, 'अस्थिभंग'),
(102136, 2582, 27, 'Navicula में अस्थिभंग'),
(102137, 2583, 27, 'अस्थिभंग पार्श्व malleolus'),
(102138, 2584, 27, 'अस्थिभंग औसत दर्जे malleolus'),
(102139, 2585, 27, 'फ्रैक्चर, पांचवें आधार (5) metatarsal'),
(102140, 2586, 27, 'आवश्यक फ्रेम समर्थन'),
(102141, 2587, 27, 'फ्रेंच'),
(102142, 2588, 27, 'फ्रेंच (कनाडा)'),
(102143, 2589, 27, 'फ्रेंच (मानक)'),
(102144, 2590, 27, 'आवृत्ति'),
(102145, 2591, 27, 'लगातार जुकाम'),
(102146, 2592, 27, 'लगातार बीमारी'),
(102147, 2593, 27, 'शुक्र'),
(102148, 2594, 27, 'शुक्रवार'),
(102149, 2595, 27, 'से'),
(102150, 2596, 27, 'से'),
(102151, 2597, 27, 'से'),
(102152, 2598, 27, 'से तिथि आज तिथि से बड़ी नहीं हो सकती.'),
(102153, 2599, 27, 'से:'),
(102154, 2600, 27, 'से: '),
(102155, 2601, 27, 'FROM_CITY'),
(102156, 2603, 27, 'FROM_FNAME'),
(102157, 2604, 27, 'FROM_LNAME'),
(102158, 2605, 27, 'FROM_MNAME'),
(102159, 2607, 27, 'FROM_PHONECELL'),
(102160, 2608, 27, 'FROM_POSTAL'),
(102161, 2609, 27, 'FROM_STATE'),
(102162, 2610, 27, 'FROM_STREET'),
(102163, 2611, 27, 'FROM_TITLE'),
(102164, 2612, 27, 'FROM_VALEDICTORY');
INSERT INTO `lang_definitions` VALUES
(102165, 2613, 27, 'फ्रंट ऑफिस'),
(102166, 2614, 27, 'फ्रंट ऑफिस प्राप्ति'),
(102167, 2615, 27, 'फ्रंट ऑफिस प्राप्ति की रिपोर्ट'),
(102168, 2616, 27, 'फ्रंट आरईसी'),
(102169, 2617, 27, 'ललाट दाएँ:'),
(102170, 2619, 27, 'पूरा नाम'),
(102171, 2620, 27, 'MySQL निष्पादनयोग्य वाली निर्देशिका के लिए पूर्ण पथ.'),
(102172, 2621, 27, 'पर्ल निष्पादनयोग्य वाली निर्देशिका के लिए पूर्ण पथ.'),
(102173, 2622, 27, 'घटना लॉग बैकअप के लिए निर्देशिका के लिए पूर्ण पथ.'),
(102174, 2623, 27, 'अस्थायी फ़ाइलों में उपयोग करने के लिए निर्देशिका पूर्ण पथ.'),
(102175, 2624, 27, 'पूरा खेल'),
(102176, 2625, 27, 'पूर्ण प्रशिक्षण'),
(102177, 2626, 27, 'पूर्णत: चुकता'),
(102178, 2633, 27, 'जी'),
(102179, 2634, 27, 'जी / डीएल'),
(102180, 2636, 27, 'पित्ताशय की स्थिति'),
(102181, 2637, 27, 'पित्त की पथरी'),
(102182, 2638, 27, 'खेल अवधि'),
(102183, 2639, 27, 'खेल'),
(102184, 2640, 27, 'छूटे खेल'),
(102185, 2641, 27, 'खेल / घटनाओं'),
(102186, 2642, 27, 'खेल / घटनाओं के लिए याद'),
(102187, 2644, 27, 'जठरशोथ'),
(102188, 2645, 27, 'जठरांत्र दर्द'),
(102189, 2646, 27, 'जठरांत्र'),
(102190, 2647, 27, 'GCAC सांख्यिकी रिपोर्ट'),
(102191, 2648, 27, 'GCAC आँकड़े'),
(102192, 2649, 27, 'GCAC यात्रा फार्म लापता है'),
(102193, 2650, 27, 'लिंग'),
(102194, 2651, 27, 'लिंग '),
(102195, 2652, 27, 'सामान्य'),
(102196, 2653, 27, 'सामान्य मुद्दा सूची'),
(102197, 2655, 27, 'सामान्य सेवा श्रेणी'),
(102198, 2657, 27, 'उत्पन्न और डाउनलोड करें सीएमएस 1500 काग़ज़ का दावा'),
(102199, 2658, 27, 'उत्पन्न और डाउनलोड करें HCFA 1500 काग़ज़ का दावा'),
(102200, 2659, 27, 'X 12 बैच पैदा और डाउनलोड करें'),
(102201, 2660, 27, 'X12 मुठभेड़ दावा बैच पैदा और डाउनलोड करें'),
(102202, 2663, 27, 'इलेक्ट्रॉनिक अनुमत नुस्खे उत्पन्न और संचारित करें.'),
(102203, 2664, 27, 'सीएमएस 1500 उत्पन्न करें'),
(102204, 2665, 27, 'सीएमएस 1500 पीडीएफ उत्पन्न करें'),
(102205, 2666, 27, 'सीएमएस 1500 पाठ उत्पन्न करें'),
(102206, 2667, 27, 'HCFA उत्पन्न करें'),
(102207, 2668, 27, 'चालान उत्पन्न करें'),
(102208, 2669, 27, 'पत्र उत्पन्न करें'),
(102209, 2670, 27, 'के बारे में पत्र उत्पन्न करें '),
(102210, 2671, 27, 'PQRI रिपोर्ट उत्पन्न करें (पद्धति A)'),
(102211, 2673, 27, 'PQRI रिपोर्ट उत्पन्न करें (पद्धति E)'),
(102212, 2677, 27, 'रिपोर्ट उत्पन्न करें'),
(102213, 2678, 27, 'उपयोगकर्ता नाम और पासवर्ड उत्पन्न करें'),
(102214, 2679, 27, 'X12 उत्पन्न करें'),
(102215, 2680, 27, 'X12 मुठभेड़ उत्पन्न करें'),
(102216, 2682, 27, 'पर उत्पन्न किया'),
(102217, 2683, 27, 'उत्पन्न करता है'),
(102218, 2684, 27, 'genitourinary'),
(102219, 2687, 27, 'जर्मन'),
(102220, 2691, 27, 'HL7 प्राप्त करें'),
(102221, 2692, 27, 'मोतियाबिंद'),
(102222, 2693, 27, 'ग्लूकोमा परिवार इतिहास'),
(102223, 2694, 27, 'वैश्विक'),
(102224, 2696, 27, 'वैश्विक आईडी'),
(102225, 2697, 27, 'वैश्विक सेटिंग्स'),
(102226, 2698, 27, 'वैश्विक'),
(102227, 2699, 27, 'जीएम / डीएल'),
(102228, 2700, 27, 'जाएँ'),
(102229, 2701, 27, 'जाएँ'),
(102230, 2704, 27, 'पर जाएँ'),
(102231, 2705, 27, 'सप्ताह के पर जाएँ'),
(102232, 2706, 27, 'आज जाएँ'),
(102233, 2707, 27, 'लक्ष्य A'),
(102234, 2708, 27, 'लक्ष्य और तरीके'),
(102235, 2709, 27, 'लक्ष्य B'),
(102236, 2710, 27, 'लक्ष्य C'),
(102237, 2711, 27, 'चोट के ग्रेड'),
(102238, 2712, 27, 'ग्रेड:'),
(102239, 2713, 27, 'ग्राम'),
(102240, 2714, 27, 'महायोग'),
(102241, 2715, 27, 'महायोग'),
(102242, 2718, 27, 'Graphable'),
(102243, 2720, 27, 'से अधिक'),
(102244, 2721, 27, 'इससे बड़ा या इसके बराबर'),
(102245, 2722, 27, 'ग्रीक'),
(102246, 2724, 27, 'समूह'),
(102247, 2725, 27, 'समूह नाम'),
(102248, 2726, 27, 'समूह नाम खाली नहीं हो सकता'),
(102249, 2727, 27, 'समूह नाम, संख्या या रिक्त स्थान के साथ शुरू नहीं कर सकते.'),
(102250, 2728, 27, 'समूह नाम, संख्या के साथ शुरू नहीं कर सकते.'),
(102251, 2729, 27, 'समूह संख्या'),
(102252, 2730, 27, 'समूह भुगतान'),
(102253, 2731, 27, 'समूह:'),
(102254, 2732, 27, 'GROUPNAME'),
(102255, 2733, 27, 'समूह और प्रवेश नियंत्रण'),
(102256, 2734, 27, 'विकास तालिका'),
(102257, 2735, 27, 'विकास तालिका'),
(102258, 2736, 27, 'gtts (बूँदें)'),
(102259, 2737, 27, 'Guamanian'),
(102260, 2739, 27, 'अभिभावक नाम'),
(102261, 2741, 27, 'स्त्री रोग परीक्षा'),
(102262, 2742, 27, 'h'),
(102263, 2743, 27, 'H.S.'),
(102264, 2744, 27, 'H / O हेपेटाइटिस'),
(102265, 2745, 27, 'सफलतापूर्वक हटा दिया गया था. वर्तमान में किसी भी उप श्रेणियों को नीचे स्थानांतरित किया है!'),
(102266, 2746, 27, 'Haematoma / चोट'),
(102267, 2747, 27, 'HAI स्थिति'),
(102268, 2750, 27, 'हाथ + उंगलियों'),
(102269, 2751, 27, 'हाथ की समस्याएं'),
(102270, 2752, 27, 'हार्ड डिस्क'),
(102271, 2753, 27, 'कठिनाई w / o'),
(102272, 2754, 27, 'दौरा करने के लिए जोड़ा गया है'),
(102273, 2755, 27, 'समाप्त हो गया है'),
(102274, 2756, 27, 'हैश'),
(102275, 2757, 27, 'हैश इस फ़ाइल के लिए मौजूद नहीं था. एक नया हैश उत्पन्न किया गया था.'),
(102276, 2758, 27, 'हैश से मेल नहीं खाता. डेटा अखंडता समझौता किया गया है.'),
(102277, 2760, 27, 'Hawaiian'),
(102278, 2761, 27, 'खतरनाक गतिविधियों'),
(102279, 2762, 27, 'खतरनाक गतिविधियों'),
(102280, 2763, 27, 'HCFA अंक में मार्जिन छोड़ा'),
(102281, 2764, 27, 'HCFA मार्जिन्स'),
(102282, 2765, 27, 'अंक में HCFA शीर्ष मार्जिन'),
(102283, 2766, 27, 'HCPCS प्रक्रिया / सेवा'),
(102284, 2767, 27, 'वह PostCalendar '),
(102285, 2768, 27, 'सिर'),
(102286, 2769, 27, 'सिर परिधि'),
(102287, 2770, 27, 'सिर परिधि'),
(102288, 2771, 27, 'सिरदर्द'),
(102289, 2772, 27, 'सिरदर्द'),
(102290, 2773, 27, 'स्वास्थ्य देखभाल संचालन'),
(102291, 2774, 27, 'स्वास्थ संबंधी संचालन'),
(102292, 2775, 27, 'स्वास्थ्य केन्द्र / क्लिनिक'),
(102293, 2776, 27, 'स्वास्थ्य रखरखाव संगठन'),
(102294, 2777, 27, 'स्वास्थ्य रखरखाव संगठन (HMO) Medicare जोखिम'),
(102295, 2778, 27, 'सुनवाई हानि'),
(102296, 2779, 27, 'दिल का दौरा'),
(102297, 2780, 27, 'दिल की बीमारी'),
(102298, 2781, 27, 'दिल की विफलता'),
(102299, 2782, 27, 'दिल की समस्या'),
(102300, 2783, 27, 'दिल की समस्याओं'),
(102301, 2784, 27, 'दिल की सर्जरी'),
(102302, 2785, 27, 'दिल का प्रत्यारोपण'),
(102303, 2786, 27, 'दिल:'),
(102304, 2787, 27, 'असंतोष'),
(102305, 2788, 27, 'गर्मी या सर्दी'),
(102306, 2789, 27, 'गर्मी या सर्दी'),
(102307, 2790, 27, 'भारी तम्बाकू धूम्रपान'),
(102308, 2791, 27, 'Hebrew'),
(102309, 2793, 27, 'HEENT'),
(102310, 2794, 27, 'ऊंचाई'),
(102311, 2796, 27, 'मदद'),
(102312, 2797, 27, 'मदद'),
(102313, 2798, 27, 'खून की उल्टी'),
(102314, 2799, 27, 'Hematochezia'),
(102315, 2800, 27, 'hematologic'),
(102316, 2801, 27, 'रक्तमेह'),
(102317, 2802, 27, 'हीमोग्लोबिन'),
(102318, 2803, 27, 'हीमोग्लोबिन A1C'),
(102319, 2804, 27, 'बलगम में खून आना'),
(102320, 2805, 27, 'हेपेटाइटिस'),
(102321, 2806, 27, 'हेपेटाइटिस A1'),
(102322, 2807, 27, 'हेपेटाइटिस A2'),
(102323, 2808, 27, 'हेपेटाइटिस B1'),
(102324, 2809, 27, 'हेपेटाइटिस B2'),
(102325, 2810, 27, 'हेपेटाइटिस B3'),
(102326, 2811, 27, 'यहां'),
(102327, 2813, 27, 'हर्निया की मरम्मत'),
(102328, 2814, 27, 'हर्नियेटेड डिस्क'),
(102329, 2815, 27, 'परिसर्प'),
(102330, 2816, 27, 'संदेह'),
(102331, 2817, 27, 'heyyo. तुम क्या करने के लिए यहां आया '),
(102332, 2818, 27, 'हिब 1'),
(102333, 2819, 27, 'हिब 2'),
(102334, 2820, 27, 'हिब 3'),
(102335, 2821, 27, 'हिब 4'),
(102336, 2822, 27, 'छिपा हुआ'),
(102337, 2823, 27, 'छिपे हुए घटनाक्रम प्रशासन'),
(102338, 2824, 27, 'छिपाएँ'),
(102339, 2825, 27, 'विवरण छिपाएँ'),
(102340, 2827, 27, 'दस्तावेज़ प्रबंधन में एन्क्रिप्शन / डिक्रिप्शन विकल्प छिपाएँ'),
(102341, 2828, 27, 'मेनू छिपाएँ'),
(102342, 2830, 27, 'अनुस्मारक छुपाएं'),
(102343, 2831, 27, 'स्तंभ छिपाएँ / दिखाएँ'),
(102344, 2833, 27, 'उच्च'),
(102345, 2834, 27, 'उच्च रक्तचाप'),
(102346, 2835, 27, 'हिंदी'),
(102347, 2836, 27, 'कूल्हे + ऊसन्धि'),
(102348, 2837, 27, 'कूल्हे और कमर'),
(102349, 2838, 27, 'कूल्हे की समस्याओं'),
(102350, 2839, 27, 'कूल्हे बदलने'),
(102351, 2840, 27, 'HIPAA नोटिस मिला'),
(102352, 2842, 27, 'अतिरोमता / striae'),
(102353, 2843, 27, 'हिस्पैनिक'),
(102354, 2844, 27, 'हिस्पैनिक - अन्य (अमेरिका में) का जन्म'),
(102355, 2845, 27, 'हिस्पैनिक - अन्य (अमेरिका के बाहर जन्मे)'),
(102356, 2846, 27, 'हिस्पैनिक या लैटिनो'),
(102357, 2847, 27, 'इतिहास'),
(102358, 2848, 27, 'इतिहास डाटा'),
(102359, 2849, 27, 'इतिहास तिथि'),
(102360, 2851, 27, 'बड़बड़ाहट इतिहास'),
(102361, 2852, 27, 'इतिहास अधिकृत नहीं'),
(102362, 2853, 27, 'दिल बड़बड़ाहट का इतिहास'),
(102363, 2854, 27, 'हिट्स'),
(102364, 2855, 27, 'एचआईवी'),
(102365, 2858, 27, 'HL7 दर्शक'),
(102366, 2860, 27, 'HMOL / L'),
(102367, 2861, 27, 'Hmong'),
(102368, 2862, 27, 'एकाधिक चयन या हटाने के लिए [Ctrl] दबाए रखें'),
(102369, 2863, 27, 'एकाधिक आइटम्स का चयन करने के लिए CTRL दबाए रखें'),
(102370, 2864, 27, 'कई दस्तों का चयन करने के लिए CTRL दबाए रखें'),
(102371, 2865, 27, 'घर'),
(102372, 2866, 27, 'घर का फोन'),
(102373, 2867, 27, 'घर का फोन नंबर'),
(102374, 2868, 27, 'बेघर या समान?'),
(102375, 2869, 27, 'बेघर, आदि'),
(102376, 2870, 27, 'बेघर, आदि'),
(102377, 2872, 27, 'मेजबान नाम'),
(102378, 2873, 27, 'मेजबान नाम खाली नहीं हो सकता'),
(102379, 2875, 27, 'घंटा'),
(102380, 2876, 27, 'घंटे'),
(102381, 2878, 27, 'चोट कैसे आया?'),
(102382, 2879, 27, 'चोट कैसे आया?'),
(102383, 2880, 27, 'हमारे बारे में कैसे सुना'),
(102384, 2881, 27, 'आने वाली घटनाओं के लिए क्वेरी करने के लिए कितने महीने आगे?'),
(102385, 2882, 27, 'HPI:'),
(102386, 2883, 27, 'HT'),
(102387, 2884, 27, 'HTML के'),
(102388, 2885, 27, 'HTML उत्पादन?'),
(102389, 2886, 27, 'LibreEHR समर्थन LLC लैब विनिमय सेवा के लिए HTTPS लिंक.'),
(102390, 2887, 27, 'हंगेरी'),
(102391, 2888, 27, 'Hylafax निर्देशिका'),
(102392, 2889, 27, 'Hylafax Enscript कमान'),
(102393, 2890, 27, 'Hylafax सर्वर'),
(102394, 2891, 27, 'Hylafax सर्वर मेजबाननाम.'),
(102395, 2892, 27, 'अतिसक्रिय'),
(102396, 2893, 27, 'अतिरक्तदाब'),
(102397, 2894, 27, 'उच्च रक्तचाप: रक्तचाप मापन'),
(102398, 2895, 27, 'उच्च रक्तचाप: रक्तचाप मापन (CQM)'),
(102399, 2896, 27, 'अतिगलग्रंथिता'),
(102400, 2897, 27, 'अल्पगलग्रंथिता'),
(102401, 2898, 27, 'जरायूच्छेदन'),
(102402, 2899, 27, 'मैं'),
(102403, 2900, 27, 'मैं इस समय के दौरान व्यस्त हूँ.'),
(102404, 2901, 27, 'मुझे पढ़ने के लिए अनुमति नहीं है '),
(102405, 2902, 27, 'ICD'),
(102406, 2903, 27, 'ICD10 निदान'),
(102407, 2904, 27, 'ICD10 प्रक्रिया / सेवा'),
(102408, 2905, 27, 'ICD9'),
(102409, 2906, 27, 'ICD9 निदान'),
(102410, 2907, 27, 'ICD9 प्रक्रिया / सेवा'),
(102411, 2909, 27, 'ID'),
(102412, 2910, 27, 'ID'),
(102413, 2911, 27, 'ID खाली नहीं हो सकता'),
(102414, 2912, 27, 'ID कार्ड'),
(102415, 2913, 27, 'IDays'),
(102416, 2914, 27, 'के रूप में पहचान'),
(102417, 2915, 27, 'पहचानकर्ता (एक शब्द)'),
(102418, 2916, 27, 'कोड की पहचान'),
(102419, 2917, 27, 'निष्क्रिय सत्र मध्यांतर सेकंड'),
(102420, 2919, 27, 'अगर सभी स्तंभों के लिए सभी डेटा इस फार्म के लिए पूरा हो गया है'),
(102421, 2920, 27, 'बिलिंग औचित्य प्रयोग किया जाता है, तो निदान कोड प्रकार का नाम दर्ज करें.'),
(102422, 2921, 27, 'दर्ज किया गया है, तो केवल उन का चयन करें, जिसने इस सेवा का इस्तेमाल किया है!'),
(102423, 2922, 27, 'यदि नाम, अंतिम नाम या LastName, FirstName का कोई भी हिस्सा'),
(102424, 2923, 27, 'द्वारा भुगतान करते हैं तो'),
(102425, 2924, 27, 'व्यक्ति मृत है, तो मृत्यु की तारीख दर्ज करें.'),
(102426, 2925, 27, 'SMTP प्रयोग किया जाता है, तो सर्वर `मेजबाननाम या IP पता है.'),
(102427, 2926, 27, 'SMTP प्रयोग किया जाता है, तो सर्वर `TCP पोर्ट संख्या (आमतौर पर 25) है.'),
(102428, 2927, 27, 'अगर बेरोजगार दर्ज विद्यार्थी'),
(102429, 2928, 27, 'अगर YMD उम्र प्रदर्शन के लिए चुना जाता है, तो वर्षों में स्विच करें जब इस मान से रोगियों बड़े है!'),
(102430, 2929, 27, 'आप ePrescription के लिए ई RX रोल बदलते हैं, तो ePrescription कार्यप्रवाह प्रभावित हो सकता है. आपको किसी भी कठिनाई का सामना करना पड़ता है, तो आप ePrescription विक्रेता से संपर्क करें.'),
(102431, 2931, 27, 'If you have chosen to upload electronic remittances, then the search window redisplays itself with the matching invoices from the X12 file. You may click on any of these invoice numbers (as described below) if you wish to make any corrections before the remittance information is applied. To apply the changes, click the Process ERA File button at the bottom of the page. This will produce a new window with a detailed report.'),
(102432, 2932, 27, 'If you have entered a Pay Date in the search page, this will override the posting date of payments and adjustments that are otherwise taken from the X12 file. This may be useful for reporting purposes, if you want your receipts reporting to use your posting date rather than the insurance company''s processing date. Note that this will also affect dates of prior payments and adjustments that are put into secondary claims.'),
(102433, 2933, 27, 'यदि आप डेटा प्रकार बदलना चाहते हैं, या पंक्तियाँ या स्तंभ जोड़ना चाहते हैं'),
(102434, 2934, 27, 'यदि आप डेटाबेस नवीनीकरण करना चाहते हैं, तो निम्न निर्देशिका में डेटाबेस ज़िप फ़ाइल रखें'),
(102435, 2936, 27, 'ध्यान न दें'),
(102436, 2937, 27, 'बीमारी'),
(102437, 2938, 27, 'IM'),
(102438, 2941, 27, 'इमेजिंग सेवा'),
(102439, 2942, 27, 'टीकाकरण'),
(102440, 2943, 27, 'टीकाकरण कोड'),
(102441, 2945, 27, 'टीकाकरण की तिथि'),
(102442, 2946, 27, 'टीकाकरण समाप्ति तिथि'),
(102443, 2947, 27, 'टीकाकरण बहुत संख्या'),
(102444, 2948, 27, 'टीकाकरण निर्माता'),
(102445, 2949, 27, 'टीकाकरण रजिस्ट्री'),
(102446, 2951, 27, 'टीकाकरण सेवा'),
(102447, 2952, 27, 'टीकाकरण शीर्षक'),
(102448, 2953, 27, 'टीकाकरण'),
(102449, 2954, 27, 'बचाव करना'),
(102450, 2955, 27, 'immunologic'),
(102451, 2956, 27, 'समाविष्ट'),
(102452, 2957, 27, 'आयात'),
(102453, 2961, 27, 'ब्राउज़र के लिए प्रमाणपत्र आयात करें.'),
(102454, 2962, 27, 'आयात विन्यास'),
(102455, 2964, 27, 'आयात रोगी'),
(102456, 2965, 27, 'आयात रोगी जनसांख्यिकी'),
(102457, 2966, 27, 'महत्वपूर्ण संहिताएं'),
(102458, 2967, 27, 'IMPORTANT: This upload tool is only for uploading documents on patients that are not yet entered into the system. To upload files for patients whom already have been entered into the system, please use the upload tool linked within the Patient Summary screen.'),
(102459, 2969, 27, 'लेखांकन से आयातित'),
(102460, 2972, 27, 'उन्नत'),
(102461, 2973, 27, 'में'),
(102462, 2974, 27, 'में'),
(102463, 2975, 27, 'हर आंख में'),
(102464, 2976, 27, 'बाईं आंख में'),
(102465, 2977, 27, 'नथुने में'),
(102466, 2978, 27, 'कार्यालय में'),
(102467, 2979, 27, 'दाहिनी आंख में'),
(102468, 2980, 27, 'घर में'),
(102469, 2981, 27, 'निष्क्रिय'),
(102470, 2982, 27, 'निष्क्रिय दिन'),
(102471, 2983, 27, 'इनबॉक्स'),
(102472, 2986, 27, 'Checksum शामिल करें'),
(102473, 2987, 27, 'पूरे किए गए शामिल करें'),
(102474, 2988, 27, 'निष्क्रिय उपयोगकर्ताओं को शामिल करें'),
(102475, 2989, 27, 'Uncategorized शामिल करें'),
(102476, 2990, 27, 'असंरचित डेटा शामिल'),
(102477, 2991, 27, 'नब्ज शामिल करें'),
(102478, 2992, 27, 'नब्ज डेटा शामिल हैं?'),
(102479, 2993, 27, 'समावेश'),
(102480, 2994, 27, 'आमदनी'),
(102481, 2996, 27, 'अधूरा'),
(102482, 2997, 27, 'अपूर्ण गर्भपात उपचार'),
(102483, 2998, 27, 'असंयमिता'),
(102484, 2999, 27, 'नैदानिक ​​प्रयोगशाला परीक्षण के परिणाम संरचित डेटा के रूप में प्रमाणित EHR प्रौद्योगिकी में शामिल करें.'),
(102485, 3000, 27, 'गलत पासवर्ड!'),
(102486, 3001, 27, 'वृद्धि हुई:'),
(102487, 3002, 27, 'क्षतिपूर्ति बीमा'),
(102488, 3003, 27, 'अनिश्चित'),
(102489, 3004, 27, 'भारतीय'),
(102490, 3005, 27, 'विषमता संकेत करता है'),
(102491, 3006, 27, 'संकेत करता है अगर, यह समस्या इस समय सक्रिय है'),
(102492, 3008, 27, 'विशेष उपयोग के लिए संकेतक'),
(102493, 3009, 27, 'जरूरतमंद मरीजों को'),
(102494, 3010, 27, 'गरीब मरीजों की रिपोर्ट'),
(102495, 3011, 27, 'indigents'),
(102496, 3014, 27, 'प्रेरित गर्भपात'),
(102497, 3016, 27, 'अयोग्य'),
(102498, 3017, 27, 'संक्रमण / फोड़ा'),
(102499, 3018, 27, 'संक्रमण'),
(102500, 3019, 27, 'Infert Couns'),
(102501, 3020, 27, 'बांझपन'),
(102502, 3021, 27, 'इन्फ्लुएंजा 1'),
(102503, 3022, 27, 'इन्फ्लुएंजा 2'),
(102504, 3023, 27, 'इन्फ्लूएंजा टीकाकरण के मरीजों के लिए> = 50 साल की उम्र'),
(102505, 3024, 27, 'मरीजों के लिए इन्फ्लूएंजा टीकाकरण> = 50 साल की उम्र (CQM)'),
(102506, 3025, 27, 'इन्फ्लुएंजा वैक्सीन'),
(102507, 3026, 27, 'जानकारी'),
(102508, 3027, 27, 'जानकारी परीक्षण 1'),
(102509, 3028, 27, 'जानकारी परीक्षण 2'),
(102510, 3029, 27, 'जानकारी टेस्ट 3'),
(102511, 3030, 27, 'जानकारी टेस्ट 4'),
(102512, 3031, 27, 'जानकारी परीक्षण 5'),
(102513, 3032, 27, 'जानकारी परीक्षण 6'),
(102514, 3034, 27, 'inhalations'),
(102515, 3035, 27, 'inhilations'),
(102516, 3037, 27, 'प्रारंभिक उपयोगकर्ता'),
(102517, 3038, 27, 'Inj / पुनर्वसन'),
(102518, 3039, 27, 'injectables'),
(102519, 3040, 27, 'Injection'),
(102520, 3041, 27, 'चोटिल शरीर के अंग'),
(102521, 3042, 27, 'चोटिल बाहर'),
(102522, 3043, 27, 'चोट'),
(102523, 3044, 27, 'चोट तंत्र'),
(102524, 3045, 27, 'चोट अवलोकन रिपोर्ट'),
(102525, 3046, 27, 'चोट निगरानी'),
(102526, 3047, 27, 'चोट के प्रकार'),
(102527, 3048, 27, 'चोट / बीमारी से संबंधित'),
(102528, 3050, 27, 'इनपुट एक MSH खंड से शुरू नहीं होता'),
(102529, 3051, 27, 'इनपुट क्षेत्रों'),
(102530, 3052, 27, 'INR'),
(102531, 3053, 27, 'Ins 1'),
(102532, 3054, 27, 'Ins 2 या Ins 3'),
(102533, 3055, 27, 'Ins पता'),
(102534, 3056, 27, 'Ins समायोजित'),
(102535, 3057, 27, 'Ins bundling'),
(102536, 3058, 27, 'Ins कोड'),
(102537, 3059, 27, 'Ins समूह'),
(102538, 3060, 27, 'Ins का नाम'),
(102539, 3061, 27, 'Ins overpaid'),
(102540, 3062, 27, 'Ins नीति'),
(102541, 3063, 27, 'Ins धन वापसी'),
(102542, 3064, 27, 'Ins सारांश'),
(102543, 3065, 27, 'Ins1'),
(102544, 3066, 27, 'Ins2'),
(102545, 3067, 27, 'Ins3'),
(102546, 3069, 27, 'डालें विफल: '),
(102547, 3070, 27, 'तालिकाओं में पुरानी घटनाओं को डालें'),
(102548, 3072, 27, 'अनिद्रा'),
(102549, 3073, 27, 'प्रवेश का निरीक्षण'),
(102550, 3074, 27, 'निरीक्षण'),
(102551, 3075, 27, 'अस्थिरता / अनुसन्धिच्युति'),
(102552, 3076, 27, 'स्थापित करें'),
(102553, 3077, 27, 'स्थापित करें'),
(102554, 3079, 27, 'DB स्थापित करें'),
(102555, 3080, 27, 'स्थापित प्रकाशनी'),
(102556, 3081, 27, 'निर्देश दिए'),
(102557, 3082, 27, 'निर्देश'),
(102558, 3084, 27, 'निर्देश:'),
(102559, 3085, 27, 'उत्पाद ID के लिए अपर्याप्त सूची'),
(102560, 3086, 27, 'इंसुलिन निर्भर मधुमेह'),
(102561, 3087, 27, 'बीमा'),
(102562, 3088, 27, 'बीमा'),
(102563, 3091, 27, 'बीमा शेष राशि'),
(102564, 3092, 27, 'बीमा शेष राशि लंबित'),
(102565, 3093, 27, 'बीमा COMP'),
(102566, 3094, 27, 'बीमा कंपनियां'),
(102567, 3095, 27, 'इंश्योरेंस कंपनी'),
(102568, 3096, 27, 'इंश्योरेंस कंपनी खोज / जोड़ें'),
(102569, 3098, 27, 'बीमा डाटा'),
(102570, 3099, 27, 'फाइल पर बीमा जानकारी'),
(102571, 3100, 27, 'बीमा अंक'),
(102572, 3101, 27, 'बीमा भुगतान'),
(102573, 3103, 27, 'बीमा प्रदाता'),
(102574, 3106, 27, 'बीमित'),
(102575, 3107, 27, 'इनटेक निष्कर्ष'),
(102576, 3108, 27, 'इनटेक तिथि'),
(102577, 3109, 27, 'बौद्धिक गिरावट'),
(102578, 3113, 27, 'आंतरिक त्रुटि - पृष्ठों को चयन किया गया नहीं!'),
(102579, 3114, 27, 'आंतरिक त्रुटि - रोगी ID प्रदान नहीं किया गया!'),
(102580, 3115, 27, 'आंतरिक त्रुटि अपलोड की गई फ़ाइल तक पहुँचने में!'),
(102581, 3116, 27, 'आंतरिक त्रुटि!'),
(102582, 3117, 27, 'आंतरिक त्रुटि, दवा ID निर्दिष्ट नहीं!'),
(102583, 3118, 27, 'आंतरिक त्रुटि: MSH-10 नहीं खोज सके'),
(102584, 3119, 27, 'आंतरिक त्रुटि: दावा '),
(102585, 3120, 27, 'आंतरिक त्रुटि: मुठभेड़ '''),
(102586, 3121, 27, 'आंतरिक त्रुटि: pid ​​या मुठभेड़ लापता है.'),
(102587, 3122, 27, 'आंतरिक त्रुटि: हम एक मुठभेड़ में हो ऐसा नहीं लगता है!'),
(102588, 3123, 27, 'आंतरिक पहचानकर्ता (pid​​)'),
(102589, 3126, 27, 'आंतरिक सिफ़ारिशों के'),
(102590, 3127, 27, 'आंतरिक समय एकत्रित'),
(102591, 3128, 27, 'अंतर्राष्ट्रीय कर्तव्य'),
(102592, 3129, 27, 'दुभाषिया'),
(102593, 3130, 27, 'दुभाषिए की जरूरत?'),
(102594, 3131, 27, 'अंतरालीय फेफड़े की बीमारी'),
(102595, 3132, 27, 'अंतराल'),
(102596, 3133, 27, 'अंतराल (मिनट)'),
(102597, 3134, 27, 'संदेश जाँच के बीच अंतराल (केवल मैनुअल जाँच के लिए शून्य पर सेट करें)'),
(102598, 3135, 27, 'हस्तक्षेप'),
(102599, 3136, 27, 'परंतु हस्तक्षेप'),
(102600, 3137, 27, 'असहिष्णुता'),
(102601, 3139, 27, 'अंतर्पेशीय'),
(102602, 3140, 27, 'नसों में'),
(102603, 3141, 27, 'परिचय'),
(102604, 3144, 27, 'अमान्य वर्ण'),
(102605, 3147, 27, 'अमान्य लंबाई'),
(102606, 3148, 27, 'अमान्य गैर संख्यात्मक चरित्र में'),
(102607, 3149, 27, 'कोड के लिए स्रोत में अमान्य या अनुपस्थित दाता '),
(102608, 3150, 27, 'प्राप्तकर्ता का पता अमान्य. पुन: प्रयास करें.'),
(102609, 3151, 27, 'अमान्य सेवा संहिताएं'),
(102610, 3152, 27, 'अवैध स्रोत पद "'),
(102611, 3153, 27, 'अमान्य उपयोगकर्ता नाम या पासवर्ड'),
(102612, 3154, 27, 'InvAmt'),
(102613, 3155, 27, 'इनवेंटरी'),
(102614, 3156, 27, 'इन्वेंटरी गतिविधि'),
(102615, 3157, 27, 'दवाओं और गैर दवा उत्पादों, दोनों को इन्वेंटरी और बेचते हैं!'),
(102616, 3158, 27, 'केवल दवाओं इन्वेंटरी और बेचते हैं!'),
(102617, 3159, 27, 'इन्वेंटरी इस आदेश के लिए उपलब्ध नहीं है.'),
(102618, 3160, 27, 'इन्वेंट्री सूची'),
(102619, 3161, 27, 'इन्वेंटरी लेनदेन'),
(102620, 3162, 27, 'बीजक'),
(102621, 3163, 27, 'बीजक'),
(102622, 3164, 27, 'चालान शेष'),
(102623, 3165, 27, 'चालान शेष तैनात नहीं किया जा सकता.मुठभेड़ बनाई नहीं गई है.'),
(102624, 3166, 27, 'चालान तिथि'),
(102625, 3167, 27, 'चालान तिथि नहीं है!'),
(102626, 3168, 27, 'चालान संख्या'),
(102627, 3169, 27, 'चालान संदर्भ संख्या'),
(102628, 3170, 27, 'चालान संदर्भ संख्या पूल, अगर इस्तेमाल किया है!'),
(102629, 3171, 27, 'चालान संदर्भ संख्या ताल'),
(102630, 3172, 27, 'चालान Refno तरणताल'),
(102631, 3173, 27, 'चालान:'),
(102632, 3174, 27, 'IPPF'),
(102633, 3175, 27, 'IPPF गर्भपात'),
(102634, 3176, 27, 'IPPF गर्भनिरोध'),
(102635, 3177, 27, 'IPPF SRH डेटा के लिए'),
(102636, 3178, 27, 'IPPF सांख्यिकी रिपोर्ट'),
(102637, 3179, 27, 'IPPF आँकड़े'),
(102638, 3180, 27, 'IPV 1'),
(102639, 3181, 27, 'IPV 2'),
(102640, 3182, 27, 'IPV 3'),
(102641, 3183, 27, 'IPV 4'),
(102642, 3185, 27, 'अनियमित दिल की धड़कन'),
(102643, 3186, 27, 'चिड़चिड़ापन'),
(102644, 3187, 27, 'जलन'),
(102645, 3188, 27, 'निम्नलिखित डेटाबेस की एक अलग भाषा संस्करण है'),
(102646, 3189, 27, 'निम्नलिखित डेटाबेस का एक अलग संस्करण है'),
(102647, 3190, 27, 'निम्नलिखित डेटाबेस के नवीनतम संस्करण है'),
(102648, 3191, 27, 'क्षेत्र जरूरी है.'),
(102649, 3192, 27, 'एक रूट नोड है और नष्ट नहीं किया जा सकता है.'),
(102650, 3193, 27, 'निम्नलिखित डेटाबेस का एक विस्तार है'),
(102651, 3195, 27, 'गलत या अज्ञात है'),
(102652, 3197, 27, '(दशमलव अंश ठीक हैं) वैध नहीं है.'),
(102653, 3198, 27, 'क्या PHP सुरक्षित मोड का उपयोग कर रहा है?'),
(102654, 3200, 27, 'क्या प्रपत्र लेआउट से पाठ अनुवादित किया जा रहा है?'),
(102655, 3201, 27, 'क्या सूची से पाठ अनुवादित किया जा रहा है?'),
(102656, 3202, 27, 'क्या फ़ाइल एन्क्रिप्टेड है?'),
(102657, 3203, 27, 'क्या यह एक नैदानिक ​​शब्द कोड प्रकार है?'),
(102658, 3204, 27, 'क्या यह एक निदान प्रकार है?'),
(102659, 3205, 27, 'क्या यह एक चिकित्सा समस्या कोड प्रकार है?'),
(102660, 3207, 27, 'क्या यह एक प्रक्रिया / सेवा प्रकार है?'),
(102661, 3208, 27, 'क्या यह सक्रिय है?'),
(102662, 3209, 27, 'क्या यह कोड प्रकार सक्रिय है?'),
(102663, 3210, 27, 'क्या यह कोड प्रकार दावों में किया जाता है?'),
(102664, 3212, 27, 'क्या इस प्रकार के शुल्क चादर में छिपा हुआ है?'),
(102665, 3213, 27, 'क्या यह बाहरी SQL तालिकाओं का उपयोग कर रहा है? अगर ऐसा है, तो स्वरूप चुनें.'),
(102666, 3214, 27, 'बहुत लंबा है'),
(102667, 3216, 27, 'समस्या'),
(102668, 3217, 27, 'समस्या'),
(102669, 3218, 27, 'अंक तिथि'),
(102670, 3219, 27, 'समस्या ID'),
(102671, 3220, 27, 'समस्या शीर्षक'),
(102672, 3221, 27, 'समस्या प्रकार'),
(102673, 3222, 27, 'समस्या प्रकार'),
(102674, 3223, 27, 'समस्या'),
(102675, 3224, 27, 'समस्या (चोट लगने / चिकित्सा / एलर्जी)'),
(102676, 3225, 27, 'समस्या (चोट लगने / चिकित्सा / एलर्जी):'),
(102677, 3226, 27, 'समस्या और मुठभेड़ों'),
(102678, 3227, 27, 'के लिए समस्या और मुठभेड़ों'),
(102679, 3228, 27, 'समस्या अधिकृत नहीं'),
(102680, 3229, 27, 'समस्या अनुभाग'),
(102681, 3230, 27, 'Italian'),
(102682, 3231, 27, 'वस्तु'),
(102683, 3232, 27, 'वस्तु'),
(102684, 3233, 27, 'वस्तु'),
(102685, 3234, 27, 'वस्तु विफल लोड'),
(102686, 3235, 27, 'IU / L'),
(102687, 3236, 27, 'IUD'),
(102688, 3237, 27, 'चतुर्थ'),
(102689, 3238, 27, 'जनवरी'),
(102690, 3239, 27, 'जनवरी'),
(102691, 3240, 27, 'जापानी'),
(102692, 3241, 27, 'पीलिया'),
(102693, 3243, 27, 'कार्य विवरण'),
(102694, 3244, 27, 'नौकरी आईडी'),
(102695, 3245, 27, 'जोड़ों का dislocations'),
(102696, 3246, 27, 'जोड़ों का दर्द'),
(102697, 3247, 27, 'जोड़ों की मोच'),
(102698, 3248, 27, 'जुलाई'),
(102699, 3249, 27, 'जुलाई'),
(102700, 3250, 27, 'जून'),
(102701, 3251, 27, 'जून'),
(102702, 3252, 27, 'Just below the check information is a blue area where you put in your search parameters. You can search by patient name, chart number, encounter number or date of service, or any combination of these. You may also select whether you want to see all invoices, open invoices, or only invoices that are due (by the patient). Click the Search button to perform the search.'),
(102703, 3253, 27, 'बस मेरा'),
(102704, 3254, 27, 'औचित्य प्रविष्टियां'),
(102705, 3255, 27, 'औचित्य'),
(102706, 3256, 27, 'औचित्य / सहेजें'),
(102707, 3257, 27, 'J {{शीर्ष औचित्य करें}}'),
(102708, 3258, 27, 'K, बाकी यहाँ है'),
(102709, 3264, 27, 'चाबी'),
(102710, 3265, 27, 'खोजशब्द'),
(102711, 3266, 27, 'किलोग्राम'),
(102712, 3267, 27, 'किग्रा / m ^ 2'),
(102713, 3269, 27, 'गुर्दे के कैंसर'),
(102714, 3270, 27, 'गुर्दे की विफलता'),
(102715, 3271, 27, 'गुर्दे में संक्रमण'),
(102716, 3272, 27, 'गुर्दे की पथरी'),
(102717, 3273, 27, 'गुर्दा प्रत्यारोपण'),
(102718, 3277, 27, 'घुटना'),
(102719, 3278, 27, 'घुटने की समस्याओं'),
(102720, 3279, 27, 'घुटने रिप्लेसमेंट'),
(102721, 3282, 27, 'कोरियाई'),
(102722, 3286, 27, 'लैब'),
(102723, 3288, 27, 'लैब एक्सचेंज साइट पता'),
(102724, 3289, 27, 'लैब एक्सचेंज साइट ID'),
(102725, 3290, 27, 'लैब विनिमय टोकन ID'),
(102726, 3294, 27, 'लैब प्रश्न स्थिति'),
(102727, 3295, 27, 'लैब की रिपोर्ट'),
(102728, 3296, 27, 'लैब नतीजे'),
(102729, 3297, 27, 'लैब परिणाम'),
(102730, 3299, 27, 'लैब परिणाम की रिपोर्ट'),
(102731, 3300, 27, 'लैब सेवा'),
(102732, 3301, 27, 'लैब परीक्षण के परिणाम'),
(102733, 3303, 27, 'लेबल'),
(102734, 3304, 27, 'लेबल खाली नहीं हो सकता'),
(102735, 3305, 27, 'लेबल Cols'),
(102736, 3306, 27, 'इस प्रकार के लिए लेबल'),
(102737, 3307, 27, 'LabelCols 1 और 999 के बीच में होनी चाहिए'),
(102738, 3308, 27, 'लेबल'),
(102739, 3311, 27, 'लैब्स'),
(102740, 3312, 27, 'फटन / त्वचा हालत'),
(102741, 3313, 27, 'फटन / घर्षण'),
(102742, 3316, 27, 'भाषा'),
(102743, 3317, 27, 'भाषा कोड'),
(102744, 3318, 27, 'भाषा परिभाषा जोड़े'),
(102745, 3319, 27, 'भाषा इंटरफ़ेस उपकरण'),
(102746, 3320, 27, 'भाषा सूची (addonly वैकल्पिक लिखने)'),
(102747, 3321, 27, 'भाषा का नाम'),
(102748, 3322, 27, 'भाषा:'),
(102749, 3324, 27, 'Laotian'),
(102750, 3325, 27, 'अंतिम'),
(102751, 3326, 27, 'पिछली गतिविधि तिथि'),
(102752, 3328, 27, 'अंतिम बिल की तारीख:'),
(102753, 3330, 27, 'पिछले साल'),
(102754, 3333, 27, 'पिछले मुठभेड़'),
(102755, 3340, 27, 'अंतिम स्तर बिल'),
(102756, 3343, 27, 'पिछले माह'),
(102757, 3344, 27, 'अंतिम नाम'),
(102758, 3345, 27, 'अंतिम नाम'),
(102759, 3346, 27, 'अंतिम नाम:'),
(102760, 3350, 27, 'अंतिम समीक्षित'),
(102761, 3351, 27, 'आखिरी रन, पर शुरू कर दिया'),
(102762, 3352, 27, 'अंतिम सहेजा गया'),
(102763, 3356, 27, 'के द्वारा अंतिम अद्यतन'),
(102764, 3357, 27, 'पर अंतिम सत्यापित किया'),
(102765, 3358, 27, 'पिछली यात्रा के'),
(102766, 3360, 27, 'पिछली पुनरावृत्ति (2-12 मो)'),
(102767, 3361, 27, 'पार्श्विकता Malleolus'),
(102768, 3362, 27, 'पार्श्विकता malleolus:'),
(102769, 3363, 27, 'पार्श्विकता'),
(102770, 3364, 27, 'इस प्रक्रिया की पार्श्विकता, यदि लागू हो'),
(102771, 3365, 27, 'पार्श्विक विस्थापित PMI:'),
(102772, 3373, 27, 'लेआउट आधारित'),
(102773, 3374, 27, 'लेआउट संपादक'),
(102774, 3375, 27, 'लेआउट समूह'),
(102775, 3376, 27, 'लेआउट शैली'),
(102776, 3378, 27, 'लेआउट आधारित भेंट फॉर्म्स'),
(102777, 3379, 27, 'लेआउट'),
(102778, 3380, 27, 'lb'),
(102779, 3381, 27, 'lbs'),
(102780, 3382, 27, 'LDL'),
(102781, 3383, 27, 'अगर अभी भी सक्रिय है, तो खाली छोड़ दें'),
(102782, 3384, 27, 'मूल फ़ाइलनाम रखने के लिए खाली छोड़ दें'),
(102783, 3385, 27, 'पासवर्ड को अपरिवर्तित रखने के लिए खाली छोड़ दें.'),
(102784, 3386, 27, 'के साथ संदेश छोड़ दें'),
(102785, 3387, 27, 'फार्म छोड़ दें'),
(102786, 3388, 27, 'पास वाक्यांश को खाली छोड़ने से दस्तावेज़ एन्क्रिप्ट नहीं होगा'),
(102787, 3390, 27, 'बाएं'),
(102788, 3391, 27, 'बाएं कान'),
(102789, 3392, 27, 'बाएं कान'),
(102790, 3394, 27, 'बाएं'),
(102791, 3395, 27, 'बाएं '),
(102792, 3396, 27, 'पैर में दर्द / ऐंठन'),
(102793, 3397, 27, 'कानूनी'),
(102794, 3399, 27, 'कानूनी कागज़ आकार'),
(102795, 3400, 27, 'लिजेंड:'),
(102796, 3401, 27, 'लंबाई'),
(102797, 3402, 27, 'संशोधक की लंबाई, 0 अगर कोई नहीं है'),
(102798, 3403, 27, 'से भी कम'),
(102799, 3404, 27, 'से भी कम या बराबर'),
(102800, 3405, 27, 'कम निजी जानकारी (, addonly वैकल्पिक लिखने)'),
(102801, 3406, 27, 'पत्र'),
(102802, 3407, 27, 'पत्र उत्पन्नकर्ता'),
(102803, 3408, 27, 'पत्र कागज आकार'),
(102804, 3409, 27, 'लेटरहेड पर, उस डॉक्टर के हस्ताक्षर'),
(102805, 3410, 27, 'लेटरहेड पर, उस मरीज के हस्ताक्षर'),
(102806, 3411, 27, 'तात्कालिकता का स्तर'),
(102807, 3412, 27, 'दायित्व'),
(102808, 3413, 27, 'दायित्व मैडिकल'),
(102809, 3414, 27, 'लाइसेंस / ID'),
(102810, 3419, 27, 'LicensedPrescriber अंतिम नाम'),
(102811, 3420, 27, 'LicensedPrescriber NPI'),
(102812, 3421, 27, 'LicensedPrescriber UPIN'),
(102813, 3423, 27, 'जीवन शैली'),
(102814, 3424, 27, 'जीवन शैली स्थिति'),
(102815, 3425, 27, 'अस्थिबंध फटी या मोच'),
(102816, 3426, 27, 'लाइट तम्बाकू धूम्रपान करने वाला'),
(102817, 3428, 27, 'घटनाक्रम की सीमा'),
(102818, 3429, 27, 'सीमाएं'),
(102819, 3431, 27, 'जुड़ा हुआ'),
(102820, 3432, 27, 'रोगी के लिए जुड़ा हुआ'),
(102821, 3433, 27, 'जुड़ा हुआ'),
(102822, 3434, 27, 'जुड़ा हुआ दस्तावेज़'),
(102823, 3435, 27, 'जुड़ा हुआ प्रक्रिया आदेश'),
(102824, 3436, 27, 'दस्तावेज़ से जुड़ा हुआ'),
(102825, 3437, 27, 'प्रक्रिया आदेश से जुड़ा हुआ'),
(102826, 3438, 27, 'सूची'),
(102827, 3439, 27, 'सूची बॉक्स'),
(102828, 3440, 27, 'सूची बॉक्स'),
(102829, 3441, 27, 'सूची बॉक्स W / जोड़'),
(102830, 3442, 27, 'सूची बॉक्स W / जोड़'),
(102831, 3443, 27, 'सूची संपादक'),
(102832, 3444, 27, 'सूची मुठभेड़ों की'),
(102833, 3445, 27, 'सूची समूहों'),
(102834, 3446, 27, 'सूची बीमा कंपनियों की'),
(102835, 3448, 27, 'सूची आइटम नंबर के साथ शुरू नहीं कर सकते हैं.'),
(102836, 3449, 27, 'सूची आइटम अवैध चरित्र (o) शामिल हैं.'),
(102837, 3451, 27, 'सूची सूचियों'),
(102838, 3452, 27, 'सूची नाम'),
(102839, 3453, 27, 'सूची के नाम संख्या के साथ शुरू नहीं कर सकते.'),
(102840, 3454, 27, 'सूची नुस्खे'),
(102841, 3455, 27, 'ऊपर के देश डेटा प्रकार विकल्प द्वारा इस्तेमाल किया हुआ सूची.'),
(102842, 3456, 27, 'ऊपर के राज्य डेटा प्रकार विकल्प द्वारा इस्तेमाल किया हुआ सूची.'),
(102843, 3457, 27, 'आरएफसी 5425 टीएलएस syslog सर्वर के सुनने के बंदरगाह.'),
(102844, 3458, 27, 'सूचियां'),
(102845, 3459, 27, 'लिथुआनियाई'),
(102846, 3460, 27, 'लिविंग विल'),
(102847, 3461, 27, 'LLL:'),
(102848, 3462, 27, 'LMP'),
(102849, 3463, 27, 'संग्रह लोड करें'),
(102850, 3464, 27, 'परिभाषाएँ लोड करें'),
(102851, 3465, 27, 'लैब विन्यास लोड करें'),
(102852, 3466, 27, 'OE प्रश्न विकल्प लोड करें'),
(102853, 3467, 27, 'आदेश परिभाषाएँ लोड करें'),
(102854, 3468, 27, 'आदेश प्रविष्टि प्रश्न लोड करें'),
(102855, 3470, 27, 'लोड हो रहा है'),
(102856, 3471, 27, 'डेटाबेस में फाइल लोड हो रहा. इस में कुछ समय लगेगा ...'),
(102857, 3472, 27, 'नियंत्रण रेखा'),
(102858, 3473, 27, 'स्थानीय'),
(102859, 3476, 27, 'स्थानीय'),
(102860, 3477, 27, 'इलाका'),
(102861, 3478, 27, 'स्थान'),
(102862, 3479, 27, 'libreehr मशीन का स्थान और संवेदनशील डेटा हो सकता है, इसलिए यह मैन्युअल रूप से इसके उपयोग के बाद फ़ाइलों को हटाने की सिफारिश की है'),
(102863, 3480, 27, 'इस स्थल का स्थान'),
(102864, 3481, 27, 'अनिर्दिष्ट स्थान'),
(102865, 3482, 27, 'स्थान, जहां Hylafax फैक्स जमा हो जाते है.'),
(102866, 3483, 27, 'स्थान, जहां स्कैन जमा हो जाते है.'),
(102867, 3484, 27, 'स्थान:'),
(102868, 3485, 27, 'ताला'),
(102869, 3492, 27, 'में प्रवेश करें'),
(102870, 3493, 27, 'में प्रवेश करें'),
(102871, 3494, 27, 'बाहर प्रवेश करें'),
(102872, 3495, 27, 'में प्रवेश करें'),
(102873, 3496, 27, 'के रूप में प्रवेश करें'),
(102874, 3497, 27, 'इन के रूप में प्रवेश करें: '),
(102875, 3498, 27, 'बाहर प्रवेश करें'),
(102876, 3499, 27, 'प्रवेश कर रहा है'),
(102877, 3500, 27, 'में प्रवेश करें'),
(102878, 3501, 27, 'में प्रवेश करें');
INSERT INTO `lang_definitions` VALUES
(102879, 3503, 27, 'दूरस्थ मेजबान में प्रवेश करें'),
(102880, 3504, 27, 'दूरस्थ मेजबान में प्रवेश विफल रहा है'),
(102881, 3505, 27, 'बाहर प्रवेश करें'),
(102882, 3506, 27, 'बाहर प्रवेश करें'),
(102883, 3507, 27, 'लॉग्स'),
(102884, 3508, 27, 'लॉग्स दर्शक'),
(102885, 3510, 27, 'झांकना'),
(102886, 3511, 27, 'लॉट'),
(102887, 3512, 27, 'लॉट ID लापता!'),
(102888, 3513, 27, 'लॉट संख्या'),
(102889, 3514, 27, 'कम'),
(102890, 3515, 27, 'कम प्राथमिकता'),
(102891, 3516, 27, 'निचले पैर'),
(102892, 3517, 27, 'न्यूनतम प्राथमिकता'),
(102893, 3519, 27, 'काठ का रीढ़'),
(102894, 3520, 27, 'दोपहर का भोजन'),
(102895, 3521, 27, 'दोपहर का भोजन'),
(102896, 3522, 27, 'फेफड़ों का कैंसर'),
(102897, 3523, 27, 'फेफड़ों की कैंसर सर्जरी'),
(102898, 3524, 27, 'फेफड़ों:'),
(102899, 3525, 27, 'फेफड़े:'),
(102900, 3526, 27, 'ल्युपस'),
(102901, 3528, 27, 'M'),
(102902, 3529, 27, 'MA श्रेणी'),
(102903, 3530, 27, 'MA क्लाइंट को गर्भपात स्वीकार'),
(102904, 3531, 27, 'MA आँकड़े'),
(102905, 3533, 27, 'भेजी गई मेल'),
(102906, 3534, 27, 'मुख्य'),
(102907, 3535, 27, 'मुख्य पता'),
(102908, 3536, 27, 'मुख्य शीर्ष फलक स्क्रीन'),
(102909, 3537, 27, 'सक्रिय दवा एलर्जी सूची बनाए.'),
(102910, 3538, 27, 'सक्रिय दवा सूची बनाए.'),
(102911, 3539, 27, 'वर्तमान और सक्रिय निदान की अब तक की एक समस्या सूची बनाए.'),
(102912, 3540, 27, 'मौजूदा श्रेणियों में संशोधन करें.'),
(102913, 3541, 27, 'के लिए नई नियुक्ति करें'),
(102914, 3542, 27, 'सुनिश्चित करें'),
(102915, 3543, 27, 'क्लियरिंग हाउस को अपलोड करने और बिल भेजा गया है, के रूप में चिन्हित कर देने के लिए बैच टेक्स्ट फाइल बना रहे है!'),
(102916, 3545, 27, 'अस्वस्थता:'),
(102917, 3548, 27, 'पुस्र्ष'),
(102918, 3549, 27, 'पुरुष कंडोम'),
(102919, 3550, 27, 'पुस्र्ष VSC'),
(102920, 3552, 27, 'मैमोग्राम'),
(102921, 3553, 27, 'प्रबंधित करें'),
(102922, 3556, 27, 'अनुवाद प्रबंधन'),
(102923, 3557, 27, 'प्रबंधन'),
(102924, 3558, 27, 'अनिवार्य और निर्दिष्ट क्षेत्रों के'),
(102925, 3559, 27, 'केवल अनिवार्य या निर्दिष्ट क्षेत्र, DUP की जांच, कोई खोज नहीं'),
(102926, 3560, 27, 'केवल अनिवार्य या निर्दिष्ट क्षेत्र, खोज और DUP चेक'),
(102927, 3561, 27, 'मैनुअल'),
(102928, 3562, 27, 'मैनुअल पोस्टिंग'),
(102929, 3563, 27, 'निर्माता'),
(102930, 3565, 27, 'मार्च'),
(102931, 3568, 27, 'मार्च'),
(102932, 3569, 27, 'वैवाहिक स्थिति'),
(102933, 3571, 27, 'बिल भेजा लेकिन बिलिंग को छोड़ दिया के रूप में चिह्नित करें'),
(102934, 3572, 27, 'मंजूरी दे दी के रूप में चिह्नित करें'),
(102935, 3573, 27, 'बिल किया नहीं के रूप में चिह्नित करें'),
(102936, 3574, 27, 'इन रिपोर्टों की समीक्षा कर दी के रूप में चिह्नित करें'),
(102937, 3575, 27, 'मंजूरी दे दी के रूप में चिह्नित किया'),
(102938, 3576, 27, 'विवाहित'),
(102939, 3578, 27, 'मुखौटा'),
(102940, 3579, 27, 'चालान नंबर के लिए मास्क'),
(102941, 3580, 27, 'रोगी IDs के लिए मास्क'),
(102942, 3581, 27, 'उत्पाद IDs के लिए मास्क'),
(102943, 3582, 27, 'मिलान'),
(102944, 3583, 27, 'केस मिलाएँ'),
(102945, 3591, 27, 'अधिकतम'),
(102946, 3592, 27, 'अधिकतम फ़ाइल गिनती तक पहुँच गया - नीचे नामों को फिर से लोड करें'),
(102947, 3594, 27, 'दाएँ दाढ़ की हड्डी:'),
(102948, 3595, 27, 'अधिकतम आयु'),
(102949, 3596, 27, 'अधिकतम अक्षर'),
(102950, 3597, 27, 'लॉगआउट से पहले, सेकंड में अधिकतम निष्क्रिय समय. डिफ़ॉल्ट 7200 (2 घंटे) है.'),
(102951, 3600, 27, 'अधिकतम उचित सूची, अगर कोई लागू नहीं तो 0'),
(102952, 3601, 27, 'अधिकतम आकार'),
(102953, 3602, 27, 'अधिकतम आकार (कोई भी आकार प्रवेश करने की अनुमति देगा 0 )'),
(102954, 3603, 27, 'मई'),
(102955, 3604, 27, 'MC'),
(102956, 3605, 27, 'मिलीग्राम'),
(102957, 3607, 27, 'इसका मतलब है, एक पासवर्ड बदलने पर पिछले तीन पासवर्ड का उपयोग की अनुमति नहीं है'),
(102958, 3609, 27, 'समूह कोड उपाय'),
(102959, 3611, 27, 'माप'),
(102960, 3612, 27, 'औसत दर्जे की malleolus:'),
(102961, 3613, 27, 'Medicaid'),
(102962, 3614, 27, 'मैडिकल'),
(102963, 3615, 27, 'मैडिकल गर्भपात'),
(102964, 3616, 27, 'मैडिकल प्रशासन'),
(102965, 3617, 27, 'मैडिकल इतिहास'),
(102966, 3618, 27, 'मैडिकल मुद्दा'),
(102967, 3619, 27, 'मैडिकल मुद्दा'),
(102968, 3620, 27, 'मैडिकल समस्या'),
(102969, 3621, 27, 'मैडिकल समस्या'),
(102970, 3622, 27, 'मैडिकल समस्या समस्या सूची'),
(102971, 3623, 27, 'मैडिकल समस्याओं'),
(102972, 3624, 27, 'मैडिकल रिकार्ड'),
(102973, 3625, 27, 'मैडिकल रिकार्ड #'),
(102974, 3626, 27, 'मैडिकल रिकॉर्ड्स'),
(102975, 3627, 27, 'मैडिकल रिकॉर्ड्स भेजे गए'),
(102976, 3629, 27, 'मैडिकल सारांश दिया'),
(102977, 3630, 27, 'मैडिकल प्रणाली'),
(102978, 3631, 27, 'मैडिकल प्रकार'),
(102979, 3632, 27, 'मैडिकल / इतिहास (addonly वैकल्पिक लिखने,)'),
(102980, 3633, 27, 'Medicare भाग B'),
(102981, 3634, 27, 'Medicare संदर्भकर्ता प्रतिपादक है'),
(102982, 3635, 27, 'दवा'),
(102983, 3636, 27, 'दवा एलर्जी की सूची'),
(102984, 3637, 27, 'दवा समस्या सूची'),
(102985, 3638, 27, 'दवा कंपनियों की सूची'),
(102986, 3639, 27, 'दवा सुलह किया?'),
(102987, 3640, 27, 'दवाएं'),
(102988, 3641, 27, 'दवाएं:'),
(102989, 3642, 27, 'चिकित्सा यूनिट्स'),
(102990, 3643, 27, 'माध्यम'),
(102991, 3645, 27, 'सदस्य संघ सांख्यिकी रिपोर्ट'),
(102992, 3646, 27, 'मेमोरी समस्याएं'),
(102993, 3647, 27, 'पुरूष'),
(102994, 3648, 27, 'पुरुष और महिला'),
(102995, 3649, 27, 'केवल पुरुषों के'),
(102996, 3650, 27, 'रजोदर्शन'),
(102997, 3651, 27, 'रजोनिवृत्ति'),
(102998, 3652, 27, 'मासिक धर्म प्रवाह'),
(102999, 3653, 27, 'मासिक धर्म आवृत्ति'),
(103000, 3654, 27, 'मानसिक बीमारी'),
(103001, 3657, 27, 'मिलाएं'),
(103002, 3658, 27, 'पूरा मिलाएं.'),
(103003, 3659, 27, 'मरीजों को मिलाएं'),
(103004, 3661, 27, 'संदेश'),
(103005, 3662, 27, 'संदेश और अनुस्मारक केंद्र'),
(103006, 3663, 27, 'संदेश सामग्री सादा टेक्स्ट नहीं है इसलिए, यह एक दस्तावेज के रूप में जमा किया गया है!'),
(103007, 3665, 27, 'भेजे गए संदेश'),
(103008, 3666, 27, 'संदेश स्थिति'),
(103009, 3669, 27, 'संदेश प्रकार'),
(103010, 3670, 27, 'संदेश:'),
(103011, 3671, 27, 'संदेश'),
(103012, 3672, 27, 'आपने आज भेजे गए संदेश'),
(103013, 3673, 27, 'विधि'),
(103014, 3674, 27, 'विधि और विशिष्ट उत्पाद'),
(103015, 3675, 27, 'निवर्तमान ईमेल भेजने के लिए विधि.'),
(103016, 3676, 27, 'विनाश की विधि'),
(103017, 3677, 27, 'मैक्सिकन / MexAmer / Chicano'),
(103018, 3679, 27, 'मिलीग्राम'),
(103019, 3680, 27, 'mg/1cc'),
(103020, 3681, 27, 'mg/2cc'),
(103021, 3682, 27, 'mg/3cc'),
(103022, 3683, 27, 'mg/4cc'),
(103023, 3684, 27, 'mg/5cc'),
(103024, 3685, 27, 'MG / DL'),
(103025, 3686, 27, 'मध्य'),
(103026, 3687, 27, 'मध्य नाम'),
(103027, 3688, 27, 'मध्य नाम'),
(103028, 3690, 27, 'Midlevel prescriber DEA'),
(103029, 3691, 27, 'Midlevel prescriber प्रथम नाम'),
(103030, 3692, 27, 'Midlevel prescriber अंतिम नाम'),
(103031, 3693, 27, 'Midlevel prescriber उपसर्ग'),
(103032, 3694, 27, 'Midlevel prescriber UPIN'),
(103033, 3695, 27, 'Mien'),
(103034, 3696, 27, 'प्रवासी या मौसमी कार्यकर्ता?'),
(103035, 3697, 27, 'प्रवासी / मौसमी'),
(103036, 3698, 27, 'लाख / CU.MM'),
(103037, 3702, 27, 'माइम प्रकार'),
(103038, 3703, 27, 'मिनट'),
(103039, 3704, 27, 'मिनट'),
(103040, 3705, 27, 'न्यूनतम आयु'),
(103041, 3706, 27, 'मामूली जोड़ों का तनाव / - श्लेषक कलाशोथ'),
(103042, 3708, 27, 'मिनट'),
(103043, 3709, 27, 'मिनट'),
(103044, 3710, 27, 'मिनट'),
(103045, 3712, 27, 'विविध'),
(103046, 3713, 27, 'विविध बिलिंग विकल्प'),
(103047, 3714, 27, 'HCFA-1500 के लिए विविध बिलिंग विकल्प'),
(103048, 3715, 27, 'विविध बिलिंग विकल्प HCFA'),
(103049, 3716, 27, 'विविध'),
(103050, 3717, 27, 'छूटे'),
(103051, 3718, 27, 'छूटे हुए'),
(103052, 3719, 27, 'एक आवश्यक फ़ील्ड छूटी'),
(103053, 3720, 27, 'छूटा शुल्क'),
(103054, 3721, 27, 'केवल Mods छूटा'),
(103055, 3722, 27, 'छूटा या अमान्य'),
(103056, 3723, 27, 'छूटे PID​​.'),
(103057, 3724, 27, 'छूटे रिपोर्ट दिनांक'),
(103058, 3725, 27, 'कोड के लिए स्रोत में दाता के बाद स्लैश छूटा '),
(103059, 3726, 27, 'मिश्रित'),
(103060, 3727, 27, 'मिलीलीटर'),
(103061, 3728, 27, 'MM / DD / YYYY'),
(103062, 3729, 27, 'mm / hg'),
(103063, 3730, 27, 'mmHg'),
(103064, 3731, 27, 'MMR 1'),
(103065, 3732, 27, 'MMR 2'),
(103066, 3733, 27, 'मोबाइल'),
(103067, 3734, 27, 'मोबाइल फोन'),
(103068, 3735, 27, 'MOD'),
(103069, 3738, 27, 'मध्यम प्राथमिकता'),
(103070, 3740, 27, 'मध्यम / कम प्राथमिकता'),
(103071, 3741, 27, 'संशोधक'),
(103072, 3742, 27, 'संशोधक'),
(103073, 3743, 27, 'संशोधित करें'),
(103074, 3745, 27, 'भुगतान संशोधित करें'),
(103075, 3746, 27, 'ModLength'),
(103076, 3753, 27, 'सोम'),
(103077, 3754, 27, 'सोम से शुक्र'),
(103078, 3755, 27, 'सोम, बुध और शुक्र'),
(103079, 3756, 27, 'सोमवार'),
(103080, 3758, 27, 'माह'),
(103081, 3759, 27, 'माह'),
(103082, 3760, 27, 'माह दृश्य'),
(103083, 3761, 27, 'महीने (s)'),
(103084, 3762, 27, 'मासिक आय'),
(103085, 3763, 27, 'महीने'),
(103086, 3765, 27, '100 से अधिक रिकॉर्ड पाया. अपने खोज मापदंड को संकीर्ण करें.'),
(103087, 3766, 27, '50 से अधिक परिणाम, अपनी खोज अधिक विशिष्ट करें.'),
(103088, 3767, 27, 'क्रमबद्ध बदलने के लिए अधिकांश कॉलम हेडर क्लिक किया जा सकता है'),
(103089, 3768, 27, 'से अंतिम'),
(103090, 3770, 27, 'से सबसे हाल नब्ज:'),
(103091, 3771, 27, 'माँ'),
(103092, 3772, 27, 'माँ का नाम'),
(103093, 3774, 27, 'मुंह'),
(103094, 3775, 27, 'ले जाएँ'),
(103095, 3776, 27, 'श्रेणी तक ले जाएँ:'),
(103096, 3777, 27, 'नीचे ले जाएँ'),
(103097, 3778, 27, 'ले जाएँ विफल रहा है!'),
(103098, 3779, 27, 'रोगी में ले जाएँ'),
(103099, 3780, 27, 'में ले जाएँ ...'),
(103100, 3781, 27, 'ऊपर ले जाएँ'),
(103101, 3782, 27, 'ले जा रहा है'),
(103102, 3783, 27, 'श्री'),
(103103, 3784, 27, 'MRN (pid​​)'),
(103104, 3785, 27, 'श्रीमती'),
(103105, 3786, 27, 'सुश्री'),
(103106, 3787, 27, 'MSH-11'),
(103107, 3788, 27, 'MSH-3.1'),
(103108, 3789, 27, 'MSH-4.1'),
(103109, 3790, 27, 'MSH-5.1'),
(103110, 3791, 27, 'MSH-6.1'),
(103111, 3794, 27, 'MSP कोड'),
(103112, 3795, 27, 'MSP परिहार संहिताओं'),
(103113, 3796, 27, 'बहु भाषा उपकरण'),
(103114, 3797, 27, 'कई क्षेत्रों में'),
(103115, 3798, 27, 'एकाधिक फ़ाइलों को Ctrl + क्लिक या SHIFT + क्लिक का उपयोग कर, एक समय में अपलोड किया जा सकता है.'),
(103116, 3799, 27, 'एकाधिक लॉट'),
(103117, 3800, 27, 'एकाधिक संशोधक, कोलन या रिक्त स्थान के द्वारा अलग किया जा सकता है, अधिकतम 4 (M1:M2:M3:M4)'),
(103118, 3802, 27, 'बहुजातीय'),
(103119, 3803, 27, 'दिल बड़बड़ाहट:'),
(103120, 3804, 27, 'मांसपेशी दर्द'),
(103121, 3805, 27, 'मांसपेशी दर्द'),
(103122, 3806, 27, 'मांसपेशी लाली'),
(103123, 3807, 27, 'मांसपेशी अकड़न'),
(103124, 3808, 27, 'मांसपेशी सूजन'),
(103125, 3809, 27, 'मांसपेशी गर्म'),
(103126, 3810, 27, 'मांसपेशी'),
(103127, 3811, 27, 'मांसपेशी की चोट'),
(103128, 3812, 27, 'पेशीकंकालीय'),
(103129, 3813, 27, 'SMTP प्रमाणीकरण का उपयोग नहीं किया जाता है तो खाली होना चाहिए.'),
(103130, 3814, 27, 'परस्पर में परिभाषित'),
(103131, 3815, 27, 'MVA'),
(103132, 3818, 27, 'मैं स्वयं'),
(103133, 3821, 27, 'N / A'),
(103134, 3822, 27, 'n /'),
(103135, 3823, 27, 'नाम'),
(103136, 3825, 27, 'नाम (अधिक के लिए क्लिक करें)'),
(103137, 3826, 27, '1 नाम'),
(103138, 3827, 27, '2 नाम'),
(103139, 3828, 27, 'नाम और प्रतिरक्षण प्रशासक का शीर्षक'),
(103140, 3831, 27, 'घटनाक्रम के नाम'),
(103141, 3832, 27, 'बीमा कंपनी के नाम'),
(103142, 3833, 27, 'प्रदाता के नाम'),
(103143, 3834, 27, 'रोगी अनुस्मारक के लिए भेजने वाले का नाम.'),
(103144, 3835, 27, 'नाम अनुवाद'),
(103145, 3836, 27, 'नाम / मान'),
(103146, 3837, 27, 'नाम:'),
(103147, 3838, 27, 'nares:'),
(103148, 3839, 27, 'Nares: सामान्य दाएँ'),
(103149, 3840, 27, 'अनुनासिक श्लेष्म गुलाबी, सेप्टम midline'),
(103150, 3841, 27, 'नेशन नोट्स'),
(103151, 3842, 27, 'नेशन नोट्स कॉन्फ़िगर'),
(103152, 3843, 27, 'नेशन नोट्स बटन बदलें'),
(103153, 3844, 27, 'राष्ट्रीयता'),
(103154, 3845, 27, 'NationNotes'),
(103155, 3847, 27, 'देशी हवाईयन या अन्य प्रशांत द्वीप'),
(103156, 3852, 27, 'मतली'),
(103157, 3854, 27, 'संचरण'),
(103158, 3855, 27, 'संचरण क्षेत्र मुठभेड़ फार्म शामिल'),
(103159, 3856, 27, 'संचरण क्षेत्र फ़्रेमसेट की पूरी ऊंचाई का उपयोग करता है'),
(103160, 3857, 27, 'संचरण क्षेत्र की यात्रा के फार्म'),
(103161, 3858, 27, 'संचरण क्षेत्र चौड़ाई'),
(103162, 3859, 27, 'संचरण मेनू रेडियो बटन जोड़ी के आकृति की में हैं'),
(103163, 3860, 27, 'संचरण मेनू एक पेड़ की आकृति में है'),
(103164, 3861, 27, 'संचरण एक स्लाइडिंग मेनू की आकृति में है'),
(103165, 3862, 27, 'NDC'),
(103166, 3863, 27, 'NDC डाटा'),
(103167, 3864, 27, 'NDC संख्या'),
(103168, 3866, 27, 'गर्दन की'),
(103169, 3867, 27, 'गर्दन की समस्याओं'),
(103170, 3868, 27, 'गर्दन की कोमलता'),
(103171, 3869, 27, 'एक विवरण दर्ज करने की आवश्यकता'),
(103172, 3870, 27, 'एक मान दर्ज करने की आवश्यकता'),
(103173, 3871, 27, 'पहचानकर्ता दर्ज करने की आवश्यकता'),
(103174, 3872, 27, 'शीर्षक दर्ज करने की आवश्यकता'),
(103175, 3873, 27, 'अधिकृत करने की जरूरत'),
(103176, 3874, 27, 'जस्टिफाई करने की जरूरत'),
(103177, 3875, 27, 'द्वितीयक बिलिंग की जरूरत'),
(103178, 3876, 27, 'नकारात्मक'),
(103179, 3877, 27, 'नकारात्मक'),
(103180, 3880, 27, 'तंत्रिका चोट'),
(103181, 3881, 27, 'तंत्रिका की स्थिति / तंत्रिका क्षति'),
(103182, 3882, 27, 'न्यूरो सन्न'),
(103183, 3883, 27, 'न्यूरो कमजोरी'),
(103184, 3884, 27, 'neurologic'),
(103185, 3885, 27, 'कभी नहीं'),
(103186, 3886, 27, 'कभी भी शराब पीने वाला नहीं'),
(103187, 3887, 27, 'कभी भी धूम्रपान करने वाला नहीं'),
(103188, 3888, 27, 'नया'),
(103189, 3889, 27, 'नया =>'),
(103190, 3890, 27, 'नया स्वीकार करने वाल'),
(103191, 3892, 27, 'नई एलर्जी'),
(103192, 3894, 27, 'नई नियुक्ति'),
(103193, 3895, 27, 'नई श्रेणियां'),
(103194, 3896, 27, 'नया श्रेणी'),
(103195, 3897, 27, 'नया ग्राहक'),
(103196, 3898, 27, 'नया परामर्श'),
(103197, 3899, 27, 'New Crop'),
(103198, 3900, 27, 'नई परिभाषा जोड़ी गई'),
(103199, 3901, 27, 'नए दस्तावेज़'),
(103200, 3902, 27, 'नए दस्तावेज़'),
(103201, 3904, 27, 'नई मुठभेड़'),
(103202, 3905, 27, 'ID के साथ बनाई गई नई मुठभेड़'),
(103203, 3906, 27, 'नई मुठभेड़ फार्म'),
(103204, 3907, 27, 'नई मुठभेड़ अधिकृत नहीं'),
(103205, 3908, 27, 'नई Enctr'),
(103206, 3909, 27, 'नई सुविधा की जानकारी'),
(103207, 3910, 27, 'नई फ़ाइल'),
(103208, 3911, 27, 'नई फ़ाइलें'),
(103209, 3912, 27, 'नया समूह'),
(103210, 3913, 27, 'नया समूह जानकारी'),
(103211, 3914, 27, 'नई Inj / स्थिति'),
(103212, 3916, 27, 'घटनाक्रम की नई सीमा'),
(103213, 3917, 27, 'नई सूची'),
(103214, 3918, 27, 'नए आदेश'),
(103215, 3919, 27, 'नया अनुच्छेद'),
(103216, 3920, 27, 'नया पासवर्ड'),
(103217, 3921, 27, 'नए रोगी'),
(103218, 3922, 27, 'नए रोगी'),
(103219, 3923, 27, 'नया रोगी मुठभेड़'),
(103220, 3924, 27, 'नया रोगी फार्म'),
(103221, 3925, 27, 'नया रोगी ID'),
(103222, 3926, 27, 'नया भुगतान'),
(103223, 3928, 27, 'नया Pt'),
(103224, 3929, 27, 'लैब मुद्रा से नए परिणाम'),
(103225, 3930, 27, 'नई खोज'),
(103226, 3931, 27, 'नई प्रस्तुतियाँ'),
(103227, 3932, 27, 'नया उपयोगकर्ता'),
(103228, 3934, 27, 'नई भेंट'),
(103229, 3935, 27, 'नई / खोज'),
(103230, 3936, 27, 'NewCrop खाते की स्थिति'),
(103231, 3937, 27, 'NewCrop व्यवस्थापक'),
(103232, 3938, 27, 'NewCrop कॉल विफल'),
(103233, 3939, 27, 'NewCrop डॉक्टर'),
(103234, 3944, 27, 'NewCrop eRx नाम'),
(103235, 3945, 27, 'NewCrop eRx साथी का नाम'),
(103236, 3946, 27, 'NewCrop eRx पासवर्ड'),
(103237, 3947, 27, 'NewCrop eRx भूमिका'),
(103238, 3948, 27, 'NewCrop eRx भूमिका'),
(103239, 3949, 27, 'NewCrop eRx साइट पता'),
(103240, 3954, 27, 'NewCrop eRx वेब सेवा पता'),
(103241, 3955, 27, 'NewCrop प्रबंधक'),
(103242, 3956, 27, 'NewCrop MedEntry'),
(103243, 3957, 27, 'NewCrop midlevel prescriber'),
(103244, 3958, 27, 'NewCrop नर्स'),
(103245, 3959, 27, 'NewCrop पर्यवेक्षण डॉक्टर'),
(103246, 3961, 27, 'अख़बार'),
(103247, 3962, 27, 'अगला'),
(103248, 3964, 27, 'अगले दिन'),
(103249, 3965, 27, 'अगले महीने'),
(103250, 3966, 27, 'अगले महीने (मेनू के लिए पकड़)'),
(103251, 3967, 27, 'अगला अनुसूचित चलाए'),
(103252, 3968, 27, 'अगले सप्ताह'),
(103253, 3969, 27, 'अगले साल (मेनू के लिए पकड़)'),
(103254, 3971, 27, 'उपनाम'),
(103255, 3973, 27, 'रात को पसीना'),
(103256, 3974, 27, 'Nl ext जननांग, VAG म्यूकोसा, गर्भाशय ग्रीवा'),
(103257, 3975, 27, 'नहीं'),
(103258, 3976, 27, 'नहीं'),
(103259, 3977, 27, 'पहुंच नहीं'),
(103260, 3978, 27, 'सक्रिय रोगी अनुस्मारक नहीं.'),
(103261, 3979, 27, 'ग्रंथिरोग नहीं है (आवश्यक 2 क्षेत्रों)'),
(103262, 3980, 27, 'कोई समायोजन कारण प्रकार मिला नहीं'),
(103263, 3981, 27, 'उपांगीय Tenderness / Masses नहीं है'),
(103264, 3983, 27, 'कोई नियुक्तिया नहीं है'),
(103265, 3985, 27, 'बिलिंग प्रणाली वर्तमान में सक्रिय नहीं है'),
(103266, 3986, 27, 'OFX निर्यात में शामिल करने के लिए, नहीं मिला बिल'),
(103267, 3987, 27, 'OFX निर्यात में शामिल करने के लिए, नहीं मिला बिल <br>'),
(103268, 3989, 27, 'कोड निर्दिष्ट किया गया नहीं था!'),
(103269, 3992, 27, 'कोई निदान नहीं है'),
(103270, 3993, 27, 'कोई दस्तावेज मिला नहीं है'),
(103271, 3994, 27, 'मुठभेड़ नहीं बनाया जा सकता है'),
(103272, 3995, 27, 'कोई अंतिम तिथि नहीं है'),
(103273, 3996, 27, 'प्रविष्टियों मिली नहीं, एक प्रविष्टि जोड़ने के लिए नीचे दिए गए फ़ॉर्म का उपयोग करें.'),
(103274, 3997, 27, 'कोई त्रुटि मिली नहीं'),
(103275, 3998, 27, 'कोई इवेंट नहीं'),
(103276, 4000, 27, 'स्थापना के लिए कोई फाइल मंचन नहीं'),
(103277, 4001, 27, 'समूह का चयन किया गया नहीं है'),
(103278, 4002, 27, 'हर्निया नहीं है'),
(103279, 4005, 27, 'कोई चोट / बीमारी नहीं है'),
(103280, 4006, 27, 'बीमा कंपनियों नहीं मिला'),
(103281, 4007, 27, 'कोई मुद्दे नहीं'),
(103282, 4008, 27, 'इस मुठभेड़ में कोई मुद्दे नहीं'),
(103283, 4009, 27, 'चयनित श्रेणी में कोई आइटम नहीं'),
(103284, 4010, 27, 'कोई आइटम चयन किया गया नहीं था!'),
(103285, 4025, 27, 'कोई लॉग फ़ाइल चयनित तिथि के लिए मौजूद नहीं हैं'),
(103286, 4027, 27, 'masses, tenderness नहीं है'),
(103287, 4028, 27, 'Re Idenitification कोड के लिए कोई रोगी रिकॉर्ड नहीं मिला'),
(103288, 4029, 27, 'कोई मेल नहीं मिला. फिर से प्रयास करें.'),
(103289, 4030, 27, 'कोई मेल नहीं मिला'),
(103290, 4031, 27, 'कोई मेल नहीं मिला. अब नए रोगी बनाएँ?'),
(103291, 4032, 27, 'मेल खाता रिकॉर्ड नहीं पाया'),
(103292, 4033, 27, 'नया परिणाम नहीं मिला'),
(103293, 4034, 27, 'नोट नहीं है'),
(103294, 4035, 27, 'ogrganomegoly नहीं है'),
(103295, 4036, 27, 'इस अवधि के लिए अवसर नहीं पाए गए.'),
(103296, 4037, 27, 'अन्य फोन नंबर सूचीबद्ध नहीं'),
(103297, 4039, 27, 'पार्टनर्स नहीं मिले'),
(103298, 4040, 27, 'दिए चयन मानदंड के लिए कोई रोगी रिकॉर्ड नहीं मिला'),
(103299, 4041, 27, 'Re identification कोड के लिए कोई रोगी रिकॉर्ड नहीं मिला'),
(103300, 4042, 27, 'कोई परिधीय शोफ नहीं है'),
(103301, 4043, 27, 'फ़ार्मेसियां नहीं मिली'),
(103302, 4044, 27, 'नुस्खे नहीं मिले'),
(103303, 4045, 27, 'बीमारी / चोट नहीं है'),
(103304, 4046, 27, 'पिछली प्रविष्टियां नहीं है.'),
(103305, 4047, 27, 'सुविधा सूची में कोई प्राथमिक व्यापार इकाई चयनित नहीं है'),
(103306, 4048, 27, 'कोई पूर्व मुठभेड़ नहीं है.'),
(103307, 4049, 27, 'इस मुठभेड़ में कोई प्रक्रिया नहीं है.'),
(103308, 4051, 27, 'प्रदाता नहीं मिला'),
(103309, 4052, 27, 'लाल चकत्ते या असामान्य घाव नहीं है.'),
(103310, 4053, 27, 'रिकॉर्ड नहीं मिला'),
(103311, 4055, 27, 'कोई रिकॉर्ड नहीं मिला. आपके खोज मानदंडों का विस्तार करें.'),
(103312, 4056, 27, 'कोई अनुस्मारक नहीं है'),
(103313, 4057, 27, 'ऊपर के खोज मापदंड के लिए कोई परिणाम नहीं मिला.'),
(103314, 4058, 27, 'कोई परिणाम नहीं है'),
(103315, 4059, 27, 'कोई परिणाम नहीं मिले'),
(103316, 4060, 27, 'खोज के लिए कोई परिणाम नहीं मिले'),
(103317, 4061, 27, 'कोई परिणाम नहीं मिले, पुन: प्रयास करें.'),
(103318, 4062, 27, 'कोई परिणाम नहीं, कृपया पुनः प्रयास करें.'),
(103319, 4063, 27, 'कोई परिणाम नहीं, कृपया पुनः प्रयास करें.'),
(103320, 4065, 27, 'नहीं दिखाएँ'),
(103321, 4067, 27, 'साइनस Tenderness नहीं है:'),
(103322, 4068, 27, 'त्वचा प्रगर्तन या स्तन पिंड नहीं है:'),
(103323, 4069, 27, 'ऐसी कोई संदर्भ नाम नहीं है:'),
(103324, 4070, 27, 'कोई तालिका चयनित नहीं है! टेबल चुनें.'),
(103325, 4071, 27, 'कोई वृषण Tenderness नहीं है, masses'),
(103326, 4072, 27, 'कोई रोमांच या पलीता नहीं है'),
(103327, 4075, 27, 'कोई यात्रा नहीं है'),
(103328, 4076, 27, 'कोई नब्ज दर्ज किया गया नहीं है.'),
(103329, 4077, 27, 'नहीं, रद्द'),
(103330, 4078, 27, 'कोई बीमा गलती नहीं है ऑटो प्राथमिक है'),
(103331, 4079, 27, 'नहीं:'),
(103332, 4080, 27, 'निशामेह'),
(103333, 4081, 27, 'भुगतान नहीं'),
(103334, 4082, 27, 'गैर प्रतिवेदित रिपोर्ट'),
(103335, 4083, 27, 'गैर विशिष्ट चोट'),
(103336, 4084, 27, 'गैर इलेक्ट्रॉनिक'),
(103337, 4085, 27, 'गैर इंसुलिन निर्भर मधुमेह'),
(103338, 4086, 27, 'गैर बीमाकृत'),
(103339, 4087, 27, 'गैर SRH मेडिकल'),
(103340, 4088, 27, 'गैर SRH गैर मेडिकल'),
(103341, 4089, 27, 'कोई नहीं'),
(103342, 4090, 27, 'कोई नहीं'),
(103343, 4091, 27, 'कोई भी परिभाषित नहीं किया'),
(103344, 4092, 27, 'कोई भी प्रलेखित नहीं किया गया है'),
(103345, 4093, 27, 'उपरोक्त में से कोई भी नहीं'),
(103346, 4094, 27, 'शीर्ष वितरण पंक्ति में से कोई भी पूरी तरह से खाली नहीं हो सकता है.'),
(103347, 4095, 27, 'गैरइंसुलिन निर्भर मधुमेह'),
(103348, 4096, 27, 'Nor'),
(103349, 4097, 27, 'सामान्य'),
(103350, 4098, 27, 'सामान्य BL'),
(103351, 4099, 27, 'सामान्य कार्डिएक परीक्षा:'),
(103352, 4100, 27, 'सामान्य कार्डिएक परीक्षा: '),
(103353, 4101, 27, 'सामान्य फेफड़ों परीक्षा:'),
(103354, 4102, 27, 'सामान्य फेफड़ों परीक्षा: '),
(103355, 4103, 27, 'सामान्य कार्यालय यात्रा'),
(103356, 4104, 27, 'सामान्य oropharynx:'),
(103357, 4105, 27, 'सामान्य दाएँ'),
(103358, 4106, 27, 'सामान्य दाएँ:'),
(103359, 4107, 27, 'सामान्य दृश्य'),
(103360, 4108, 27, 'सामान्य:'),
(103361, 4109, 27, 'आम तौर पर इसकी जाँच की जानी चाहिए. अभिगम नियंत्रण से संबंधित नहीं है.'),
(103362, 4112, 27, 'नार्वेजियन'),
(103363, 4115, 27, 'नाक'),
(103364, 4116, 27, 'नकसीर'),
(103365, 4117, 27, 'एक अक्षर या संख्या नहीं'),
(103366, 4119, 27, 'सभी क्षेत्रों सभी कोड या कोड प्रकार के लिए आवश्यक नहीं हैं.'),
(103367, 4120, 27, 'अनुमति नहीं'),
(103368, 4121, 27, 'व्यवस्थापकों के समूह को नष्ट करने की अनुमति नहीं'),
(103369, 4122, 27, 'संपादित करने की अनुमति नहीं'),
(103370, 4123, 27, 'सभी सुरक्षा वस्तुओं को निष्क्रिय करने की अनुमति नहीं'),
(103371, 4124, 27, 'व्यवस्थापकों के ACL से कुछ भी निष्क्रिय करने की अनुमति नहीं'),
(103372, 4125, 27, 'व्यवस्थापकों के समूह से व्यवस्थापक उपयोगकर्ता को हटाने की अनुमति नहीं'),
(103373, 4126, 27, 'व्यवस्थापकों के समूह से इस उपयोगकर्ता को हटाने की अनुमति नहीं'),
(103374, 4127, 27, 'लागू नहीं'),
(103375, 4128, 27, 'PostCalendar मॉड्यूल का उपयोग करने के लिए अधिकृत नहीं'),
(103376, 4129, 27, 'अनुमति नहीं'),
(103377, 4130, 27, 'अधिकृत नहीं'),
(103378, 4131, 27, 'इस दस्ते के लिए अधिकृत नहीं!'),
(103379, 4132, 27, 'इस दस्ते के लिए अधिकृत नहीं है.'),
(103380, 4133, 27, 'उपयोगकर्ताओं को प्रबंधित करने के लिए अधिकृत नहीं!'),
(103381, 4134, 27, 'परिणामों पर हस्ताक्षर के लिए अधिकृत नहीं'),
(103382, 4135, 27, 'उपलब्ध नहीं'),
(103383, 4137, 27, 'बिल नहीं भेजा'),
(103384, 4138, 27, 'जाँच नहीं की'),
(103385, 4139, 27, 'बाहर नहीं गए'),
(103386, 4140, 27, 'कोडित नहीं'),
(103387, 4141, 27, 'देय नहीं'),
(103388, 4143, 27, 'जांच नहीं की'),
(103389, 4144, 27, 'जांच नहीं की:'),
(103390, 4145, 27, 'जांच नहीं की: '),
(103391, 4146, 27, 'नहीं मिला'),
(103392, 4148, 27, 'नहीं मिला!'),
(103393, 4149, 27, 'हिस्पैनिक या लैटिनो नहीं'),
(103394, 4150, 27, 'स्थापित नहीं'),
(103395, 4152, 27, 'के बाद नहीं देखा'),
(103396, 4153, 27, 'नहीं भेजा'),
(103397, 4154, 27, 'अभी तक नहीं भेजा'),
(103398, 4155, 27, 'निर्दिष्ट नहीं'),
(103399, 4156, 27, 'निर्दिष्ट नहीं.'),
(103400, 4157, 27, 'टिप्पणी'),
(103401, 4158, 27, 'संहिताएं टिप्पणी'),
(103402, 4159, 27, 'ध्यान दें स्थापित क्लिक करने के बाद पूरी तरह से संसाधित करने के लिए यह 5-10 मिनट का समय ले लेगा'),
(103403, 4160, 27, 'ध्यान दें उन्नयन क्लिक करने के बाद पूरी तरह से संसाधित करने के लिए यह 5-10 मिनट का समय ले लेगा'),
(103404, 4161, 27, 'ऑडिट लॉगिंग सक्रिय करने की जरूरत पर ध्यान दें'),
(103405, 4162, 27, 'ध्यान दें प्रकार'),
(103406, 4163, 27, 'ध्यान दें: 12:00 दोपहर अपराह्न है,पूर्वाह्न नहीं'),
(103407, 4164, 27, 'ध्यान दें: अपने हार्डवेयर विन्यास के आधार पर बाहरी डेटा आयात को एक घंटे से भी अधिक समय लग सकता है. उदाहरण के लिए, RxNorm डेटा तालिकाओं में 6 मिलियन पंक्तियों से अधिक होते हैं.'),
(103408, 4165, 27, 'ध्यान दें: केवल द्विवार्षिक अंतर्राष्ट्रीय Snomed रिलीज वर्तमान में समर्थित है'),
(103409, 4166, 27, 'ध्यान दें: केवल पूर्ण मासिक RxNorm रिलीज वर्तमान में समर्थित है'),
(103410, 4168, 27, 'ध्यान दें: यह कोड एक अधिकृत उपयोगकर्ता द्वारा दर्ज नहीं किया गया था.प्रसंस्करण के लिए केवल अधिकृत कोड ओपन चिकित्सा बिलिंग नेटवर्क पर अपलोड किया जा सकता है. आप इन कोड को अपलोड करना चाहते हैं, तो यहाँ एक अधिकृत उपयोगकर्ता का चयन करें.'),
(103411, 4170, 27, 'ध्यान दें: यदि आप नकली नामों के साथ फाइल अपलोड करते हैं तो स्वचालित रूप से फ़ाइल का नाम बदल दिया जाएगा (उदाहरण के लिए, file.jpg file.1.jpg हो जाएगा). Filenames , रोगी के प्रति अनूठा माना जाता है श्रेणी के अनुसार नहीं.'),
(103412, 4171, 27, 'ध्यान दें: यदि आप नकली नामों के साथ फाइल अपलोड करते हैं तो स्वचालित रूप से फ़ाइल का नाम बदल दिया जाएगा उदाहरण के लिए ''<i> file.jpg </ i>'' <i> file.jpg.1 </ i> '' बन जाएगा. Filenames , रोगी के प्रति अनूठा माना जाता है श्रेणी के अनुसार नहीं.'),
(103413, 4172, 27, 'टिप्पणी'),
(103414, 4173, 27, 'टिप्पणी - किसी भी मुठभेड़ों के (addonly वैकल्पिक लिखने,)'),
(103415, 4174, 27, 'टिप्पणी - मेरे मुठभेड़ों के (addonly वैकल्पिक लिखने)'),
(103416, 4175, 27, 'टिप्पणी अधिकृत नहीं'),
(103417, 4177, 27, 'रिकॉर्ड कुछ भी नहीं'),
(103418, 4179, 27, 'एलर्जी के लिए आयात करने के लिए कुछ भी नहीं'),
(103419, 4180, 27, 'पर्चे के लिए आयात करने के लिए कुछ भी नहीं'),
(103420, 4181, 27, 'दिखाने के लिए कुछ भी नहीं'),
(103421, 4182, 27, 'कुछ भी नहीं चुना गया था'),
(103422, 4184, 27, 'सूचना :: PostCalendar सबमिशन / संशोधन'),
(103423, 4185, 27, 'सूचना'),
(103424, 4186, 27, 'सूचना ईमेल पता'),
(103425, 4188, 27, 'सूचनाएं'),
(103426, 4189, 27, 'घटना सबमिशन / संशोधन के बारे में व्यवस्थापक को सूचित करें?'),
(103427, 4190, 27, 'नवम्बर'),
(103428, 4191, 27, 'नवम्बर'),
(103429, 4192, 27, 'अब के लिए पोस्टिंग:'),
(103430, 4193, 27, 'अब छपाई कर रहा है'),
(103431, 4194, 27, 'अब $ stmt_count बयान छपाई और मुठभेड़ों का अद्यतन कर रहा है.'),
(103432, 4195, 27, 'अब $ stmt_count बयान छपाई और चालान अद्यतन कर रहा है.'),
(103433, 4196, 27, 'अब $ stmt_count बयान छपाई, मुठभेड़ों का अद्यतन नहीं किया जाएगा.'),
(103434, 4197, 27, 'अब $ stmt_count बयान छपाई, चालान अद्यतन नहीं किया जाएगा.'),
(103435, 4198, 27, 'NPI'),
(103436, 4199, 27, 'NQF'),
(103437, 4200, 27, 'संख्या'),
(103438, 4201, 27, 'संख्या लैब्स'),
(103439, 4204, 27, 'वर्ष दृश्य में स्तंभों की संख्या.'),
(103440, 4211, 27, 'ग्राहक प्रमाणपत्र वैध होने कि दिनों की संख्या.'),
(103441, 4213, 27, 'मुद्रा के लिए दशमलव बिंदु के बाद अंकों की संख्या, आमतौर पर 0 या 2.'),
(103442, 4214, 27, 'प्रति पृष्ठ प्रदर्शित करने के लिए मुठभेड़ों की संख्या.'),
(103443, 4215, 27, 'चूक गए, खेल या घटनाओं की संख्या, यदि कोई हो'),
(103444, 4216, 27, 'ईमेल सूचना भेजने के लिए अग्रिम में घंटे की संख्या.'),
(103445, 4217, 27, 'फोन अधिसूचना भेजने के लिए अग्रिम में घंटे की संख्या.'),
(103446, 4218, 27, 'एसएमएस सूचनाएं भेजने के लिए अग्रिम में घंटे की संख्या.'),
(103447, 4221, 27, 'अतीत के इतिहास के स्तम्भों की संख्या'),
(103448, 4222, 27, 'रोगी सूची में प्रति पृष्ठ प्रदर्शित करने के लिए रोगियों की संख्या.'),
(103449, 4223, 27, 'सुन्नता'),
(103450, 4224, 27, 'अंश'),
(103451, 4225, 27, 'संख्यात्मक प्रदर्शन का क्रम'),
(103452, 4227, 27, 'पोषण'),
(103453, 4229, 27, 'O.A.F.V.'),
(103454, 4230, 27, 'O2 Sat'),
(103455, 4231, 27, 'मोटापा I'),
(103456, 4232, 27, 'मोटापा II'),
(103457, 4233, 27, 'मोटापा III'),
(103458, 4234, 27, 'लक्ष्य'),
(103459, 4237, 27, 'व्यवसाय'),
(103460, 4239, 27, 'घटना'),
(103461, 4240, 27, 'अक्टूबर'),
(103462, 4241, 27, 'अक्टूबर'),
(103463, 4242, 27, 'OD'),
(103464, 4243, 27, 'की'),
(103465, 4244, 27, 'मात्रा की'),
(103466, 4245, 27, 'गोलियों की'),
(103467, 4246, 27, 'महीने के हर'),
(103468, 4247, 27, 'OFC नोट्स'),
(103469, 4248, 27, 'बंद'),
(103470, 4249, 27, 'कार्यालय नोट्स'),
(103471, 4250, 27, 'कार्यालय यात्रा'),
(103472, 4251, 27, 'आधिकारिक क्लीनिकल क्वालिटी उपाय (CQM) उपाय समूह'),
(103473, 4252, 27, 'रोगी पोर्टल के लिए offsite Https लिंक.'),
(103474, 4253, 27, 'रोगी पोर्टल के लिए offsite Https लिंक. (रोगी लिंक)'),
(103475, 4254, 27, 'Offsite रोगी पोर्टल पारण'),
(103476, 4255, 27, 'Offsite रोगी पोर्टल पारण(पंजीकृत नहीं तो रिक्त डाल).'),
(103477, 4256, 27, 'Offsite रोगी पोर्टल प्रदाता ID'),
(103478, 4257, 27, 'Offsite रोगी पोर्टल प्रदाता ID (पंजीकृत नहीं तो रिक्त डाल).'),
(103479, 4258, 27, 'Offsite रोगी पोर्टल साइट पता'),
(103480, 4259, 27, 'Offsite रोगी पोर्टल साइट पता (रोगी लिंक)'),
(103481, 4260, 27, 'Offsite रोगी पोर्टल उपयोगकर्ता नाम'),
(103482, 4261, 27, 'Offsite रोगी पोर्टल उपयोगकर्ता नाम (पंजीकृत नहीं तो रिक्त डाल).'),
(103483, 4263, 27, 'वंशज'),
(103484, 4265, 27, 'मरहम'),
(103485, 4267, 27, 'ठीक है'),
(103486, 4269, 27, 'दिनांक GCAC मुद्दे से जोड़ने के लिए ठीक है'),
(103487, 4270, 27, 'पुराना'),
(103488, 4272, 27, 'पुराने ग्राहकों के'),
(103489, 4273, 27, 'पुरानी फ्रैक्चर गैर / कुसम्मिलन'),
(103490, 4274, 27, 'बाएँ मेनू के बिना पुरानी शैली लेआउट'),
(103491, 4275, 27, 'खोज या दोहराव जाँच के बिना पुरानी शैली स्थिर फार्म'),
(103492, 4277, 27, 'छोड़ दे'),
(103493, 4278, 27, 'परिधियों छोड़ दे'),
(103494, 4279, 27, 'रोगी जनसांख्यिकी में नियोक्ता जानकारी छोड़ दे'),
(103495, 4280, 27, 'नियोक्ता छोड़ दे'),
(103496, 4281, 27, 'रूप, मार्ग और अंतराल छोड़ दे, जो खुराक का हिस्सा बन गया'),
(103497, 4282, 27, 'जनसांख्यिकी रूप से बीमा और कुछ अन्य चीजों को छोड़ दे'),
(103498, 4283, 27, 'आंतरिक उपयोगकर्ताओं छोड़ दे?'),
(103499, 4284, 27, 'सह भुगतान पैनल से भुगतान की विधि छोड़ दे'),
(103500, 4285, 27, 'autoassign को छोड़ दे'),
(103501, 4286, 27, 'पर'),
(103502, 4287, 27, 'पर'),
(103503, 4288, 27, 'हाथ में'),
(103504, 4289, 27, 'आदेश पर'),
(103505, 4290, 27, 'साइट पर'),
(103506, 4291, 27, 'प्राथमिक व्यापार सुविधा एक बार स्थापित किया तो यह बदलना नहीं चाहिए. सुविधा को बदलना NewCrop ePrescription के कार्यकरण को प्रभावित करेगा.'),
(103507, 4292, 27, 'यदि आप अपना पासवर्ड बदल लें, तो आपको फिर से लॉगिन करना होगा.'),
(103508, 4297, 27, 'ऑनलाइन सहायता'),
(103509, 4298, 27, 'ऑनलाइन सहायता लिंक'),
(103510, 4299, 27, 'केवल सक्रिय'),
(103511, 4300, 27, 'Only applicable if a provider or collated list was chosen above. PRIMARY only selects patients that the provider is the primary provider. ENCOUNTER selects all patients that the provider has seen.'),
(103512, 4302, 27, 'अगर केवल बिलिंग स्थान'),
(103513, 4303, 27, 'केवल निष्क्रिय'),
(103514, 4304, 27, 'केवल मेरा'),
(103515, 4305, 27, 'केवल निदान रिपोर्टिंग संहिताएं दिखाएँ'),
(103516, 4306, 27, 'केवल सेवा संहिता वित्त संहिताओं रिपोर्टिंग दिखाएँ'),
(103517, 4307, 27, 'केवल सक्रिय नुस्खे अपलोड करें'),
(103518, 4310, 27, 'बीमारी की शुरुआत:'),
(103519, 4311, 27, 'बीमारी की शुरुआत: '),
(103520, 4312, 27, 'सूजन की शुरुआत:'),
(103521, 4313, 27, 'शुरुआत / अस्पताल. तिथि:'),
(103522, 4314, 27, 'ऑनसाइट रोगी पोर्टल साइट पता');
INSERT INTO `lang_definitions` VALUES
(103523, 4315, 27, 'उफ़!'),
(103524, 4316, 27, 'खुला'),
(103525, 4318, 27, 'नई विंडो में खोलें'),
(103526, 4321, 27, 'खोलें आज की भेंट'),
(103527, 4322, 27, 'LibreEHR में पहले से ही एक प्रमाणपत्र प्राधिकार कॉन्फ़िगर है.'),
(103528, 4323, 27, 'LibreEHR आवेदन श्रेणी'),
(103529, 4324, 27, 'LibreEHR डेटाबेस नवीनीकरण'),
(103530, 4325, 27, 'De-IDENTIFICATION के लिए LibreEHR डेटाबेस नवीनीकरण'),
(103531, 4326, 27, 'LibreEHR योगदान निर्देशिका में आने वाली फ़ाइल को नहीं पहचानता है. क्योंकि संभावना यह है, आपको MySQL डाटाबेस में supported_external_dataloads तालिका के रिलीज, विन्यस्त करने की जरूरत है.'),
(103532, 4327, 27, 'क्लाइंट प्रमाण पत्र बनाने से पहले LibreEHR प्रमाण पत्र का उपयोग करने के लिए कॉन्फ़िगर किया जाना चाहिए.'),
(103533, 4328, 27, 'LibreEHR को उपयोगकर्ता प्रमाणीकरण करने के लिए जावास्क्रिप्ट की आवश्यकता है.'),
(103534, 4329, 27, 'LibreEHR उपयोगकर्ता'),
(103535, 4330, 27, 'उद्घाटन'),
(103536, 4332, 27, 'ऑप्थाल्मिक'),
(103537, 4333, 27, 'विकल्प'),
(103538, 4334, 27, 'दस्तावेज़ भंडारण की पद्धति सहेजने के लिए विकल्प.'),
(103539, 4335, 27, 'उत्पादों की बिक्री और सूची का समर्थन करने के विकल्प'),
(103540, 4336, 27, 'वैकल्पिक'),
(103541, 4337, 27, 'आईडी कार्ड छवि के लिए वैकल्पिक श्रेणी नाम, रोगी सारांश पृष्ठ पर देखा जा सकता है.'),
(103542, 4338, 27, 'फोटो छवियों के लिए वैकल्पिक श्रेणी नाम रोगी सारांश पृष्ठ में देखा जा सकता है'),
(103543, 4339, 27, 'रोगी सारांश पेज से लिंक करने के लिए एक दस्तावेज़ का वैकल्पिक श्रेणी नाम. आपको उनके आईडी कार्ड देखने के लिए एक रोगी के नाम पर क्लिक करने देता है.'),
(103544, 4340, 27, 'परिणामों को मैनुअल प्रविष्टि करने के लिए वैकल्पिक डिफॉल्ट सीमा'),
(103545, 4341, 27, 'परिणामों को मैनुअल प्रविष्टि करने के लिए वैकल्पिक डिफॉल्ट इकाइयों'),
(103546, 4342, 27, 'वैकल्पिक गंतव्य नाम'),
(103547, 4343, 27, 'वैकल्पिक दवा के नाम, % का उपयोग वाइल्डकार्ड के रूप में करें'),
(103548, 4345, 27, 'इस घटना के बारे में वैकल्पिक जानकारी'),
(103549, 4346, 27, 'वैकल्पिक lot संख्या, % का उपयोग वाइल्डकार्ड के रूप में करें'),
(103550, 4347, 27, 'वैकल्पिक सांख्यिक रोगी ID'),
(103551, 4348, 27, 'वैकल्पिक प्रक्रिया संहिता'),
(103552, 4349, 27, 'वैकल्पिक प्रक्रिया / सेवा संहिता'),
(103553, 4350, 27, 'विकल्प'),
(103554, 4351, 27, 'या'),
(103555, 4352, 27, 'या'),
(103556, 4353, 27, 'या चयन करें'),
(103557, 4354, 27, 'या खींचें और क्लिक करें तेजी से चयन के लिए .'),
(103558, 4356, 27, 'या बाहर करने के लिए'),
(103559, 4358, 27, 'या इसे कम करने के लिए Shift-क्लिक करें'),
(103560, 4359, 27, 'या ERA फाइल अपलोड करें:'),
(103561, 4360, 27, 'मौखिक'),
(103562, 4361, 27, 'मौखिक mucosa गुलाबी, गला साफ'),
(103563, 4362, 27, 'आदेश'),
(103564, 4363, 27, 'आदेश और परिणाम के प्रकार'),
(103565, 4364, 27, 'आदेश सूची'),
(103566, 4365, 27, 'आदेश तिथि'),
(103567, 4367, 27, 'से आदेश'),
(103568, 4368, 27, 'आदेश ID'),
(103569, 4369, 27, 'आदेश 1 और 999 के बीच में होनी चाहिए'),
(103570, 4370, 27, 'आदेश नाम'),
(103571, 4371, 27, 'आदेश प्राथमिकताएं'),
(103572, 4372, 27, 'आदेश संसाधक'),
(103573, 4373, 27, 'आदेश परिणाम'),
(103574, 4374, 27, 'आदेश स्थिति'),
(103575, 4375, 27, 'आदेश की स्थिती'),
(103576, 4376, 27, 'आदेश सारांश'),
(103577, 4378, 27, 'आदेश के प्रकार'),
(103578, 4380, 27, 'आदेश / परिणाम प्रकार'),
(103579, 4381, 27, 'आदेशित'),
(103580, 4382, 27, 'द्वारा आदेश'),
(103581, 4383, 27, 'आदेश दिए प्रक्रिया'),
(103582, 4384, 27, 'आदेश देते प्रदाता'),
(103583, 4385, 27, 'आदेश पथ'),
(103584, 4386, 27, 'अंग चोट'),
(103585, 4387, 27, 'संगठन'),
(103586, 4388, 27, 'संगठन का नाम'),
(103587, 4389, 27, 'संगठन इकाई का नाम'),
(103588, 4390, 27, 'संगठन'),
(103589, 4391, 27, 'केंद्रित x 3'),
(103590, 4392, 27, 'मूल'),
(103591, 4396, 27, 'oropharynx: '),
(103592, 4397, 27, 'Orthopnea'),
(103593, 4398, 27, 'OS'),
(103594, 4399, 27, 'Osetoarthritis'),
(103595, 4402, 27, 'अन्य'),
(103596, 4403, 27, 'अन्य'),
(103597, 4404, 27, 'अन्य ( निर्दिष्ट करें)'),
(103598, 4405, 27, 'अन्य - निर्दिष्ट'),
(103599, 4406, 27, 'अन्य संघीय कार्यक्रम'),
(103600, 4407, 27, 'अन्य HCFA'),
(103601, 4408, 27, 'अन्य चोट कहीं निर्दिष्ट नहीं'),
(103602, 4409, 27, 'अन्य देयता बीमा प्राथमिक है'),
(103603, 4410, 27, 'अन्य महीने'),
(103604, 4411, 27, 'अन्य गैर संघीय कार्यक्रमों'),
(103605, 4412, 27, 'अन्य नोट्स'),
(103606, 4413, 27, 'अन्य प्रासंगिक लक्षण'),
(103607, 4414, 27, 'अन्य प्रासंगिक लक्षण:'),
(103608, 4415, 27, 'अन्य pt resp'),
(103609, 4416, 27, 'अन्य तनाव / अतिरिक्त उपयोग चोट'),
(103610, 4417, 27, 'अन्य सर्जिकल'),
(103611, 4418, 27, 'अन्य / सामान्य गर्भपात से संबंधित'),
(103612, 4420, 27, 'दूसरों के'),
(103613, 4421, 27, 'अन्यथा आप मौजूदा डेटा से / संदर्भ नष्ट कर देंगे.'),
(103614, 4422, 27, 'ओटावा टखने नियम'),
(103615, 4423, 27, 'OU'),
(103616, 4424, 27, 'बाहर'),
(103617, 4425, 27, 'कार्यालय से बाहर'),
(103618, 4426, 27, 'आउटबाउंड रेफरल'),
(103619, 4427, 27, 'परिणाम'),
(103620, 4428, 27, 'दृष्टिकोण'),
(103621, 4430, 27, 'छुट्टी की समग्र स्थिति'),
(103622, 4431, 27, 'अतिदेय'),
(103623, 4432, 27, 'अति प्रयोग'),
(103624, 4433, 27, 'अवलोकन'),
(103625, 4434, 27, 'अधिक वजन'),
(103626, 4435, 27, 'HIPAA चुनाव अधिलेखित करें'),
(103627, 4437, 27, 'ऑक्सीजन संतृप्ति'),
(103628, 4438, 27, 'oz'),
(103629, 4439, 27, 'P'),
(103630, 4440, 27, 'p.c.'),
(103631, 4441, 27, 'दोपहर बाद'),
(103632, 4442, 27, 'p.r.n.'),
(103633, 4443, 27, 'प्रशांत द्वीप'),
(103634, 4444, 27, 'Paedeatric'),
(103635, 4445, 27, 'पृष्ठ'),
(103636, 4446, 27, 'पृष्ठों के'),
(103637, 4447, 27, 'भुगतान किया'),
(103638, 4448, 27, 'आप भुगतान की गई राशि की अनुमति दे देंगे'),
(103639, 4449, 27, 'भुगतान की गई राशि'),
(103640, 4450, 27, 'के माध्यम से भुगतान'),
(103641, 4451, 27, 'दर्द'),
(103642, 4453, 27, 'घबराहट'),
(103643, 4455, 27, 'पैप स्मीयर'),
(103644, 4456, 27, 'काग़ज़'),
(103645, 4457, 27, 'पेपर आकार'),
(103646, 4458, 27, 'पक्षाघात'),
(103647, 4461, 27, 'विश्लेषण HL7'),
(103648, 4463, 27, 'साथी'),
(103649, 4464, 27, 'साथी का नाम'),
(103650, 4467, 27, 'वाक्यांश पास करें'),
(103651, 4468, 27, 'दस्तावेज को डिक्रिप्ट करने के लिए वाक्यांश पास करें'),
(103652, 4469, 27, 'मृत रोगी'),
(103653, 4470, 27, 'निष्क्रिय चेतावनी'),
(103654, 4471, 27, 'निष्क्रिय चेतावनी नियम'),
(103655, 4472, 27, 'पासवर्ड'),
(103656, 4473, 27, 'पासवर्ड परिवर्तन करें'),
(103657, 4474, 27, 'पासवर्ड परिवर्तन सफल'),
(103658, 4475, 27, 'पासवर्ड परिवर्तन सफल'),
(103659, 4476, 27, 'पासवर्ड न्यूनतम आवश्यकताओं को पूरा नहीं करता है और चार निम्न वस्तुओं में से कम से कम तीन को शामिल करना चाहिए: एक नंबर, एक लोअरकेस अक्षर, एक अपरकेस अक्षर, एक विशेष चरित्र (एक अक्षर या संख्या नहीं).'),
(103660, 4477, 27, 'पासवर्ड समाप्त ग्रेस अवधि'),
(103661, 4479, 27, 'फोन प्रवेश द्वार के लिए पासवर्ड. Maviq द्वारा स्वचालित VOIP सेवा प्रदान की . अधिक जानकारी के लिए http://signup.maviq.com जाएँ.'),
(103662, 4480, 27, 'SMS गेटवे के लिए पासवर्ड'),
(103663, 4481, 27, 'SMS गेटवे के लिए पासवर्ड.'),
(103664, 4483, 27, 'पासवर्ड सुरक्षा हाल ही में उन्नत किया गया है.'),
(103665, 4484, 27, 'CouchDB से कनेक्ट करने के लिए पासवर्ड'),
(103666, 4485, 27, 'बहुत छोटा पासवर्ड . आवश्यक न्यूनतम 8 वर्ण.'),
(103667, 4486, 27, 'पासवर्ड:'),
(103668, 4487, 27, 'पासवर्ड मेल नहीं खाते!'),
(103669, 4488, 27, 'अतीत Appoinments'),
(103670, 4489, 27, 'अतीत नियुक्तियां प्रदर्शन विजेट'),
(103671, 4490, 27, 'पिछला देय'),
(103672, 4491, 27, 'पिछला देय'),
(103673, 4492, 27, 'पिछला देय अंतराल (क्लीनिकल अनुस्मारक)'),
(103674, 4493, 27, 'पिछला देय अंतराल (रोगी अनुस्मारक)'),
(103675, 4494, 27, 'अतीत मुठभेड़ सूची'),
(103676, 4495, 27, 'अतीत मुठभेड़'),
(103677, 4496, 27, 'अतीत मुठभेड़ और दस्तावेज'),
(103678, 4497, 27, 'के लिए अतीत मुठभेड़'),
(103679, 4498, 27, 'HL7 डेटा चिपकाएँ'),
(103680, 4499, 27, 'नीचे दिए गए पाठ क्षेत्र में आयात करने के लिए डेटा चिपकाएँ:'),
(103681, 4500, 27, 'थपथपाना'),
(103682, 4502, 27, 'पैच'),
(103683, 4508, 27, 'इवेंट लॉग बैकअप के लिए पथ'),
(103684, 4509, 27, 'CA प्रमाणपत्र फ़ाइल के लिए पथ'),
(103685, 4510, 27, 'CA कुंजी फ़ाइल के लिए पथ'),
(103686, 4511, 27, 'MySQL बायनेरिज़ के लिए पथ'),
(103687, 4512, 27, 'पर्ल बायनेरिज़ के लिए पथ'),
(103688, 4513, 27, 'अस्थाई फ़ाइलें के लिए पथ'),
(103689, 4514, 27, 'रोगी'),
(103690, 4515, 27, 'रोगी'),
(103691, 4516, 27, 'रोगी'),
(103692, 4517, 27, 'रोगी का पता'),
(103693, 4518, 27, 'रोगी का पता लापता है'),
(103694, 4521, 27, 'रोगी एलर्जी'),
(103695, 4522, 27, 'रोगी एलर्जी'),
(103696, 4523, 27, 'रोगी की नियुक्ति'),
(103697, 4524, 27, 'रोगी बैलेंस'),
(103698, 4525, 27, 'रोगी देय शेष राशि'),
(103699, 4528, 27, 'रोगी चार्ट आईडी'),
(103700, 4529, 27, 'रोगी चेकआउट'),
(103701, 4530, 27, 'के लिए रोगी चेकआउट '),
(103702, 4531, 27, 'रोगी शहर'),
(103703, 4532, 27, 'रोगी शहर लापता है.'),
(103704, 4533, 27, 'रोगी संचार भेजा'),
(103705, 4534, 27, 'रोगी संचार भेजा'),
(103706, 4535, 27, 'रोगी देश'),
(103707, 4536, 27, 'रोगी देश लापता है. इसके अलावा आप वैश्विक सेटिंग्स में डिफ़ॉल्ट रोगी देश सेट नहीं किया है'),
(103708, 4537, 27, 'रोगी कवरेज'),
(103709, 4539, 27, 'रोगी डेटा'),
(103710, 4541, 27, 'रोगी जन्म तारीख लापता है.'),
(103711, 4542, 27, 'रोगी का विवरण'),
(103712, 4543, 27, 'रोगी जन्म तिथि'),
(103713, 4544, 27, 'रोगी दस्तावेज'),
(103714, 4545, 27, 'रोगी शिक्षा'),
(103715, 4546, 27, 'रोगी शिक्षा सामग्री'),
(103716, 4547, 27, 'रोगी मुठभेड़'),
(103717, 4548, 27, 'रोगी मुठभेड़ पर्चा'),
(103718, 4549, 27, 'रोगी मुठभेड़'),
(103719, 4550, 27, 'रोगी खोजक'),
(103720, 4551, 27, 'रोगी पहला नाम'),
(103721, 4553, 27, 'रोगी पहला नाम लापता है'),
(103722, 4558, 27, 'रोगी लिंग'),
(103723, 4559, 27, 'रोगी लिंग लापता है'),
(103724, 4560, 27, 'रोगी को रोगी पोर्टल अधिकृत नहीं किया गया है.'),
(103725, 4561, 27, 'रोगी इतिहास'),
(103726, 4562, 27, 'रोगी इतिहास / लाइफस्टाइल'),
(103727, 4563, 27, 'रोगी घर फोन'),
(103728, 4564, 27, 'रोगी ID'),
(103729, 4565, 27, 'रोगी ID'),
(103730, 4566, 27, 'रोगी ID कार्ड'),
(103731, 4567, 27, 'रोगी ID श्रेणी का नाम'),
(103732, 4568, 27, 'रोगी टीकाकरण'),
(103733, 4569, 27, 'रोगी सूचना'),
(103734, 4570, 27, 'रोगी निर्देश'),
(103735, 4571, 27, 'रोगी बीमा वितरण'),
(103736, 4572, 27, 'रोगी बीमा वितरण की रिपोर्ट'),
(103737, 4573, 27, 'रोगी समस्याएँ'),
(103738, 4575, 27, 'रोगी अंतिम नाम'),
(103739, 4577, 27, 'रोगी अंतिम नाम लापता है'),
(103740, 4581, 27, 'रोगी सूची'),
(103741, 4582, 27, 'रोगी सूची स्तंभ'),
(103742, 4584, 27, 'रोगी सूची नई विंडो'),
(103743, 4585, 27, 'रोगी सूची पृष्ठ आकार'),
(103744, 4586, 27, 'रोगी देखने का त्रुटियाँ'),
(103745, 4587, 27, 'रोगी मेडिकल समस्याएं'),
(103746, 4588, 27, 'रोगी की दवाएं'),
(103747, 4589, 27, 'रोगी का नाम'),
(103748, 4590, 27, 'रोगी का नाम व पता'),
(103749, 4593, 27, 'रोगी का नाम आवश्यक'),
(103750, 4595, 27, 'रोगी नोट'),
(103751, 4596, 27, 'रोगी नोट के प्रकार'),
(103752, 4597, 27, 'रोगी नोट्स'),
(103753, 4598, 27, 'रोगी नोट्स (, addonly वैकल्पिक लिखने)'),
(103754, 4599, 27, 'रोगी संख्या'),
(103755, 4600, 27, 'रोगी भुगतान'),
(103756, 4602, 27, 'रोगी फोटो श्रेणी का नाम'),
(103757, 4603, 27, 'रोगी पोर्टल'),
(103758, 4605, 27, 'रोगी पोर्टल बंद कर दिया है'),
(103759, 4606, 27, 'रोगी पोर्टल लॉगइन'),
(103760, 4607, 27, 'रोगी पोर्टल वेब पता'),
(103761, 4608, 27, 'रोगी मुद्रित रिपोर्ट'),
(103762, 4609, 27, 'रोगी रिकॉर्ड की रिपोर्ट'),
(103763, 4610, 27, 'रोगी रिकॉर्ड अनुरोध'),
(103764, 4611, 27, 'रोगी रिकॉर्ड अनुरोध'),
(103765, 4613, 27, 'रोगी अनुस्मारक'),
(103766, 4614, 27, 'रोगी अनुस्मारक बैच के कार्य'),
(103767, 4615, 27, 'रोगी अनुस्मारक निर्माण प्रसंस्करण प्राथमिकता'),
(103768, 4616, 27, 'रोगी अनुस्मारक नियम'),
(103769, 4617, 27, 'रोगी अनुस्मारक प्रेषक का ईमेल'),
(103770, 4618, 27, 'रोगी अनुस्मारक प्रेषक का नाम'),
(103771, 4619, 27, 'रोगी अनुस्मारक'),
(103772, 4620, 27, 'रोगी की रिपोर्ट'),
(103773, 4621, 27, 'रोगी अनुरोध'),
(103774, 4622, 27, 'रोगी अनुरोधित मेडिकल रिकॉर्ड्स'),
(103775, 4623, 27, 'रोगी परिणाम'),
(103776, 4624, 27, 'रोगी खोज परिणाम शैली'),
(103777, 4625, 27, 'रोगी खोज / स्क्रीन जोड़ें'),
(103778, 4626, 27, 'रोगी की स्थापना'),
(103779, 4627, 27, 'रोगी स्टेट'),
(103780, 4629, 27, 'रोगी सारांश'),
(103781, 4630, 27, 'रोगी लेनदेन'),
(103782, 4631, 27, 'रोगी पिन'),
(103783, 4632, 27, 'आपके द्वारा दर्ज, जनसांख्यिकीय जानकारी से मेल खाने वाल रोगी डेटाबेस में.'),
(103784, 4633, 27, 'रोगी / ग्राहक'),
(103785, 4634, 27, 'रोगी:'),
(103786, 4635, 27, 'PatientID'),
(103787, 4636, 27, 'रोगियों के'),
(103788, 4637, 27, 'प्रसंस्कृत रोगियों के'),
(103789, 4638, 27, 'वेतन'),
(103790, 4639, 27, 'Pay attention to the "Done with" checkboxes. After the insurances are marked complete then we will start asking the patient to pay the remaining balance; if you fail to mark all of the insurances complete then the remaining amount will not be collected! Also if there is a balance that the patient should pay, then set the due date appropriately, as this will affect the language that appears on patient statements.'),
(103791, 4640, 27, 'भुगतान तिथिें:'),
(103792, 4641, 27, 'वेतन स्थिति'),
(103793, 4642, 27, 'प्राप्तकर्ता का नाम'),
(103794, 4643, 27, 'दाता'),
(103795, 4644, 27, 'भुगतानकर्ता प्रकार'),
(103796, 4645, 27, 'भर रहे'),
(103797, 4646, 27, 'भर रहे एंटिटी'),
(103798, 4647, 27, 'भुगतान'),
(103799, 4648, 27, 'भुगतान'),
(103800, 4649, 27, 'भुगतान एडजस्टमेंट कोड'),
(103801, 4650, 27, 'के खिलाफ भुगतान'),
(103802, 4651, 27, 'भुगतान राशि'),
(103803, 4652, 27, 'भुगतान राशि संख्यात्मक होनी चाहिए'),
(103804, 4653, 27, 'भुगतान श्रेणी'),
(103805, 4654, 27, 'भुगतान की तिथि'),
(103806, 4655, 27, 'पर भुगतान प्रवेश किया'),
(103807, 4656, 27, 'इससे भुगतान'),
(103808, 4657, 27, 'भुगतान द्वार'),
(103809, 4658, 27, 'भुगतान Ins'),
(103810, 4659, 27, 'भुगतान सूची'),
(103811, 4660, 27, 'भुगतान पद्धति'),
(103812, 4661, 27, 'भुगतान छंटनी करें'),
(103813, 4662, 27, 'भुगतान की स्थिति'),
(103814, 4663, 27, 'भुगतान के प्रकार'),
(103815, 4664, 27, 'कोड के लिए भुगतान मूल्य '),
(103816, 4665, 27, 'भुगतान'),
(103817, 4667, 27, 'PCP'),
(103818, 4668, 27, 'पंक्तियों की pct (%)'),
(103819, 4669, 27, 'PDF'),
(103820, 4670, 27, 'PDF डाउनलोड चयनित वक्तव्य'),
(103821, 4672, 27, 'कमर और कूल्हे'),
(103822, 4673, 27, 'Pemphigus'),
(103823, 4674, 27, 'लंबित'),
(103824, 4676, 27, 'लंबित F / U'),
(103825, 4677, 27, 'लंबित फॉलोअप'),
(103826, 4678, 27, 'परिणाम से फॉलोअप लंबित'),
(103827, 4679, 27, 'लंबित आदेश'),
(103828, 4680, 27, 'लंबित Res'),
(103829, 4681, 27, 'लंबित समीक्षा'),
(103830, 4682, 27, 'लंबित Rx गणना'),
(103831, 4684, 27, 'Pennington फर्म LibreEHR V'),
(103832, 4685, 27, 'पेप्टिक अल्सर रोग'),
(103833, 4686, 27, 'प्रति मुठभेड़'),
(103834, 4687, 27, 'प्रति मिनट'),
(103835, 4688, 27, 'प्रति नथुने'),
(103836, 4689, 27, 'प्रति नथुने'),
(103837, 4690, 27, 'प्रति Oris'),
(103838, 4691, 27, 'प्रति Oris'),
(103839, 4692, 27, 'प्रति मलाशय'),
(103840, 4693, 27, 'प्रति मलाशय'),
(103841, 4694, 27, 'प्रतिशत'),
(103842, 4697, 27, 'प्रतिशतक'),
(103843, 4698, 27, 'छिद्रित दाएँ:'),
(103844, 4699, 27, 'खोज करना'),
(103845, 4700, 27, 'यह क्रिया करें'),
(103846, 4701, 27, 'प्रदर्शन का प्रतिशत'),
(103847, 4703, 27, 'काम कर रही प्रयोगशाला सुविधा'),
(103848, 4705, 27, 'अवधि'),
(103849, 4706, 27, 'दिन में अवधि, जहां एक उपयोगकर्ता समाप्त पासवर्ड के साथ प्रवेश कर सकते हैं.'),
(103850, 4707, 27, 'perioperative देखभाल'),
(103851, 4708, 27, 'परिधीय'),
(103852, 4709, 27, 'अनसाल्टेड पासवर्ड को अनुमति दें'),
(103853, 4710, 27, 'Persian'),
(103854, 4712, 27, 'व्यक्ति'),
(103855, 4713, 27, 'व्यक्तिगत बनाएं'),
(103856, 4714, 27, 'PG'),
(103857, 4715, 27, 'Pharm'),
(103858, 4716, 27, 'Pharm Com गणना'),
(103859, 4717, 27, 'फ़ार्मेसियां'),
(103860, 4718, 27, 'फार्मेसी'),
(103861, 4719, 27, 'फार्मेसी डिस्पेंसरी'),
(103862, 4720, 27, 'Pheumothorax'),
(103863, 4723, 27, 'phiMail संदेश अंतराल की जाँच (मिनट)'),
(103864, 4724, 27, 'phiMail अधिसूचना उपयोगकर्ता'),
(103865, 4725, 27, 'phiMail पारण'),
(103866, 4726, 27, 'phiMail सर्वर पता'),
(103867, 4727, 27, 'phiMail उपयोगकर्ता नाम'),
(103868, 4729, 27, 'फ़ोन'),
(103869, 4730, 27, 'फोन कॉल की सूची'),
(103870, 4731, 27, 'फोन कॉल की सूची की रिपोर्ट'),
(103871, 4733, 27, 'फोन प्रवेश द्वार पारण'),
(103872, 4734, 27, 'फोन प्रवेश द्वार URL'),
(103873, 4735, 27, 'फोन प्रवेश द्वार उपयोगकर्ता नाम'),
(103874, 4737, 27, 'फोन अधिसूचना घंटे'),
(103875, 4738, 27, 'फोन नंबर'),
(103876, 4740, 27, 'प्रकाश की असहनीयता'),
(103877, 4741, 27, 'तस्वीरें'),
(103878, 4742, 27, 'PHP संकुचित'),
(103879, 4743, 27, 'PHP CURL मॉड्यूल अपने सर्वर में सक्षम होना चाहिए.'),
(103880, 4744, 27, 'PHP निकाला'),
(103881, 4745, 27, 'PHP-GACL पहुँच नियंत्रण बंद कर दिया हैं'),
(103882, 4746, 27, 'PHP-GACL स्थापित नहीं है'),
(103883, 4747, 27, 'शारीरिक परीक्षा'),
(103884, 4749, 27, 'चिकित्सक अनुरोध'),
(103885, 4750, 27, 'चिकित्सक हस्ताक्षर'),
(103886, 4752, 27, 'चिकित्सक'),
(103887, 4753, 27, 'चुनना'),
(103888, 4754, 27, 'चुनना'),
(103889, 4755, 27, 'एक CSS थीम उठाओ.'),
(103890, 4756, 27, 'PID'),
(103891, 4757, 27, 'PID ​​(श्रोणि सूजन बीमारी)'),
(103892, 4758, 27, 'गोली आकार'),
(103893, 4759, 27, 'गोलियां'),
(103894, 4760, 27, 'संस्थापित का विकल्प चाहत है, तो निम्न निर्देशिका में डेटाबेस ज़िप फ़ाइल रखें'),
(103895, 4761, 27, 'निम्नलिखित निर्देशिका में डाउनलोड किया ICD 10 डेटाबेस ज़िप फाइल रखें'),
(103896, 4762, 27, 'निम्नलिखित निर्देशिका में डाउनलोड किया ICD 9 डेटाबेस ज़िप फ़ाइल रखें'),
(103897, 4763, 27, 'निम्नलिखित निर्देशिका में डाउनलोड किया RxNorm डेटाबेस ज़िप फ़ाइल रखें'),
(103898, 4764, 27, 'निम्नलिखित निर्देशिका में डाउनलोड किया Snomed डेटाबेस ज़िप फ़ाइल रखें'),
(103899, 4765, 27, 'प्लेसहोल्डर'),
(103900, 4766, 27, 'प्लेसहोल्डर (रिक्त ACLs बनाए रखता है)'),
(103901, 4767, 27, 'सादा पाठ'),
(103902, 4768, 27, 'योजना'),
(103903, 4771, 27, 'योजना का नाम'),
(103904, 4775, 27, 'योजना तैयार'),
(103905, 4779, 27, 'योजना:'),
(103906, 4782, 27, 'योजनाएं'),
(103907, 4784, 27, 'खिलाड़ी'),
(103908, 4785, 27, 'खेलने का स्थान'),
(103909, 4786, 27, 'जानकारी के ऊपर किसी भी गलत है, तो कॉल करें'),
(103910, 4787, 27, 'अपना पासवर्ड बदल दें.'),
(103911, 4788, 27, 'एक फ़ाइल का चयन करें'),
(103912, 4789, 27, 'एक रोगी का चयन करें'),
(103913, 4790, 27, 'सूची से एक वैध चयन करें'),
(103914, 4791, 27, 'एक वैध चयन करें'),
(103915, 4792, 27, 'के लिए एक मूल्य का चयन करें'),
(103916, 4793, 27, 'ऊपर तिथि सीमा मापदंड का चयन करें, और परिणाम देखने के लिए ताज़ा बटन क्लिक करें.'),
(103917, 4794, 27, 'उचित स्वरूपित EDI-271 फ़ाइल का चयन करें'),
(103918, 4795, 27, 'De Identification डेटा डाउनलोड करने के लिए डाउनलोड बटन पर क्लिक करें'),
(103919, 4796, 27, 'De Identification डेटा डाउनलोड करने के लिए डाउनलोड बटन पर क्लिक करें'),
(103920, 4797, 27, 'इस विंडो को बंद करें.'),
(103921, 4798, 27, 'नए नाम की तुलना करें'),
(103922, 4801, 27, 'आगे बढ़ने से पहले निम्न निर्देशिका बनाएँ'),
(103923, 4802, 27, 'इस पर्चे को स्वीकार नहीं करें जब तक यह facimile के माध्यम से प्राप्त न किया जाए'),
(103924, 4803, 27, 'इस पर्चे को स्वीकार नहीं करें जब तक यह facsimile के माध्यम से प्राप्त न किया जाए'),
(103925, 4804, 27, 'आपके ब्राउज़र को रोकने या फिर से लोड करने के बटन का उपयोग न करें जब तक इस पेज के चलने के अधिक से अधिक 10 मिनट गुजर जाए, इससे सर्वर प्रक्रिया पर रोक नहीं होगी और uneccesary संसाधनों की खपत नहीं होगी.'),
(103926, 4805, 27, 'CURL विस्तार सक्रिय करें'),
(103927, 4806, 27, 'OPENSSL विस्तार सक्रिय करें'),
(103928, 4807, 27, 'SOAP विस्तार सक्रिय करें'),
(103929, 4808, 27, 'Xml एक्सटेंशन सक्रिय करें'),
(103930, 4809, 27, 'अंतिम समीक्षा के लिए एक तिथि दर्ज करें.'),
(103931, 4810, 27, 'एक तिथि दर्ज करें.'),
(103932, 4811, 27, 'एक देय तारीख दर्ज करें'),
(103933, 4812, 27, 'एक संदेश दर्ज करें'),
(103934, 4813, 27, 'संख्या और एक दशमलव बिंदु उपयोग कर के एक मौद्रिक राशि दर्ज करें.'),
(103935, 4814, 27, 'एक नया पासवर्ड दर्ज करें'),
(103936, 4815, 27, 'एक शीर्षक दर्ज करें!'),
(103937, 4816, 27, 'ऊपर एक वैध प्रत्यक्ष पता दाखिल करें.'),
(103938, 4819, 27, 'सही Re Identification कोड दर्ज करें'),
(103939, 4821, 27, 'नई खोज स्ट्रिंग दर्ज करें'),
(103940, 4822, 27, 'सही Re Identification कोड दर्ज करें'),
(103941, 4823, 27, 'पासवर्ड दर्ज करें'),
(103942, 4824, 27, 'चेक संख्या भरें'),
(103943, 4825, 27, 'चेक / रेफरी संख्या भरें'),
(103944, 4826, 27, 'तिथि भरें'),
(103945, 4827, 27, 'भुगतान राशि भरें'),
(103946, 4828, 27, 'भुगतान श्रेणी भरें'),
(103947, 4829, 27, 'इससे भुगतान भरें'),
(103948, 4830, 27, 'तिथि तक पोस्ट भरें'),
(103949, 4831, 27, 'जारी रखने से पहले उन्हें भरें.'),
(103950, 4832, 27, 'कृपया दौरे कारण बताएं'),
(103951, 4833, 27, 'कृपया ऊपर खोज मापदंड भरें, और रिपोर्ट शुरू करने के लिए सबमिट क्लिक करें.'),
(103952, 4834, 27, 'कृपया ऊपर खोज मापदंड भरें, और परिणाम देखने के लिए सबमिट क्लिक करें.'),
(103953, 4835, 27, 'कृपया ऊपर खोज मापदंड भरें, और परिणाम देखने के लिए सबमिट क्लिक करें. (परिणाम एक पॉप अप विंडो में प्रदर्शित किया जाएगा)'),
(103954, 4836, 27, 'फिर से लॉगिन करें.'),
(103955, 4837, 27, 'Please note that this can take a very long time, up to several minutes, your web browser may not appear very active during this time but generating a bill is a complicated process and your web browser is merely waiting for more information.'),
(103956, 4838, 27, 'कृपया ध्यान दें: स्थिरांक, केस संवेदनशील है और कोई भी स्ट्रिंग की अनुमति दी गई है.'),
(103957, 4839, 27, 'केवल वर्णमाला के अक्षरों का प्रयोग करें'),
(103958, 4840, 27, 'केवल बिना रिक्त स्थान के वर्णमाला के अक्षरों का प्रयोग करें'),
(103959, 4841, 27, 'इस राशि का भुगतान करें'),
(103960, 4842, 27, 'अपने स्थापित फाइलें निम्न निर्देशिका में रखें'),
(103961, 4843, 27, 'कृपया देखें'),
(103962, 4844, 27, 'पासवर्ड रीसेट करें.'),
(103963, 4845, 27, 'De-identification को चलने से पहले अपाचे सर्वर को पुनः प्रारंभ करें'),
(103964, 4847, 27, 'कृपया चुनें'),
(103965, 4849, 27, 'एक भाषा का चयन करें'),
(103966, 4850, 27, 'एक रोगी का चयन करें.'),
(103967, 4851, 27, 'Please select a Primary Business Entity facility with ''Tax ID'' as your facility Tax ID. If you are an individual practitioner, use your tax id. This is used for identifying you in the NewCrop system.'),
(103968, 4854, 27, 'कृपया एक प्राप्तकर्ता का चयन करें'),
(103969, 4855, 27, 'एक प्रारंभ तिथि और समाप्ति तिथि का चयन करें'),
(103970, 4856, 27, 'एक वैध प्राप्तकर्ता का चयन करें'),
(103971, 4858, 27, 'कोड के लिए एक समायोजन कारण का चयन करें '),
(103972, 4859, 27, 'एक घटना का चयन करें'),
(103973, 4860, 27, 'कोई भी खोज विकल्प चुनें.'),
(103974, 4863, 27, 'कम से कम एक पर्चे का चयन करें!'),
(103975, 4865, 27, 'कॉपी या अग्रेषित करने के लिए वांछित पृष्ठों का चयन करें:'),
(103976, 4866, 27, 'कृपया भुगतान पद्धति का चयन करें'),
(103977, 4867, 27, 'भुगतान के प्रकार का चयन करें.'),
(103978, 4869, 27, '270 बैच बनाने के लिए आवश्यक X12 साथी, का चयन करें'),
(103979, 4870, 27, 'सेट करें'),
(103980, 4871, 27, 'de_identification_config चर को वापस शून्य पर सेट करें'),
(103981, 4873, 27, 'नई De Identification प्रक्रिया शुरू करें'),
(103982, 4874, 27, 'De Identification प्रक्रियाओं, समारोह, टेबल शामिल करने के लिए LibreEHR डाटाबेस अपग्रेड करें'),
(103983, 4875, 27, 'अधिक जानकारी के लिए De Identification त्रुटि लॉग तालिका देखें'),
(103984, 4876, 27, 'कुछ समय के बाद De Identification स्क्रीन पर जाएँ'),
(103985, 4877, 27, 'कुछ समय बाद De Identification स्क्रीन पर जाएँ'),
(103986, 4878, 27, 'कुछ समय के बाद स्क्रीन पर जाएँ'),
(103987, 4881, 27, 'बहुवचन'),
(103988, 4882, 27, 'PM'),
(103989, 4883, 27, 'PM कार्यक्रम'),
(103990, 4884, 27, 'PMT विधि'),
(103991, 4885, 27, 'PND'),
(103992, 4886, 27, 'न्यूमोकोकल संयुग्म 1'),
(103993, 4887, 27, 'न्यूमोकोकल संयुग्म 2'),
(103994, 4888, 27, 'न्यूमोकोकल संयुग्म 3'),
(103995, 4889, 27, 'न्यूमोकोकल संयुग्म 4'),
(103996, 4890, 27, 'न्यूमोकोकल टीका'),
(103997, 4891, 27, 'निमोनिया टीकाकरण'),
(103998, 4892, 27, 'पुराने वयस्कों के लिए निमोनिया टीकाकरण की स्थिति'),
(103999, 4893, 27, 'पुराने वयस्कों के लिए निमोनिया टीकाकरण की स्थिति (CQM)'),
(104000, 4894, 27, 'Podiatric'),
(104001, 4896, 27, 'सेवा के बिंदु (पीओएस)'),
(104002, 4897, 27, 'पॉलिसी'),
(104003, 4898, 27, 'पॉलिसी No'),
(104004, 4899, 27, 'पॉलिसी नंबर'),
(104005, 4900, 27, 'पोलिश देश'),
(104006, 4901, 27, 'Polydypsia'),
(104007, 4902, 27, 'polyps'),
(104008, 4903, 27, 'बहुमूत्रता'),
(104009, 4904, 27, 'कमजोर भूख'),
(104010, 4905, 27, 'कमजोर वितरण'),
(104011, 4906, 27, 'कमजोर सुनवाई'),
(104012, 4907, 27, 'इन रिपोर्टों को देखने के लिए पॉप अप सक्रिय होने की जरूरत'),
(104013, 4908, 27, 'घटनाओं के साथ वर्ष दिखाएं?'),
(104014, 4909, 27, 'पॉपअप'),
(104015, 4910, 27, 'पोर्टल'),
(104016, 4911, 27, 'पोर्टल गतिविधि'),
(104017, 4917, 27, 'पुर्तगाली'),
(104018, 4918, 27, 'पुर्तगाली (ब्राजील)'),
(104019, 4919, 27, 'पुर्तगाली (यूरोपीय)'),
(104020, 4920, 27, 'POS कोड'),
(104021, 4922, 27, 'सकारात्मक'),
(104022, 4923, 27, 'सकारात्मक'),
(104023, 4925, 27, 'के लिए पोस्ट'),
(104024, 4926, 27, 'नाक ड्रिप'),
(104025, 4927, 27, 'पोस्ट भुगतान'),
(104026, 4928, 27, 'सर्जरी के बाद'),
(104027, 4929, 27, 'बिल भेजा के रूप में लेखा और मार्क को पोस्ट'),
(104028, 4930, 27, 'तिथि तक पोस्ट'),
(104029, 4931, 27, 'तिथि तक पोस्ट आज की तुलना में अधिक नहीं हो सकता'),
(104030, 4932, 27, 'तिथि तक पोस्ट वित्तीय समाप्ति तिथि से बड़ा होना चाहिए.'),
(104031, 4933, 27, 'गर्भपात के बाद की देखभाल'),
(104032, 4934, 27, 'गर्भपात के बाद गर्भनिरोध'),
(104033, 4935, 27, 'गर्भपात के बाद परामर्श'),
(104034, 4936, 27, 'गर्भपात के बाद फॉलोअप'),
(104035, 4937, 27, 'डाक का'),
(104036, 4938, 27, 'पोस्टल कोड'),
(104037, 4939, 27, 'पोस्टल कोड'),
(104038, 4941, 27, 'PostCalendar'),
(104039, 4942, 27, 'PostCalendar प्रशासन'),
(104040, 4943, 27, 'PostCalendar श्रेणी सेटिंग्स'),
(104041, 4944, 27, 'PostCalendar वैश्विक सेटिंग्स'),
(104042, 4945, 27, 'पर पोस्ट किया'),
(104043, 4946, 27, 'पोस्टिंग तिथि'),
(104044, 4948, 27, 'द्वारा संचालित'),
(104045, 4949, 27, 'PPE + पिछला Med / सर्जन Hx'),
(104046, 4950, 27, 'PQRI'),
(104047, 4951, 27, 'PQRI रजिस्ट्री ID'),
(104048, 4952, 27, 'PQRI रजिस्ट्री नाम'),
(104049, 4953, 27, 'प्रैक्टिस'),
(104050, 4954, 27, 'प्रैक्टिस डिफ़ॉल्ट सेटिंग'),
(104051, 4955, 27, 'अभ्यास सेटिंग'),
(104052, 4956, 27, 'व्यवसायी'),
(104053, 4958, 27, 'पूर्व भुगतान'),
(104054, 4959, 27, 'पूर्व भुगतान'),
(104055, 4960, 27, 'पूर्व गर्भपात परामर्श'),
(104056, 4961, 27, 'पूर्व गर्भपात परामर्श'),
(104057, 4962, 27, 'pref Cat'),
(104058, 4964, 27, 'प्राथमिकताएं'),
(104059, 4965, 27, 'पसंदीदा इवेंट श्रेणी'),
(104060, 4966, 27, 'पसंदीदा भाषा'),
(104061, 4967, 27, 'पसंदीदा फार्मेसी'),
(104062, 4968, 27, 'पसंदीदा प्रदाता संगठन (पी.पी.ओ.)'),
(104063, 4969, 27, 'preg टेस्ट'),
(104064, 4970, 27, 'प्रारंभिक'),
(104065, 4971, 27, 'रिपोर्ट चलाने की तैयारी'),
(104066, 4972, 27, 'पूर्व भुगतान'),
(104067, 4973, 27, 'पर्चे'),
(104068, 4974, 27, 'पर्चे की अपनी सीमा तक पहुँच गया है'),
(104069, 4975, 27, 'पर्चे का इतिहास'),
(104070, 4976, 27, 'पर्चे का इतिहास आयात सफलतापूर्वक पूरा'),
(104071, 4977, 27, 'पर्चे लेबल'),
(104072, 4978, 27, 'पर्चे की रिपोर्ट'),
(104073, 4979, 27, 'पर्चे'),
(104074, 4980, 27, 'पर्चे और बांटना'),
(104075, 4981, 27, 'पर्चे और अन्य रेफरल'),
(104076, 4982, 27, 'विशेषज्ञ द्वारा पर्चे और / या रेफरल'),
(104077, 4983, 27, 'पर्चे की रिपोर्ट'),
(104078, 4984, 27, 'पर्चे / सिफ़ारिशों की'),
(104079, 4985, 27, 'वर्तमान'),
(104080, 4986, 27, 'पेश शिकायत'),
(104081, 4987, 27, 'पेश समस्या (ओं)'),
(104082, 4988, 27, 'दबाएँ आगे बढ़ने के लिए जारी'),
(104083, 4989, 27, 'प्रकल्पित निदान'),
(104084, 4990, 27, 'विशेषज्ञ द्वारा परिकल्पित निदान'),
(104085, 4991, 27, 'पिछला'),
(104086, 4992, 27, 'पिछला Med / Surg Hx'),
(104087, 4993, 27, 'पिछला. माह (मेनू के लिए पकड़)'),
(104088, 4994, 27, 'पिछला. वर्ष (मेनू के लिए पकड़)'),
(104089, 4995, 27, 'निरोधक देखभाल'),
(104090, 4998, 27, 'पूर्वावलोकन इवेंट'),
(104091, 5000, 27, 'का पूर्वावलोकन'),
(104092, 5001, 27, 'पिछला'),
(104093, 5002, 27, 'पिछले परामर्श'),
(104094, 5003, 27, 'पिछले दिन'),
(104095, 5004, 27, 'पिछले इतिहास / स्क्रीनिंग'),
(104096, 5005, 27, 'पिछले माह'),
(104097, 5006, 27, 'पिछला सप्ताह'),
(104098, 5007, 27, 'कीमत'),
(104099, 5008, 27, 'कीमत छूट'),
(104100, 5009, 27, 'कीमत स्तर'),
(104101, 5010, 27, 'कीमत स्तर:'),
(104102, 5011, 27, 'कीमतें'),
(104103, 5012, 27, 'प्राथमिक'),
(104104, 5013, 27, 'प्राथमिक व्यापार इकाई'),
(104105, 5014, 27, 'प्राथमिक व्यापार इकाई कर आईडी NewCrop ePrescription के लिए खाता आईडी के रूप में प्रयोग किया जाता है. सुविधा को बदलना NewCrop के कार्यकरण को प्रभावित करेगा.'),
(104106, 5022, 27, 'प्राथमिक इन्स'),
(104107, 5023, 27, 'प्राथमिक बीमा'),
(104108, 5024, 27, 'प्राथमिक बीमा डाटा'),
(104109, 5025, 27, 'प्राथमिक बीमा प्रदाता'),
(104110, 5026, 27, 'प्राथमिक प्रदाता'),
(104111, 5027, 27, 'छापें'),
(104112, 5028, 27, 'छापें (HTML)'),
(104113, 5029, 27, 'छापें (PDF)'),
(104114, 5031, 27, 'कोई भी मुठभेड़ छापें'),
(104115, 5032, 27, 'खाली रेफरल प्रपत्र छापें'),
(104116, 5033, 27, 'आदेश छापें'),
(104117, 5034, 27, 'तिथि छापें'),
(104118, 5039, 27, 'सरूप छापें'),
(104119, 5040, 27, 'चार कक्ष छापें'),
(104120, 5042, 27, 'संदेश छापें'),
(104121, 5043, 27, 'अनेक छापें'),
(104122, 5044, 27, 'फैक्स करने के लिए अनेक प्रिंट'),
(104123, 5045, 27, 'नाम, हस्ताक्षर और तिथि छापें.'),
(104124, 5046, 27, 'नोट्स छापें'),
(104125, 5047, 27, 'पृष्ठ 1 छापें'),
(104126, 5048, 27, 'पृष्ठ 2 छापें'),
(104127, 5051, 27, 'प्रदाता द्वारा प्राप्तियां छापें'),
(104128, 5052, 27, 'अभिलेख छापें'),
(104129, 5053, 27, 'चयनित वक्तव्य छापें'),
(104130, 5054, 27, 'शॉट रिकॉर्ड छापें'),
(104131, 5056, 27, 'यह मुठभेड़ छापें'),
(104132, 5057, 27, 'यह टिप्पणी छापें'),
(104133, 5058, 27, 'यह टिप्पणी छापें'),
(104134, 5060, 27, 'फैक्स करने के लिए छापें'),
(104135, 5061, 27, 'दृश्य छापें'),
(104136, 5062, 27, 'छापने योग्य'),
(104137, 5063, 27, 'छापने योग्य संस्करण'),
(104138, 5064, 27, 'छपी'),
(104139, 5066, 27, 'छपाई परिणाम:'),
(104140, 5067, 27, 'छपाई छोड़ दिया; में परीक्षण उत्पादन देखें'),
(104141, 5068, 27, 'छपाई छोड़ दिया; में परीक्षण उत्पादन देखें '),
(104142, 5069, 27, 'पूर्व प्राधिकरण'),
(104143, 5070, 27, 'पूर्व प्राधिकरण प्रपत्र'),
(104144, 5071, 27, 'पूर्व भेंट'),
(104145, 5072, 27, 'प्राथमिकता'),
(104146, 5073, 27, 'प्राथमिकता '),
(104147, 5074, 27, 'निजी'),
(104148, 5075, 27, 'समस्या'),
(104149, 5076, 27, 'समस्या DX'),
(104150, 5077, 27, 'समस्या सूची'),
(104151, 5079, 27, 'समस्याओं / मुद्दों'),
(104152, 5080, 27, 'Proc Bat'),
(104153, 5081, 27, 'Proc Cat'),
(104154, 5082, 27, 'Proc Load'),
(104155, 5083, 27, 'Proc Pending Rev'),
(104156, 5084, 27, 'Proc Prov'),
(104157, 5085, 27, 'Proc Res'),
(104158, 5086, 27, 'प्रक्रिया'),
(104159, 5087, 27, 'प्रक्रिया शारीरिक साइटें'),
(104160, 5088, 27, 'प्रक्रिया बूलियन परिणाम'),
(104161, 5089, 27, 'प्रक्रिया संहिता'),
(104162, 5090, 27, 'प्रक्रिया संहिता'),
(104163, 5091, 27, 'प्रक्रिया Lateralities'),
(104164, 5092, 27, 'प्रक्रिया का नाम'),
(104165, 5093, 27, 'प्रक्रिया आदेश'),
(104166, 5094, 27, 'प्रक्रिया आदेश'),
(104167, 5095, 27, 'के लिए प्रक्रिया आदेश'),
(104168, 5097, 27, 'प्रक्रिया के आदेश और रिपोर्ट'),
(104169, 5098, 27, 'प्रक्रिया पिकर'),
(104170, 5099, 27, 'प्रक्रिया प्रदाता'),
(104171, 5100, 27, 'प्रक्रिया प्रदाता'),
(104172, 5101, 27, 'प्रक्रिया प्रदाता');
INSERT INTO `lang_definitions` VALUES
(104173, 5102, 27, 'प्रक्रिया की रिपोर्ट'),
(104174, 5103, 27, 'प्रक्रिया रिपोर्ट की स्थितियां'),
(104175, 5104, 27, 'असामान्य प्रक्रिया रिजल्ट'),
(104176, 5105, 27, 'प्रक्रिया नतीजे की स्थितियां'),
(104177, 5106, 27, 'प्रक्रिया का परिणाम'),
(104178, 5107, 27, 'प्रक्रिया मार्ग'),
(104179, 5108, 27, 'प्रक्रिया नमूना प्रकार'),
(104180, 5109, 27, 'प्रक्रिया सांख्यिकी रिपोर्ट'),
(104181, 5110, 27, 'प्रक्रिया के प्रकार'),
(104182, 5111, 27, 'प्रक्रिया के प्रकार'),
(104183, 5112, 27, 'प्रक्रिया इकाइयां'),
(104184, 5113, 27, 'प्रक्रिया / सेवा'),
(104185, 5114, 27, 'प्रक्रिया'),
(104186, 5115, 27, 'की प्रक्रिया करें'),
(104187, 5116, 27, 'प्रक्रिया करें और अनुस्मारक भेजें'),
(104188, 5117, 27, 'ERA फ़ाइल की प्रक्रिया करें'),
(104189, 5118, 27, 'CSV रिकॉर्ड के लिए नई फ़ाइलों की प्रक्रिया करें'),
(104190, 5119, 27, 'अनुस्मारक की प्रक्रिया करें'),
(104191, 5120, 27, 'इस प्रक्रिया में कुछ समय लगता है'),
(104192, 5121, 27, 'प्रक्रिया किया'),
(104193, 5122, 27, 'द्वारा प्रक्रिया'),
(104194, 5123, 27, 'प्रक्रिया तिथि'),
(104195, 5124, 27, 'सफलतापूर्वक प्रक्रिया'),
(104196, 5125, 27, 'प्रक्रिया कर रहा है'),
(104197, 5126, 27, 'प्रक्रिया कर रहा है और रोगी अनुस्मारक भेज रहा है'),
(104198, 5127, 27, 'रोगी अनुस्मारक प्रक्रिया कर रहा है'),
(104199, 5128, 27, 'प्रक्रिया समय'),
(104200, 5129, 27, 'उत्पाद'),
(104201, 5130, 27, 'उत्पाद गर्भनिरोधक विधि'),
(104202, 5131, 27, 'उत्पादन'),
(104203, 5132, 27, 'उत्पाद'),
(104204, 5133, 27, 'उत्पाद लेकिन कोई दवाओं का सेवन नहीं और कोई टेम्पलेट्स नहीं'),
(104205, 5134, 27, 'प्रोफेसर'),
(104206, 5135, 27, 'प्रगति नोट्स'),
(104207, 5136, 27, 'प्रोस्टेट कैंसर'),
(104208, 5137, 27, 'प्रोस्टेट कैंसर स्क्रीनिंग'),
(104209, 5138, 27, 'प्रोस्टेट परीक्षा'),
(104210, 5139, 27, 'प्रोस्टेट की समस्याएं'),
(104211, 5140, 27, 'प्रोस्टेट w/o enlrgmt, पिंड, tender'),
(104212, 5141, 27, 'प्रोटोकॉल'),
(104213, 5142, 27, 'पूर्ण पथ प्रदान करें'),
(104214, 5143, 27, 'फ़ाइल का पूर्ण पथ प्रदान करें'),
(104215, 5145, 27, 'प्रत्येक कार्यालय के दौरे के लिए रोगियों को नैदानिक ​​सारांश प्रदान प्रदान करें.'),
(104216, 5146, 27, 'Provide patients with an electronic copy of their health information (including diagnostic test results, problem list, medication lists, medication allergies), upon request.'),
(104217, 5147, 27, 'Provide patients with timely electronic access to their health information (including lab results, problem list, medication lists, medication allergies) within four business days of the information being available to the EP.'),
(104218, 5148, 27, 'यात्रा के लिए रोगी को रिकॉर्ड प्रदान करें'),
(104219, 5149, 27, 'मान्य ईमेल पता प्रदान करें'),
(104220, 5150, 27, 'क्लीनिकल सारांश प्रदान की?'),
(104221, 5151, 27, 'शिक्षा संसाधन प्रदान की?'),
(104222, 5152, 27, 'प्रदाता'),
(104223, 5153, 27, 'प्रदाता Id'),
(104224, 5154, 27, 'प्रदाता ID'),
(104225, 5155, 27, 'निर्दिष्ट सुविधा प्रदाता ID'),
(104226, 5156, 27, 'प्रदाता मिलान त्रुटियाँ'),
(104227, 5159, 27, 'प्रदाता संख्या'),
(104228, 5160, 27, 'प्रदाता रिश्ता'),
(104229, 5162, 27, 'प्रदाता:'),
(104230, 5163, 27, 'प्रदाता'),
(104231, 5164, 27, 'प्रदाता NPI'),
(104232, 5165, 27, 'प्रदाता पूरा कैलेंडर देखें'),
(104233, 5166, 27, 'prv'),
(104234, 5167, 27, 'PSA'),
(104235, 5168, 27, 'सोरायसिस'),
(104236, 5169, 27, 'मनोवैज्ञानिक निदान'),
(104237, 5170, 27, 'मनोवैज्ञानिक दवा'),
(104238, 5171, 27, 'मानसिक रोगों का'),
(104239, 5172, 27, 'मनोरोग संक्षिप्त पत्र'),
(104240, 5173, 27, 'मनोरोग निदान'),
(104241, 5174, 27, 'मनोरोग परीक्षा'),
(104242, 5175, 27, 'मनोरोग इतिहास'),
(104243, 5176, 27, 'मनोरोग सेवन'),
(104244, 5177, 27, 'मनोरोग चिकित्सा'),
(104245, 5178, 27, 'Pt %'),
(104246, 5179, 27, 'Pt टिप्पणी'),
(104247, 5180, 27, 'Pt टिप्पणी / Auth'),
(104248, 5181, 27, 'Pt अधिक भुगतान'),
(104249, 5182, 27, 'Pt भुगतान किया'),
(104250, 5183, 27, 'Pt Rec अनुरोध'),
(104251, 5184, 27, 'Pt धन वापसी'),
(104252, 5185, 27, 'Pt रिहाई'),
(104253, 5186, 27, 'Pt रिपोर्ट'),
(104254, 5187, 27, 'PT छात्र, या खाली छोड़ दें'),
(104255, 5188, 27, 'PT_CITY'),
(104256, 5189, 27, 'PT_DOB'),
(104257, 5191, 27, 'PT_FNAME'),
(104258, 5192, 27, 'PT_LNAME'),
(104259, 5193, 27, 'PT_MNAME'),
(104260, 5196, 27, 'PT_POSTAL'),
(104261, 5198, 27, 'PT_STATE'),
(104262, 5199, 27, 'PT_STREET'),
(104263, 5201, 27, 'सार्वजनिक'),
(104264, 5203, 27, 'सार्वजनिक स्वास्थ्य सेवा (PHS) या अन्य संघीय एजेंसी'),
(104265, 5204, 27, 'प्योर्टो रिको'),
(104266, 5205, 27, 'फुफ्फुसीय'),
(104267, 5206, 27, 'नाड़ी'),
(104268, 5207, 27, 'पंजाबी'),
(104269, 5208, 27, 'खरीद'),
(104270, 5209, 27, 'खरीद / वापसी'),
(104271, 5210, 27, 'खरीदारियां'),
(104272, 5211, 27, 'P {{हैडर जस्टिफाई}}'),
(104273, 5213, 27, 'q.3h'),
(104274, 5214, 27, 'q.4h'),
(104275, 5215, 27, 'q.5h'),
(104276, 5216, 27, 'q.6h'),
(104277, 5217, 27, 'q.8h'),
(104278, 5218, 27, 'q.d.'),
(104279, 5219, 27, 'q.i.d.'),
(104280, 5220, 27, 'QOH'),
(104281, 5221, 27, 'QOH मासिक उपयोग की तुलना में कम है'),
(104282, 5222, 27, 'मात्रा'),
(104283, 5223, 27, 'मात्रा'),
(104284, 5224, 27, 'गुणवत्ता'),
(104285, 5225, 27, 'गुणवत्ता के उपाय (CQM)'),
(104286, 5226, 27, 'मात्रा'),
(104287, 5227, 27, 'NDC के लिए मात्रा'),
(104288, 5228, 27, 'हाथ में मात्रा'),
(104289, 5229, 27, 'मात्रा व्यर्थ लगता है'),
(104290, 5231, 27, 'प्रश्नचिह्न'),
(104291, 5232, 27, 'HCFA बैच प्रक्रिया के लिए कतार'),
(104292, 5233, 27, 'HCFA बैच प्रक्रिया और छपाई के लिए कतार'),
(104293, 5234, 27, 'UB -92 बैच प्रक्रिया के लिए कतार'),
(104294, 5235, 27, 'UB -92 बैच प्रक्रिया और छपाई के लिए कतार'),
(104295, 5236, 27, 'पंक्तिबद्ध'),
(104296, 5237, 27, 'कतारबद्ध घटनाक्रम प्रशासन'),
(104297, 5238, 27, 'के लिए कतारबद्ध'),
(104298, 5240, 27, 'पंक्तिबद्ध प्रस्तुतियाँ प्रशासन'),
(104299, 5241, 27, 'छोड़ना'),
(104300, 5242, 27, 'शराब छोड़ो'),
(104301, 5243, 27, 'R'),
(104302, 5244, 27, 'रोगी, मुठभेड़, या पता लगाने के लिए RA'),
(104303, 5245, 27, 'नस्ल'),
(104304, 5246, 27, 'नस्ल और राष्ट्रीयता'),
(104305, 5247, 27, 'जाति / जातीयता'),
(104306, 5248, 27, 'रेडियो'),
(104307, 5249, 27, 'रेडियो बटन'),
(104308, 5251, 27, 'सीमा'),
(104309, 5252, 27, 'चकत्ते'),
(104310, 5253, 27, 'दर'),
(104311, 5254, 27, 'अनुपात'),
(104312, 5255, 27, 'कच्चा रिपोर्ट'),
(104313, 5256, 27, 'पुन: पहचान'),
(104314, 5257, 27, 'पुन: पहचान की प्रक्रिया पूरा हो गया है'),
(104315, 5258, 27, 'पुन: पहचान की प्रक्रिया चल रही है'),
(104316, 5259, 27, 'पुन: पहचान फ़ाइल सहेजा जाएगा'),
(104317, 5260, 27, 'फिर से चोट?'),
(104318, 5261, 27, 'फिर से खोलने'),
(104319, 5262, 27, 'फिर से खोला'),
(104320, 5263, 27, 'प्रतिक्रिया'),
(104321, 5264, 27, 'प्रतिक्रिया'),
(104322, 5265, 27, 'पढ़ना'),
(104323, 5268, 27, 'असल नाम'),
(104324, 5269, 27, 'वास्तव में हटाना'),
(104325, 5270, 27, 'कारण'),
(104326, 5271, 27, 'कारण मृतक'),
(104327, 5272, 27, 'मृत्यु के लिए कारण'),
(104328, 5274, 27, 'संदर्भ के लिए कारण'),
(104329, 5275, 27, 'यात्रा के लिए कारण'),
(104330, 5276, 27, 'कारण / प्रपत्र'),
(104331, 5277, 27, 'प्राप्ति'),
(104332, 5278, 27, 'भुगतान के लिए प्राप्ति'),
(104333, 5279, 27, 'प्राप्ति उत्पन्न'),
(104334, 5280, 27, 'भुगतान की विधि की रिपोर्ट से प्राप्तियां'),
(104335, 5281, 27, 'प्राप्तियां सारांश'),
(104336, 5282, 27, 'प्राप्त'),
(104337, 5283, 27, 'के द्वारा प्राप्त किया'),
(104338, 5284, 27, 'फैक्स प्राप्त'),
(104339, 5285, 27, 'प्राप्त, समीक्षा नहीं की'),
(104340, 5287, 27, 'पानेवाला'),
(104341, 5288, 27, 'पानेवाला ID'),
(104342, 5289, 27, 'पानेवाला आईडी (ISA08)'),
(104343, 5290, 27, 'पानेवाला आईडी क्वालीफायर (ISA07)'),
(104344, 5291, 27, 'पानेवाला आईडी के'),
(104345, 5292, 27, 'हाल के तीन पासवर्ड की अनुमति नहीं है.'),
(104346, 5293, 27, 'प्राप्तकर्ता'),
(104347, 5294, 27, 'प्राप्तकर्ता सूची खाली है'),
(104348, 5295, 27, 'प्राप्तकर्ता का नाम'),
(104349, 5296, 27, 'प्रकटीकरण के प्राप्तकर्ता'),
(104350, 5297, 27, 'प्राप्तकर्ता आवश्यक जब तक status हो गया है होता नहीं'),
(104351, 5298, 27, 'सिफारिश'),
(104352, 5299, 27, 'फिर से दौरा के लिए सिफारिश'),
(104353, 5300, 27, 'सिफारिशें'),
(104354, 5301, 27, 'सिफारिशें और उपचार'),
(104355, 5302, 27, 'विशेषज्ञ द्वारा सिफारिशें'),
(104356, 5303, 27, 'रिकॉर्ड'),
(104357, 5304, 27, 'रिकॉर्ड पहले से ही मौजूद'),
(104358, 5310, 27, 'महत्वपूर्ण लक्षण में रिकॉर्ड और चार्ट बदल जाता है.'),
(104359, 5311, 27, 'रिकॉर्ड जनसांख्यिकी.'),
(104360, 5312, 27, 'रिकॉर्ड प्रकटीकरण'),
(104361, 5313, 27, 'स्वास्थ्य का रिकॉर्ड'),
(104362, 5314, 27, 'भुगतान रिकॉर्ड'),
(104363, 5315, 27, 'रिकॉर्ड अनुरोध तिथि'),
(104364, 5316, 27, '13 साल की उम्र या पुराने रोगियों के लिए रिकॉर्ड धूम्रपान की स्थिति.'),
(104365, 5317, 27, 'रिकॉर्ड्स'),
(104366, 5318, 27, 'रिकार्ड मिले'),
(104367, 5319, 27, 'रिकार्ड मिले'),
(104368, 5320, 27, 'मनोरंजक दवाओं का उपयोग'),
(104369, 5321, 27, 'मनोरंजनात्मक दवाएं'),
(104370, 5322, 27, 'मलाशय के'),
(104371, 5323, 27, 'मलाशय परीक्षा'),
(104372, 5324, 27, 'मलाशय'),
(104373, 5325, 27, 'पुनप्रेषण'),
(104374, 5326, 27, 'लाली'),
(104375, 5327, 27, 'कम:'),
(104376, 5328, 27, 'संदर्भ'),
(104377, 5329, 27, 'द्वारा संदर्भ'),
(104378, 5330, 27, 'संदर्भ तिथि'),
(104379, 5331, 27, 'को संदर्भ'),
(104380, 5332, 27, 'संदर्भ वर्गीकरण (जोखिम स्तर)'),
(104381, 5333, 27, 'परिणामों के संदर्भ सीमा'),
(104382, 5334, 27, 'संदर्भ कारण'),
(104383, 5336, 27, 'Referer नाम और हस्ताक्षर'),
(104384, 5337, 27, 'रेफरल'),
(104385, 5338, 27, 'द्वारा रेफरल'),
(104386, 5339, 27, 'सिफ़ारिश कार्ड'),
(104387, 5340, 27, 'सिफ़ारिश तिथि'),
(104388, 5341, 27, 'सिफ़ारिश पर्चा'),
(104389, 5342, 27, 'रेफरल फार्म'),
(104390, 5343, 27, 'रेफरल आईडी'),
(104391, 5345, 27, 'सिफारिश स्रोत'),
(104392, 5346, 27, 'मुठभेड़ों के लिए सिफारिश स्रोत'),
(104393, 5347, 27, 'को सिफ़ारिश'),
(104394, 5348, 27, 'सिफ़ारिश'),
(104395, 5349, 27, 'सिफ़ारिश रिपोर्ट'),
(104396, 5350, 27, 'द्वारा सिफ़ारिश'),
(104397, 5351, 27, 'द्वारा सिफ़ारिश'),
(104398, 5352, 27, 'को सिफ़ारिश'),
(104399, 5353, 27, 'सिफ़ारिश करनेवाला'),
(104400, 5355, 27, 'सिफारिश करनेवाला से निदान'),
(104401, 5356, 27, 'सिफारिश करनेवाला से निदान'),
(104402, 5357, 27, 'सिफारिश करनेवाला चिकित्सक और प्रैक्टिस'),
(104403, 5358, 27, 'सिफारिश करनेवाला प्रदाता'),
(104404, 5359, 27, 'फिर से भरना'),
(104405, 5360, 27, 'केवल एक बार'),
(104406, 5361, 27, 'केवल एक बार'),
(104407, 5362, 27, 'सामान्य सजगता'),
(104408, 5363, 27, 'ताज़ा करे'),
(104409, 5365, 27, 'अनुस्मारक ताज़ा कर रहा है'),
(104410, 5368, 27, 'स्टेट करने से इनकार कर दिया'),
(104411, 5369, 27, 'reg_re'),
(104412, 5370, 27, 'पंजीकरण'),
(104413, 5372, 27, 'पंजीकृत'),
(104414, 5373, 27, 'पंजीकृत'),
(104415, 5375, 27, 'पंजीकरण की तिथि'),
(104416, 5376, 27, 'पंजीकरण प्रपत्र'),
(104417, 5377, 27, 'पुनर्वास'),
(104418, 5380, 27, 'पलटाना संभावित'),
(104419, 5381, 27, 'से संबंधित हैं'),
(104420, 5382, 27, 'संबंधित'),
(104421, 5383, 27, 'संबंधित मुद्दा'),
(104422, 5384, 27, 'संबंधित रोगी टिप्पणी'),
(104423, 5385, 27, 'रिश्ता / बच्चे'),
(104424, 5386, 27, 'संबंध'),
(104425, 5387, 27, 'संबंध'),
(104426, 5388, 27, 'इस इकाई के सापेक्ष आदेश देने'),
(104427, 5389, 27, 'रिश्तेदार'),
(104428, 5399, 27, 'रिले स्वास्थ्य साख इस उपयोगकर्ता खाते से लापता हैं.'),
(104429, 5400, 27, 'रिले स्वास्थ्य ID'),
(104430, 5402, 27, 'रिलीज़ तिथि'),
(104431, 5403, 27, 'धर्म'),
(104432, 5406, 27, 'दोबारा लॉगिन'),
(104433, 5407, 27, 'Remdr'),
(104434, 5408, 27, 'चयनित सुविधा याद रखें'),
(104435, 5409, 27, 'अनुस्मारक'),
(104436, 5410, 27, 'अनुस्मारक अंतराल'),
(104437, 5411, 27, 'अनुस्मारक अभी तक नहीं भेजा'),
(104438, 5412, 27, 'पर अनुस्मारक भेजा'),
(104439, 5413, 27, 'अनुस्मारक'),
(104440, 5414, 27, 'परिहार'),
(104441, 5415, 27, 'दूरस्थ मेजबान'),
(104442, 5416, 27, 'हटाना'),
(104443, 5419, 27, 'समूह हटाएं'),
(104444, 5420, 27, 'समूह के रूप में निकालें'),
(104445, 5421, 27, 'टीकाकरण के लिए समर्थन निकालता है'),
(104446, 5422, 27, 'PhpMyAdmin के लिए समर्थन निकालता है'),
(104447, 5423, 27, 'नुस्खे के लिए समर्थन निकालता है'),
(104448, 5425, 27, 'चार्ट ट्रैकर सुविधा निकालता है'),
(104449, 5426, 27, 'गुर्दे की पथरी'),
(104450, 5427, 27, 'नाम बदलें'),
(104451, 5428, 27, 'समूह का नाम बदलें'),
(104452, 5429, 27, 'प्रस्तुत कर रहा'),
(104453, 5430, 27, 'प्रस्तुत कर रहा प्रदाता'),
(104454, 5431, 27, 'प्रस्तुत कर रहा प्रदाता संख्या'),
(104455, 5432, 27, 'पुन: व्यवस्थित करें'),
(104456, 5433, 27, 'पर पुन: व्यवस्थित करें'),
(104457, 5434, 27, 'पुन: व्यवस्थित बिंदु पहुंच गया है'),
(104458, 5435, 27, 'पुन: व्यवस्थित बिंदु, 0 यदि लागू नहीं'),
(104459, 5436, 27, 'Rep'),
(104460, 5437, 27, 'नया पासवर्ड दोहराएँ'),
(104461, 5438, 27, 'घटना दोहराए जाने'),
(104462, 5439, 27, 'जानकारी दोहरा रहा है:'),
(104463, 5440, 27, 'दोहराता है'),
(104464, 5441, 27, 'बदलें'),
(104465, 5444, 27, 'तिथि दें'),
(104466, 5445, 27, 'से उत्तर'),
(104467, 5446, 27, 'रिपोर्ट'),
(104468, 5447, 27, 'रिपोर्ट - क्लीनिकल'),
(104469, 5449, 27, 'द्वारा रिपोर्ट'),
(104470, 5453, 27, 'रिपोर्ट इतिहास / परिणाम'),
(104471, 5454, 27, 'रिपोर्ट परिणाम'),
(104472, 5455, 27, 'रिपोर्ट परिणाम / इतिहास'),
(104473, 5457, 27, 'रिपोर्ट स्थिति'),
(104474, 5458, 27, 'रिपोर्ट योग'),
(104475, 5459, 27, 'रिपोर्ट / प्रपत्र'),
(104476, 5460, 27, 'रिपोर्ट योग्य'),
(104477, 5461, 27, 'रिपोर्टेड'),
(104478, 5462, 27, 'रिपोर्टेड तिथि'),
(104479, 5463, 27, 'रिपोर्टें'),
(104480, 5467, 27, 'अनुरोध पर ध्यान नहीं दिया - दावा प्रसंस्करण पहले से ही चल रहा है!'),
(104481, 5474, 27, 'सेवा का अनुरोध'),
(104482, 5475, 27, 'मजबूत पासवर्ड की आवश्यकता'),
(104483, 5476, 27, 'अद्वितीय पासवर्ड की आवश्यकता'),
(104484, 5477, 27, 'अपेक्षित'),
(104485, 5478, 27, 'आवश्यक सह वेतन'),
(104486, 5479, 27, 'आवश्यक फ़ील्ड गुम: अपलोड करने के लिए EDI-271 फ़ाइल का चयन करें'),
(104487, 5480, 27, 'आवश्यक फ़ील्ड गुम: पहला नाम दर्ज करें'),
(104488, 5481, 27, 'आवश्यक फ़ील्ड गुम: अंतिम नाम दर्ज करें'),
(104489, 5482, 27, 'आवश्यक फ़ील्ड गुम: उपयोगकर्ता नाम दर्ज करें'),
(104490, 5483, 27, 'आवश्यक फ़ील्ड'),
(104491, 5484, 27, 'आवश्यकताएँ'),
(104492, 5485, 27, 'आरक्षित'),
(104493, 5486, 27, 'आरक्षित'),
(104494, 5487, 27, 'अनुसूचित अवकाश समय को परिभाषित करने के लिए उपयोग के लिए आरक्षित'),
(104495, 5488, 27, 'जब एक प्रदाता के लिए नियुक्तियों उपलब्ध नहीं है, तो परिभाषित करने के आरक्षित.'),
(104496, 5489, 27, 'निर्दिष्ट रूप में घटना घटि नहीं तो परिभाषित करने के लिए आरक्षित.'),
(104497, 5490, 27, 'जब प्रदाता के लिए नियुक्तियों उपलब्ध है, तो परिभाषित करने के लिए आरक्षित.'),
(104498, 5491, 27, 'रीसेट करें'),
(104499, 5492, 27, 'Offsite पोर्टल पहचान रीसेट करें'),
(104500, 5493, 27, 'ऑनसाइट पोर्टल पहचान रीसेट करें'),
(104501, 5495, 27, 'Resn'),
(104502, 5496, 27, 'संकल्प'),
(104503, 5497, 27, 'श्वसन'),
(104504, 5498, 27, 'श्वासयंत्र प्रयास अनुपाजिंत'),
(104505, 5499, 27, 'श्वसन'),
(104506, 5501, 27, 'उपयोगकर्ता व्यवस्थापक में निर्धारित कार्यक्रम सुविधाएं को गैर अधिकृत उपयोगकर्ताओं को सीमित करें.'),
(104507, 5502, 27, 'सुविधाएं के लिए उपयोगकर्ताओं को सीमित'),
(104508, 5503, 27, 'सीमित प्रशिक्षण'),
(104509, 5504, 27, 'परिणाम'),
(104510, 5505, 27, 'परिणाम नाम'),
(104511, 5506, 27, 'परिणाम स्थिति'),
(104512, 5507, 27, 'परिणाम स्थिति या विषमता लापता है'),
(104513, 5508, 27, 'परिणामस्वरूप, एक वाइल्डकार्ड के रूप में % का उपयोग'),
(104514, 5509, 27, 'परिणाम'),
(104515, 5510, 27, 'परिणाम और'),
(104516, 5511, 27, 'खोज के लिए परिणाम मिले'),
(104517, 5512, 27, 'परिणाम समूह'),
(104518, 5514, 27, 'परिणाम पथ'),
(104519, 5515, 27, 'प्रति पृष्ठ परिणाम'),
(104520, 5516, 27, 'परिणाम / विवरण'),
(104521, 5517, 27, 'रेटिना परीक्षा'),
(104522, 5518, 27, 'राइट मुकर:'),
(104523, 5519, 27, 'लौटें'),
(104524, 5520, 27, 'अपने भुगतान के साथ ऊपर भाग लौटाएँ'),
(104525, 5521, 27, 'कैलेंडर पर लौटें'),
(104526, 5522, 27, 'परिणाम की रिपोर्ट पर लौटें'),
(104527, 5523, 27, 'इस पृष्ठ पर लौटें और आप ICD10 अनुभाग शीर्षक पर क्लिक करके ICD10 स्थापना प्रक्रिया को पूरा करने में सक्षम होगे'),
(104528, 5524, 27, 'इस पृष्ठ पर लौटें और आप ICD9 अनुभाग शीर्षक पर क्लिक करके ICD9 स्थापना प्रक्रिया को पूरा करने में सक्षम होगे'),
(104529, 5525, 27, 'इस पृष्ठ पर लौटें और आप RXNORM अनुभाग शीर्षक पर क्लिक करके RxNorm स्थापना प्रक्रिया को पूरा करने में सक्षम होगे'),
(104530, 5526, 27, 'इस पृष्ठ पर लौटें और आप SNOMED अनुभाग शीर्षक पर क्लिक करके Snomed स्थापना प्रक्रिया को पूरा करने में सक्षम होगे'),
(104531, 5527, 27, 'मूल्य लौटें'),
(104532, 5528, 27, 'वापसी यात्रा'),
(104533, 5529, 27, 'खेलने वापस'),
(104534, 5530, 27, 'पिछले तीन पासवर्ड के पुन: उपयोग की अनुमति नहीं है!'),
(104535, 5534, 27, 'PMH की समीक्षा करें:'),
(104536, 5535, 27, 'प्रणाली की समीक्षा'),
(104537, 5536, 27, 'सिस्टम जांच की समीक्षा'),
(104538, 5537, 27, 'समीक्षित'),
(104539, 5538, 27, 'संशोधन'),
(104540, 5539, 27, 'Rheumotoid गठिया'),
(104541, 5540, 27, 'Rheumotoid गठिया'),
(104542, 5541, 27, 'दाएँ'),
(104543, 5542, 27, 'दाएँ कान'),
(104544, 5543, 27, 'दाएँ कान'),
(104545, 5545, 27, 'दाएँ'),
(104546, 5546, 27, 'कानों में बज रहा'),
(104547, 5547, 27, 'कानों में बज रहा'),
(104548, 5549, 27, 'जोखिम कारक'),
(104549, 5550, 27, 'जोखिम का स्तर'),
(104550, 5551, 27, 'RLL:'),
(104551, 5552, 27, 'ROM'),
(104552, 5553, 27, 'रोमानियाई देश'),
(104553, 5560, 27, 'रोस्टर'),
(104554, 5561, 27, 'मार्ग'),
(104555, 5562, 27, 'प्रशासन का मार्ग, यदि लागू हो'),
(104556, 5563, 27, 'मार्ग किया'),
(104557, 5564, 27, 'पंक्तियाँ'),
(104558, 5565, 27, 'MOR बिना RRR'),
(104559, 5566, 27, 'रगड़ो:'),
(104560, 5567, 27, 'रगड़ो:'),
(104561, 5568, 27, 'नियम'),
(104562, 5569, 27, 'नियम जोड़ें'),
(104563, 5570, 27, 'नियम विस्तार'),
(104564, 5572, 27, 'नियम संपादित करें'),
(104565, 5575, 27, 'नियम सेट करें'),
(104566, 5578, 27, 'नियम'),
(104567, 5580, 27, 'नियम विन्यास'),
(104568, 5581, 27, 'कमांड चलाने: '),
(104569, 5582, 27, 'टूटना'),
(104570, 5583, 27, 'रूसी देश'),
(104571, 5584, 27, 'RX'),
(104572, 5585, 27, 'RX'),
(104573, 5586, 27, 'Rx नीचे मार्जिन (px)'),
(104574, 5587, 27, 'Rx DEA # सक्षम करें'),
(104575, 5588, 27, 'Rx NPI सक्षम करें'),
(104576, 5589, 27, 'Rx राज्य Lic सक्षम करें. #'),
(104577, 5590, 27, 'Rx वाम मार्जिन (px)'),
(104578, 5591, 27, 'Rx पेपर आकार'),
(104579, 5592, 27, 'Rx दाएँ मार्जिन (px)'),
(104580, 5593, 27, 'Rx दिखाएँ DEA #'),
(104581, 5594, 27, 'Rx दिखाएँ NPI'),
(104582, 5595, 27, 'Rx दिखाएँ राज्य Lic. #'),
(104583, 5596, 27, 'Rx शीर्ष मार्जिन (px)'),
(104584, 5598, 27, 'RxNorm'),
(104585, 5599, 27, 'RxNorm डाटाबेस'),
(104586, 5600, 27, 'S'),
(104587, 5601, 27, 's.s.'),
(104588, 5602, 27, 'S3:'),
(104589, 5603, 27, 'S4:'),
(104590, 5604, 27, 'SA ** लाइसेंस पढ़ने के लिए पढ़ें Docs / license.txt या कृपया जाओ * http://www.gnu.org/copyleft/gpl.html ** / / / ============ ================================================== =========== / / '),
(104591, 5605, 27, 'बिक्री'),
(104592, 5606, 27, 'बिक्री'),
(104593, 5607, 27, 'आइटम द्वारा बिक्री'),
(104594, 5608, 27, 'उत्पाद की रिपोर्ट द्वारा बिक्री'),
(104595, 5609, 27, 'लार'),
(104596, 5610, 27, 'उसी दिन'),
(104597, 5611, 27, 'सैमो का (निवासी) या सैमोई (भाषा)'),
(104598, 5612, 27, 'नमूना'),
(104599, 5613, 27, 'स्वीकृति के प्रकार'),
(104600, 5617, 27, 'शनि'),
(104601, 5618, 27, 'शनि औरamp रवि'),
(104602, 5619, 27, 'शनिवार'),
(104603, 5620, 27, 'सहेजें'),
(104604, 5621, 27, 'सहेजें'),
(104605, 5622, 27, 'सहेजें और बंद करें'),
(104606, 5624, 27, 'सहेजें और बांटना'),
(104607, 5625, 27, 'सहेजें और संचारित करें'),
(104608, 5626, 27, 'नए रूप में सहेजें'),
(104609, 5627, 27, 'नए नोट के रूप में सहेजें'),
(104610, 5628, 27, 'प्रमाणपत्र जमावट सहेजें'),
(104611, 5629, 27, 'परिवर्तन सहेजें'),
(104612, 5630, 27, 'प्रपत्र सहेजें'),
(104613, 5631, 27, 'टीकाकरण सहेजें'),
(104614, 5632, 27, 'नई फील्ड सहेजें'),
(104615, 5633, 27, 'नया समूह सहेजें'),
(104616, 5634, 27, 'नई सूची सहेजें'),
(104617, 5635, 27, 'नई टेम्पलेट सहेजें'),
(104618, 5636, 27, 'चयन चूक को सहेजें'),
(104619, 5637, 27, 'रोगी जनसांख्यिकी सहेजें'),
(104620, 5638, 27, 'चार्ट ID के लिए सहेजें सफल'),
(104621, 5639, 27, 'लेनदेन सहेजें'),
(104622, 5641, 27, 'स्कैन किए गए'),
(104623, 5642, 27, 'मुठभेड़ नोट स्कैन किए'),
(104624, 5643, 27, 'स्कैनर निर्देशिका'),
(104625, 5644, 27, 'स्कैनर'),
(104626, 5645, 27, 'अनुसूची'),
(104627, 5646, 27, 'अनुसूची सुविधाएं:'),
(104628, 5647, 27, 'स्कूल नोट'),
(104629, 5648, 27, 'पार्श्वकुब्जता'),
(104630, 5651, 27, 'SE'),
(104631, 5652, 27, 'SE पता'),
(104632, 5653, 27, 'SE सिटी'),
(104633, 5654, 27, 'SE देश'),
(104634, 5655, 27, 'SE लोकैलिटी'),
(104635, 5656, 27, 'SE कोड'),
(104636, 5657, 27, 'SE राज्य'),
(104637, 5658, 27, 'SE ज़िप कोड'),
(104638, 5659, 27, 'खोजें'),
(104639, 5661, 27, 'खोजें'),
(104640, 5662, 27, 'फिर से खोजें'),
(104641, 5663, 27, 'सभी कॉलम खोजें'),
(104642, 5664, 27, 'के द्वारा खोजें:'),
(104643, 5665, 27, 'के लिए खोजें'),
(104644, 5666, 27, 'के लिए खोजें:'),
(104645, 5667, 27, 'में खोजें'),
(104646, 5668, 27, 'में खोजें'),
(104647, 5669, 27, 'खोजें या जोड़ें रोगी'),
(104648, 5670, 27, 'भुगतान खोजें'),
(104649, 5671, 27, 'परिणाम खोजें'),
(104650, 5672, 27, 'परिणाम खोजें:'),
(104651, 5673, 27, 'चुनी गई खोजें'),
(104652, 5674, 27, 'खोज स्ट्रिंग डेटाबेस में सूची के साथ मेल नहीं खाता'),
(104653, 5675, 27, 'खोज स्ट्रिंग कम से कम तीन अक्षर होना चाहिए'),
(104654, 5676, 27, 'खोजें पाठ'),
(104655, 5677, 27, 'घटनाक्रम खोजें'),
(104656, 5678, 27, 'खोजें / जोड़ें'),
(104657, 5679, 27, 'खोजें / बीमाकर्ता जोड़ें'),
(104658, 5680, 27, 'नियुक्तियों के लिए खोजें'),
(104659, 5681, 27, 'खोज रहा है ...'),
(104660, 5682, 27, 'सीट बेल्ट का प्रयोग करें'),
(104661, 5683, 27, 'सीट बेल्ट का उपयोग करें'),
(104662, 5684, 27, 'द्वितीय'),
(104663, 5687, 27, 'द्वितीयक'),
(104664, 5688, 27, 'द्वितीयक बीमा'),
(104665, 5689, 27, 'द्वितीयक बीमा डाटा'),
(104666, 5690, 27, 'द्वितीयक बीमा प्रदाता'),
(104667, 5691, 27, 'द्वितीयक चिकित्सा प्रकार'),
(104668, 5698, 27, 'सुरक्षा'),
(104669, 5699, 27, 'सभी देखें'),
(104670, 5700, 27, 'प्राधिकरण देखें'),
(104671, 5701, 27, 'ग्रोथ चार्ट देखें'),
(104672, 5702, 27, 'उत्पन्न दावों के अंतिम सेट से संदेश देखें'),
(104673, 5704, 27, 'के बाद से देखा'),
(104674, 5705, 27, 'अनुभाग का नाम'),
(104675, 5706, 27, 'अनुभाग बैच दावा'),
(104676, 5707, 27, 'बरामदगी'),
(104677, 5708, 27, 'Sel'),
(104678, 5709, 27, 'चयन'),
(104679, 5710, 27, 'चयन'),
(104680, 5712, 27, 'एक संदर्भ का चयन करें'),
(104681, 5713, 27, 'एक प्रतिशत पंक्तियों चुनें या या तिथियाँ का चयन करें'),
(104682, 5714, 27, 'एक समय अवधि का चयन करें'),
(104683, 5715, 27, 'एक उपयोगकर्ता का चयन करें'),
(104684, 5716, 27, 'सभी चुनें'),
(104686, 5720, 27, 'श्रेणी का चयन करें'),
(104687, 5722, 27, 'हटाने के लिए संगत चेकबॉक्स चुनें'),
(104688, 5723, 27, 'हटाने के लिए मापदंडों का चयन करें'),
(104689, 5724, 27, 'CSV तालिका का चयन करें'),
(104690, 5725, 27, 'De Identification के लिए आवश्यक डाटा चयन करें'),
(104691, 5726, 27, 'De Identified डेटा में शामिल करने के लिए डेटा चयन करें'),
(104692, 5727, 27, 'तिथि का चयन करें'),
(104693, 5728, 27, 'इच्छित दस्ते का चयन करें'),
(104694, 5729, 27, 'निदान का चयन करें'),
(104695, 5730, 27, 'डी पहचान अनुरोध के लिए निदान का चयन करें'),
(104696, 5731, 27, 'दवाओं का चयन करें'),
(104697, 5732, 27, 'दवाओं का चयन करें'),
(104698, 5733, 27, 'डी पहचान अनुरोध के लिए ड्रग्स का चयन करें'),
(104699, 5734, 27, 'ईडीआई-271 फ़ाइल चुनें'),
(104700, 5736, 27, 'क्षेत्र चुनें'),
(104701, 5737, 27, 'क्षेत्र चुनें'),
(104702, 5738, 27, 'छपाई के लिए चयन करें'),
(104703, 5739, 27, 'टीकाकरण का चयन करें'),
(104704, 5740, 27, 'डी पहचान अनुरोध के लिए टीकाकरण का चयन करें'),
(104705, 5741, 27, 'टाइप करके, बीमा का चयन करें'),
(104706, 5742, 27, 'समस्या चुनें'),
(104707, 5744, 27, 'भाषा चुने'),
(104708, 5745, 27, 'एक का चयन करें'),
(104709, 5746, 27, 'सेवा का औचित्य साबित करने के लिए एक या एक से अधिक निदान कोड का चयन करें'),
(104710, 5747, 27, 'अपलोड करने के लिए एक या एक से अधिक फाइलों का चयन करें'),
(104711, 5754, 27, 'निर्यात करने के लिए विन्यास आइटम्स का चयन करें'),
(104712, 5755, 27, 'इस दिन,चूक गए घटनाओं के लिए मुख्य रूप से जिम्मेदार, मुद्दे का चयन करें'),
(104713, 5759, 27, 'चुनें प्रयोक्ता'),
(104714, 5760, 27, 'ड्रॉपडाउन सूची से उपयोगकर्ता चुनें'),
(104715, 5761, 27, 'कोई भाषा का चयन करें, यदि कोई हो, लॉग इन पर चुना जा सकता है. (केवल उचित अगर ऊपर सभी भाषाएँ बंद कर दिया है तो)'),
(104716, 5762, 27, 'समूह हटाने की पुष्टि करने के लिए हाँ का चयन करें'),
(104717, 5765, 27, 'चयनित'),
(104718, 5766, 27, 'चयनित मुठभेड़'),
(104719, 5767, 27, 'इसका चयन करना एक संदेश पैदा करेगा, लिए जिसे व्यक्तिगत रूप से प्रत्येक प्राप्तकर्ता के द्वारा संसाधित करने की आवश्यकता है. (यह एक समूह काम नहीं है).'),
(104720, 5768, 27, 'स्वयं'),
(104721, 5769, 27, 'स्वयं को अदा करें'),
(104722, 5771, 27, 'भेजें'),
(104723, 5772, 27, 'एक दिनांकित अनुस्मारक भेजें'),
(104724, 5773, 27, 'एक अनुस्मारक भेजें'),
(104725, 5774, 27, 'भेजें प्रगति पर'),
(104726, 5775, 27, 'संदेश भेजें'),
(104727, 5776, 27, 'अनुस्मारक बैच भेजें'),
(104728, 5777, 27, 'निवारक / अनुवर्ती कार्रवाई की देखभाल के लिए रोगी वरीयता प्रति रोगियों को अनुस्मारक भेजें.'),
(104729, 5778, 27, 'सिफ़ारिशों के साथ सारांश भेजें'),
(104730, 5779, 27, 'इस फाइल को भेजें'),
(104731, 5780, 27, 'यह संदेश भेजें'),
(104732, 5781, 27, 'को भेजें'),
(104733, 5784, 27, 'सभी को भेजें'),
(104734, 5788, 27, 'प्रेषक'),
(104735, 5789, 27, 'प्रेषक ID'),
(104736, 5790, 27, 'प्रेषक ID (ISA06)'),
(104737, 5791, 27, 'प्रेषक ID क्वालीफायर (ISA05)'),
(104738, 5792, 27, 'प्रेषक IDs के'),
(104739, 5793, 27, 'के लिए भेजा जा रहा है'),
(104740, 5794, 27, 'संवेदनशीलता'),
(104741, 5795, 27, 'संवेदनशीलता:'),
(104742, 5796, 27, 'संवेदी परीक्षा सामान्य'),
(104743, 5797, 27, 'भेजे गए'),
(104744, 5799, 27, 'द्वारा भेजे गए, सभी के लिए खाली छोड़ें'),
(104745, 5801, 27, 'तिथि भेजी गई'),
(104746, 5802, 27, 'आइटम भेजे गए'),
(104747, 5803, 27, 'मेडिकल रिकॉर्ड्स भेजा है?'),
(104748, 5804, 27, 'सफलतापूर्वक भेजा'),
(104749, 5807, 27, 'प्रिंटर के लिए भेजा.'),
(104750, 5808, 27, 'सभी के लिए खाली छोड़ दें, के लिए भेजा'),
(104751, 5810, 27, 'भेजा है, लेकिन अभी तक पुष्टि नहीं की.'),
(104752, 5811, 27, 'भेजा गया, प्राप्त नहीं'),
(104753, 5812, 27, 'सितंबर'),
(104754, 5813, 27, 'अलग किए गए'),
(104755, 5814, 27, 'सितंबर'),
(104756, 5815, 27, 'seq'),
(104757, 5816, 27, 'अनुक्रम'),
(104758, 5818, 27, 'Serv Rep'),
(104759, 5821, 27, 'सेवा'),
(104760, 5822, 27, 'सेवा श्रेणी'),
(104761, 5823, 27, 'सेवा संहिता'),
(104762, 5824, 27, 'सेवा संहिता वित्त रिपोर्टिंग'),
(104763, 5825, 27, 'सेवा संहिताएं'),
(104764, 5826, 27, 'सेवा दिनांक'),
(104765, 5827, 27, 'सेवा दिनांक:'),
(104766, 5829, 27, 'सेवा स्थान'),
(104767, 5830, 27, 'सेवा का नाम'),
(104768, 5831, 27, 'विशेषज्ञ द्वारा प्रदान की सेवा'),
(104769, 5832, 27, 'सेवा रिपोर्टिंग'),
(104770, 5833, 27, 'केवल रिपोर्टिंग सेवा'),
(104771, 5834, 27, 'सेवाएं'),
(104772, 5835, 27, 'श्रेणी द्वारा सेवाएं'),
(104773, 5836, 27, 'प्रदान की सेवाएं'),
(104774, 5837, 27, 'प्रदान की सेवाएं'),
(104775, 5838, 27, 'सेवाएं /उत्पादों के'),
(104776, 5839, 27, 'सत्र प्रकार'),
(104777, 5840, 27, 'समूह'),
(104778, 5841, 27, 'लॉगिन के बीच चयनित सुविधा याद करने के लिए एक सुविधा कुकी सेट करें.'),
(104779, 5842, 27, 'पूर्ण के रूप में सेट करें'),
(104780, 5843, 27, 'CDR इंजन आधारित रिपोर्ट के लिए प्रसंस्करण प्राथमिकता सेट करें.'),
(104781, 5844, 27, '(पूर्ण क्लिनिक मोड में) रोगी अनुस्मारक के निर्माण के लिए प्रसंस्करण प्राथमिकता सेट करें.'),
(104782, 5845, 27, 'पूर्ण निरपेक्ष पथ पर सेट करें. HTTPS के लिए ग्राहक SSL प्रमाणपत्र बनाने के लिए.'),
(104783, 5846, 27, 'के लिए सेट'),
(104784, 5847, 27, 'डिफ़ॉल्ट सेट'),
(104785, 5848, 27, 'डेटाबेस में संस्करण संख्या सेट कर रहा है ...'),
(104786, 5849, 27, 'सेटिंग्स'),
(104787, 5851, 27, 'गंभीर माइग्रेन'),
(104788, 5853, 27, 'दर्द की तीव्रता'),
(104789, 5854, 27, 'दर्द की तीव्रता:'),
(104790, 5855, 27, 'लिंग'),
(104791, 5856, 27, 'यौन संचारित रोग'),
(104792, 5857, 27, 'SFTP'),
(104793, 5858, 27, 'शा -1 हैश'),
(104794, 5859, 27, 'सहभाजन'),
(104795, 5860, 27, 'सर्वर से छपाई के लिए शैल कमांड.'),
(104796, 5863, 27, 'लघु विवरण'),
(104797, 5864, 27, 'सांस की तकलीफ'),
(104798, 5865, 27, 'सांस की तकलीफ'),
(104799, 5866, 27, 'सांस की तकलीफ 2'),
(104800, 5867, 27, 'लघु रिकॉर्ड'),
(104801, 5868, 27, 'तक लघु रिकॉर्ड'),
(104802, 5870, 27, 'nnnnn-nnnn-nn तरह होना चाहिए'),
(104803, 5871, 27, 'दो पत्र होने चाहिए'),
(104804, 5872, 27, '10 अंक होने चाहिए'),
(104805, 5873, 27, 'केवल 10 अंक होने चाहिए'),
(104806, 5874, 27, 'कंधा'),
(104807, 5875, 27, 'कंधा + हंसली'),
(104808, 5876, 27, 'कंधे की समस्या'),
(104809, 5877, 27, 'प्रदर्शन'),
(104810, 5878, 27, 'सक्रिय दिखाएँ'),
(104811, 5880, 27, 'सभी दिखाएँ'),
(104812, 5881, 27, 'सभी प्रक्रियाओं को दिखाएँ'),
(104813, 5883, 27, 'सभी लेनदेन दिखाएँ'),
(104814, 5884, 27, 'व्यस्त दिखाएँ'),
(104815, 5885, 27, 'केवल अधिकृत दिखाएँ'),
(104816, 5886, 27, 'उपलब्ध समय दिखाएँ'),
(104817, 5887, 27, 'अमेरिका और मीट्रिक दोनों दिखाएँ (मुख्य इकाई मीट्रिक है)'),
(104818, 5888, 27, 'अमेरिका और मीट्रिक दोनों दिखाएँ (मुख्य इकाई अमेरिका है)'),
(104819, 5889, 27, 'विवरण दिखाएँ'),
(104820, 5890, 27, 'केवल त्रुटियों को दिखाएँ?'),
(104821, 5891, 27, 'ग्राफ़ दिखाएं'),
(104822, 5892, 27, 'Mouseover पर मँडरा घटना पाठ दिखाएं?'),
(104823, 5893, 27, 'व्यवस्थापक पृष्ठों पर कितने घटनाओं को दिखाएं?'),
(104824, 5894, 27, 'निष्क्रिय दिखाएँ'),
(104825, 5896, 27, 'मेनू दिखाएं'),
(104826, 5897, 27, 'मीट्रिक ही दिखाएँ'),
(104827, 5898, 27, 'टिप्पणी दिखाएँ'),
(104828, 5900, 27, 'केवल न छोड़े गए प्रक्रियाओं को दिखाएँ'),
(104829, 5901, 27, 'रोगी टिप्पणी दिखाएँ'),
(104830, 5902, 27, 'पाउंड और औंस दिखाएँ'),
(104831, 5903, 27, 'दशमलव मान के रूप में पाउंड दिखाएँ'),
(104832, 5904, 27, 'प्राथमिक पूरा दिखाएँ'),
(104833, 5905, 27, 'अनुस्मारक दिखाएँ'),
(104834, 5906, 27, 'रिपोर्ट दिखाएँ'),
(104835, 5907, 27, 'खोज / पेश लिंक ब्लॉक में दिखाएँ?'),
(104836, 5910, 27, 'सूची जोड़ें विजेट के लिए कस्टम राज्य प्रपत्र (शीर्षक और संक्षिप्त के लिए पूछेंगे) दिखाएँ.'),
(104837, 5911, 27, 'मरीज ​​सारांश स्क्रीन पर यह श्रेणी दिखाये, भले ही इस श्रेणी के लिए कोई समस्या नहीं दर्ज किया गया है.'),
(104838, 5913, 27, 'केवल unbilled दिखाएँ'),
(104839, 5914, 27, 'अमेरिका ही दिखाएँ'),
(104840, 5915, 27, 'दिखा रहा है'),
(104841, 5916, 27, 'परिणाम दिखा रहा है'),
(104842, 5920, 27, 'सहोदर'),
(104843, 5921, 27, 'सिकल सेल'),
(104844, 5922, 27, 'हस्ताक्षर'),
(104845, 5923, 27, 'Sigmoid/Colonoscopy'),
(104846, 5925, 27, 'प्रयोगशाला के परिणाम पर हस्ताक्षर (addonly वैकल्पिक, लिखने)'),
(104847, 5926, 27, 'परिणाम पर हस्ताक्षर'),
(104848, 5927, 27, 'हस्ताक्षर'),
(104849, 5929, 27, 'हस्ताक्षर:'),
(104850, 5930, 27, 'Rx पर हस्ताक्षर किए'),
(104851, 5932, 27, 'उल्लेखनीय सूजन:'),
(104852, 5933, 27, 'सरलीकृत'),
(104853, 5934, 27, 'सरलीकृत सह भुगतान'),
(104854, 5935, 27, 'सरलीकृत जनसांख्यिकी'),
(104855, 5936, 27, 'सरलीकृत नुस्खे'),
(104856, 5937, 27, 'तब से'),
(104857, 5938, 27, 'निष्ठा से,'),
(104858, 5940, 27, 'एक'),
(104859, 5941, 27, 'एकल चयन सूची'),
(104860, 5942, 27, 'सूची में जोड़ने के क्षमता के साथ एकल चयन सूची'),
(104861, 5943, 27, 'एकमात्र'),
(104862, 5946, 27, 'साइनस की समस्या'),
(104863, 5947, 27, 'साइनस सर्जरी'),
(104864, 5948, 27, 'साइनस Tenderness:'),
(104865, 5949, 27, 'शिरानालशोथ'),
(104866, 5950, 27, 'स्थल'),
(104867, 5951, 27, 'स्थल ID'),
(104868, 5952, 27, 'मैडिकल इन्फोर्मेशन इंटीग्रेशन, LLC लैब विनिमय सेवा के लिए साइट ID.');
INSERT INTO `lang_definitions` VALUES
(104869, 5953, 27, 'LibreEHR समर्थन LLC लैब विनिमय सेवा के लिए साइट ID.'),
(104870, 5956, 27, 'आकार'),
(104871, 5957, 27, 'आकार 1 और 999 के बीच में होनी चाहिए'),
(104872, 5958, 27, 'आकार / सूची'),
(104873, 5959, 27, 'त्वचा'),
(104874, 5960, 27, 'त्वचा कैंसर'),
(104875, 5961, 27, 'त्वचा रोग'),
(104876, 5962, 27, 'त्वचा अन्य'),
(104877, 5963, 27, 'रोगी टिप्पणी का प्राधिकरण छोड़ें'),
(104878, 5964, 27, 'अनुभाग छोड़ा जा रहा'),
(104879, 5965, 27, 'SQL लेजर डंप छोड़ा जा रहा - विंडोज सर्वर के लिए लागू नहीं'),
(104880, 5967, 27, 'सोने की प्रवृत्ति'),
(104881, 5968, 27, 'सोने की प्रवृत्ति'),
(104882, 5969, 27, 'शयन'),
(104883, 5970, 27, 'स्लोवाक देश'),
(104884, 5972, 27, 'SM ऋण w / o'),
(104885, 5973, 27, 'समझदार कैश साफ कर दिया गया है'),
(104886, 5974, 27, 'धूम्रपान करनेवाला, वर्तमान स्थिति अज्ञात'),
(104887, 5976, 27, 'धूम्रपान की स्थिति'),
(104888, 5977, 27, 'SMS Auth'),
(104889, 5978, 27, 'SMS गेटवे'),
(104890, 5979, 27, 'SMS गेटवे API कुंजी'),
(104891, 5980, 27, 'SMS गेटवे API कुंजी'),
(104892, 5981, 27, 'SMS गेटवे पारण'),
(104893, 5982, 27, 'SMS गेटवे उपयोगकर्ता नाम'),
(104894, 5983, 27, 'SMS अधिसूचना'),
(104895, 5984, 27, 'SMS अधिसूचना घंटे'),
(104896, 5985, 27, 'से पहले SMS भेजा'),
(104897, 5986, 27, 'SMS भेजा'),
(104898, 5987, 27, 'SMS पाठ, उपयोगी टैग: ***NAME***, ***PROVIDER***, ***DATE***, ***STARTTIME***, ***ENDTIME***<br> i.e. Dear ***NAME***'),
(104899, 5988, 27, 'SMS के / ईमेल अलर्ट सेटिंग'),
(104900, 5989, 27, 'प्रमाणीकरण के लिए SMTP पारण'),
(104901, 5992, 27, 'SMTP सर्वर होस्ट नाम'),
(104902, 5993, 27, 'SMTP सर्वर पोर्ट नंबर'),
(104903, 5994, 27, 'प्रमाणीकरण के लिए SMTP उपयोगकर्ता'),
(104904, 5995, 27, 'SNOMED'),
(104905, 5996, 27, 'SNOMED (RF1) नैदानिक ​​शब्द'),
(104906, 5997, 27, 'SNOMED (RF1) निदान'),
(104907, 5998, 27, 'SNOMED (RF1) प्रक्रिया'),
(104908, 5999, 27, 'SNOMED (RF2) निदान'),
(104909, 6000, 27, 'SNOMED नैदानिक ​​शब्द'),
(104910, 6001, 27, 'SNOMED डाटाबेस'),
(104911, 6002, 27, 'SNOMED निदान'),
(104912, 6003, 27, 'SNOMED प्रक्रिया'),
(104913, 6004, 27, 'खर्राटे'),
(104914, 6005, 27, 'SOAP'),
(104915, 6006, 27, 'सामाजिक कठिनाइयों'),
(104916, 6009, 27, 'सामाजिक इतिहास:'),
(104917, 6010, 27, 'सामाजिक सुरक्षा नंबर'),
(104918, 6011, 27, 'समाधान'),
(104919, 6013, 27, 'सोमेटिक संदर्भ'),
(104920, 6014, 27, 'कुछ प्राधिकरण प्रदर्शित नहीं. सभी को देखने के लिए यहां क्लिक करें'),
(104921, 6015, 27, 'कुछ कोड प्रदर्शित नहीं.'),
(104922, 6016, 27, 'कुछ मुठभेड़ प्रदर्शित नहीं. सभी को देखने के लिए यहां क्लिक करें.'),
(104923, 6017, 27, 'कुछ त्रुटि De Identification की प्रक्रिया के दौरान उत्पन्न हुई'),
(104924, 6018, 27, 'कुछ नोट्स प्रदर्शित नहीं.'),
(104925, 6019, 27, 'कुछ कार्यालय नोट्स प्रदर्शित नहीं. सभी को देखने के लिए यहां क्लिक करें.'),
(104926, 6020, 27, 'कुछ शब्द'),
(104927, 6023, 27, 'कुछ गलत हो गया. पुन: प्रयास करें.'),
(104928, 6024, 27, 'जल्द ही लंबित अंतराल (क्लीनिकल अनुस्मारक)'),
(104929, 6025, 27, 'जल्द ही लंबित अंतराल (रोगी अनुस्मारक)'),
(104930, 6026, 27, 'गले में ख़राश'),
(104931, 6027, 27, 'क्षमा कोई नियुक्ति तय नहीं हो गई है'),
(104932, 6028, 27, 'क्षमा करें, आपकी फ़ाइल अपलोड करने में कोई समस्या थी'),
(104933, 6029, 27, 'क्रमबद्ध करें'),
(104934, 6030, 27, 'क्रमबद्ध करें'),
(104935, 6031, 27, 'क्रमबद्ध Checksum द्वारा क्रमबद्ध करें'),
(104936, 6032, 27, 'टिप्पणियाँ द्वारा क्रमबद्ध करें'),
(104937, 6033, 27, 'Crt प्रयोक्ता द्वारा क्रमबद्ध करें'),
(104938, 6034, 27, 'तिथि द्वारा क्रमबद्ध करें'),
(104939, 6035, 27, 'तिथि / समय द्वारा क्रमबद्ध करें'),
(104940, 6036, 27, 'घटना द्वारा क्रमबद्ध करें'),
(104941, 6037, 27, 'समूह द्वारा क्रमबद्ध करें'),
(104942, 6040, 27, 'PatientID द्वारा क्रमबद्ध करें'),
(104943, 6041, 27, 'क्रमबद्ध सफलता से'),
(104944, 6043, 27, 'उपयोगकर्ता द्वारा क्रमबद्ध करें'),
(104945, 6044, 27, 'टीकाकरण द्वारा क्रमबद्ध करें'),
(104946, 6045, 27, 'नीचे क्रमबद्ध करें'),
(104947, 6046, 27, 'परिणाम द्वारा क्रमबद्ध करें'),
(104948, 6047, 27, 'ऊपर क्रमबद्ध करें'),
(104949, 6048, 27, 'स्रोत'),
(104950, 6049, 27, 'स्रोत फ़ाइल'),
(104951, 6050, 27, 'स्रोत फ़ाइल पथ'),
(104952, 6051, 27, 'स्रोत कोड के लिए लापता है '),
(104953, 6052, 27, 'स्रोत लॉट'),
(104954, 6054, 27, 'स्रोत रोगी'),
(104955, 6055, 27, 'स्रोत रोगी को जन्म तिथि नहीं है'),
(104956, 6056, 27, 'स्रोत रोगी नहीं मिला'),
(104957, 6057, 27, 'स्रोत:'),
(104958, 6060, 27, 'अंतरिक्ष'),
(104959, 6061, 27, 'अंतरिक्ष'),
(104960, 6062, 27, 'स्पेनिश देश'),
(104961, 6063, 27, 'स्पेनिश (लैटिन अमेरिकी)'),
(104962, 6064, 27, 'स्पेनिश (स्पेन)'),
(104963, 6066, 27, 'विशेष वर्ण की अनुमति नहीं है'),
(104964, 6067, 27, 'नब्ज प्रपत्र के लिए विशेष उपचार'),
(104965, 6068, 27, 'विशेषज्ञ'),
(104966, 6069, 27, 'विशेषज्ञ का नाम और हस्ताक्षर'),
(104967, 6071, 27, 'विशेषता'),
(104968, 6072, 27, 'विशेषता प्रणाली'),
(104969, 6073, 27, 'विशेषता:'),
(104970, 6074, 27, 'विशिष्ट'),
(104971, 6075, 27, 'विशिष्ट अनुप्रयोग'),
(104972, 6076, 27, 'विशिष्ट गर्भनिरोधक सेवा'),
(104973, 6077, 27, 'विशिष्ट परिणाम'),
(104974, 6078, 27, 'विशिष्ट सेवा'),
(104975, 6079, 27, 'निर्दिष्ट'),
(104976, 6080, 27, 'Specifies formatting for codes. # = digit, * = any character. Empty if not used.'),
(104977, 6081, 27, 'Specifies formatting for codes. # = digit, @ = alpha, * = any character. Empty if not used.'),
(104978, 6082, 27, 'Specifies formatting for invoice reference numbers. # = digit, * = any character. Empty if not used.'),
(104979, 6083, 27, 'Specifies formatting for invoice reference numbers. # = digit, @ = alpha, * = any character. Empty if not used.'),
(104980, 6084, 27, 'Specifies formatting for product NDC fields. # = digit, * = any character. Empty if not used.'),
(104981, 6085, 27, 'Specifies formatting for product NDC fields. # = digit, @ = alpha, * = any character. Empty if not used.'),
(104982, 6086, 27, 'Specifies formatting for the external patient ID. # = digit, * = any character. Empty if not used.'),
(104983, 6087, 27, 'Specifies formatting for the external patient ID. # = digit, @ = alpha, * = any character. Empty if not used.'),
(104984, 6088, 27, 'नमूना'),
(104985, 6089, 27, 'नमूना संख्या / पहचानकर्ता'),
(104986, 6090, 27, 'नमूना प्रकार'),
(104987, 6092, 27, 'भाषण श्रुतलेख'),
(104988, 6093, 27, 'शुक्राणुनाशक'),
(104989, 6094, 27, 'स्प्लेनेक्टोमी'),
(104990, 6095, 27, 'पति'),
(104991, 6097, 27, 'थूक'),
(104992, 6098, 27, 'थूक:'),
(104993, 6099, 27, 'SQ'),
(104994, 6102, 27, 'दस्ता'),
(104995, 6103, 27, 'दस्ते सदस्यता'),
(104996, 6104, 27, 'दस्ते'),
(104997, 6105, 27, 'SRH'),
(104998, 6106, 27, 'SRH - परिवार नियोजन'),
(104999, 6107, 27, 'SRH गैर परिवार नियोजन'),
(105000, 6108, 27, 'SRH सिफ़ारिशें'),
(105001, 6109, 27, 'SRH भेंट प्रपत्र'),
(105002, 6110, 27, 'SRV तिथि'),
(105003, 6111, 27, 'SS'),
(105004, 6112, 27, 'SSL प्रमाणपत्र प्रशासन'),
(105005, 6113, 27, 'SSN'),
(105006, 6114, 27, 'स्थिरता'),
(105007, 6115, 27, 'रिलीज स्टेज्ड'),
(105008, 6116, 27, 'मानक'),
(105009, 6117, 27, 'मानक कोड'),
(105010, 6118, 27, 'मानक उपाय'),
(105011, 6119, 27, 'मानक उपाय (सक्रिय अलर्ट)'),
(105012, 6120, 27, 'मानक उपाय (निष्क्रिय अलर्ट)'),
(105013, 6121, 27, 'मानक उपाय (रोगी अनुस्मारक)'),
(105014, 6122, 27, 'मानक नाम'),
(105015, 6123, 27, 'Standard; Simplified: only title, start date, comments and an Active checkbox;no diagnosis, occurrence, end date, referred-by or sports fields. ; Football Injury'),
(105016, 6124, 27, 'प्रारंभ'),
(105017, 6125, 27, 'प्रारंभ (YYYY-MM-DD) : '),
(105018, 6126, 27, 'एक अन्य रिपोर्ट प्रारंभ'),
(105019, 6128, 27, 'प्रारंभ तिथि'),
(105020, 6129, 27, 'इस क्लिनिक में प्रारंभ तिथि'),
(105021, 6130, 27, 'प्रारंभ तिथि समाप्ति तिथि से बड़ा नहीं होना चाहिए'),
(105022, 6131, 27, 'प्रारंभ तिथि:'),
(105023, 6132, 27, 'प्रारंभ तिथि:'),
(105024, 6133, 27, 'प्रारंभ समय'),
(105025, 6134, 27, 'तिथि शुरू'),
(105026, 6135, 27, 'stat'),
(105027, 6136, 27, 'राज्य'),
(105028, 6137, 27, 'राज्य डेटा प्रकार'),
(105029, 6138, 27, 'राज्य एलआईसी. #'),
(105030, 6139, 27, 'राज्य लाइसेंस संख्या'),
(105031, 6140, 27, 'राज्य सूची'),
(105032, 6141, 27, 'राज्य सूची (addonly वैकल्पिक लिखने)'),
(105033, 6142, 27, 'राज्य सूची विजेट कस्टम फील्ड्स'),
(105034, 6143, 27, 'राज्य या प्रांत'),
(105035, 6144, 27, 'राज्य / इलाका'),
(105036, 6145, 27, 'राज्य / पैरिश'),
(105037, 6146, 27, 'बयान सारांश'),
(105038, 6147, 27, 'बयान और अद्यतन चालान.'),
(105039, 6148, 27, 'भेजे गए बयान:'),
(105040, 6149, 27, 'बयान; चालान अद्यतन नहीं किया जाएगा.'),
(105041, 6150, 27, 'स्टेटिक पाठ'),
(105042, 6151, 27, 'आंकड़े'),
(105043, 6152, 27, 'आँकड़े'),
(105044, 6153, 27, 'स्थिति'),
(105045, 6154, 27, 'प्रवेश की स्थिति'),
(105046, 6155, 27, 'दावे की स्थिति'),
(105047, 6156, 27, 'यथास्थिति'),
(105048, 6158, 27, 'STD / AIDS Couns'),
(105049, 6159, 27, 'Stength और कंडीशनिंग'),
(105050, 6164, 27, 'DSM IV डेटाबेस को स्थापित करने के लिए कदम'),
(105051, 6165, 27, 'आईसीडी 10 डेटाबेस को स्थापित करने के लिए कदम'),
(105052, 6166, 27, 'आईसीडी 9 डेटाबेस को स्थापित करने के लिए कदम'),
(105053, 6167, 27, 'RxNorm डेटाबेस को स्थापित करने के लिए कदम'),
(105054, 6168, 27, 'Snomed डेटाबेस को स्थापित करने के लिए कदम'),
(105055, 6169, 27, 'कड़े जोड़'),
(105056, 6170, 27, 'कठोरता'),
(105057, 6171, 27, 'स्टॉक महीने'),
(105058, 6172, 27, 'पेट में दर्द'),
(105059, 6174, 27, 'संग्रहित हैश'),
(105060, 6175, 27, 'मांसपेशियों का तनाव'),
(105061, 6176, 27, 'धारा'),
(105062, 6177, 27, 'सड़क'),
(105063, 6178, 27, 'सड़क पता'),
(105064, 6179, 27, 'सड़क और संख्या'),
(105065, 6180, 27, 'शक्ति'),
(105066, 6182, 27, 'strep गले का'),
(105067, 6183, 27, 'तनाव अस्थिभंग'),
(105068, 6184, 27, 'तनाव टेस्ट'),
(105069, 6185, 27, 'स्ट्रोक'),
(105070, 6186, 27, 'मजबूत पासवर्ड का मतलब है कम से कम 8 वर्ण, और निम्न में से कम से कम तीन: एक नंबर, एक छोटा अक्षर, एक अपरकेस पत्र, एक विशेष चरित्र.'),
(105071, 6187, 27, 'शैली'),
(105072, 6188, 27, 'नए रोगियों को जोड़ने के लिए इस्तेमाल की प्रपत्र की शैली'),
(105073, 6189, 27, 'उप-श्रेणी'),
(105074, 6190, 27, 'उप - कुल'),
(105075, 6191, 27, 'उपश्रेणी'),
(105076, 6192, 27, 'उपश्रेणी'),
(105077, 6193, 27, 'subcutaneously'),
(105078, 6194, 27, 'विषय'),
(105079, 6195, 27, 'आत्मनिष्ठ'),
(105080, 6196, 27, 'sublingual'),
(105081, 6197, 27, 'sublingual'),
(105082, 6198, 27, 'जमा करना'),
(105083, 6199, 27, 'जमा करना'),
(105084, 6200, 27, 'सभी सामग्री जमा करें'),
(105085, 6202, 27, 'घटना जमा करें'),
(105086, 6203, 27, 'प्रपत्र जमा करें'),
(105087, 6204, 27, 'चुना गया कंटेन्ट जमा करें'),
(105088, 6205, 27, 'जमा किया'),
(105089, 6206, 27, 'द्वारा जमा किया'),
(105090, 6207, 27, 'जमाकर्ता ईडीआई पहुंच नंबर (PER06)'),
(105091, 6208, 27, 'अभिदाता'),
(105092, 6209, 27, 'अभिदाता पता'),
(105093, 6213, 27, 'अभिदाता नियोक्ता'),
(105094, 6214, 27, 'अभिदाता नियोक्ता (एसई)'),
(105095, 6215, 27, 'अभिदाता नियोक्ता पता'),
(105096, 6216, 27, 'अभिदाता नियोक्ता सिटी'),
(105097, 6217, 27, 'अभिदाता नियोक्ता देश'),
(105098, 6218, 27, 'अभिदाता नियोक्ता राज्य'),
(105099, 6221, 27, 'अभिदाता नियोक्ता पिन कोड'),
(105100, 6225, 27, 'अभिदाता फोन'),
(105101, 6226, 27, 'अभिदाता रिश्ता'),
(105102, 6227, 27, 'अभिदाता संबंध स्वयं नहीं है लेकिन नाम एक ही है! यह वास्तव में ठीक है?'),
(105103, 6228, 27, 'अभिदाता संबंध स्वयं नहीं है लेकिन SS संख्या एक ही है!'),
(105104, 6229, 27, 'अभिदाता संबंध स्वयं है लेकिन नाम अलग है! यह वास्तव में ठीक है?'),
(105105, 6230, 27, 'अभिदाता संबंध स्वयं है लेकिन SS संख्या अलग है!'),
(105106, 6231, 27, 'अभिदाता लिंग'),
(105107, 6237, 27, 'प्रतिस्थापन'),
(105108, 6238, 27, 'अनुमति दी प्रतिस्थापन की'),
(105109, 6240, 27, 'सफलता'),
(105110, 6241, 27, 'सफलता'),
(105111, 6242, 27, 'प्रयोगशाला परिणाम की सफलता की पुष्टि रसीद'),
(105112, 6243, 27, 'प्रयोगशाला के परिणाम प्राप्ति में सफलता'),
(105113, 6244, 27, 'लैब एक्सचेंज नेटवर्क से परिणाम प्राप्ति में सफलता'),
(105114, 6246, 27, 'सफलतापूर्वक श्रेणी जोड़ा'),
(105115, 6247, 27, 'सफलतापूर्वक, श्रेणी में जोड़ा'),
(105116, 6248, 27, 'सफलतापूर्वक नष्ट कर दिया'),
(105117, 6250, 27, 'सफलतापूर्वक डेटाबेस स्थापित.'),
(105118, 6251, 27, 'सफलतापूर्वक निम्न डेटाबेस स्थापित'),
(105119, 6252, 27, 'सफलतापूर्वक संशोधित'),
(105120, 6253, 27, 'सफलतापूर्वक सहेजा गया. आप आवंटित करना चाहेंगे?'),
(105121, 6254, 27, 'सफलतापूर्वक सहेजा गया. आप वितरित करना चाहते हैं?'),
(105122, 6256, 27, 'सफलतापूर्वक संग्रहीत.'),
(105123, 6257, 27, 'सफलतापूर्वक डेटाबेस का उन्नयन.'),
(105124, 6258, 27, 'सफलतापूर्वक निम्न डेटाबेस उन्नत बनाया'),
(105125, 6259, 27, 'सफलतापूर्वक.'),
(105126, 6260, 27, 'आत्महत्या'),
(105127, 6261, 27, 'सारांश'),
(105128, 6262, 27, 'का सारांश'),
(105129, 6265, 27, 'Sun'),
(105130, 6267, 27, 'रविवार'),
(105131, 6268, 27, 'Superbill'),
(105132, 6269, 27, 'Superbill संहिताएं'),
(105133, 6270, 27, 'Superbill संहिताएं प्रशासन'),
(105134, 6271, 27, 'Superbill रिपोर्ट'),
(105135, 6272, 27, 'Superbill / शुल्क शीट'),
(105136, 6273, 27, 'Superbills'),
(105137, 6274, 27, 'Superbills कभी कभी मुठभेड़ प्रपत्र या रूटिंग स्लिप्स के रूप में संदर्भित किया जाता है, अधिकांश चिकित्सा पद्धतियों का एक आवश्यक हिस्सा हैं.'),
(105138, 6275, 27, 'उत्कृष्ट उपयोगकर्ता'),
(105139, 6276, 27, 'पर्यवेक्षण'),
(105140, 6278, 27, 'पर्यवेक्षण डॉक्टर डीईए'),
(105141, 6279, 27, 'पर्यवेक्षण डॉक्टर पहले नाम'),
(105142, 6280, 27, 'पर्यवेक्षण डॉक्टर अंतिम नाम'),
(105143, 6281, 27, 'पर्यवेक्षण डॉक्टर NPI'),
(105144, 6282, 27, 'पर्यवेक्षण डॉक्टर UPIN'),
(105145, 6283, 27, 'प्रदायक सुविधा नाम'),
(105146, 6284, 27, 'कई प्रदाताओं पर लागू होने वाली कैलेंडर घटनाओं का समर्थन करें'),
(105147, 6285, 27, 'बैकअप पृष्ठ के माध्यम से विन्यास डेटा का आयात /निर्यात समर्थन करें.'),
(105148, 6286, 27, 'मल्टी प्रदाता घटनाक्रम का समर्थन करें'),
(105149, 6288, 27, 'TripleDES एन्क्रिप्शन / डिक्रिप्शन ही समर्थन करता है.'),
(105150, 6289, 27, 'भूतल के प्रकार'),
(105151, 6290, 27, 'सर्जरी'),
(105152, 6291, 27, 'सर्जरी'),
(105153, 6292, 27, 'सर्जरी समस्या सूची'),
(105154, 6293, 27, 'निलंबित'),
(105155, 6294, 27, 'निलंबन'),
(105156, 6295, 27, 'Svc तिथि'),
(105157, 6296, 27, 'Svc तिथि:'),
(105158, 6299, 27, 'पसीना:'),
(105159, 6300, 27, 'स्वीडिश देश'),
(105160, 6301, 27, 'सूजन'),
(105161, 6302, 27, 'सूजन अधिकार'),
(105162, 6303, 27, 'जोड़ों में सूजन'),
(105163, 6304, 27, 'सूजी हुई लिम्फ नोड्स'),
(105164, 6305, 27, 'मुद्रा के लिए दशमलव बिंदु के रूप में इस्तेमाल किया प्रतीक. दशमलव स्थान 0 है, तो उपयोग नहीं किया जाता.'),
(105165, 6306, 27, 'मुद्रा के लिए हजार अलग करने के लिए इस्तेमाल किया प्रतीक.'),
(105166, 6307, 27, 'लक्षण'),
(105167, 6308, 27, 'समकालित करें'),
(105168, 6309, 27, 'कस्टम भाषा तालिका के साथ अनुवाद समकालित करें.'),
(105169, 6310, 27, 'नए कस्टम निरंतर समकालित करें:'),
(105170, 6311, 27, 'नए कस्टम भाषा समकालित करें:'),
(105171, 6312, 27, 'नई परिभाषा (भाषा, स्थिर, परिभाषा) समकालित करें:'),
(105172, 6313, 27, 'बेहोशी'),
(105173, 6314, 27, 'संलक्षण निगरानी'),
(105174, 6315, 27, 'संलक्षण निगरानी - गैर मुद्दों की रिपोर्ट'),
(105175, 6316, 27, 'संलक्षण निगरानी रिपोर्ट'),
(105176, 6317, 27, 'श्लेषक कलाशोथ, चोट, स्नेहपुटीशोथ'),
(105177, 6318, 27, 'प्रणाली'),
(105178, 6322, 27, 'T'),
(105179, 6323, 27, 't.i.d.'),
(105180, 6324, 27, 'दूरदर्शन'),
(105181, 6325, 27, 'तालिका'),
(105182, 6327, 27, 'तालिका निर्माण विफल'),
(105183, 6328, 27, 'तालिका अद्यतन विफल'),
(105184, 6330, 27, 'गोली'),
(105185, 6332, 27, 'टेगलॉग'),
(105186, 6335, 27, 'लेना'),
(105187, 6336, 27, 'ड्रॉप डाउन से, बीमा ले'),
(105188, 6337, 27, 'ड्रॉप डाउन से, से भुगतान ले'),
(105189, 6338, 27, 'Takeback'),
(105190, 6339, 27, 'समय लेता है'),
(105191, 6340, 27, 'लंबा नेविगेशन क्षेत्र'),
(105192, 6344, 27, 'लक्ष्य और स्रोत जन्म तिथि से मेल नहीं खाते'),
(105193, 6345, 27, 'लक्ष्य और स्रोत pid ​​मेल नहीं खा सकता!'),
(105194, 6346, 27, 'लक्ष्य और स्रोत SSN मेल नहीं खाते'),
(105195, 6347, 27, 'लक्ष्य तिथि'),
(105196, 6348, 27, 'लक्ष्य रोगी'),
(105197, 6349, 27, 'लक्ष्य रोगी की कोई जन्म तिथि नहीं है'),
(105198, 6350, 27, 'लक्ष्य रोगी नहीं मिला'),
(105199, 6351, 27, 'टारगेट / कार्रवाई समूह'),
(105200, 6354, 27, 'कर आईडी'),
(105201, 6355, 27, 'कर की दर'),
(105202, 6356, 27, 'करों'),
(105203, 6357, 27, 'वर्गीकरण'),
(105204, 6358, 27, 'td'),
(105205, 6359, 27, 'टीम चोट अवलोकन'),
(105206, 6360, 27, 'टीम रोस्टर'),
(105207, 6361, 27, 'टीम रोस्टर देखें'),
(105208, 6362, 27, 'टीम / दस्ते'),
(105209, 6363, 27, 'Tel'),
(105210, 6364, 27, 'देश का टेलीफोन कोड'),
(105211, 6366, 27, 'अस्थायी'),
(105212, 6367, 27, 'अस्थायी स्थान'),
(105213, 6368, 27, 'अस्थायी विधि'),
(105214, 6369, 27, 'तापमान'),
(105215, 6370, 27, 'साँचा'),
(105216, 6371, 27, 'साँचा नाम'),
(105217, 6372, 27, 'साँचा नामों की संख्या के साथ शुरू नहीं कर सकते.'),
(105218, 6373, 27, 'साँचा:'),
(105219, 6374, 27, 'साँचा'),
(105220, 6375, 27, 'लौकिक धमनी'),
(105221, 6376, 27, 'पट्टा चोट'),
(105222, 6377, 27, 'Tendonitis / Osis / स्नेहपुटीशोथ'),
(105223, 6378, 27, 'अंतरिम चालान रेफरी No'),
(105224, 6379, 27, 'तृतीयक'),
(105225, 6380, 27, 'तृतीयक बीमा'),
(105226, 6381, 27, 'तृतीयक बीमा डाटा'),
(105227, 6382, 27, 'तृतीयक बीमा प्रदाता'),
(105228, 6383, 27, 'निर्धारण की परीक्षा'),
(105229, 6384, 27, 'प्रणाली की परीक्षा'),
(105230, 6385, 27, 'पाठ'),
(105231, 6386, 27, 'पाठ निदान'),
(105232, 6387, 27, 'पाठ क्षेत्र'),
(105233, 6393, 27, 'पाठ तारीख'),
(105234, 6394, 27, 'पाठ तारीख'),
(105235, 6395, 27, 'पाठ क्षेत्र'),
(105236, 6396, 27, 'पाठ क्षेत्र'),
(105237, 6397, 27, 'पाठ बॉक्स'),
(105238, 6398, 27, 'पाठ बॉक्स'),
(105239, 6399, 27, 'पाठ बॉक्स सूची'),
(105240, 6400, 27, 'पाठ बॉक्स सूची'),
(105241, 6401, 27, 'Thai'),
(105242, 6402, 27, 'शुक्रिया'),
(105243, 6403, 27, 'चुनने के लिए धन्यवाद'),
(105244, 6404, 27, 'साफ'' बटन सभी एनोटेशन हटा देगा.'),
(105245, 6405, 27, 'उपरोक्त बयान विफल रहा है'),
(105246, 6406, 27, 'अपाचे SSL सर्वर प्रमाणपत्र और सार्वजनिक कुंजी'),
(105247, 6407, 27, 'प्रमाणपत्र प्राधिकारी प्रमाणपत्र'),
(105248, 6408, 27, 'दावा फाइल: '),
(105249, 6409, 27, 'अमेरिका एक्सटेंशन की संगत अवस्था SNOMED पैकेज पहले से ही स्थापित किया गया है.'),
(105250, 6410, 27, 'समतुल्य निजी कुंजी'),
(105251, 6413, 27, 'इनकार कोड है'),
(105252, 6414, 27, 'इनकार समूह कोड है'),
(105253, 6415, 27, 'गंतव्य प्रपत्र बंद कर दिया था'),
(105254, 6416, 27, 'गंतव्य प्रपत्र बंद था, मैं आपके चयन पर कार्य नहीं कर सकता.'),
(105255, 6417, 27, 'इस प्रक्रिया का प्रदर्शन करनेवाली संस्था'),
(105256, 6418, 27, 'ईपी, पात्र अस्पताल या CAH, जो मरीज को प्राप्त करता है, एक सेवा सेटिंग से या सेवा प्रदाता से या मुठभेड़ प्रासंगिक है, ऐसा मानता ​​है, उसने Medical Reconciliation करना चाहिए.'),
(105257, 6421, 27, 'ईपी, पात्र अस्पताल या CAH जो अपने रोगी को किसी अन्य सेवा केन्द्र या सेवा प्रदाता के पास स्थानांतरण करता है, या अपने रोगी को किसी अन्य सेवा केन्द्र या सेवा प्रदाता के पास संदर्भित करता है, उनको प्रत्येक स्थानांतरण या संदर्भ के लिए देखभाल रिकॉर्ड का सारांश प्रदान करना चाहिए.'),
(105258, 6422, 27, 'घटना को मंजूरी दे दी गई है.'),
(105259, 6423, 27, 'घटना छिपे हुए हैं.'),
(105260, 6424, 27, 'निर्यात डेटा नीचे पाठ क्षेत्र में दिखाई देता है. आप एक ईमेल में या किसी भी अन्य इच्छित गंतव्य में यह कॉपी और पेस्ट कर सकते हैं.'),
(105261, 6426, 27, 'निर्यात डेटा नीचे पाठ क्षेत्र में दिखाई देता है. आप एक ईमेल में या किसी भी अन्य इच्छित गंतव्य में यह कॉपी और पेस्ट कर सकते हैं.'),
(105262, 6427, 27, 'निर्यात डेटा नीचे पाठ क्षेत्र में दिखाई देता है. आप एक ईमेल में या किसी भी अन्य इच्छित गंतव्य में यह कॉपी और पेस्ट कर सकते हैं.'),
(105263, 6428, 27, 'फ़ाइल CouchDB में सहेजा नहीं जा सका.'),
(105264, 6429, 27, 'फ़ाइल का सफलतापूर्वक नाम बदला नहीं जा सकता है, यह त्रुटि आमतौर पर संग्रहण प्रणाली पर अनुमति की समस्या से संबंधित है.'),
(105265, 6430, 27, 'फ़ाइल का सफलतापूर्वक संग्रहीत नहीं किया जा सकता है, यह त्रुटि आमतौर पर संग्रहण प्रणाली पर अनुमति की समस्या से संबंधित है.'),
(105266, 6431, 27, 'प्रथम ("लक्ष्य") चार्ट सबसे पूर्ण और सही माना जाता है. जनसांख्यिकी, इतिहास और बीमा वर्ग बनाए रखा जाएगा.'),
(105267, 6433, 27, 'पहला कदम एकीकृत मेडिकल भाषा प्रणाली वेब साइट में खाता खोलने का है.'),
(105268, 6434, 27, 'निम्नलिखित कैलेंडर घटना जोड़ा गया है:'),
(105269, 6435, 27, 'निम्नलिखित कैलेंडर घटना modifed किया गया है:'),
(105270, 6436, 27, 'निम्नलिखित श्रेणियां अपने श्रेणी सूची में से हटा दिया जाएगा'),
(105271, 6437, 27, 'निम्नलिखित डेटाबेस रिहाई वर्तमान में स्थापित है'),
(105272, 6438, 27, 'निम्नलिखित दस्तावेज इस सीधे संदेश से जुड़े थे:'),
(105273, 6439, 27, 'निम्नलिखित EDI फ़ाइल का अपलोड कर दिया गया है'),
(105274, 6440, 27, 'निम्नलिखित इमरजेंसी लॉगिन उपयोगकर्ता सक्रिय है:'),
(105275, 6441, 27, 'निम्न त्रुटियाँ उत्पन्न हुई'),
(105276, 6444, 27, 'निम्नलिखित क्षेत्र आवश्यक हैं'),
(105277, 6446, 27, 'निम्नलिखित क्षेत्र अनुरोध भेजने के लिए भरे जाने है.'),
(105278, 6447, 27, 'निम्नलिखित अंतर्राष्ट्रीय Snomed रिलीज भाषाएँ समर्थित हैं'),
(105279, 6448, 27, 'निम्न समस्याओं के लिए मेल खाते निदान कोड है. मुठभेड़ मुद्दों को अद्यतन नहीं किया जाएगा. बजाय मुठभेड़ इंटरफ़ेस का उपयोग करें.'),
(105280, 6449, 27, 'ATNA ऑडिट रिपोजिटरी मशीन का मेजबाननाम.'),
(105281, 6450, 27, 'प्रारंभिक खिड़की चालान खोज पृष्ठ है. शीर्ष पर आप एक स्रोत (जैसे चेक नंबर) , भुगतान तारीख और चेक राशि दर्ज कर सकते हैं. स्रोत और भुगतान की तारीख का कारण, आपको प्रत्येक दावे के लिए, फिर से उन्हें प्रवेश करने की जरूरत नहीं है. आपके द्वारा दर्ज की राशि भुगतान का हिस्सा है और प्रत्येक चालान के लिए कम हो जाएगा और शून्य पर खत्म हो जाएगा.'),
(105282, 6451, 27, 'स्थापना निर्देशिका पैदा किए जाने की जरूरत है.'),
(105283, 6452, 27, 'स्थापित अंतरराष्ट्रीय SNOMED संस्करण staged अमेरिका एक्सटेंशन SNOMED पैकेज के साथ संगत नहीं है.'),
(105284, 6453, 27, 'स्थापित अंतरराष्ट्रीय SNOMED संस्करण पुराना है और staged अमेरिका एक्सटेंशन SNOMED फ़ाइल के साथ संगत नहीं है.'),
(105285, 6454, 27, 'स्थापित संस्करण और staged फ़ाइलें समान हैं.'),
(105286, 6455, 27, 'स्थापित संस्करण staged फ़ाइलों की तुलना में एक अधिक नवीन संस्करण है.'),
(105287, 6456, 27, 'लेबल जो प्रपत्र पर उपयोगकर्ता के लिए प्रकट होता है'),
(105288, 6457, 27, 'अक्षरों की लंबाई संख्या निम्नलिखित से अधिक न हो'),
(105289, 6458, 27, 'मर्ज नहीं चलेंगे, जब तक दो चार्ट्स के लिए SSN और जन्म तिथि समान हो. जन्म तिथि खाली नहीं हो सकता.'),
(105290, 6459, 27, 'संदेश इस समय नहीं भेजा जा सका.'),
(105291, 6460, 27, 'नई श्रेणी इसकि एक उप श्रेणी हो जाएगा '),
(105292, 6461, 27, 'नया पासवर्ड वर्तमान पासवर्ड के समान नहीं हो सकता.'),
(105293, 6462, 27, 'नया पासवर्ड क्षेत्र समान नहीं हैं.'),
(105294, 6463, 27, 'staged फ़ाइलों की संख्या गलत है. केवल वे फ़ाइल रखना जो आप उन्नयन / स्थापित करना चाहते हैं .'),
(105295, 6464, 27, 'staged फ़ाइलों की संख्या गलत है. केवल वे फ़ाइल रखना जो आप उन्नयन / स्थापित करना चाहते हैं .'),
(105296, 6465, 27, 'पेज जनसांख्यिकी पर पुनः निर्देशित किया जाएगा. आप देश के क्षेत्र को संपादित करें और फिर NewCrop के लिए क्लिक करें.'),
(105297, 6466, 27, 'पासवर्ड कम से कम आठ अक्षरों का होना चाहिए, और'),
(105298, 6468, 27, 'रोगी रिकॉर्ड अनुरोध दर्ज किया गया है'),
(105299, 6469, 27, 'रोगी अनुस्मारक भेज दिया गया है'),
(105300, 6470, 27, 'रोगी अनुस्मारक अद्यतन किया गया है'),
(105301, 6472, 27, 'पोस्ट किया भुगतान इस तिथि से पहले नहीं हो सकता है, अंतिम रिपोर्ट लेने के बाद, पिछले तिथियों के रिपोर्ट पोस्ट नहीं करें.'),
(105302, 6474, 27, 'से कच्चे डेटा फीड रिलीज प्राप्त किया जा सकता है'),
(105303, 6475, 27, 'नीचे दिए गए शेष जानकारी, आप मैन्युअल पोस्ट कर रहे हैं, या आप मैन्युअल सुधार कर रहे हैं केवल तभी लागू होता है.'),
(105304, 6477, 27, 'अनुरोध किया गया दस्तावेज़ फाइल सिस्टम पर उम्मीद स्थान पर मौजूद नहीं है या इसे उपयोग करने के लिए पर्याप्त अनुमतियाँ नहीं हैं.'),
(105305, 6479, 27, 'दूसरा ("स्रोत") चार्ट जनसांख्यिकी, इतिहास और बीमा वर्गों को बंद कर देगा. उसके अन्य डेटा लक्षित चार्ट में विलय हो जाएगा.'),
(105306, 6480, 27, 'The Source and Date columns are copied from the first page, so normally you will not need to touch those. You can put a payment amount in the Pay column, an adjustment amount in the Adjust column, or both. You can also click the "W" on the right to automatically compute an adjustment value that writes off the remainder of the charge for that line item.'),
(105307, 6481, 27, 'मंचन फ़ाइलों की सब रिहाई तिथियाँ वही रिहाई से नहीं हैं.'),
(105308, 6482, 27, 'मंचन फ़ाइलों का सब संशोधन, वही रिलीज से नहीं हैं.'),
(105309, 6483, 27, 'मंचन किया अमेरिका एक्सटेंशन SNOMED पैकेज स्थापित नहीं किया जा सकता जब तक, अंतर्राष्ट्रीय SNOMED पैकेज स्थापित किया जाय!'),
(105310, 6484, 27, 'कैलेंडर का समय विघटन और नियुक्ति स्लॉट के लिए मिनटों में सबसे छोटा अंतराल.'),
(105311, 6485, 27, 'अनुवादित लेबल वर्तमान भाषा में फार्म पर प्रदर्शित होगा'),
(105312, 6486, 27, 'अनुवादित शीर्षक जो वर्तमान भाषा में प्रदर्शित होगा'),
(105313, 6487, 27, 'वर्तमान भाषा में विवरण का अनुवाद'),
(105314, 6488, 27, 'अनुवाद तालिकाएँ सिंक्रनाइज़ हैं.'),
(105315, 6489, 27, 'इस इकाई के प्रकार'),
(105316, 6490, 27, 'इस प्रक्रिया या परिणाम की पहचान करनेवाला विक्रेता विशेष कोड'),
(105317, 6491, 27, 'X 12 फाइलें और परिणामस्वरूप HTML उत्पादन रिपोर्ट्स मुख्य LibreEHR स्थापना निर्देशिका के "युग" उपनिर्देशिका में संग्रहीत हैं. आप समय समय पर इन अभिलेखागार का उल्लेख करना चाहते होगे. यूआरएल है'),
(105318, 6492, 27, 'ज़िप फ़ाइल में निम्न आइटम्स शामिल होंगे'),
(105319, 6493, 27, 'थीम'),
(105320, 6494, 27, 'फिर कच्चा डेटा फीड रिलीज से प्राप्त किया जा सकता है'),
(105321, 6495, 27, 'चिकित्सीय इंजेक्शन'),
(105322, 6496, 27, 'वहाँ हैं'),
(105323, 6497, 27, 'वर्तमान में कोई नुस्खे नहीं'),
(105324, 6498, 27, 'आपके सबमिशन में त्रुटियाँ हैं. ये नीचे उल्लिखित हैं.'),
(105325, 6500, 27, 'चेक आउट किया कोई चार्ट नहीं हैं'),
(105326, 6501, 27, 'इस रोगी के लिए कोई खुलासे दर्ज नहीं हैं.'),
(105327, 6502, 27, 'कोई नई प्रस्तुतियाँ नहीं हैं'),
(105328, 6503, 27, 'इस रोगी के लिए फाइल पर कोई टिप्पणी नहीं हैं.'),
(105329, 6504, 27, 'इस रोगी के लिए फाइल पर कोई लेनदेन नहीं हैं.'),
(105330, 6505, 27, 'के लिए भेजने के लिए एक मेल त्रुटि हैं.'),
(105331, 6506, 27, 'पहले से ही एक श्रेणी नामित है'),
(105332, 6507, 27, 'पहले से ही एक उपश्रेणी नामित है'),
(105333, 6508, 27, 'पहले से ही एक आइटम नामित है'),
(105334, 6509, 27, 'एक रोगी रिकॉर्ड अनुरोध वहां पहले से ही खुला है.'),
(105335, 6510, 27, 'AR खाते के लिए कोई COA प्रविष्टि नहीं है '),
(105336, 6511, 27, 'नकदी खाते के लिए कोई COA प्रविष्टि नहीं है '),
(105337, 6512, 27, 'आय खाते के लिए कोई COA प्रविष्टि नहीं है '),
(105338, 6513, 27, 'वर्तमान रोगी नहीं है'),
(105339, 6515, 27, 'चालान आईडी के लिए कोई मेल नहीं है'),
(105340, 6516, 27, 'चालान आईडी के लिए कोई मेल नहीं है= '),
(105341, 6517, 27, 'सेवाएँ ID के लिए कोई हिस्से प्रविष्टि नहीं है '),
(105342, 6519, 27, 'संदेश भेजने में कोई समस्या थी.'),
(105343, 6520, 27, 'आपका अनुरोध संसाधित करते समय एक त्रुटि हुई थी.'),
(105344, 6521, 27, 'निम्न स्ट्रिंग के एक LibreEHR एसक्यूएल भागने की त्रुटि थी'),
(105345, 6522, 27, 'ये 2012 लिंक हैं'),
(105346, 6523, 27, 'दाएँ गाढ़ा:'),
(105347, 6524, 27, 'जांघ'),
(105348, 6525, 27, 'जांघ + हैमस्ट्रिंग'),
(105349, 6526, 27, 'चीजें जो बैक कार्यालय केवल पढ़ सकते हैं'),
(105350, 6527, 27, 'चीजें जो बैक कार्यालय केवल पढ़ और प्रविष्टि कर सकते हैं लेकिन संशोधित नहीं कर सकते हैं'),
(105351, 6528, 27, 'चीजें जो बैक कार्यालय पढ़ सकते हैं और संशोधित कर सकते हैं'),
(105352, 6529, 27, 'चीजें जो बैक कार्यालय पढ़ सकते हैं और अंशत: संशोधित कर सकते हैं'),
(105353, 6530, 27, 'चीजें जो चिकित्सक केवल पढ़ सकते हैं'),
(105354, 6531, 27, 'चीजें जो चिकित्सक केवल पढ़ और प्रविष्टि कर सकते हैं लेकिन संशोधित नहीं कर सकते हैं'),
(105355, 6532, 27, 'चीजें जो चिकित्सक पढ़ सकते हैं और संशोधित कर सकते हैं'),
(105356, 6533, 27, 'चीजें जो चिकित्सक पढ़ सकते हैं और अंशत: संशोधित कर सकते हैं'),
(105357, 6534, 27, 'चीजें जो प्रमुख कार्यालय केवल पढ़ सकते हैं'),
(105358, 6535, 27, 'चीजें जो प्रमुख कार्यालय केवल पढ़ और प्रविष्टि कर सकते हैं लेकिन संशोधित नहीं कर सकते हैं'),
(105359, 6536, 27, 'चीजें जो प्रमुख कार्यालय पढ़ सकते हैं और संशोधित कर सकते हैं'),
(105360, 6537, 27, 'चीजें जो प्रमुख कार्यालय पढ़ सकते हैं और अंशत: संशोधित कर सकते हैं'),
(105361, 6538, 27, 'चीजें जो वैद्य केवल पढ़ सकते हैं'),
(105362, 6539, 27, 'चीजें जो वैद्य केवल पढ़ और प्रविष्टि कर सकते हैं लेकिन संशोधित नहीं कर सकते हैं'),
(105363, 6540, 27, 'चीजें जो वैद्य पढ़ सकते हैं और संशोधित कर सकते हैं'),
(105364, 6541, 27, 'चीजें जो वैद्य पढ़ सकते हैं और अंशत: संशोधित कर सकते हैं'),
(105365, 6542, 27, 'तृतीय'),
(105366, 6544, 27, 'यह क्रिया पीछे लौट नहीं सकती.'),
(105367, 6545, 27, 'यह क्रिया पीछे लौट नहीं सकती.'),
(105368, 6547, 27, 'यह क्रिया लॉग करेंगे'),
(105369, 6549, 27, 'यह नियुक्ति स्लॉट पहले से ही उपयोग में हैं, फिर भी उपयोग करें'),
(105370, 6550, 27, 'यह नियुक्ति स्लॉट उपलब्ध नहीं है, किसी अन्य का चयन करें.'),
(105371, 6551, 27, 'इस कैलेंडर वर्ष में'),
(105372, 6552, 27, 'यह दावा रद्द कर दिया गया है.'),
(105373, 6553, 27, 'यह दावा बंद कर दिया गया है.'),
(105374, 6554, 27, 'यह दावा इनकार कर दिया गया है. कारण: -'),
(105375, 6555, 27, 'यह दावा अगले स्तर के लिए भेज दिया गया है.'),
(105376, 6556, 27, 'यह कोड टाइप संबंधों को स्वीकार नहीं करता.'),
(105377, 6557, 27, 'इस संदर्भ में वर्ग शामिल हैं जो हटा दिया जाएगा. आप अभी भी जारी रखना चाहते हैं?');
INSERT INTO `lang_definitions` VALUES
(105378, 6558, 27, 'नियुक्तियों कैलेंडर में कैसे प्रदर्शित हो, यह निर्धारित करता है.'),
(105379, 6559, 27, 'यह नियुक्ति के लिए कौन सा रंग स्कीमा प्रयोग हो, यह निर्धारित करता है.'),
(105380, 6561, 27, 'यह मुठभेड़'),
(105381, 6562, 27, 'इस मुठभेड़ का बिल भेजा गया है. इसे बदलने के लिए, इसे फिर से खोला जाना चाहिए.'),
(105382, 6564, 27, 'यह सुविधा अभी तक उपलब्ध नहीं है'),
(105383, 6565, 27, 'यह सुविधा बहुत प्रयोगात्मक है और पूरी तरह से परीक्षण नहीं किया है. अपने जोखिम पर प्रयोग करें!'),
(105384, 6566, 27, 'चालान संख्या को इस में बदल दिया गया है '),
(105385, 6569, 27, 'यह चार्ट मुख्य चार्ट में विलय कर दिया जायगा और फिर हटा दिया जायगा.'),
(105386, 6571, 27, 'यह मर्ज किए गए डेटा प्राप्त करने के लिए मुख्य चार्ट है.'),
(105387, 6572, 27, 'इस स्थान'),
(105388, 6575, 27, 'यह मॉड्यूल परीक्षण मोड में है. डेटाबेस बदला नहीं जाएगा.'),
(105389, 6576, 27, 'यह मॉड्यूल EOB डेटा के प्रभावी प्रविष्टि को बढ़ावा देता है.'),
(105390, 6577, 27, 'इस महीने से तिथि तक'),
(105391, 6579, 27, 'यह पृष्ठ आपको, समर्थित बाहरी dataloads की समीक्षा करने की अनुमति देता है जो आप स्थापित और उन्नयन कर सकते हैं.नीचे प्रत्येक खंड का खंड शीर्षक पर क्लिक करके विस्तार किया जा सकता है, विशेष डेटाबेस की स्थिति की समीक्षा करने के लिए.'),
(105392, 6580, 27, 'इस पृष्ठ को सुरक्षा कारणों के लिए निष्क्रिय कर दिया.'),
(105393, 6581, 27, 'यह पृष्ठ इनलाइन प्रवेश पृष्ठ शामिल करेगा, हमे हर बार दोबारा लॉगिन क्लिक करने की जरूरत नहीं है.'),
(105394, 6582, 27, 'इस रोगी की कोई गतिविधि नहीं है.'),
(105395, 6583, 27, 'यह रोगी आईडी पहले से ही उपयोग में है!'),
(105396, 6584, 27, 'यह उत्पाद हर गोदाम में केवल एक लॉट की अनुमति देता है.'),
(105397, 6585, 27, 'यह प्रोटोकॉल लागू नहीं है'),
(105398, 6586, 27, 'यह रिपोर्ट वर्तमान में केवल ICD9 कोड के लिए काम करता है.'),
(105399, 6591, 27, 'यह कदम एक फाइल उत्पन्न करेगा जो आप भविष्य में उपयोग के लिए सहेजें. फाइल फिर से उत्पन्न नहीं हो सकती. क्या आप आगे बढ़ना चाहते हैं?'),
(105400, 6592, 27, 'यह उपयोगकर्ता किसी भी समूह का सदस्य नहीं है'),
(105401, 6593, 27, 'यह उपयोगकर्ता नए आने वाले सीधे संदेश की सूचना प्राप्त करेंगे'),
(105402, 6594, 27, 'यह सुविधा प्रायोगिक है. यह प्रयोग करने से पहले अपने डेटाबेस और दस्तावेजों का बैकअप लें!'),
(105403, 6595, 27, 'यह दौरे में नए गर्भनिरोधक का उपयोग शुरू होता है'),
(105404, 6596, 27, 'यह दौरे को एक GCAC फार्म, रेफरल या प्रक्रिया सेवा की जरूरत होगी.'),
(105405, 6597, 27, 'यह पुराना केवल मीट्रिक नब्ज फार्म था, अब पदावनत है.'),
(105406, 6598, 27, 'इस सप्ताह से तिथि तक'),
(105407, 6600, 27, 'यह सीसीआर (केयर रिकॉर्ड की निरंतरता) और सीसीडी (केयर दस्तावेज़ की निरंतरता) रिपोर्टिंग को चालू कर पायेगा.'),
(105408, 6602, 27, 'यह डिबगिंग ( ''डमी '') भाषा का चयन करने की अनुमति देगा.'),
(105409, 6605, 27, 'यह भौतिक डेटा अद्यतन के बिना "चलाना" हो जाएगा.'),
(105410, 6606, 27, 'यह टार प्रारूप में एक बैकअप बनाएगा और अपने वेब ब्राउज़र को भेज देगा तब आप इसे सहेज सकते हैं'),
(105411, 6607, 27, 'यह दस्तावेज़ एन्क्रिप्शन और डिक्रिप्शन सुविधाओं को निष्क्रिय करेगा, और यूआई में उन्हें छुपा देगा.'),
(105412, 6613, 27, 'यह बिलिंग विजेट रोगी को सारांश स्क्रीन में हमेशा खुला होने के लिए मजबूर करेगा.'),
(105413, 6616, 27, 'यह एक में दो रोगी चार्ट विलय करेगा. यह उपयोगी है जब एक मरीज को गलती से दोहराया गया है. अगर यह अक्सर होता है, तो अपने कार्यालय प्रक्रियाओं को ठीक करें - नियमित रूप से यह चलना नहीं है!'),
(105414, 6617, 27, 'यह e-Prescriptions साइट पर जाने से नहीं रोकेगा.'),
(105415, 6619, 27, 'यह कस्टम टीकाकरण सूची के बजाय मानक CVX टीकाकरण सूची का उपयोग करेगा.'),
(105416, 6622, 27, 'थोरैसिक रीढ़'),
(105417, 6623, 27, 'Thous / CU.MM'),
(105418, 6625, 27, 'गला'),
(105419, 6626, 27, 'गले के कैंसर'),
(105420, 6627, 27, 'गले के कैंसर सर्जरी'),
(105421, 6628, 27, 'घनास्त्रता / स्ट्रोक'),
(105422, 6629, 27, 'गुरु'),
(105423, 6630, 27, 'बृहस्पतिवार'),
(105424, 6631, 27, 'बृहस्पतिवार'),
(105425, 6632, 27, 'थायराइड सामान्य'),
(105426, 6633, 27, 'थायराइड समस्याएं'),
(105427, 6634, 27, 'TIA'),
(105428, 6636, 27, 'TID'),
(105429, 6638, 27, 'समय'),
(105430, 6639, 27, 'समय प्रदर्शन स्वरूप'),
(105431, 6640, 27, 'समय वृद्धि जोड़ने के लिए (मिनट 1-60)'),
(105432, 6641, 27, 'समय चयन'),
(105433, 6642, 27, 'समय स्लॉट खुला है, सहेजें.'),
(105434, 6647, 27, 'समयबद्ध घटना'),
(105435, 6648, 27, 'समय सरणी (N / A)'),
(105436, 6649, 27, 'टाइमस्टैम्प और पाठ'),
(105437, 6650, 27, 'TIN'),
(105438, 6651, 27, 'टिनिटस'),
(105439, 6652, 27, 'शीर्षक'),
(105440, 6653, 27, 'शीर्षक V'),
(105441, 6654, 27, 'TitleCols 1 और 999 के बीच में होनी चाहिए'),
(105442, 6655, 27, 'शीर्षक'),
(105443, 6656, 27, 'TM  ''S:'),
(105444, 6657, 27, 'TMs / EAMs / EE, ext नाक'),
(105445, 6658, 27, 'तक'),
(105446, 6659, 27, 'तक'),
(105447, 6660, 27, 'तक'),
(105448, 6661, 27, 'फ़ाइल का पूर्ण पथ के लिए'),
(105449, 6662, 27, 'नोट जोड़ने के लिए, कृपया क्लिक करें '),
(105450, 6663, 27, 'नोट जोड़ने के लिए यहां क्लिक करें'),
(105451, 6664, 27, 'प्रभावित क्षेत्र के लिए'),
(105452, 6665, 27, 'प्रभावित क्षेत्र के लिए'),
(105453, 6666, 27, 'स्वचालित रूप से निर्दिष्ट प्रपत्र खोलने के लिए. कुछ खेल की टीमें यहाँ football_injury_audit का उपयोग करती है.'),
(105454, 6667, 27, 'बिलिंग देखने के लिए'),
(105455, 6668, 27, 'श्रेणी के लिए'),
(105456, 6669, 27, 'क्लीनिकल देखने के लिए'),
(105457, 6670, 27, 'copay के लिए'),
(105458, 6672, 27, 'ded''ble के लिए'),
(105459, 6673, 27, 'Dems के लिए'),
(105460, 6674, 27, 'ग्राहक पक्ष SSL प्रमाणपत्र निष्क्रिय करने के लिए अपाचे विन्यास फाइल और सेट में उपरोक्त पंक्तियों की टिप्पणी करें'),
(105461, 6675, 27, 'HTTPS निष्क्रिय करने के लिए, अपाचे विन्यास फाइल में उपरोक्त पंक्तियों की टिप्पणी करें और अपाचे सर्वर को पुनः आरंभ करें'),
(105462, 6676, 27, 'क्लाइंट पक्ष SSL प्रमाणपत्र सक्रिय करने के लिए'),
(105463, 6677, 27, 'क्लाइंट पक्ष SSL प्रमाणपत्र प्रमाणीकरण सक्रिय करने के लिए, HTTPS सक्रिय होना चाहिए.'),
(105464, 6678, 27, 'केवल HTTPS सक्रिय करने के लिए उपरोक्त परिवर्तन करें और अपाचे सर्वर को पुनः आरंभ करें. यदि आप ग्राहक पक्ष प्रमाण पत्र विन्यस्त करना चाहते हैं, तो अगले भाग में उन्हें विन्यस्त करें.'),
(105465, 6679, 27, 'Enctr करें'),
(105466, 6680, 27, 'सेक्स के द्वारा फिल्टर करने के लिए'),
(105467, 6681, 27, 'इतिहास'),
(105468, 6682, 27, 'मुद्दों के लिए'),
(105469, 6683, 27, 'मुठभेड़ / परामर्श मौजूदा मुद्दे को लिंक करने के लिए, क्लिक करें '),
(105470, 6684, 27, 'मुठभेड़ / परामर्श मौजूदा मुद्दे को लिंक करने के लिए, उपरोक्त इच्छित मुद्दे पर क्लिक करके हाइलाइट करें और [सेव] क्लिक करें.कई मुद्दों पर चयन करने के लिए [Ctrl] बटन दबाए रखें.'),
(105471, 6685, 27, 'फिर से प्रवेश करने के लिए'),
(105472, 6686, 27, 'खुलासे रिकॉर्ड करने के लिए, कृपया क्लिक करें'),
(105473, 6687, 27, 'चलाने के लिए'),
(105474, 6688, 27, 'क्लाइंट प्रमाण पत्र प्रमाणीकरण के साथ HTTPS पहुँच सेटअप के लिए, निम्न कार्य करें'),
(105475, 6689, 27, 'त्वचा के लिए'),
(105476, 6690, 27, 'त्वचा के लिए'),
(105477, 6691, 27, 'इस दौरे के लिए?'),
(105478, 6693, 27, 'करने के लिए:'),
(105479, 6694, 27, 'करने के लिए: '),
(105480, 6695, 27, 'TO_CITY'),
(105481, 6696, 27, 'TO_FAX'),
(105482, 6697, 27, 'TO_FNAME'),
(105483, 6698, 27, 'TO_LNAME'),
(105484, 6699, 27, 'TO_MNAME'),
(105485, 6700, 27, 'TO_ORGANIZATION'),
(105486, 6703, 27, 'TO_POSTAL'),
(105487, 6704, 27, 'TO_STATE'),
(105488, 6705, 27, 'TO_STREET'),
(105489, 6706, 27, 'TO_TITLE'),
(105490, 6707, 27, 'TO_VALEDICTORY'),
(105491, 6708, 27, 'तम्बाकू'),
(105492, 6709, 27, 'तम्बाकू बंद हस्तक्षेप'),
(105493, 6710, 27, 'तम्बाकू बंद हस्तक्षेप (CQM)'),
(105494, 6712, 27, 'तम्बाकू का उपयोग'),
(105495, 6713, 27, 'तंबाकू का उपयोग आकलन'),
(105496, 6714, 27, 'तंबाकू का उपयोग आकलन (CQM)'),
(105497, 6715, 27, 'आज'),
(105498, 6716, 27, 'आज'),
(105499, 6717, 27, 'आज'),
(105500, 6718, 27, 'आज की शेष राशि'),
(105501, 6719, 27, 'आज का शुल्क'),
(105502, 6720, 27, 'आज की तिथि'),
(105503, 6721, 27, 'आज का घटनाक्रम'),
(105504, 6723, 27, 'मैडिकल इन्फोर्मेशन एकता, LLC लैब विनिमय सेवा के लिए टोकन ID.'),
(105505, 6724, 27, 'LibreEHR समर्थन LLC लैब विनिमय सेवा के लिए टोकन ID.'),
(105506, 6726, 27, 'गलतुण्डिका उच्छेदन'),
(105507, 6728, 27, 'शीर्ष'),
(105508, 6730, 27, 'विषय'),
(105509, 6731, 27, 'संपूर्ण'),
(105510, 6732, 27, 'संपूर्ण'),
(105511, 6733, 27, 'कुल सक्रिय कार्रवाई'),
(105512, 6734, 27, 'अद्यतन करने के बाद कुल सक्रिय अनुस्मारक'),
(105513, 6735, 27, 'अद्यतन करने से पहले कुल सक्रिय अनुस्मारक'),
(105514, 6737, 27, 'देय कुल राशि'),
(105515, 6738, 27, 'कुल राशि भुगतान'),
(105516, 6739, 27, 'देय कुल शेष राशि'),
(105517, 6740, 27, 'कुल शुल्क'),
(105518, 6741, 27, 'कुल शुल्क'),
(105519, 6742, 27, 'कुल ग्राहक'),
(105520, 6743, 27, 'कुल मूल्य'),
(105521, 6744, 27, 'निम्नलिखित चेक संख्या के लिए कुल वितरण पूर्ण नहीं है'),
(105522, 6745, 27, 'कुल प्रविष्टियां'),
(105523, 6746, 27, 'ईमेल के माध्यम से भेजा कुल विफल अनुस्मारक'),
(105524, 6747, 27, 'फोन के माध्यम से भेजा कुल विफल अनुस्मारक'),
(105525, 6748, 27, 'के लिए कुल'),
(105526, 6749, 27, 'के लिए कुल '),
(105527, 6750, 27, 'श्रेणी के लिए कुल'),
(105528, 6751, 27, 'कुल निष्क्रिय अनुस्मारक'),
(105529, 6752, 27, 'कुल नई अनुस्मारक'),
(105530, 6753, 27, 'नियुक्तियों की कुल संख्या'),
(105531, 6755, 27, 'टीकाकरण की कुल संख्या'),
(105532, 6756, 27, 'मामलों की कुल संख्या'),
(105533, 6758, 27, 'रोगियों की कुल संख्या'),
(105534, 6760, 27, 'कुल रोगी शेष राशि'),
(105535, 6761, 27, 'कुल रोगी'),
(105536, 6764, 27, 'कुल रिकॉर्ड'),
(105537, 6765, 27, 'कुल SRH और परिवार नियोजन'),
(105538, 6766, 27, 'ईमेल के माध्यम से भेजा कुल सफल अनुस्मारक'),
(105539, 6767, 27, 'फोन के माध्यम से भेजा कुल सफल अनुस्मारक'),
(105540, 6770, 27, 'कुल अपरिवर्तित अनुस्मारक'),
(105541, 6771, 27, 'प्रक्रिया भेजने के बाद नहीं भेजे गए कुल अनुस्मारक'),
(105542, 6772, 27, 'अद्यतन करने के बाद नहीं भेजे गए कुल अनुस्मारक'),
(105543, 6773, 27, 'प्रक्रिया भेजने से पहले नहीं भेजे गए कुल अनुस्मारक'),
(105544, 6774, 27, 'अद्यतन करने से पहले नहीं भेजे गए कुल अनुस्मारक'),
(105545, 6775, 27, 'कुल अद्यतन अनुस्मारक'),
(105546, 6776, 27, 'कुलयोग'),
(105547, 6777, 27, 'के लिए कुलयोग'),
(105548, 6778, 27, 'के लिए कुलयोग '),
(105549, 6780, 27, 'को {{रेंज}}'),
(105550, 6785, 27, 'प्रशिक्षण के प्रकार'),
(105551, 6786, 27, 'लेन - देन'),
(105552, 6787, 27, 'लेन - देन'),
(105553, 6788, 27, 'लेन - देन'),
(105554, 6789, 27, 'लेन - देन विफल रहा है गंतव्य स्थल में अपर्याप्त मात्रा.'),
(105555, 6790, 27, 'लेन - देन विफल रहा है, मात्रा शून्य से भी कम है'),
(105556, 6791, 27, 'लेन - देन के प्रकार'),
(105557, 6792, 27, 'लेनदेन'),
(105558, 6793, 27, 'लेनदेन'),
(105559, 6794, 27, 'लेनदेन (वैकल्पिक लिखने)'),
(105560, 6795, 27, 'लेनदेन / सिफ़ारिश'),
(105561, 6797, 27, 'स्थानांतरण'),
(105562, 6798, 27, 'स्थानांतरण की तारीख'),
(105563, 6799, 27, 'स्थानांतरण स्रोत बहुत में, अपर्याप्त मात्रा में विफल रहा है'),
(105564, 6800, 27, 'स्थानांतरण सारांश'),
(105565, 6801, 27, 'पर स्थानांतरण'),
(105566, 6804, 27, 'स्थानांतरण'),
(105567, 6806, 27, 'देखभाल के स्थानांतरण / स्थानांतरण?'),
(105568, 6807, 27, 'प्रवेश नियंत्रण समूह अनुवाद'),
(105569, 6808, 27, 'नियुक्ति श्रेणियाँ अनुवाद'),
(105570, 6809, 27, 'दस्तावेज़ श्रेणियाँ अनुवाद'),
(105571, 6810, 27, 'लेआउट अनुवाद करें'),
(105572, 6811, 27, 'सूचियां अनुवाद करें'),
(105573, 6812, 27, 'रोगी नोट टाइटल अनुवाद करें'),
(105574, 6813, 27, 'यह अनुवाद करें'),
(105575, 6814, 27, 'अनुवाद'),
(105576, 6815, 27, 'अनुवाद'),
(105577, 6816, 27, 'संचारित करें'),
(105578, 6817, 27, 'संचारित विफल रहा'),
(105579, 6818, 27, 'चयनित आदेश संचारित करें'),
(105580, 6819, 27, 'आघात'),
(105581, 6820, 27, 'उपचार'),
(105582, 6822, 27, 'उपचार लक्ष्य'),
(105583, 6823, 27, 'उपचार योजना'),
(105584, 6824, 27, 'उपचार योजना'),
(105585, 6825, 27, 'प्राप्त उपचार'),
(105586, 6826, 27, 'उपचार:'),
(105587, 6827, 27, 'उपचार: '),
(105588, 6828, 27, 'रुझान'),
(105589, 6829, 27, 'trftime ($ month_format, mktime (0, 0, 0, $ , 1, 2000))); $ month_value'),
(105590, 6830, 27, 'ट्रिगर बिंदु / कम्पार्टमेंट सिंड्रोम / DOMS / ऐंठन'),
(105591, 6831, 27, 'Trimalleolar'),
(105592, 6832, 27, 'ट्रंक और उदर'),
(105593, 6835, 27, 'मौजूदा उपयोगकर्ता नाम के साथ उपयोगकर्ता बनाने की कोशिश कर रहा है!'),
(105594, 6837, 27, 'चम्मच'),
(105595, 6839, 27, 'TTS'),
(105596, 6840, 27, 'क्षय रोग'),
(105597, 6841, 27, 'मंगल'),
(105598, 6842, 27, 'मंगल और amp'),
(105599, 6843, 27, 'मंगलवार'),
(105600, 6844, 27, 'अर्बुद'),
(105601, 6845, 27, 'तुर्की'),
(105602, 6848, 27, 'प्रतिदिन दो बार'),
(105603, 6850, 27, 'कान की झिल्ली'),
(105604, 6851, 27, 'टाइप'),
(105605, 6852, 27, '(रिक्त स्थानों सहित) टाइप ID या नाम. 3 अक्षर न्यूनतम.'),
(105606, 6853, 27, 'रोगी खोज परिणामों के लिए प्रदर्शित स्तंभों के प्रकार'),
(105607, 6854, 27, 'प्रकटीकरण के प्रकार'),
(105608, 6855, 27, 'घटना के प्रकार'),
(105609, 6856, 27, 'स्क्रीन लेआउट के प्रकार'),
(105610, 6857, 27, 'यहाँ रोगी पहचानकर्ता टाइप या स्कैन करें'),
(105611, 6858, 27, 'यहाँ अपना संदेश टाइप करें'),
(105612, 6859, 27, 'आदेश और परिणाम के प्रकार'),
(105613, 6864, 27, 'कैलगरी विश्वविद्यालय खेल चिकित्सा केन्द्र द्वारा प्रदान की UCSMC कोड'),
(105614, 6865, 27, 'यूक्रेनी देश'),
(105615, 6866, 27, 'ulcerations'),
(105616, 6867, 27, 'सव्रण बृहदांत्रशोथ'),
(105617, 6868, 27, 'अल्सर:'),
(105618, 6871, 27, 'बनाने में असमर्थ'),
(105619, 6874, 27, 'Ar_activity में यह भुगतान का मिलान करने में असमर्थ'),
(105620, 6876, 27, 'अप्रयोजित'),
(105621, 6877, 27, 'सौंपा नहीं'),
(105622, 6878, 27, 'अनाधिकृत'),
(105623, 6879, 27, 'EPrescription को अनाधिकृत पहुँच'),
(105624, 6880, 27, 'अनाधिकृत उपयोग.'),
(105625, 6881, 27, 'unbilled'),
(105626, 6882, 27, 'केवल unbilled'),
(105627, 6884, 27, 'जीभ के नीचे'),
(105628, 6885, 27, 'वजन'),
(105629, 6886, 27, 'undiagnosed'),
(105630, 6887, 27, 'अवितरित'),
(105631, 6888, 27, 'अवितरित'),
(105632, 6889, 27, 'अवितरित है'),
(105633, 6890, 27, 'चेकआउट पूर्ववत्'),
(105634, 6892, 27, 'अद्वितीय ग्राहक'),
(105635, 6893, 27, 'इस प्रकार के लिए अद्वितीय मानव पठनीय पहचानकर्ता'),
(105636, 6894, 27, 'अद्वितीय नए ग्राहक'),
(105637, 6895, 27, 'इस प्रकार के लिए अद्वितीय संख्यात्मक पहचानकर्ता'),
(105638, 6896, 27, 'अद्वितीय देखे मरीज'),
(105639, 6897, 27, 'अद्वितीय देखे मरीजों की रिपोर्ट'),
(105640, 6898, 27, 'अद्वितीय सपा'),
(105641, 6899, 27, 'इकाई'),
(105642, 6900, 27, 'इकाइयां'),
(105643, 6901, 27, 'इकाइयां'),
(105644, 6902, 27, 'परिणाम मूल्य को लागू इकाइयां'),
(105645, 6903, 27, 'दौरा प्रपत्र के लिए इकाइयां'),
(105646, 6904, 27, 'इकाइयां एक संख्या होनी चाहिए'),
(105647, 6905, 27, 'इकाइयां परिभाषित नहीं'),
(105648, 6906, 27, 'इकाइयां / L'),
(105649, 6907, 27, 'अज्ञात'),
(105650, 6910, 27, 'अज्ञात अगर कभी धूम्रपान किया है'),
(105651, 6911, 27, 'अज्ञात या N / A'),
(105652, 6912, 27, 'अज्ञात उपयोगकर्ता ID:'),
(105653, 6913, 27, 'रोगी की लिंक रद्द'),
(105654, 6914, 27, 'बेनाम बीमा कंपनी'),
(105655, 6915, 27, 'अपंजीकृत'),
(105656, 6918, 27, 'सभी का चयन रद्द'),
(105657, 6919, 27, 'अचयनित'),
(105658, 6920, 27, 'अनिर्दिष्ट'),
(105659, 6921, 27, 'असंरचित'),
(105660, 6922, 27, 'असमर्थित डेटाबेस लोड फ़ाइल'),
(105661, 6924, 27, 'जब तक'),
(105662, 6925, 27, 'अकाल दाखिल'),
(105663, 6926, 27, 'अप्रयुक्त'),
(105664, 6927, 27, 'uor'),
(105665, 6928, 27, 'तक है'),
(105666, 6929, 27, 'आगामी नियुक्तियां'),
(105667, 6930, 27, 'आगामी घटनाएँ'),
(105668, 6931, 27, 'अद्यतन'),
(105669, 6932, 27, 'अद्यतन'),
(105670, 6933, 27, 'अद्यतन सक्रिय'),
(105671, 6934, 27, 'अद्यतन फ़ाइलें'),
(105672, 6935, 27, 'अद्यतन जानकारी'),
(105673, 6936, 27, 'अद्यतन सूची'),
(105674, 6937, 27, 'अद्यतन प्रदाता संख्या'),
(105675, 6938, 27, 'अद्यतन आइटम चयनित'),
(105676, 6939, 27, 'फ़ाइल में निम्न चर अद्यतन करें'),
(105677, 6940, 27, 'अद्यतन उपयोगकर्ता जानकारी'),
(105678, 6942, 27, 'अद्यतन हो रहा जनसांख्यिकी अधिकृत नहीं है.'),
(105679, 6943, 27, 'वैश्विक विन्यास डिफ़ॉल्ट्स अद्यतन हो रहा है'),
(105680, 6944, 27, 'संस्करण संकेतक अद्यतन हो रहा है'),
(105681, 6945, 27, 'उन्नयन'),
(105682, 6946, 27, 'उन्नयन करें'),
(105683, 6947, 27, 'डेटाबेस उन्नयन'),
(105684, 6948, 27, 'प्रक्रिया, कार्य और तालिकाएँ शामिल करने के लिए LibreEHR डेटाबेस उन्नयन करें. de-identification की प्रक्रिया के लिए आवश्यक है.'),
(105685, 6949, 27, 'उन्नयन जारी रहेगा'),
(105686, 6950, 27, 'UPIN'),
(105687, 6951, 27, 'अपलोड'),
(105688, 6954, 27, 'विन्यास डाटा अपलोड'),
(105689, 6955, 27, 'दस्तावेज़ अपलोड करें'),
(105690, 6956, 27, 'अपलोड असफल!'),
(105691, 6957, 27, 'के लिए तस्वीर अपलोड करें'),
(105692, 6958, 27, 'आयात फ़ाइल अपलोड करें:'),
(105693, 6960, 27, 'अपलोड सफलतापूर्वक संसाधित'),
(105694, 6961, 27, 'अपलोड की रिपोर्ट'),
(105695, 6963, 27, 'इस फाइल को अपलोड करें:'),
(105696, 6964, 27, 'Upon clicking an invoice number the "manual posting window" appears. Here you can change the due date and notes for the invoice, select the party for whom you are posting, and select the insurances for which all expected paymants have been received. Most importantly, for each billing code for which an amount was charged, you can enter payment and adjustment information.'),
(105697, 6965, 27, 'Upon searching you are presented with a list of invoices. You may click on one of the invoice numbers to open a second window, which is the data entry page for manual posting. You may also click on a patient name if you want to enter a note that the front office staff will see when the patient checks in, and you may select invoices to appear on patient statements and print those statements.'),
(105698, 6966, 27, 'ऊपरी बांह'),
(105699, 6968, 27, 'अत्यावश्यकता'),
(105700, 6970, 27, 'मूत्र'),
(105701, 6971, 27, 'मूत्र ड्रिब्लिंग'),
(105702, 6972, 27, 'मूत्र फ्रीक्वेंसी'),
(105703, 6973, 27, 'मूत्र संदेह'),
(105704, 6974, 27, 'मूत्र Microalbumin'),
(105705, 6975, 27, 'मूत्र धारा'),
(105706, 6976, 27, 'मूत्र तात्कालिकता'),
(105707, 6977, 27, 'URL'),
(105708, 6979, 27, 'LibreEHR समर्थन के लिए URL.'),
(105709, 6981, 27, 'फोन प्रवेश द्वार के लिए URL. Maviq द्वारा प्रदान की स्वचालित VOIP सेवा. अधिक जानकारी के लिए http://signup.maviq.com जाएँ.'),
(105710, 6985, 27, 'प्रयोग'),
(105711, 6986, 27, 'उपयोग संकेतक (ISA15)'),
(105712, 6987, 27, 'बस उस स्तंभ पर सॉर्ट करने के लिए एक क्षेत्र में अकेले% का प्रयोग करें'),
(105713, 6988, 27, '24 घंटे समय स्वरूप का उपयोग करें?'),
(105714, 6990, 27, 'Use certified EHR technology to identify patient-specific education resources and provide those resources to the patient if appropriate.'),
(105715, 6991, 27, 'शुल्क पैनल का प्रयोग करें'),
(105716, 6992, 27, 'Use CPOE for medication orders directly entered by any licensed healthcare professional who can enter orders into the medical record per state, local and professional guidelines.'),
(105717, 6997, 27, 'पसंदीदा टीकाकरण सूची का प्रयोग करें'),
(105718, 6999, 27, 'तिथि श्रेणी का उपयोग करें'),
(105719, 7000, 27, 'डिफ़ॉल्ट का उपयोग करें'),
(105720, 7001, 27, 'निकालने के लिए हटाएँ विकल्प का प्रयोग करें.'),
(105721, 7002, 27, 'अंतरराष्ट्रीय तिथि शैली का उपयोग करें?'),
(105722, 7003, 27, 'स्रोत फ़ाइल नाम का उपयोग करें'),
(105723, 7004, 27, 'एक खरीद या हस्तांतरण के लिए नीचे दिए गए फ़ील्ड का उपयोग करें.'),
(105724, 7005, 27, 'केवल नव स्थापित साइटों के साथ इस सुविधा का उपयोग करें, '),
(105725, 7006, 27, 'विषयों का प्रयोग करें?'),
(105726, 7007, 27, 'उपयोगकर्ता'),
(105727, 7009, 27, 'उपयोगकर्ता / समूह'),
(105728, 7010, 27, 'उपयोगकर्ता का प्रशासन'),
(105729, 7011, 27, 'उपयोगकर्ता और सुविधा प्रशासन'),
(105730, 7012, 27, 'उपयोगकर्ता और समूह प्रशासन'),
(105731, 7014, 27, 'उपयोगकर्ता प्रमाणपत्र प्रमाणीकरण निष्क्रिय किया जाता है'),
(105732, 7015, 27, 'उपयोगकर्ता परिभाषित'),
(105733, 7016, 27, 'उपयोगकर्ता निर्धारित क्षेत्र 11'),
(105734, 7017, 27, 'उपयोगकर्ता निर्धारित क्षेत्र 12'),
(105735, 7018, 27, 'उपयोगकर्ता निर्धारित फील्ड'),
(105736, 7019, 27, 'उपयोगकर्ता निर्धारित सूची 1'),
(105737, 7020, 27, 'उपयोगकर्ता निर्धारित सूची 2'),
(105738, 7021, 27, 'उपयोगकर्ता निर्धारित सूची 3'),
(105739, 7022, 27, 'उपयोगकर्ता निर्धारित सूची 4'),
(105740, 7023, 27, 'उपयोगकर्ता निर्धारित सूची 5'),
(105741, 7024, 27, 'उपयोगकर्ता निर्धारित सूची 6'),
(105742, 7025, 27, 'उपयोगकर्ता परिभाषित सूची 7'),
(105743, 7026, 27, 'उपयोगकर्ता परिभाषित पाठ 1'),
(105744, 7027, 27, 'उपयोगकर्ता परिभाषित पाठ 2'),
(105745, 7028, 27, 'उपयोगकर्ता परिभाषित पाठ 3'),
(105746, 7029, 27, 'उपयोगकर्ता परिभाषित पाठ 4'),
(105747, 7030, 27, 'उपयोगकर्ता परिभाषित पाठ 5'),
(105748, 7031, 27, 'उपयोगकर्ता परिभाषित पाठ 6'),
(105749, 7032, 27, 'उपयोगकर्ता परिभाषित पाठ 7'),
(105750, 7033, 27, 'उपयोगकर्ता परिभाषित पाठ 8'),
(105751, 7034, 27, 'उपयोगकर्ता का प्रथम नाम'),
(105752, 7037, 27, 'उपयोगकर्ता लॉगऑन (अगर 03 से ऊपर है, बाकी रिक्त स्थान छोड़ दे) (ISA02)'),
(105753, 7038, 27, 'उपयोगकर्ता लॉगऑन आवश्यक संकेतक (ISA01 ~ 00 या 03 का उपयोग करें)'),
(105754, 7039, 27, 'उपयोगकर्ता पुस्तिका'),
(105755, 7040, 27, 'उपयोगकर्ता सदस्यता'),
(105756, 7041, 27, 'उपयोगकर्ता नाम'),
(105757, 7042, 27, 'उपयोगकर्ता नाम या होस्ट नाम खाली नहीं हो सकता'),
(105758, 7043, 27, 'उपयोगकर्ता या होस्ट नाम'),
(105759, 7044, 27, 'उपयोगकर्ता का पासवर्ड (ISA04 ~ अगर 01 से ऊपर है, बाकी रिक्त स्थान दें)'),
(105760, 7045, 27, 'उपयोगकर्ता पासवर्ड संकेतक आवश्यक (ISA03 ~ 00 या 01 का उपयोग करें)'),
(105761, 7046, 27, 'उपयोगकर्ता सेटिंग्स'),
(105762, 7047, 27, 'उपयोगकर्ता विशिष्ट सेटिंग'),
(105763, 7048, 27, 'उपयोगकर्ता  ''नया पासवर्ड'),
(105764, 7049, 27, 'उपयोगकर्ता नाम'),
(105765, 7051, 27, 'फोन प्रवेश द्वार के लिए उपयोगकर्ता नाम. Maviq द्वारा प्रदान की स्वचालित VOIP सेवा. अधिक जानकारी के लिए http://signup.maviq.com जाएँ.'),
(105766, 7052, 27, 'SMS गेटवे के लिए उपयोगकर्ता नाम'),
(105767, 7053, 27, 'SMS गेटवे के लिए उपयोगकर्ता नाम.'),
(105768, 7054, 27, 'CouchDB से कनेक्ट करने के लिए उपयोगकर्ता नाम'),
(105769, 7055, 27, 'उपयोगकर्ता नाम:'),
(105770, 7056, 27, 'उपयोगकर्ता'),
(105771, 7057, 27, 'उपयोगकर्ता / समूह / लॉग्स प्रशासन'),
(105772, 7058, 27, 'PHP <a href="http://php.net/strftime"> strftime </ a> प्रारूप का उपयोग करता है'),
(105773, 7059, 27, 'UTIs'),
(105774, 7062, 27, 'छुट्टी'),
(105775, 7063, 27, 'छुट्टी'),
(105776, 7064, 27, 'टीका'),
(105777, 7065, 27, 'योनि अंगूठी'),
(105778, 7066, 27, 'बिदाई का'),
(105779, 7067, 27, 'वैधीकृत करें'),
(105780, 7068, 27, 'मूल्य'),
(105781, 7069, 27, 'मूल्य 1'),
(105782, 7070, 27, 'मूल्य 2'),
(105783, 7072, 27, 'मूल्य एक संख्या होना चाहिए'),
(105784, 7073, 27, 'चर1'),
(105785, 7074, 27, 'चर2'),
(105786, 7075, 27, 'de-identification उन्नयन स्क्रिप्ट को चलाने के लिए एक चर'),
(105787, 7076, 27, 'वेरिसेला 1'),
(105788, 7077, 27, 'वेरिसेला 2'),
(105789, 7078, 27, 'वैरिकाज़ नसों के'),
(105790, 7079, 27, 'संवहनी हालत'),
(105791, 7080, 27, 'संवहनी चोट'),
(105792, 7081, 27, 'संवहनी सर्जरी'),
(105793, 7083, 27, 'विक्रेता'),
(105794, 7084, 27, 'संस्करण'),
(105795, 7085, 27, 'सिर का चक्कर'),
(105796, 7086, 27, 'दिग्गजों का प्रशासन'),
(105797, 7087, 27, 'दिग्गजों का प्रशासन की योजना'),
(105798, 7088, 27, 'VFC'),
(105799, 7089, 27, 'Vietnamese'),
(105800, 7090, 27, 'देखें'),
(105801, 7091, 27, 'देखें'),
(105802, 7092, 27, 'देखें एलर्जी'),
(105803, 7093, 27, 'एक x12-835 काल फ़ाइल देखें'),
(105804, 7094, 27, 'देखें बैच दावा x12 पाठ'),
(105805, 7097, 27, 'व्यापक रोगी की रिपोर्ट देखें'),
(105806, 7098, 27, 'CSV टेबल देखें'),
(105807, 7100, 27, 'देखें दस्तावेज'),
(105808, 7101, 27, 'देखें मुठभेड़'),
(105809, 7102, 27, 'देखें युग x12 पाठ'),
(105810, 7103, 27, 'एक पॉप अप विंडो में घटनाएँ देखें?'),
(105811, 7104, 27, 'सुविधा उपयोगकर्ता विशिष्ट जानकारी देखें'),
(105812, 7106, 27, 'स्थानीय x12 फ़ाइल देखें'),
(105813, 7107, 27, 'देखें लॉग'),
(105814, 7108, 27, 'देखें पृष्ठ 1'),
(105815, 7109, 27, 'देखें पृष्ठ 2'),
(105816, 7110, 27, 'अतीत और भविष्य अनुस्मारक देखें'),
(105817, 7111, 27, 'रोगी देखें'),
(105818, 7116, 27, 'संबंधित मुठभेड़ देखें'),
(105819, 7117, 27, 'रिपोर्ट देखें'),
(105820, 7118, 27, 'README फाइल देखें'),
(105821, 7121, 27, 'देखें / संपादन करें एलर्जी'),
(105822, 7122, 27, 'देखें / संपादन करें समस्या'),
(105823, 7123, 27, 'देखें / छापें'),
(105824, 7124, 27, 'देखें:'),
(105825, 7125, 27, 'VISA'),
(105826, 7126, 27, 'VISA/MC/AMEX/Dis'),
(105827, 7127, 27, 'आंत का नुकसान / आघात / सर्जरी'),
(105828, 7133, 27, 'श्रेणी पर जाएँ:'),
(105829, 7134, 27, 'तिथि पर जाएँ'),
(105830, 7135, 27, 'तिथि पर जाएँ'),
(105831, 7137, 27, 'प्रपत्र पर जाएँ'),
(105832, 7138, 27, 'इतिहास पर जाएँ'),
(105833, 7140, 27, 'दौरा'),
(105834, 7141, 27, 'से दौरा'),
(105835, 7142, 27, 'महत्वपूर्ण लक्षण'),
(105836, 7143, 27, 'नब्ज'),
(105837, 7144, 27, 'नब्ज (मैट्रिक)'),
(105838, 7145, 27, 'नब्ज विकल्प प्रपत्र'),
(105839, 7146, 27, 'आवाज़'),
(105840, 7147, 27, 'आवाज भेजा गया'),
(105841, 7149, 27, 'उल्टी'),
(105842, 7151, 27, 'W'),
(105843, 7152, 27, 'कमर परिधि'),
(105844, 7153, 27, 'कमर परिधि'),
(105845, 7154, 27, 'प्रतीक्षा'),
(105846, 7155, 27, 'चल आना'),
(105847, 7157, 27, 'वॉल्ट Pennington'),
(105848, 7158, 27, 'गोदाम'),
(105849, 7159, 27, 'गोदाम अधिकतम, अगर लागू नहीं तो 0'),
(105850, 7160, 27, 'गोदाम न्यूनतम, अगर लागू नहीं तो 0'),
(105851, 7161, 27, 'गोदामों के'),
(105852, 7162, 27, 'गर्म'),
(105853, 7163, 27, 'चेतावनी'),
(105854, 7164, 27, 'चेतावनी'),
(105855, 7166, 27, 'चेतावनी, चेक नंबर पहले से ही डेटाबेस में मौजूद'),
(105856, 7167, 27, 'चेतावनी, रोगी की समस्याओं की सूची में अस्पष्ट कोड है!'),
(105857, 7168, 27, 'चेतावनी: एक दौरा पहले से ही आज इस रोगी के लिए बनाया गया था!'),
(105858, 7169, 27, 'चेतावनी: यदि आप 2012/10/31 स्पेनिश संस्करण का उपयोग कर रहे हैं, तो आप contrib / snomed में रखने से पहले एक बार इसे खोल दे (क्योंकि यह जारी की फाइल  "डबल ज़िपित " , है).'),
(105859, 7170, 27, 'चेतावनी: रोगी ID अनन्य नहीं है!'),
(105860, 7171, 27, 'चेतावनी: यह अपलोड की गई फ़ाइल के डेटा से, विन्यास जानकारी को अधिलेखित कर देगा!'),
(105861, 7173, 27, 'चेतावनी'),
(105862, 7175, 27, 'पहले से ही अपलोड किया गया था'),
(105863, 7176, 27, 'नहीं मिला'),
(105864, 7177, 27, 'हम शेष राशि के शीघ्र भुगतान की सराहना करते हैं'),
(105865, 7178, 27, 'हमने हमारे आउट पेशेंट मनोरोग क्लिनिक में मूल्यांकन और उपचार के लिए आपके उपरोक्त रोगी को देखा है. इस सिफ़ारिश के लिए धन्यवाद.'),
(105866, 7179, 27, 'कमजोरी'),
(105867, 7181, 27, 'वेब खोज'),
(105868, 7182, 27, 'वेबसाइट'),
(105869, 7183, 27, 'ऑनसाइट रोगी पोर्टल के लिए वेबसाइट लिंक.'),
(105870, 7184, 27, 'बुधवार'),
(105871, 7185, 27, 'बुधवार'),
(105872, 7186, 27, 'सप्ताह'),
(105873, 7187, 27, 'सप्ताह'),
(105874, 7188, 27, 'सप्ताह दृश्य'),
(105875, 7189, 27, 'सप्ताह (s)'),
(105876, 7190, 27, 'साप्ताहिक एक्सपोज़र'),
(105877, 7191, 27, 'सप्ताह'),
(105878, 7192, 27, 'सप्ताह'),
(105879, 7193, 27, 'वज़न'),
(105880, 7194, 27, 'बच्चों और किशोरों के लिए वजन आकलन और परामर्श'),
(105881, 7195, 27, 'बच्चों और किशोरों के लिए वजन आकलन और परामर्श (CQM)'),
(105882, 7196, 27, 'वजन में परिवर्तन'),
(105883, 7197, 27, 'वजन घटाने के'),
(105884, 7198, 27, 'वजन घटाने के क्लिनिक'),
(105885, 7199, 27, 'आपका स्वागत है'),
(105886, 7202, 27, 'क्या गिना जा रहा है?'),
(105887, 7203, 27, 'घरघराहट'),
(105888, 7204, 27, 'घरघराहट'),
(105889, 7205, 27, 'घरघराहट:'),
(105890, 7208, 27, 'कहां संबंधित, स्कैन किया हुआ या कागज दस्तावेज़ पाया जा सकता है?'),
(105891, 7209, 27, 'क्या बीमित है'),
(105892, 7211, 27, 'चोट'),
(105893, 7212, 27, 'सफ़ेद'),
(105894, 7213, 27, 'कौन'),
(105895, 7214, 27, 'किसने जवाब दिया?'),
(105896, 7215, 27, 'विधवा'),
(105897, 7216, 27, 'चौडाई'),
(105898, 7217, 27, 'बाएं नेविगेशन फ्रेम की पिक्सल में चौड़ाई.'),
(105899, 7221, 27, 'चयनित के साथ:'),
(105900, 7222, 27, 'पुराने नाम के साथ'),
(105901, 7224, 27, 'किसके साथ हम संदेश छोड़ सकते हैं?'),
(105902, 7225, 27, 'पर रोक लगाई'),
(105903, 7226, 27, 'घंटे के भीतर'),
(105904, 7227, 27, 'घंटे के भीतर:'),
(105905, 7228, 27, 'मिनट के भीतर'),
(105906, 7229, 27, 'मिनट के भीतर:'),
(105907, 7230, 27, 'सुविधा के बिना'),
(105908, 7231, 27, 'प्रदाता के बिना'),
(105909, 7232, 27, 'अद्यतन के बिना'),
(105910, 7233, 27, 'गवाह'),
(105911, 7234, 27, 'सप्ताह'),
(105912, 7235, 27, 'WNL'),
(105913, 7237, 27, 'महिला'),
(105914, 7238, 27, 'केवल महिलाएं'),
(105915, 7240, 27, 'काम'),
(105916, 7241, 27, 'काम टिप्पणी'),
(105917, 7242, 27, 'कार्यालय का फोन'),
(105918, 7243, 27, 'कार्यालय का फ़ोन नंबर'),
(105919, 7244, 27, 'संबंधित काम?'),
(105920, 7245, 27, 'कार्य / शिक्षा / शौक'),
(105921, 7246, 27, 'काम / स्कूल टिप्पणी'),
(105922, 7247, 27, 'कार्यदिवस'),
(105923, 7248, 27, 'कार्यकर्ता मुआवजा'),
(105924, 7249, 27, 'श्रमिक मुआवजा स्वास्थ्य योजना'),
(105925, 7250, 27, 'नियोक्ता समूह स्वास्थ्य योजना के साथ कार्य वृद्ध लाभार्थी या पति'),
(105926, 7251, 27, 'काम चल रहा... इसमें एक मिनट लग सकता हैं.'),
(105927, 7252, 27, 'बदतर'),
(105928, 7253, 27, 'आप ग्लोबल खाते पर शेष राशि लागू करना चाहेंगे?'),
(105929, 7254, 27, 'आप मंजूर के रूप में उन्हें चिह्नित करना चाहते हैं.'),
(105930, 7255, 27, 'आप आवंटित करना चाहेंगे?'),
(105931, 7256, 27, 'आप इस मरीज के लिए वितरण रद्द करना चाहते हैं?'),
(105932, 7257, 27, 'आप भुगतान वितरण हटाना चाहते हैं?'),
(105933, 7258, 27, 'आप भुगतान हटाना चाहते हैं?'),
(105934, 7259, 27, 'आप भुगतान संशोधित और समाप्त करना चाहेंगे?'),
(105935, 7260, 27, 'आप भुगतान रूपांतरित करना चाहते हैं?'),
(105936, 7261, 27, 'आप भुगतान पोस्ट और समाप्त करना चाहेंगे?'),
(105937, 7262, 27, 'आप भुगतान पोस्ट करना चाहते हैं?'),
(105938, 7263, 27, 'आप सहेजना चाहेंगे?'),
(105939, 7264, 27, 'कलाई'),
(105940, 7265, 27, 'कलाई और हाथ'),
(105941, 7266, 27, 'कलाई की समस्याएं'),
(105942, 7267, 27, 'लिखना'),
(105943, 7268, 27, 'लिख डालना'),
(105944, 7270, 27, 'wsome'),
(105945, 7271, 27, 'WT'),
(105946, 7273, 27, 'X रद्द'),
(105947, 7274, 27, 'X रद्द'),
(105948, 7275, 27, 'एक्स - रे'),
(105949, 7276, 27, 'एक्सरे व्याख्या:'),
(105950, 7277, 27, 'एक्स रे व्याख्या:'),
(105951, 7278, 27, 'X12 केवल: रिप्लेसमेंट दावा '),
(105952, 7279, 27, 'X 12 साथी'),
(105953, 7280, 27, 'X12 पार्टनर्स'),
(105954, 7281, 27, 'x12 पाठ'),
(105955, 7284, 27, 'Y'),
(105956, 7285, 27, 'साल'),
(105957, 7286, 27, 'साल'),
(105958, 7287, 27, 'साल दृश्य'),
(105959, 7288, 27, 'साल'),
(105960, 7289, 27, 'साल'),
(105961, 7290, 27, 'साल या महीने'),
(105962, 7291, 27, 'साल, महीने और दिन'),
(105963, 7292, 27, 'हाँ'),
(105964, 7293, 27, 'हां'),
(105965, 7294, 27, 'हां'),
(105966, 7295, 27, 'हाँ!'),
(105967, 7296, 27, 'हाँ, हटाएँ और प्रवेश'),
(105968, 7298, 27, 'हां / नहीं'),
(105969, 7299, 27, 'हाँ:'),
(105970, 7300, 27, 'Yiddish');
INSERT INTO `lang_definitions` VALUES
(105971, 7303, 27, 'आप स्थायी रूप से मौजूदा टेम्पलेट को बदलने वाले हैं. क्या आप जारी रखना चाहते हैं?'),
(105972, 7304, 27, 'आप ग्रेस लॉगइन अवधि में हैं. पहले अपने पासवर्ड बदलें'),
(105973, 7305, 27, 'आपको इस घटना को हटाने की अनुमति नहीं है'),
(105974, 7306, 27, 'आपको इस घटना को संपादित करने की अनुमति नहीं है'),
(105975, 7307, 27, 'आप इस बात के लिए अधिकृत नहीं हैं.'),
(105976, 7308, 27, 'आप इस दस्ते का उपयोग करने के लिए अधिकृत नहीं हैं.'),
(105977, 7309, 27, 'आप मुद्दों को जोड़ने/संपादन करने के लिए अधिकृत नहीं हैं'),
(105978, 7310, 27, 'आप अपॉइंटमेंट शेड्यूल करने के लिए अधिकृत नहीं हैं.'),
(105979, 7311, 27, 'आप इस मुठभेड़ को देखने के लिए अधिकृत नहीं हैं.'),
(105980, 7312, 27, 'आप एक पुराने मुठभेड़ के खिलाफ पोस्ट कर रहे हैं?'),
(105981, 7313, 27, 'आप सीधे इस फ़ंक्शन का उपयोग नहीं कर सकते हैं.'),
(105982, 7314, 27, 'आप सीधे इस पेज का उपयोग नहीं कर सकते हैं.'),
(105983, 7315, 27, 'आप एक श्रेणी के लिए एक खाली मूल्य नहीं जोड़ सकते हैं!'),
(105984, 7316, 27, 'आप एक उपश्रेणी के लिए एक खाली मूल्य नहीं जोड़ सकते हैं!'),
(105985, 7317, 27, 'आप एक आइटम के लिए एक खाली मूल्य नहीं जोड़ सकते हैं!'),
(105986, 7318, 27, 'आप पूरा मूल्य YES के साथ एक भविष्य की तिथि प्रवेश नहीं कर सकते हैं.'),
(105987, 7319, 27, 'आपने किसी भी कार्रवाई का चयन नहीं किया हैं.'),
(105988, 7320, 27, 'आपको यह नोट देखने/संपादन करने के लिए अनुमति नहीं है'),
(105989, 7321, 27, 'आपने अवरोधित सामग्री में परिवर्तन करने का प्रयास किया है. आप ऐसा करना चाहते हैं, तो ताला निकालें. , अनलॉक लाइन निकालने के लिए, ''/ * ताला :: * /'''),
(105990, 7322, 27, 'आप सफलतापूर्वक लॉग आउट कर चुके.'),
(105991, 7323, 27, 'आप Txt फ़ाइलें अपलोड कर सकते हैं.'),
(105992, 7324, 27, 'आप वैकल्पिक रूप से एक फ़ाइल से HL7 परिणाम अपलोड कर सकते हैं'),
(105993, 7325, 27, 'आप नया रोगी मुठभेड़ फार्म में डिफ़ॉल्ट शिकायत के रूप में यहाँ पाठ डाल सकता है.'),
(105994, 7326, 27, 'आपको दस्तावेज़ एन्क्रिप्ट करने के लिए एक पास वाक्यांश दर्ज करना आवश्यक है'),
(105995, 7327, 27, 'आप उपयोगकर्ता की पासवर्ड को बदलने के लिए अपनी खुद की पासवर्ड दर्ज करें. पासवर्ड अपरिवर्तित रखने के लिए खाली छोड़ दें.'),
(105996, 7329, 27, 'आपको पहले एक रोगी को जोड़ना होगा या चयन करना होगा'),
(105997, 7330, 27, 'आपको पहले एक मुठभेड़ बनाना होगा या चयन करना होगा'),
(105998, 7331, 27, 'आपको एक यात्रा श्रेणी का चयन करना होगा'),
(105999, 7332, 27, 'आपको एक यात्रा श्रेणी का चयन करना होगा.'),
(106000, 7333, 27, 'आपको जारी रखने के लिए कुछ क्षेत्रों का चयन करना होगा.'),
(106001, 7334, 27, 'You should be running this test if this claim appeared to generate successfully but the actual claim file does not contain any data or only an unfinished portion of the amount of data it is supposed to contain. It is obvious with HCFA claims because they are human readable, with X12 claims it is a more difficult process to determine if the claim is properly complete.'),
(106002, 7335, 27, 'आपको कम से कम एक संदर्भ का चयन करना चाहिए'),
(106003, 7336, 27, 'आपको कम से कम एक प्रदाता का चयन करना चाहिए'),
(106004, 7339, 27, 'आपकी समाप्ति तिथि अमान्य है'),
(106005, 7340, 27, 'आपकी घटना हटा दी गई है.'),
(106006, 7341, 27, 'आपकी घटना को संशोधित किया गया है.'),
(106007, 7342, 27, 'आपकी घटना प्रस्तुत कि गई है.'),
(106008, 7343, 27, 'आपकी फ़ाइल बहुत बड़ी है'),
(106009, 7345, 27, 'आपकी सूची का नाम नामकरण आवश्यकताओं को पूरा करने के लिए बदल दिया गया है.'),
(106010, 7346, 27, 'आपका संदेश प्रति वितरण के लिए प्रस्तुत किया गया था'),
(106011, 7347, 27, 'इस श्रेणी, प्रक्रिया या परिणाम के लिए आपका नाम'),
(106012, 7348, 27, 'आपका पासवर्ड'),
(106013, 7349, 27, 'आपका पासवर्ड समाप्त हो गया है. अपना पासवर्ड बदल दें.'),
(106014, 7350, 27, 'आपका पासवर्ड को समाप्त हो रहा है'),
(106015, 7351, 27, 'आपका पासवर्ड आज समाप्त हो रहा है. अपना पासवर्ड बदल दें.'),
(106016, 7353, 27, 'आपका PostCalendar विन्यास, डिफ़ॉल्ट का उपयोग करने के लिए रीसेट किया गया है.'),
(106017, 7354, 27, 'आपका PostCalendar विन्यास अद्यतन किया गया है.'),
(106018, 7355, 27, 'आपकी दोहराई जाने वाली आवृत्ति एक पूर्णांक होनी चाहिए.'),
(106019, 7356, 27, 'आपकी दोहराई जाने वाली आवृत्ति कम से कम 1 होनी चाहिए.'),
(106020, 7357, 27, 'आपकी आरंभ तिथि अपने अंत तिथि से अधिक है'),
(106021, 7358, 27, 'आपकी आरंभ तिथि अमान्य है'),
(106022, 7359, 27, 'आपका सबमिशन असफल रहा.'),
(106023, 7360, 27, 'yyyy-mm-dd'),
(106024, 7361, 27, 'YYYY-MM-DD'),
(106025, 7362, 27, 'इस दस्तावेज़ के साथ जुड़े YYYY-MM-DD तिथि'),
(106026, 7363, 27, 'yyyy-mm-dd तिथि नष्ट'),
(106027, 7364, 27, 'yyyy-mm-dd जन्म तिथि'),
(106028, 7365, 27, 'yyyy-mm-dd जन्म तिथि'),
(106029, 7366, 27, 'yyyy-mm-dd समय समाप्ति की तिथि'),
(106030, 7367, 27, 'yyyy-mm-dd शुरुआत या अस्पताल में भर्ती की तिथि'),
(106031, 7368, 27, 'yyyy-mm-dd शुरुआत, सर्जरी या दवा की शुरुआत की तिथि'),
(106032, 7369, 27, 'yyyy-mm-dd खरीद या स्थानांतरण की तिथि'),
(106033, 7370, 27, 'yyyy-mm-dd वसूली या दवा की समाप्ति की तिथि'),
(106034, 7371, 27, 'yyyy-mm-dd खेलने के लिए वापसी की तिथि'),
(106035, 7372, 27, 'yyyy-mm-dd सेवा की तिथि'),
(106036, 7373, 27, 'yyyy-mm-dd इस पत्र की तिथि'),
(106037, 7374, 27, 'yyyy-mm-dd खेलने के लिए लौट आए तिथि'),
(106038, 7375, 27, 'yyyy-mm-dd दस्तावेज़ तिथि'),
(106039, 7376, 27, 'yyyy-mm-dd घटना तिथि या शुरू होने की तिथि'),
(106040, 7381, 27, 'yyyy-mm-dd hh:mm:ss'),
(106041, 7382, 27, 'yyyy-mm-dd घंटे (24): मिनट'),
(106042, 7383, 27, 'yyyy-mm-dd इस घटना की अंतिम तिथि'),
(106043, 7387, 27, 'शून्य'),
(106044, 7389, 27, 'पिन'),
(106045, 7390, 27, 'पिन कोड'),
(106046, 7391, 27, 'ज़िप / देश:'),
(106047, 7392, 27, 'पिन'),
(106048, 7393, 27, ' लेकिन था '),
(106049, 7394, 27, ' नहीं पहुंचा जा सका.'),
(106050, 7395, 27, 'आप वास्तव में मिटाना चाहते हैं'),
(106051, 7396, 27, 'दवा'),
(106052, 7397, 27, 'नहीं भेजा ईमेल'),
(106053, 7398, 27, 'से'),
(106054, 7399, 27, 'बनाया गया है. '),
(106055, 7400, 27, 'फिर से खोल दिया गया है.'),
(106056, 7401, 27, 'इतिहास'),
(106057, 7402, 27, 'एक नंबर नहीं है'),
(106058, 7403, 27, 'फिर से बिलिंग के लिए तैयार है.'),
(106059, 7404, 27, 'LLL:'),
(106060, 7405, 27, 'Lot'),
(106061, 7406, 27, 'Medicaid मूल संदर्भ संख्या '),
(106062, 7407, 27, 'मिनट'),
(106063, 7408, 27, 'नहीं मिला!'),
(106064, 7409, 27, 'Pecularities in many browsers may mean that the output below enters your screen in sudden jerks and that there are long pauses of several seconds where it appears as though things may have crashed. That is not the case, you will eventually see output coming out line by line. There may be sequential numbers appearing below, this is to indicate that even though nothing else may be displaying there is activity going on. These numbers will be interspersed with the content of the billing and that is normal.'),
(106065, 7410, 27, 'पर्चे की अपनी सीमा तक पहुँच गया है'),
(106066, 7411, 27, 'जब तक'),
(106067, 7412, 27, 'अद्यतन विफल रहा है, डेटाबेस में नहीं ?'),
(106068, 7413, 27, 'केवल बिल भेजा के रूप में चिह्नित किया गया था.'),
(106069, 7414, 27, 'सफलतापूर्वक पंक्तिबद्ध किया गया था.'),
(106070, 7415, 27, '! चला गया w / o दौरा'),
(106071, 7416, 27, 'कोड के लिए'),
(106072, 7417, 27, 'PostCalendar सेटिंग्स में जाँच की है!'),
(106073, 7418, 27, '# Ins / Fin मुद्दा'),
(106074, 7419, 27, '# गोलियों की'),
(106075, 7420, 27, '$'),
(106076, 7421, 27, '$ कोडिंग किया'),
(106077, 7422, 27, '$ लेबल (YYYY-MM-DD): '),
(106078, 7423, 27, '%'),
(106079, 7424, 27, '% रद्द <24'),
(106080, 7425, 27, '% रद्द <24 '),
(106081, 7426, 27, 'मौजूद होना चाहिए, लेकिन नहीं .'),
(106082, 7427, 27, '(% किसी स्ट्रिंग से मेल खाता है, _ कोई भी वर्ण से मेल खाता है)'),
(106083, 7428, 27, '([Ctrl] + एकाधिक प्राप्तकर्ताओं को चुनने के लिए क्लिक करें)'),
(106084, 7429, 27, '(वापस)'),
(106085, 7430, 27, '(संपादित करने के लिए क्लिक करें)'),
(106086, 7431, 27, '(ईमेल वितरण तत्काल है, जबकि ऑटोमेटेड VOIP आगे की प्रक्रिया के लिए सेवा प्रदाता को भेजा है)'),
(106087, 7432, 27, '(अधिक)'),
(106088, 7433, 27, '(नए रोगी)'),
(106089, 7434, 27, '(नोट्स और प्राधिकरण)'),
(106090, 7435, 27, '(रोगी नोट्स)'),
(106091, 7436, 27, '(इनमें से किसी एक का चयन करें, या अपना खुद का शीर्षक लिखें)'),
(106092, 7437, 27, '(शिफ्ट)क्लिक करें या खींचें, मान बदलने के लिए'),
(106093, 7438, 27, '* अनुस्मारक किया'),
(106094, 7439, 27, '** कृपया सर्जरी को समस्याएँ में स्थानांतरित करना!'),
(106095, 7440, 27, '* आवश्यक'),
(106096, 7441, 27, '+ चार्ट निकाला'),
(106097, 7442, 27, '- कोई नहीं'),
(106098, 7443, 27, '- सभी -'),
(106099, 7444, 27, '- रोल का चयन करें -'),
(106100, 7445, 27, '.'),
(106101, 7446, 27, '0'),
(106102, 7447, 27, '0-10'),
(106103, 7448, 27, '0-24'),
(106104, 7451, 27, '1'),
(106105, 7452, 27, '1 = उत्तर अमेरिका. अन्य देश कोड की सूची के लिए http://www.wtng.info/ देखें.'),
(106106, 7453, 27, 'अब से 1 दिन'),
(106107, 7454, 27, 'अब से 1 महीने'),
(106108, 7455, 27, 'अब से 1 सप्ताह'),
(106109, 7456, 27, 'अब से 1 वर्ष'),
(106110, 7457, 27, '1.आराम करें. 2. दो दिनों के लिए बर्फ. 3 संपीड़न, जगह में ड्रेसिंग छोड़ दें. जब तक पैर सुन्न या पीला रंग विकसित नहीं हो 4 पैर उठाओ'),
(106111, 7458, 27, '11-14'),
(106112, 7459, 27, '12 घंटे'),
(106113, 7460, 27, '15-19'),
(106114, 7462, 27, '2'),
(106115, 7463, 27, 'अब से 2 दिन'),
(106116, 7464, 27, 'अब से 2 महीने'),
(106117, 7465, 27, 'अब से 2 सप्ताह'),
(106118, 7466, 27, 'अब से 2 साल'),
(106119, 7467, 27, '2-20 साल'),
(106120, 7468, 27, '20-24'),
(106121, 7477, 27, '2111-13'),
(106122, 7478, 27, '24 घंटा'),
(106123, 7479, 27, '25 +'),
(106124, 7480, 27, '25-29'),
(106125, 7481, 27, '2'),
(106126, 7482, 27, 'अब से 3 दिन'),
(106127, 7483, 27, '3 महीने'),
(106128, 7484, 27, 'अब से 3 महीने'),
(106129, 7485, 27, 'प्रतिदिन 3 बार'),
(106130, 7486, 27, 'अब से 3 सप्ताह'),
(106131, 7487, 27, '30-34'),
(106132, 7488, 27, '35-39'),
(106133, 7489, 27, '3 री'),
(106134, 7490, 27, 'अब से 4 दिन'),
(106135, 7491, 27, '4 महीने'),
(106136, 7492, 27, 'अब से 4 महीने'),
(106137, 7493, 27, 'प्रतिदिन 4 बार'),
(106138, 7494, 27, 'अब से 4 सप्ताह'),
(106139, 7495, 27, '40-44'),
(106140, 7496, 27, '45 +'),
(106141, 7497, 27, '465.9, URI'),
(106142, 7498, 27, '466.0, ब्रोंकाइटिस, तीव्र NOS'),
(106143, 7499, 27, '486.0, निमोनिया, तीव्र'),
(106144, 7500, 27, '491.21, COPD तेज़ हो जाना'),
(106145, 7501, 27, '491.8, ब्रोंकाइटिस, जीर्ण'),
(106146, 7502, 27, '493.92, अस्थमा, तीव्र exac.'),
(106147, 7503, 27, '496.0, COPD'),
(106148, 7504, 27, '4'),
(106149, 7505, 27, 'अब से 5 दिन'),
(106150, 7506, 27, 'अब से 5 महीने'),
(106151, 7507, 27, 'अब से 5 सप्ताह'),
(106152, 7508, 27, '519.7, श्वसनी - आकर्ष'),
(106153, 7509, 27, '5'),
(106154, 7510, 27, 'अब से 6 दिन'),
(106155, 7511, 27, '6 महीने'),
(106156, 7512, 27, 'अब से 6 महीने'),
(106157, 7513, 27, 'अब से 6 सप्ताह'),
(106158, 7514, 27, '6'),
(106159, 7515, 27, 'अब से 7 महीने'),
(106160, 7516, 27, 'अब से 8 महीने'),
(106161, 7517, 27, '824.0 फ्रैक्चर, औसत दर्जे का malleolus, बंद हुआ'),
(106162, 7518, 27, '824.2 फ्रैक्चर, पार्श्व malleolus, बंद'),
(106163, 7519, 27, '824.6 फ्रैक्चर, Trimalleolar, बंद'),
(106164, 7520, 27, '825.32 फ्रैक्चर, Navicular की (टखने)'),
(106165, 7521, 27, '825.35 फ्रैक्चर, पांचवें (5) metatarsal के आधार'),
(106166, 7522, 27, '845.00 टखने की मोच NOS'),
(106167, 7523, 27, '845.01 मोच औसत दर्जे (तिकोना) Lig.'),
(106168, 7524, 27, '845.02 मोच, केलकेनीयल अनुजंघास्थिक'),
(106169, 7525, 27, 'अब से 9 माह'),
(106170, 7526, 27, '99212 स्थापित - सीधी'),
(106171, 7527, 27, '99,213 स्थापित - कम जटिलता'),
(106172, 7528, 27, '<चिकित्सक कक्ष में'),
(106173, 7529, 27, '> बाहर गए'),
(106174, 7530, 27, '?'),
(106175, 7531, 27, '? नहीं आया'),
(106176, 7532, 27, '@ पहुंचे'),
(106177, 7533, 27, '[दृश्य बदलें]'),
(106178, 7534, 27, '[पिछले मुठभेड़ की तिथि]'),
(106179, 7535, 27, '[अंतिम मुठभेड़ के बाद से दिन]'),
(106180, 7536, 27, '[EOBs]'),
(106181, 7537, 27, '[निर्यात OFX]'),
(106182, 7538, 27, '[सिफारिश नहीं]'),
(106183, 7539, 27, '[मुठभेड़ों की संख्या]'),
(106184, 7540, 27, '[रिपोर्टें]'),
(106185, 7541, 27, '[सभी का चयन]'),
(106186, 7542, 27, '[SQL लेजर]'),
(106187, 7543, 27, '[बैच प्रोसेसिंग प्रारंभ]'),
(106188, 7544, 27, '[देखें log]'),
(106189, 7545, 27, '[मुद्रण योग्य रिपोर्ट देखें]'),
(106190, 7546, 27, '_PC_DUR_HOURS'),
(106191, 7547, 27, '_PC_DUR_MINUTES'),
(106192, 7548, 27, '_PC_LOCALE'),
(106193, 7549, 27, '~ देर से पहुंचे'),
(106194, 1, 28, 'A'),
(106195, 2, 28, 'Un numar de control sau numarul de identificare a plății'),
(106196, 3, 28, 'Un certificat de autentificare pentru administrator'),
(106197, 5, 28, 'Un document clinic este atasat.'),
(106198, 7, 28, 'Este necesar un distributor'),
(106199, 8, 28, 'o forma de vizita GCAC trebuie adaugata la aceasta vizita'),
(106200, 9, 28, 'Este necesar un numar de lot'),
(106201, 10, 28, 'Este necesar un numar de lot!'),
(106202, 11, 28, 'O litera mica'),
(106203, 12, 28, 'Un numar'),
(106204, 14, 28, 'Un pacient cu acest ID exista deja.'),
(106205, 15, 28, 'Un pacient cu acest nume exista deja.'),
(106206, 16, 28, 'Un pacient cu acest SS exista deja.'),
(106207, 18, 28, 'Un numar pozitiv va arata ca multe programari trecute pe Widget pe ecran in fisa pacientului.'),
(106208, 19, 28, 'O sursa de referinta va fi specificata pentru fiecare vizita.'),
(106209, 20, 28, 'Este necesar un cod IPPF.'),
(106210, 21, 28, 'Un caracter special'),
(106211, 22, 28, 'O valoare unica pentru identificarea acestui camp, dar ne-vizibila de user.'),
(106212, 24, 28, 'a.c.'),
(106213, 25, 28, 'a.m.'),
(106214, 26, 28, 'A/F Nivel dreapta:'),
(106215, 27, 28, 'AB'),
(106216, 28, 28, 'Abreviere'),
(106217, 29, 28, 'Abces:'),
(106218, 30, 28, 'Abdominal'),
(106219, 31, 28, 'Capabil sa suporte greutatea patru (4) etape'),
(106220, 32, 28, 'Abn'),
(106221, 33, 28, 'ABN1'),
(106222, 34, 28, 'Anormal'),
(106223, 35, 28, 'Anormal test de sange'),
(106224, 36, 28, 'Cresterea parului anormala'),
(106225, 37, 28, 'Anormala mamografie'),
(106226, 39, 28, 'Avort'),
(106227, 40, 28, 'Probleme avort'),
(106228, 41, 28, 'Avort metoda'),
(106229, 42, 28, 'Categorii legate de avort'),
(106230, 43, 28, 'Avorturi'),
(106231, 44, 28, 'Despre calendar'),
(106232, 46, 28, 'Absentele de diagnostic'),
(106233, 47, 28, 'Acceptare transfer'),
(106234, 48, 28, 'Acceptare plata pentru'),
(106235, 49, 28, 'Acceptare plata pentru'),
(106236, 50, 28, 'Accepta cesiunea'),
(106237, 51, 28, 'Acces control'),
(106238, 52, 28, 'Acces control lista administratie'),
(106239, 54, 28, 'Acces nepermis'),
(106240, 55, 28, 'Acces neautorizat'),
(106241, 56, 28, 'Accesul pacientului in portal'),
(106242, 59, 28, 'Numele contului'),
(106243, 62, 28, 'Contabilitate'),
(106244, 64, 28, 'Dureri'),
(106245, 65, 28, 'Confirmare solicitant (ISA 14)'),
(106246, 66, 28, 'Confirmare,licentiere si certificare'),
(106247, 67, 28, 'ACL'),
(106248, 68, 28, 'ACL Administrare'),
(106249, 69, 28, 'ACL Admiinistrare neautorizata'),
(106250, 71, 28, 'Acnee'),
(106251, 72, 28, 'Act'),
(106252, 73, 28, 'Actul de date'),
(106253, 74, 28, 'Actiune'),
(106254, 75, 28, 'Actiuni'),
(106255, 77, 28, 'Activare CCR/CCD de raportare'),
(106256, 78, 28, 'Activa'),
(106257, 79, 28, 'Alerta activa'),
(106258, 80, 28, 'Reguli alerta active'),
(106259, 81, 28, 'Alerte active/ memento-uri'),
(106260, 82, 28, 'Intalniri active'),
(106261, 84, 28, 'Liste active'),
(106262, 85, 28, 'Pacienti activi'),
(106263, 86, 28, 'Planuri active'),
(106264, 87, 28, 'Activitate'),
(106265, 88, 28, 'Tipul activitatii'),
(106266, 90, 28, 'Intoxicatie acuta/ retragere'),
(106267, 92, 28, 'Cronica acuta'),
(106268, 93, 28, 'adauga'),
(106269, 94, 28, 'Adauga'),
(106270, 95, 28, 'ADAUGA'),
(106271, 96, 28, 'Adauga o companie'),
(106272, 98, 28, 'Adauga o farmacie'),
(106273, 100, 28, 'Adauga un eveniment pentru '),
(106274, 101, 28, 'Adauga ca o noua nota'),
(106275, 102, 28, 'Adauga ca nou'),
(106276, 104, 28, 'Adaugati butoane'),
(106277, 105, 28, 'Adăugați butoane pentru caractere speciale, textele să fie afișate în partea de sus a Editor pentru includerea în textul de pe un Click'),
(106278, 106, 28, 'Adauga categorie'),
(106279, 107, 28, 'Adauga constanta'),
(106280, 108, 28, 'Adauga context'),
(106281, 109, 28, 'Adauga coplatitor'),
(106282, 110, 28, 'Adauga criteriu'),
(106283, 111, 28, 'Adauga buton customizat'),
(106284, 112, 28, 'Adauga diagnostic'),
(106285, 113, 28, 'Adauga medicament'),
(106286, 114, 28, 'Adauga intalnire'),
(106287, 115, 28, 'Adauga intalnire/ note'),
(106288, 116, 28, 'Adauga facilitate'),
(106289, 117, 28, 'Adauga domeniu'),
(106290, 118, 28, 'Adăugați următoarele linii în fișierul de configurare Apache'),
(106291, 119, 28, 'Adauga grup'),
(106292, 120, 28, 'Adauga codul ICD'),
(106293, 121, 28, 'Adauga imunitate'),
(106294, 122, 28, 'Adaugare nepermisa'),
(106295, 123, 28, 'Adauga problema'),
(106296, 125, 28, 'Adauga limba'),
(106297, 126, 28, 'Adaugare noua'),
(106298, 127, 28, 'Adaugare noua'),
(106299, 128, 28, 'Adauga categorie noua '),
(106300, 129, 28, 'Adauga certificat nou in fisierul de configurare Apache'),
(106301, 132, 28, 'Adauga grup nou'),
(106302, 133, 28, 'Adauga noua problema'),
(106303, 134, 28, 'Adauga lot nou si tanzactii'),
(106304, 135, 28, 'Adauga Nota Noua'),
(106305, 136, 28, 'Adauga nota noua'),
(106306, 137, 28, 'Adauga partener nou'),
(106307, 140, 28, 'Adauga nota'),
(106308, 141, 28, 'Adauga inregistrarea pacientului'),
(106309, 142, 28, 'Adauga reteta'),
(106310, 143, 28, 'Adauga procedura'),
(106311, 144, 28, 'Adauga numarul furnizorului'),
(106312, 145, 28, 'Adauga dezintoxicare'),
(106313, 147, 28, 'Adauga la'),
(106314, 148, 28, 'Adauga la lista de medicamente'),
(106315, 149, 28, 'Adauga nivel de top'),
(106316, 150, 28, 'Adauga tranzactie'),
(106317, 151, 28, 'Adauga utilizator'),
(106318, 152, 28, 'Adauga utilizator la grup'),
(106319, 153, 28, 'Adaugare/editare eRX'),
(106320, 154, 28, 'Adaugare/editare tranzacia pacientului'),
(106321, 155, 28, 'Adaugat'),
(106322, 156, 28, 'Adaugarea demografica nu este autorizata'),
(106323, 158, 28, 'Sindrom Addison'),
(106324, 159, 28, 'Sindromul Addison'),
(106325, 160, 28, 'Atribute suplimentare'),
(106326, 161, 28, 'Diagnostic suplimentar'),
(106327, 162, 28, 'Istorie suplimentara'),
(106328, 163, 28, 'Istorie note suplimentara'),
(106329, 164, 28, 'Informatii suplimentare'),
(106330, 165, 28, 'Laboratoare suplimentare'),
(106331, 166, 28, 'Note suplimentare'),
(106332, 167, 28, 'Note suplimentare pentru aceste rezultate sau recomandari'),
(106333, 168, 28, 'Note suplimentare:'),
(106334, 169, 28, 'Note suplimentare: '),
(106335, 170, 28, 'Note X-RAY suplimenatre'),
(106336, 172, 28, 'Doar adaugare'),
(106337, 174, 28, 'Carte de adrese'),
(106338, 175, 28, 'Adresa'),
(106339, 178, 28, 'Adresa carte'),
(106340, 179, 28, 'Intrare agenda pentru compania care efectueaza aceasta procedura'),
(106341, 180, 28, 'Intrare agenda pentru distribuitor'),
(106342, 181, 28, 'Intrare agenda pentru furnizor'),
(106343, 182, 28, 'Tipuri intrare agenda'),
(106344, 187, 28, 'Adresa 1'),
(106345, 188, 28, 'Adresa 2'),
(106346, 189, 28, 'DESTINATAR'),
(106347, 190, 28, 'Adj'),
(106348, 191, 28, 'Adj suma'),
(106349, 192, 28, 'Ajusta'),
(106350, 193, 28, 'Ajustare'),
(106351, 194, 28, 'Ajustare Amt'),
(106352, 195, 28, 'Motiv de ajustare'),
(106353, 196, 28, 'Ajustare valoare pentru cod '),
(106354, 197, 28, 'Ajustari'),
(106355, 198, 28, 'Ajustare Adm'),
(106356, 199, 28, 'Admin'),
(106357, 200, 28, 'Admin adresa email'),
(106358, 201, 28, 'Administra prin'),
(106359, 202, 28, 'Administrat'),
(106360, 203, 28, 'Administrat de'),
(106361, 205, 28, 'Site-ul administrat'),
(106362, 206, 28, 'Administrare'),
(106363, 207, 28, 'Administrare site'),
(106364, 208, 28, 'Administratori'),
(106365, 209, 28, 'Administratorii pot face orice'),
(106366, 210, 28, 'Informatii Admin'),
(106367, 212, 28, 'Greutate adulti verificare si urmarire'),
(106368, 213, 28, 'Greutate adulti verificare si urmarire (CQM)'),
(106369, 214, 28, 'Directiva in avans'),
(106370, 215, 28, 'Directive in avans'),
(106371, 216, 28, 'Avertizari directive in avans'),
(106372, 218, 28, 'Avansat'),
(106373, 219, 28, 'Sfat'),
(106374, 221, 28, 'Afecteaza normal'),
(106375, 223, 28, 'Apeluri dupa ora'),
(106376, 226, 28, 'Dupa salvarea PDF-ului,apasa (vezi logo) pentru verificare erori'),
(106377, 227, 28, 'Dupa salvarea fisierului( lor) TEXT,apasa (vezi logo) pentru verificare erori'),
(106378, 228, 28, 'Dupa salvarea grupului,apasa (vezi logo)pentru verificare erori'),
(106379, 230, 28, 'Dupa ce informatia este corect introdusa,apasa butonul Save'),
(106380, 232, 28, 'Plan de ingrijire'),
(106381, 233, 28, 'inca odata'),
(106382, 234, 28, 'Varsta'),
(106383, 235, 28, 'Varsta de'),
(106384, 236, 28, 'Categorie de varsta'),
(106385, 237, 28, 'Datele de varsta sunt in afara intervalului'),
(106386, 238, 28, 'Afisare format varsta'),
(106387, 239, 28, 'Format varsta pentru "varsta de la" nu este valid'),
(106388, 240, 28, 'Format varsta pentru "varsta pana la" nu este valid'),
(106389, 241, 28, 'Varsta de la'),
(106390, 242, 28, 'Varsta in ani pentru afisare format schimbat'),
(106391, 243, 28, 'Varsta maxima'),
(106392, 244, 28, 'Varsta minima'),
(106393, 245, 28, 'Interval de varsta'),
(106394, 247, 28, 'Imbatranire coloane:'),
(106395, 249, 28, 'Albanez'),
(106396, 250, 28, 'Alcool'),
(106397, 251, 28, 'Consum de alcool'),
(106398, 253, 28, 'Numarul alerta'),
(106399, 255, 28, 'Alerte'),
(106400, 259, 28, 'Toate'),
(106401, 260, 28, 'TOATE'),
(106402, 261, 28, 'Toate (Colationate format A)'),
(106403, 262, 28, 'Toate (Colationate format B)'),
(106404, 263, 28, 'Toate (cumulativ)'),
(106405, 266, 28, 'Toate categoriile'),
(106406, 268, 28, 'Toate codurile'),
(106407, 269, 28, 'Toate zilele'),
(106408, 270, 28, 'Evenimentele zilnice'),
(106409, 271, 28, 'Toate campurile demografice ,cu cautare si dubla verificare'),
(106410, 272, 28, 'Toate facilitatile'),
(106411, 273, 28, 'Toate pagubele/problemele'),
(106412, 274, 28, 'Toate limbile permise'),
(106413, 276, 28, 'Toate sau o parte din prenume'),
(106414, 277, 28, 'Toate sau o parte din numele de familie'),
(106415, 278, 28, 'Totul sau o parte din oragnizatie'),
(106416, 280, 28, 'Toate produsele'),
(106417, 281, 28, 'Toti furnizorii'),
(106418, 283, 28, 'Toate subiectele'),
(106419, 284, 28, 'Toti utilizatorii'),
(106420, 285, 28, 'Alergic'),
(106421, 286, 28, 'Alergii'),
(106422, 287, 28, 'Alergii:'),
(106423, 288, 28, 'Alergie'),
(106424, 289, 28, 'Import alergie finalizat cu succes'),
(106425, 291, 28, 'Reactii alergice'),
(106426, 294, 28, 'Alocat'),
(106427, 295, 28, 'Permite'),
(106428, 296, 28, 'Permiteți toate limbile disponibile ca opțiuni în meniul de autentificare.'),
(106429, 297, 28, 'Permite crearea de cereri care conțin diagnostice, dar nu la proceduri sau taxe. Cele mai multe clinici nu doresc acest lucru.'),
(106430, 299, 28, 'Permiteti email'),
(106431, 300, 28, 'Permiteti mesaje pe email?'),
(106432, 301, 28, 'Permiteti email?'),
(106433, 302, 28, 'Permiteti intalniri creante?'),
(106434, 303, 28, 'Permiteti schimb de informatii despre sanatate'),
(106435, 306, 28, 'Permiteti mesaj pe mail'),
(106436, 308, 28, 'Permiteti portal pacienti'),
(106437, 309, 28, 'Permiteti SMS'),
(106438, 310, 28, 'Permiteti SMS ( mesaj text)?'),
(106439, 311, 28, 'Permiteti evenimentele prezentate sa fie active instant?'),
(106440, 312, 28, 'Permiteti mesaj pe telefon?'),
(106441, 313, 28, 'Permite utilizatorilor să publice Evenimente globale'),
(106442, 314, 28, 'Permite utilizatorilor să publice calendare personale'),
(106443, 315, 28, 'Permiteti mesaj voce?'),
(106444, 316, 28, 'Permis'),
(106445, 317, 28, 'Limbi permise'),
(106446, 318, 28, 'Permis( c)'),
(106447, 323, 28, 'Deja exista'),
(106448, 324, 28, 'Deja exista.'),
(106449, 325, 28, 'Deja folosit,alege alt identificator'),
(106450, 326, 28, 'Deja folosit,alege alt titlu'),
(106451, 327, 28, 'Alt adresa'),
(106452, 328, 28, 'modifica'),
(106453, 329, 28, 'Alternativ, puteți folosi pagina de căutare pentru a încărca un remitențe electronic (X12 835) pe care le-ați obținut de la plătitor sau de centru de informare. Puteți face acest lucru făcând clic pe butonul Browse și selectați fișierul pentru a încărca, și apoi clic pe Căutare pentru a efectua încărcarea și afișa facturile aferente. În acest caz, celelalte parametrii menționați mai sus nu se aplică și vor fi ignorate. Încărcarea salvează fișierul, dar nu prelucrează încă conținutul său - care se face separat așa cum este descris mai jos.'),
(106454, 330, 28, 'AM'),
(106455, 331, 28, 'AM Program'),
(106456, 332, 28, 'AMC'),
(106457, 333, 28, 'Urmarire AMC'),
(106458, 338, 28, 'Se modifica nota existenta'),
(106459, 343, 28, 'American Indian'),
(106460, 344, 28, 'American Indian sau Alaska nascut'),
(106461, 345, 28, 'AMEX'),
(106462, 347, 28, 'Suma'),
(106463, 348, 28, 'Cantitatea administrata'),
(106464, 349, 28, 'Suma taxe'),
(106465, 350, 28, 'Suma pentru soldul anterior'),
(106466, 351, 28, 'Suma pentru aceasta vizita'),
(106467, 352, 28, 'Suma platita'),
(106468, 353, 28, 'Suma'),
(106469, 354, 28, 'Amt facturate'),
(106470, 355, 28, 'O dată de încheiere ulterioară datei de început este necesar pentru evenimente repetate!'),
(106471, 356, 28, 'A aparut o eroare la semnarea formularului'),
(106472, 362, 28, 'A aparut o eroare neasteptata'),
(106473, 363, 28, 'O litera mare'),
(106474, 365, 28, 'Si'),
(106475, 366, 28, 'SI'),
(106476, 367, 28, 'si'),
(106477, 368, 28, 'si '),
(106478, 369, 28, 'și toate datele subordonate? Această acțiune va fi inregistrata'),
(106479, 370, 28, 'si modifica'),
(106480, 371, 28, 'si prelucrate'),
(106481, 372, 28, 'si reporneste serverul Apache'),
(106482, 373, 28, 'si motivul este'),
(106483, 374, 28, 'Anemie'),
(106484, 375, 28, 'Glezna'),
(106485, 376, 28, 'Glezna+calcai'),
(106486, 377, 28, 'Evaluarea gleznei de la'),
(106487, 378, 28, 'Problemele gleznei'),
(106488, 381, 28, 'Anorexie'),
(106489, 382, 28, 'Un alt lucru care se poate face în fereastra de înregistrare este cererea secundar de facturare. Dacă selectaţi această casetă de selectare, înainte de salvare, apoi cererea iniţială va fi re-deschis şi în coada de aşteptare în pagina de facturare, şi vor fi procesate în timpul următoare de facturare a alerga.'),
(106490, 384, 28, 'Anus nl, nicio sensibilitate rectala/ masa'),
(106491, 385, 28, 'Anxietate'),
(106492, 386, 28, 'Orice'),
(106493, 387, 28, 'Orice categorie'),
(106494, 388, 28, 'Orice parte din codul dorit sau descrierea'),
(106495, 389, 28, 'Orice parte din specialitatea dorita'),
(106496, 390, 28, 'Orice parte din ID medicamentului sau numele medicamentului'),
(106497, 391, 28, 'Orice parte din ID imuniza'),
(106498, 392, 28, 'Orice parte din numele pacientului, sau ''nume,prenume'',sau "X-Y"'),
(106499, 393, 28, 'Alte informatii relevante'),
(106500, 395, 28, 'Apnee'),
(106501, 396, 28, 'Aspect'),
(106502, 397, 28, 'Aspect:'),
(106503, 398, 28, 'Adaugati aceasta nota'),
(106504, 399, 28, 'Adaugati la nota existenta'),
(106505, 400, 28, 'Adaugati la aceasta nota'),
(106506, 401, 28, 'Adaugati la aceasta Nota'),
(106507, 402, 28, 'Apendicectomie'),
(106508, 404, 28, 'Pacienti aplicabili'),
(106509, 405, 28, 'Aplicatie'),
(106510, 406, 28, 'Numele pentru pagina de autentificare si principalul titlu al ferestrei'),
(106511, 407, 28, 'Aplicarea Codului Receptor (GS03 - În cazul în care va fi folosit ISA08 goale)'),
(106512, 408, 28, 'Aplicatia cod de expeditor (GS02)'),
(106513, 409, 28, 'Aplicarea titlului'),
(106514, 410, 28, 'Se aplica la semnele vitale si la graficul de crestere'),
(106515, 411, 28, 'Se aplica la semnele vitale de la'),
(106516, 413, 28, 'Aplica la zona afectata'),
(106517, 414, 28, 'Aplica la piele'),
(106518, 415, 28, 'Aplicarea'),
(106519, 416, 28, 'Aplicarea plasturelui la site'),
(106520, 417, 28, 'Programare'),
(106521, 418, 28, 'Data progamare'),
(106522, 419, 28, 'Mod de afisare a programarii'),
(106523, 420, 28, 'Regula de reamintire a programarii'),
(106524, 421, 28, 'Starea programarii'),
(106525, 422, 28, 'Starile programarilor'),
(106526, 423, 28, 'Programare in'),
(106527, 424, 28, 'Culoarea programarii/ evenimentului'),
(106528, 425, 28, 'Progaramari'),
(106529, 426, 28, 'Programari ( optional)'),
(106530, 427, 28, 'Programari (scrieri optionale)'),
(106531, 430, 28, 'Programari si intalniri'),
(106532, 431, 28, 'Raport programari'),
(106533, 432, 28, 'Raport programari-intalniri'),
(106534, 434, 28, 'Aprobari'),
(106535, 436, 28, 'Aprobat'),
(106536, 437, 28, 'Administrare evenimente aprobate'),
(106537, 440, 28, 'Appt-Enc'),
(106538, 441, 28, 'Appts'),
(106539, 442, 28, 'Apr'),
(106540, 443, 28, 'Aprilie'),
(106541, 444, 28, 'Arabic'),
(106542, 446, 28, 'Arhiva'),
(106543, 447, 28, 'Exista'),
(106544, 450, 28, 'Sunt taxele percepute pentru acest tip?'),
(106545, 451, 28, 'Sunt titluri nota de pacienti pentru a fi traduse?'),
(106546, 453, 28, 'Esti pregatit sa completezi o noua GCAC problema pentru aceasta vizita?'),
(106547, 454, 28, 'Esti sigur ca ai postat pentru azi?'),
(106548, 455, 28, 'Esti sigur ca vrei sa aprobi acest eveniment?'),
(106549, 457, 28, 'Sunteți sigur că doriți să eliminați complet acest formular?'),
(106550, 459, 28, 'Sunteți sigur că doriți să ștergeți această dezvăluire?'),
(106551, 460, 28, 'Sunteti sigur ca doriti sa stergeti acest eveniment?'),
(106552, 461, 28, 'Sunteti sigur ca doriti sa stergeti acest articol din baza de date?'),
(106553, 462, 28, 'Sunteti sigur ca doriti sa stergeti aceasta nota?'),
(106554, 464, 28, 'Sunteti sigur ca doriti sa stergeti acest eveniment?'),
(106555, 465, 28, 'Sunteti sigur ca doriti sa ascundeti acest eveniment?'),
(106556, 467, 28, 'Sunteti sigur ca doriti sa vedeti acest eveniment?'),
(106557, 468, 28, 'Sunteti sigur ca doriti sa stergeti intreaga denumire a grupului?'),
(106558, 469, 28, 'Sunteti sigur ca doriti sa stergeti intreaga lista?'),
(106559, 470, 28, 'Sunteți sigur că doriți să ștergeți domeniu în'),
(106560, 471, 28, 'Sunteti sigur ca doriti sa stergeti fisierele selectate?'),
(106561, 472, 28, 'Sunteti sigur ca doriti sa continuati aceasta actiune?'),
(106562, 473, 28, 'Zona nespecificata'),
(106563, 474, 28, 'Brat'),
(106564, 475, 28, 'Armean'),
(106565, 478, 28, 'Artrita'),
(106566, 481, 28, 'ca'),
(106567, 484, 28, 'Asiatic'),
(106568, 487, 28, 'Evaluare'),
(106569, 488, 28, 'Evaluare pentru'),
(106570, 489, 28, 'Asistent'),
(106571, 490, 28, 'Astm'),
(106572, 491, 28, 'ca'),
(106573, 495, 28, 'Echipa atletica'),
(106574, 496, 28, 'Echipa atletica'),
(106575, 497, 28, 'Atletic/rana'),
(106576, 500, 28, 'ATNA certificat local audit'),
(106577, 503, 28, 'Atentie'),
(106578, 504, 28, 'Attn'),
(106579, 516, 28, 'Aug'),
(106580, 517, 28, 'August'),
(106581, 523, 28, 'Autorizatie de grup'),
(106582, 524, 28, 'Statusul autorizatiei'),
(106583, 525, 28, 'Autorizatii'),
(106584, 526, 28, 'Autoriza'),
(106585, 527, 28, 'Autorizeaza-orice intalnire'),
(106586, 528, 28, 'Autorizeaza intalnirea mea'),
(106587, 530, 28, 'Autorizat'),
(106588, 531, 28, 'Doar autorizare'),
(106589, 532, 28, 'Autotrimitere'),
(106590, 535, 28, 'Auto creare intalniri noi'),
(106591, 536, 28, 'Auto generare'),
(106592, 537, 28, 'Calcule automate de masura AMC'),
(106593, 542, 28, 'Urmarire calcule autoamte de masura AMC'),
(106594, 543, 28, 'Masuri automate AMC'),
(106595, 544, 28, 'Automat'),
(106596, 549, 28, 'Automobil medical'),
(106597, 550, 28, 'autosalvare'),
(106598, 551, 28, 'Categorii disponibile'),
(106599, 552, 28, 'Timp disponibil'),
(106600, 557, 28, 'Medie lunara'),
(106601, 558, 28, 'Smulgere/ smulgere fractura'),
(106602, 559, 28, 'Smulgerea maleolei laterale'),
(106603, 560, 28, 'Smulgerea maleolei mediene '),
(106604, 561, 28, 'Bazate pe gradul de conştientizare'),
(106605, 562, 28, 'Axilar'),
(106606, 566, 28, 'Inapoi'),
(106607, 567, 28, 'inapoi'),
(106608, 568, 28, 'Opt vizite in urma'),
(106609, 569, 28, 'Unsprezece vizite in urma'),
(106610, 570, 28, 'Cinci vizite in urma'),
(106611, 571, 28, 'Patru vizite in urma'),
(106612, 572, 28, 'Noua vizite in urma'),
(106613, 573, 28, 'O vizita in urma'),
(106614, 574, 28, 'Durere de spate'),
(106615, 575, 28, 'Probleme cu spatele'),
(106616, 576, 28, 'Sapte vizite in urma'),
(106617, 577, 28, 'Sase vizite in urma'),
(106618, 578, 28, 'Operatie de spate'),
(106619, 579, 28, 'Zece vizite in urma'),
(106620, 580, 28, 'Trei vizite in urma'),
(106621, 581, 28, 'Inapoi la pagina de Admin'),
(106622, 584, 28, 'Inapoi la pacient'),
(106623, 585, 28, 'Inapoi la utilizator'),
(106624, 586, 28, 'Inapoi la vizualizarea'),
(106625, 587, 28, 'Doisprezece vizite in urma'),
(106626, 588, 28, 'Doua vizite in urma'),
(106627, 589, 28, 'Serviciile de fundal'),
(106628, 590, 28, 'Acoperire'),
(106629, 591, 28, 'Fisierul de rezerva a fost creeat.Acum trimitem descarcarea'),
(106630, 593, 28, 'Acoperirea a fost luata cu succes in'),
(106631, 594, 28, 'Verificare gresita'),
(106632, 595, 28, 'Debit/ datorie rea'),
(106633, 597, 28, 'Bal'),
(106634, 598, 28, 'Balanta'),
(106635, 599, 28, 'balanta'),
(106636, 603, 28, 'Proiectul de banca'),
(106637, 611, 28, 'Cerere lot'),
(106638, 612, 28, 'Instrument de verificare lot'),
(106639, 613, 28, 'Intrare plata lot'),
(106640, 614, 28, 'Platile lotului'),
(106641, 615, 28, 'Procesarea lotului initiata, dureaza un timp'),
(106642, 616, 28, 'Rezultatele lotului'),
(106643, 619, 28, 'pentru ca acest id nu exista'),
(106644, 620, 28, 'incepe'),
(106645, 621, 28, 'data de inceput'),
(106646, 623, 28, 'Data de inceput a serviciului an-luna-zi'),
(106647, 624, 28, 'Ora de inceput din zi pentru calendarul evenimentelor'),
(106648, 630, 28, 'intre'),
(106649, 633, 28, 'bilateral'),
(106650, 634, 28, 'Bilateral:'),
(106651, 636, 28, 'Data facturii'),
(106652, 638, 28, 'facturat'),
(106653, 640, 28, 'Facturare'),
(106654, 648, 28, 'Unitatea de Facturare'),
(106655, 665, 28, 'Biopsie'),
(106656, 666, 28, 'Data nasterii'),
(106657, 667, 28, 'Nastere-24 luni'),
(106658, 669, 28, 'Negru'),
(106659, 670, 28, 'Negru lung'),
(106660, 671, 28, 'Negru sau african american'),
(106661, 672, 28, 'Cancer de sange'),
(106662, 673, 28, 'Infectie in sange'),
(106663, 674, 28, 'Formulare albe'),
(106664, 675, 28, 'Probleme de sangerare'),
(106665, 677, 28, 'Balonare'),
(106666, 678, 28, 'Blocat'),
(106667, 679, 28, 'Sange'),
(106668, 680, 28, 'Tensiune arteriala'),
(106669, 681, 28, 'Tensiune arteriala'),
(106670, 682, 28, 'Sangerare nazala'),
(106671, 686, 28, 'BMI'),
(106672, 687, 28, 'Situatia BMI'),
(106673, 689, 28, 'Regiunea corpului'),
(106674, 692, 28, 'Sensibilitate osoasa'),
(106675, 696, 28, 'Jos'),
(106676, 697, 28, 'Ambele urechi'),
(106677, 698, 28, 'Ambele urechi'),
(106678, 699, 28, 'Buton'),
(106679, 701, 28, 'Casuta 10 A. relatarile angajatului '),
(106680, 702, 28, 'Casuta 10 B. accident auto '),
(106681, 703, 28, 'Casuta 10 C. altfel de accident '),
(106682, 706, 28, 'Casuta 15.Data aceleiasi boli sau similare ( an-luna-zi)'),
(106683, 708, 28, 'Casuta 16. Data de la care nu se lucreaza( an-luna-zi)'),
(106684, 710, 28, 'Casuta 18.Data spitalizarii de la (an-luna-zi) '),
(106685, 711, 28, 'Casuta 18.Data spitalizarii pana la ( an -luna-zi) '),
(106686, 712, 28, 'Esta laboratorul de afara folosit?'),
(106687, 715, 28, 'BP'),
(106688, 719, 28, 'Bpd'),
(106689, 721, 28, 'Bps'),
(106690, 722, 28, 'Brazilian portughez'),
(106691, 723, 28, 'San'),
(106692, 724, 28, 'Operatie la san'),
(106693, 727, 28, 'Examen la san'),
(106694, 730, 28, 'Sunetul respiratiei'),
(106695, 732, 28, 'Oase rupte'),
(106696, 734, 28, 'Bronsita de la'),
(106697, 735, 28, 'Rasfoiti'),
(106698, 736, 28, 'Rasfoiti pentru inregistrare'),
(106699, 739, 28, 'Drept bombat'),
(106700, 741, 28, 'Arsura la urinare'),
(106701, 742, 28, 'Arsura la urinare'),
(106702, 744, 28, 'Ocupat'),
(106703, 745, 28, 'dar inca nu e procesat'),
(106704, 746, 28, 'Fesa'),
(106705, 747, 28, 'fesa +S.I.'),
(106706, 748, 28, 'de'),
(106707, 749, 28, 'de'),
(106708, 750, 28, 'de gura'),
(106709, 751, 28, 'de/sursa'),
(106710, 752, 28, 'de:'),
(106711, 753, 28, 'C'),
(106712, 758, 28, 'Calendar'),
(106713, 759, 28, 'Calendar ora sfarsit'),
(106714, 760, 28, 'Interval calendaristic'),
(106715, 761, 28, 'Ecranul calendarului'),
(106716, 762, 28, 'Setarile calendarului'),
(106717, 763, 28, 'Calendar ora de inceput'),
(106718, 764, 28, 'Calendar UI'),
(106719, 765, 28, 'Vederea calendarului'),
(106720, 766, 28, 'Apelul la addForm () merge aici <br>'),
(106721, 767, 28, 'Calorii'),
(106722, 768, 28, 'Cambodgian'),
(106724, 774, 28, 'anulare'),
(106725, 775, 28, 'Schimbari anulate'),
(106726, 776, 28, 'anulare'),
(106727, 777, 28, 'cancer'),
(106728, 778, 28, 'Cancer de colon'),
(106729, 779, 28, 'mamografie'),
(106730, 780, 28, 'Test Papanicolau'),
(106731, 781, 28, 'Cancer de prostata'),
(106732, 782, 28, 'Acesta nu se poate adauga deoarece exista deja'),
(106733, 783, 28, 'aceasta nu se poate adauga deoarece exista deja o copie'),
(106734, 784, 28, 'nu se poate arhiva'),
(106735, 786, 28, 'nu se poate sterge/ignora'),
(106736, 790, 28, 'nu se poate creea'),
(106737, 795, 28, 'nu se gaseste '),
(106738, 796, 28, 'nu se poate gasi o destinatie a fisierului'),
(106739, 800, 28, 'Imposibil de gasit referinta documentului postscript in '),
(106740, 803, 28, 'Nu se poate deschide '),
(106741, 807, 28, 'nu se poate citi'),
(106742, 808, 28, 'nu se poate citi directorul'),
(106743, 809, 28, 'Imposibil de actualizat deoarece nu editaţi o înregistrare existentă!'),
(106744, 810, 28, 'Scrie cu majuscula'),
(106745, 812, 28, 'capsula'),
(106746, 813, 28, 'card'),
(106747, 814, 28, 'catalizator cardiac'),
(106748, 815, 28, 'electrocardiograma'),
(106749, 816, 28, 'cardiovascular'),
(106750, 821, 28, 'Cartilaj/ condrale /leziuni la disc'),
(106751, 822, 28, 'leziune a cartilajului'),
(106752, 824, 28, 'numerar'),
(106753, 825, 28, 'numerar'),
(106754, 826, 28, 'numerar Rec'),
(106755, 827, 28, 'Incasari in numerar de catre furnizor'),
(106756, 829, 28, 'operatie de cataracta'),
(106757, 830, 28, 'cataracta'),
(106758, 831, 28, 'categorii'),
(106759, 832, 28, 'categorii pentru'),
(106760, 833, 28, 'categorie'),
(106761, 834, 28, 'categorie'),
(106762, 835, 28, 'categorie '),
(106763, 836, 28, 'detalii categorie'),
(106764, 837, 28, 'limite categorie'),
(106765, 838, 28, 'numele categoriei'),
(106766, 839, 28, 'numele categoriei este gol'),
(106767, 840, 28, 'categorie/ titlu'),
(106768, 841, 28, 'caucazian'),
(106769, 850, 28, 'CDR'),
(106770, 852, 28, 'celula'),
(106771, 853, 28, 'telefon celular'),
(106772, 855, 28, 'numar telefon mobil'),
(106773, 856, 28, 'centrul de certificare'),
(106774, 857, 28, 'central/ America de Sud'),
(106775, 858, 28, 'Certificat de autoritatea crt locație fișier nu poate fi gol'),
(106776, 859, 28, 'Certificat de autoritatea cheia locatie fisier nu poate fi gol'),
(106777, 860, 28, 'Certificatu de trimis la RFC 5425TLS server syslog'),
(106778, 861, 28, 'Certificat de utilizator'),
(106779, 862, 28, 'Certificate'),
(106780, 864, 28, 'CampUS'),
(106781, 865, 28, 'CampUSVA'),
(106782, 866, 28, 'modifica'),
(106783, 867, 28, 'Modifica'),
(106784, 868, 28, 'Modifica activitatea'),
(106785, 869, 28, 'Modificare esuata ! eroare de conectare couchDB'),
(106786, 870, 28, 'Modifica in Vision'),
(106787, 871, 28, 'Modifica in Vision'),
(106788, 872, 28, 'Modifica parola'),
(106789, 874, 28, 'Modificat'),
(106790, 875, 28, 'Modificarea intestinului'),
(106791, 876, 28, 'Modifica identitatea pacientului pentru document'),
(106792, 877, 28, 'Caracteristici'),
(106793, 878, 28, 'Caractere ramase'),
(106794, 879, 28, 'Incrca'),
(106795, 880, 28, 'Incarca ajustarea'),
(106796, 881, 28, 'Incarca codul'),
(106797, 882, 28, 'Incarcari'),
(106798, 883, 28, 'Diagrama'),
(106799, 884, 28, 'Activitate diagrama'),
(106800, 885, 28, 'Raport de activitate diagrama verificare intrari/iesiri'),
(106801, 886, 28, 'ID Diagrama'),
(106802, 887, 28, 'ID Diagrama'),
(106803, 889, 28, 'Locatia activitatii diagramei'),
(106804, 890, 28, 'Nota diagrama'),
(106805, 891, 28, 'Numar diagrama'),
(106806, 892, 28, 'Locatie depozitare diagrama'),
(106807, 893, 28, 'Diagrama tractor'),
(106808, 894, 28, 'Diagrama Trk'),
(106809, 895, 28, 'Diagrama verificata'),
(106810, 896, 28, 'Diagrama iesita'),
(106811, 898, 28, 'Verificat'),
(106812, 899, 28, 'verificat'),
(106813, 900, 28, 'Verificare completa'),
(106814, 902, 28, 'Verifica suma'),
(106815, 903, 28, 'Verifica datele'),
(106816, 904, 28, 'Verificaţi pentru diferenţele de traduceri cu limba personalizate tabelul.'),
(106817, 906, 28, 'Verifica in'),
(106818, 907, 28, 'Verifica data de intrare'),
(106819, 909, 28, 'Verifica rezultatele de laborator'),
(106820, 910, 28, 'Marcaj de selectare indica revizuite'),
(106821, 911, 28, 'verifica nr'),
(106822, 912, 28, 'verifica numarul'),
(106823, 915, 28, 'Verifica plata'),
(106824, 916, 28, 'Verifica caseta daca acesta este un fisier neinteles'),
(106825, 917, 28, 'Verifica acest lucru daca doriti ca furnizorii sa vada toate programarile in mod prestabilit si nu doar a lor.'),
(106826, 918, 28, 'Verificati pentru a crea probleme la acest diagnostic.'),
(106827, 919, 28, 'verifica /data EOB'),
(106828, 920, 28, 'Verifica/ nr EOB'),
(106829, 921, 28, 'Selectare /numar ref'),
(106830, 922, 28, 'Selectare/ numar referinta'),
(106831, 923, 28, 'Caseta de selectare'),
(106832, 924, 28, 'caseta de selectare'),
(106833, 925, 28, 'Caseta w/ text'),
(106834, 926, 28, 'Caseta w/ text'),
(106835, 928, 28, 'Verificat'),
(106836, 929, 28, 'Casuta verificata= da, goala=nu'),
(106837, 931, 28, 'Bifarea lacatului va bloca orice modificare ulterioara a orice formulare din aceasta vizita.'),
(106838, 932, 28, 'Verifica cos de produse'),
(106839, 933, 28, 'Suma de verificare'),
(106840, 934, 28, 'Piept'),
(106841, 935, 28, 'CATB piept'),
(106842, 936, 28, 'Durere in piept'),
(106843, 937, 28, 'Durere in piept:'),
(106844, 938, 28, 'Dureri in piept'),
(106845, 942, 28, 'Plangere sef'),
(106846, 943, 28, 'Copil'),
(106847, 945, 28, 'Stare de imunizare din copilarie'),
(106848, 946, 28, 'Frisoane'),
(106849, 947, 28, 'Chineza'),
(106850, 948, 28, 'Chineza ( simplificat)'),
(106851, 949, 28, 'Chineza (traditional)'),
(106852, 951, 28, 'Alegeri'),
(106853, 975, 28, 'Oras'),
(106854, 976, 28, 'Nume Oras'),
(106855, 977, 28, 'Oras, Judet'),
(106856, 978, 28, 'Oras, Cod Postal'),
(106857, 979, 28, 'Oras/Judet'),
(106858, 990, 28, 'Anuleaza Pacientul Activ'),
(106859, 1003, 28, 'Click pentru ordinea sumarului'),
(106860, 1004, 28, 'Click pentru rezultat'),
(106861, 1005, 28, 'Click aici'),
(106862, 1006, 28, 'Apasa aici sa adaugi pacient nou'),
(106863, 1007, 28, 'Apasa aici pentru a adauga noi leziuni modificare stare şi edita activitatea zilnică'),
(106864, 1008, 28, 'Apasa aici pentru a alege data'),
(106865, 1009, 28, 'Apasa aici pentru a alege data si ora'),
(106866, 1010, 28, 'Apasa aici pentru a alege data de inceput'),
(106867, 1020, 28, 'Apasa aici pentru a cauta'),
(106868, 1021, 28, 'Apasa aici pentru a actualiza setarile prioritatilor,categoriei si numelui'),
(106869, 1022, 28, 'Apasa aici pentru a vedea tot'),
(106870, 1026, 28, 'Apasa aici pentru a vizualiza detaliile pacientului'),
(106871, 1027, 28, 'Apasa aici pentru a le vizualiza pe toate'),
(106872, 1028, 28, 'Apasa aici pentru a vizualiza/edita mai multe detalii'),
(106873, 1030, 28, 'Apasati pe oricare dintre parti de timp pentru a-l mari'),
(106874, 1031, 28, 'Apasati pe numele pacientului pentru a deschide dosarul pacientului'),
(106875, 1032, 28, 'Apasa reactualizare pentru a vizualiza toate rezultatele, sau vă rugăm să intrare criteriile de mai sus pentru a vizualiza specifice rezultatele de căutare.'),
(106876, 1033, 28, 'Apasa pentru a aduga diagnostic'),
(106877, 1034, 28, 'Apasa pentru a adauga noi componente'),
(106878, 1035, 28, 'Apasa pentru a adauga o noua consultatie'),
(106879, 1037, 28, 'Apasa pentru a descarca'),
(106880, 1038, 28, 'Apasa pentru a edita'),
(106881, 1039, 28, 'Apasa pentru a edita o descriere'),
(106882, 1040, 28, 'Apasa pentru a edita acest eveniment'),
(106883, 1041, 28, 'Apasa pentru a genera raportul'),
(106884, 1043, 28, 'Apasa pentru a printa'),
(106885, 1044, 28, 'Apasa pentru a primi (adauga) lot nou'),
(106886, 1045, 28, 'Apasa pentru a selecta'),
(106887, 1046, 28, 'Apasa pentru a Selecta'),
(106888, 1047, 28, 'Faceţi clic pentru a selecta un cod standard industrial pentru această procedură'),
(106889, 1069, 28, 'Istoricul sumar (medical) al clientului'),
(106890, 1070, 28, 'Numele clientului');
INSERT INTO `lang_definitions` VALUES
(106891, 1071, 28, 'Numarul clientului'),
(106892, 1074, 28, 'Clienti'),
(106893, 1075, 28, 'Clinic'),
(106894, 1079, 28, 'Clinic'),
(106895, 1081, 28, 'Istoric Clinic'),
(106896, 1083, 28, 'Planuri Clinice'),
(106897, 1106, 28, 'Clinicieni'),
(106898, 1108, 28, 'Cloneaza ultima vizita'),
(106899, 1109, 28, 'Inchide fereastra'),
(106900, 1111, 28, 'Inchide fereastra'),
(106901, 1112, 28, 'Inchis'),
(106902, 1113, 28, 'cm'),
(106903, 1150, 28, 'Cafea'),
(106904, 1154, 28, 'Inchide'),
(106905, 1155, 28, 'inchide'),
(106906, 1156, 28, 'Inchide Tot'),
(106907, 1157, 28, 'Inchide tot'),
(106908, 1158, 28, 'inchide toate'),
(106909, 1163, 28, 'Cancer de colon'),
(106910, 1164, 28, 'Imagine cancer de colon'),
(106911, 1165, 28, 'Operatie cancer de colon'),
(106912, 1166, 28, 'Colonoscopie'),
(106913, 1167, 28, 'colonoscopie'),
(106914, 1168, 28, 'Culoare'),
(106915, 1170, 28, 'Coloana'),
(106916, 1171, 28, 'Coloane'),
(106917, 1173, 28, 'Coma'),
(106918, 1174, 28, 'Comentariu'),
(106919, 1175, 28, 'Comentarii'),
(106920, 1176, 28, 'Comentarii pentru acest rezultat sau recomandare'),
(106921, 1180, 28, 'Comunicatii'),
(106922, 1182, 28, 'Companie'),
(106923, 1183, 28, 'Nume companie'),
(106924, 1184, 28, 'Complet'),
(106925, 1186, 28, 'Finalizat'),
(106926, 1188, 28, 'Finalizat?'),
(106927, 1190, 28, 'Complicatiile de la furnizorul de servicii'),
(106928, 1192, 28, 'Componente'),
(106929, 1194, 28, 'Concluzii'),
(106930, 1199, 28, 'Configurare'),
(106931, 1200, 28, 'Configurare Export/Import'),
(106932, 1208, 28, 'Confirma creare Pacient nou'),
(106933, 1209, 28, 'Confirma parola noua'),
(106934, 1226, 28, 'Scurta Descriere a Consultatiei'),
(106935, 1308, 28, 'Tara'),
(106936, 1340, 28, 'Creaza pacient nou'),
(106937, 1346, 28, 'Creare vizita'),
(106938, 1369, 28, 'Curenta'),
(106939, 1379, 28, 'Parola curenta'),
(106940, 1407, 28, 'Data Nasterii'),
(106941, 1421, 28, 'Baza de date'),
(106942, 1422, 28, 'Baza de date nu este instalata'),
(106943, 1427, 28, 'Data'),
(106944, 1428, 28, 'DATA'),
(106945, 1438, 28, 'Data crearii'),
(106946, 1439, 28, 'Data mortii'),
(106947, 1451, 28, 'Data Facturarii'),
(106948, 1452, 28, 'Data nasterii'),
(106949, 1453, 28, 'Data nasterii'),
(106950, 1454, 28, 'Data Nasterii'),
(106951, 1455, 28, 'Data Introducerii'),
(106952, 1456, 28, 'Data Leziunii'),
(106953, 1461, 28, 'Data Raportului'),
(106954, 1462, 28, 'Data Serviciului'),
(106955, 1463, 28, 'Data Serviciului'),
(106956, 1464, 28, 'Data Serviciului = Azi'),
(106957, 1466, 28, 'Data serviciului:'),
(106958, 1467, 28, 'Data semnaturii'),
(106959, 1522, 28, 'Implicit'),
(106960, 1523, 28, 'Vezi calendarul implicit'),
(106961, 1538, 28, 'Motivul implicit al vizitei'),
(106962, 1654, 28, 'Semnat digital'),
(106963, 1667, 28, 'Dezactivarea calendarului'),
(106964, 1668, 28, 'Toate revizuite si negative'),
(106965, 1692, 28, 'Dezvaluiri'),
(106966, 1715, 28, 'Afisezi calendarul?'),
(106967, 1733, 28, 'Divortat'),
(106968, 1742, 28, 'Nu afisa calendarul'),
(106969, 1749, 28, 'nu fa nimic'),
(106970, 1751, 28, 'Sigur vrei sa stergi'),
(106971, 1759, 28, 'Doresti sa continui cu adaugarea acestui pacient nou?'),
(106972, 1762, 28, 'Data Nasterii'),
(106973, 1763, 28, 'Lipseste data nasterii, va rog sa introducerii'),
(106974, 1767, 28, 'Numele doctorului si semnatura'),
(106975, 1791, 28, 'Documente'),
(106976, 1829, 28, 'Dr. Vizita'),
(106977, 1904, 28, 'Modifica'),
(106978, 1905, 28, 'modifica'),
(106979, 1906, 28, 'Modifica Alergiile'),
(106980, 1907, 28, 'Modifica Categoriile'),
(106981, 1908, 28, 'Modifica Definitiile'),
(106982, 1909, 28, 'Modifica definitii'),
(106983, 1971, 28, 'Contact in caz de urgenta'),
(106984, 1972, 28, 'Persoana de contact in caz de urgenta'),
(106985, 1973, 28, 'Telefon in caz de urgenta'),
(106986, 1990, 28, 'Nu este permisa parola goala.'),
(106987, 2009, 28, 'Activare urmarire AMC'),
(106988, 2073, 28, 'Intalnire'),
(106989, 2074, 28, 'Intalnire'),
(106990, 2075, 28, 'Intalnire '),
(106991, 2080, 28, 'date intalnire'),
(106992, 2081, 28, 'Data intalnirii'),
(106993, 2086, 28, 'Formulare de intalnire'),
(106994, 2088, 28, 'Istoric intalniri'),
(106995, 2089, 28, 'ID intalnire'),
(106996, 2091, 28, 'Numar intalnire'),
(106997, 2108, 28, 'Statistice intalnire'),
(106998, 2109, 28, 'Probleme sumar'),
(106999, 2110, 28, 'Intalnirea a fost codata'),
(107000, 2111, 28, 'Intalnire:'),
(107001, 2113, 28, 'Intalniri'),
(107002, 2114, 28, 'Intalniri si formulare'),
(107003, 2115, 28, 'Intalniri &amp; Formulare'),
(107004, 2116, 28, 'Neautorizat pentru intalniri'),
(107005, 2117, 28, 'Raport intalniri'),
(107006, 2118, 28, 'Sectia intalniri'),
(107007, 2135, 28, 'Oră sfârşit de zi pentru evenimente din calendar'),
(107008, 2167, 28, 'intrari'),
(107009, 2225, 28, 'Eroare: parolele nu se potrivesc. Va rugam sa veridicati introducerea acestora.'),
(107010, 2226, 28, 'Eroare: parolele nu se potrivesc. Va rugam sa veridicati introducerea acestora.'),
(107011, 2243, 28, 'Semneaza electronic'),
(107012, 2244, 28, 'Jurnal semnaturi electronice'),
(107013, 2247, 28, 'Pacient Existent'),
(107014, 2296, 28, 'Pacienti exclusi'),
(107015, 2308, 28, 'Deschide toate'),
(107016, 2334, 28, 'Incarcare date externe'),
(107017, 2336, 28, 'ID Extern'),
(107018, 2356, 28, 'Unitati'),
(107019, 2357, 28, 'Unitate'),
(107020, 2358, 28, 'unitate'),
(107021, 2359, 28, 'Adminitrare Unitate'),
(107022, 2360, 28, 'Oras Unitate'),
(107023, 2361, 28, 'Cod Unitate'),
(107024, 2372, 28, 'Unitate:'),
(107025, 2373, 28, 'ESUARE'),
(107026, 2374, 28, 'esuat'),
(107027, 2375, 28, 'Esuat'),
(107028, 2390, 28, 'Istoric de Familie'),
(107029, 2391, 28, 'Istoric de Familie la Glaucoma'),
(107030, 2392, 28, 'Istoric de Familie:'),
(107031, 2401, 28, 'Istoricul Tatalui'),
(107032, 2421, 28, 'Foaie de taxe'),
(107033, 2422, 28, 'Foaie de taxe Optiuni'),
(107034, 2423, 28, 'Taxe'),
(107035, 2424, 28, 'Feminin'),
(107036, 2461, 28, 'Fisiere'),
(107037, 2464, 28, 'Completeaza aici doar daca se trimit notificari catre pacienti'),
(107038, 2539, 28, 'pentru'),
(107039, 2540, 28, 'Pentru'),
(107040, 2557, 28, 'Creaza pacient nou (fortat)'),
(107041, 2572, 28, 'Formulare'),
(107042, 2619, 28, 'Numele Intreg'),
(107043, 2697, 28, 'Setari globale'),
(107044, 2698, 28, 'Globale'),
(107045, 2739, 28, 'Numele Tutorelui'),
(107046, 2828, 28, 'Ascunde meniul'),
(107047, 2847, 28, 'Istoric'),
(107048, 2865, 28, 'Acasa'),
(107049, 2866, 28, 'Telefon acasa'),
(107050, 2867, 28, 'Numarul de telefon de acasa'),
(107051, 2928, 28, 'Daca YMD este bifat pentru afisarea varstei, schimba in ANI cand sunt pacienti mai in varsta decat valoarea in ani'),
(107052, 2949, 28, 'Registrul de imunizare'),
(107053, 2967, 28, 'IMPORTANT: Aceasta unealta de upload este doar pentru incarcarea documentelor la pacienti care nu sunt INCA introdusi in sistem. Sa incarci fisiere pentru pacienti care sunt deja introdusi in sistem, te rog incarca din unealta din dreptul pacientului.'),
(107054, 3000, 28, 'Parola gresita!'),
(107055, 3009, 28, 'Pacient nevoias'),
(107056, 3023, 28, 'Imunizarea Gripa pentru pacientii> = 50 Ani'),
(107057, 3024, 28, 'Imunizarea Gripa pentru pacientii> = 50 Ani (CQM)'),
(107058, 3025, 28, 'Imunizare vaccin'),
(107059, 3026, 28, 'Info'),
(107060, 3027, 28, 'Info test 1'),
(107061, 3028, 28, 'Info test 2'),
(107062, 3029, 28, 'Info test 3'),
(107063, 3030, 28, 'Info test 4'),
(107064, 3031, 28, 'Info test 5'),
(107065, 3032, 28, 'Info test 6'),
(107066, 3034, 28, 'Inhalatii'),
(107067, 3153, 28, 'Utilizator sau parola gresita'),
(107068, 3214, 28, 'este prea lung'),
(107069, 3216, 28, 'Problema'),
(107070, 3217, 28, 'problema'),
(107071, 3218, 28, 'Data Problemei'),
(107072, 3219, 28, 'ID Problema'),
(107073, 3220, 28, 'Titlul Problemei'),
(107074, 3221, 28, 'Tipul Problemei'),
(107075, 3222, 28, 'Tipuri de Probleme'),
(107076, 3223, 28, 'Probleme'),
(107077, 3224, 28, 'Probleme (Raniri/Medicale/Alergii)'),
(107078, 3225, 28, 'Probleme (Raniri/Medicale/Alergii):'),
(107079, 3226, 28, 'Probleme si Intalniri'),
(107080, 3227, 28, 'Probleme si Intalniri pentru'),
(107081, 3228, 28, 'Neautorizat pentru probleme'),
(107082, 3229, 28, 'Sectiunea Probleme'),
(107083, 3316, 28, 'Limba'),
(107084, 3322, 28, 'Limba:'),
(107085, 3330, 28, 'Ultimul an calendaristic'),
(107086, 3343, 28, 'Ultima Luna'),
(107087, 3344, 28, 'Numele de Familie'),
(107088, 3345, 28, 'Numele de familie'),
(107089, 3346, 28, 'Numele de familie:'),
(107090, 3350, 28, 'Ultima data revizuit'),
(107091, 3352, 28, 'Ultima data salvat'),
(107092, 3357, 28, 'Ultima data verificat pe'),
(107093, 3358, 28, 'Ultima vizita'),
(107094, 3373, 28, 'Formulare'),
(107095, 3378, 28, 'Formulare Vizita din Salbloane'),
(107096, 3379, 28, 'Sabloane'),
(107097, 3385, 28, 'Lasati gol pentru a nu schimba parola.'),
(107098, 3414, 28, 'Serie si nr. buletin'),
(107099, 3435, 28, 'Legatura ordinelor de proceduri'),
(107100, 3436, 28, 'Legatura la document'),
(107101, 3438, 28, 'Lista'),
(107102, 3458, 28, 'Liste'),
(107103, 3470, 28, 'SE INCARCA'),
(107104, 3489, 28, 'Incuiat'),
(107105, 3492, 28, 'Autentificare'),
(107106, 3493, 28, 'Autentificare'),
(107107, 3494, 28, 'Iesire'),
(107108, 3495, 28, 'Autentificat'),
(107109, 3496, 28, 'Autentificat ca'),
(107110, 3497, 28, 'Autentificat ca: '),
(107111, 3498, 28, 'Iesit.'),
(107112, 3500, 28, 'Autentificare'),
(107113, 3501, 28, 'Autentificare'),
(107114, 3505, 28, 'Iesire'),
(107115, 3506, 28, 'iesire'),
(107116, 3534, 28, 'Principal'),
(107117, 3535, 28, 'Adresa principala'),
(107118, 3536, 28, 'Ecranul principal panoul de sus'),
(107119, 3548, 28, 'Masculin'),
(107120, 3569, 28, 'Stare Civila'),
(107121, 3576, 28, 'Casatorit'),
(107122, 3607, 28, 'Inseamna ca ultimele trei parole nu sunt permise la schimbarea parolei.'),
(107123, 3617, 28, 'Istoric Medical'),
(107124, 3620, 28, 'Problema medicala'),
(107125, 3621, 28, 'Problema Medicala'),
(107126, 3622, 28, 'Problema Medicala Lista de Probleme'),
(107127, 3623, 28, 'Probleme Medicale'),
(107128, 3624, 28, 'Dosar Medical'),
(107129, 3625, 28, 'Dosar Medical #'),
(107130, 3626, 28, 'Inregistrari medicale'),
(107131, 3659, 28, 'Fuziune pacient'),
(107132, 3661, 28, 'Messah'),
(107133, 3662, 28, 'Messaje si centru reminder'),
(107134, 3671, 28, 'Mesaje'),
(107135, 3672, 28, 'Mesaje trimise azi'),
(107136, 3673, 28, 'Metoda'),
(107137, 3713, 28, 'Optiuni diferite de plata'),
(107138, 3714, 28, 'Optiuni diferite de plata pentru HCFA-1500'),
(107139, 3715, 28, 'Optiuni diferite de plata HCFA-1500'),
(107140, 3716, 28, 'Diferite'),
(107141, 3717, 28, 'Uitate'),
(107142, 3771, 28, 'Mama'),
(107143, 3772, 28, 'Numele Mamei'),
(107144, 3773, 28, 'Istoricul Mamei'),
(107145, 3783, 28, 'Dl.'),
(107146, 3785, 28, 'Dna.'),
(107147, 3786, 28, 'Dsoara.'),
(107148, 3823, 28, 'Nume'),
(107149, 3825, 28, 'Nume (click pentru mai mult)'),
(107150, 3826, 28, 'Nume 1'),
(107151, 3827, 28, 'Nume 2'),
(107152, 3837, 28, 'Nume:'),
(107153, 3857, 28, 'Zona de navigare a formularelor vizita'),
(107154, 3904, 28, 'Vizita noua'),
(107155, 3906, 28, 'Formular pentru vizita noua'),
(107156, 3920, 28, 'Parola noua'),
(107157, 3921, 28, 'Pacient nou'),
(107158, 3922, 28, 'PACIENT NOU'),
(107159, 3923, 28, 'Pacient nou (eroare?!)'),
(107160, 3924, 28, 'Formular pacient nou'),
(107161, 3925, 28, 'IDul pacientului nou'),
(107162, 3926, 28, 'Plata noua'),
(107163, 3928, 28, 'PT nou'),
(107164, 3929, 28, 'Rezultate noi de la schimbul de laborator'),
(107165, 3930, 28, 'Cautare noua'),
(107166, 3931, 28, 'Submiteri noi'),
(107167, 3932, 28, 'User nou'),
(107168, 3934, 28, 'Vizita noua'),
(107169, 3935, 28, 'Cautare noua'),
(107170, 3962, 28, 'Urmatorul'),
(107171, 3975, 28, 'Nu'),
(107172, 3976, 28, 'NU'),
(107173, 4031, 28, 'Nu am gasit nimic. Creaza pacient nou?'),
(107174, 4066, 28, 'Nu exista semnaturi pe dosar'),
(107175, 4075, 28, 'Fara vizite'),
(107176, 4103, 28, 'Vizita normala la birou'),
(107177, 4122, 28, 'Interzis modificarea'),
(107178, 4128, 28, 'Nu ai autorizatie pentru a accesa modulul de PostCalendar'),
(107179, 4172, 28, 'Notite'),
(107180, 4175, 28, 'Neautorizat pentru notite'),
(107181, 4177, 28, 'Nu s-a inregistrat nimic'),
(107182, 4184, 28, 'NOTIFICARE: Post calendar prezentarea /modificarea'),
(107183, 4222, 28, 'Afiseaza numarul de pacienti pe pagina in lista pacienti'),
(107184, 4250, 28, 'Vizita la birou'),
(107185, 4292, 28, 'Dupa ce va schimbati parola va trebui sa va re-autentificati.'),
(107186, 4318, 28, 'Deschide intr-o fereastra noua'),
(107187, 4319, 28, 'Deschide pacientul'),
(107188, 4321, 28, 'Deschide vizitele de azi'),
(107189, 4376, 28, 'Ordine sumar'),
(107190, 4402, 28, 'Altele'),
(107191, 4403, 28, 'altele'),
(107192, 4420, 28, 'Altele'),
(107193, 4469, 28, 'Pacienti admisi'),
(107194, 4472, 28, 'Parola'),
(107195, 4473, 28, 'Schimbare parola'),
(107196, 4474, 28, 'Schimbarea parolei a reusit'),
(107197, 4475, 28, 'Schimbarea parolei a reusit.'),
(107198, 4476, 28, 'Parola nu este suficienta. Trebuie sa contina cel putin trei din urmatoarele patru lucruri: un numar, o litera mica, o majuscula, un caracter special (nu o litera sau un numar)'),
(107199, 4482, 28, 'Parola pentru utilizatorul de mai sus'),
(107200, 4483, 28, 'Securitatea parolelor a fost recent intarita.'),
(107201, 4485, 28, 'Parola prea scurta. Minim 8 caractere.'),
(107202, 4486, 28, 'Parola:'),
(107203, 4487, 28, 'Parolele nu se potrivesc!'),
(107204, 4494, 28, 'Lista Vizitelor'),
(107205, 4495, 28, 'Lista Vizitelor'),
(107206, 4496, 28, 'Lista Vizitelor si Documentelor'),
(107207, 4497, 28, 'Lista Vizitelor pentru'),
(107208, 4514, 28, 'Pacient'),
(107209, 4515, 28, 'pacient'),
(107210, 4516, 28, 'PACIENT'),
(107211, 4517, 28, 'Adresa pacientului'),
(107212, 4518, 28, 'Lipseste adresa pacientului'),
(107213, 4521, 28, 'Alergiile pacientului'),
(107214, 4522, 28, 'Alergiile Pacientului'),
(107215, 4543, 28, 'Data nasterii a pacientului'),
(107216, 4547, 28, 'Vizita Pacient'),
(107217, 4548, 28, 'Formular Vizita Pacient'),
(107218, 4549, 28, 'Vizite Pacienti'),
(107219, 4561, 28, 'Istoric Pacient'),
(107220, 4562, 28, 'Istoric Pacient / Stil de Viata'),
(107221, 4610, 28, 'Cereri de inregistrare pacienti'),
(107222, 4619, 28, 'Memento-uri pacient'),
(107223, 4633, 28, 'Pacient/Client'),
(107224, 4634, 28, 'Pacient:'),
(107225, 4635, 28, 'PacientID'),
(107226, 4636, 28, 'Pacienti admisi'),
(107227, 4637, 28, 'Pacienti procesati'),
(107228, 4638, 28, 'Plata'),
(107229, 4640, 28, 'Data platii:'),
(107230, 4641, 28, 'Statusul platii'),
(107231, 4642, 28, 'Numele platitorului'),
(107232, 4647, 28, 'Plata'),
(107233, 4648, 28, 'plata'),
(107234, 4665, 28, 'Plati'),
(107235, 4681, 28, 'Revizuire in asteptare'),
(107236, 4814, 28, 'Va rugam introduceti o parola noua'),
(107237, 4823, 28, 'Va rugam introduceti parola'),
(107238, 4832, 28, 'Specifica motivul vizitei'),
(107239, 4844, 28, 'Va rugam sa va resetati parola.'),
(107240, 4941, 28, 'Post calendar'),
(107241, 4942, 28, 'Administrare post calendar'),
(107242, 4943, 28, 'Post calendar setari categorie'),
(107243, 4944, 28, 'Post calendar setari globale'),
(107244, 4953, 28, 'Practica'),
(107245, 4991, 28, 'Prec'),
(107246, 5001, 28, 'Precedent'),
(107247, 5093, 28, 'Ordinea procedurii'),
(107248, 5094, 28, 'Ordinea procedurii'),
(107249, 5095, 28, 'Ordinea procedurii pentru'),
(107250, 5114, 28, 'Proceduri'),
(107251, 5152, 28, 'Furnizor'),
(107252, 5165, 28, 'Furnizorii vad intregul calendar'),
(107253, 5224, 28, 'Calitate'),
(107254, 5225, 28, 'Masuratori de calitate (CQM)'),
(107255, 5263, 28, 'Reactie'),
(107256, 5264, 28, 'Reactii'),
(107257, 5270, 28, 'Motiv'),
(107258, 5275, 28, 'Motivul vizitei'),
(107259, 5276, 28, 'Motiv/Formular'),
(107260, 5292, 28, 'Nu sunt permise ultimele 3 parole.'),
(107261, 5317, 28, 'Inregistrari'),
(107262, 5348, 28, 'Referinte'),
(107263, 5358, 28, 'Referit de'),
(107264, 5437, 28, 'Repetati parola noua'),
(107265, 5446, 28, 'Raport'),
(107266, 5447, 28, 'Raport - Clinic'),
(107267, 5449, 28, 'Raport intocmit de'),
(107268, 5453, 28, 'Istoric Rapoarte / Rezultate'),
(107269, 5463, 28, 'Rapoarte'),
(107270, 5485, 28, 'REZERVAT'),
(107271, 5486, 28, 'Rezervat'),
(107272, 5528, 28, 'Revenire vizita'),
(107273, 5535, 28, 'Revizuiri ale systemului'),
(107274, 5536, 28, 'Revizuiri ale systemului Verificate'),
(107275, 5578, 28, 'Reguli'),
(107276, 5601, 28, 'CNP'),
(107277, 5620, 28, 'Salveaza'),
(107278, 5621, 28, 'SALVEAZA'),
(107279, 5622, 28, 'Salveaza si inchide'),
(107280, 5623, 28, 'Salveaza si sterge cererea'),
(107281, 5624, 28, 'Salveaza si distribuie'),
(107282, 5625, 28, 'Salveaza si transmite'),
(107283, 5626, 28, 'Salveaza ca nou'),
(107284, 5627, 28, 'Salveaza ca notita noua'),
(107285, 5628, 28, 'Salveaza setarile certificatului'),
(107286, 5629, 28, 'Salveaza schimbarile'),
(107287, 5630, 28, 'Salveaza formularul'),
(107288, 5631, 28, 'Salveaza vaccinarea'),
(107289, 5632, 28, 'Salveaza campul nou'),
(107290, 5633, 28, 'Salveaza grupul nou'),
(107291, 5634, 28, 'Salveaza lista noua'),
(107292, 5635, 28, 'Salveaza sablonul nou'),
(107293, 5636, 28, 'Salveaza selectia de omisiuni'),
(107294, 5637, 28, 'Salveaza informatiile demografice ale pacientului'),
(107295, 5659, 28, 'Cautare'),
(107296, 5661, 28, 'cautare'),
(107297, 5662, 28, 'cauta din nou'),
(107298, 5663, 28, 'Cauta in toate coloanele'),
(107299, 5702, 28, 'Vezi mesaje de la ultimul set de plangeri generate'),
(107300, 5704, 28, 'Vazut din'),
(107301, 5745, 28, 'Alege Una'),
(107302, 5766, 28, 'Intalnirea Selectata'),
(107303, 5795, 28, 'Sensibilitate:'),
(107304, 5834, 28, 'Servicii'),
(107305, 5877, 28, 'Arata'),
(107306, 5878, 28, 'Arata activ'),
(107307, 5880, 28, 'Arata tot'),
(107308, 5896, 28, 'Arata meniul'),
(107309, 5915, 28, 'Afiseaza'),
(107310, 5916, 28, 'Afiseaza rezultatul'),
(107311, 5924, 28, 'Semneaza'),
(107312, 5926, 28, 'Semneaza rezultatele'),
(107313, 5927, 28, 'Semnatura'),
(107314, 5928, 28, 'Semnatura pe dosar'),
(107315, 5929, 28, 'Semnatura:'),
(107316, 5940, 28, 'Necasatorit'),
(107317, 6055, 28, 'Pacientul sursa nu are data de nastere'),
(107318, 6092, 28, 'Dictare discurs'),
(107319, 6113, 28, 'CNP'),
(107320, 6118, 28, 'Masuratori standard'),
(107321, 6119, 28, 'Masuratori standard (Alerte active)'),
(107322, 6120, 28, 'Masuratori standard (Alerte pasive)'),
(107323, 6121, 28, 'Masuratori standard (Alerte pacienti)'),
(107324, 6122, 28, 'Nume standard'),
(107325, 6188, 28, 'Stilul de formular folosit la adaugarea de pacienti noi'),
(107326, 6189, 28, 'Sub categorie'),
(107327, 6190, 28, 'Sub-total'),
(107328, 6191, 28, 'Subcategorie'),
(107329, 6192, 28, 'subcategorie'),
(107330, 6193, 28, 'subcutanat'),
(107331, 6194, 28, 'Subiect'),
(107332, 6195, 28, 'Subiectib'),
(107333, 6260, 28, 'Sinucidere'),
(107334, 6261, 28, 'Sumar'),
(107335, 6262, 28, 'Sumarul'),
(107336, 6265, 28, 'Soare'),
(107337, 6267, 28, 'Duminica'),
(107338, 6563, 28, 'Aceasta vizita este incuiata. Nu se mai pot adauga formulare.'),
(107339, 6593, 28, 'Acest user va primi notificari noi din "Mesagerie directa"'),
(107340, 6658, 28, 'La'),
(107341, 6659, 28, 'LA'),
(107342, 6660, 28, 'la'),
(107343, 6669, 28, 'La vedere clinica'),
(107344, 6683, 28, 'Pentru a lega aceasta vizita/consultatie cu o problema existenta, dati click pe '),
(107345, 6684, 28, 'Pentru a lega aceasta vizita/consultatie cu o problema existenta, dati click pe problema dorita in casuta de mai sus pentru a o selecta si apoi apasati [Salveaza]. Tineti tasta [Ctrl] pentru a selecta mai multe probleme.'),
(107346, 6691, 28, 'la aceasta vizita?'),
(107347, 6693, 28, 'La:'),
(107348, 6694, 28, 'LA_ORAS '),
(107349, 6695, 28, 'LA_FAX'),
(107350, 6696, 28, 'LA_FNUME'),
(107351, 6697, 28, 'LA_LNUME'),
(107352, 6698, 28, 'LA_MNUME'),
(107353, 6728, 28, 'Sus'),
(107354, 6792, 28, 'tranzactii'),
(107355, 6793, 28, 'tranzactii'),
(107356, 6877, 28, 'Nespecificat'),
(107357, 6878, 28, 'Neautorizat'),
(107358, 7015, 28, 'Definite de utilizator'),
(107359, 7056, 28, 'Utilizatori'),
(107360, 7063, 28, 'Vacanta'),
(107361, 7064, 28, 'Vaccin'),
(107362, 7067, 28, 'valideaza'),
(107363, 7068, 28, 'Valoare'),
(107364, 7069, 28, 'Valoare 1'),
(107365, 7070, 28, 'Valoare 2'),
(107366, 7072, 28, 'Valoarea trebuie sa fie numerica'),
(107367, 7084, 28, 'Versiune'),
(107368, 7090, 28, 'vizualizeaza'),
(107369, 7091, 28, 'Vizualizare'),
(107370, 7092, 28, 'Vezi Alergii'),
(107371, 7100, 28, 'Vezi documentul'),
(107372, 7101, 28, 'Vezi intalnirea'),
(107373, 7107, 28, 'Vezi jurnalul'),
(107374, 7108, 28, 'Vezi pagina 1'),
(107375, 7109, 28, 'Vezi pagina 2'),
(107376, 7111, 28, 'Vezi pacientul'),
(107377, 7117, 28, 'Vezi raportul'),
(107378, 7121, 28, 'Vizualizare/Modificare Alergii'),
(107379, 7122, 28, 'Vizualizare/Modificare problema'),
(107380, 7123, 28, 'Vizualizare/Tiparire'),
(107381, 7124, 28, 'Vizualizare:'),
(107382, 7132, 28, 'Categoria vizitei'),
(107383, 7133, 28, 'Categoria vizite:'),
(107384, 7134, 28, 'Data Vizitei'),
(107385, 7135, 28, 'Data vizitei'),
(107386, 7137, 28, 'Formulare vizita'),
(107387, 7138, 28, 'Istoric vizite'),
(107388, 7140, 28, 'Vizite'),
(107389, 7141, 28, 'Formular vizite'),
(107390, 7142, 28, 'Semne Vitale'),
(107391, 7143, 28, 'Vitale'),
(107392, 7146, 28, 'Voce'),
(107393, 7147, 28, 'Voce Trimis'),
(107394, 7199, 28, 'Bine ati venit'),
(107395, 7212, 28, 'Alb'),
(107396, 7213, 28, 'Cine'),
(107397, 7214, 28, 'Cine a raspuns?'),
(107398, 7215, 28, 'Vaduvit'),
(107399, 7216, 28, 'Latime'),
(107400, 7242, 28, 'Telefon de serviciu'),
(107401, 7263, 28, 'Doriti sa salvati?'),
(107402, 7285, 28, 'An'),
(107403, 7286, 28, 'an'),
(107404, 7287, 28, 'Vedere an'),
(107405, 7288, 28, 'An(i)'),
(107406, 7289, 28, 'Ani'),
(107407, 7290, 28, 'Ani sau luni'),
(107408, 7291, 28, 'Ani, luni si zile'),
(107409, 7292, 28, 'DA'),
(107410, 7293, 28, 'Da'),
(107411, 7294, 28, 'da'),
(107412, 7295, 28, 'DA!'),
(107413, 7296, 28, 'Da, sterge si logheaza'),
(107414, 7298, 28, 'Da/Nu'),
(107415, 7299, 28, 'Da:'),
(107416, 7325, 28, 'Poti pune aici textul implicit de plangere in Nou Pacient'),
(107417, 7331, 28, 'Trebuie sa alegeti o categorie de vizita'),
(107418, 7332, 28, 'Trebuie sa alegeti o categorie de vizita.'),
(107419, 7348, 28, 'Parola dvs'),
(107420, 7349, 28, 'Parola dvs a expirat. Va rugam sa va schimbati parola.'),
(107421, 7350, 28, 'Parola dvs expira pe'),
(107422, 7351, 28, 'Parola dvs expira astazi. Va rugam sa va schimbati parola.'),
(107423, 7430, 28, '(Click pentru modificare)'),
(107424, 7433, 28, '(Pacient nou)'),
(107425, 7483, 28, '3 Luni'),
(107426, 7484, 28, '3 Luni de-acum incolo'),
(107427, 7485, 28, 'De 3 ori pe zi'),
(107428, 7486, 28, '3 Saptamani de-acum incolo'),
(107429, 7487, 28, '30-34'),
(107430, 7488, 28, '35-39'),
(107431, 7489, 28, 'Al 3-lea'),
(107432, 7490, 28, '4 Zile de-acum incolo'),
(107433, 7491, 28, '4 Luni'),
(107434, 7492, 28, '4 Luni de-acum incolo'),
(107435, 7493, 28, 'De 4 ori pe zi'),
(107436, 7494, 28, '4 Saptamani de-acum incolo'),
(107437, 7495, 28, '40-44'),
(107438, 7496, 28, '45+'),
(107439, 7504, 28, 'Al 4-lea'),
(107440, 7505, 28, '5 zile de-acum incolo'),
(107441, 7506, 28, '5 luni de-acum incolo'),
(107442, 7507, 28, '5 saptamani de-acum in colo'),
(107443, 7509, 28, 'Al 5-lea'),
(107444, 7510, 28, '6 zile de-acum incolo'),
(107445, 7511, 28, '6 Luni'),
(107446, 7512, 28, '6 Luni de-acum incolo'),
(107447, 7513, 28, '6 saptamani de-acum in colo'),
(107448, 7514, 28, 'Al 6-lea'),
(107449, 7515, 28, '7 Luni de-acum incolo'),
(107450, 7516, 28, '8 Luni de-acum incolo'),
(107451, 7525, 28, '9 luni de-acum incolo'),
(107452, 7526, 28, '99212 Stabilit - necomplicat'),
(107453, 7527, 28, '99213 Stabilit - complexitate redusa'),
(107454, 7528, 28, '< In camera de examinare'),
(107455, 7529, 28, '> Verificat'),
(107456, 7530, 28, '?'),
(107457, 7531, 28, '? Nu afisa'),
(107458, 7532, 28, '@ Ajuns'),
(107459, 7533, 28, '[Schimba viewul]'),
(107460, 7534, 28, '[Data ultimei intalniri]'),
(107461, 7535, 28, '[Zile de la ultima intalnire]'),
(107462, 7536, 28, '[EOBs]'),
(107463, 7537, 28, '[Export OFX]'),
(107464, 7538, 28, '[nerecomandat]'),
(107465, 7539, 28, '[Numar de intalniri]'),
(107466, 7540, 28, '[Rapoarte]'),
(107467, 7541, 28, '[Selecteaza tot]'),
(107468, 7542, 28, '[SQL-Ledger]'),
(107469, 7543, 28, '[Incepere proces Batch]'),
(107470, 7544, 28, '[Vizualizare Log]'),
(107471, 7545, 28, '[Vizualizare raport printabil]'),
(107472, 7546, 28, '_PC_DUR_HOURS'),
(107473, 7547, 28, '_PC_DUR_MINUTES'),
(107474, 7548, 28, '_PC_LOCALE'),
(107475, 7549, 28, '~ Intarziere'),
(107476, 1, 29, 'Một'),
(107477, 2, 29, 'Số séc hoặc số yêu cầu để nhận biết việc thanh toán'),
(107478, 3, 29, 'Một giấy chứng nhận của máy khách cho người quản trị'),
(107479, 4, 29, 'Một tài liệu lâm sàng được đính kèm'),
(107480, 5, 29, 'Một tài liệu lâm sàng được đính kèm.'),
(107481, 7, 29, 'Phải có nhà phân phối'),
(107482, 8, 29, 'Phải thêm vào lần đến khám này một biểu mẫu đến khám GCAC.'),
(107483, 9, 29, 'Phải có số lô sản xuất'),
(107484, 10, 29, 'Phải có số lô sản xuất!'),
(107485, 11, 29, 'Dùng chữ thường'),
(107486, 12, 29, 'Chữ số'),
(107487, 14, 29, 'Đã có bệnh nhân với số chứng minh thư này.'),
(107488, 15, 29, 'Đã có bệnh nhân với tên này.'),
(107489, 16, 29, 'Đã có bệnh nhân với số ASXH này.'),
(107490, 17, 29, 'Một số dương thể hiện bao nhiêu lần hẹn trước đây tại một Tiện ích trong màn hình Tóm lược Bệnh nhân (một số âm thể hiện các lần hẹn trước đây theo thứ tự giảm dần)'),
(107491, 18, 29, 'Một số dương thể hiện bao nhiêu lần hẹn trước đây tại một Tiện ích trong màn hình Tóm lược Bệnh nhân.'),
(107492, 19, 29, 'Có thể chỉ ra nguồn giới thiệu cho mỗi lần đến khám.'),
(107493, 20, 29, 'Phải có mã IPPF liên quan!'),
(107494, 21, 29, 'Ký tự đặc biệt'),
(107495, 22, 29, 'Một giá trị duy nhất để xác định trường này, không hiển thị cho người sử dụng'),
(107496, 23, 29, 'Đã có một lần khám trong này hôm nay cho bệnh nhân này. Bấm "Hủy bỏ" để mở nó, hay OK để thực hiện việc tạo lần khám mới.'),
(107497, 24, 29, 'trước khi ăn'),
(107498, 25, 29, 'buổi sáng'),
(107499, 26, 29, 'A/F Level Right:'),
(107500, 27, 29, 'AB'),
(107501, 28, 29, 'Viết tắt'),
(107502, 29, 29, 'Abcess:'),
(107503, 30, 29, 'Bụng'),
(107504, 31, 29, 'Có khả năng Mang Nặng bốn (4) bước:'),
(107505, 32, 29, 'Abn'),
(107506, 33, 29, 'ABN1'),
(107507, 34, 29, 'Bất bình thường'),
(107508, 35, 29, 'Xét nghiệm máu bất thường'),
(107509, 36, 29, 'Tăng trưởng Tóc Bất thường'),
(107510, 37, 29, 'Tuyến vú Bất thường'),
(107511, 39, 29, 'Phá thai'),
(107512, 40, 29, 'Vấn đề Nạo phá thai'),
(107513, 41, 29, 'Phương pháp Phá thai'),
(107514, 42, 29, 'Thể loại Phá thai-Liên quan'),
(107515, 43, 29, 'Phá thai'),
(107516, 44, 29, 'Giới thiệu về lịch'),
(107517, 46, 29, 'Chẩn đoán vắng mặt'),
(107518, 47, 29, 'Chấp nhận Chuyển nhượng'),
(107519, 48, 29, 'Chấp nhận Thanh toán cho'),
(107520, 49, 29, 'Chấp nhận Thanh toán cho'),
(107521, 50, 29, 'Chấp nhận Phần được giao'),
(107522, 51, 29, 'Kiểm soát Truy nhập'),
(107523, 52, 29, 'Quản trị Danh sách Kiểm soát Truy nhập'),
(107524, 53, 29, 'Ngày truy nhập'),
(107525, 54, 29, 'Không được phép truy nhập'),
(107526, 55, 29, 'Không được Cấp phép Truy nhập'),
(107527, 56, 29, 'Cổng thông tin bệnh nhân Truy cập'),
(107528, 57, 29, 'Tai nạn'),
(107529, 59, 29, 'Tên Tài khoản'),
(107530, 62, 29, 'Kế toán'),
(107531, 64, 29, 'Đau nhức'),
(107532, 65, 29, 'Đã yêu cầu Xác nhận (ISA14)'),
(107533, 66, 29, 'Lời cảm ơn, Cấp phép và Chứng chỉ'),
(107534, 67, 29, 'ACL'),
(107535, 68, 29, 'Quản trị ACL'),
(107536, 69, 29, 'Không được quyền Quản trị ACL'),
(107537, 70, 29, 'Cập nhật Thành công ACL'),
(107538, 71, 29, 'Mụn trứng cá'),
(107539, 72, 29, 'Được dùng'),
(107540, 73, 29, 'Ngày Hành động'),
(107541, 74, 29, 'Hành động'),
(107542, 75, 29, 'Những Hoạt động'),
(107543, 77, 29, 'Kích hoạt việc Báo cáo CCR / CCD'),
(107544, 78, 29, 'Có hiệu lực'),
(107545, 79, 29, 'Cảnh báo Đang có hiệu lực'),
(107546, 80, 29, 'Các luật Cảnh báo Đang có hiệu lực'),
(107547, 81, 29, 'Cảnh báo / Nhắc nhở Đang có hiệu lực'),
(107548, 82, 29, 'Lần khám Đang được chọn'),
(107549, 84, 29, 'Danh sách hoạt động'),
(107550, 85, 29, 'Bệnh nhân Đang được chọn'),
(107551, 86, 29, 'Kế hoạch Đang được chọn'),
(107552, 87, 29, 'Hoạt động'),
(107553, 88, 29, 'Loại Hoạt động'),
(107554, 92, 29, 'Cấp tính / mãn tính'),
(107555, 93, 29, 'thêm'),
(107556, 94, 29, 'Thêm'),
(107557, 95, 29, 'THÊM'),
(107558, 96, 29, 'Thêm Công ty'),
(107559, 98, 29, 'Thêm Nhà thuốc'),
(107560, 100, 29, 'thêm một sự kiện cho '),
(107561, 101, 29, 'Thêm như ghi chú mới'),
(107562, 102, 29, 'Tạo Mới'),
(107563, 104, 29, 'Thêm Các nút'),
(107564, 105, 29, 'Hiển thị phía trên của trình soạn thảo các nút cho các ký tự, văn bản đặc biệt để đưa vào văn bản khi được nhấn'),
(107565, 106, 29, 'Thêm Thể loại'),
(107566, 107, 29, 'Thêm Hằng số'),
(107567, 108, 29, 'Thêm Bối cảnh'),
(107568, 109, 29, 'Thêm Tiền phụ phí'),
(107569, 110, 29, 'Thêm tiêu chí'),
(107570, 111, 29, 'Thêm Nút Tùy chỉnh'),
(107571, 112, 29, 'Thêm Chẩn đoán'),
(107572, 113, 29, 'Thêm Thuốc'),
(107573, 114, 29, 'Thêm Lần khám'),
(107574, 115, 29, 'Thêm lần khám / ghi chú'),
(107575, 116, 29, 'Thêm Cơ sở'),
(107576, 117, 29, 'Thêm Trường'),
(107577, 118, 29, 'Thêm những dòng sau vào tập tin cấu hình Apache'),
(107578, 119, 29, 'Thêm Nhóm'),
(107579, 120, 29, 'Thêm Mã ICD'),
(107580, 121, 29, 'Thêm Tiêm chủng'),
(107581, 122, 29, 'Không được quyền thêm!'),
(107582, 123, 29, 'Thêm Vấn đề'),
(107583, 124, 29, 'Thêm mục để theo dõi'),
(107584, 125, 29, 'Thêm Ngôn ngữ'),
(107585, 126, 29, 'Thêm Mới'),
(107586, 127, 29, 'Thêm mới'),
(107587, 128, 29, 'Thêm thể loại mới: '),
(107588, 129, 29, 'Thêm chứng nhận mới vào tập tin cấu hình Apache'),
(107589, 130, 29, 'Thêm Thành phần Mới'),
(107590, 131, 29, 'Thêm Các Thành phần Mới'),
(107591, 132, 29, 'Thêm Nhóm Mới'),
(107592, 133, 29, 'Thêm Vấn đề Mới'),
(107593, 134, 29, 'Thêm lô hàng và giao dịch mới'),
(107594, 135, 29, 'Thêm Ghi chú Mới'),
(107595, 136, 29, 'Thêm ghi chú mới'),
(107596, 137, 29, 'Thêm Đối tác Mới'),
(107597, 138, 29, 'Thêm Bệnh nhân Mới'),
(107598, 140, 29, 'Thêm Ghi chú'),
(107599, 141, 29, 'Thêm Hồ sơ Bệnh nhân'),
(107600, 142, 29, 'Thêm Đơn thuốc'),
(107601, 143, 29, 'Thêm Thủ tục'),
(107602, 144, 29, 'Thêm Số của Nhà cung cấp'),
(107603, 145, 29, 'Thêm phục hồi chức năng'),
(107604, 146, 29, 'Thêm Quy tắc'),
(107605, 147, 29, 'Thêm vào'),
(107606, 148, 29, 'Thêm vào Danh sách Điều trị'),
(107607, 149, 29, 'Thêm Mức đỉnh'),
(107608, 150, 29, 'Thêm giao dịch'),
(107609, 151, 29, 'Thêm Người dùng'),
(107610, 152, 29, 'Thêm Người dùng vào Nhóm'),
(107611, 153, 29, 'Thêm / Chỉnh sửa eRx'),
(107612, 154, 29, 'Thêm / Chỉnh sửa Giao dịch của Bệnh nhân'),
(107613, 155, 29, 'đã thêm'),
(107614, 156, 29, 'Không được phép thêm thông tin cá nhân.'),
(107615, 157, 29, 'Gặp lỗi khi thêm mục để theo dõi'),
(107616, 158, 29, 'Hội chứng Addison'),
(107617, 159, 29, 'Hội chứng Addison'),
(107618, 160, 29, 'Các thuộc tính Bổ sung'),
(107619, 161, 29, 'Các chẩn đoán Bổ sung:'),
(107620, 162, 29, 'Lịch sử Bổ sung'),
(107621, 163, 29, 'Ghi chú lịch sử bổ sung'),
(107622, 164, 29, 'Thông tin Bổ sung'),
(107623, 165, 29, 'Phòng thí nghiệm Bổ sung'),
(107624, 166, 29, 'Ghi chú Bổ sung'),
(107625, 167, 29, 'Ghi chú bổ sung cho kết quả hay khuyến nghị này'),
(107626, 168, 29, 'Ghi chú Bổ sung:'),
(107627, 169, 29, 'Ghi chú Bổ sung: '),
(107628, 170, 29, 'Ghi chú X-Quang bổ sung:'),
(107629, 171, 29, 'Thêm vào đó, có thể nhập Gói Mở rộng Snomed của Hoa Kỳ tương ứng sau khi cài đặt Bản phát hành Snomed Quốc tế (phiên bản Tiếng Anh).'),
(107630, 172, 29, 'chỉ được thêm'),
(107631, 173, 29, 'Sổ Địa chỉ'),
(107632, 174, 29, 'Sổ Địa chỉ'),
(107633, 175, 29, 'Địa chỉ'),
(107634, 178, 29, 'Sổ Địa chỉ'),
(107635, 179, 29, 'Đầu mục trong sổ địa chỉ cho công ty đang thực hiện thủ tục này'),
(107636, 180, 29, 'Đầu mục trong sổ địa chỉ cho nhà phân phối'),
(107637, 181, 29, 'Đầu mục trong sổ địa chỉ cho người bán'),
(107638, 182, 29, 'Các loại Sổ Địa chỉ'),
(107639, 183, 29, 'Nhãn Địa chỉ'),
(107640, 187, 29, 'Địa chỉ 1'),
(107641, 188, 29, 'Địa chỉ 2'),
(107642, 189, 29, 'ADDRESSEE'),
(107643, 190, 29, 'Điều chỉnh'),
(107644, 191, 29, 'Số tiền điều chỉnh'),
(107645, 192, 29, 'Điều chỉnh'),
(107646, 193, 29, 'Điều chỉnh'),
(107647, 194, 29, 'Số tiền điều chỉnh'),
(107648, 195, 29, 'Các lý do Điều chỉnh'),
(107649, 196, 29, 'Điều chỉnh giá trị cho mã '),
(107650, 197, 29, 'Điều chỉnh'),
(107651, 198, 29, 'Quản trị điều chỉnh'),
(107652, 199, 29, 'Quản trị'),
(107653, 200, 29, 'Địa chỉ email Quản trị viên'),
(107654, 201, 29, 'Quản lý Bằng'),
(107655, 202, 29, 'Được quản trị'),
(107656, 203, 29, 'Được quản trị Bởi'),
(107657, 204, 29, 'Ngày Được quản trị'),
(107658, 205, 29, 'Địa điểm được Quản trị'),
(107659, 206, 29, 'Quản trị'),
(107660, 207, 29, 'Địa điểm Quản trị'),
(107661, 208, 29, 'Quản trị viên'),
(107662, 209, 29, 'Quản trị viên có thể làm bất cứ điều gì'),
(107663, 210, 29, 'Ngày Thừa nhận'),
(107664, 212, 29, 'Sàng lọc và Theo dõi Trọng lượng Người lớn'),
(107665, 213, 29, 'Sàng lọc và Theo dõi Trọng lượng Người lớn (CQM)'),
(107666, 214, 29, 'Chỉ thị Nâng cao'),
(107667, 215, 29, 'Chỉ thị Nâng cao'),
(107668, 216, 29, 'Cảnh báo Chỉ thị Nâng cao'),
(107669, 218, 29, 'Nâng cao'),
(107670, 219, 29, 'Lời khuyên'),
(107671, 221, 29, 'Ảnh hưởng đến bình thường'),
(107672, 222, 29, 'Tiếng/Người Nam Phi'),
(107673, 223, 29, 'Cuộc gọi sau giờ làm việc'),
(107674, 224, 29, 'Sau khi hoàn thành việc di chuyển từ các cơ chế mật khẩu cũ, nơi lưu mật khẩu không có salt trong bảng người dùng, cờ này cần được đặt thành false (sai) để chỉ cho phép xác thực bằng phương pháp mới.'),
(107675, 225, 29, 'Sau khi thực hiện các cấu hình trên, kết nhập chứng chỉ máy khách quản trị vào trình duyệt và khởi động lại máy chủ Apache (mật khẩu rỗng).'),
(107676, 226, 29, 'Sau khi lưu các file PDF, nhấp vào [Xem Bản ghi] để kiểm tra lỗi.'),
(107677, 227, 29, 'Sau khi lưu các tập tin văn bản, nhấp vào [Xem Bản ghi] để kiểm tra lỗi.'),
(107678, 228, 29, 'Sau khi lưu loạt của bạn, hãy nhấp vào [Xem Bản ghi] để kiểm tra lỗi.'),
(107679, 229, 29, 'Sau đó cột "Phù hợp với" sẽ hiện mã bệnh nhân được chọn, hay 0 để tạo.'),
(107680, 230, 29, 'Sau khi đã nhập đúng thông tin, hãy nhấp vào nút Lưu.'),
(107681, 231, 29, 'Sau khi Tải lên, bấm nút "Kết nhập"'),
(107682, 232, 29, 'Kế hoạch Chăm sóc'),
(107683, 233, 29, 'Lần nữa'),
(107684, 234, 29, 'Tuổi'),
(107685, 235, 29, 'Tuổi Khi'),
(107686, 236, 29, 'Thể loại Tuổi'),
(107687, 237, 29, 'Dữ liệu tuổi vượt khỏi phạm vi.'),
(107688, 238, 29, 'Định dạng Hiển thị Tuổi'),
(107689, 239, 29, 'Định dạng tuổi cho "tuổi từ bao nhiêu" là không hợp lệ'),
(107690, 240, 29, 'Định dạng tuổi cho "tuổi lên đến" là không hợp lệ'),
(107691, 241, 29, 'Tuổi Từ'),
(107692, 242, 29, 'Tuổi theo Năm để Thay đổi Định dạng Hiển thị'),
(107693, 243, 29, 'Tuổi lớn nhất'),
(107694, 244, 29, 'Tuổi nhỏ nhất'),
(107695, 245, 29, 'Phạm vi Tuổi'),
(107696, 247, 29, 'Cột Tuổi:'),
(107697, 249, 29, 'Tiếng/Người Albany'),
(107698, 250, 29, 'Rượu'),
(107699, 251, 29, 'Lượng cồn hấp thu'),
(107700, 252, 29, 'Sử dụng Rượu'),
(107701, 253, 29, 'Số lần Cảnh báo'),
(107702, 255, 29, 'Cảnh báo'),
(107703, 258, 29, 'ALEUT'),
(107704, 259, 29, 'Tất cả'),
(107705, 260, 29, 'TẤT CẢ'),
(107706, 261, 29, 'Tất cả (đối chiếu Định dạng A)'),
(107707, 262, 29, 'Tất cả (đối chiếu Định dạng B)'),
(107708, 263, 29, 'Tất cả (Tích lũy)'),
(107709, 265, 29, 'Tất cả Tính toán Đo lường Tự động (AMC)'),
(107710, 266, 29, 'Tất cả Thể loại'),
(107711, 267, 29, 'Tất cả Đo lường Chất lượng Lâm sàng (CQM)'),
(107712, 268, 29, 'Tất cả Mã'),
(107713, 269, 29, 'Cả Ngày'),
(107714, 270, 29, 'Sự kiện trong Cả Ngày'),
(107715, 271, 29, 'Tất cả các trường thông tin cá nhân, tìm kiếm và kiểm tra trùng lặp'),
(107716, 272, 29, 'Tất cả các Cơ sở'),
(107717, 273, 29, 'Tất cả các Chấn thương / Vấn đề / Vấn đề'),
(107718, 274, 29, 'Cho phép Mọi Ngôn ngữ'),
(107719, 275, 29, 'Tất cả Nhóm Đo lường CQM (Đo lường Chất lượng Lâm sàng) Chính thức'),
(107720, 276, 29, 'Tất cả hoặc một phần của tên'),
(107721, 277, 29, 'Tất cả hoặc một phần của họ'),
(107722, 278, 29, 'Tất cả hoặc một phần của tổ chức'),
(107723, 279, 29, 'Tất cả Bệnh nhân'),
(107724, 280, 29, 'Tất cả Sản phẩm'),
(107725, 281, 29, 'Tất cả các Nhà cung cấp'),
(107726, 282, 29, 'Tất cả Đánh giá và Âm tính:'),
(107727, 283, 29, 'Tất cả Chủ đề'),
(107728, 284, 29, 'Tất cả Người dùng'),
(107729, 285, 29, 'Dị ứng'),
(107730, 286, 29, 'Các dị ứng'),
(107731, 287, 29, 'Các dị ứng:'),
(107732, 288, 29, 'Dị ứng'),
(107733, 289, 29, 'Đã hoàn thành kết nhập dị ứng'),
(107734, 290, 29, 'Danh sách Vấn đề Dị ứng'),
(107735, 291, 29, 'Phản ứng Dị ứng'),
(107736, 294, 29, 'Phân phối'),
(107737, 295, 29, 'Cho Phép'),
(107738, 296, 29, 'Cho phép tất cả các ngôn ngữ có sẵn trong phần lựa chọn lúc đăng nhập.'),
(107739, 297, 29, 'Cho phép tạo ra các yêu cầu có chứa chẩn đoán nhưng không có thủ tục hoặc phí. Hầu hết các phòng khám không muốn điều này.'),
(107740, 298, 29, 'Cho phép Gỡ lỗi Ngôn ngữ'),
(107741, 299, 29, 'Cho phép Email'),
(107742, 300, 29, 'Cho phép các tin nhắn email?'),
(107743, 301, 29, 'Cho phép Email?'),
(107744, 302, 29, 'Cho phép Yêu cầu Lần khám'),
(107745, 303, 29, 'Cho phép Trao đổi Thông tin Y tế'),
(107746, 304, 29, 'Cho phép Chia sẻ Thông tin Tiêm chủng'),
(107747, 305, 29, 'Cho phép Đăng ký Sử dụng Tiêm chủng'),
(107748, 306, 29, 'Cho phép Gửi Thư'),
(107749, 308, 29, 'Cho phép Cổng thông tin Bệnh nhân'),
(107750, 309, 29, 'Cho phép tin nhắn SMS'),
(107751, 310, 29, 'Cho phép tin nhắn SMS (tin nhắn văn bản)?'),
(107752, 311, 29, 'Cho phép các sự kiện trình được thực hiện hoạt động ngay lập tức?'),
(107753, 312, 29, 'Cho phép tin nhắn điện thoại?'),
(107754, 313, 29, 'Cho phép người dùng xuất bản các Sự kiện Tổng thể'),
(107755, 314, 29, 'Cho phép người dùng xuất bản Lịch Cá nhân'),
(107756, 315, 29, 'Cho phép tin nhắn bằng giọng nói'),
(107757, 316, 29, 'Được cho phép'),
(107758, 317, 29, 'Ngôn ngữ Được phép'),
(107759, 318, 29, 'Cho phép (c)'),
(107760, 319, 29, 'Cho phép Chữ ký Điện tử trên toàn bộ lần khám'),
(107761, 320, 29, 'Cho phép Các biểu mẫu Cá nhân Ký điện tử'),
(107762, 321, 29, 'Cho phép Thư'),
(107763, 322, 29, 'Cho phép Hộp thư thoại'),
(107764, 323, 29, 'đã tồn tại'),
(107765, 324, 29, 'đã tồn tại.'),
(107766, 325, 29, 'Đã được dùng, hãy chọn số định danh khác'),
(107767, 326, 29, 'Đã được dùng, hãy chọn tiêu đề khác'),
(107768, 327, 29, 'Địa chỉ khác'),
(107769, 328, 29, 'thay đổi'),
(107770, 329, 29, 'Ngoài ra, bạn có thể sử dụng trang tìm kiếm để tải lên một tập tin chuyển tiền điện tử (X12 835) mà bạn đã thu được từ người trả tiền hoặc ngân hàng của bạn. Bạn có thể làm điều này bằng cách nhấp vào nút Browse và chọn tập tin để tải lên, và sau đó nhấp vào Tìm kiếm để thực hiện việc tải lên và hiển thị hóa đơn tương ứng. Trong trường hợp này các thông số khác được đề cập ở trên không áp dụng và sẽ bị bỏ qua. Việc tải lên lưu các tập tin nhưng không xử lý nội dung của nó -- việc xử lý được thực hiện một cách riêng biệt như mô tả dưới đây.'),
(107771, 330, 29, 'AM'),
(107772, 331, 29, 'Chương trình AM'),
(107773, 332, 29, 'AMC'),
(107774, 333, 29, 'Theo dõi AMC'),
(107775, 334, 29, 'AMC-2011'),
(107776, 335, 29, 'AMC-2014'),
(107777, 338, 29, 'Sửa đổi Lưu ý Đang có'),
(107778, 339, 29, 'Đã điều chỉnh Từ'),
(107779, 340, 29, 'Trạng thái Đã điều chỉnh'),
(107780, 341, 29, 'Các điều chỉnh'),
(107781, 342, 29, 'Các điều chỉnh cho'),
(107782, 343, 29, 'Mỹ Da Đỏ'),
(107783, 344, 29, 'Mỹ Da Đỏ hoặc người Alaska'),
(107784, 345, 29, 'AMEX'),
(107785, 346, 29, 'Amharic'),
(107786, 347, 29, 'Số tiền'),
(107787, 348, 29, 'Số tiền đã Quản trị'),
(107788, 349, 29, 'Số tiền Phí'),
(107789, 350, 29, 'Số tiền cho Số tiền Còn lại'),
(107790, 351, 29, 'Số tiền cho Lần đến Này'),
(107791, 352, 29, 'Số tiền đã Trả'),
(107792, 353, 29, 'Số tiền:'),
(107793, 354, 29, 'Số tiền đã lập Hóa đơn'),
(107794, 355, 29, 'Các sự kiện lặp lại phải có ngày kết thúc sau ngày bắt đầu!'),
(107795, 356, 29, 'Lỗi xảy ra khi đang ký biểu mẫu đó'),
(107796, 357, 29, 'Một lỗi xảy ra trong khi chép toàn bộ cây thư mục web LibreEHR'),
(107797, 358, 29, 'Một lỗi xảy ra trong khi chép toàn bộ cây thư mục web phpGACL'),
(107798, 359, 29, 'Một lỗi xảy ra trong khi chép toàn bộ cây thư mục web SQL-Ledger'),
(107799, 360, 29, 'Đã tạo ra và liên kết một vấn đề GCAC  không đầy đủ. Một người nào đó sẽ phải hoàn thành nó sau này.'),
(107800, 362, 29, 'Đã xảy ra một lỗi bất ngờ.'),
(107801, 363, 29, 'Một ký tự hoa'),
(107802, 365, 29, 'Và'),
(107803, 366, 29, 'VÀ'),
(107804, 367, 29, 'và'),
(107805, 368, 29, 'và '),
(107806, 369, 29, 'và tất cả các dữ liệu cấp dưới? Hành động này sẽ được ghi nhận'),
(107807, 370, 29, 'và sửa đổi lần'),
(107808, 371, 29, 'và xử lý.'),
(107809, 372, 29, 'và khởi động lại máy chủ Apache.'),
(107810, 373, 29, 'và lý do là'),
(107811, 374, 29, 'Thiếu máu'),
(107812, 375, 29, 'Mắt cá chân'),
(107813, 376, 29, 'Mắt cá chân + gót chân'),
(107814, 377, 29, 'Mẫu Đánh giá Mắt cá chân'),
(107815, 378, 29, 'Vấn đề với Mắt cá chân'),
(107816, 379, 29, 'Cứng khớp Sondlilitis'),
(107817, 380, 29, 'Cứng khớp Spondlilitis'),
(107818, 381, 29, 'Biếng ăn'),
(107819, 382, 29, 'Một việc khác bạn có thể làm trong cửa sổ vào sổ cái là yêu cầu lập hóa đơn thứ cấp. Nếu bạn chọn hộp đánh dấu này trước khi lưu, phiếu yêu cầu gốc sẽ được mở ra lại và xếp hàng vào trang Lập hóa đơn, và sẽ được xử lý vào lần lập hóa đơn kế tiếp.'),
(107820, 383, 29, 'trước'),
(107821, 384, 29, 'Nl hậu môn, trực tràng không đau / khối lượng'),
(107822, 385, 29, 'Lo âu'),
(107823, 386, 29, 'Bất kỳ'),
(107824, 387, 29, 'Bất kỳ loại'),
(107825, 388, 29, 'Bất kỳ phần nào của mã bạn cần hoặc mô tả của nó'),
(107826, 389, 29, 'Bất kỳ phần nào của dấu viết đặc biệt bạn cần'),
(107827, 390, 29, 'Bất kỳ phần nào của mã hoặc tên thuốc'),
(107828, 391, 29, 'Bất kỳ phần nào của mã hoặc tên của tiêm chủng'),
(107829, 392, 29, 'Bất kỳ phần nào của tên bệnh nhân, hoặc "họ, tên", hoặc "X-Y"'),
(107830, 393, 29, 'Thông tin nào khác có liên quan'),
(107831, 394, 29, 'Khóa API cho Cổng SMS.'),
(107832, 395, 29, 'Ngưng thở'),
(107833, 396, 29, 'Bề ngoài'),
(107834, 397, 29, 'Bề ngoài:'),
(107835, 398, 29, 'Thêm lưu ý này'),
(107836, 399, 29, 'Thêm vào các lưu ý đang có'),
(107837, 400, 29, 'Thêm vào lưu ý này'),
(107838, 401, 29, 'Thêm vào Lưu ý này'),
(107839, 402, 29, 'Ruột thừa'),
(107840, 403, 29, 'ruột thừa'),
(107841, 404, 29, 'Bệnh nhân Phù hợp'),
(107842, 405, 29, 'Ứng dụng'),
(107843, 406, 29, 'Tên ứng dụng cho trang đăng nhập và tiêu đề cửa sổ chính.'),
(107844, 407, 29, 'Mã Người nhận Đơn xin (GS03 - Nếu để trống thì dùng ISA08)'),
(107845, 408, 29, 'Mã Người gửi Đơn xin (GS02)'),
(107846, 409, 29, 'Tiêu đề Ứng dụng'),
(107847, 410, 29, 'Áp dụng cho các biểu mẫu Thể trạng và Biểu đồ Tăng trưởng'),
(107848, 411, 29, 'Áp dụng cho biểu mẫu Thể trạng'),
(107849, 412, 29, 'Áp dụng thay đổi chỉ cho sự kiện hiện tại, cho lần này và các lần xuất hiện trong tương lai, hoặc cho tất cả các lần xuất hiện?'),
(107850, 413, 29, 'áp dụng đối với khu vực bị ảnh hưởng'),
(107851, 414, 29, 'áp dụng cho da'),
(107852, 415, 29, 'Đang áp dụng'),
(107853, 416, 29, 'Đang áp dụng bản vá cho trang web'),
(107854, 417, 29, 'Cuộc hẹn'),
(107855, 418, 29, 'Cuộc Hẹn ngày'),
(107856, 419, 29, 'Kiểu hiển thị Cuộc Hẹn'),
(107857, 420, 29, 'Nhắc nhở Cuộc Hẹn'),
(107858, 421, 29, 'Tình trạng cuộc hẹn'),
(107859, 422, 29, 'Trạng thái cuộc hẹn'),
(107860, 423, 29, 'Trong cuộc hẹn'),
(107861, 424, 29, 'Màu cho Cuộc hẹn / Sự kiện'),
(107862, 425, 29, 'Các cuộc hẹn'),
(107863, 426, 29, 'Các cuộc hẹn (tùy chọn viết)'),
(107864, 427, 29, 'Các cuộc hẹn (tùy chọn viết, viết một phần)'),
(107865, 430, 29, 'Cuộc hẹn và cuộc Gặp'),
(107866, 431, 29, 'Báo cáo Các cuộc hẹn'),
(107867, 432, 29, 'Báo cáo Hẹn - Găp'),
(107868, 434, 29, 'Phê duyệt'),
(107869, 435, 29, 'Phê duyệt bệnh nhân tại Bệnh nhân/Khách hàng -> Nhập -> Đang chờ Phê duyệt'),
(107870, 436, 29, 'Đã Phê duyệt'),
(107871, 437, 29, 'Quản trị Sự kiện Phê duyệt'),
(107872, 438, 29, 'Phê duyệt Thành công'),
(107873, 440, 29, 'Appt-ENC'),
(107874, 441, 29, 'Cuộc hẹn'),
(107875, 442, 29, 'Tháng Tư'),
(107876, 443, 29, 'Tháng Tư'),
(107877, 444, 29, 'Tiếng Ả Rập'),
(107878, 446, 29, 'Lưu trữ'),
(107879, 447, 29, 'Có dịch tên nhóm kiểm soát truy cập không?'),
(107880, 448, 29, 'Có dịch tên thể loại cuộc hẹn không?'),
(107881, 449, 29, 'Có dịch tên thể loại tài liệu không?'),
(107882, 450, 29, 'Có tính phí cho loại này không?'),
(107883, 451, 29, 'Có dịch các tiêu đề ghi chú cho bệnh nhân không?'),
(107884, 452, 29, 'Có lưu các mã trong bản SQL bên ngoài không (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(107885, 453, 29, 'Bạn đã chuẩn bị để hoàn thành một vấn đề mới GCAC cho chuyến thăm này?'),
(107886, 454, 29, 'Bạn có chắc chắn vào sổ cái cho hôm nay?'),
(107887, 455, 29, 'Bạn có chắc chắn muốn chấp nhận những sự kiện này?'),
(107888, 457, 29, 'Bạn chắc chắn rằng bạn muốn gỡ bỏ hoàn toàn mẫu này?'),
(107889, 458, 29, 'Bạn có chắc bạn muốn xóa'),
(107890, 459, 29, 'Bạn có chắc bạn muốn xóa Cho Biết này?'),
(107891, 460, 29, 'Bạn có chắc chắn, bạn muốn xoá sự kiện này?'),
(107892, 461, 29, 'Bạn có chắc, bạn muốn xóa mục này từ cơ sở dữ liệu?'),
(107893, 462, 29, 'Bạn có chắc, bạn muốn xóa này lưu ý?'),
(107894, 464, 29, 'Bạn có chắc chắn, bạn muốn chỉnh sửa các sự kiện này?'),
(107895, 465, 29, 'Bạn chắc chắn rằng bạn muốn ẩn những sự kiện này?'),
(107896, 466, 29, 'Bạn có chắc bạn muốn truyền lại nữa?'),
(107897, 467, 29, 'Có chắc chắn bạn muốn xem các sự kiện này?'),
(107898, 468, 29, 'Có chắc bạn muốn xóa toàn bộ nhóm có tên'),
(107899, 469, 29, 'Có chắc bạn muốn xóa toàn bộ danh sách'),
(107900, 470, 29, 'Bạn có chắc bạn muốn xóa các lĩnh vực'),
(107901, 471, 29, 'Bạn có chắc bạn muốn xóa các lĩnh vực được lựa chọn?'),
(107902, 472, 29, 'Bạn có chắc chắn bạn ''d muốn tiếp tục với những hành động này?'),
(107903, 473, 29, 'Khu vực không có quy định'),
(107904, 474, 29, 'Tay'),
(107905, 475, 29, 'Tiếng Armenia'),
(107906, 477, 29, 'Arrythmia'),
(107907, 478, 29, 'Viêm khớp'),
(107908, 479, 29, 'Viêm khớp / Degen doanh diseas'),
(107909, 480, 29, 'Viêm khớp / Degen khớp'),
(107910, 481, 29, 'như'),
(107911, 482, 29, 'Vào Lúc'),
(107912, 484, 29, 'Châu Á'),
(107913, 487, 29, 'Đánh giá (Assessment)'),
(107914, 488, 29, 'Giao Để'),
(107915, 489, 29, 'Trợ lý'),
(107916, 490, 29, 'Hen suyễn'),
(107917, 491, 29, 'tại'),
(107918, 492, 29, 'Ít nhất một tham số tìm kiếm được yêu cầu nếu bạn chọn Tất cả.'),
(107919, 493, 29, 'Tại các Navicular'),
(107920, 494, 29, 'Tại các Navicular:'),
(107921, 495, 29, 'Đội thể dục'),
(107922, 496, 29, 'Đội Thể dục'),
(107923, 497, 29, 'Thuộc thể thao / tai nạn thương tích'),
(107924, 498, 29, 'ATNA kiểm toán CA giấy chứng nhận'),
(107925, 499, 29, 'chủ kiểm toán ATNA'),
(107926, 500, 29, 'Giấy chứng nhận kiểm toán khu vực ATNA'),
(107927, 501, 29, 'Cổng kiểm toán ATNA'),
(107928, 503, 29, 'Sự chú ý'),
(107929, 504, 29, 'Attn'),
(107930, 509, 29, 'Sao lưu Kiểm tra đăng nhập'),
(107931, 510, 29, 'Kiểm toán Đăng nhập lộn xộn'),
(107932, 511, 29, 'Kiểm toán đăng nhập Theo'),
(107933, 512, 29, 'Kiểm toán Đăng nhập Ghi Bệnh nhân'),
(107934, 513, 29, 'Kiểm toán Đăng nhập Lập kế hoạch'),
(107935, 514, 29, 'Kiểm toán Đăng nhập Cục An ninh'),
(107936, 515, 29, 'Kiểm toán Đăng nhập CHỌN truy vấn'),
(107937, 516, 29, 'Tháng Tám'),
(107938, 517, 29, 'Tháng Tám'),
(107939, 519, 29, 'Quyền'),
(107940, 520, 29, 'Quyền / Ghi chú'),
(107941, 523, 29, 'Nhóm Ủy quyền'),
(107942, 524, 29, 'Trạng thái Ủy quyền'),
(107943, 525, 29, 'Ủy quyền'),
(107944, 526, 29, 'Ủy quyền'),
(107945, 527, 29, 'Ủy quyền - bất kỳ cuộc gặp gỡ'),
(107946, 528, 29, 'Ủy quyền - cuộc gặp gỡ của tôi'),
(107947, 529, 29, 'Authorize.net'),
(107948, 530, 29, 'Ủy quyền'),
(107949, 531, 29, 'Ủy quyền Chỉ'),
(107950, 532, 29, 'Gửi tự động');
INSERT INTO `lang_definitions` VALUES
(107951, 535, 29, 'Tự động-Tạo cuộc gặp mới'),
(107952, 536, 29, 'Tự động tạo ra'),
(107953, 537, 29, 'Biện pháp tính toán tự động (AMC)'),
(107954, 538, 29, 'Biện pháp tính toán tự động (AMC) - 2011'),
(107955, 539, 29, 'Biện pháp tính toán tự động (AMC) - 2014'),
(107956, 542, 29, 'Biện pháp tính toán tự động (AMC) Theo dõi'),
(107957, 543, 29, 'Các biện pháp tự động (AMC)'),
(107958, 544, 29, 'Tự động'),
(107959, 546, 29, 'Tự động tạo ra một cuộc gặp gỡ mới khi tình trạng bổ nhiệm được thiết lập để "@" (đến).'),
(107960, 549, 29, 'Xe Y Tế Lưu Động'),
(107961, 550, 29, 'tự động lưu'),
(107962, 551, 29, 'Có sẵn loại'),
(107963, 552, 29, 'Thời gian Rảnh'),
(107964, 555, 29, 'Kiểu Nhãn Avery để in nhãn bệnh nhân từ popups trong màn hình điều hướng bên trái'),
(107965, 557, 29, 'Trung bình hàng tháng'),
(107966, 558, 29, 'Sự nhổ lên / gãy xương do giật'),
(107967, 559, 29, 'Sự nhổ lên mắt cá bên'),
(107968, 560, 29, 'Sự nhổ lên mắt cá trung gian '),
(107969, 561, 29, 'Dựa vào Nhận thức'),
(107970, 562, 29, 'Nách'),
(107971, 565, 29, '2 lần/ngày'),
(107972, 566, 29, 'Quay lại'),
(107973, 567, 29, 'quay lại'),
(107974, 568, 29, '8 lần trở lại thăm khám'),
(107975, 569, 29, '11 lần trở lại thăm khám'),
(107976, 570, 29, '5 lần trở lại thăm khám'),
(107977, 571, 29, '4 lần trở lại thăm khám'),
(107978, 572, 29, '9 lần trở lại thăm khám'),
(107979, 573, 29, '1 lần trở lại thăm khám'),
(107980, 574, 29, 'Đau Lưng'),
(107981, 575, 29, 'Vấn đề về Lưng'),
(107982, 576, 29, '7 lần trở lại thăm khám'),
(107983, 577, 29, '6 lần trở lại thăm khám'),
(107984, 578, 29, 'Giải phẫu Lưng'),
(107985, 579, 29, '10 lần trở lại thăm khám'),
(107986, 580, 29, '3 lần trở lại thăm khám'),
(107987, 581, 29, 'Quay lại Trang Quản trị'),
(107988, 582, 29, 'Quay lại lần khám'),
(107989, 583, 29, 'Quay lại trang Bệnh nhân'),
(107990, 584, 29, 'Quay lại Trang Bệnh nhân'),
(107991, 585, 29, 'Quay lại Trang Người dùng'),
(107992, 586, 29, 'Quay lại Trang Xem'),
(107993, 587, 29, '12 lần trở lại thăm khám'),
(107994, 588, 29, '2 lần trở lại thăm khám'),
(107995, 589, 29, 'Các dịch vụ Chạy nền'),
(107996, 590, 29, 'Sao lưu'),
(107997, 591, 29, 'Tập tin sao lưu đã được tạo ra. Bây giờ sẽ tải về'),
(107998, 592, 29, 'Danh sách Sao lưu'),
(107999, 593, 29, 'Sao lưu thành công thực hiện trong'),
(108000, 594, 29, 'Chi phiếu không tiền bảo chứng'),
(108001, 595, 29, 'Nợ xấu'),
(108002, 596, 29, 'Tiếng Bahasa In-đô-nê-xia'),
(108003, 597, 29, 'Cân đối'),
(108004, 598, 29, 'Bảng cân đối'),
(108005, 599, 29, 'bảng cân đối'),
(108006, 600, 29, 'Số tiền Thanh toán'),
(108007, 601, 29, 'Số tiền Còn lại'),
(108008, 603, 29, 'Hối phiếu Ngân hàng'),
(108009, 604, 29, 'Nhãn Mã vạch'),
(108010, 605, 29, 'Kiểu Nhãn Mã vạch'),
(108011, 606, 29, 'Kiểu mã vạch để in nhãn mã vạch từ popups trong cửa sổ điều hướng bên trái'),
(108012, 607, 29, 'Cơ sở của Metarsal thứ 5'),
(108013, 608, 29, 'Cơ sở của Metarsal thứ 5:'),
(108014, 611, 29, 'Yêu cầu Hàng loạt'),
(108015, 612, 29, 'Công cụ Truyền thông Hàng loạt'),
(108016, 613, 29, 'Khoản mục Thanh toán Hàng loạt'),
(108017, 614, 29, 'Thanh toán Hàng loạt'),
(108018, 615, 29, 'Xử lý hàng loạt đã được tiến hành; cần một ít thời gian để làm.'),
(108019, 616, 29, 'Kết quả Làm Hàng loạt'),
(108020, 617, 29, 'BatchCom'),
(108021, 618, 29, 'Hãy kiên nhẫn, một số tập tin cần nhiều phút để xử lý'),
(108022, 619, 29, 'bởi vì mã đó không tồn tại.'),
(108023, 620, 29, 'Bắt đầu'),
(108024, 621, 29, 'Ngày Bắt đầu'),
(108025, 623, 29, 'Ngày bắt đầu dịch vụ năm-tháng-ngày'),
(108026, 624, 29, 'Bắt đầu từ giờ trong ngày cho các lịch sự kiện.'),
(108027, 626, 29, 'Ợ hơi'),
(108028, 628, 29, 'Tiếng/Người Bengal'),
(108029, 630, 29, 'giữa'),
(108030, 631, 29, 'Hai chiều'),
(108031, 633, 29, 'Song phương'),
(108032, 634, 29, 'Song phương:'),
(108033, 636, 29, 'Hóa đơn Ngày:'),
(108034, 637, 29, 'Hóa đơn / Thu tiền'),
(108035, 638, 29, 'Đã gửi hóa đơn'),
(108036, 640, 29, 'Lập hóa đơn'),
(108037, 641, 29, 'Lập hóa đơn (tùy chọn cho ghi)'),
(108038, 642, 29, 'Người nhận Hóa đơn'),
(108039, 644, 29, 'Mã Hóa đơn cho Dịch vụ được Yêu cầu'),
(108040, 645, 29, 'Mã hóa đơn'),
(108041, 646, 29, 'Dữ liệu Hóa đơn'),
(108042, 647, 29, 'Thanh toán cho Bộ phận'),
(108043, 648, 29, 'Thanh toán cho Cơ sở'),
(108044, 649, 29, 'Thông tin Hóa đơn'),
(108045, 650, 29, 'Vị trí nhận Thanh toán'),
(108046, 655, 29, 'Người quản lý Thanh toán'),
(108047, 656, 29, 'Lưu ý Thanh toán'),
(108048, 657, 29, 'Lưu ý Thanh toán cho '),
(108049, 658, 29, 'Lưu ý Thanh toán:'),
(108050, 659, 29, 'Kết quả hàng đợi thanh toán:'),
(108051, 660, 29, 'Báo cáo Hóa đơn'),
(108052, 661, 29, 'Trạng thái Hóa đơn'),
(108053, 662, 29, 'Tình trạng Hóa đơn = Chưa gửi hóa đơn'),
(108054, 663, 29, 'thanh toán đến '),
(108055, 665, 29, 'Sinh thiết'),
(108056, 666, 29, 'Ngày sinh'),
(108057, 667, 29, 'Khi sinh-24 tháng'),
(108058, 669, 29, 'Đen'),
(108059, 670, 29, 'Nám Phổi'),
(108060, 671, 29, 'Người da đen hoặc người Mỹ gốc Phi'),
(108061, 672, 29, 'Ung thư Bàng quang'),
(108062, 673, 29, 'Nhiễm trùng Bàng quang'),
(108063, 674, 29, 'Biểu mẫu Trống'),
(108064, 675, 29, 'Vấn đề Chảy máu'),
(108065, 676, 29, 'Điểm Mù'),
(108066, 677, 29, 'Đầy hơi'),
(108067, 678, 29, 'Bị chặn'),
(108068, 679, 29, 'Máu'),
(108069, 680, 29, 'Huyết Áp'),
(108070, 681, 29, 'Huyết áp'),
(108071, 682, 29, 'Chảy Máu cam'),
(108072, 683, 29, 'Blue Cross Blue Shield'),
(108073, 684, 29, 'Đường màu xanh trong báo cáo này để cung cấp thông tin. Đường màu đen hiển thị thông tin có trước đây. Đường màu xanh lá cây cho thấy thay đổi đã được áp dụng thành công. Đường màu đỏ chỉ ra sai sót, hoặc thay đổi đã không được áp dụng, chúng phải được xử lý bằng tay. Tuyên bố hiện đang bị từ chối và đảo ngược thanh toán không được xử lý tự động và như vậy sẽ xuất hiện trong màu đỏ.'),
(108074, 685, 29, 'Giảm Thị lực'),
(108075, 686, 29, 'BMI'),
(108076, 687, 29, 'Trạng thái BMI'),
(108077, 689, 29, 'Vùng Cơ thể'),
(108078, 690, 29, 'Điểm trên Cơ thể'),
(108079, 691, 29, 'Điểm trên cơ thể, nếu phù hợp'),
(108080, 692, 29, 'Xương Đau:'),
(108081, 693, 29, 'Đau xương: mắt cá Medial'),
(108082, 694, 29, 'Luận lý'),
(108083, 696, 29, 'Dưới'),
(108084, 697, 29, 'Cả hai tai'),
(108085, 698, 29, 'cả hai tai'),
(108086, 699, 29, 'Dưới'),
(108087, 700, 29, 'Lề Dưới (điểm ảnh)'),
(108088, 701, 29, 'BOX 10 A. Liên quan đến công việc '),
(108089, 702, 29, 'BOX 10 B. Tai nạn Xe cộ '),
(108090, 703, 29, 'BOX 10 C. Tai nạn khác '),
(108091, 706, 29, 'BOX 15. Ngày có bệnh đó hay bệnh tương tự (Năm-tháng-ngày):'),
(108092, 707, 29, 'BOX 15. Ngày có bệnh đó hay bệnh tương tự/Khác (Năm-tháng-ngày):'),
(108093, 708, 29, 'BOX 16. Không thể làm việc từ ngày (Năm-tháng-ngày):'),
(108094, 709, 29, 'BOX 16. Không thể làm việc đến ngày (Năm-tháng-ngày):'),
(108095, 710, 29, 'BOX 18. Nhập viện từ ngày (Năm-tháng-ngày): '),
(108096, 711, 29, 'BOX 18. Nhập viện đến ngày (Năm-tháng-ngày): '),
(108097, 712, 29, 'BOX 20. Bên ngoài phòng thí nghiệm được sử dụng?'),
(108098, 713, 29, 'BOX 22. Nộp lại luật y tế (ICD-9) '),
(108099, 714, 29, 'BOX 23. Trước khi ủy quyền số '),
(108100, 715, 29, 'Huyết áp'),
(108101, 716, 29, 'Huyết áp tâm trương'),
(108102, 717, 29, 'Huyết áp tâm thu'),
(108103, 719, 29, 'Bpd'),
(108104, 721, 29, 'Bps'),
(108105, 722, 29, 'Tiếng/Người Bồ Đào Nha ở Brazin'),
(108106, 723, 29, 'Vú'),
(108107, 724, 29, 'Sinh thiết Vú'),
(108108, 726, 29, 'Bệnh về Vú'),
(108109, 727, 29, 'Kiểm tra Vú'),
(108110, 728, 29, 'U vú'),
(108111, 730, 29, 'Âm thanh Vú:'),
(108112, 732, 29, 'Gãy Xương'),
(108113, 733, 29, 'dạng gãy'),
(108114, 734, 29, 'Viêm phế quản mẫu'),
(108115, 735, 29, 'Duyệt xem'),
(108116, 736, 29, 'Duyệt Hồ sơ'),
(108117, 737, 29, 'Bầm / tụ máu'),
(108118, 739, 29, 'Phồng phải:'),
(108119, 741, 29, 'Đốt với Đi tiểu'),
(108120, 742, 29, 'Đốt Với ​​Đi tiểu'),
(108121, 743, 29, 'Điện thoại Công việc'),
(108122, 744, 29, 'Bận rộn'),
(108123, 745, 29, 'nhưng chưa được xử lý.'),
(108124, 746, 29, 'Mông'),
(108125, 747, 29, 'Mông + S.I.'),
(108126, 748, 29, 'bởi'),
(108127, 749, 29, 'Bởi'),
(108128, 750, 29, 'bằng miệng'),
(108129, 751, 29, 'Bởi / Nguồn'),
(108130, 752, 29, 'Bởi:'),
(108131, 753, 29, 'C'),
(108132, 754, 29, 'Giấy chứng nhận CA để xác minh máy chủ syslog RFC 5425 TLS.'),
(108133, 755, 29, 'Thời gian lưu trong bộ nhớ đệm (tính bằng giây)'),
(108134, 756, 29, 'Có nhớ đệm kết quả khuôn mẫu?'),
(108135, 757, 29, 'Dùng cà phê'),
(108136, 758, 29, 'Lịch'),
(108137, 759, 29, 'Giờ Kết thúc trong Lịch'),
(108138, 760, 29, 'Thời khoảng trong Lịch'),
(108139, 761, 29, 'Màn hình Lịch'),
(108140, 762, 29, 'Cài đặt Lịch'),
(108141, 763, 29, 'Giờ Bắt đầu trong Lịch'),
(108142, 764, 29, 'Giao diện Lịch'),
(108143, 765, 29, 'Xem Lịch'),
(108144, 766, 29, 'Gọi addForm () ở đây. <br>'),
(108145, 767, 29, 'Năng lượng'),
(108146, 768, 29, 'Tiếng/Người Campuchia'),
(108148, 774, 29, 'Hủy bỏ'),
(108149, 775, 29, 'Hủy bỏ Thay đổi'),
(108150, 776, 29, 'Đã hủy bỏ'),
(108151, 777, 29, 'Ung thư'),
(108152, 778, 29, 'Sàng lọc Ung thư: Sàng lọc Ung thư ruột kết'),
(108153, 779, 29, 'Sàng lọc Ung thư: Chụp nhũ ảnh'),
(108154, 780, 29, 'Sàng lọc Ung thư: Phết tế bào Cổ tử cung'),
(108155, 781, 29, 'Sàng lọc Ung thư: Sàng lọc Ung thư Tuyến tiền liệt'),
(108156, 782, 29, 'Không thể thêm đầu mục này bởi vì đã có nó!'),
(108157, 783, 29, 'Không thể thêm / cập nhật đầu mục này bởi vì đã có bản sao của nó!'),
(108158, 784, 29, 'không thể được lưu trữ, đã bỏ qua'),
(108159, 785, 29, 'không có thể được chuyển đổi sang JPEG. Có lẽ ImageMagick không được cài đặt?'),
(108160, 786, 29, 'không thể bị xóa, đã bỏ qua'),
(108161, 787, 29, 'Không thể hiển thị nội tuyến bởi vì loại của nó không được hỗ trợ bởi trình duyệt.'),
(108162, 788, 29, 'không thể hiển thị nội tuyến bỏi vì loại của nó không được hỗ trợ bởi trình duyệt'),
(108163, 789, 29, 'không thể hiển thị nội tuyến bởi vì loại của nó không được hỗ trợ bởi trình duyệt.'),
(108164, 790, 29, 'Không thể tạo'),
(108165, 791, 29, 'Không thể tạo tập tin'),
(108166, 792, 29, 'Không thể xóa tập tin (từ máy chủ SFTP)'),
(108167, 793, 29, 'Không thể xóa tập tin'),
(108168, 794, 29, 'Không thể xác định một tên tập tin đích'),
(108169, 795, 29, 'Không thể tìm thấy '),
(108170, 796, 29, 'Không thể tìm thấy một tên tập tin đích'),
(108171, 799, 29, 'Không thể tìm thấy bệnh nhân từ khách hàng id SQL-Ledger'),
(108172, 800, 29, 'Không thể tìm thấy tài liệu tham khảo tài liệu postscript '),
(108173, 801, 29, 'Không thể tìm thấy nhà cung cấp từ SQL-Ledger nhân viên = '),
(108174, 802, 29, 'Không thể Sửa đổi cách thanh toán.Không bị phân chia là Tiêu cực.'),
(108175, 803, 29, 'Không thể mở '),
(108176, 804, 29, 'Không thể Đăng cho Bảo hiểm.Các thực thể Thanh toán được lựa chọn là bệnh nhân'),
(108177, 805, 29, 'Không thể Đăng cho bệnh nhân. Thực thể chi trả chọn là Bảo hiểm.'),
(108178, 806, 29, 'Không thể Đăng Payments.Undistributed là tiêu cực.'),
(108179, 807, 29, 'Không thể đọc'),
(108180, 808, 29, 'Không thể đọc thư mục'),
(108181, 809, 29, 'Không thể cập nhật vì bạn không phải chỉnh sửa một mục nhập hiện tại!'),
(108182, 810, 29, 'Viết hoa'),
(108183, 811, 29, 'Viết hoa hết'),
(108184, 812, 29, 'viên nang'),
(108185, 813, 29, 'Thẻ'),
(108186, 814, 29, 'Đặt ống thông tim'),
(108187, 815, 29, 'Tim Echo'),
(108188, 816, 29, 'Tim mạch'),
(108189, 821, 29, 'Sụn ​​/ chondral / đĩa thiệt hại'),
(108190, 822, 29, 'Sụn ​​bị thương'),
(108191, 823, 29, 'Cartoid rung nl, bàn đạp xung nl'),
(108192, 824, 29, 'tiền mặt'),
(108193, 825, 29, 'Tiền mặt'),
(108194, 826, 29, 'Tiền mặt Rec'),
(108195, 827, 29, 'Giấy biên nhận tiền bởi nhà cung cấp'),
(108196, 829, 29, 'Phẫu thuật Đục thủy tinh thể'),
(108197, 830, 29, 'Đục thủy tinh thể'),
(108198, 831, 29, 'Thể loại'),
(108199, 832, 29, 'Thể loại cho'),
(108200, 833, 29, 'Thể loại'),
(108201, 834, 29, 'thể loại'),
(108202, 835, 29, 'Thể loại '),
(108203, 836, 29, 'Thể loại Thông tin chi tiết'),
(108204, 837, 29, 'Giới hạn Thể loại'),
(108205, 838, 29, 'Tên Thể loại'),
(108206, 839, 29, 'Tên thể loại đang trống'),
(108207, 840, 29, 'Thể loại / Tiêu đề'),
(108208, 841, 29, 'Da trắng'),
(108209, 842, 29, 'Làm cho Giấy biên nhận In Thông tin Nhà cung cấp / Lần khám Chính'),
(108210, 846, 29, 'CCR Phê duyệt'),
(108211, 847, 29, 'CCr Xem lại Bệnh nhân'),
(108212, 848, 29, 'CCR Xem lại và Phê duyệt'),
(108213, 850, 29, 'CDR'),
(108214, 851, 29, 'CDR Ưu tiên Xử lý Báo cáo'),
(108215, 852, 29, 'Di động'),
(108216, 853, 29, 'Điện thoại Di động'),
(108217, 854, 29, 'Số điện thoại di động'),
(108218, 855, 29, 'Số Điện thoại Di động'),
(108219, 856, 29, 'Trung ương chứng nhận'),
(108220, 857, 29, 'Trung / Nam Mỹ'),
(108221, 858, 29, 'Giấy chứng nhận Cơ quan crt tập tin vị trí không thể để trống'),
(108222, 859, 29, 'Vị trí Quyền hành giấy chứng nhận tập tin quan trọng không thể để trống'),
(108223, 860, 29, 'Giấy chứng nhận để gửi RFC 5425 máy chủ syslog TLS.'),
(108224, 861, 29, 'Giấy chứng nhận người sử dụng'),
(108225, 862, 29, 'Giấy chứng nhận'),
(108226, 864, 29, 'ChampUS'),
(108227, 865, 29, 'ChampUSVA'),
(108228, 866, 29, 'thay đổi'),
(108229, 867, 29, 'Thay đổi'),
(108230, 868, 29, 'Hoạt động thay đổi'),
(108231, 869, 29, 'Lỗi khi thay đổi! Có phải kết nối CouchDB bị lỗi?'),
(108232, 870, 29, 'Thay đổi thị lực'),
(108233, 871, 29, 'Thay đổi thị lực'),
(108234, 872, 29, 'Thay đổi Mật khẩu'),
(108235, 874, 29, 'Thay đổi'),
(108236, 875, 29, 'Thay đổi ruột'),
(108237, 876, 29, 'Đang thay đổi mã bệnh nhân cho tài liệu'),
(108238, 877, 29, 'Đặc điểm'),
(108239, 878, 29, 'Số ký tự Còn lại'),
(108240, 879, 29, 'Phí'),
(108241, 880, 29, 'Phí điều chỉnh'),
(108242, 881, 29, 'Mã Phí'),
(108243, 882, 29, 'Phí'),
(108244, 883, 29, 'Biểu đồ'),
(108245, 884, 29, 'Hoạt động biểu đồ'),
(108246, 885, 29, 'Báo cáo hoạt động biểu đồ check-in/out'),
(108247, 886, 29, 'Biểu đồ ID'),
(108248, 887, 29, 'Lập biểu đồ ID:'),
(108249, 888, 29, 'Nhãn Biểu đồ'),
(108250, 889, 29, 'Biểu đồ Bài gửi cuối'),
(108251, 890, 29, 'Lập biểu đồ Lưu ý'),
(108252, 891, 29, 'Biểu đồ số'),
(108253, 892, 29, 'Nơi Lưu trữ Biểu đồ'),
(108254, 893, 29, 'Biểu đồ theo dõi'),
(108255, 894, 29, 'Biểu đồ TRK'),
(108256, 895, 29, 'Biểu đồ kiểm tra ra'),
(108257, 896, 29, 'Bảng xếp hạng Out'),
(108258, 898, 29, 'Kiểm tra'),
(108259, 899, 29, 'kiểm tra'),
(108260, 900, 29, 'Chọn tất cả'),
(108261, 902, 29, 'Kiểm tra Số tiền'),
(108262, 903, 29, 'Kiểm tra ngày'),
(108263, 904, 29, 'Kiểm tra sự khác biệt của bản dịch với bảng ngôn ngữ tùy chỉnh.'),
(108264, 906, 29, 'Đăng ký Để'),
(108265, 907, 29, 'Kiểm tra dữ liệu đầu vào'),
(108266, 908, 29, 'Kiểm tra các mục để vẽ đồ thị'),
(108267, 909, 29, 'Kiểm tra kết quả từ phòng thí nghiệm'),
(108268, 910, 29, 'Dấu kiểm là đã xem lại'),
(108269, 911, 29, 'Số Chi phiếu'),
(108270, 912, 29, 'Số Chi phiếu'),
(108271, 915, 29, 'Thanh toán bằng Chi phiếu'),
(108272, 916, 29, 'Đánh dấu hộp này nếu đây là một tập tin được mã hóa'),
(108273, 917, 29, 'Đánh dấu ở đây nếu bạn muốn theo mặc định các nhà cung cấp xem được tất cả các cuộc hẹn không chỉ của riêng mình.'),
(108274, 918, 29, 'Đánh dấu để tạo vấn đề cho chẩn đoán này'),
(108275, 919, 29, 'Ngày Chi phiếu / EOB:'),
(108276, 920, 29, 'Số Chi phiếu / EOB:'),
(108277, 921, 29, 'Số Chi phiếu / Tham khảo'),
(108278, 922, 29, 'Số Chi phiếu / Tham khảo'),
(108279, 923, 29, 'Danh sách hộp kiểm'),
(108280, 924, 29, 'hộp kiểm trong danh sách'),
(108281, 925, 29, 'hộp kiểm với văn bản'),
(108282, 926, 29, 'Hộp kiểm với văn bản'),
(108283, 927, 29, 'Các hộp kiểm bên trên cho biết bạn có muốn từ chố và xóa tập tin HL7 đó không.'),
(108284, 928, 29, 'Đã đánh dấu'),
(108285, 929, 29, 'Ô được đánh dấu = có, trống = không có'),
(108286, 931, 29, 'Đánh dấu vào hộp kiểm khóa sẽ ngăn việc sửa đổi sau này trên bắt kỳ biểu mẫu nào trong lần khám này.'),
(108287, 932, 29, 'Tính tiền'),
(108288, 933, 29, 'Tổng kiểm'),
(108289, 934, 29, 'Ngực'),
(108290, 935, 29, 'Ngực CTAB'),
(108291, 936, 29, 'Đau ngực'),
(108292, 937, 29, 'Đau ngực:'),
(108293, 938, 29, 'Cơn đau thắt ngực'),
(108294, 940, 29, 'CHG'),
(108295, 942, 29, 'Giám đốc khiếu nại'),
(108296, 943, 29, 'Con'),
(108297, 945, 29, 'Tình trạng tiêm chủng thời thơ ấu (CQM)'),
(108298, 946, 29, 'Ớn lạnh'),
(108299, 947, 29, 'Tiếng Trung Quốc'),
(108300, 948, 29, 'Chữ Trung Quốc (giản thể)'),
(108301, 949, 29, 'Chữ Trung Quốc (truyền thống)'),
(108302, 951, 29, 'Lựa chọn'),
(108303, 952, 29, 'Cắt túi mật'),
(108304, 953, 29, 'cắt túi mật'),
(108305, 954, 29, 'Cắt túi mật'),
(108306, 955, 29, 'Chọn'),
(108307, 956, 29, 'Chọn một phần và bấm vào một mục bên trong nó, sau đó trong các phần khác, bạn sẽ thấy các mục có liên quan được đánh dấu, và bạn có thể nhấp vào phần đó để thêm và xóa các mối quan hệ.'),
(108308, 957, 29, 'Chọn tiêu chí'),
(108309, 959, 29, 'Chọn Tập tin'),
(108310, 960, 29, 'Chọn từ danh sách'),
(108311, 961, 29, 'Chọn Hướng Bố trí'),
(108312, 962, 29, 'Chọn danh sách'),
(108313, 963, 29, 'Chọn Kích cỡ Giấy'),
(108314, 964, 29, 'Chọn Xác lập ngôn ngữ PDF'),
(108315, 965, 29, 'Chọn định dạng in cho báo cáo cuộc gặp gỡ này.'),
(108316, 967, 29, 'Viêm phế quản Mãn tính'),
(108317, 968, 29, 'Đau khớp mãn tính'),
(108318, 969, 29, 'Bệnh thận mãn tính (CKD)'),
(108319, 970, 29, 'Viêm màng hoạt dịch mãn tính / tràn dịch / liên đau / bệnh gút'),
(108320, 971, 29, 'Mãn tính / tái phát'),
(108321, 973, 29, 'Xơ gan'),
(108322, 974, 29, 'Xơ gan Of The gan'),
(108323, 975, 29, 'Thành phố'),
(108324, 976, 29, 'Tên thành phố'),
(108325, 977, 29, 'Thành phố, Tỉnh'),
(108326, 978, 29, 'Thành phố, Mã Tỉnh'),
(108327, 979, 29, 'Thành phố/ Tỉnh'),
(108328, 980, 29, 'yêu cầu'),
(108329, 981, 29, 'Yêu cầu '),
(108330, 982, 29, 'Tình trạng Yêu cầu'),
(108331, 983, 29, 'Yêu cầu bồi thường kiểm tra đã hoàn thành'),
(108332, 984, 29, 'Loại Yêu cầu'),
(108333, 985, 29, 'Yêu cầu bồi thường được tạo trong tập tin'),
(108334, 986, 29, 'Yêu cầu bồi thường được tạo trong tập tin '),
(108335, 987, 29, 'Yêu cầu'),
(108336, 988, 29, 'Phân loại'),
(108337, 989, 29, 'Xóa'),
(108338, 990, 29, 'BỎ CHỌN BỆNH NHÂN ĐANG CHỌN'),
(108339, 991, 29, 'Bỏ chọn tất cả'),
(108340, 992, 29, 'Rõ ràng HL7 dữ liệu'),
(108341, 993, 29, 'Rõ ràng Giải thích rõ'),
(108342, 994, 29, 'Xoá thông minh Cache'),
(108343, 995, 29, 'Thanh toán bù trừ nhà thông tin cần thiết để tạo EDI hàng loạt 270.'),
(108344, 996, 29, 'Số CLIA'),
(108345, 997, 29, 'Nhấp'),
(108346, 998, 29, 'Nhấp vào ''xuất khẩu'' để xuất khẩu mục, tiểu thể loại, khoản, dữ liệu nội dung vào một tập tin văn bản. Bất kỳ giống nhau của tập tin này vào một tập tin XML là hoàn toàn trùng hợp ngẫu nhiên. Các thẻ mở và đóng cửa phải là trên cùng một dòng, họ phải là chữ thường không có dấu cách. Để nhập khẩu, trình duyệt cho một tập tin và nhấp vào ''nhập khẩu''. Nếu dữ liệu là hoàn toàn khác nhau, nó sẽ kết hợp với các dữ liệu hiện có của bạn. Nếu có tên mục tương tự, một tuổi sẽ được lưu giữ và mới được lưu với một số được thêm vào cuối cùng.'),
(108347, 999, 29, 'Nhấp vào một điểm trên hình ảnh để thêm một chú thích mới, nhấp vào đó lần nữa để loại bỏ nó'),
(108348, 1000, 29, 'Nhấp vào Tải về Giấy chứng nhận để tải về các giấy chứng nhận trong tập tin ssl.zip'),
(108349, 1001, 29, 'nhấp vào để biết thêm'),
(108350, 1002, 29, 'Nhấp vào để có thêm chi tiết'),
(108351, 1003, 29, 'Nhấp vào để có tóm tắt đặt hàng'),
(108352, 1004, 29, 'Nhấp vào để có kết quả'),
(108353, 1005, 29, 'Nhấp vào đây'),
(108354, 1006, 29, 'Nhấp vào đây để thêm một bệnh nhân mới.'),
(108355, 1007, 29, 'Nhấp vào đây để thêm mới chấn thương, thay đổi tình trạng và chỉnh sửa hoạt động hàng ngày'),
(108356, 1008, 29, 'Nhấp vào đây để chọn một ngày'),
(108357, 1009, 29, 'Nhấp vào đây để chọn ngày và giờ'),
(108358, 1010, 29, 'Nhấp vào đây để chọn ngày bắt đầu'),
(108359, 1011, 29, 'Nhấp vào đây để chọn ngày giờ'),
(108360, 1012, 29, 'Nhấp vào đây để chọn ngày giờ bắt đầu'),
(108361, 1013, 29, 'Nhấp vào đây để chọn ngày giờ kết thúc'),
(108362, 1014, 29, 'Nhấp vào Đây để Xác lập Môdun này'),
(108363, 1016, 29, 'Nhấp vào Đây để Vô hiệu Môdun này'),
(108364, 1018, 29, 'Nhấp vào Đây để Kích hoạt Môdun này'),
(108365, 1019, 29, 'Nhấp vào Đây để Cài đặt Môdun này'),
(108366, 1020, 29, 'nhấp vào đây để tìm kiếm'),
(108367, 1021, 29, 'nhấp vào đây để cập nhật các thiết lập ưu tiên, thể loại và bí danh'),
(108368, 1022, 29, 'Nhấp vào đây để xem tất cả.'),
(108369, 1023, 29, 'Nhấp vào đây để xem và vẽ đồ thị'),
(108370, 1024, 29, 'Nhấp vào đây để xem và vẽ đồ thị tất cả dữ liệu nghiên cứu.'),
(108371, 1025, 29, 'Nhấp vào đây để xem và vẽ đồ thị tất cả các thể trạng.'),
(108372, 1026, 29, 'Nhấp vào đây để xem chi tiết bệnh nhân'),
(108373, 1027, 29, 'Nhấp vào đây để xem tất cả.'),
(108374, 1028, 29, 'Nhấp vào đây để xem/sửa các chi tiết khác'),
(108375, 1029, 29, 'Nhấp nút Cài đặt để cài đặt cơ sở dữ liệu phát hành từ ngày sau đây'),
(108376, 1030, 29, 'Nhấp chuột vào bất kỳ phần nào của thời gian để tăng nó'),
(108377, 1031, 29, 'Nhấp vào Tên Bệnh nhân để Mở Tập tin Bệnh nhân'),
(108378, 1032, 29, 'Nhấp vào Refresh để xem tất cả các kết quả, hay vui lòng nhập vào tiêu chí tìm kiếm ở trên để xem kết quả cụ thể.'),
(108379, 1033, 29, 'Nhấp để thêm chẩn đoán'),
(108380, 1034, 29, 'Nhấp  để thêm các thành phần mới'),
(108381, 1035, 29, 'Nhấp để thêm tham vấn ​​mới'),
(108382, 1036, 29, 'Nhấp để chọn chẩn đoán để khẳng định.'),
(108383, 1037, 29, 'Nhấp để tải về'),
(108384, 1038, 29, 'Nhấp để chỉnh sửa'),
(108385, 1039, 29, 'Nhấp để chỉnh sửa diễn giải'),
(108386, 1040, 29, 'Nhấp vào đây để chỉnh sửa sự kiện này'),
(108387, 1041, 29, 'Nhấp vào đây để tạo ra các báo cáo'),
(108388, 1042, 29, 'Nhấp để tìm bệnh nhân phù hợp'),
(108389, 1043, 29, 'Nhấp vào đây để in'),
(108390, 1044, 29, 'Nhấp vào đây để nhận được (thêm) lô thuốc mới'),
(108391, 1045, 29, 'Nhấp vào đây để chọn'),
(108392, 1046, 29, 'Nhấp vào đây Để Chọn'),
(108393, 1047, 29, 'Nhấp vào đây để chọn một mã số tiêu chuẩn công nghiệp cho thủ tục này'),
(108394, 1048, 29, 'Nhấp vào đây để chọn mã số thủ tục tùy chọn'),
(108395, 1049, 29, 'Nhấp để chọn hay đổi bộ mã'),
(108396, 1050, 29, 'Nhấp vào đây để chọn hoặc thay đổi mã CVX'),
(108397, 1051, 29, 'Nhấp vào đây để lựa chọn hoặc thay đổi chẩn đoán'),
(108398, 1052, 29, 'Nhấp vào đây để lựa chọn hoặc thay đổi mã số dịch vụ'),
(108399, 1053, 29, 'Nhấp vào đây để chọn bệnh nhân'),
(108400, 1054, 29, 'Nhấp vào đây để chọn mã liên quan'),
(108401, 1055, 29, 'Nhấp vào đây để lựa chọn dịch vụ để thực hiện nếu kết quả này là bất thường'),
(108402, 1056, 29, 'Nhấp vào đây để lựa chọn các thủ tục mong muốn'),
(108403, 1057, 29, 'Nhấp để sắp xếp'),
(108404, 1058, 29, 'Nhấp vào đây để xem'),
(108405, 1059, 29, 'Nhấp vào đây để xem hoặc chỉnh sửa'),
(108406, 1060, 29, 'Nhấp vào đây để xem / chỉnh sửa'),
(108407, 1061, 29, 'Nhấp Nâng cấp để nâng cấp cơ sở dữ liệu phát hành từ ngày sau đây'),
(108408, 1062, 29, 'Nhấp chỗ được chỉ ra ở trên để tìm bệnh nhân phù hợp.'),
(108409, 1063, 29, 'Nhấp vào:'),
(108410, 1064, 29, 'Ngày hết hạn Chứng chỉ Máy khách'),
(108411, 1065, 29, 'Thời gian hợp lệ của chứng chỉ máy khách'),
(108412, 1066, 29, 'Sự hợp lệ của chứng chỉ máy khách phải là một con số.'),
(108413, 1067, 29, 'Bản sao cho Khách hàng'),
(108414, 1069, 29, 'Tóm tắt lịch sử điều trị của khách hàng'),
(108415, 1070, 29, 'Tên Khách hàng'),
(108416, 1071, 29, 'Số Khách hàng'),
(108417, 1072, 29, 'Hồ sơ Khách hàng - Khách hàng Mới'),
(108418, 1073, 29, 'Hồ sơ khách hàng - Khách hàng độc đáo'),
(108419, 1074, 29, 'Khách hàng'),
(108420, 1075, 29, 'Phóng khám'),
(108421, 1076, 29, 'Bản sao của Phóng khám'),
(108422, 1077, 29, 'Ghi chép Hàng ngày của Phòng khám'),
(108423, 1078, 29, 'Mã Phòng khám'),
(108424, 1079, 29, 'Lâm sàng'),
(108425, 1080, 29, 'Quyết định Quy định lâm sàng Báo Cáo Quản lý'),
(108426, 1081, 29, 'Lịch sử Lâm sàng'),
(108427, 1083, 29, 'Kế hoạch Lâm sàng'),
(108428, 1084, 29, 'Chất lượng các Biện pháp Lâm sàng (CQM)'),
(108429, 1085, 29, 'Chất lượng các Biện pháp Lâm sàng (CQM) - 2011'),
(108430, 1086, 29, 'Chất lượng các Biện pháp Lâm sàng (CQM) - 2014'),
(108431, 1087, 29, 'Nhắc nhở Lâm sàng'),
(108432, 1088, 29, 'Báo cáo Lâm sàng'),
(108433, 1089, 29, 'Thể loại Quy tắc Hành động Lâm sàng'),
(108434, 1090, 29, 'Mục Quy tắc Hành động Lâm sàng'),
(108435, 1091, 29, 'Phương pháp lọc Rule lâm sàng'),
(108436, 1092, 29, 'Mục tiêu Phương pháp lâm sàng Rule'),
(108437, 1093, 29, 'Lâm sàng Rules'),
(108438, 1094, 29, 'Lâm sàng Rules Khoảng Tuổi'),
(108439, 1095, 29, 'Các quy tắc so sánh lâm sàng'),
(108440, 1096, 29, 'Các loại quy tắc khám lâm sàng'),
(108441, 1097, 29, 'Tùy chọn nhắc nhở các quy tắc lâm sàng'),
(108442, 1098, 29, 'Tùy chọn khử hoạt nhắc nhở các quy tắc lâm sàng'),
(108443, 1099, 29, 'Nhắc nhở lâm sàng Khoảng Rules'),
(108444, 1100, 29, 'Nhắc nhở lâm sàng phương pháp quy'),
(108445, 1101, 29, 'Lâm sàng Rules Khoảng mục tiêu'),
(108446, 1102, 29, 'Các mục tiêu Lâm sàng'),
(108447, 1106, 29, 'Bác sĩ lâm sàng'),
(108448, 1107, 29, 'Nhân bản'),
(108449, 1108, 29, 'Clone Khách quá khứ'),
(108450, 1109, 29, 'Đóng'),
(108451, 1110, 29, 'Đóng Cửa sổ'),
(108452, 1111, 29, 'đóng cửa sổ'),
(108453, 1112, 29, 'Đã đóng'),
(108454, 1113, 29, 'cm'),
(108455, 1114, 29, 'CMS 1500 Lợi nhuận'),
(108456, 1118, 29, 'Mã CMS'),
(108457, 1127, 29, 'CN2-12 còn nguyên vẹn'),
(108458, 1128, 29, 'Cùng Chi trả'),
(108459, 1129, 29, 'Đã Cùng Chi trả'),
(108460, 1130, 29, 'Cùng Chi trả'),
(108461, 1131, 29, 'Mã số'),
(108462, 1132, 29, 'Mã số'),
(108463, 1133, 29, 'Bộ tìm Mã số'),
(108464, 1134, 29, 'Mã phải là hai chữ cái viết thường'),
(108465, 1135, 29, 'Mã hoặc biểu tượng để chỉ tiền tệ'),
(108466, 1136, 29, 'Văn bản Mã'),
(108467, 1137, 29, 'loại mã'),
(108468, 1138, 29, 'loại mã'),
(108469, 1139, 29, 'Không nhận ra loại mã'),
(108470, 1140, 29, 'Chưa định nghĩa loại mã'),
(108471, 1141, 29, 'Loại Mã'),
(108472, 1142, 29, 'Mã'),
(108473, 1143, 29, 'Đã lập mã'),
(108474, 1144, 29, 'Mã số'),
(108475, 1145, 29, 'Mã hóa'),
(108476, 1146, 29, 'Đang mã (nhấp để học thêm)'),
(108477, 1147, 29, 'Mã hóa - bất kỳ cuộc gặp gỡ (viết, wsome tùy chọn)'),
(108478, 1148, 29, 'Mã hóa - cuộc gặp gỡ của tôi (viết, wsome tùy chọn)'),
(108479, 1149, 29, 'Mã hóa không được uỷ quyền'),
(108480, 1150, 29, 'Cà phê'),
(108481, 1151, 29, 'Dùng Cà phê'),
(108482, 1152, 29, 'Đồng bảo hiểm'),
(108483, 1153, 29, 'Sb w / o'),
(108484, 1154, 29, 'Thu gọn'),
(108485, 1155, 29, 'thu gọn'),
(108486, 1156, 29, 'Thu gọn Tất cả'),
(108487, 1157, 29, 'Thu gọn tất cả'),
(108488, 1158, 29, 'thu gọn tất cả'),
(108489, 1161, 29, 'Tổng hợp'),
(108490, 1162, 29, 'Tập hợp các Báo cáo'),
(108491, 1163, 29, 'Ung thư đại tràng'),
(108492, 1164, 29, 'Màn ảnh ung thư đại tràng'),
(108493, 1165, 29, 'Phẫu thuật ung thư đại tràng'),
(108494, 1166, 29, 'Nội soi đại tràng'),
(108495, 1167, 29, 'nội soi đại tràng'),
(108496, 1168, 29, 'Màu sắc'),
(108497, 1169, 29, 'Màu: abbr'),
(108498, 1170, 29, 'Cột'),
(108499, 1171, 29, 'Cột'),
(108500, 1172, 29, 'Phối hợp lô'),
(108501, 1173, 29, 'Dấu Phẩy'),
(108502, 1174, 29, 'Ghi chú'),
(108503, 1175, 29, 'Các ghi chú'),
(108504, 1176, 29, 'Ghi chú / Đề nghị cho kết quả này'),
(108505, 1177, 29, 'Công ty Bảo hiểm Thương mại'),
(108506, 1178, 29, 'Cam kết thay đổi'),
(108507, 1179, 29, 'Truyền thông'),
(108508, 1180, 29, 'Truyền thông'),
(108509, 1182, 29, 'Công ty'),
(108510, 1183, 29, 'Tên công ty'),
(108511, 1184, 29, 'Hoàn thành'),
(108512, 1186, 29, 'Hoàn thành'),
(108513, 1188, 29, 'Hoàn thành?'),
(108514, 1190, 29, 'Các biến chứng bằng cách cung cấp dịch vụ'),
(108515, 1191, 29, 'Các biến chứng của phá thai'),
(108516, 1192, 29, 'Thành phần'),
(108517, 1193, 29, 'Hệ thống đặt hàng Máy Tính y tế Trợ Giúp'),
(108518, 1194, 29, 'Kết luận'),
(108519, 1198, 29, 'Cấu hình'),
(108520, 1199, 29, 'Cấu hình'),
(108521, 1200, 29, 'Kết xuất / Kết nhập Cấu hình'),
(108522, 1201, 29, 'Đã lưu cấu hình thành công'),
(108523, 1202, 29, 'Cấu hình Apache và Imed EMR sử dụng giấy chứng nhận phía khách hàng SSL.'),
(108524, 1203, 29, 'Cấu hình Apache để sử dụng Khách hàng bên SSL giấy chứng nhận'),
(108525, 1204, 29, 'Cấu hình Apache để sử dụng HTTPS.'),
(108526, 1205, 29, 'Cấu hình LIBREEHR sử dụng Khách hàng bên SSL giấy chứng nhận'),
(108527, 1208, 29, 'Xác nhận bệnh nhân mới'),
(108528, 1209, 29, 'Xác nhận mật khẩu mới'),
(108529, 1210, 29, 'Xác nhận thanh toán'),
(108530, 1214, 29, 'Bẩm sinh'),
(108531, 1215, 29, 'Conjuntiva, học sinh'),
(108532, 1216, 29, 'Lỗi kết nối'),
(108533, 1217, 29, 'Các kết nối'),
(108534, 1218, 29, 'Không đổi'),
(108535, 1219, 29, 'không đổi tên'),
(108536, 1220, 29, 'Không đổi tên là trống'),
(108537, 1221, 29, 'hằng số'),
(108538, 1222, 29, 'Táo bón'),
(108539, 1223, 29, 'Trạng thái cơ thể'),
(108540, 1226, 29, 'Mô tả Tóm tắt Tư vấn'),
(108541, 1227, 29, 'Liên hệ'),
(108542, 1228, 29, 'Email liên lạc'),
(108543, 1229, 29, 'Liên hệ Địa chỉ Email'),
(108544, 1230, 29, 'Liên hệ EMR Direct để đăng ký dịch vụ gửi thông điệp phiMail Direct'),
(108545, 1231, 29, 'thông tin liên hệ'),
(108546, 1232, 29, 'Kính áp tròng'),
(108547, 1233, 29, 'Liên hệ Medical Information Integration, LLC tại http://mi-squared.com về Dịch vụ Trao đổi Thí nghiệm.'),
(108548, 1234, 29, 'Liên hệ Medical Information Integration, LLC tại http://mi-squared.com hay ZH Healthcare tại http://zhservices.com để đăng ký dịch vụ eRx service'),
(108549, 1236, 29, 'Tên liên hệ'),
(108550, 1237, 29, 'Người Liên hệ'),
(108551, 1238, 29, 'Điện thoại Liên hệ'),
(108552, 1239, 29, 'Số Điện thoại Liên hệ'),
(108553, 1240, 29, 'Liên hệ ZMG, LLC (zmghealth@gmail.com) để đăng ký dịch vụ eRx'),
(108554, 1241, 29, 'có ít nhất ba trong số bốn mục sau đây:'),
(108555, 1243, 29, 'Nội dung'),
(108556, 1244, 29, 'nội dung'),
(108557, 1245, 29, 'Bối cảnh'),
(108558, 1246, 29, 'Tên ngữ cảnh ''t có thể được sản phẩm nào'),
(108559, 1247, 29, 'Tiếp tục'),
(108560, 1248, 29, 'Tính liên tục của tài liệu chăm sóc (CCD)'),
(108561, 1249, 29, 'Tính liên tục của Ghi Chăm Sóc (CCR)'),
(108562, 1250, 29, 'điều chỉnh Khách hàng'),
(108563, 1251, 29, 'Tránh thai'),
(108564, 1252, 29, 'Vấn đề Tránh thai'),
(108565, 1253, 29, 'Biến chứng thai (ghi rõ)'),
(108566, 1254, 29, 'Phương pháp Tránh thai'),
(108567, 1255, 29, 'Sản phẩm Tránh thai'),
(108568, 1256, 29, 'Dịch vụ ngừa thai trước đó bắt đầu'),
(108569, 1257, 29, 'Bắt đầu Tránh thai'),
(108570, 1258, 29, 'Mã Kiểm soát'),
(108571, 1259, 29, 'Số Kiểm soát'),
(108572, 1261, 29, 'CÙNG CHI TRẢ'),
(108573, 1262, 29, 'Cùng chi trả'),
(108574, 1263, 29, 'Cùng chi trả'),
(108575, 1264, 29, 'Tiền phụ phí không tích cực'),
(108576, 1266, 29, 'Cùng chi trả'),
(108577, 1267, 29, 'COPD'),
(108578, 1268, 29, 'Sao chép các Trang vào Biểu đồ Bệnh nhân'),
(108579, 1269, 29, 'Sao chép các Giá trị'),
(108580, 1270, 29, 'Đang sao chép tập tin cơ sở dữ liệu. Cần thời gian để làm...'),
(108581, 1271, 29, 'Thông báo Bản quyền'),
(108582, 1273, 29, 'Động mạch vành Bypass'),
(108583, 1274, 29, 'Bypass ghép động mạch vành (CABG)'),
(108584, 1275, 29, 'Đã sửa chữa'),
(108585, 1277, 29, 'CouchDB'),
(108586, 1278, 29, 'Bị lỗi Kết nối tới CouchDB.'),
(108587, 1279, 29, 'Cơ sở dữ liệu CouchDB'),
(108588, 1280, 29, 'Tên cơ sở dữ liệu CouchDB'),
(108589, 1281, 29, 'Máy chủ CouchDB'),
(108590, 1282, 29, 'Tên máy chủ CouchDB'),
(108591, 1283, 29, 'Cho phép Ghi nhật ký CouchDB'),
(108592, 1284, 29, 'Mật khẩu CouchDB'),
(108593, 1285, 29, 'Cổng CouchDB'),
(108594, 1286, 29, 'Cổng CouchDB'),
(108595, 1288, 29, 'Tên Người dùng CouchDB'),
(108596, 1289, 29, 'Ho'),
(108597, 1290, 29, 'Ho:'),
(108598, 1294, 29, 'Không thể đọc tập tin'),
(108599, 1296, 29, 'Không thể gửi email do một vấn đề ở máy chủ, '),
(108600, 1297, 29, 'Không thể gửi email do một vấn đề ở máy chủ, '),
(108601, 1298, 29, 'Không thể tạo thư mục sao lưu:'),
(108602, 1299, 29, 'Không thể loại bỏ thư mục:'),
(108603, 1300, 29, 'Không thể loại bỏ tập tin sao lưu cũ:'),
(108604, 1301, 29, 'Không thể loại bỏ tập tin xuất khẩu cũ:'),
(108605, 1302, 29, 'Coumadin Quản lý - Giám sát INR'),
(108606, 1303, 29, 'Couns bằng phương pháp'),
(108607, 1304, 29, 'Tư vấn'),
(108608, 1305, 29, 'Tư vấn hoạt động'),
(108609, 1306, 29, 'MẪU CHỈ ĐỊNH ĐIỀU TRỊ'),
(108610, 1307, 29, 'Counter-Giới Thiệu'),
(108611, 1308, 29, 'Quốc gia'),
(108612, 1309, 29, 'Quốc gia Loại dữ liệu'),
(108613, 1310, 29, 'Quốc gia danh sách'),
(108614, 1311, 29, 'Danh sách quốc gia (viết, thêm tùy chọn)'),
(108615, 1312, 29, 'Quốc gia Tên có đại diện trong hai chữ cái. (Ví dụ: Việt Nam là VN)'),
(108616, 1313, 29, 'Tỉnh lỵ'),
(108617, 1315, 29, 'Phiếu giảm giá'),
(108618, 1318, 29, 'CPT'),
(108619, 1319, 29, 'Mã CPT'),
(108620, 1320, 29, 'Mã CPT'),
(108621, 1321, 29, 'Thủ tục / Dịch vụ CPT4'),
(108622, 1322, 29, 'Đo lường Hiệu năng CPTII'),
(108623, 1323, 29, 'CQM'),
(108624, 1324, 29, 'Crackles:'),
(108625, 1325, 29, 'kem'),
(108626, 1326, 29, 'Tạo ra một giấy chứng nhận Khách hàng bên SSL cho mỗi người dùng hoặc máy khách hàng.'),
(108627, 1327, 29, 'Tạo ra một giấy chứng nhận SSL phía khách hàng cho người sử dụng hoặc một khách hàng tên máy.'),
(108628, 1329, 29, 'Tạo một sự kiện'),
(108629, 1330, 29, 'Tạo và tải về một bản sao lưu đầy đủ'),
(108630, 1332, 29, 'Tạo sao lưu'),
(108631, 1333, 29, 'Tạo hàng loạt'),
(108632, 1334, 29, 'Giấy chứng nhận Khách hàng'),
(108633, 1335, 29, 'Tạo Khách hàng bên SSL giấy chứng nhận'),
(108634, 1336, 29, 'Tạo Bản sao chép'),
(108635, 1338, 29, 'Tạo bản Sao lưu Nhật ký sự kiện'),
(108636, 1339, 29, 'Tạo vấn đề mới'),
(108637, 1340, 29, 'Tạo Bệnh nhân Mới'),
(108638, 1342, 29, 'Tạo Giây chứng nhận ngoại vi Portal'),
(108639, 1343, 29, 'Tạo Giây chứng nhận Portal tại chỗ'),
(108640, 1344, 29, 'Lưu ý bệnh nhân'),
(108641, 1345, 29, 'Tạo Cơ quan Giấy chứng nhận SSL và chứng chỉ máy chủ.'),
(108642, 1346, 29, 'Tạo lần Đến khám'),
(108643, 1347, 29, 'Đã tạo'),
(108644, 1348, 29, 'Đang tạo tập tin kết xuất'),
(108645, 1351, 29, 'Đấng Tạo Hóa'),
(108646, 1352, 29, 'tín dụng'),
(108647, 1353, 29, 'Thẻ tín dụng'),
(108648, 1354, 29, 'Các khoản tín dụng'),
(108649, 1356, 29, 'Tiêu chuẩn'),
(108650, 1358, 29, 'Bệnh Crohn ''s'),
(108651, 1359, 29, 'Crohns bệnh'),
(108652, 1360, 29, 'CSV xuất khẩu'),
(108653, 1361, 29, 'Tệp tin CSV'),
(108654, 1362, 29, 'Bảng CSV'),
(108655, 1363, 29, 'CU.MM'),
(108656, 1364, 29, 'Cuban'),
(108657, 1365, 29, 'Số chữ số Thập phân Tiền tệ'),
(108658, 1366, 29, 'Dấu Thập phân Tiền tệ'),
(108659, 1367, 29, 'Biểu tượng Tiền tệ'),
(108660, 1368, 29, 'Dấu tách Hàng ngàn Tiền tệ'),
(108661, 1369, 29, 'Hiện tại'),
(108662, 1370, 29, 'Cồn hiện thời'),
(108663, 1371, 29, 'Tham khảo hiện thời'),
(108664, 1372, 29, 'Tiêu chuẩn hiện thời'),
(108665, 1373, 29, 'Màu đánh dấu ngày hiện thời'),
(108666, 1374, 29, 'Hiện đang còn hút thuốc mỗi ngày'),
(108667, 1375, 29, 'Hiện tại tên tập tin đã được thay đổi thành'),
(108668, 1376, 29, 'Hiện tại Hash'),
(108669, 1377, 29, 'Vị trí Hiện tại'),
(108670, 1378, 29, 'Thuốc Hiện tại'),
(108671, 1379, 29, 'Mật khẩu Hiện tại'),
(108672, 1380, 29, 'Bệnh nhân Hiện tại'),
(108673, 1382, 29, 'Hiện tại giải trí Thuốc'),
(108674, 1383, 29, 'Hiện đang còn hút thuốc không thường xuyên'),
(108675, 1386, 29, 'Đang hoạt động'),
(108676, 1387, 29, 'Đang chạy'),
(108677, 1388, 29, 'Hiện đang không có cơ sở.'),
(108678, 1389, 29, 'Hội chứng cushing'),
(108679, 1390, 29, 'Hội chứng Cushing'),
(108680, 1392, 29, 'Tuỳ chỉnh'),
(108681, 1393, 29, 'Tuỳ chỉnh đầu vào?'),
(108682, 1394, 29, 'Tuỳ chỉnh Bảng'),
(108683, 1396, 29, 'Mã CVX'),
(108684, 1397, 29, 'Ánh xạ Mã CVX'),
(108685, 1398, 29, 'Chủng ngừa CVX'),
(108686, 1399, 29, 'Chu kỳ'),
(108687, 1400, 29, 'CYP'),
(108688, 1401, 29, 'CYP tố'),
(108689, 1402, 29, 'CYP Báo cáo'),
(108690, 1403, 29, 'Czech'),
(108691, 1404, 29, 'D'),
(108692, 1405, 29, 'D & C'),
(108693, 1406, 29, 'D & E'),
(108694, 1407, 29, 'Ngày Sinh'),
(108695, 1408, 29, 'hàng ngày'),
(108696, 1409, 29, 'Bản ghi Hàng ngày'),
(108697, 1410, 29, 'Tiếng/Người Đan Mạch'),
(108698, 1411, 29, 'Dữ liệu tương tự đã có trong cơ sở dữ liệu, xin vui lòng thay đổi mã số và / hoặc mô tả'),
(108699, 1412, 29, 'Dữ liệu tương tự đã có trong cơ sở dữ liệu, hãy thay đổi tên liên tục'),
(108700, 1413, 29, 'Dữ liệu cột'),
(108701, 1416, 29, 'Lỗi Dữ liệu'),
(108702, 1420, 29, 'Loại Dữ liệu'),
(108703, 1421, 29, 'Cơ sở dữ liệu'),
(108704, 1422, 29, 'Cơ sở dữ liệu không được cài đặt.'),
(108705, 1423, 29, 'Vá lỗi Cơ sở dữ liệu'),
(108706, 1424, 29, 'Việc báo cáo Cơ sở dữ liệu'),
(108707, 1425, 29, 'Đã hoàn thành nâng cấp cơ sở dữ liệu.'),
(108708, 1426, 29, 'DataCols phải là một số giữa 1 và 999'),
(108709, 1427, 29, 'Ngày'),
(108710, 1428, 29, 'NGÀY'),
(108711, 1431, 29, 'Ngày được quản lý'),
(108712, 1432, 29, 'Ngày và giờ của lần lấy mẫu'),
(108713, 1433, 29, 'Ngày và giờ của lần quan sát này'),
(108714, 1435, 29, 'Ngày và giờ mà mẫu được lấy'),
(108715, 1436, 29, 'Ngày không được lớn hơn Hôm nay'),
(108716, 1437, 29, 'Ngày các dịch vụ tránh thai được bắt đầu cung cấp.'),
(108717, 1438, 29, 'Ngày Tạo'),
(108718, 1439, 29, 'Ngày Qua đời'),
(108719, 1440, 29, 'Ngày Hủy'),
(108720, 1441, 29, 'Định dạng Hiển thị Ngày'),
(108721, 1442, 29, '"Kết thúc cuộc hẹn" có định dạng ngày không hợp lệ'),
(108722, 1443, 29, '"Bắt đầu cuộc hẹn" có định dạng ngày không hợp lệ'),
(108723, 1444, 29, '"Cuộc hẹn Tiếp theo" có định dạng ngày không hợp lệ'),
(108724, 1445, 29, '"Chưa từng thấy từ" có định dạng ngày không hợp lệ'),
(108725, 1446, 29, '"Đã thấy từ" có định dạng ngày không hợp lệ'),
(108726, 1447, 29, 'Ngày Chủng Ngừa Thông tin Báo cáo Với'),
(108727, 1448, 29, 'Thiếu ngày cho mã số '),
(108728, 1449, 29, 'Tiêu chuẩn Ngày Chủ đạo'),
(108729, 1450, 29, 'Ngày gửi tiền vào ngân hàng năm-tháng-ngày'),
(108730, 1451, 29, 'Ngày Lập hóa đơn'),
(108731, 1452, 29, 'Ngày Sinh'),
(108732, 1453, 29, 'Ngày sinh'),
(108733, 1454, 29, 'Ngày sinh'),
(108734, 1455, 29, 'Ngày của Đầu mục'),
(108735, 1456, 29, 'Ngày Bị thương tích'),
(108736, 1458, 29, 'Ngày thanh toán năm-tháng-ngày'),
(108737, 1459, 29, 'Ngày giới thiệu'),
(108738, 1460, 29, 'Ngày trả lời'),
(108739, 1462, 29, 'Ngày Dịch vụ'),
(108740, 1463, 29, 'Ngày Dịch vụ'),
(108741, 1464, 29, 'Ngày Dịch vụ = Hôm nay'),
(108742, 1465, 29, 'Ngày dịch vụ tháng/ngày/năm'),
(108743, 1466, 29, 'Ngày Dịch vụ:'),
(108744, 1467, 29, 'Ngày Ký'),
(108745, 1469, 29, 'Ngày của đơn hàng này'),
(108746, 1470, 29, 'Ngày của báo cáo này'),
(108747, 1471, 29, 'Ngày Tuyên bố VIS'),
(108748, 1472, 29, 'Ngày yêu cầu'),
(108749, 1475, 29, 'Bộ chọn ngày'),
(108750, 1476, 29, 'Ngày Gửi'),
(108751, 1477, 29, 'Ngày đã Gửi TIn nhắn'),
(108752, 1479, 29, 'Không thể để trống giá trị ngày.'),
(108753, 1480, 29, 'Ngày / Hẹn'),
(108754, 1481, 29, 'Ngày / Ghi chú'),
(108755, 1482, 29, 'Ngày / Ghi chú của cuối'),
(108756, 1483, 29, 'Ngày / Giờ'),
(108757, 1484, 29, 'Ngày:'),
(108758, 1485, 29, 'Bản ghi Tin nhắn có Ngày'),
(108759, 1486, 29, 'Ngày'),
(108760, 1487, 29, 'ngày'),
(108761, 1489, 29, 'Xem theo ngày'),
(108762, 1490, 29, 'Ngày'),
(108763, 1491, 29, 'Ngày M-F'),
(108764, 1492, 29, 'ngày'),
(108765, 1493, 29, 'Ngày'),
(108766, 1494, 29, 'ngày trước'),
(108767, 1495, 29, 'Bỏ lỡ Ngày và Trò chơi'),
(108768, 1496, 29, 'Ngày từ lần khám trước'),
(108769, 1497, 29, 'Ngày bị bỏ lỡ'),
(108770, 1498, 29, 'Ngày mỗi cột:'),
(108771, 1500, 29, 'Ngày / Cột:'),
(108772, 1501, 29, 'đã cài CSDL'),
(108773, 1502, 29, 'DD / MM / YYYY'),
(108774, 1503, 29, 'De Xác định'),
(108775, 1504, 29, 'De Quy trình Xác định được hoàn thành'),
(108776, 1505, 29, 'De Xác định quá trình đang diễn ra'),
(108777, 1506, 29, 'De quá trình nhận dạng được bắt đầu và đang chạy trong nền'),
(108778, 1507, 29, 'De dữ liệu đã xác định có thể không đầy đủ'),
(108779, 1508, 29, 'De-nhận dạng các tập tin sẽ được lưu trong'),
(108780, 1509, 29, 'DEA'),
(108781, 1511, 29, 'Điếc'),
(108782, 1512, 29, 'Gỡ rối Thông tin'),
(108783, 1515, 29, 'Tháng Mười hai'),
(108784, 1516, 29, 'CHẾT'),
(108785, 1517, 29, 'Tháng Mười hai'),
(108786, 1520, 29, 'Được khấu trừ'),
(108787, 1521, 29, 'Được khấu trừ Met'),
(108788, 1522, 29, 'Mặc định'),
(108789, 1523, 29, 'Cách xem Lịch Mặc định'),
(108790, 1524, 29, 'Mã Biểu mẫu Lần khám Mặc định'),
(108791, 1526, 29, 'Cơ sở Mặc định'),
(108792, 1527, 29, 'Ngôn ngữ Mặc định'),
(108793, 1528, 29, 'Ngôn ngữ mặc định nếu không có ngôn ngữ khác được cho phép hoặc lựa chọn.'),
(108794, 1529, 29, 'Danh sách mặc định (tùy chọn cho ghi, chỉ được thêm)'),
(108795, 1530, 29, 'Phương pháp Mặc định'),
(108796, 1531, 29, 'Ngày hết hạn mật khẩu mặc định'),
(108797, 1532, 29, 'Mặc định mật khẩu hết hạn thời gian trong ngày. 0 có nghĩa là tính năng này bị vô hiệu hóa.'),
(108798, 1533, 29, 'Quốc gia Mặc định của Bệnh nhân'),
(108799, 1536, 29, 'Nhà cung cấp Mặc định'),
(108800, 1537, 29, 'Phạm vi Mặc định'),
(108801, 1538, 29, 'Lý do Mặc định cho Lần khám'),
(108802, 1540, 29, 'Thiết lập mặc định'),
(108803, 1541, 29, 'Trạng thái mặc định của hộp chọn Cửa sổ Mới trong danh sách bệnh nhân.'),
(108804, 1542, 29, 'Khuôn mẫu Mặc định'),
(108805, 1546, 29, 'Đơn vị Mặc định'),
(108806, 1547, 29, 'Giá trị Mặc định'),
(108807, 1548, 29, 'Kho hàng Mặc định'),
(108808, 1549, 29, 'X12 Đối tác Mặc định'),
(108809, 1550, 29, 'Mặc định / Toàn bộ'),
(108810, 1551, 29, 'Del'),
(108811, 1552, 29, 'del'),
(108812, 1553, 29, 'Tái phát trễ (> 12 Tháng)'),
(108813, 1554, 29, 'Xóa'),
(108814, 1555, 29, 'xóa'),
(108815, 1556, 29, 'Xóa danh mục với ID (s): '),
(108816, 1557, 29, 'Xóa Thể loại'),
(108817, 1560, 29, 'Xóa Nhóm'),
(108818, 1561, 29, 'Xóa Danh sách'),
(108819, 1562, 29, 'Xóa trang'),
(108820, 1563, 29, 'Xóa bệnh nhân, Encounter, Mẫu, Số, tài liệu, thanh toán, Thanh toán hoặc giao dịch'),
(108821, 1565, 29, 'Xóa dòng'),
(108822, 1566, 29, 'Xóa mục được chọn'),
(108823, 1568, 29, 'Xóa thành công.'),
(108824, 1569, 29, 'Xóa tài liệu này'),
(108825, 1570, 29, 'Xóa hình thức này'),
(108826, 1571, 29, 'Xóa ghi chú'),
(108827, 1573, 29, 'Đã xoá thành công.'),
(108828, 1575, 29, 'Không thể hủy bỏ việc xóa sự kiện này. Nó không thể được khôi phục một khi đã bị xóa. Bạn có chắc chắn muốn xóa sự kiện này không?'),
(108829, 1581, 29, 'Sa sút trí tuệ'),
(108830, 1582, 29, 'Thông tin cá nhân'),
(108831, 1583, 29, 'Thông tin cá nhân (tùy chọn cho ghi, chỉ được thêm)'),
(108832, 1585, 29, 'Tiêu chí lọc thông tin cá nhân'),
(108833, 1586, 29, 'Không cho thông tin cá nhân.'),
(108834, 1587, 29, 'Không cho thông tin cá nhân.'),
(108835, 1588, 29, 'Từ chối'),
(108836, 1589, 29, 'Mẫu số'),
(108837, 1590, 29, 'Nha khoa'),
(108838, 1592, 29, 'Nha khoa Các vấn đề'),
(108839, 1595, 29, 'Tùy thuộc vào loại hóa đơn bạn đang thử nghiệm, bạn sẽ thấy HCFA như sản lượng trên một trang trắng cho các hóa đơn HCFA, bạn sẽ thấy nhiều dòng văn bản và thông tin phần nào bị cắt xén nếu bạn đang thử nghiệm một yêu cầu bồi thường X12. Đó văn bản bị cắt xén các định dạng X12 EDI 4010A. Đôi khi bạn sẽ thấy các nhân vật kỳ lạ trông giống như cờ domino hoặc squiglies, đây là những ký tự điều khiển như nguồn cấp dữ liệu trang và là bình thường.'),
(108840, 1596, 29, 'Tiền gửi ngày'),
(108841, 1597, 29, 'Tiền gửi ngày không được lớn hơn Hôm nay'),
(108842, 1598, 29, 'Gửi ngày:'),
(108843, 1599, 29, 'Chán nản'),
(108844, 1600, 29, 'Trầm cảm'),
(108845, 1602, 29, 'Mô tả'),
(108846, 1603, 29, 'mô tả'),
(108847, 1605, 29, 'Mô tả của các Tiết lộ'),
(108848, 1606, 29, 'Mô tả của mã này thủ tục hoặc kết quả'),
(108849, 1607, 29, 'Bản dịch của Mô tả'),
(108850, 1609, 29, 'Điểm đến'),
(108851, 1610, 29, 'Điểm đến Filename'),
(108852, 1611, 29, 'Destroy Nhiều'),
(108853, 1612, 29, 'Phá hủy ...'),
(108854, 1613, 29, 'Bị tiêu hủy'),
(108855, 1614, 29, 'Thuốc bị tiêu hủy'),
(108856, 1615, 29, 'Báo cáo Thuốc đã bị Tiêu hủy'),
(108857, 1616, 29, 'Xem chi tiết'),
(108858, 1617, 29, 'Thông tin chi tiết'),
(108859, 1619, 29, 'Phát triển bất thường'),
(108860, 1620, 29, 'Bệnh tiểu đường'),
(108861, 1621, 29, 'Đái tháo đường'),
(108862, 1622, 29, 'Bệnh tiểu đường: Quản lý Huyết Áp (CQM)'),
(108863, 1623, 29, 'Bệnh tiểu đường: Kiểm tra Mắt'),
(108864, 1624, 29, 'Bệnh tiểu đường: Kiểm tra Mắt (CQM)'),
(108865, 1625, 29, 'Bệnh tiểu đường: Kiểm tra Chân'),
(108866, 1626, 29, 'Bệnh tiểu đường: Kiểm tra Chân (CQM)'),
(108867, 1627, 29, 'Bệnh tiểu đường: HbA1c Poor Control (CQM)'),
(108868, 1628, 29, 'Bệnh tiểu đường: Hemoglobin A1c'),
(108869, 1629, 29, 'Bệnh tiểu đường: Quản lý và Kiểm soát LDL (CQM)'),
(108870, 1630, 29, 'Bệnh tiểu đường: Urine Microalbumin'),
(108871, 1631, 29, 'Chẩn đoán'),
(108872, 1633, 29, 'Chẩn đoán'),
(108873, 1634, 29, 'Mã Chẩn đoán');
INSERT INTO `lang_definitions` VALUES
(108874, 1636, 29, 'Ngày Chẩn đoán'),
(108875, 1637, 29, 'Chẩn đoán phải được mã hóa thành một cuộc gặp gỡ liên kết'),
(108876, 1638, 29, 'Tên Chẩn đoán'),
(108877, 1639, 29, 'Báo cáo Chẩn đoán'),
(108878, 1640, 29, 'Việc báo cáo Chẩn đoán'),
(108879, 1641, 29, 'Chỉ Báo cáo Chẩn đoán'),
(108880, 1642, 29, 'Tiêu đề Chẩn đoán'),
(108881, 1643, 29, 'Chẩn đoán:'),
(108882, 1644, 29, 'Chẩn đoán: '),
(108883, 1645, 29, 'Xét nghiệm chẩn đoán:'),
(108884, 1646, 29, 'Quay'),
(108885, 1647, 29, 'Màng ngăn / mũ'),
(108886, 1648, 29, 'Tiêu chảy'),
(108887, 1650, 29, 'Lời dặn'),
(108888, 1651, 29, 'Lời dặn: '),
(108889, 1652, 29, 'Bạn có nhận được một bản sao của Thông Báo HIPAA?'),
(108890, 1653, 29, 'Diffuse:'),
(108891, 1654, 29, 'Đã ký Chữ ký số'),
(108892, 1657, 29, 'Thư trực tiếp'),
(108893, 1663, 29, 'Tên Giám đốc'),
(108894, 1665, 29, 'Người khuyết tật'),
(108895, 1667, 29, 'Vô hiệu hoá Lịch'),
(108896, 1668, 29, 'Vô hiệu hoá Tracker Chart'),
(108897, 1669, 29, 'Vô hiệu hoá Chủng ngừa'),
(108898, 1670, 29, 'Vô hiệu hoá Biểu mẫu Thể trạng Hệ mét Cũ'),
(108899, 1672, 29, 'Vô hiệu hoá phpMyAdmin'),
(108900, 1673, 29, 'Vô hiệu hoá Đơn thuốc'),
(108901, 1674, 29, 'Vô hiệu hóa các Nhóm Người dùng'),
(108902, 1675, 29, 'vô hiệu hóa'),
(108903, 1676, 29, 'Vô hiệu hóa'),
(108904, 1678, 29, 'DISC'),
(108905, 1681, 29, 'Mủ'),
(108906, 1682, 29, 'Mủ Từ Niệu đạo'),
(108907, 1684, 29, 'Xả phải'),
(108908, 1685, 29, 'Xả phải:'),
(108909, 1689, 29, 'Công bố thông tin'),
(108910, 1690, 29, 'Tiết lộ Loại'),
(108911, 1691, 29, 'Tiết lộ loại'),
(108912, 1692, 29, 'Tiết Lộ'),
(108913, 1694, 29, 'Giảm giá'),
(108914, 1695, 29, 'Số lượng Giá giảm'),
(108915, 1696, 29, 'Mức Giảm giá'),
(108916, 1697, 29, 'Phần trăm Giảm giá'),
(108917, 1698, 29, 'Giá giảm là Số lượng Tiền tệ'),
(108918, 1699, 29, 'Giá giảm tại thời điểm thanh toán được nhập vào là số tiền, ngược lại với tỷ lệ phần trăm.'),
(108919, 1700, 29, 'Rời rạc Kết quả'),
(108920, 1701, 29, 'Bệnh'),
(108921, 1702, 29, 'Phân chia'),
(108922, 1703, 29, 'Số lượng'),
(108923, 1704, 29, 'Công văn'),
(108924, 1705, 29, 'Công văn tài liệu nhận'),
(108925, 1706, 29, 'Phân phát'),
(108926, 1707, 29, 'Hiển thị các chỉ thị nâng cao trong trang thông tin cá nhân.'),
(108927, 1709, 29, 'Hiển thị ngày sự kiện trong khối?'),
(108928, 1711, 29, 'Hiển thị có bao nhiêu sự kiện?'),
(108929, 1713, 29, 'Hiển thị vị trí trong khối?'),
(108930, 1714, 29, 'Hiển thị Tên'),
(108931, 1715, 29, 'Hiển thị lịch?'),
(108932, 1718, 29, 'Hiển thị ngày hôm nay của các sự kiện trong khối ?'),
(108933, 1719, 29, 'Hiển thị chủ đề trong khối?'),
(108934, 1720, 29, 'Hiển thị các sự kiện sắp tới trong khối?'),
(108935, 1721, 29, 'Hiển thị cột'),
(108936, 1722, 29, 'Hiển thị số lượng của hầu hết các tiết lộ gần đây như sau:'),
(108937, 1723, 29, 'Hiển thị số lượng sau đây của hầu hết các ghi chú gần đây'),
(108938, 1724, 29, 'Hiển thị số lượng của hầu hết các ghi chú gần đây như sau:'),
(108939, 1725, 29, 'Phân phối'),
(108940, 1726, 29, 'Phân phối'),
(108941, 1727, 29, 'Nhà phân phối'),
(108942, 1729, 29, 'Viêm túi thừa'),
(108943, 1730, 29, 'Viêm túi thừa Phẫu thuật'),
(108944, 1731, 29, 'Divirticulitis'),
(108945, 1732, 29, 'Divirticulitis Phẫu thuật'),
(108946, 1733, 29, 'Ly hôn'),
(108947, 1734, 29, 'Chóng mặt:'),
(108948, 1735, 29, 'Không được thay đổi'),
(108949, 1737, 29, 'Không hiển thị Dị ứng đã tải lên NewCorp'),
(108950, 1739, 29, 'Không hiển thị Điều trị đã tải lên NewCorp'),
(108951, 1742, 29, 'Không hiển thị lịch.'),
(108952, 1744, 29, 'Không kiểm kê và bán bất kỳ sản phẩm nào'),
(108953, 1745, 29, 'Không yêu cầu xác thực ghi chú của bệnh nhân'),
(108954, 1746, 29, 'Không Làm tỉnh Order'),
(108955, 1747, 29, 'không lưu'),
(108956, 1748, 29, 'không thay thế'),
(108957, 1749, 29, 'không làm gì cả'),
(108958, 1751, 29, 'Bạn có thực sự muốn xóa'),
(108959, 1752, 29, 'Bạn có thực sự muốn xóa các lựa chọn?'),
(108960, 1753, 29, 'Bạn có thực sự muốn xóa nhóm này'),
(108961, 1755, 29, 'Bạn có muốn tiếp tục không?'),
(108962, 1756, 29, 'Bạn có muốn xóa này?'),
(108963, 1757, 29, 'Bạn có muốn xoá không?'),
(108964, 1758, 29, 'Bạn có muốn loại bỏ hồ sơ này?'),
(108965, 1759, 29, 'Bạn có muốn tiếp tục bổ sung thêm bệnh nhân mới này?'),
(108966, 1760, 29, 'Bạn có muốn tiếp tục với tên mới?'),
(108967, 1761, 29, 'Bạn có muốn vĩnh viễn xóa hồ sơ chủng ngừa này?'),
(108968, 1762, 29, 'Ngày Sinh'),
(108969, 1763, 29, 'Không có Ngày Sinh, vui lòng nhập nếu có thể'),
(108970, 1764, 29, 'Tài liệu'),
(108971, 1765, 29, 'Bác sĩ'),
(108972, 1766, 29, 'Bác sĩ:'),
(108973, 1767, 29, 'Tên và chữ ký của bác sĩ'),
(108974, 1768, 29, 'Tài liệu'),
(108975, 1769, 29, 'tài liệu'),
(108976, 1770, 29, 'Thể loại Tài liệu'),
(108977, 1775, 29, 'Tài liệu không thể chuyển được id bệnh nhân'),
(108978, 1777, 29, 'Ngày giấy tờ'),
(108979, 1778, 29, 'Ngày giấy tờ và vấn đề cập nhật thành công'),
(108980, 1779, 29, 'Tài liệu ID'),
(108981, 1780, 29, 'Tài liệu chuyển thể loại mới'),
(108982, 1781, 29, 'Tài liệu chuyển id bệnh nhân'),
(108983, 1783, 29, 'Tài liệu thông qua kiểm tra tính toàn vẹn.'),
(108984, 1784, 29, 'Phương thức Lưu trữ Tài liệu'),
(108985, 1785, 29, 'Đã đổi tên tài liệu thành công.'),
(108986, 1790, 29, 'Lưu trữ tài liệu / hình ảnh'),
(108987, 1791, 29, 'Tài liệu'),
(108988, 1792, 29, 'Tài liệu (viết, addonly tùy chọn)'),
(108989, 1794, 29, 'DOE'),
(108990, 1798, 29, 'Loại này có cho phép các mã liên quan không?'),
(108991, 1799, 29, 'Trong nước Đối tác'),
(108992, 1800, 29, 'Không lưu lại'),
(108993, 1801, 29, 'Don ''t Save'),
(108994, 1802, 29, 'Don ''t Lưu Thay đổi'),
(108995, 1803, 29, 'Đã xong'),
(108996, 1804, 29, 'Đã xong với:'),
(108997, 1805, 29, 'Đã xong. Bây giờ sẽ gửi bản tải xuống.'),
(108998, 1806, 29, 'DOS'),
(108999, 1807, 29, 'Liều dùng'),
(109000, 1809, 29, 'nhấp đúp chuột vào để chỉnh sửa'),
(109001, 1810, 29, 'Quáng gà'),
(109002, 1811, 29, 'Tải về'),
(109003, 1814, 29, 'Tải về bất cứ lúc nào'),
(109004, 1815, 29, 'Tải tập tin thanh toán, gửi kế toán và nhãn hiệu như lập hoá đơn'),
(109005, 1817, 29, 'Tải về Giấy chứng nhận'),
(109006, 1818, 29, 'Tải dữ liệu cấu hình về'),
(109007, 1820, 29, 'tải tập tin được mã hóa về'),
(109008, 1827, 29, 'Tải Các báo cáo Được lựa chọn về'),
(109009, 1828, 29, 'Tiến sĩ Kiểm tra'),
(109010, 1829, 29, 'Tiến sĩ Chơi'),
(109011, 1830, 29, 'Tiến sĩ'),
(109012, 1831, 29, 'Kéo để di chuyển'),
(109013, 1832, 29, 'Đái láu'),
(109014, 1833, 29, 'Giấy phép Lái xe hoặc Số căn cước Tiểu bang'),
(109015, 1834, 29, 'Thuốc'),
(109016, 1835, 29, 'Thuốc Finder'),
(109017, 1836, 29, 'Thuốc Các hình thức'),
(109018, 1837, 29, 'Thiếu Mã Thuốc!'),
(109019, 1838, 29, 'Thời khoảng dùng Thuốc'),
(109020, 1839, 29, 'Thuốc tồn kho'),
(109021, 1840, 29, 'Tên Thuốc'),
(109022, 1841, 29, 'Thuốc Tuyến đường'),
(109023, 1845, 29, 'Thuốc đơn vị'),
(109024, 1846, 29, 'Thuốc'),
(109025, 1847, 29, 'Thuốc và các sản phẩm'),
(109026, 1848, 29, 'Khô Miệng'),
(109027, 1849, 29, 'Chẩn đoán DSMIV'),
(109028, 1850, 29, 'DT 1'),
(109029, 1851, 29, 'DT 2'),
(109030, 1852, 29, 'DT 3'),
(109031, 1853, 29, 'DT 4'),
(109032, 1854, 29, 'DT 5'),
(109033, 1855, 29, 'DTaP 1'),
(109034, 1856, 29, 'DTaP 2'),
(109035, 1857, 29, 'DTaP 3'),
(109036, 1858, 29, 'DTaP 4'),
(109037, 1859, 29, 'DTaP 5'),
(109038, 1860, 29, 'Nợ'),
(109039, 1861, 29, 'Ngày Tới hạn:'),
(109040, 1862, 29, 'Ngày tới hạn dạng tháng/ngày/năm hoặc năm-tháng-ngày'),
(109041, 1863, 29, 'Ngày Tới hạn:'),
(109042, 1864, 29, 'Nợ BH'),
(109043, 1865, 29, 'Nợ Pt'),
(109044, 1866, 29, 'Sắp Đến hạn'),
(109045, 1867, 29, 'Tình trạng Nợ'),
(109046, 1868, 29, 'Cập nhật Tình trạng Nợ'),
(109047, 1869, 29, 'Đang chép Cơ sở dữ liệu LibreEHR'),
(109048, 1870, 29, 'Đang chép cây thư mục web LibreEHR'),
(109049, 1871, 29, 'Đang chép cơ sở dữ liệu phpGACL'),
(109050, 1872, 29, 'Đang chép cây thư mục web phpGACL'),
(109051, 1873, 29, 'Đang chép cơ sở dữ liệu SQL-Ledger'),
(109052, 1874, 29, 'Đang chép cây thư mục web SQL-Ledger'),
(109053, 1875, 29, 'Kiểm tra Trùng lặp'),
(109054, 1876, 29, 'Trùng lặp ID trên dòng'),
(109055, 1877, 29, 'Trùng lặp tên trên dòng'),
(109056, 1878, 29, 'CẢNH BÁO TRÙNG LẬP'),
(109057, 1879, 29, 'Durable điện của Luật sư'),
(109058, 1880, 29, 'thời gian'),
(109059, 1881, 29, 'Thời gian'),
(109060, 1882, 29, 'Hà Lan'),
(109061, 1883, 29, 'Dx Rep'),
(109062, 1884, 29, 'Chứng khó nuốt'),
(109063, 1885, 29, 'Khó thở:'),
(109064, 1886, 29, 'Tiểu khó'),
(109065, 1888, 29, 'E-Prescription?'),
(109066, 1890, 29, 'e-Rx'),
(109067, 1892, 29, 'Đổi mới e-Rx'),
(109068, 1893, 29, 'Mỗi người dùng phải đặt tin nhắn của bản thân họ là hoàn thành.'),
(109069, 1894, 29, 'Tái phát nhanh (<2 Tháng)'),
(109070, 1895, 29, 'Tai'),
(109071, 1896, 29, 'ECG'),
(109072, 1897, 29, 'eClaims'),
(109073, 1898, 29, 'Phù'),
(109074, 1902, 29, 'Tải lên Tập tin EDI-271'),
(109075, 1903, 29, 'Tải lên Tập tin Phản hồi EDI-271'),
(109076, 1904, 29, 'Chỉnh sửa'),
(109077, 1905, 29, 'chỉnh sửa'),
(109078, 1906, 29, 'Chỉnh sửa Dị ứng'),
(109079, 1907, 29, 'Chỉnh sửa Thể loại'),
(109080, 1908, 29, 'Chỉnh sửa Định nghĩa'),
(109081, 1909, 29, 'Chỉnh sửa các định nghĩa'),
(109082, 1910, 29, 'Chỉnh sửa Chẩn đoán'),
(109083, 1911, 29, 'Chỉnh sửa Tiết lộ'),
(109084, 1912, 29, 'Chỉnh sửa Cơ sở'),
(109085, 1913, 29, 'Chỉnh sửa Cơ sở'),
(109086, 1914, 29, 'Chỉnh sửa Thông tin Cơ sở'),
(109087, 1915, 29, 'Chỉnh sửa Thông tin Người dùng Riêng cho Cơ sở'),
(109088, 1916, 29, 'Chỉnh sửa Tập tin trong'),
(109089, 1917, 29, 'Chỉnh sửa biểu mẫu'),
(109090, 1918, 29, 'Chỉnh sửa Cài đặt toàn cầu'),
(109091, 1919, 29, 'Không được phép chỉnh sửa!'),
(109092, 1920, 29, 'Chỉnh sửa bố trí'),
(109093, 1921, 29, 'Chỉnh sửa danh sách'),
(109094, 1922, 29, 'Chỉnh sửa Thanh toán'),
(109095, 1923, 29, 'Chỉnh sửa Cấu trúc'),
(109096, 1924, 29, 'Chỉnh sửa Người dùng'),
(109097, 1925, 29, 'Chỉnh sửa Xác lập Người dùng'),
(109098, 1928, 29, 'Giáo dục'),
(109099, 1929, 29, 'Giáo dục ngày'),
(109100, 1931, 29, 'ee * GNU General Public License để biết thêm chi tiết. ** Bạn nên đã nhận được một bản sao của * Giấy phép Công cộng GNU cùng với chương trình này, nếu không, viết thư cho các miễn phí '),
(109101, 1932, 29, 'Ngày có hiệu lực'),
(109102, 1934, 29, 'Hiệu quả'),
(109103, 1935, 29, 'EIN'),
(109104, 1936, 29, 'Xuất tinh'),
(109105, 1937, 29, 'Khuỷu tay'),
(109106, 1938, 29, 'Elbow vấn đề'),
(109107, 1939, 29, 'Điện tử'),
(109108, 1942, 29, 'Điện tử Remits'),
(109109, 1944, 29, 'Đủ điều kiện'),
(109110, 1945, 29, 'Đủ điều kiện 270 Inquiry hàng loạt'),
(109111, 1946, 29, 'Đủ điều kiện đáp ứng'),
(109112, 1947, 29, 'Tình trạng hội đủ điều kiện cho vắc xin cho trẻ em cung cấp vắc-xin'),
(109113, 1948, 29, 'Đủ điều kiện'),
(109114, 1949, 29, 'Email'),
(109115, 1951, 29, 'Địa chỉ Email'),
(109116, 1953, 29, 'Địa chỉ email của người gửi để nhắc nhở bệnh nhân. Trả lời nhắc nhở bệnh nhân sẽ được hướng dẫn đến địa chỉ này. Điều quan trọng là sử dụng một địa chỉ từ phòng khám của bạn ''s miền để tránh giúp ngăn ngừa nhắc nhở bệnh nhân đi đến các thư mục thư rác.'),
(109117, 1954, 29, 'Địa chỉ email, nếu có, để nhận được thông báo hành chính.'),
(109118, 1955, 29, 'Địa chỉ email, nếu có, để nhận được thông báo khẩn cấp người sử dụng đăng nhập kích hoạt.'),
(109119, 1956, 29, 'Cho Email'),
(109120, 1957, 29, 'Email từ Batchcom'),
(109121, 1958, 29, 'Thông báo bằng Email'),
(109122, 1959, 29, 'Giờ Thông báo bằng Email'),
(109123, 1960, 29, 'Báo cáo Thông báo bằng Email'),
(109124, 1961, 29, 'Gửi email trước'),
(109125, 1962, 29, 'Người gửi Email'),
(109126, 1963, 29, 'Đã gửi Email'),
(109127, 1964, 29, 'Đã gửi Email đến'),
(109128, 1965, 29, 'Tiêu đề email'),
(109129, 1966, 29, 'Nội dung email, Có thể dùng Thẻ: ***NAME***, ví dụ Kính gửi ***NAME***'),
(109130, 1967, 29, 'Nội dung email, Có thể dùng Thẻ: ***NAME***, ví dụ Kính gửi ***NAME***{{Không được dịch thành phần ***NAME*** của hằng số này.}}'),
(109131, 1968, 29, 'Phương pháp Chuyển giao Email'),
(109132, 1969, 29, 'Email đã được gửi đến địa chỉ sau đây'),
(109133, 1971, 29, 'Liên lạc khi Khẩn Cấp'),
(109134, 1972, 29, 'Người Liên hệ khi Khẩn cấp'),
(109135, 1973, 29, 'Số Điện thoại Liên hệ khi Khẩn cấp'),
(109136, 1974, 29, 'Ngừa thai Khẩn cấp'),
(109137, 1975, 29, 'Đăng nhập khi Khẩn cấp'),
(109138, 1976, 29, 'Trường hợp khẩn cấp Đăng nhập ACL được chọn. Người sử dụng vẫn còn trong trạng thái hoạt động, xin vui lòng de-kích hoạt người sử dụng và kích hoạt khi cần thiết trong các tình huống khẩn cấp. Thăm chính -> Người dùng để kích hoạt hoặc de-kích hoạt.'),
(109139, 1977, 29, 'Đăng nhập email kích hoạt khẩn cấp sẽ được lưu hành chỉ khi cài đặt sau đây trong tập tin / globals.php giao diện được cấu hình:'),
(109140, 1978, 29, 'Địa chỉ Email Đăng nhập khẩn cấp'),
(109141, 1979, 29, 'Đăng nhập sử dụng khẩn cấp có thể làm bất cứ điều gì'),
(109142, 1980, 29, 'Điện thoại khi Khẩn cấp'),
(109143, 1982, 29, 'Khí phế thũng (Emphysema)'),
(109144, 1983, 29, 'Nhân viên'),
(109145, 1984, 29, 'Công ty'),
(109146, 1985, 29, 'Địa chỉ Công ty'),
(109147, 1986, 29, 'Dữ liệu Công ty'),
(109148, 1987, 29, 'Tên Công ty'),
(109149, 1988, 29, 'EMPTY'),
(109150, 1989, 29, 'Rỗng'),
(109151, 1991, 29, 'Giá trị sản phẩm nào trong "Giờ Email"'),
(109152, 1992, 29, 'Giá trị sản phẩm nào trong "Tên người gửi Email"'),
(109153, 1993, 29, 'Có sản phẩm nào giá trị trong "Chủ đề email"'),
(109154, 1994, 29, 'Có sản phẩm nào giá trị trong "Văn bản Email"'),
(109155, 1995, 29, 'Giá trị sản phẩm nào trong "Tên của nhà cung cấp"'),
(109156, 1996, 29, 'Giá trị sản phẩm nào trong "Mật khẩu"'),
(109157, 1997, 29, 'Giá trị sản phẩm nào trong "Giờ SMS"'),
(109158, 1998, 29, 'Giá trị sản phẩm nào trong "Tin nhắn văn bản"'),
(109159, 1999, 29, 'Giá trị sản phẩm nào trong "Tên"'),
(109160, 2006, 29, 'Kích hoạt tính năng AMC khiến'),
(109161, 2008, 29, 'Kích hoạt tính năng AMC báo cáo'),
(109162, 2009, 29, 'Kích hoạt tính năng AMC Theo dõi'),
(109163, 2011, 29, 'Kích hoạt tính năng ATNA Kiểm toán'),
(109164, 2013, 29, 'Kích hoạt tính năng Logging Kiểm toán'),
(109165, 2014, 29, 'Kích hoạt tính năng Trail kiểm toán và xác thực Node (ATNA).'),
(109166, 2015, 29, 'Kích hoạt tính năng tự động tính toán đo lường (AMC) Báo cáo'),
(109167, 2016, 29, 'Kích hoạt tính năng khách hàng SSL'),
(109168, 2017, 29, 'Kích hoạt tính năng xác thực giấy chứng nhận SSL khách hàng.'),
(109169, 2019, 29, 'Kích hoạt tính năng Rules quyết định lâm sàng (CDR)'),
(109170, 2022, 29, 'Kích hoạt tính năng lâm sàng Đo lường Chất lượng (CQM) Báo cáo'),
(109171, 2023, 29, 'Kích hoạt tính năng Popup Reminder lâm sàng'),
(109172, 2024, 29, 'Kích hoạt tính năng Widget Reminder lâm sàng'),
(109173, 2027, 29, 'Kích hoạt tính năng CQM báo cáo'),
(109174, 2030, 29, 'Kích hoạt mục Phí trong Trình đơn bên Trái'),
(109175, 2031, 29, 'Kích hoạt tính năng Hylafax Hỗ trợ'),
(109176, 2033, 29, 'Kích hoạt kết nhập tin nhắn trạng thái cho NewCrop erx'),
(109177, 2037, 29, 'Kích hoạt tính năng Lab Trao đổi'),
(109178, 2039, 29, 'Cho phép ghi nhật ký đối với việc tải lên / tải xuống tập tin đến / từ CouchDB'),
(109179, 2040, 29, 'Kích hoạt tính năng đăng nhập của tất cả các truy vấn SQL SELECT.'),
(109180, 2041, 29, 'Cho phép đăng nhập các hoạt động sao lưu liên quan.'),
(109181, 2043, 29, 'Cho phép đăng nhập các hoạt động linh tinh.'),
(109182, 2044, 29, 'Kích hoạt tính năng đăng nhập của các hoạt động đặt hàng.'),
(109183, 2045, 29, 'Kích hoạt tính năng đăng nhập sửa đổi hồ sơ bệnh nhân.'),
(109184, 2046, 29, 'Kích hoạt tính năng đăng nhập của hoạt động lập kế hoạch.'),
(109185, 2047, 29, 'Kích hoạt tính năng đăng nhập của hoạt động an ninh và quản trị.'),
(109186, 2049, 29, 'Kích hoạt tính năng NewCrop eRx Dịch vụ'),
(109187, 2051, 29, 'Kích hoạt tính năng Portal Bệnh nhân ngoại vi'),
(109188, 2052, 29, 'Kích hoạt tính năng Portal Bệnh nhân ngoại vi.'),
(109189, 2053, 29, 'Kích hoạt tính năng Cổng thông tin bệnh nhân tại chỗ'),
(109190, 2055, 29, 'Kích hoạt tính năng Cổng thông tin bệnh nhân tại chỗ.'),
(109191, 2056, 29, 'Kích hoạt tính năng Widget Nhắc nhở bệnh nhân'),
(109192, 2058, 29, 'Kích hoạt tính năng khiến cho tính toán đo lường tự động (AMC) dữ liệu yêu cầu'),
(109193, 2060, 29, 'Kích hoạt tính năng báo cáo ngày theo dõi Đối với các tính toán đo lường tự động (AMC)'),
(109194, 2061, 29, 'Kích hoạt tính năng hỗ trợ quét'),
(109195, 2065, 29, 'Kích hoạt tính năng hỗ trợ LibreEHR LLC Lab Trao đổi dịch vụ.'),
(109196, 2066, 29, 'Cho phép người sử dụng Giấy chứng nhận xác thực'),
(109197, 2067, 29, 'Kích hoạt tính năng ZMG, dịch vụ LLC eRx'),
(109198, 2068, 29, 'kích hoạt'),
(109199, 2070, 29, 'Cho phép bảng Biểu phí cũ để nhập mã số hóa đơn và thanh toán. Không nên dùng, thay vì vậy hãy sử dụng Bảng Phí.'),
(109200, 2071, 29, 'Khám'),
(109201, 2072, 29, 'Khám'),
(109202, 2073, 29, 'Lần khám'),
(109203, 2074, 29, 'lần khám'),
(109204, 2075, 29, 'Lần khám '),
(109205, 2076, 29, 'gặp phải điều trị nội trú cấp tính hoặc ED'),
(109206, 2081, 29, 'Ngày Khám'),
(109207, 2086, 29, 'Biểu mẫu Khám'),
(109208, 2087, 29, 'đánh giá sức khỏe và hành vi trong lần khám'),
(109209, 2088, 29, 'Lịch sử Khám'),
(109210, 2089, 29, 'Mã Lần khám'),
(109211, 2090, 29, 'gặp phải cúm'),
(109212, 2091, 29, 'Số lượng lần khám'),
(109213, 2093, 29, 'gặp phải xả điều dưỡng'),
(109214, 2094, 29, 'gặp phải cơ sở điều dưỡng'),
(109215, 2095, 29, 'gặp phải lao động trị liệu'),
(109216, 2096, 29, 'gặp phải chuyến thăm văn phòng'),
(109217, 2097, 29, 'gặp phải bệnh nhân ngoại trú'),
(109218, 2098, 29, 'gặp phải bệnh nhân ngoại trú w / PCP & OBGYN'),
(109219, 2099, 29, 'Kích thước Trang Lần khám'),
(109220, 2100, 29, 'Thanh toán Lần khám'),
(109221, 2101, 29, 'gặp phải khi mang thai'),
(109222, 2102, 29, 'gặp y tế dự phòng - tư vấn cá nhân'),
(109223, 2103, 29, 'gặp phải y tế dự phòng 40 tuổi trở lên'),
(109224, 2104, 29, 'gặp phải tư vấn nhóm thuốc phòng ngừa'),
(109225, 2105, 29, 'gặp phải các dịch vụ y tế dự phòng khác'),
(109226, 2106, 29, 'gặp các dịch vụ y tế dự phòng 18 tuổi trở lên'),
(109227, 2107, 29, 'gặp phải tâm thần - tâm lý'),
(109228, 2108, 29, 'Thống kê lần khám'),
(109229, 2109, 29, 'Tóm tắt Lần khám'),
(109230, 2110, 29, 'Lần khám đã được mã hóa'),
(109231, 2111, 29, 'Lần khám:'),
(109232, 2112, 29, 'Gặp phải: gặp phải không inpt cấp tính, bệnh nhân ngoại trú, hoặc nhãn khoa'),
(109233, 2113, 29, 'Lần khám'),
(109234, 2114, 29, 'Lần khám & Biểu mẫu'),
(109235, 2115, 29, 'Lần khám &amp; Biểu mẫu'),
(109236, 2116, 29, 'Gặp không phép'),
(109237, 2117, 29, 'Cuộc gặp gỡ Báo cáo'),
(109238, 2118, 29, 'Cuộc gặp gỡ Mục'),
(109239, 2120, 29, 'Mã hóa'),
(109240, 2121, 29, 'Kết thúc'),
(109241, 2122, 29, 'Kết thúc (năm-tháng-ngày): '),
(109242, 2123, 29, 'Ngày Kết thúc'),
(109243, 2124, 29, 'Ngày kết thúc'),
(109244, 2126, 29, 'Ngày kết thúc phải sau ngày Bắt đầu'),
(109245, 2127, 29, 'Ngày Kết thúc:'),
(109246, 2131, 29, 'Thời gian Kết thúc'),
(109247, 2133, 29, 'Ngày kết thúc dịch vụ năm-tháng-ngày'),
(109248, 2134, 29, 'Kết thúc DOS mm / dd / yyyy nếu bạn muốn nhập một dải'),
(109249, 2135, 29, 'Kết thúc giờ trong ngày cho các sự kiện lịch.'),
(109250, 2136, 29, 'Endo bất thường máu'),
(109251, 2137, 29, 'Nội tiết'),
(109252, 2138, 29, 'Nội soi'),
(109253, 2141, 29, 'Tiếng/Người Anh'),
(109254, 2142, 29, 'Tiếng/Người Anh '),
(109255, 2143, 29, 'Tiếng/Người Anh (Ấn Độ)'),
(109256, 2144, 29, 'Tiếng/Người Anh (Tiêu chuẩn)'),
(109257, 2145, 29, 'Enscript lệnh được sử dụng bởi Hylafax.'),
(109258, 2146, 29, 'Đảm bảo LibreEHR có quyền ghi vào thư mục'),
(109259, 2147, 29, 'ENT Discharge'),
(109260, 2148, 29, 'ENT Pain'),
(109261, 2149, 29, 'Nhập mã chẩn đoán để loại trừ tất cả các hoá đơn không chứa nó'),
(109262, 2151, 29, 'Nhập vào cơ thể của bức thư ở đây'),
(109263, 2152, 29, 'Nhập mật khẩu gốc cơ sở dữ liệu'),
(109264, 2153, 29, 'Nhập Tên đăng nhập cơ sở dữ liệu gốc'),
(109265, 2154, 29, 'Nhập Chẩn đoán'),
(109266, 2155, 29, 'Nhập Thuốc'),
(109267, 2158, 29, 'Nhập Chủng ngừa'),
(109268, 2159, 29, 'Nhập Khóa'),
(109269, 2161, 29, 'Nhập Tiểu bang mới'),
(109270, 2164, 29, 'Nhập mã nhận dạng Re'),
(109271, 2165, 29, 'Nhập tiêu chí tìm kiếm của bạn ở trên'),
(109272, 2167, 29, 'đầu mục'),
(109273, 2168, 29, 'Môi trường'),
(109274, 2169, 29, 'EOB nhập dữ liệu'),
(109275, 2170, 29, 'EOB viết bài - Chuyển tiền điện tử'),
(109276, 2171, 29, 'EOB viết bài - Hướng dẫn'),
(109277, 2172, 29, 'EOB viết bài - Hóa đơn'),
(109278, 2173, 29, 'EOB viết bài - Lưu ý bệnh nhân'),
(109279, 2174, 29, 'EOB viết bài - Tìm kiếm'),
(109280, 2176, 29, 'Bệnh động kinh'),
(109281, 2178, 29, 'ERA'),
(109282, 2180, 29, 'ERA viết bài'),
(109283, 2181, 29, 'Xoá bỏ'),
(109284, 2182, 29, 'Cương cứng'),
(109285, 2183, 29, 'Lôi'),
(109286, 2185, 29, 'Lỗi xác nhận nhận được kết quả phòng thí nghiệm'),
(109287, 2187, 29, 'Lỗi nhận được kết quả phòng thí nghiệm từ phòng thí nghiệm Exchange mạng'),
(109288, 2188, 29, 'Lỗi trong lựa chọn "Giới Tính"'),
(109289, 2189, 29, 'Lỗi trong lựa chọn "HIPAA"'),
(109290, 2190, 29, 'Lỗi trong lựa chọn "Quy trình"'),
(109291, 2191, 29, 'Lỗi trong lựa chọn "SMS Gateway"'),
(109292, 2192, 29, 'Lỗi trong "Sắp xếp theo" lựa chọn'),
(109293, 2193, 29, 'Lỗi trong gzip nén tập tin: '),
(109294, 2194, 29, 'Lỗi trong YES hoặc NO tùy chọn'),
(109295, 2195, 29, 'Lỗi mở tải lên tập tin để đọc'),
(109296, 2199, 29, 'Lỗi khi lấy kết quả từ phòng thí nghiệm Exchange Network'),
(109297, 2202, 29, 'Lỗi khi cấp đặc quyền tập tin cho người sử dụng LibreEHR.'),
(109298, 2205, 29, 'lỗi trong khi đăng ký hình thức!'),
(109299, 2206, 29, 'Lỗi trong khi tiết kiệm đến tập tin'),
(109300, 2208, 29, 'Lỗi trong khi ghi vào tập tin'),
(109301, 2210, 29, 'Lỗi, các tập tin không tồn tại'),
(109302, 2211, 29, 'ERROR, không thể để thu thập dữ liệu từ máy chủ'),
(109303, 2212, 29, 'Lỗi, không thể để tạo ra chứng chỉ khách hàng.'),
(109304, 2213, 29, 'Lỗi, không thể tạo ra các giấy chứng nhận admin.p12.'),
(109305, 2214, 29, 'Lỗi, không thể tạo ra các chứng chỉ Certificate Authority.'),
(109306, 2215, 29, 'Lỗi, không thể tạo ra các giấy chứng nhận Server.'),
(109307, 2216, 29, 'Lỗi, không thể mở tập tin'),
(109308, 2217, 29, 'Lỗi, Giấy chứng nhận xác thực người dùng không được kích hoạt trong LibreEHR'),
(109309, 2218, 29, 'Lỗi. Bạn cần phải cài đặt các mô-đun Lưu Trữ / Tar.php php.'),
(109310, 2219, 29, 'LỖI: không thể mở table.sql, hình thức bị hỏng?'),
(109311, 2220, 29, 'Lỗi: ID trùng lặp trên dòng'),
(109312, 2221, 29, 'Lỗi: nhân đôi tên trên đường dây'),
(109313, 2222, 29, 'LỖI: Field'),
(109314, 2223, 29, 'LỖI: Thiếu mô đun ZipArchive PHP'),
(109315, 2224, 29, 'LỖI: Không có thư mục kết nhập ICD.'),
(109316, 2225, 29, 'Lỗi: mật khẩu không trùng. Xin vui lòng kiểm tra việc gõ phím của bạn.'),
(109317, 2226, 29, 'Lỗi: mật khẩu không trùng. Xin vui lòng kiểm tra việc gõ phím của bạn.'),
(109318, 2227, 29, 'Lỗi: tập tin không tồn tại'),
(109319, 2228, 29, 'LỖI: Biến sau đây không chứa ký tự phù hợp'),
(109320, 2229, 29, 'LỖI: Không thể sao chép các tập tin.'),
(109321, 2230, 29, 'Lỗi: Không thể để tạo ra kho lưu trữ tải về'),
(109322, 2231, 29, 'LỖI: Không thể Tạo Lưu trữ Zip.'),
(109323, 2232, 29, 'LỖI: Không thể để trích xuất các tập tin.'),
(109324, 2233, 29, 'LỖI: Không thể tải các tập tin vào cơ sở dữ liệu.'),
(109325, 2234, 29, 'LỖI: Không thể để thiết lập số phiên bản.'),
(109326, 2235, 29, 'Lỗi'),
(109327, 2236, 29, 'Trạng thái Tài khoản eRx'),
(109328, 2237, 29, 'Bản ghi eRx'),
(109329, 2238, 29, 'Tên eRx'),
(109330, 2239, 29, 'Mật khẩu ERX'),
(109331, 2240, 29, 'Vai trò ERX'),
(109332, 2241, 29, 'Người dùng ERX'),
(109333, 2242, 29, 'Ban đỏ:'),
(109334, 2245, 29, 'Vùng bắc cực'),
(109335, 2247, 29, 'Bệnh nhân Cũ'),
(109336, 2249, 29, 'Dân tộc'),
(109337, 2250, 29, 'Dân tộc hay chủng tộc'),
(109338, 2251, 29, 'Danh sách Dân tộc-Chủng tộc (viết, addonly tùy chọn)'),
(109339, 2252, 29, 'ETIN'),
(109340, 2253, 29, 'Sự kiện'),
(109341, 2254, 29, 'Sự kiện Bắt đầu'),
(109342, 2255, 29, 'Thể loại Sự kiện'),
(109343, 2256, 29, 'Ngày Sự kiện'),
(109344, 2257, 29, 'Mô tả Sự kiện'),
(109345, 2258, 29, 'Chi tiết Sự kiện'),
(109346, 2259, 29, 'Không lặp lại sự kiện'),
(109347, 2260, 29, 'Thời gian của Sự kiện'),
(109348, 2261, 29, 'Thời gian của sự kiện theo phút'),
(109349, 2262, 29, 'Phí của Sự kiện'),
(109350, 2263, 29, 'Địa điểm của Sự kiện'),
(109351, 2264, 29, 'Lặp lại sự kiện mỗi'),
(109352, 2265, 29, 'Lặp lại sự kiện vào'),
(109353, 2266, 29, 'Thời gian bắt đầu sự kiện'),
(109354, 2267, 29, 'Tiêu đề sự kiện'),
(109355, 2268, 29, 'Tiêu đề Sự kiện'),
(109356, 2269, 29, 'Trang web Sự kiện'),
(109357, 2270, 29, 'Sự kiện'),
(109358, 2271, 29, 'Sự kiện của'),
(109359, 2272, 29, 'Mở sự kiện trong cửa sổ mới'),
(109360, 2273, 29, 'mỗi'),
(109361, 2274, 29, 'Mỗi'),
(109362, 2275, 29, 'mỗi 3 giờ'),
(109363, 2276, 29, 'mỗi 4 giờ'),
(109364, 2277, 29, 'mỗi 5 giờ'),
(109365, 2278, 29, 'mỗi 6 giờ'),
(109366, 2279, 29, 'mỗi 8 giờ'),
(109367, 2280, 29, 'Mỗi Thứ tư'),
(109368, 2281, 29, 'Mỗi vật'),
(109369, 2282, 29, 'Mỗi Thứ ba'),
(109370, 2283, 29, 'Mỗi, mỗi khác, mỗi thứ 3, vv'),
(109371, 2285, 29, 'Kết quả kiểm tra và thử'),
(109372, 2286, 29, 'Kết quả kiểm tra'),
(109373, 2289, 29, 'Kiểm tra'),
(109374, 2290, 29, 'Ngày Kiểm tra'),
(109375, 2291, 29, 'Ví dụ'),
(109376, 2292, 29, 'Ví dụ'),
(109377, 2293, 29, 'Kiểm tra / Xét nghiệm'),
(109378, 2294, 29, 'Loại trừ'),
(109379, 2295, 29, 'Chảy nước mắt sống'),
(109380, 2296, 29, 'Loại trừ bệnh nhân'),
(109381, 2297, 29, 'Loại trừ'),
(109382, 2298, 29, 'Tổ chức độc quyền cung cấp (EPO)'),
(109383, 2299, 29, 'Cỡ Giấy Điều hành (Executive)'),
(109384, 2300, 29, 'Tập thể dục'),
(109385, 2301, 29, 'Cách Tập thể dục'),
(109386, 2302, 29, 'Cách tập thể dục'),
(109387, 2303, 29, 'Tồn tại'),
(109388, 2304, 29, 'Thoát khỏi Quản lý'),
(109389, 2305, 29, 'Exp'),
(109390, 2306, 29, 'Mở rộng'),
(109391, 2307, 29, 'mở rộng'),
(109392, 2308, 29, 'Mở rộng tất cả'),
(109393, 2311, 29, 'Mở rộng Xem'),
(109394, 2312, 29, 'Dự kiến ​​form_encounter.pid được '),
(109395, 2313, 29, 'Hết hạn'),
(109396, 2314, 29, 'Ngày hết hạn'),
(109397, 2315, 29, 'Ngày hết hạn'),
(109398, 2316, 29, 'hết hiệu lực vào'),
(109399, 2317, 29, 'Kết xuất'),
(109400, 2318, 29, 'Kết xuất như CSV'),
(109401, 2319, 29, 'Kết xuất Cấu hình'),
(109402, 2322, 29, 'Kết xuất Thông tin cá nhân của Bệnh nhân'),
(109403, 2323, 29, 'Báo cáo Kết xuất PQRI'),
(109404, 2325, 29, 'Kết xuất các mục được chọn theo dạng CSV'),
(109405, 2326, 29, 'Xuất khẩu được lựa chọn để Bộ sưu tập'),
(109406, 2327, 29, 'Xuất khẩu để CSV'),
(109407, 2328, 29, 'Xuất khẩu sang hệ thống thanh toán bên ngoài'),
(109408, 2329, 29, 'Tiếp xúc với nước ngoài'),
(109409, 2330, 29, 'Tiếp xúc nước ngoài'),
(109410, 2331, 29, 'Ext Thời gian thu thập'),
(109411, 2332, 29, 'Bên ngoài'),
(109412, 2334, 29, 'Tải Dữ liệu Bên ngoài'),
(109413, 2335, 29, 'Công cụ Kết nhập Cơ sở dữ liệu Bên ngoài'),
(109414, 2336, 29, 'Số CMND/Hộ chiếu'),
(109415, 2337, 29, 'Số CMND/Hộ chiếu'),
(109416, 2338, 29, 'Số CMND/Hộ chiếu'),
(109417, 2339, 29, 'Chỉ hiện Bên ngoài'),
(109418, 2342, 29, 'Bên ngoài Giới thiệu'),
(109419, 2343, 29, 'Bên ngoài Giới thiệu Theo dõi'),
(109420, 2344, 29, 'Bên ngoài giới thiệu?'),
(109421, 2345, 29, 'Bên ngoài Giới thiệu'),
(109422, 2346, 29, 'Giải nén tập tin zip'),
(109423, 2347, 29, 'Đang giải nén tập tin đó. Việc này cần một ít thời gian...'),
(109424, 2348, 29, 'Dịch rỉ:'),
(109425, 2349, 29, 'Eye kích thích'),
(109426, 2350, 29, 'Mắt đau'),
(109427, 2351, 29, 'Mắt đỏ'),
(109428, 2352, 29, 'Mắt'),
(109429, 2353, 29, 'F'),
(109430, 2354, 29, 'F / H máu vấn đề'),
(109431, 2355, 29, 'F / H Nữ rậm lông / striae'),
(109432, 2356, 29, 'Các cơ sở'),
(109433, 2357, 29, 'Cơ sở'),
(109434, 2358, 29, 'cơ sở'),
(109435, 2359, 29, 'Quản trị Cơ sở'),
(109436, 2360, 29, 'Thành phố của Cơ sở'),
(109437, 2361, 29, 'Mã của Cơ sở'),
(109438, 2362, 29, 'Mã Quốc gia của Cơ sở'),
(109439, 2363, 29, 'Fax của Cơ sở'),
(109440, 2364, 29, 'Tên Cơ sở'),
(109441, 2365, 29, 'NPI của Cơ sở'),
(109442, 2366, 29, 'Điện thoại Cơ sở'),
(109443, 2367, 29, 'Thông tin Người dùng Riêng cho Cơ sở'),
(109444, 2368, 29, 'Tiểu bang của Cơ sở'),
(109445, 2369, 29, 'Đường của Cơ sở'),
(109446, 2370, 29, 'Mã Zip của Cơ sở'),
(109447, 2372, 29, 'Cơ sở:'),
(109448, 2373, 29, 'HƯ HỎNG'),
(109449, 2374, 29, 'đã hỏng'),
(109450, 2375, 29, 'Đã hỏng'),
(109451, 2380, 29, 'Không thể tạo thư mục tạm. CouchDB sẽ không làm việc được.'),
(109452, 2382, 29, 'Đã hỏng.'),
(109453, 2383, 29, 'thất bại'),
(109454, 2390, 29, 'Lịch sử Gia đình'),
(109455, 2391, 29, 'Lịch sử Gia đình của Bệnh tăng nhãn áp'),
(109456, 2392, 29, 'Lịch sử Gia đình:'),
(109457, 2394, 29, 'Gia đình Thanh toán'),
(109458, 2395, 29, 'Số người trong Gia Đình'),
(109459, 2396, 29, 'Đầy màu sắc'),
(109460, 2398, 29, 'Tiếng Farsi'),
(109461, 2400, 29, 'Cha'),
(109462, 2402, 29, 'Mệt mỏi'),
(109463, 2403, 29, 'mệt mỏi'),
(109464, 2404, 29, 'Fax'),
(109465, 2405, 29, 'Đếm fax'),
(109466, 2406, 29, 'Số fax'),
(109467, 2408, 29, 'Fax / Quét'),
(109468, 2409, 29, 'Fax Đến'),
(109469, 2410, 29, 'Fax Đi'),
(109470, 2411, 29, 'Các tính năng'),
(109471, 2412, 29, 'Tháng Hai'),
(109472, 2413, 29, 'Tháng Hai'),
(109473, 2414, 29, 'FECA'),
(109474, 2415, 29, 'Mã Thuốc Liên bang'),
(109475, 2416, 29, 'EIN Liên bang'),
(109476, 2417, 29, 'Mã Thuế Liên bang'),
(109477, 2418, 29, 'Phí'),
(109478, 2419, 29, 'phí'),
(109479, 2420, 29, 'Không cho phép tính phí'),
(109480, 2421, 29, 'Bảng Phí'),
(109481, 2422, 29, 'Tùy chọn Bảng Phí'),
(109482, 2423, 29, 'Phí'),
(109483, 2424, 29, 'Nữ'),
(109484, 2425, 29, 'Nữ AP'),
(109485, 2426, 29, 'Nữ Bao cao su'),
(109486, 2427, 29, 'Nữ G'),
(109487, 2428, 29, 'Nữ LC'),
(109488, 2429, 29, 'Nữ P'),
(109489, 2430, 29, 'Nữ triệu chứng'),
(109490, 2431, 29, 'Nữ VSC'),
(109491, 2434, 29, 'sốt'),
(109492, 2435, 29, 'sốt:'),
(109493, 2436, 29, 'FH máu vấn đề'),
(109494, 2437, 29, 'u xơ tử cung'),
(109495, 2441, 29, 'Loại thông tin để sử dụng cho quốc gia của người sử dụng lao động hoặc người đăng ký trong phần thông tin cá nhân.'),
(109496, 2442, 29, 'Loại thông tin để sử dụng cho tiểu bang của người sử dụng lao động hoặc người đăng ký trong phần thông tin cá nhân.'),
(109497, 2443, 29, 'Đang thiếu ô nhập!'),
(109498, 2447, 29, 'Tập tin'),
(109499, 2448, 29, 'trong thư mục Tài liệu để tìm hiểu làm thế nào để tự động hoá quá trình tạo bản sao lưu nhật ký'),
(109500, 2449, 29, 'vị trí tập tin'),
(109501, 2450, 29, 'Quản lý tập tin'),
(109502, 2453, 29, 'Đã gán quyền truy cập hồ sơ cho người sử dụng LibreEHR.'),
(109503, 2454, 29, 'Việc lấy tập tin về từ CouchDB đã thất bại'),
(109504, 2455, 29, 'Phòng Hồ sơ'),
(109505, 2456, 29, 'Tập tin để tải lên'),
(109506, 2458, 29, 'Tập tin có cùng tên đã tồn tại tại vị trí:'),
(109507, 2459, 29, 'tên tập tin'),
(109508, 2461, 29, 'các tập tin'),
(109509, 2462, 29, 'Philippines'),
(109510, 2463, 29, 'Điền vào bất kỳ của Row Dưới đây.'),
(109511, 2464, 29, 'Điền ở đây chỉ khi gửi email thông báo cho bệnh nhân'),
(109512, 2465, 29, 'Điền vào các giá trị dưới đây'),
(109513, 2467, 29, 'Điền vào Row.'),
(109514, 2468, 29, 'Lọc'),
(109515, 2469, 29, 'Lọc cho hằng số'),
(109516, 2470, 29, 'Lọc cho các định nghĩa'),
(109517, 2471, 29, 'đã lọc từ'),
(109518, 2472, 29, 'bộ lọc'),
(109519, 2473, 29, 'Bộ lọc'),
(109520, 2474, 29, 'Cuối cùng'),
(109521, 2475, 29, 'Chẩn đoán Cuối cùng'),
(109522, 2476, 29, 'Chẩn đoán cuối cùng của chuyên gia'),
(109523, 2478, 29, 'Tài chính'),
(109524, 2479, 29, 'Ngày Kết sổ Tài chính (năm-tháng-ngày)'),
(109525, 2480, 29, 'Báo cáo Tài chính - bất cứ điều gì'),
(109526, 2481, 29, 'Báo cáo Tài chính - cuộc gặp gỡ của tôi'),
(109527, 2482, 29, 'Ngày Xem xét Tài chính'),
(109528, 2483, 29, 'Tổng kết Tài chính theo Mã Dịch vụ'),
(109529, 2484, 29, 'Tìm'),
(109530, 2485, 29, 'Tìm Giờ trống'),
(109531, 2486, 29, 'Tìm Cuộc hẹn Hiện có'),
(109532, 2487, 29, 'Tìm Bệnh nhân'),
(109533, 2488, 29, 'Tìm Vật liệu Giáo dục Bệnh nhân'),
(109534, 2489, 29, 'Những phát hiện'),
(109535, 2490, 29, 'Những phát hiện bởi chuyên gia'),
(109536, 2491, 29, 'Mỹ'),
(109537, 2492, 29, 'Kết thúc Thanh toán'),
(109538, 2493, 29, 'đã kết thúc'),
(109539, 2495, 29, 'Lần đầu tiên'),
(109540, 2497, 29, 'Ngày đầu tiên trong tuần'),
(109541, 2498, 29, 'Tên'),
(109542, 2499, 29, 'Tên'),
(109543, 2500, 29, 'Tên:'),
(109544, 2503, 29, 'Thể hình'),
(109545, 2504, 29, 'Thể hình Cấp'),
(109546, 2505, 29, 'Phòng tập thể dục cấp cho máy nghe nhạc này vào ngày này'),
(109547, 2507, 29, 'Phòng tập thể dục để chơi'),
(109548, 2508, 29, 'Sửa chữa gặp phải ngày nào gặp'),
(109549, 2509, 29, 'Sửa lỗi này'),
(109550, 2510, 29, 'FL'),
(109551, 2511, 29, 'đầy hơi'),
(109552, 2512, 29, 'dòng chảy'),
(109553, 2514, 29, 'mùa cúm'),
(109554, 2515, 29, 'Mùa Cúm'),
(109555, 2516, 29, 'cúm tiêm phòng vắc xin'),
(109556, 2517, 29, 'Vấn đề chất lỏng và chất điện phân'),
(109557, 2518, 29, 'FMS'),
(109558, 2519, 29, 'Cỡ Giấy Sổ (Folio)'),
(109559, 2520, 29, 'Thực hiện theo cách thủ công'),
(109560, 2521, 29, 'Theo các chỉ dẫn này để cài đặt hay nâng cấp cơ sở dữ liệu sau đây'),
(109561, 2522, 29, 'Theo Sát'),
(109562, 2524, 29, 'Lý do Theo Sát'),
(109563, 2525, 29, 'Sau đây là một tùy chỉnh mới liên tục:'),
(109564, 2526, 29, 'Sau đây là một ngôn ngữ tùy chỉnh mới:'),
(109565, 2527, 29, 'Sau đây là một định nghĩa mới (Ngôn ngữ, Constant, Definition):'),
(109566, 2529, 29, 'Dịch vụ Theo sát'),
(109567, 2530, 29, 'Chỉ định Theo sát'),
(109568, 2531, 29, 'Thực phẩm không chịu được'),
(109569, 2532, 29, 'chân'),
(109570, 2533, 29, 'Các vấn đề về chân'),
(109571, 2534, 29, 'Chân:'),
(109572, 2535, 29, 'Chấn thương do Bóng đá'),
(109573, 2536, 29, 'Chấn thương do Bóng đá'),
(109574, 2537, 29, 'Báo cáo Chấn thương do Bóng đá'),
(109575, 2538, 29, 'Loại Giày dép'),
(109576, 2539, 29, 'cho'),
(109577, 2540, 29, 'Đối với'),
(109578, 2541, 29, 'Đối với các mã'),
(109579, 2543, 29, 'Khiếu nại Encounter'),
(109580, 2544, 29, 'Ví dụ:'),
(109581, 2547, 29, 'cho Hóa đơn'),
(109582, 2548, 29, 'Đối với Medicare chỉ, buộc các nhà cung cấp đề cập đến là tương tự như các nhà cung cấp vẽ.'),
(109583, 2552, 29, 'Đối với Tổ chức Referred / học viên'),
(109584, 2553, 29, 'Đối với quá khứ'),
(109585, 2554, 29, 'cho biến'),
(109586, 2555, 29, 'cho:'),
(109587, 2556, 29, 'Buộc Mở Thành phần Hóa đơn'),
(109588, 2557, 29, 'Buộc Tạo Bệnh nhân mới'),
(109589, 2559, 29, 'cẳng tay'),
(109590, 2560, 29, 'Dạng'),
(109591, 2561, 29, 'dạng'),
(109592, 2564, 29, 'Định dạng'),
(109593, 2565, 29, 'định dạng'),
(109594, 2567, 29, 'Định dạng không chính xác cho NDC'),
(109595, 2568, 29, 'Định dạng được sử dụng để hiển thị hầu hết các ngày.'),
(109596, 2569, 29, 'Định dạng được sử dụng để hiển thị hầu hết các thời gian.'),
(109597, 2570, 29, 'Báo cáo đã Định dạng'),
(109598, 2571, 29, 'Đã từng hút thuốc'),
(109599, 2572, 29, 'Các biểu mẫu'),
(109600, 2573, 29, 'Quản trị Các biểu mẫu'),
(109601, 2575, 29, 'Chuyển tiếp'),
(109602, 2576, 29, 'Chuyển tiếp Các trang bằng Fax'),
(109603, 2577, 29, 'Đã chuyển tiếp'),
(109604, 2579, 29, 'Thứ tư'),
(109605, 2581, 29, 'gay xương'),
(109606, 2582, 29, 'Gãy xương ở các Navicula'),
(109607, 2583, 29, 'Gãy xương mắt cá bên'),
(109608, 2584, 29, 'Gãy xương mắt cá trung gian'),
(109609, 2585, 29, 'Gãy xương, cơ sở thứ năm (5) xương bàn chân'),
(109610, 2587, 29, 'Tiếng Pháp'),
(109611, 2588, 29, 'Tiếng Pháp (Canada)'),
(109612, 2589, 29, 'Tiếng Pháp (Chuẩn)'),
(109613, 2590, 29, 'tần số'),
(109614, 2591, 29, 'thường xuyên cảm lạnh'),
(109615, 2592, 29, 'thường xuyên bệnh tật'),
(109616, 2593, 29, 'Thứ 6'),
(109617, 2594, 29, 'Thứ Sáu'),
(109618, 2595, 29, 'Từ'),
(109619, 2596, 29, 'TỪ'),
(109620, 2597, 29, 'từ'),
(109621, 2598, 29, 'Từ ngày không được lớn hơn Đến ngày.'),
(109622, 2599, 29, 'từ:'),
(109623, 2600, 29, 'từ: '),
(109624, 2601, 29, 'FROM_CITY'),
(109625, 2603, 29, 'FROM_FNAME'),
(109626, 2604, 29, 'FROM_LNAME'),
(109627, 2605, 29, 'FROM_MNAME'),
(109628, 2607, 29, 'FROM_PHONECELL'),
(109629, 2608, 29, 'FROM_POSTAL'),
(109630, 2609, 29, 'FROM_STATE'),
(109631, 2610, 29, 'FROM_STREET'),
(109632, 2611, 29, 'FROM_TITLE'),
(109633, 2612, 29, 'FROM_VALEDICTORY'),
(109634, 2613, 29, 'Nhận Bệnh'),
(109635, 2614, 29, 'Giấy biên nhận Nhận Bệnh'),
(109636, 2615, 29, 'Báo cáo Giấy biên nhận Nhận Bệnh'),
(109637, 2616, 29, 'Mặt trận Rec'),
(109638, 2617, 29, 'Trán phải:'),
(109639, 2619, 29, 'Tên đầy đủ'),
(109640, 2620, 29, 'Đường dẫn đầy đủ đến thư mục chứa MySQL thực thi.'),
(109641, 2621, 29, 'Đường dẫn đầy đủ đến thư mục có chứa file thực thi Perl.'),
(109642, 2622, 29, 'Đường dẫn đầy đủ đến thư mục sao lưu bản ghi sự kiện.'),
(109643, 2623, 29, 'Đường dẫn đầy đủ đến thư mục được sử dụng cho các tập tin tạm thời.'),
(109644, 2624, 29, 'Full chơi'),
(109645, 2625, 29, 'Full Đào tạo'),
(109646, 2626, 29, 'Được thanh toán đầy đủ'),
(109647, 2633, 29, 'G'),
(109648, 2634, 29, 'G / DL'),
(109649, 2636, 29, 'Gall Bladder Điều kiện'),
(109650, 2637, 29, 'Gall Stones'),
(109651, 2638, 29, 'Trò chơi Thời gian'),
(109652, 2639, 29, 'Trò chơi'),
(109653, 2640, 29, 'Trò chơi bị bỏ lỡ'),
(109654, 2641, 29, 'trò chơi / sự kiện'),
(109655, 2642, 29, 'Trò chơi / sự kiện bị bỏ lỡ'),
(109656, 2644, 29, 'Vị viêm'),
(109657, 2645, 29, 'Dạ dày Đau'),
(109658, 2646, 29, 'Đường tiêu hóa'),
(109659, 2647, 29, 'GCAC Thống kê Báo cáo'),
(109660, 2648, 29, 'GCAC Thống kê'),
(109661, 2649, 29, 'Hình thức GCAC chuyến thăm được'),
(109662, 2650, 29, 'Giới Tính'),
(109663, 2651, 29, 'Giới Tính '),
(109664, 2652, 29, 'Chung'),
(109665, 2655, 29, 'Dịch vụ Tổng kyø'),
(109666, 2657, 29, 'Tạo ra và tải về các tuyên bố CMS giấy 1500'),
(109667, 2658, 29, 'Tạo ra và tải về các tuyên bố giấy HCFA 1500'),
(109668, 2659, 29, 'Tạo ra và tải về X12 hàng loạt'),
(109669, 2660, 29, 'Tạo ra và tải về X12 hàng loạt cuộc gặp gỡ yêu cầu bồi thường'),
(109670, 2663, 29, 'Tạo ra và truyền tải quy định cho phép điện tử.'),
(109671, 2664, 29, 'Tạo CMS 1500'),
(109672, 2665, 29, 'Tạo CMS 1500 PDF'),
(109673, 2666, 29, 'Tạo ra văn bản 1500 CMS'),
(109674, 2667, 29, 'Tạo HCFA'),
(109675, 2668, 29, 'Tạo Hóa đơn'),
(109676, 2669, 29, 'Tạo thư'),
(109677, 2670, 29, 'Tạo thư về '),
(109678, 2671, 29, 'Tạo PQRI báo cáo (Phương pháp A)'),
(109679, 2673, 29, 'Tạo PQRI báo cáo (Phương pháp E)'),
(109680, 2677, 29, 'Tạo Báo cáo'),
(109681, 2678, 29, 'Tạo Tên đăng nhập và mật khẩu Đối với'),
(109682, 2679, 29, 'Tạo X12'),
(109683, 2680, 29, 'Tạo X12 Encounter'),
(109684, 2682, 29, 'Tạo ra trên'),
(109685, 2683, 29, 'Tạo ra'),
(109686, 2684, 29, 'Sinh dục'),
(109687, 2687, 29, 'Tiếng Đức'),
(109688, 2691, 29, 'Nhận HL7'),
(109689, 2692, 29, 'Bệnh tăng nhãn áp'),
(109690, 2693, 29, 'Bệnh tăng nhãn áp Lịch Sử Gia Đình'),
(109691, 2694, 29, 'Toàn cầu'),
(109692, 2696, 29, 'Toàn cầu ID'),
(109693, 2697, 29, 'Toàn cầu Cài đặt'),
(109694, 2698, 29, 'Toàn bộ'),
(109695, 2699, 29, 'GM / DL'),
(109696, 2700, 29, 'đi'),
(109697, 2701, 29, 'Đi'),
(109698, 2704, 29, 'Tới'),
(109699, 2705, 29, 'Tới tuần'),
(109700, 2706, 29, 'Go Hôm nay'),
(109701, 2711, 29, 'Cấp bậc của thương tích'),
(109702, 2712, 29, 'Lớp:'),
(109703, 2713, 29, 'gram'),
(109704, 2714, 29, 'Tổng cộng'),
(109705, 2715, 29, 'Lớn Tổng số'),
(109706, 2718, 29, 'Lập đồ thị'),
(109707, 2720, 29, 'Lớn hơn'),
(109708, 2721, 29, 'Lớn hơn hoặc bằng'),
(109709, 2722, 29, 'Tiếng Hy Lạp'),
(109710, 2724, 29, 'Nhóm'),
(109711, 2725, 29, 'Tên Nhóm'),
(109712, 2726, 29, 'Tên nhóm không được để trống'),
(109713, 2727, 29, 'Tên nhóm không thể bắt đầu với con số hoặc các khoảng trống'),
(109714, 2728, 29, 'Tên nhóm không thể bắt đầu với những con số.'),
(109715, 2729, 29, 'Số Nhóm'),
(109716, 2730, 29, 'Nhóm Thanh toán'),
(109717, 2731, 29, 'Nhóm:'),
(109718, 2732, 29, 'Tên nhóm'),
(109719, 2733, 29, 'Nhóm và Điều khiển Truy cập'),
(109720, 2734, 29, 'Biểu đồ Tăng trưởng'),
(109721, 2735, 29, 'Biểu đồ Tăng trưởng'),
(109722, 2736, 29, 'gtts (giọt)'),
(109723, 2737, 29, 'Guamanian'),
(109724, 2739, 29, 'Tên người giám hộ'),
(109725, 2741, 29, 'Phụ khoa thi'),
(109726, 2742, 29, 'giờ'),
(109727, 2743, 29, 'trước khi ngủ'),
(109728, 2744, 29, 'H / O Viêm gan'),
(109729, 2745, 29, 'đã được xoá thành công. Bất kỳ loại phụ hiện nay nếu được di chuyển dưới đây'),
(109730, 2746, 29, 'Haematoma / bầm tím'),
(109731, 2747, 29, 'HAI Status'),
(109732, 2750, 29, 'Tay + ngón tay'),
(109733, 2751, 29, 'Vấn đề với Tay'),
(109734, 2752, 29, 'Ổ đĩa Cứng'),
(109735, 2753, 29, 'Khó khăn w / o'),
(109736, 2754, 29, 'đã được liên kết với lần đến khám'),
(109737, 2755, 29, 'đã hết hạn'),
(109738, 2756, 29, 'Mã băm (Hash)'),
(109739, 2757, 29, 'Không tồn tại mã băm (hash) cho tập tin này. Đã tạo mã băm mới.'),
(109740, 2758, 29, 'Mã băm (Hash) không phù hợp. Tính toàn vẹn dữ liệu đã bị vi phạm.'),
(109741, 2760, 29, 'Tiếng Hawai'),
(109742, 2761, 29, 'Hoạt động Nguy hại'),
(109743, 2762, 29, 'Hoạt động nguy hại'),
(109744, 2763, 29, 'HCFA lề trái tại các điểm'),
(109745, 2764, 29, 'HCFA Lợi nhuận'),
(109746, 2765, 29, 'HCFA trên lề trong điểm'),
(109747, 2766, 29, 'Thủ tục / Dịch vụ HCPCS'),
(109748, 2767, 29, 'he PostCalendar '),
(109749, 2768, 29, 'Đầu'),
(109750, 2769, 29, 'CV Đầu'),
(109751, 2770, 29, 'Chu vi Đầu'),
(109752, 2771, 29, 'Nhức đầu'),
(109753, 2772, 29, 'Nhức đầu'),
(109754, 2773, 29, 'chăm sóc sức khỏe'),
(109755, 2774, 29, 'Vận Hành Chăm sóc sức khỏe'),
(109756, 2775, 29, 'Trung tâm y tế / phòng khám'),
(109757, 2776, 29, 'Tổ chức duy trì sức khoẻ'),
(109758, 2777, 29, 'Tổ chức bảo trì sức khỏe (HMO) Medicare rủi ro'),
(109759, 2778, 29, 'Giảm Thính lực'),
(109760, 2779, 29, 'Đau Tim'),
(109761, 2780, 29, 'Bệnh Tim'),
(109762, 2781, 29, 'Suy Tim'),
(109763, 2782, 29, 'Vấn đề về Tim'),
(109764, 2783, 29, 'Vấn đề về Tim'),
(109765, 2784, 29, 'Phẫu thuật Tim'),
(109766, 2785, 29, 'Ghép Tim'),
(109767, 2786, 29, 'TIM:'),
(109768, 2787, 29, 'Ợ nóng'),
(109769, 2788, 29, 'Nóng hoặc lạnh'),
(109770, 2789, 29, 'Nóng Hoặc Lạnh'),
(109771, 2791, 29, 'Tiếng Do Thái,'),
(109772, 2793, 29, 'HEENT'),
(109773, 2794, 29, 'Chiều cao'),
(109774, 2796, 29, 'Trợ giúp'),
(109775, 2797, 29, 'giúp đỡ'),
(109776, 2798, 29, 'Nôn ra máu'),
(109777, 2799, 29, 'Hematochezia'),
(109778, 2800, 29, 'Huyết học'),
(109779, 2801, 29, 'Tiểu máu'),
(109780, 2802, 29, 'Hemoglobin'),
(109781, 2803, 29, 'Hb A1c'),
(109782, 2804, 29, 'Ho ra máu'),
(109783, 2805, 29, 'Viêm gan siêu vi'),
(109784, 2806, 29, 'Viêm gan A 1'),
(109785, 2807, 29, 'Viêm gan A 2'),
(109786, 2808, 29, 'Viêm gan B 1'),
(109787, 2809, 29, 'Viêm gan B 2'),
(109788, 2810, 29, 'Viêm gan B 3'),
(109789, 2811, 29, 'đây'),
(109790, 2813, 29, 'Thoát vị sửa chữa'),
(109791, 2814, 29, 'Thoát vị đĩa'),
(109792, 2815, 29, 'Herpes'),
(109793, 2816, 29, 'Sự do dự'),
(109794, 2817, 29, 'heyyo. bạn đã ở đây trong '),
(109795, 2818, 29, 'Hib 1'),
(109796, 2819, 29, 'Hib 2'),
(109797, 2820, 29, 'Hib 3'),
(109798, 2821, 29, 'Hib 4'),
(109799, 2822, 29, 'Thành viên ẩn danh'),
(109800, 2823, 29, 'Quản Lý Sự kiện Ẩn'),
(109801, 2824, 29, 'Ẩn'),
(109802, 2825, 29, 'Giấu Chi tiết'),
(109803, 2827, 29, 'Ẩn Tùy chọn Mã hóa / Giải mã trong Quản lý Tài liệu'),
(109804, 2828, 29, 'Giấu Trình đơn'),
(109805, 2830, 29, 'Giấu các Nhắc nhở'),
(109806, 2831, 29, 'Giấu/Hiện Các cột'),
(109807, 2833, 29, 'Cao'),
(109808, 2834, 29, 'Cao Huyết áp'),
(109809, 2835, 29, 'Tiếng Hin-ddi'),
(109810, 2836, 29, 'Hông + háng'),
(109811, 2837, 29, 'Hông và háng'),
(109812, 2838, 29, 'Vấn đề Hông'),
(109813, 2839, 29, 'Thay thế Hông'),
(109814, 2840, 29, 'Đã nhận Thông báo HIPAA'),
(109815, 2842, 29, 'Hirsutism/Striae'),
(109816, 2843, 29, 'Tây Ban Nha'),
(109817, 2844, 29, 'Tây Ban Nha - Loại khác (Sinh ra tại Mỹ)'),
(109818, 2845, 29, 'Tây Ban Nha - Loại khác (Sinh ra bên ngoài Mỹ)'),
(109819, 2846, 29, 'Người Tây Ban Nha hoặc La tinh'),
(109820, 2847, 29, 'Lịch sử'),
(109821, 2848, 29, 'Lịch sử Dữ liệu'),
(109822, 2849, 29, 'Lịch sử ngày'),
(109823, 2851, 29, 'Lịch sử Róc Rách'),
(109824, 2852, 29, 'Lịch sử không được uỷ quyền'),
(109825, 2853, 29, 'Lịch sử của Róc Rách tim'),
(109826, 2854, 29, 'Lượt truy cập'),
(109827, 2855, 29, 'HIV'),
(109828, 2858, 29, 'Bộ xem HL7'),
(109829, 2860, 29, 'HMOL / L'),
(109830, 2861, 29, 'Tiếng Hmong'),
(109831, 2862, 29, 'Giữ [Ctrl] để lựa chọn nhiều mục hoặc để bỏ chọn'),
(109832, 2863, 29, 'Giữ phím Ctrl để chọn nhiều mục'),
(109833, 2864, 29, 'Giữ phím Ctrl để chọn nhiều đội'),
(109834, 2865, 29, 'Trang chủ'),
(109835, 2866, 29, 'Điện thoại nhà'),
(109836, 2867, 29, 'Số Điện thoại Nhà'),
(109837, 2868, 29, 'Vô gia cư hoặc tương tự?'),
(109838, 2869, 29, 'Vô gia cư, vv'),
(109839, 2870, 29, 'Vô gia cư, vv'),
(109840, 2872, 29, 'Tên Máy chủ'),
(109841, 2873, 29, 'Không thể để trống Tên Máy chủ'),
(109842, 2875, 29, 'Giờ'),
(109843, 2876, 29, 'Giờ'),
(109844, 2878, 29, 'Làm thế nào chấn thương xảy ra?'),
(109845, 2879, 29, 'Làm thế nào chấn thương xảy ra?:'),
(109846, 2880, 29, 'Làm thế nào họ biết về chúng tôi'),
(109847, 2881, 29, 'Truy vấn các sự kiện sắp tới cho bao nhiêu quý?'),
(109848, 2882, 29, 'HPI:'),
(109849, 2883, 29, 'HT'),
(109850, 2884, 29, 'HTML'),
(109851, 2886, 29, 'Https liên kết cho LLC LibreEHR Hỗ trợ dịch vụ Lab Exchange.'),
(109852, 2887, 29, 'Tiếng/Người Hungary'),
(109853, 2888, 29, 'Hylafax mục'),
(109854, 2889, 29, 'Hylafax Enscript lệnh');
INSERT INTO `lang_definitions` VALUES
(109855, 2890, 29, 'Hylafax máy chủ'),
(109856, 2891, 29, 'Hylafax máy chủ tên máy.'),
(109857, 2892, 29, 'Hiếu động'),
(109858, 2893, 29, 'Cao huyết áp'),
(109859, 2894, 29, 'Cao huyết áp: Đo Huyết Áp'),
(109860, 2895, 29, 'Cao huyết áp: Đo Huyết Áp (CQM)'),
(109861, 2896, 29, 'Cường giáp'),
(109862, 2897, 29, 'Suy giáp'),
(109863, 2898, 29, 'Cắt bỏ tử cung'),
(109864, 2899, 29, 'Tôi'),
(109865, 2900, 29, 'Tôi bận rộn trong thời gian này.'),
(109866, 2901, 29, 'Tôi không có sự cho phép đọc '),
(109867, 2902, 29, 'ICD'),
(109868, 2903, 29, 'Chẩn đoán ICD10'),
(109869, 2904, 29, 'Thủ tục / Dịch vụ ICD10'),
(109870, 2905, 29, 'ICD9'),
(109871, 2906, 29, 'Chẩn đoán ICD9'),
(109872, 2907, 29, 'Thủ tục / Dịch vụ ICD9'),
(109873, 2909, 29, 'Mã'),
(109874, 2910, 29, 'Mã'),
(109875, 2911, 29, 'Không thể để trống mã số'),
(109876, 2912, 29, 'CMND'),
(109877, 2913, 29, 'IDays'),
(109878, 2914, 29, 'xác định là'),
(109879, 2915, 29, 'Nhận dạng (một từ)'),
(109880, 2917, 29, 'Giây Timeout phiên nhàn rỗi'),
(109881, 2919, 29, 'Nếu tất cả các dữ liệu cho tất cả các cột được hoàn thành mẫu đơn này'),
(109882, 2920, 29, 'Nếu biện minh thanh toán được sử dụng nhập vào tên của loại mã chẩn đoán.'),
(109883, 2921, 29, 'nếu nhập vào, chỉ chọn những người đã có dịch vụ này'),
(109884, 2922, 29, 'Nếu tên, bất kỳ phần nào của họ hoặc họ, tên'),
(109885, 2923, 29, 'Nếu thanh toán bằng'),
(109886, 2924, 29, 'Nếu đã qua đời, thì nhập vào ngày mất.'),
(109887, 2925, 29, 'Nếu SMTP được dùng, tên máy hoặc địa chỉ IP của máy chủ.'),
(109888, 2926, 29, 'Nếu SMTP được dùng, số cổng TCP của máy chủ (thường là 25).'),
(109889, 2927, 29, 'nếu thất nghiệp thì nhập là Sinh viên'),
(109890, 2929, 29, 'Nếu bạn thay đổi e-RX Vai trò cho ePrescription, nó có thể ảnh hưởng đến công việc ePrescription. Nếu bạn phải đối mặt với bất kỳ khó khăn, hãy liên hệ với nhà cung cấp ePrescription của bạn.'),
(109891, 2931, 29, 'Nếu bạn đã chọn để tải lên chuyển tiền điện tử, sau đó cửa sổ tìm kiếm sẽ hiển thị lại với hoá đơn phù hợp từ các tập tin X12. Bạn có thể click vào bất kỳ của những con số hóa đơn (như mô tả dưới đây) nếu bạn muốn thực hiện bất kỳ chỉnh sửa trước khi thông tin chuyển tiền được áp dụng. Để áp dụng các thay đổi, hãy nhấp vào nút Process File ERA ở dưới cùng của trang. Điều này sẽ tạo ra một cửa sổ mới với một báo cáo chi tiết.'),
(109892, 2932, 29, 'Nếu bạn đã bước vào một ngày phải trả tiền trong các trang tìm kiếm, điều này sẽ ghi đè lên đăng ngày thanh toán và điều chỉnh nếu không được lấy từ các tập tin X12. Điều này có thể hữu ích cho mục đích báo cáo, nếu bạn muốn biên lai của bạn báo cáo sử dụng ngày đăng chứ không phải là công ty bảo hiểm ''s ngày chế biến. Lưu ý rằng điều này cũng sẽ ảnh hưởng đến ngày thanh toán và điều chỉnh trước khi được đưa vào tuyên bố thứ cấp.'),
(109893, 2933, 29, 'Nếu bạn muốn thay đổi các kiểu dữ liệu, hoặc thêm các hàng hoặc cột'),
(109894, 2934, 29, 'Nếu bạn muốn để nâng cấp cơ sở dữ liệu, sau đó đặt các tập tin zip cơ sở dữ liệu trong các thư mục sau đây'),
(109895, 2936, 29, 'Bỏ qua'),
(109896, 2937, 29, 'Bệnh tật'),
(109897, 2938, 29, 'Tiêm bắp'),
(109898, 2941, 29, 'Dịch vụ Hình ảnh'),
(109899, 2942, 29, 'Thuốc tiêm'),
(109900, 2943, 29, 'Mã Thuốc tiêm'),
(109901, 2945, 29, 'Ngày Thuốc tiêm'),
(109902, 2947, 29, 'Số Lô Thuốc tiêm'),
(109903, 2948, 29, 'Nhà sản xuất Thuốc tiêm'),
(109904, 2949, 29, 'Số đăng ký Thuốc tiêm'),
(109905, 2951, 29, 'Dịch vụ Tiêm chủng'),
(109906, 2952, 29, 'Tiêu đề Thuốc tiêm'),
(109907, 2953, 29, 'Thuốc tiêm'),
(109908, 2954, 29, 'Tiêm chủng'),
(109909, 2955, 29, 'Miễn dịch'),
(109910, 2956, 29, 'Cấy ghép'),
(109911, 2957, 29, 'Kết nhập'),
(109912, 2961, 29, 'Kết nhập giấy chứng nhận vào trình duyệt.'),
(109913, 2962, 29, 'Kết nhập Cấu hình'),
(109914, 2964, 29, 'Kết nhập Bệnh nhân'),
(109915, 2965, 29, 'Kết nhập Thông tin cá nhân của Bệnh nhân'),
(109916, 2966, 29, 'Mã Quan trọng'),
(109917, 2969, 29, 'Kết nhập từ Kế toán'),
(109918, 2972, 29, 'Đã cải thiện'),
(109919, 2973, 29, 'in'),
(109920, 2974, 29, 'TRONG'),
(109921, 2975, 29, 'vào mỗi mắt'),
(109922, 2976, 29, 'vào mắt trái'),
(109923, 2977, 29, 'vào lỗ mũi'),
(109924, 2978, 29, 'Trong Văn phòng'),
(109925, 2979, 29, 'vào mắt phải'),
(109926, 2980, 29, 'trong nhà'),
(109927, 2981, 29, 'Không hoạt động'),
(109928, 2982, 29, 'Ngày Không hoạt động'),
(109929, 2983, 29, 'Hộp thư đến'),
(109930, 2986, 29, 'Bao gồm Tổng kiểm'),
(109931, 2987, 29, 'Bao gồm cái đã hoàn thành'),
(109932, 2988, 29, 'Bao gồm các thành viên không dùng được'),
(109933, 2989, 29, 'Bao gồm cái chưa phân loại'),
(109934, 2990, 29, 'Bao gồm các dữ liệu phi cấu trúc'),
(109935, 2991, 29, 'Bao gồm Thể trạng'),
(109936, 2992, 29, 'Bao gồm các dữ liệu thể trạng?'),
(109937, 2993, 29, 'Việc bao gồm'),
(109938, 2994, 29, 'Thu nhập'),
(109939, 2996, 29, 'Không đầy đủ'),
(109940, 2997, 29, 'Điều trị không đầy đủ phá thai'),
(109941, 2998, 29, 'Tiểu không kiểm soát'),
(109942, 2999, 29, 'Kết hợp các kết quả xét nghiệm phòng thí nghiệm lâm sàng vào công nghệ EHR chứng nhận như là dữ liệu có cấu trúc.'),
(109943, 3001, 29, 'tăng:'),
(109944, 3002, 29, 'Bồi thường bảo hiểm'),
(109945, 3003, 29, 'Không xác định'),
(109946, 3004, 29, 'Ấn Độ'),
(109947, 3005, 29, 'Chỉ bất thường'),
(109948, 3006, 29, 'Cho biết nếu vấn đề này hiện đang hoạt động'),
(109949, 3008, 29, 'Chỉ số cho việc sử dụng chuyên ngành'),
(109950, 3009, 29, 'Nghèo khổ bệnh nhân'),
(109951, 3010, 29, 'Nghèo Bệnh nhân Báo cáo'),
(109952, 3011, 29, 'Indigents'),
(109953, 3014, 29, 'Gây ra phá thai'),
(109954, 3016, 29, 'Không đủ điều kiện'),
(109955, 3017, 29, 'Nhiễm trùng / áp xe'),
(109956, 3018, 29, 'Nhiễm trùng'),
(109957, 3019, 29, 'Infert Couns'),
(109958, 3020, 29, 'Vô sinh'),
(109959, 3021, 29, 'Cúm 1'),
(109960, 3022, 29, 'Cúm 2'),
(109961, 3023, 29, 'Chủng ngừa cúm cho bệnh nhân từ 50 tuổi trở lên'),
(109962, 3024, 29, 'Chủng ngừa cúm cho bệnh nhân từ 50 tuổi trở lên (CQM)'),
(109963, 3025, 29, 'Vắc-xin Cúm'),
(109964, 3026, 29, 'Thông tin'),
(109965, 3027, 29, 'Thông tin kiểm tra 1'),
(109966, 3028, 29, 'Thông tin kiểm tra 2'),
(109967, 3029, 29, 'Thông tin kiểm tra 3'),
(109968, 3030, 29, 'Thông tin kiểm tra 4'),
(109969, 3031, 29, 'Thông tin kiểm tra 5'),
(109970, 3032, 29, 'Thông tin kiểm tra 6'),
(109971, 3034, 29, 'hít'),
(109972, 3035, 29, 'inhilations'),
(109973, 3037, 29, 'Ban đầu người sử dụng'),
(109974, 3038, 29, 'Inj / Rehab'),
(109975, 3039, 29, 'Thuốc chích'),
(109976, 3040, 29, 'Tiêm'),
(109977, 3041, 29, 'Bị thương Body Part'),
(109978, 3042, 29, 'Bị thương Out'),
(109979, 3043, 29, 'Chấn thương'),
(109980, 3044, 29, 'Thương tích Cơ chế'),
(109981, 3045, 29, 'Báo cáo tai nạn thương tích Tổng quan'),
(109982, 3046, 29, 'Chấn thương giám sát'),
(109983, 3047, 29, 'Chấn thương Loại'),
(109984, 3048, 29, 'Tai nạn thương tích / bệnh tật liên quan đến'),
(109985, 3051, 29, 'Input Fields'),
(109986, 3052, 29, 'INR'),
(109987, 3053, 29, 'BH 1'),
(109988, 3054, 29, 'BH 2 hay BH 3'),
(109989, 3056, 29, 'Điều chỉnh BH'),
(109990, 3057, 29, 'Bao gộp BH'),
(109991, 3058, 29, 'Mã BH'),
(109992, 3061, 29, 'Trả dư BH'),
(109993, 3063, 29, 'Hoàn trả BH'),
(109994, 3064, 29, 'Tóm tắt BH'),
(109995, 3065, 29, 'BH1'),
(109996, 3066, 29, 'BH2'),
(109997, 3067, 29, 'BH3'),
(109998, 3069, 29, 'Chèn thất bại: '),
(109999, 3070, 29, 'Chèn các sự kiện cũ vào bảng'),
(110000, 3072, 29, 'Mất ngủ'),
(110001, 3074, 29, 'Kiểm tra'),
(110002, 3075, 29, 'Sự bất ổn / subluxation'),
(110003, 3076, 29, 'CÀI ĐẶT'),
(110004, 3077, 29, 'Cài đặt'),
(110005, 3079, 29, 'cài đặt DB'),
(110006, 3080, 29, 'Bản phát hành Được cài đặt'),
(110007, 3081, 29, 'Hướng dẫn'),
(110008, 3082, 29, 'Hướng dẫn'),
(110009, 3084, 29, 'Hướng dẫn:'),
(110010, 3085, 29, 'Không đủ hàng cho mã sản phẩm'),
(110011, 3086, 29, 'Insulin phụ thuộc Bệnh tiểu đường'),
(110012, 3087, 29, 'Bảo hiểm'),
(110013, 3088, 29, 'bảo hiểm'),
(110014, 3091, 29, 'Cân đối Bảo hiểm'),
(110015, 3093, 29, 'Cty Bảo hiểm'),
(110016, 3094, 29, 'Công ty Bảo hiểm'),
(110017, 3095, 29, 'Công ty Bảo hiểm'),
(110018, 3096, 29, 'Tìm kiếm / Thêm Công ty Bảo hiểm'),
(110019, 3098, 29, 'Dữ liệu Bảo hiểm'),
(110020, 3099, 29, 'Thông tin bảo hiểm trong hồ sơ'),
(110021, 3100, 29, 'Số Bảo hiểm'),
(110022, 3101, 29, 'Bảo hiểm Thanh toán'),
(110023, 3103, 29, 'Nhà cung cấp Bảo hiểm'),
(110024, 3106, 29, 'Đã bảo hiểm'),
(110025, 3107, 29, 'Lượng Kết luận'),
(110026, 3108, 29, 'Intake ngày'),
(110027, 3109, 29, 'Trí tuệ Từ chối'),
(110028, 3113, 29, 'Lỗi nội bộ - không có các trang đã được lựa chọn!'),
(110029, 3114, 29, 'Lỗi nội bộ - ID bệnh nhân không được cung cấp!'),
(110030, 3115, 29, 'Lỗi nội bộ truy cập vào tập tin tải lên!'),
(110031, 3116, 29, 'Lỗi nội bộ!'),
(110032, 3117, 29, 'Lỗi nội bộ, không ID thuốc quy định!'),
(110033, 3119, 29, 'Lỗi nội bộ: yêu cầu bồi thường '),
(110034, 3120, 29, 'Lỗi nội bộ: cuộc gặp gỡ '''),
(110035, 3121, 29, 'Lỗi nội bộ: pid hoặc cuộc gặp gỡ là mất tích.'),
(110036, 3123, 29, 'Nhận dạng nội bộ (pid)'),
(110037, 3126, 29, 'Nội bộ Giới thiệu tham gia'),
(110038, 3127, 29, 'Nội bộ Thời gian thu'),
(110039, 3128, 29, 'Quốc tế Duty'),
(110040, 3129, 29, 'Thông dịch viên'),
(110041, 3130, 29, 'Cần thông dịch viên không?'),
(110042, 3131, 29, 'Bệnh kẽ phổi'),
(110043, 3132, 29, 'Khoảng thời gian'),
(110044, 3135, 29, 'Can thiệp'),
(110045, 3137, 29, 'Không khoan dung'),
(110046, 3139, 29, 'tiêm bắp'),
(110047, 3140, 29, 'tĩnh mạch'),
(110048, 3141, 29, 'Giới thiệu'),
(110049, 3144, 29, 'Không hợp lệ nhân vật trong'),
(110050, 3147, 29, 'Không hợp lệ chiều dài cho'),
(110051, 3148, 29, 'Không hợp lệ nhân vật không phải số'),
(110052, 3149, 29, 'Đối tượng nộp không hợp lệ hoặc thiếu trong mã nguồn cho mã '),
(110053, 3151, 29, 'Không hợp lệ dịch vụ Mã'),
(110054, 3152, 29, 'Chỉ nguồn không hợp lệ "'),
(110055, 3154, 29, 'InvAmt'),
(110056, 3155, 29, 'Kiểm kê'),
(110057, 3156, 29, 'Hoạt động Kiểm kê'),
(110058, 3157, 29, 'Kiểm kê và bán cả hai loại thuốc và sản phẩm không là thuốc'),
(110059, 3158, 29, 'Chỉ kiểm kê và bán thuốc'),
(110060, 3159, 29, 'Hàng tồn kho là không có sẵn cho lệnh này.'),
(110061, 3160, 29, 'Hàng tồn kho Danh sách'),
(110062, 3161, 29, 'Kiểm kê giao dịch'),
(110063, 3162, 29, 'Hoá đơn'),
(110064, 3163, 29, 'hóa đơn'),
(110065, 3166, 29, 'Hoá đơn ngày'),
(110066, 3167, 29, 'Hoá đơn đã không có ngày!'),
(110067, 3168, 29, 'Hóa đơn số'),
(110068, 3169, 29, 'Số hóa đơn tham khảo'),
(110069, 3170, 29, 'Hoá đơn tài liệu tham khảo số lượng hồ bơi, nếu được sử dụng'),
(110070, 3171, 29, 'Tập hợp Số Tham chiếu Hóa đơn'),
(110071, 3172, 29, 'Tập hợp Số TC Hóa đơn'),
(110072, 3173, 29, 'Hóa đơn:'),
(110073, 3174, 29, 'IPPF'),
(110074, 3177, 29, 'IPPF SRH Data for'),
(110075, 3178, 29, 'IPPF Statistics Report'),
(110076, 3179, 29, 'IPPF Stats'),
(110077, 3180, 29, 'IPV 1'),
(110078, 3181, 29, 'IPV 2'),
(110079, 3182, 29, 'IPV 3'),
(110080, 3183, 29, 'IPV 4'),
(110081, 3185, 29, 'Không thường xuyên Heart Beat'),
(110082, 3186, 29, 'Khó chịu'),
(110083, 3187, 29, 'Kích thích'),
(110084, 3191, 29, 'là một lĩnh vực cần thiết.'),
(110085, 3192, 29, 'là một nút gốc và không thể bị xóa.'),
(110086, 3197, 29, 'là không hợp lệ (phân số thập phân là OK).'),
(110087, 3198, 29, 'PHP bằng cách sử dụng chế độ Safe Mode?'),
(110088, 3200, 29, 'Có dịch văn bản trong các bố trí biểu mẫu không?'),
(110089, 3201, 29, 'Có dịch văn bản trong các danh sách không?'),
(110090, 3202, 29, 'Đến tập tin được mã hóa?'),
(110091, 3204, 29, 'Đây có phải là một loại chẩn đoán không?'),
(110092, 3212, 29, 'Có giấu loại này trong bảng lệ phí không?'),
(110093, 3214, 29, 'quá dài'),
(110094, 3216, 29, 'Rắc rối'),
(110095, 3217, 29, 'rắc rối'),
(110096, 3218, 29, 'Ngày gặp Rắc rối'),
(110097, 3219, 29, 'Mã số Rắc rối'),
(110098, 3220, 29, 'Tựa đề Rắc rối'),
(110099, 3223, 29, 'Rắc rối'),
(110100, 3224, 29, 'Rắc rối (Chấn thương / Nội khoa / Dị ứng)'),
(110101, 3225, 29, 'Rắc rối (Chấn thương / Nội khoa / Dị ứng):'),
(110102, 3226, 29, 'Rắc rối và Lần khám'),
(110103, 3227, 29, 'Rắc rối và Lần khám của'),
(110104, 3228, 29, 'Các vấn đề không được uỷ quyền'),
(110105, 3229, 29, 'Đề mục Rắc rối'),
(110106, 3230, 29, 'Tiếng Ý'),
(110107, 3231, 29, 'Mục'),
(110108, 3232, 29, 'mục'),
(110109, 3234, 29, 'Các mục tải không thành công'),
(110110, 3235, 29, 'IU / L'),
(110111, 3236, 29, 'Vòng tránh thai'),
(110112, 3237, 29, 'Tiêm tĩnh mạch'),
(110113, 3238, 29, 'Tháng Một'),
(110114, 3239, 29, 'Tháng Một'),
(110115, 3240, 29, 'Tiếng Nhật'),
(110116, 3241, 29, 'Vàng da'),
(110117, 3243, 29, 'Mô tả Công việc'),
(110118, 3244, 29, 'Mã Công việc'),
(110119, 3245, 29, 'Phần lệch mạng'),
(110120, 3246, 29, 'Đau khớp'),
(110121, 3247, 29, 'Phần bong gân'),
(110122, 3248, 29, 'Tháng Bảy'),
(110123, 3249, 29, 'Tháng Bảy'),
(110124, 3250, 29, 'Tháng Sáu'),
(110125, 3251, 29, 'Tháng Sáu'),
(110126, 3252, 29, 'Ngay dưới các thông tin kiểm tra là một khu vực màu xanh nơi bạn đặt các thông số tìm kiếm của bạn. Bạn có thể tìm kiếm theo tên bệnh nhân, biểu đồ, gặp phải số hoặc ngày của dịch vụ, hoặc bất kỳ sự kết hợp nào trong số này. Bạn cũng có thể chọn xem bạn có muốn xem tất cả các hoá đơn, hoá đơn mở, hoặc hoá đơn chỉ là do (bệnh nhân). Nhấp vào nút Tìm kiếm để thực hiện tìm kiếm.'),
(110127, 3253, 29, 'Chỉ của Tôi'),
(110128, 3255, 29, 'Biện minh cho'),
(110129, 3256, 29, 'Justify / Lưu'),
(110130, 3258, 29, 'k, đây là phần còn lại'),
(110131, 3264, 29, 'Khóa'),
(110132, 3265, 29, 'Từ khóa'),
(110133, 3266, 29, 'kg'),
(110134, 3267, 29, 'kg/m^2'),
(110135, 3269, 29, 'Ung thư Thận'),
(110136, 3270, 29, 'Suy thận'),
(110137, 3271, 29, 'Nhiễm trùng Thận'),
(110138, 3272, 29, 'Sỏi Thận'),
(110139, 3273, 29, 'Ghép Thận'),
(110140, 3277, 29, 'Đầu gối'),
(110141, 3278, 29, 'Vấn đề với đầu gối'),
(110142, 3279, 29, 'Thay thế đầu gối'),
(110143, 3282, 29, 'Tiếng Hàn Quốc'),
(110144, 3286, 29, 'Phòng thí nghiệm'),
(110145, 3288, 29, 'Địa chỉ trang web phòng thí nghiệm Trao đổi'),
(110146, 3289, 29, 'Site ID Lab Trao đổi'),
(110147, 3290, 29, 'Phòng thí nghiệm Trao đổi Mã Số ID'),
(110148, 3294, 29, 'Trạng thái Hỏi Phòng thí nghiệm'),
(110149, 3295, 29, 'Báo cáo Thí nghiệm'),
(110150, 3296, 29, 'Kết quả Thí nghiệm'),
(110151, 3297, 29, 'Kết quả Thí nghiệm'),
(110152, 3299, 29, 'Báo cáo Kết quả Thí nghiệm'),
(110153, 3300, 29, 'Dịch vụ Thí nghiệm'),
(110154, 3301, 29, 'Kết quả Phòng thí nghiệm Thử nghiệm'),
(110155, 3303, 29, 'Nhãn'),
(110156, 3304, 29, 'Label không có thể được để trống'),
(110157, 3305, 29, 'Nhãn cột'),
(110158, 3307, 29, 'LabelCols phải là một số giữa 1 và 999'),
(110159, 3308, 29, 'Nhãn'),
(110160, 3311, 29, 'Phòng thí nghiệm'),
(110161, 3312, 29, 'Rách / tình trạng da'),
(110162, 3313, 29, 'Rách / mài mòn'),
(110163, 3316, 29, 'Ngôn ngữ'),
(110164, 3317, 29, 'Mã Ngôn ngữ'),
(110165, 3318, 29, 'Đã thêm định nghĩa ngôn ngữ'),
(110166, 3319, 29, 'Công cụ Ngôn ngữ Giao diện'),
(110167, 3320, 29, 'Danh sách ngôn ngữ (viết, addonly tùy chọn)'),
(110168, 3321, 29, 'Tên Ngôn ngữ'),
(110169, 3322, 29, 'Ngôn ngữ:'),
(110170, 3324, 29, 'Tiếng Lào'),
(110171, 3325, 29, 'Họ'),
(110172, 3326, 29, 'Ngày Hoạt động Trước đây'),
(110173, 3328, 29, 'Ngày Hóa đơn Trước đây:'),
(110174, 3330, 29, 'Năm Ngoái'),
(110175, 3333, 29, 'Lần gặp Trước'),
(110176, 3343, 29, 'Tháng trước'),
(110177, 3344, 29, 'Họ'),
(110178, 3345, 29, 'Họ'),
(110179, 3346, 29, 'Họ:'),
(110180, 3350, 29, 'Lần xem xét Trước đây'),
(110181, 3352, 29, 'Lưu Lần cuối'),
(110182, 3356, 29, 'Cập nhật lần cuối bởi'),
(110183, 3357, 29, 'Xác nhận Lần cuối Ngày'),
(110184, 3358, 29, 'Lần Đến khám cuối'),
(110185, 3360, 29, 'Tái phát chậm (2-12 Tháng)'),
(110186, 3361, 29, 'Bên mắt cá'),
(110187, 3362, 29, 'Bên mắt cá:'),
(110188, 3363, 29, 'Tay thuận'),
(110189, 3364, 29, 'Tay thuận của thủ tục này, nếu áp dụng'),
(110190, 3365, 29, 'bên cửa PMI:'),
(110191, 3373, 29, 'Dựa trên Bố trí'),
(110192, 3374, 29, 'Trình sửa Bố trí'),
(110193, 3375, 29, 'Các nhóm bố trí'),
(110194, 3376, 29, 'Kiểu mẫu Bố trí'),
(110195, 3378, 29, 'Biểu mẫu Đến khám Dựa trên Bố trí'),
(110196, 3379, 29, 'Bố trí'),
(110197, 3380, 29, 'lb'),
(110198, 3381, 29, 'lbs'),
(110199, 3382, 29, 'LDL'),
(110200, 3383, 29, 'để trống nếu vẫn còn đang bị'),
(110201, 3384, 29, 'Để trống Để Giữ Tên tập tin gốc'),
(110202, 3385, 29, 'Để trống để giữ nguyên không thay đổi mật khẩu.'),
(110203, 3386, 29, 'Để lại tin nhắn với'),
(110204, 3387, 29, 'Để lại Mẫu'),
(110205, 3388, 29, 'Bỏ trống cụm từ vượt qua sẽ không mã hóa các tài liệu'),
(110206, 3390, 29, 'Còn lại'),
(110207, 3391, 29, 'Tai Trái'),
(110208, 3392, 29, 'tai trái'),
(110209, 3394, 29, 'Còn lại:'),
(110210, 3395, 29, 'Còn lại: '),
(110211, 3396, 29, 'Đau chân / chuột rút'),
(110212, 3397, 29, 'Pháp lý'),
(110213, 3400, 29, 'Chú thích:'),
(110214, 3401, 29, 'Chiều dài'),
(110215, 3402, 29, 'Chiều dài của bộ biến đổi, 0 nếu không có'),
(110216, 3403, 29, 'Ít hơn'),
(110217, 3404, 29, 'Ít hơn hoặc bằng'),
(110218, 3405, 29, 'Ít thông tin cá nhân (viết addonly tùy chọn)'),
(110219, 3406, 29, 'Thư'),
(110220, 3407, 29, 'Thư Generator'),
(110221, 3409, 29, 'Giấy bác sĩ những dấu hiệu'),
(110222, 3410, 29, 'Giấy viết thư mà bệnh nhân có dấu hiệu'),
(110223, 3411, 29, 'Mức độ cấp bách'),
(110224, 3412, 29, 'Trách nhiệm pháp lý'),
(110225, 3413, 29, 'Trách nhiệm pháp lý y tế'),
(110226, 3414, 29, 'Giấy phép/ID'),
(110227, 3419, 29, 'LicensedPrescriber tên cuối cùng'),
(110228, 3420, 29, 'LicensedPrescriber NPI'),
(110229, 3421, 29, 'LicensedPrescriber UPIN'),
(110230, 3423, 29, 'Lối sống'),
(110231, 3424, 29, 'Lối sống tình trạng'),
(110232, 3425, 29, 'Rách hay bong gân dây chằng'),
(110233, 3428, 29, 'Giới hạn của sự kiện'),
(110234, 3431, 29, 'Liên kết'),
(110235, 3433, 29, 'Liên kết'),
(110236, 3436, 29, 'liên kết để tài liệu'),
(110237, 3438, 29, 'Danh sách'),
(110238, 3439, 29, 'Hộp danh sách'),
(110239, 3440, 29, 'hộp danh sách'),
(110240, 3441, 29, 'hộp danh sách w / thêm'),
(110241, 3442, 29, 'Danh sách hộp w / add'),
(110242, 3443, 29, 'Danh sách biên tập'),
(110243, 3444, 29, 'Danh sách gặp'),
(110244, 3445, 29, 'Danh sách các nhóm'),
(110245, 3446, 29, 'Công ty Danh sách Bảo hiểm'),
(110246, 3448, 29, 'Danh sách các mục không thể bắt đầu với một số.'),
(110247, 3449, 29, 'Danh sách các mục có chứa ký tự bất hợp pháp (s).'),
(110248, 3451, 29, 'Danh sách danh sách'),
(110249, 3452, 29, 'Danh sách Name'),
(110250, 3453, 29, 'Tên danh sách không có thể bắt đầu với những con số.'),
(110251, 3454, 29, 'Danh sách Đơn thuốc'),
(110252, 3455, 29, 'Danh sách được sử dụng bởi Quốc gia Loại trên dữ liệu tùy chọn.'),
(110253, 3456, 29, 'Danh sách được sử dụng bởi Nhà nước Loại trên dữ liệu tùy chọn.'),
(110254, 3457, 29, 'Cổng lắng nghe của máy chủ syslog TLS 5425 RFC.'),
(110255, 3458, 29, 'Danh sách'),
(110256, 3460, 29, 'Living Will'),
(110257, 3461, 29, 'LLL:'),
(110258, 3462, 29, 'LMP'),
(110259, 3464, 29, 'Tải định nghĩa'),
(110260, 3470, 29, 'LOADING'),
(110261, 3471, 29, 'Tải tập tin vào cơ sở dữ liệu. Điều này sẽ mất một thời gian ...'),
(110262, 3472, 29, 'LOC'),
(110263, 3473, 29, 'Nội bộ'),
(110264, 3476, 29, 'Địa phương'),
(110265, 3477, 29, 'Nơi'),
(110266, 3478, 29, 'Địa điểm'),
(110267, 3479, 29, 'vị trí của máy libreehr và có thể chứa dữ liệu nhạy cảm, vì vậy nó được khuyến khích để tự xóa các tập tin sau khi sử dụng của nó'),
(110268, 3480, 29, 'Vị trí của rất nhiều này'),
(110269, 3481, 29, 'Vị trí không xác định'),
(110270, 3482, 29, 'Vị trí nơi Hylafax cửa hàng fax.'),
(110271, 3483, 29, 'Vị trí nơi được lưu trữ quét.'),
(110272, 3484, 29, 'Đến từ:'),
(110273, 3485, 29, 'Khóa'),
(110274, 3492, 29, 'Đăng nhập'),
(110275, 3494, 29, 'Thoát'),
(110276, 3495, 29, 'Đăng nhập'),
(110277, 3496, 29, 'Đăng nhập như'),
(110278, 3497, 29, 'Đăng nhập như: '),
(110279, 3498, 29, 'Đăng xuất.'),
(110280, 3500, 29, 'Đăng nhập'),
(110281, 3501, 29, 'đăng nhập'),
(110282, 3505, 29, 'Đăng xuất'),
(110283, 3506, 29, 'đăng xuất'),
(110284, 3507, 29, 'Các bản ghi'),
(110285, 3508, 29, 'Các bản ghi Viewer'),
(110286, 3510, 29, 'Look Up'),
(110287, 3511, 29, 'Lô hàng'),
(110288, 3512, 29, 'Thiếu Mã Lô hàng!'),
(110289, 3513, 29, 'Số Lô'),
(110290, 3514, 29, 'Thấp'),
(110291, 3516, 29, 'Hạ chân'),
(110292, 3519, 29, 'Thắt lưng cột sống'),
(110293, 3520, 29, 'TRƯA'),
(110294, 3521, 29, 'Ăn trưa'),
(110295, 3522, 29, 'Ung thư phổi'),
(110296, 3523, 29, 'Ung thư phổi phẫu thuật'),
(110297, 3524, 29, 'Phổi:'),
(110298, 3525, 29, 'Phổi:'),
(110299, 3526, 29, 'Lupus'),
(110300, 3528, 29, 'M'),
(110301, 3529, 29, 'MA Thể loại'),
(110302, 3530, 29, 'MA Khách hàng chấp nhận phá thai'),
(110303, 3531, 29, 'MA Thống kê'),
(110304, 3533, 29, 'Đã gửi Thư'),
(110305, 3534, 29, 'Chính'),
(110306, 3535, 29, 'Địa chỉ Chính'),
(110307, 3536, 29, 'Cửa sổ màn hình chính'),
(110308, 3537, 29, 'Duy trì danh sách hoạt động dị ứng thuốc.'),
(110309, 3538, 29, 'Duy trì danh sách thuốc đang hoạt động.'),
(110310, 3539, 29, 'Duy trì một danh sách vấn đề up-to-ngày của chẩn đoán hiện tại và hoạt động.'),
(110311, 3540, 29, 'Sửa đổi danh mục hiện tại.'),
(110312, 3541, 29, 'Hãy bổ nhiệm mới cho'),
(110313, 3542, 29, 'Hãy chắc chắn rằng "'),
(110314, 3543, 29, 'Các tập tin văn bản hàng loạt để tải lên Clearing House và sẽ đánh dấu như lập hoá đơn'),
(110315, 3545, 29, 'Tình trạng bất ổn:'),
(110316, 3548, 29, 'Nam'),
(110317, 3549, 29, 'Nam Bao cao su'),
(110318, 3550, 29, 'Nam VSC'),
(110319, 3552, 29, 'Chụp quang tuyến vú'),
(110320, 3553, 29, 'Quản lý'),
(110321, 3556, 29, 'Quản lý dịch'),
(110322, 3557, 29, 'Quản lý'),
(110323, 3558, 29, 'Thông tin bắt buộc hoặc được chọn'),
(110324, 3559, 29, 'Chỉ có thông tin bắt buộc hoặc được chọn, kiểm tra trùng lặp, không tìm kiếm'),
(110325, 3560, 29, 'Chỉ có thông tin bắt buộc hoặc được chọn, có tìm kiếm và kiểm tra trùng lặp'),
(110326, 3561, 29, 'Hướng dẫn sử dụng'),
(110327, 3562, 29, 'Hướng dẫn Viết bài'),
(110328, 3563, 29, 'Nhà sản xuất'),
(110329, 3565, 29, 'Tháng Ba'),
(110330, 3568, 29, 'Tháng Ba'),
(110331, 3569, 29, 'Tình trạng Hôn nhân'),
(110332, 3571, 29, 'Đánh dấu là thanh toán lập hoá đơn nhưng bỏ qua'),
(110333, 3572, 29, 'Đánh dấu đã rà phá'),
(110334, 3573, 29, 'Đánh dấu như không lập hoá đơn'),
(110335, 3575, 29, 'Được đánh dấu như xóa'),
(110336, 3576, 29, 'Đã kết hôn'),
(110337, 3578, 29, 'Mask'),
(110338, 3579, 29, 'Mặt nạ cho Số Hóa đơn'),
(110339, 3580, 29, 'Mặt nạ cho Mã Bệnh nhân'),
(110340, 3581, 29, 'Mặt cho Mã Sản phẩm'),
(110341, 3582, 29, 'Phù hợp với'),
(110342, 3591, 29, 'Max'),
(110343, 3594, 29, 'Hàm trên phải:'),
(110344, 3595, 29, 'Tuổi tối đa'),
(110345, 3597, 29, 'Tối đa thời gian nhàn rỗi trong vài giây trước khi đăng xuất. Mặc định là 7.200 (2 giờ).'),
(110346, 3603, 29, 'Tháng Năm'),
(110347, 3604, 29, 'MC'),
(110348, 3605, 29, 'mcg'),
(110349, 3607, 29, 'Phương tiện không có của ba mật khẩu được cho phép khi thay đổi mật khẩu.'),
(110350, 3609, 29, 'Đo Mã Nhóm'),
(110351, 3611, 29, 'Đo lường'),
(110352, 3612, 29, 'Medial mắt cá:'),
(110353, 3613, 29, 'Medicaid'),
(110354, 3614, 29, 'Nội khoa'),
(110355, 3615, 29, 'Phá thai Nội khoa'),
(110356, 3616, 29, 'Quản trị Nội khoa'),
(110357, 3617, 29, 'Lịch sử Nội khoa'),
(110358, 3618, 29, 'Rắc rối Nội khoa'),
(110359, 3619, 29, 'Rắc rối nội khoa'),
(110360, 3620, 29, 'Vấn đề nội khoa'),
(110361, 3623, 29, 'Vấn đề Nội khoa'),
(110362, 3624, 29, 'Hồ sơ Nội khoa'),
(110363, 3625, 29, 'Số Hồ sơ Nội khoa'),
(110364, 3626, 29, 'Hồ sơ Nội khoa'),
(110365, 3627, 29, 'Đã gửi Hồ sơ Nội khoa'),
(110366, 3629, 29, 'Đã đưa Tóm lược Nội khoa'),
(110367, 3630, 29, 'Hệ thống Nội khoa'),
(110368, 3631, 29, 'Loại Nội khoa'),
(110369, 3632, 29, 'Nội khoa / Lịch sử (tùy chọn cho ghi, chỉ được thêm)'),
(110370, 3633, 29, 'Chăm sóc y tế Phần B'),
(110371, 3634, 29, 'Medicare giới thiệu là Renderer'),
(110372, 3635, 29, 'Thuốc men'),
(110373, 3636, 29, 'Danh sách Dị ứng Thuốc'),
(110374, 3638, 29, 'Danh sách Thuốc men'),
(110375, 3639, 29, 'Đã thực hiện Kiểm tra Thuốc men?'),
(110376, 3640, 29, 'Thuốc men'),
(110377, 3641, 29, 'Thuốc men:'),
(110378, 3642, 29, 'Liều Thuốc'),
(110379, 3643, 29, 'Trung bình'),
(110380, 3645, 29, 'Báo cáo Thống kê thành viên Hiệp hội'),
(110381, 3646, 29, 'Bộ nhớ vấn đề'),
(110382, 3647, 29, 'Đàn ông'),
(110383, 3648, 29, 'Đàn ông và phụ nữ'),
(110384, 3649, 29, 'Men Only'),
(110385, 3650, 29, 'Có kinh nguyệt'),
(110386, 3651, 29, 'Thời kỳ mãn kinh'),
(110387, 3652, 29, 'Kinh nguyệt dòng'),
(110388, 3653, 29, 'Kinh nguyệt Tần số'),
(110389, 3654, 29, 'Bệnh tâm thần'),
(110390, 3661, 29, 'Tin nhắn'),
(110391, 3662, 29, 'Trung tâm Tin nhắn và Nhắc nhở'),
(110392, 3665, 29, 'Đã gửi Tin nhắn'),
(110393, 3666, 29, 'Trạng thái Tin nhắn'),
(110394, 3670, 29, 'TIN NHẮN:'),
(110395, 3671, 29, 'Tin nhắn'),
(110396, 3672, 29, 'Tin nhắn bạn đã gửi hôm nay'),
(110397, 3673, 29, 'Phương pháp'),
(110398, 3674, 29, 'Phương pháp và sản phẩm cụ thể'),
(110399, 3675, 29, 'Phương pháp gửi email gửi đi.'),
(110400, 3676, 29, 'Phương pháp hủy diệt'),
(110401, 3677, 29, 'Mexico / MexAmer / Chicano'),
(110402, 3679, 29, 'mg'),
(110403, 3680, 29, 'mg/1cc'),
(110404, 3681, 29, 'mg/2cc'),
(110405, 3682, 29, 'mg/3cc'),
(110406, 3683, 29, 'mg/4cc'),
(110407, 3684, 29, 'mg/5cc'),
(110408, 3685, 29, 'MG / DL'),
(110409, 3686, 29, 'Tên đệm'),
(110410, 3687, 29, 'Tên đệm'),
(110411, 3688, 29, 'Tên đệm'),
(110412, 3690, 29, 'Midlevel Prescriber DEA'),
(110413, 3691, 29, 'Midlevel tên Prescriber đầu tiên'),
(110414, 3692, 29, 'Midlevel tên Prescriber cuối'),
(110415, 3693, 29, 'Midlevel Prescriber Tiền tố'),
(110416, 3694, 29, 'Midlevel Prescriber UPIN'),
(110417, 3695, 29, 'Vẻ người'),
(110418, 3696, 29, 'Người nhập cư hoặc lao động theo mùa?'),
(110419, 3697, 29, 'Nhập cư/Theo mùa'),
(110420, 3698, 29, 'Triệu / CU.MM'),
(110421, 3702, 29, 'Kiểu MIME'),
(110422, 3703, 29, 'Phút'),
(110423, 3704, 29, 'phút'),
(110424, 3705, 29, 'Tuổi Tối thiểu'),
(110425, 3706, 29, 'Chủng doanh nhỏ + / - viêm màng hoạt dịch'),
(110426, 3708, 29, 'Phút'),
(110427, 3709, 29, 'phút'),
(110428, 3710, 29, 'Phút'),
(110429, 3712, 29, 'L.tinh'),
(110430, 3713, 29, 'Misc Thanh toán Tùy chọn'),
(110431, 3714, 29, 'Misc Thanh toán lựa chọn cho HCFA-1500'),
(110432, 3715, 29, 'Tùy chọn Thanh toán Linh tinh HCFA'),
(110433, 3716, 29, 'Linh tinh'),
(110434, 3717, 29, 'Bị thiếu'),
(110435, 3718, 29, 'thiếu'),
(110436, 3719, 29, 'Thiếu một thông tin cần thiết'),
(110437, 3720, 29, 'Thiếu Phí'),
(110438, 3721, 29, 'Thiếu Mods'),
(110439, 3722, 29, 'Thiếu hoặc Không hợp lệ'),
(110440, 3723, 29, 'Thiếu PID.'),
(110441, 3724, 29, 'Thiếu ngày báo cáo'),
(110442, 3725, 29, 'Thiếu dấu gạch chéo sau khi đối tượng nộp trong mã nguồn cho mã '),
(110443, 3726, 29, 'Hỗn hợp'),
(110444, 3727, 29, 'ml'),
(110445, 3728, 29, 'MM / DD / YYYY'),
(110446, 3729, 29, 'mm / hg'),
(110447, 3730, 29, 'mmHg'),
(110448, 3731, 29, 'MMR 1'),
(110449, 3732, 29, 'MMR 2'),
(110450, 3733, 29, 'Điện thoại di động'),
(110451, 3734, 29, 'Điện thoại di động'),
(110452, 3735, 29, 'Mod'),
(110453, 3741, 29, 'Modifier'),
(110454, 3742, 29, 'Bộ biến đổi'),
(110455, 3745, 29, 'Sửa đổi khoản thanh toán'),
(110456, 3746, 29, 'Độ dài BBĐ'),
(110457, 3753, 29, 'Thứ 2'),
(110458, 3754, 29, 'Thứ 2 đến Thứ 6'),
(110459, 3755, 29, 'Thứ 2, Thứ 4 &amp; Thứ 6'),
(110460, 3756, 29, 'Thứ Hai'),
(110461, 3758, 29, 'Tháng'),
(110462, 3759, 29, 'tháng'),
(110463, 3760, 29, 'Xem theo Tháng'),
(110464, 3761, 29, 'Tháng'),
(110465, 3762, 29, 'Thu nhập Hàng tháng'),
(110466, 3763, 29, 'Tháng'),
(110467, 3765, 29, 'Hơn 100 hồ sơ được tìm thấy. Hãy thu hẹp tiêu chí tìm kiếm của bạn.'),
(110468, 3766, 29, 'Hơn 50 kết quả, xin vui lòng tìm kiếm của bạn cụ thể hơn.'),
(110469, 3768, 29, 'Gần đây:'),
(110470, 3770, 29, 'Thể trạng gần đây nhất từ:'),
(110471, 3771, 29, 'Mẹ'),
(110472, 3772, 29, 'Tên của mẹ'),
(110473, 3774, 29, 'Miệng'),
(110474, 3775, 29, 'Di chuyển'),
(110475, 3776, 29, 'Di chuyển tài liệu đến Thể loại:'),
(110476, 3777, 29, 'Dời Xuống'),
(110477, 3779, 29, 'Di chuyển đến Bệnh nhân'),
(110478, 3780, 29, 'Di chuyển tới ...'),
(110479, 3781, 29, 'Dời Lên'),
(110480, 3783, 29, 'Ông'),
(110481, 3785, 29, 'Bà'),
(110482, 3786, 29, 'Bà'),
(110483, 3796, 29, 'Multi Language Tool'),
(110484, 3797, 29, 'Nhiều khu vực'),
(110485, 3799, 29, 'Nhiều Rất nhiều'),
(110486, 3802, 29, 'Đa chủng tộc'),
(110487, 3803, 29, 'Thán:'),
(110488, 3804, 29, 'Musc Ache'),
(110489, 3805, 29, 'Musc nhức'),
(110490, 3806, 29, 'Musc Đỏ'),
(110491, 3807, 29, 'Musc độ cứng'),
(110492, 3808, 29, 'Musc sưng'),
(110493, 3809, 29, 'Musc ấm'),
(110494, 3810, 29, 'Cơ bắp'),
(110495, 3811, 29, 'Cơ chấn thương'),
(110496, 3812, 29, 'Cơ xương khớp'),
(110497, 3813, 29, 'Phải có sản phẩm nào nếu không được sử dụng xác thực SMTP.'),
(110498, 3814, 29, 'Lẫn nhau Xác định'),
(110499, 3815, 29, 'MVA'),
(110500, 3818, 29, 'Bản thân tôi'),
(110501, 3821, 29, 'N / A'),
(110502, 3822, 29, 'n / a'),
(110503, 3823, 29, 'Tên'),
(110504, 3825, 29, 'Tên (Nhấn vào đây để biết thêm)'),
(110505, 3826, 29, 'Tên 1'),
(110506, 3827, 29, 'Tên 2'),
(110507, 3828, 29, 'Tên và Chức danh của Người quản trị Tiêm chủng'),
(110508, 3831, 29, 'Tên của Sự kiện'),
(110509, 3832, 29, 'Tên của công ty bảo hiểm'),
(110510, 3833, 29, 'Tên của Nhà cung cấp'),
(110511, 3834, 29, 'Tên của người gửi các nhắc nhở bệnh nhân.'),
(110512, 3835, 29, 'Tên dịch'),
(110513, 3836, 29, 'Tên / Giá trị'),
(110514, 3837, 29, 'Tên:'),
(110515, 3838, 29, 'NARES:'),
(110516, 3839, 29, 'NARES: Bình thường phải'),
(110517, 3840, 29, 'Niêm mạc mũi màu hồng, vách ngăn đường giữa'),
(110518, 3841, 29, 'Đất nước Ghi chú'),
(110519, 3842, 29, 'Ghi chú Nation Cấu hình'),
(110520, 3844, 29, 'Quốc tịch'),
(110521, 3845, 29, 'NationNotes'),
(110522, 3847, 29, 'Thổ Dân Hawaii hoặc Người Đảo Thái Bình Dương'),
(110523, 3852, 29, 'Buồn nôn'),
(110524, 3854, 29, 'Vùng chuyển hướng'),
(110525, 3855, 29, 'Vùng chuyển hướng bao gồm các biểu mẫu khám'),
(110526, 3856, 29, 'Vùng chuyển hướng sử dụng hết chiều cao của bộ khung'),
(110527, 3857, 29, 'Các biểu mẫu Đến khám trong Vùng Chuyển hướng'),
(110528, 3858, 29, 'Độ rộng Vùng Chuyển hướng'),
(110529, 3859, 29, 'Danh mục chuyển hướng có các cặp nút chọn'),
(110530, 3860, 29, 'Danh mục chuyển hướng có dạng cây'),
(110531, 3861, 29, 'Vùng chuyển hướng dùng danh mục dạng trượt'),
(110532, 3862, 29, 'NDC'),
(110533, 3864, 29, 'NDC Số'),
(110534, 3866, 29, 'Cổ'),
(110535, 3867, 29, 'Cổ vấn đề'),
(110536, 3868, 29, 'Cổ dẻo'),
(110537, 3869, 29, 'Cần phải nhập một mô tả'),
(110538, 3870, 29, 'Cần phải nhập một giá trị trở lại'),
(110539, 3871, 29, 'Cần nhập định danh'),
(110540, 3872, 29, 'Cần phải nhập tiêu đề'),
(110541, 3873, 29, 'Cần Auth'),
(110542, 3874, 29, 'Nhu cầu Justify'),
(110543, 3875, 29, 'Nhu cầu thanh toán trung học'),
(110544, 3876, 29, 'Tiêu cực'),
(110545, 3877, 29, 'Phủ định'),
(110546, 3880, 29, 'Dây thần kinh bị thương'),
(110547, 3881, 29, 'Tình trạng thần kinh / tổn thương thần kinh'),
(110548, 3882, 29, 'Thần kinh tê'),
(110549, 3883, 29, 'Điểm yếu Thần kinh'),
(110550, 3884, 29, 'Thần kinh'),
(110551, 3885, 29, 'Không bao giờ'),
(110552, 3886, 29, 'Không bao giờ uống rượu'),
(110553, 3887, 29, 'Không bao giờ hút thuốc'),
(110554, 3888, 29, 'Mới'),
(110555, 3889, 29, 'Mới =>'),
(110556, 3890, 29, 'New chất nhận'),
(110557, 3892, 29, 'Dị ứng Mới'),
(110558, 3894, 29, 'Cuộc hẹn Mới'),
(110559, 3895, 29, 'Các thể loại Mới'),
(110560, 3896, 29, 'Thể loại Mới'),
(110561, 3897, 29, 'Các khách hàng Mới'),
(110562, 3898, 29, 'Tư vấn Mới'),
(110563, 3899, 29, 'New Crop'),
(110564, 3900, 29, 'Đã thêm bộ định nghĩa mới'),
(110565, 3901, 29, 'Tài liệu mới'),
(110566, 3904, 29, 'Lần khám Mới'),
(110567, 3905, 29, 'Đã tạo lần khám mới với mã số'),
(110568, 3906, 29, 'Biểu mẫu Lần khám Mới'),
(110569, 3907, 29, 'Không được quyền tạo lần khám mới'),
(110570, 3908, 29, 'Lần khám Mới'),
(110571, 3909, 29, 'Cơ sở thông tin mới'),
(110572, 3912, 29, 'Nhóm Mới'),
(110573, 3913, 29, 'Thông tin Nhóm Mới'),
(110574, 3914, 29, 'New inj / Trạng thái'),
(110575, 3916, 29, 'Giới hạn các sự kiện mới'),
(110576, 3917, 29, 'Danh sách Mới'),
(110577, 3918, 29, 'Đơn đặt hàng Mới'),
(110578, 3919, 29, 'Đoạn văn Mới'),
(110579, 3920, 29, 'Mật khẩu Mới'),
(110580, 3921, 29, 'Bệnh nhân Mới'),
(110581, 3922, 29, 'BỆNH NHÂN MỚI'),
(110582, 3923, 29, 'Lần khám Bệnh nhân Mới'),
(110583, 3924, 29, 'Biểu mẫu Bệnh nhân Mới'),
(110584, 3925, 29, 'Mã Bệnh nhân Mới'),
(110585, 3926, 29, 'Lần thanh toán Mới'),
(110586, 3928, 29, 'New Pt'),
(110587, 3929, 29, 'Kết quả mới từ phòng thí nghiệm Exchange'),
(110588, 3930, 29, 'Tìm kiếm Mới'),
(110589, 3931, 29, 'New Submissions'),
(110590, 3932, 29, 'Người dùng Mới'),
(110591, 3934, 29, 'Lần đến Mới'),
(110592, 3935, 29, 'Thêm / Tìm kiếm'),
(110593, 3936, 29, 'NewCrop Trạng thái Tài khoản'),
(110594, 3937, 29, 'NewCrop Quản trị'),
(110595, 3938, 29, 'NewCrop không gọi được'),
(110596, 3939, 29, 'NewCrop Bác sĩ'),
(110597, 3944, 29, 'NewCrop eRx Tên'),
(110598, 3945, 29, 'NewCrop eRx Tên Đối tác'),
(110599, 3946, 29, 'NewCrop eRx Mật khẩu'),
(110600, 3947, 29, 'Vai trò NewCrop eRX'),
(110601, 3948, 29, 'Vai trò NewCrop eRx'),
(110602, 3949, 29, 'NewCrop eRx Địa chỉ'),
(110603, 3954, 29, 'NewCrop eRx Địa chỉ Dịch vụ Web'),
(110604, 3955, 29, 'NewCrop Người quản lý'),
(110605, 3956, 29, 'NewCrop Đầu mục thuốc'),
(110606, 3957, 29, 'NewCrop midlevel Prescriber'),
(110607, 3958, 29, 'NewCrop Y tá'),
(110608, 3959, 29, 'NewCrop Bác sĩ Giám sát'),
(110609, 3961, 29, 'Báo'),
(110610, 3962, 29, 'Tiếp theo'),
(110611, 3964, 29, 'Ngày Hôm sau'),
(110612, 3965, 29, 'Tháng Sau'),
(110613, 3966, 29, 'Tháng sau (giữ để hiện trình đơn)'),
(110614, 3968, 29, 'Tuần Sau'),
(110615, 3969, 29, 'Năm sau (giữ để hiện trình đơn)'),
(110616, 3971, 29, 'Biệt danh'),
(110617, 3973, 29, 'Đổ Mồ hôi Trộm'),
(110618, 3974, 29, 'Nl ext cơ quan sinh dục, VAG niêm mạc, cổ tử cung'),
(110619, 3975, 29, 'Không'),
(110620, 3976, 29, 'KHÔNG'),
(110621, 3977, 29, 'Không truy cập'),
(110622, 3978, 29, 'Không có nhắc nhở về bệnh nhân đang làm.'),
(110623, 3979, 29, 'Không có adenopathy (2 khu vực cần thiết)'),
(110624, 3980, 29, 'Không có loại điều chỉnh được tìm thấy lý do cho'),
(110625, 3981, 29, 'Không có sự dịu dàng adnexal / khối lượng'),
(110626, 3983, 29, 'Không có cuộc hẹn'),
(110627, 3985, 29, 'Không có hệ thống thanh toán đang hoạt động'),
(110628, 3987, 29, 'Không có Bills tìm thấy để Bao gồm trong OFX xuất khẩu <br>'),
(110629, 3989, 29, 'Không có mã đã được quy định!'),
(110630, 3992, 29, 'Không có chẩn đoán'),
(110631, 3993, 29, 'Các tài liệu tìm thấy'),
(110632, 3995, 29, 'Không có ngày kết thúc'),
(110633, 3996, 29, 'Không có mục được tìm thấy, sử dụng mẫu dưới đây để thêm một mục nhập.'),
(110634, 3997, 29, 'Không có lỗi được tìm thấy'),
(110635, 3998, 29, 'Không có sự kiện'),
(110636, 4001, 29, 'Không có nhóm được lựa chọn'),
(110637, 4002, 29, 'Không thoát vị'),
(110638, 4005, 29, 'Không có thương tích / bệnh tật'),
(110639, 4006, 29, 'Không tìm thấy công ty bảo hiểm nào'),
(110640, 4007, 29, 'Không có rắc rối'),
(110641, 4009, 29, 'Không có mục nào theo thể loại được chọn'),
(110642, 4010, 29, 'Không có mục nào được lựa chọn!'),
(110643, 4025, 29, 'Không có tập tin nhật ký nào cho ngày được chọn'),
(110644, 4027, 29, 'Không có quần chúng, nhạy cảm'),
(110645, 4028, 29, 'Không tìm thấy hồ sơ Bệnh nhân với mã nhận dạng Re đã cho.'),
(110646, 4030, 29, 'Không tìm thấy thông tin đó.'),
(110647, 4031, 29, 'Không tìm thấy thông tin đó. Tạo bệnh nhân mới không?'),
(110648, 4033, 29, 'Không tìm thấy kết quả mới'),
(110649, 4034, 29, 'Không có ghi chú'),
(110650, 4035, 29, 'Không có ogrganomegoly'),
(110651, 4036, 29, 'Không mở được tìm thấy cho giai đoạn này.'),
(110652, 4037, 29, 'Không có số điện thoại khác được liệt kê'),
(110653, 4039, 29, 'Đối tác tìm thấy'),
(110654, 4040, 29, 'Không có hồ sơ bệnh nhân được tìm thấy cho các tiêu chí lựa chọn cho'),
(110655, 4041, 29, 'Không có hồ sơ bệnh nhân được tìm thấy cho mã nhận dạng cho Re'),
(110656, 4042, 29, 'Không có phù ngoại vi'),
(110657, 4043, 29, 'Không Tìm thấy Nhà thuốc nào'),
(110658, 4044, 29, 'Không Tìm thấy Toa thuốc nào'),
(110659, 4045, 29, 'Hiện không có bệnh / chấn thương'),
(110660, 4046, 29, 'Không có đầu mục trước.'),
(110661, 4047, 29, 'Không có Thực thể Kinh doanh Chính nào được trong trong danh sách cơ sở'),
(110662, 4051, 29, 'Không Tìm thấy Nhà cung cấp nào'),
(110663, 4052, 29, 'Không có phát ban hoặc các tổn thương bất thường'),
(110664, 4053, 29, 'Không tìm thấy hồ sơ'),
(110665, 4055, 29, 'Không tìm thấy hồ sơ. Vui lòng mở rộng tiêu chí tìm kiếm của bạn.'),
(110666, 4056, 29, 'Không có nhắc nhở'),
(110667, 4057, 29, 'Không tìm thấy kết quả nào cho tiêu chí tìm kiếm trên.'),
(110668, 4058, 29, 'Không có Kết quả'),
(110669, 4060, 29, 'Không Tìm thấy Kết quả nào'),
(110670, 4062, 29, 'Không có kết quả, vui lòng thử lại.'),
(110671, 4063, 29, 'Không có kết quả, vui lòng thử lại.'),
(110672, 4065, 29, 'Chưa Đến'),
(110673, 4067, 29, 'Không Đau xoang:'),
(110674, 4068, 29, 'Không có dimpling da hoặc các nốt vú'),
(110675, 4069, 29, 'KHÔNG TÊN BỐI CẢNH ĐÓ'),
(110676, 4071, 29, 'Không có đau tinh hoàn, quần chúng'),
(110677, 4072, 29, 'Không có cảm giác mạnh hoặc cố nhấc'),
(110678, 4075, 29, 'Không có chuyến thăm'),
(110679, 4076, 29, 'Chưa ghi nhận thể trạng nào.'),
(110680, 4077, 29, 'Không, Hủy bỏ'),
(110681, 4079, 29, 'Không:'),
(110682, 4080, 29, 'Nocturia'),
(110683, 4081, 29, 'Không trả tiền'),
(110684, 4082, 29, 'Không báo cáo Báo cáo'),
(110685, 4083, 29, 'Không cụ thể chấn thương'),
(110686, 4084, 29, 'Không điện tử'),
(110687, 4085, 29, 'Bệnh tiểu đường phụ thuộc Insulin'),
(110688, 4087, 29, 'SRH y tế'),
(110689, 4088, 29, 'Không SRH Phi Y Tế'),
(110690, 4089, 29, 'Không có'),
(110691, 4090, 29, 'không có'),
(110692, 4091, 29, 'Không xác định'),
(110693, 4092, 29, 'Không có gì được ghi nhận'),
(110694, 4093, 29, 'Không có trong danh sách trên'),
(110695, 4094, 29, 'Hàng phân phối Top thể là hoàn toàn trống.'),
(110696, 4095, 29, 'Noninsulin phụ thuộc Bệnh tiểu đường'),
(110697, 4096, 29, 'Cũng không'),
(110698, 4097, 29, 'Bình thường'),
(110699, 4098, 29, 'Bình thường BL'),
(110700, 4099, 29, 'Kiểm tra Tim Bình thường:'),
(110701, 4100, 29, 'Kiểm tra Tim Bình thường: '),
(110702, 4101, 29, 'Kiểm tra Phổi Bình thường:'),
(110703, 4102, 29, 'Kiểm tra Phổi Bình thường: '),
(110704, 4103, 29, 'Lần khám ở Văn phòng Bình thường'),
(110705, 4104, 29, 'Hầu họng Bình thường:'),
(110706, 4105, 29, 'Bên phải Bình thường'),
(110707, 4106, 29, 'Bên phải Bình thường:'),
(110708, 4107, 29, 'Xem Bình thường'),
(110709, 4108, 29, 'bình thường:'),
(110710, 4109, 29, 'Thông thường điều này nên được đánh dấu. Không liên quan đến kiểm soát truy cập.'),
(110711, 4112, 29, 'Tiếng Na Uy'),
(110712, 4115, 29, 'Mũi'),
(110713, 4116, 29, 'Sự chảy máu mũi'),
(110714, 4117, 29, 'không phải là một ký tự hoặc số'),
(110715, 4119, 29, 'Một số mã hay loại mã không yêu cầu tất cả thông tin.'),
(110716, 4120, 29, 'Không được phép'),
(110717, 4121, 29, 'Không được phép xóa nhóm Quản trị viên'),
(110718, 4122, 29, 'Không được phép để chỉnh sửa'),
(110719, 4123, 29, 'Không được phép ngừng hoạt động tất cả các đối tượng bảo mật'),
(110720, 4124, 29, 'Không được phép ngừng hoạt động bất cứ điều gì từ các quản trị viên ACL'),
(110721, 4125, 29, 'Không được phép loại bỏ các người sử dụng quản trị từ các nhóm quản trị viên'),
(110722, 4126, 29, 'Không được phép để loại bỏ người dùng khỏi nhóm quản trị'),
(110723, 4128, 29, 'Không được uỷ quyền truy cập PostCalendar mô-đun'),
(110724, 4129, 29, 'Không được uỷ quyền'),
(110725, 4130, 29, 'Không được ủy quyền'),
(110726, 4132, 29, 'Không được uỷ quyền cho đội này.'),
(110727, 4135, 29, 'Không có'),
(110728, 4137, 29, 'Không lập hoá đơn'),
(110729, 4138, 29, 'Không kiểm tra'),
(110730, 4139, 29, 'Không kiểm tra ra'),
(110731, 4141, 29, 'Không Do'),
(110732, 4143, 29, 'Không được kiểm tra'),
(110733, 4144, 29, 'Không được kiểm tra:'),
(110734, 4145, 29, 'Không được kiểm tra: '),
(110735, 4146, 29, 'không tìm thấy'),
(110736, 4148, 29, 'không tìm thấy!'),
(110737, 4149, 29, 'Không phải gốc Tây Ban Nha hoặc La tinh'),
(110738, 4152, 29, 'Chưa từng thấy từ'),
(110739, 4154, 29, 'Gửi Tuy nhiên,'),
(110740, 4156, 29, 'Không rõ.'),
(110741, 4157, 29, 'Ghi chú'),
(110742, 4158, 29, 'Mã Ghi chú'),
(110743, 4159, 29, 'Lưu ý nó sẽ mất 5-10 phút để hoàn toàn xử lý sau khi bạn nhấp vào Cài đặt'),
(110744, 4160, 29, 'Lưu ý nó sẽ mất 5-10 phút để hoàn toàn xử lý sau khi bạn nhấp vào Nâng cấp'),
(110745, 4161, 29, 'Lưu ý rằng Kiểm toán Đăng nhập cần phải được kích hoạt ở trên'),
(110746, 4162, 29, 'Loại Ghi chú'),
(110747, 4168, 29, 'Lưu ý: Mã này đã không được nhập vào bởi một người dùng có thẩm quyền. Mã số duy nhất được ủy quyền có thể được tải lên Mạng Thanh toán Mở y tế để xử lý. Nếu bạn muốn tải lên các mã số, hãy chọn một người dùng có thẩm quyền ở đây.'),
(110748, 4170, 29, 'Chú ý: Nếu những tập tin đang tải lên có tên trùng với những tập tin đã có sẽ được tự động đổi tên (ví dụ, file.jpg sẽ trở thành file.1.jpg). Việc kiểm tra tên tập tin không trùng lặp được thực hiện cho mỗi bệnh nhân, không phải cho mỗi thể loại.'),
(110749, 4171, 29, 'Chú ý: Nếu những tập tin đang tải lên có tên trùng với những tập tin đã có sẽ được tự động đổi tên (ví dụ, ''<i>file.jpg</i>'' sẽ trở thành ''<i>file.1.jpg</i>''). Việc kiểm tra tên tập tin không trùng lặp được thực hiện cho mỗi bệnh nhân, không phải cho mỗi thể loại.'),
(110750, 4172, 29, 'Ghi chú'),
(110751, 4173, 29, 'Ghi chú - bất kỳ cuộc gặp gỡ (viết, addonly tùy chọn)'),
(110752, 4174, 29, 'Ghi chú - cuộc gặp gỡ của tôi (viết, addonly tùy chọn)'),
(110753, 4175, 29, 'Ghi chú không được uỷ quyền'),
(110754, 4177, 29, 'Không Ghi nhận gì'),
(110755, 4179, 29, 'Không có Dị ứng để kết nhập'),
(110756, 4180, 29, 'Không có Toa thuốc để kết nhập'),
(110757, 4182, 29, 'Không chọn gì'),
(110758, 4184, 29, 'THÔNG BÁO :: PostCalendar thông tin / Sửa đổi'),
(110759, 4185, 29, 'Thông báo'),
(110760, 4186, 29, 'Địa chỉ khai báo Email'),
(110761, 4188, 29, 'Thông báo'),
(110762, 4189, 29, 'Thông báo cho quản trị Giới thiệu những thông tin sự kiện / Sửa đổi?'),
(110763, 4190, 29, 'Tháng Mười một'),
(110764, 4191, 29, 'Tháng Mười một'),
(110765, 4192, 29, 'Bây giờ gửi bài cho:'),
(110766, 4193, 29, 'Bây giờ in'),
(110767, 4194, 29, 'Bây giờ in báo cáo stmt_count và cập nhật những cuộc gặp gỡ.'),
(110768, 4195, 29, 'Bây giờ in báo cáo stmt_count và cập nhật hoá đơn.'),
(110769, 4196, 29, 'Bây giờ in ấn báo cáo stmt_count, cuộc gặp gỡ sẽ không được cập nhật.'),
(110770, 4197, 29, 'Bây giờ in ấn báo cáo stmt_count, hóa đơn sẽ không được cập nhật.'),
(110771, 4198, 29, 'NPI'),
(110772, 4199, 29, 'NQF'),
(110773, 4200, 29, 'Số'),
(110774, 4201, 29, 'Số phòng thí nghiệm'),
(110775, 4204, 29, 'Số cột trong xem năm.'),
(110776, 4211, 29, 'Số ngày giấy chứng nhận của khách hàng là hợp lệ.'),
(110777, 4213, 29, 'Số chữ số sau dấu thập phân cho tiền tệ, thường là 0 hoặc 2.'),
(110778, 4214, 29, 'Số lần khám sẽ được hiển thị trên mỗi trang.'),
(110779, 4215, 29, 'Số lượng của trò chơi hoặc các sự kiện bị mất, nếu có'),
(110780, 4216, 29, 'Số giờ trước để gửi các thông báo email.'),
(110781, 4217, 29, 'Số giờ trước để gửi thông báo điện thoại.'),
(110782, 4218, 29, 'Số giờ trước để gửi tin nhắn SMS thông báo.'),
(110783, 4221, 29, 'Số các cột lịch sử trong quá khứ'),
(110784, 4223, 29, 'Tê'),
(110785, 4224, 29, 'Tử số'),
(110786, 4225, 29, 'Chữ số rõ ràng Theo'),
(110787, 4227, 29, 'Dinh dưỡng'),
(110788, 4229, 29, 'O.A.F.V.'),
(110789, 4230, 29, 'O2 Sat'),
(110790, 4231, 29, 'Béo phì tôi'),
(110791, 4232, 29, 'Béo phì II'),
(110792, 4233, 29, 'Béo phì III'),
(110793, 4234, 29, 'Mục tiêu (Objective)'),
(110794, 4237, 29, 'Nghề Nghiệp'),
(110795, 4239, 29, 'Lần xuất hiện'),
(110796, 4240, 29, 'Tháng Mười'),
(110797, 4241, 29, 'Tháng Mười'),
(110798, 4242, 29, 'Mỗi ngày một viên'),
(110799, 4243, 29, 'của'),
(110800, 4244, 29, 'với số lượng'),
(110801, 4245, 29, 'thuốc viên'),
(110802, 4246, 29, 'của mỗi tháng'),
(110803, 4247, 29, 'Ghi chú Vp'),
(110804, 4248, 29, 'Tắt'),
(110805, 4249, 29, 'Ghi chú Văn phòng'),
(110806, 4250, 29, 'Lần Đến Văn phòng'),
(110807, 4251, 29, 'Chất lượng các biện pháp chính thức lâm sàng (CQM) Nhóm Đo lường'),
(110808, 4252, 29, 'Liên kết ngoại vi Https cho Portal bệnh nhân.'),
(110809, 4254, 29, 'Cổng thông tin bệnh nhân ngoại vi mật khẩu'),
(110810, 4255, 29, 'Mật khẩu Portal Bệnh nhân ngoại vi (Đặt Trống Nếu không đăng).'),
(110811, 4258, 29, 'Địa chỉ trang web Cổng thông tin bệnh nhân ngoại vi'),
(110812, 4260, 29, 'Tên đăng nhập Portal Bệnh nhân ngoại vi'),
(110813, 4261, 29, 'Tên đăng nhập Portal Bệnh nhân ngoại vi (Đặt Trống Nếu không đăng).'),
(110814, 4263, 29, 'Con cái'),
(110815, 4265, 29, 'thuốc mỡ'),
(110816, 4267, 29, 'OK'),
(110817, 4269, 29, 'OK để liên kết các vấn đề GCAC ngày'),
(110818, 4270, 29, 'Xưa'),
(110819, 4272, 29, 'Old Khách hàng'),
(110820, 4273, 29, 'Old gãy xương không / malunion'),
(110821, 4274, 29, 'Bố trí với phong cách cũ không có danh mục bên trái'),
(110822, 4275, 29, 'Biễu mẫu tĩnh với phong cách cũ không có tìm kiếm hoặc kiểm tra trùng lặp');
INSERT INTO `lang_definitions` VALUES
(110823, 4279, 29, 'Bỏ qua thông tin người sử dụng lao động trong thông tin cá nhân bệnh nhân'),
(110824, 4280, 29, 'Bỏ qua Người sử dụng lao động'),
(110825, 4281, 29, 'Bỏ hình thức, cách dùng và khoảng thời gian là một phần của liều lượng'),
(110826, 4282, 29, 'Bỏ bảo hiểm và một số thứ khác khỏi biểu mẫu thông tin cá nhân'),
(110827, 4283, 29, 'Bỏ qua người dùng nội bộ?'),
(110828, 4284, 29, 'Bỏ phương thức thanh toán khỏi bảng đồng chi trả'),
(110829, 4285, 29, 'bỏ qua để autoassign'),
(110830, 4286, 29, 'trên'),
(110831, 4287, 29, 'Bật'),
(110832, 4288, 29, 'Trên Tay'),
(110833, 4289, 29, 'Trong Đơn hàng'),
(110834, 4290, 29, 'Tại Địa điểm'),
(110835, 4291, 29, 'Khi Cơ sở Kinh doanh Chính được chọn, không nên thay đổi nó. Việc thay đổi cơ sở sẽ ảnh hưởng sự hoạt động của NewCrop ePrescription.'),
(110836, 4292, 29, 'Một khi bạn thay đổi mật khẩu của mình, bạn sẽ phải đăng nhập lại.'),
(110837, 4297, 29, 'Hỗ trợ Trực tuyến'),
(110838, 4298, 29, 'Liên kết Hỗ trợ Trực tuyến'),
(110839, 4299, 29, 'Chỉ có cái có hiệu lực'),
(110840, 4302, 29, 'chỉ khi vị trí thanh toán'),
(110841, 4303, 29, 'Chỉ có cái không hiệu lực'),
(110842, 4304, 29, 'Chỉ có Của tôi'),
(110843, 4307, 29, 'Chỉ tải lên các toa thuốc có hiệu lực'),
(110844, 4310, 29, 'Khởi phát bệnh:'),
(110845, 4311, 29, 'Khởi phát bệnh: '),
(110846, 4312, 29, 'Khởi phát Sưng:'),
(110847, 4313, 29, 'Ngày Khởi phát / Nhập viện:'),
(110848, 4314, 29, 'Địa chỉ Cổng thông tin Bệnh nhân'),
(110849, 4315, 29, 'Ối!'),
(110850, 4316, 29, 'Mở'),
(110851, 4321, 29, 'Mở Đến khám Hôm nay'),
(110852, 4322, 29, 'LibreEHR đã có một Certificate Authority cấu hình.'),
(110853, 4324, 29, 'LibreEHR Cơ sở dữ liệu Nâng cấp'),
(110854, 4325, 29, 'LibreEHR Nâng cấp cơ sở dữ liệu cho De-nhận dạng'),
(110855, 4327, 29, 'LibreEHR phải được cấu hình để sử dụng giấy chứng nhận trước khi nó có thể tạo các chứng chỉ của khách hàng.'),
(110856, 4328, 29, 'LibreEHR yêu cầu Javascript để thực hiện xác thực người dùng.'),
(110857, 4329, 29, 'LibreEHR Người dùng'),
(110858, 4330, 29, 'Hở'),
(110859, 4332, 29, 'Nhãn khoa'),
(110860, 4333, 29, 'Tùy chọn'),
(110861, 4335, 29, 'Tùy chọn hỗ trợ theo dõi tồn kho và bán hàng của sản phẩm'),
(110862, 4336, 29, 'Tùy chọn'),
(110863, 4337, 29, 'Tùy chọn loại tên cho một hình ảnh thẻ ID có thể được xem từ trang tóm tắt bệnh nhân.'),
(110864, 4338, 29, 'Tùy chọn loại tên cho hình ảnh hình ảnh có thể được xem từ trang tóm tắt bệnh nhân.'),
(110865, 4339, 29, 'Tùy chọn loại tên của một tài liệu liên kết đến từ trang tóm tắt bệnh nhân. Cho phép bạn nhấn chuột vào một tên bệnh nhân để xem thẻ ID của họ.'),
(110866, 4340, 29, 'Tùy chọn mặc định phạm vi cho các mục hướng dẫn sử dụng của kết quả'),
(110867, 4341, 29, 'Tùy chọn mặc định đơn vị cho các mục hướng dẫn sử dụng của kết quả'),
(110868, 4342, 29, 'Tùy chọn Tên Đích đến'),
(110869, 4343, 29, 'Tùy chọn tên thuốc, sử dụng % như là một ký tự đại diện'),
(110870, 4345, 29, 'Thông tin thêm về sự kiện này'),
(110871, 4346, 29, 'Rất nhiều số tùy chọn, sử dụng% như là một ký tự đại diện'),
(110872, 4347, 29, 'Tùy chọn số bệnh nhân ID'),
(110873, 4348, 29, 'Tùy chọn thủ tục mã'),
(110874, 4350, 29, 'Tùy chọn'),
(110875, 4351, 29, 'Hoặc'),
(110876, 4352, 29, 'HOẶC'),
(110877, 4353, 29, 'hoặc chọn'),
(110878, 4354, 29, 'hoặc nhấp chuột và kéo để lựa chọn nhanh hơn.'),
(110879, 4356, 29, 'Hoặc Out To'),
(110880, 4358, 29, 'hoặc Shift-Click để giảm'),
(110881, 4359, 29, 'Hoặc tải lên tập tin ERA:'),
(110882, 4360, 29, 'Uống'),
(110883, 4361, 29, 'Niêm mạc miệng màu hồng, cổ họng rõ ràng'),
(110884, 4362, 29, 'Thứ tự'),
(110885, 4363, 29, 'Trình tự, kết quả loại'),
(110886, 4364, 29, 'Bảng kê Đơn hàng'),
(110887, 4365, 29, 'Ngày Đặt hàng'),
(110888, 4367, 29, 'Đặt hàng Từ'),
(110889, 4369, 29, 'Số thứ tự phải là một con số giữa 1 và 999'),
(110890, 4370, 29, 'Tên Đơn hàng'),
(110891, 4371, 29, 'Thứ tự Ưu tiên'),
(110892, 4372, 29, 'Trình tự Thủ tục'),
(110893, 4375, 29, 'Trạng thái Đơn hàng'),
(110894, 4378, 29, 'Loại Đặt hàng'),
(110895, 4380, 29, 'Đặt hàng / Kết Quả Thể loại'),
(110896, 4381, 29, 'Đã đặt hàng'),
(110897, 4384, 29, 'Thứ tự cung cấp'),
(110898, 4386, 29, 'Cơ quan tổn thương'),
(110899, 4387, 29, 'Tổ chức'),
(110900, 4388, 29, 'Tên Tổ chức'),
(110901, 4389, 29, 'Tên Đơn vị Tổ chức'),
(110902, 4390, 29, 'Tổ chức'),
(110903, 4391, 29, 'Định hướng x 3'),
(110904, 4392, 29, 'Nguyên gốc'),
(110905, 4396, 29, 'Hầu họng: '),
(110906, 4397, 29, 'Khó thở'),
(110907, 4398, 29, 'Dung dịch uống'),
(110908, 4399, 29, 'Osetoarthritis'),
(110909, 4402, 29, 'Khác'),
(110910, 4403, 29, 'khác'),
(110911, 4404, 29, 'Khác (ghi rõ)'),
(110912, 4405, 29, 'Khác - Chỉ định'),
(110913, 4406, 29, 'Chương trình Liên Bang khác'),
(110914, 4407, 29, 'Khác HCFA'),
(110915, 4408, 29, 'Các chấn thương khác chưa được chi tiết'),
(110916, 4410, 29, 'khác tháng'),
(110917, 4411, 29, 'Chương trình Không Liên bang Khác'),
(110918, 4412, 29, 'Ghi chú Khác'),
(110919, 4413, 29, 'Các triệu chứng Phù hợp Khác'),
(110920, 4414, 29, 'Các triệu chứng Phù hợp Khác:'),
(110921, 4415, 29, 'Các pt resp khác'),
(110922, 4416, 29, 'Tổn thương do căn thẳng/quá liều khác'),
(110923, 4417, 29, 'Phẫu thuật Khác'),
(110924, 4418, 29, 'Liên quan đến Phá thai Khác/Chung chung'),
(110925, 4420, 29, 'Ngôn ngữ khác'),
(110926, 4421, 29, 'nếu không bạn sẽ phá hủy các tham chiếu đến/từ dữ liệu hiện có.'),
(110927, 4422, 29, 'Ottawa mắt cá Rules'),
(110928, 4423, 29, 'Đường uống'),
(110929, 4424, 29, 'NGOÀI'),
(110930, 4425, 29, 'Ngoài Văn phòng'),
(110931, 4426, 29, 'Giới thiệu Ra ngoài'),
(110932, 4427, 29, 'Kết quả'),
(110933, 4428, 29, 'Outlook'),
(110934, 4431, 29, 'QUÁ HẠN'),
(110935, 4432, 29, 'Việc sử dụng quá'),
(110936, 4434, 29, 'Thừa cân'),
(110937, 4435, 29, 'Ghi đè lên HIPAA sự lựa chọn'),
(110938, 4437, 29, 'Oxygen Saturation'),
(110939, 4439, 29, 'P'),
(110940, 4440, 29, 'sau khi ăn'),
(110941, 4441, 29, 'chiều tối'),
(110942, 4442, 29, 'khi cần'),
(110943, 4443, 29, 'Đảo Thái Bình Dương'),
(110944, 4444, 29, 'Paedeatric'),
(110945, 4445, 29, 'Trang'),
(110946, 4446, 29, 'Trang'),
(110947, 4447, 29, 'Trả'),
(110948, 4448, 29, 'Trả số tiền mà bạn sẽ phân bổ'),
(110949, 4450, 29, 'Thanh toán qua'),
(110950, 4451, 29, 'Đau'),
(110951, 4453, 29, 'Sự nhảy động'),
(110952, 4455, 29, 'Pap Smear'),
(110953, 4458, 29, 'Tê liệt'),
(110954, 4461, 29, 'Phân tích cú pháp HL7'),
(110955, 4463, 29, 'Đối tác'),
(110956, 4464, 29, 'Đối tác Tên'),
(110957, 4467, 29, 'Mật khẩu'),
(110958, 4468, 29, 'Mật khẩu để giải mã tài liệu'),
(110959, 4469, 29, 'Bệnh nhân Qua đời'),
(110960, 4470, 29, 'Cảnh báo Thụ động'),
(110961, 4471, 29, 'Quy tắc Cảnh báo Thụ động'),
(110962, 4472, 29, 'Mật khẩu'),
(110963, 4473, 29, 'Thay đổi Mật khẩu'),
(110964, 4475, 29, 'Thay đổi mật khẩu thành công.'),
(110965, 4477, 29, 'Giai đoạn mật khẩu sắp hết hạn'),
(110966, 4479, 29, 'Mật khẩu cho cổng điện thoại. Tự động dịch vụ VoIP được cung cấp bởi Maviq. Vui lòng truy cập http://signup.maviq.com để biết thêm thông tin.'),
(110967, 4480, 29, 'Mật khẩu cho SMS Gateway'),
(110968, 4481, 29, 'Mật khẩu cho SMS Gateway.'),
(110969, 4483, 29, 'Bảo mật mật khẩu gần đây đã được nâng cấp.'),
(110970, 4486, 29, 'Mật khẩu:'),
(110971, 4490, 29, 'Quá hạn'),
(110972, 4491, 29, 'Quá Hạn'),
(110973, 4492, 29, 'Thời khoảng Quá Hạn (Nhắc nhở Lâm sàng)'),
(110974, 4493, 29, 'Thời khoảng Quá Hạn (Nhắc nhở Bệnh nhân)'),
(110975, 4494, 29, 'Danh sách Lần khám Trước đây'),
(110976, 4495, 29, 'Lần khám Trước đây'),
(110977, 4496, 29, 'Lần khám và Tài liệu Trước đây'),
(110978, 4497, 29, 'Lần khám Trước đây của'),
(110979, 4498, 29, 'Dán HL7 Data'),
(110980, 4499, 29, 'Dán dữ liệu để nhập khẩu vào khu vực văn bản dưới đây:'),
(110981, 4500, 29, 'Pat'),
(110982, 4502, 29, 'Bản vá'),
(110983, 4508, 29, 'Con đường cho sao lưu Event Log'),
(110984, 4509, 29, 'Đường dẫn File chứng chỉ CA'),
(110985, 4510, 29, 'Đường dẫn đến File Key CA'),
(110986, 4511, 29, 'Đường dẫn đến MySQL Binaries'),
(110987, 4512, 29, 'Đường dẫn đến Perl Binaries'),
(110988, 4513, 29, 'Đường dẫn đến tập tin tạm thời'),
(110989, 4514, 29, 'Bệnh nhân'),
(110990, 4515, 29, 'bệnh nhân'),
(110991, 4516, 29, 'BỆNH NHÂN'),
(110992, 4521, 29, 'Bệnh nhân dị ứng'),
(110993, 4522, 29, 'Bệnh nhân dị ứng'),
(110994, 4523, 29, 'Bệnh nhân bổ nhiệm'),
(110995, 4528, 29, 'Bệnh nhân biểu đồ ID'),
(110996, 4529, 29, 'Bệnh nhân Thanh toán'),
(110997, 4530, 29, 'Bệnh nhân Thanh toán cho '),
(110998, 4531, 29, 'Bệnh nhân Thành phố'),
(110999, 4533, 29, 'Bệnh nhân Truyền thông đã gửi'),
(111000, 4534, 29, 'Bệnh nhân Comunication đã gửi'),
(111001, 4535, 29, 'Bệnh nhân Quốc gia'),
(111002, 4539, 29, 'Dữ liệu Bệnh nhân'),
(111003, 4541, 29, 'Thiếu Ngày Sinh của Bệnh nhân'),
(111004, 4542, 29, 'Chi tiết Bệnh nhân'),
(111005, 4543, 29, 'Ngày sinh của Bệnh nhân'),
(111006, 4544, 29, 'Tài liệu của Bệnh nhân'),
(111007, 4545, 29, 'Nghiên cứu Bệnh lý'),
(111008, 4546, 29, 'Phương tiện Nghiên cứu Bệnh lý'),
(111009, 4547, 29, 'Bệnh nhân gặp'),
(111010, 4548, 29, 'Biểu mẫu Lần khám của Bệnh Nhân'),
(111011, 4549, 29, 'Các lần khám của Bệnh nhân'),
(111012, 4550, 29, 'Tìm kiếm Bệnh nhân'),
(111013, 4551, 29, 'Tên Bệnh nhân'),
(111014, 4553, 29, 'Thiếu tên bệnh nhân'),
(111015, 4558, 29, 'Giới tính của Bệnh nhân'),
(111016, 4559, 29, 'Thiếu Giới tính của Bệnh nhân'),
(111017, 4560, 29, 'Bệnh nhân đã không được uỷ quyền là Cổng thông tin bệnh nhân.'),
(111018, 4561, 29, 'Lịch sử Bệnh nhân'),
(111019, 4562, 29, 'Lịch sử Bệnh nhân / Lối sống'),
(111020, 4563, 29, 'Điện thoại nhà Bệnh Nhân'),
(111021, 4564, 29, 'Bệnh nhân ID'),
(111022, 4566, 29, 'Bệnh nhân ID card'),
(111023, 4567, 29, 'Tên Thể loại ID bệnh nhân'),
(111024, 4568, 29, 'Bệnh nhân Tiêm chủng'),
(111025, 4569, 29, 'Thông tin Bệnh nhân'),
(111026, 4570, 29, 'Hướng dẫn Bệnh nhân'),
(111027, 4571, 29, 'Bảo hiểm Phân phối Bệnh Nhân'),
(111028, 4572, 29, 'Báo cáo phân phối bảo hiểm bệnh nhân'),
(111029, 4573, 29, 'Bệnh nhân vấn đề'),
(111030, 4575, 29, 'Bệnh nhân cuối tên'),
(111031, 4581, 29, 'Bệnh nhân Danh sách'),
(111032, 4586, 29, 'Bệnh nhân Lookup lỗi'),
(111033, 4587, 29, 'Bệnh nhân y tế vấn đề'),
(111034, 4588, 29, 'Bệnh nhân thuốc'),
(111035, 4589, 29, 'Tên Bệnh nhân'),
(111036, 4590, 29, 'Tên và Địa chỉ Bệnh nhân'),
(111037, 4593, 29, 'Phải có Tên Bệnh nhân'),
(111038, 4595, 29, 'Ghi chú về Bệnh nhân'),
(111039, 4596, 29, 'Các loại Ghi chú về Bệnh nhân'),
(111040, 4597, 29, 'Ghi chú về Bệnh nhân'),
(111041, 4598, 29, 'Ghi chú Bệnh nhân (tùy chọn cho ghi, chỉ thêm)'),
(111042, 4599, 29, 'Số của Bệnh nhân'),
(111043, 4600, 29, 'Bệnh nhân Thanh toán'),
(111044, 4602, 29, 'Tên Thể loại ảnh bệnh nhân'),
(111045, 4603, 29, 'Bệnh nhân Portal'),
(111046, 4605, 29, 'Cổng thông tin bệnh nhân bị tắt'),
(111047, 4606, 29, 'Bệnh nhân Cổng Thông tin Đăng nhập'),
(111048, 4607, 29, 'Địa chỉ Web Portal bệnh nhân'),
(111049, 4608, 29, 'Bệnh nhân In Báo cáo'),
(111050, 4609, 29, 'Báo cáo bệnh nhân ghi'),
(111051, 4610, 29, 'Yêu cầu Hồ sơ Bệnh nhân'),
(111052, 4611, 29, 'Yêu cầu các Hồ sơ Bệnh nhân'),
(111053, 4613, 29, 'Nhắc nhở về Bệnh nhân'),
(111054, 4614, 29, 'Hàng loạt Việc Nhắc nhở về Bệnh nhân'),
(111055, 4616, 29, 'Quy luật Nhắc nhở về Bệnh nhân'),
(111056, 4617, 29, 'Email Người gửi Nhắc nhở về Bệnh nhân'),
(111057, 4618, 29, 'Tên Người gửi Nhắc nhở về Bệnh nhân'),
(111058, 4619, 29, 'Nhắc nhở về Bệnh nhân'),
(111059, 4620, 29, 'Báo cáo về Bệnh nhân'),
(111060, 4621, 29, 'Yêu cầu của Bệnh nhân'),
(111061, 4622, 29, 'Hồ sơ Y tế của Bệnh nhân được Yêu cầu'),
(111062, 4623, 29, 'Kết quả về Bệnh nhân'),
(111063, 4624, 29, 'Kiểu Kết quả Tìm kiếm về Bệnh nhân'),
(111064, 4625, 29, 'Màn hình Tìm kiếm / Thêm Bệnh nhân'),
(111065, 4626, 29, 'Thiết lập của Bệnh nhân'),
(111066, 4627, 29, 'Tiểu bang của Bệnh nhân'),
(111067, 4629, 29, 'Tóm lượt về Bệnh nhân'),
(111068, 4630, 29, 'Giao dịch của Bệnh nhân'),
(111069, 4631, 29, 'Mã Zip của Bệnh nhân'),
(111070, 4632, 29, 'bệnh nhân (s) trong cơ sở dữ liệu phù hợp với các thông tin nhân khẩu học mà bạn đã nhập.'),
(111071, 4633, 29, 'Bệnh nhân / Khách hàng'),
(111072, 4634, 29, 'Bệnh nhân:'),
(111073, 4635, 29, 'PatientID'),
(111074, 4636, 29, 'Bệnh nhân'),
(111075, 4638, 29, 'Trả'),
(111076, 4639, 29, 'Hãy chú ý "Done" hộp kiểm tra. Sau khi bảo hiểm được đánh dấu đầy đủ thì chúng ta sẽ bắt đầu yêu cầu bệnh nhân phải trả số dư còn lại, nếu bạn không đánh dấu tất cả các loại bảo hiểm hoàn thành thì số tiền còn lại sẽ không được thu thập! Ngoài ra nếu có một sự cân bằng mà bệnh nhân phải trả tiền, sau đó thiết lập ngày hết hạn một cách thích hợp, vì điều này sẽ ảnh hưởng đến ngôn ngữ xuất hiện trên báo cáo bệnh nhân.'),
(111077, 4640, 29, 'Trả ngày:'),
(111078, 4641, 29, 'Trả Status'),
(111079, 4642, 29, 'Người nhận thanh toán Name'),
(111080, 4643, 29, 'Đối tượng nộp'),
(111081, 4644, 29, 'Đối tượng nộp Loại'),
(111082, 4645, 29, 'Thanh toán'),
(111083, 4646, 29, 'Thanh toán Entity'),
(111084, 4647, 29, 'Thanh toán'),
(111085, 4648, 29, 'thanh toán'),
(111086, 4649, 29, 'Mã Điều chỉnh Thanh toán'),
(111087, 4651, 29, 'Khoản tiền thanh toán'),
(111088, 4652, 29, 'Khoản tiền thanh toán phải là Numeric'),
(111089, 4653, 29, 'Thanh toán Thể loại'),
(111090, 4654, 29, 'Thanh toán ngày'),
(111091, 4655, 29, 'thanh toán được nhập vào'),
(111092, 4656, 29, 'Thanh toán Từ'),
(111093, 4658, 29, 'Thanh toán Ins'),
(111094, 4659, 29, 'Thanh toán Danh sách'),
(111095, 4660, 29, 'Phương thức thanh toán'),
(111096, 4661, 29, 'Thanh toán Sắp xếp theo'),
(111097, 4662, 29, 'Thanh toán Tình trạng'),
(111098, 4663, 29, 'Loại thanh toán'),
(111099, 4664, 29, 'Giá trị thanh toán cho mã '),
(111100, 4665, 29, 'Thanh toán'),
(111101, 4667, 29, 'PCP'),
(111102, 4669, 29, 'PDF'),
(111103, 4670, 29, 'PDF Download Báo cáo lựa chọn'),
(111104, 4672, 29, 'Xương chậu và mông'),
(111105, 4673, 29, 'Bịnh có mụt nước trên da'),
(111106, 4674, 29, 'Đang chờ'),
(111107, 4676, 29, 'Đang chờ T / D'),
(111108, 4677, 29, 'Đang chờ Theo dõi'),
(111109, 4678, 29, 'Đang chờ Theo dõi Kết quả'),
(111110, 4679, 29, 'Đơn hàng Đang chờ'),
(111111, 4680, 29, 'Trong khi chờ Res'),
(111112, 4681, 29, 'Đang chờ Xem xét'),
(111113, 4682, 29, 'Trong khi chờ Rx Lượt'),
(111114, 4684, 29, 'Pennington Công ty LibreEHR v'),
(111115, 4685, 29, 'Bệnh loét dạ dày'),
(111116, 4687, 29, 'mỗi phút'),
(111117, 4688, 29, 'Mỗi lỗ mũi'),
(111118, 4689, 29, 'mỗi lỗ mũi'),
(111119, 4690, 29, 'Uống'),
(111120, 4691, 29, 'uống'),
(111121, 4692, 29, 'Nhét hậu môn'),
(111122, 4693, 29, 'mỗi trực tràng'),
(111123, 4694, 29, 'Tỷ lệ phần trăm'),
(111124, 4697, 29, 'Phần Trăm'),
(111125, 4698, 29, 'Đục phải:'),
(111126, 4699, 29, 'Thực hiện Tìm kiếm'),
(111127, 4700, 29, 'Thực hiện hành động này'),
(111128, 4701, 29, 'Hiệu suất Tỷ lệ phần trăm'),
(111129, 4703, 29, 'Thực hiện Cơ sở phòng thí nghiệm'),
(111130, 4705, 29, 'Dấu chấm'),
(111131, 4706, 29, 'Thời gian trong ngày mà người dùng có thể đăng nhập bằng một mật khẩu hết hạn.'),
(111132, 4707, 29, 'Perioperative Chăm sóc'),
(111133, 4708, 29, 'Thiết bị ngoại vi'),
(111134, 4712, 29, 'Người'),
(111135, 4713, 29, 'Cá nhân'),
(111136, 4714, 29, 'PG'),
(111137, 4715, 29, 'Pharm'),
(111138, 4716, 29, 'Pharm Com Lượt'),
(111139, 4717, 29, 'Nhà thuốc'),
(111140, 4718, 29, 'Nhà thuốc'),
(111141, 4719, 29, 'Dược bệnh xá'),
(111142, 4720, 29, 'Pheumothorax'),
(111143, 4729, 29, 'Điện thoại'),
(111144, 4730, 29, 'Danh sách cuộc gọi điện thoại'),
(111145, 4733, 29, 'Điện thoại Cổng Mật khẩu'),
(111146, 4734, 29, 'Cổng URL điện thoại'),
(111147, 4735, 29, 'Cổng Tên đăng nhập điện thoại'),
(111148, 4737, 29, 'Thông báo Giờ điện thoại'),
(111149, 4738, 29, 'Số điện thoại'),
(111150, 4740, 29, 'Chứng sợ ánh sáng'),
(111151, 4741, 29, 'Hình ảnh'),
(111152, 4742, 29, 'PHP nén'),
(111153, 4743, 29, 'PHP cURL mô-đun nên được cho phép trong máy chủ của bạn.'),
(111154, 4744, 29, 'đã trích xuất PHP'),
(111155, 4745, 29, 'kiểm soát truy cập được php-GACL tắt'),
(111156, 4746, 29, 'PHP-gacl không được cài đặt'),
(111157, 4747, 29, 'Vật lý thi'),
(111158, 4749, 29, 'Bác sĩ yêu cầu'),
(111159, 4750, 29, 'Bác sĩ Chữ ký'),
(111160, 4752, 29, 'Bác sĩ'),
(111161, 4753, 29, 'chọn'),
(111162, 4754, 29, 'Chọn'),
(111163, 4755, 29, 'Chọn một chủ đề CSS.'),
(111164, 4756, 29, 'PID'),
(111165, 4757, 29, 'PID (viêm vùng chậu)'),
(111166, 4758, 29, 'Pill Size'),
(111167, 4759, 29, 'Thuốc'),
(111168, 4760, 29, 'Đặt file zip cơ sở dữ liệu trong thư mục sau đây nếu muốn tùy chọn để cài đặt'),
(111169, 4765, 29, 'Giữ chỗ'),
(111170, 4766, 29, 'Giữ chỗ (duy trì ACL trống)'),
(111171, 4767, 29, 'Hoàn toàn là Chữ'),
(111172, 4768, 29, 'Kế hoạch (Plan)'),
(111173, 4771, 29, 'Tên Kế hoạch'),
(111174, 4775, 29, 'Kế hoạch Set'),
(111175, 4779, 29, 'Kế hoạch:'),
(111176, 4782, 29, 'Kế hoạch'),
(111177, 4784, 29, 'Thủ'),
(111178, 4785, 29, 'Chơi Chức vụ'),
(111179, 4786, 29, 'Xin vui lòng gọi nếu có của các thông tin trên là không chính xác'),
(111180, 4787, 29, 'Xin vui lòng thay đổi mật khẩu của bạn.'),
(111181, 4788, 29, 'Chọn một tập tin'),
(111182, 4789, 29, 'Vui lòng chọn một bệnh nhân'),
(111183, 4790, 29, 'Hãy chọn một lựa chọn hợp lệ từ danh sách.'),
(111184, 4791, 29, 'Hãy chọn một lựa chọn hợp lệ.'),
(111185, 4792, 29, 'Xin vui lòng lựa chọn một giá trị cho'),
(111186, 4793, 29, 'Xin vui lòng lựa chọn tiêu chuẩn phạm vi ngày ở trên, và nhấn Refresh để xem kết quả.'),
(111187, 4794, 29, 'Xin vui lòng lựa chọn đúng định dạng tệp tin EDI-271'),
(111188, 4795, 29, 'Vui lòng Click vào nút download để tải về De dữ liệu Xác định'),
(111189, 4796, 29, 'Vui lòng Click vào nút download để tải về các dữ liệu Re Xác định'),
(111190, 4797, 29, 'Hãy đóng cửa sổ này.'),
(111191, 4798, 29, 'Xin hãy so sánh tên mới'),
(111192, 4802, 29, 'Xin vui lòng không chấp nhận toa thuốc này, trừ khi nó đã được nhận thông qua facimile.'),
(111193, 4803, 29, 'Xin vui lòng không chấp nhận toa thuốc này, trừ khi nó đã được nhận qua fax.'),
(111194, 4804, 29, 'Xin vui lòng sử dụng trình duyệt của bạn ngừng hoặc tải lại nút trong khi trang đang chạy trừ khi hơn 10 phút đã trôi qua, điều này sẽ không gây ra quá trình dừng lại trên máy chủ và sẽ tiêu thụ tài nguyên uneccesary.'),
(111195, 4809, 29, 'Xin vui lòng nhập một ngày để xem lại lần cuối.'),
(111196, 4810, 29, 'Xin vui lòng nhập một ngày.'),
(111197, 4813, 29, 'Xin vui lòng nhập một số lượng tiền tệ bằng cách sử dụng số duy nhất và là một điểm thập phân.'),
(111198, 4814, 29, 'Nhập mật khẩu mới'),
(111199, 4815, 29, 'Xin vui lòng nhập một tiêu đề!'),
(111200, 4819, 29, 'Xin vui lòng nhập chính xác mã nhận dạng Re'),
(111201, 4821, 29, 'Xin vui lòng nhập chuỗi tìm kiếm mới'),
(111202, 4822, 29, 'Xin vui lòng nhập mã Re Xác định chính xác'),
(111203, 4823, 29, 'Hãy nhập mật khẩu'),
(111204, 4824, 29, 'Điền vào các số Kiểm tra'),
(111205, 4826, 29, 'Xin vui lòng Điền vào các ngày'),
(111206, 4827, 29, 'Xin vui lòng Điền Số tiền thanh toán'),
(111207, 4828, 29, 'Điền vào các loại thanh toán'),
(111208, 4829, 29, 'Điền vào các thanh toán Từ'),
(111209, 4830, 29, 'Điền vào các bài viết Đến ngày'),
(111210, 4831, 29, 'Xin vui lòng điền vào trong trước khi tiếp tục.'),
(111211, 4832, 29, 'Xin cho biết lý do ghé thăm'),
(111212, 4834, 29, 'Xin vui lòng nhập vào tiêu chí tìm kiếm ở trên, và nhấp Gửi để xem kết quả.'),
(111213, 4835, 29, 'Xin vui lòng nhập vào tiêu chí tìm kiếm ở trên, và nhấn Gửi để xem kết quả. (Kết quả sẽ được hiển thị trong một cửa sổ bật lên)'),
(111214, 4836, 29, 'Vui lòng đăng nhập lại.'),
(111215, 4837, 29, 'Xin lưu ý rằng điều này có thể mất một thời gian rất dài, lên đến vài phút, trình duyệt web của bạn không có thể xuất hiện rất tích cực trong thời gian này, nhưng tạo ra một dự luật là một quá trình phức tạp và trình duyệt web của bạn chỉ đơn thuần chờ đợi để biết thêm thông tin.'),
(111216, 4838, 29, 'Lưu ý: hằng số có phân biệt chữ hoa hay thường và chuỗi bất kỳ được cho phép.'),
(111217, 4839, 29, 'Xin vui lòng chỉ sử dụng ký tự chữ cái'),
(111218, 4840, 29, 'Xin vui lòng chỉ sử dụng các ký tự chữ cái không có khoảng cách'),
(111219, 4841, 29, 'Xin vui lòng trả số tiền này'),
(111220, 4843, 29, 'Vui lòng tham khảo tập tin'),
(111221, 4844, 29, 'Vui lòng thiết lập lại mật khẩu.'),
(111222, 4845, 29, 'Hãy khởi động lại máy chủ apache trước khi chơi với de-nhận dạng'),
(111223, 4849, 29, 'Hãy chọn một ngôn ngữ'),
(111224, 4850, 29, 'Chọn một bệnh nhân.'),
(111225, 4851, 29, 'Hãy chọn một cơ sở kinh doanh thực thể tiểu học với ''Tax ID'' là ID Thuế cơ sở của bạn. Nếu bạn là một học viên cá nhân, sử dụng id thuế của bạn. Điều này được sử dụng để xác định bạn trong hệ thống NewCrop.'),
(111226, 4855, 29, 'Hãy chọn một ngày bắt đầu và ngày kết thúc'),
(111227, 4858, 29, 'Hãy chọn một lý do điều chỉnh cho mã '),
(111228, 4859, 29, 'Hãy chọn một sự kiện'),
(111229, 4860, 29, 'Hãy chọn bất kỳ tùy chọn tìm kiếm.'),
(111230, 4863, 29, 'Vui lòng chọn ít nhất một đơn thuốc!'),
(111231, 4865, 29, 'Hãy chọn trang bạn muốn sao chép hoặc chuyển tiếp:'),
(111232, 4866, 29, 'Chọn Phương thức thanh toán'),
(111233, 4869, 29, 'Xin vui lòng chọn X12 đối tác, cần thiết để tạo ra hàng loạt 270'),
(111234, 4870, 29, 'Xin vui lòng thiết lập'),
(111235, 4871, 29, 'Xin vui lòng thiết lập lại biến de_identification_config không'),
(111236, 4873, 29, 'Hãy bắt đầu quá trình nhận dạng De'),
(111237, 4874, 29, 'Xin vui lòng nâng cấp LibreEHR Cơ sở dữ liệu bao gồm các thủ tục nhận dạng De, chức năng, bảng'),
(111238, 4875, 29, 'Xin vui lòng xem bảng De Xác định lỗi đăng nhập để biết thêm chi tiết'),
(111239, 4876, 29, 'Vui lòng truy cập vào màn hình nhận dạng De sau một thời gian'),
(111240, 4877, 29, 'Vui lòng truy cập vào màn hình nhận dạng Re sau một thời gian'),
(111241, 4878, 29, 'Vui lòng truy cập vào màn hình sau một thời gian'),
(111242, 4882, 29, 'PM'),
(111243, 4883, 29, 'PM Chương trình'),
(111244, 4884, 29, 'Pmt Phương pháp'),
(111245, 4885, 29, 'PND'),
(111246, 4886, 29, 'Liên cầu khuẩn 1'),
(111247, 4887, 29, 'Liên cầu khuẩn 2'),
(111248, 4888, 29, 'Liên cầu khuẩn 3'),
(111249, 4889, 29, 'Liên cầu khuẩn 4'),
(111250, 4890, 29, 'Phế cầu khuẩn Vắc-xin'),
(111251, 4891, 29, 'Viêm phổi tiêm phòng vắc xin'),
(111252, 4892, 29, 'Tình trạng tiêm phòng vắc xin viêm phổi cho những người có tuổi'),
(111253, 4893, 29, 'Tình trạng tiêm phòng vắc xin viêm phổi cho những người có tuổi (CQM)'),
(111254, 4894, 29, 'Podiatric'),
(111255, 4896, 29, 'Điểm dịch vụ (POS)'),
(111256, 4897, 29, 'Chính sách'),
(111257, 4898, 29, 'Chính sách Không có'),
(111258, 4899, 29, 'Số hợp đồng bảo hiểm'),
(111259, 4900, 29, 'Ba Lan'),
(111260, 4901, 29, 'Polydypsia'),
(111261, 4902, 29, 'Polyp'),
(111262, 4903, 29, 'Polyuria'),
(111263, 4904, 29, 'Ăn không ngon miệng'),
(111264, 4905, 29, 'Người nghèo lưu hành'),
(111265, 4906, 29, 'Nghèo thính'),
(111266, 4907, 29, 'Cần phải kích hoạt cửa sổ mở lên (pop up) để xem các báo cáo này'),
(111267, 4908, 29, 'Tạo ra cách nhìn một năm với các sự kiện không?'),
(111268, 4909, 29, 'Mở lên (popup)'),
(111269, 4911, 29, 'Hoạt động Cổng thông tin'),
(111270, 4917, 29, 'Tiếng Bồ Đào Nha'),
(111271, 4918, 29, 'Tiếng Bồ Đào Nha (Brazil)'),
(111272, 4919, 29, 'Tiếng Bồ Đào Nha (châu Âu)'),
(111273, 4920, 29, 'Mã POS'),
(111274, 4922, 29, 'Tích cực'),
(111275, 4923, 29, 'Tích cực'),
(111276, 4925, 29, 'Đăng Đối với'),
(111277, 4926, 29, 'Đăng mũi nhỏ giọt'),
(111278, 4927, 29, 'Gửi thanh toán'),
(111279, 4928, 29, 'Đăng phẫu thuật'),
(111280, 4929, 29, 'Đăng kế toán và đánh dấu như lập hoá đơn'),
(111281, 4930, 29, 'Đăng Đến ngày'),
(111282, 4931, 29, 'Đăng Đến ngày không được lớn hơn Hôm nay'),
(111283, 4932, 29, 'Đăng Đến ngày Phải lớn hơn Ngày Đóng tài chính.'),
(111284, 4933, 29, 'Post-Chăm Sóc phá thai'),
(111285, 4934, 29, 'Sau phá thai Ngừa thai'),
(111286, 4935, 29, 'Sau phá thai Tư vấn'),
(111287, 4936, 29, 'Sau phá thai tiếp theo'),
(111288, 4937, 29, 'Bưu chính'),
(111289, 4938, 29, 'Mã bưu chính'),
(111290, 4939, 29, 'Mã bưu chính'),
(111291, 4941, 29, 'PostCalendar'),
(111292, 4942, 29, 'PostCalendar Quản trị'),
(111293, 4943, 29, 'Cài đặt PostCalendar Thể loại'),
(111294, 4944, 29, 'PostCalendar Cài đặt toàn cầu'),
(111295, 4945, 29, 'Được đăng trên'),
(111296, 4946, 29, 'Ngày gửi'),
(111297, 4948, 29, 'Powered by:'),
(111298, 4949, 29, 'PPE + Trước Med / Surg HX'),
(111299, 4950, 29, 'PQRI'),
(111300, 4951, 29, 'PQRI Registry ID'),
(111301, 4952, 29, 'PQRI Registry Name'),
(111302, 4953, 29, 'Thực hành'),
(111303, 4954, 29, 'Thiết lập Thực hành Mặc định'),
(111304, 4955, 29, 'Cài đặt Thực hành'),
(111305, 4956, 29, 'Người thực hành'),
(111306, 4959, 29, 'Trước khi thanh toán'),
(111307, 4960, 29, 'Pre-Phá thai Tư vấn'),
(111308, 4961, 29, 'Pre-Phá thai Tư vấn'),
(111309, 4962, 29, 'Loại Ưu tiên'),
(111310, 4964, 29, 'Tùy chọn'),
(111311, 4965, 29, 'Ưu tiên Thể loại Sự kiện'),
(111312, 4966, 29, 'Ưu tiên Ngôn ngữ'),
(111313, 4967, 29, 'Ưu tiên Nhà thuốc'),
(111314, 4968, 29, 'Tổ chức Cung cấp Ưu tiên (PPO)'),
(111315, 4969, 29, 'Preg thử nghiệm'),
(111316, 4970, 29, 'Sơ bộ'),
(111317, 4972, 29, 'Trả trước'),
(111318, 4973, 29, 'Toa thuốc'),
(111319, 4974, 29, 'toa thuốc đã đạt đến giới hạn của nó là'),
(111320, 4975, 29, 'Lịch sử Toa thuốc'),
(111321, 4976, 29, 'Đã nhập Lịch sử Toa thuốc thành công'),
(111322, 4977, 29, 'Nhãn Toa thuốc'),
(111323, 4978, 29, 'Báo cáo Toa thuốc'),
(111324, 4979, 29, 'Toa thuốc'),
(111325, 4980, 29, 'Đơn thuốc và Dispensations'),
(111326, 4981, 29, 'Quy định và giới thiệu khác'),
(111327, 4982, 29, 'Quy định và / hoặc giới thiệu của chuyên gia'),
(111328, 4983, 29, 'Quy định Báo cáo'),
(111329, 4984, 29, 'Quy định / Giới thiệu tham gia'),
(111330, 4985, 29, 'Hiện nay'),
(111331, 4986, 29, 'Trình bày khiếu nại'),
(111332, 4988, 29, 'Nhấn Continue để tiếp tục'),
(111333, 4989, 29, 'Giả định chẩn đoán'),
(111334, 4990, 29, 'Giả định chẩn đoán của chuyên gia'),
(111335, 4991, 29, 'Trước'),
(111336, 4992, 29, 'Trước Med / Surg HX'),
(111337, 4993, 29, 'Trước. tháng (giữ cho thực đơn)'),
(111338, 4994, 29, 'Trước. năm (giữ cho thực đơn)'),
(111339, 4995, 29, 'Chăm sóc Phòng ngừa'),
(111340, 4998, 29, 'Xem trước Sự kiện'),
(111341, 5000, 29, 'Xem trước của'),
(111342, 5001, 29, 'Trang trước'),
(111343, 5002, 29, 'Tư vấn Trước đây'),
(111344, 5003, 29, 'Ngày Trước'),
(111345, 5004, 29, 'Lịch sử / Sàng lọc trước'),
(111346, 5005, 29, 'Tháng Trước'),
(111347, 5006, 29, 'Tuần Trước'),
(111348, 5007, 29, 'Giá'),
(111349, 5008, 29, 'Giảm Giá'),
(111350, 5009, 29, 'Mức Giá'),
(111351, 5010, 29, 'Mức Giá:'),
(111352, 5011, 29, 'Giá'),
(111353, 5012, 29, 'Chính'),
(111354, 5013, 29, 'Thực thể Kinh doanh Chính'),
(111355, 5014, 29, 'Mã số thuế của thực thể kinh doanh chính được dùng như mã tài khoản của ePrescription NewCrop. Thay đổi cơ sở sẽ ảnh hưởng đến cách làm việc trong NewCrop.'),
(111356, 5022, 29, 'BH Chính'),
(111357, 5023, 29, 'Bảo hiểm Chính'),
(111358, 5024, 29, 'Dữ liệu Bảo hiểm Chính'),
(111359, 5025, 29, 'Nhà cung cấp Bảo hiểm Chính'),
(111360, 5026, 29, 'Nhà cung cấp Chính'),
(111361, 5027, 29, 'In ấn'),
(111362, 5028, 29, 'In dạng HTML'),
(111363, 5029, 29, 'In dạng PDF'),
(111364, 5031, 29, 'In Bất kỳ Lần khám'),
(111365, 5032, 29, 'In Biểu mẫu Giới thiệu Trống'),
(111366, 5033, 29, 'In lệnh'),
(111367, 5039, 29, 'In Định dạng'),
(111368, 5040, 29, 'In Bốn Bảng điều chỉnh'),
(111369, 5042, 29, 'In thông báo'),
(111370, 5043, 29, 'In nhiều'),
(111371, 5044, 29, 'In Nhiều Để Fax'),
(111372, 5045, 29, 'In tên, ký hiệu, ngày.'),
(111373, 5046, 29, 'In Ghi chú'),
(111374, 5047, 29, 'In trang 1'),
(111375, 5048, 29, 'In trang 2'),
(111376, 5051, 29, 'In Biên nhận theo Nhà cung cấp'),
(111377, 5052, 29, 'In Hồ sơ'),
(111378, 5053, 29, 'In báo cáo được lựa chọn'),
(111379, 5054, 29, 'In Ghi Shot'),
(111380, 5056, 29, 'In Lần khám Này'),
(111381, 5057, 29, 'In ghi chú này'),
(111382, 5058, 29, 'In Ghi chú Này'),
(111383, 5060, 29, 'In Để Fax'),
(111384, 5061, 29, 'Xem trước khi In'),
(111385, 5062, 29, 'có thể in'),
(111386, 5063, 29, 'Phiên bản Có thể in'),
(111387, 5064, 29, 'Đã in'),
(111388, 5066, 29, 'Kết quả in ấn:'),
(111389, 5067, 29, 'Đã bỏ qua việc in; hãy xem kết quả thử tại'),
(111390, 5068, 29, 'Đã bỏ qua việc in; hãy xem kết quả thử tại '),
(111391, 5069, 29, 'Trước khi Auth'),
(111392, 5070, 29, 'Cho Authorization Mẫu khoá'),
(111393, 5072, 29, 'Ưu tiên'),
(111394, 5073, 29, 'Ưu tiên '),
(111395, 5074, 29, 'Riêng'),
(111396, 5075, 29, 'Vấn đề'),
(111397, 5076, 29, 'Vấn đề DX'),
(111398, 5077, 29, 'Vấn đề Danh sách'),
(111399, 5079, 29, 'Vấn đề / vấn đề'),
(111400, 5080, 29, 'Proc Bát'),
(111401, 5081, 29, 'Proc Cát'),
(111402, 5083, 29, 'Proc Pending Rev'),
(111403, 5085, 29, 'Proc Res'),
(111404, 5086, 29, 'Thủ tục'),
(111405, 5087, 29, 'Thủ tục Body Sites'),
(111406, 5088, 29, 'Kết quả Luận lý của Thủ tục'),
(111407, 5089, 29, 'Mã Thủ tục'),
(111408, 5090, 29, 'Mã Thủ tục'),
(111409, 5091, 29, 'Thủ tục Lateralities'),
(111410, 5093, 29, 'Đặt hàng Thủ tục'),
(111411, 5095, 29, 'Đặt hàng Thủ tục cho'),
(111412, 5102, 29, 'Báo cáo Thủ tục'),
(111413, 5103, 29, 'Trạng thái Báo cáo Thủ tục'),
(111414, 5104, 29, 'Thủ tục Kết quả bất thường'),
(111415, 5105, 29, 'Trạng thái Báo cáo Thủ tục'),
(111416, 5106, 29, 'Kết quả Thủ tục'),
(111417, 5107, 29, 'Các tuyến Thủ tục'),
(111418, 5108, 29, 'Thủ tục Mẫu loại'),
(111419, 5109, 29, 'Thống kê thủ tục Báo cáo'),
(111420, 5110, 29, 'Loại thủ tục'),
(111421, 5111, 29, 'Thủ tục loại'),
(111422, 5112, 29, 'Thủ tục đơn vị'),
(111423, 5114, 29, 'Thủ tục'),
(111424, 5115, 29, 'Quy trình'),
(111425, 5117, 29, 'File quá trình ERA'),
(111426, 5125, 29, 'Chế biến'),
(111427, 5129, 29, 'Sản phẩm'),
(111428, 5130, 29, 'Thai Phương pháp sản phẩm'),
(111429, 5132, 29, 'Sản phẩm'),
(111430, 5133, 29, 'Những sản phẩm không có thuốc theo toa và không có mẫu'),
(111431, 5134, 29, 'Giáo sư'),
(111432, 5135, 29, 'Tiến độ Ghi chú'),
(111433, 5136, 29, 'Ung thư tuyến tiền liệt'),
(111434, 5137, 29, 'Tuyến tiền liệt Ung Thư'),
(111435, 5138, 29, 'Tuyến tiền liệt thi'),
(111436, 5139, 29, 'Tuyến tiền liệt vấn đề'),
(111437, 5140, 29, 'Tuyến tiền liệt w / o enlrgmt, nốt, đấu thầu'),
(111438, 5142, 29, 'Cung cấp đường dẫn tuyệt đối'),
(111439, 5143, 29, 'Cung cấp đường dẫn tuyệt đối của tập tin'),
(111440, 5145, 29, 'Cung cấp bản tóm tắt lâm sàng cho bệnh nhân cho mỗi lần khám văn phòng.'),
(111441, 5146, 29, 'Cung cấp cho bệnh nhân với một bản sao điện tử của thông tin sức khỏe của họ (bao gồm cả kết quả xét nghiệm chẩn đoán, vấn đề danh sách, danh mục thuốc, dị ứng thuốc), theo yêu cầu.'),
(111442, 5147, 29, 'Cung cấp cho bệnh nhân truy cập điện tử kịp thời thông tin sức khỏe của họ (bao gồm cả kết quả phòng thí nghiệm, vấn đề danh sách, danh sách thuốc, dị ứng thuốc) trong vòng bốn ngày làm việc của các thông tin có sẵn để bảo vệ môi trường.'),
(111443, 5148, 29, 'Cung cấp hồ sơ bệnh nhân cho Chơi'),
(111444, 5149, 29, 'Cung cấp địa chỉ email hợp lệ'),
(111445, 5150, 29, 'Cung cấp Tóm tắt thông tin Lâm sàng?'),
(111446, 5151, 29, 'Cung cấp Tài nguyên Giáo dục?'),
(111447, 5152, 29, 'Người Khám'),
(111448, 5156, 29, 'Nhà cung cấp lỗi phù hợp'),
(111449, 5159, 29, 'Nhà cung cấp số'),
(111450, 5162, 29, 'Người Khám:'),
(111451, 5163, 29, 'Các nhà cung cấp'),
(111452, 5164, 29, 'Các nhà cung cấp NPI'),
(111453, 5165, 29, 'Các nhà cung cấp Xem Lịch Toàn bộ'),
(111454, 5166, 29, 'PRV'),
(111455, 5167, 29, 'PSA'),
(111456, 5168, 29, 'Bệnh vẩy nến'),
(111457, 5169, 29, 'Psych Chẩn đoán'),
(111458, 5170, 29, 'Psych thuốc'),
(111459, 5171, 29, 'Tâm thần'),
(111460, 5172, 29, 'Tâm thần học Giới thiệu tóm tắt Thư'),
(111461, 5173, 29, 'Tâm thần chẩn đoán'),
(111462, 5174, 29, 'Tâm thần thi'),
(111463, 5175, 29, 'Tâm thần học Lịch sử'),
(111464, 5176, 29, 'Tâm thần Intake'),
(111465, 5177, 29, 'Tâm thần Thuốc'),
(111466, 5178, 29, 'Pt%'),
(111467, 5179, 29, 'Pt Ghi chú'),
(111468, 5180, 29, 'Pt Ghi chú / Auth'),
(111469, 5181, 29, 'Pt nộp thừa'),
(111470, 5182, 29, 'Pt trả tiền'),
(111471, 5183, 29, 'Pt Rec Request'),
(111472, 5184, 29, 'Pt hoàn'),
(111473, 5185, 29, 'Pt phát hành'),
(111474, 5186, 29, 'Pt Báo cáo'),
(111475, 5187, 29, 'Sinh viên PT, hoặc để trống'),
(111476, 5188, 29, 'PT_CITY'),
(111477, 5189, 29, 'PT_DOB'),
(111478, 5191, 29, 'PT_FNAME'),
(111479, 5192, 29, 'PT_LNAME'),
(111480, 5193, 29, 'PT_MNAME'),
(111481, 5196, 29, 'PT_POSTAL'),
(111482, 5198, 29, 'PT_STATE'),
(111483, 5199, 29, 'PT_STREET'),
(111484, 5201, 29, 'Công khai'),
(111485, 5204, 29, 'Puerto Rico'),
(111486, 5205, 29, 'Phổi'),
(111487, 5206, 29, 'Mạch'),
(111488, 5207, 29, 'Tiếng Punjab'),
(111489, 5208, 29, 'Mua hàng'),
(111490, 5209, 29, 'Mua/Trả hàng'),
(111491, 5210, 29, 'Mua hàng'),
(111492, 5213, 29, 'q.3h'),
(111493, 5214, 29, 'q.4h'),
(111494, 5215, 29, 'q.5h'),
(111495, 5216, 29, 'q.6h'),
(111496, 5217, 29, 'q.8h'),
(111497, 5218, 29, '1 lần/ngày'),
(111498, 5219, 29, '4 lần/ngày'),
(111499, 5220, 29, 'QOH'),
(111500, 5221, 29, 'QOH là ít hơn so với sử dụng hàng tháng'),
(111501, 5222, 29, 'Số lượng'),
(111502, 5223, 29, 'QTY'),
(111503, 5224, 29, 'Chất lượng'),
(111504, 5225, 29, 'Các biện pháp chất lượng (CQM)'),
(111505, 5226, 29, 'Số lượng'),
(111506, 5227, 29, 'Số lượng cho NDC'),
(111507, 5228, 29, 'Số lượng On Hand'),
(111508, 5229, 29, 'số lượng có vẻ như không sử dụng được'),
(111509, 5231, 29, 'Chấm hỏi'),
(111510, 5232, 29, 'Xếp hàng cho HCFA chế biến hàng loạt'),
(111511, 5233, 29, 'Xếp hàng cho HCFA xử lý hàng loạt và in ấn'),
(111512, 5234, 29, 'Xếp hàng cho chế biến hàng loạt UB-92'),
(111513, 5235, 29, 'Xếp hàng cho chế biến hàng loạt UB-92 và in ấn'),
(111514, 5236, 29, 'Xếp hàng đợi'),
(111515, 5237, 29, 'Xếp hàng đợi sự kiện Quản trị'),
(111516, 5238, 29, 'Xếp hàng đợi cho'),
(111517, 5240, 29, 'Xếp hàng đợi phản hồi và những đề nghị, gợi ý Quản trị'),
(111518, 5241, 29, 'Đã bỏ'),
(111519, 5242, 29, 'Bỏ Rượu'),
(111520, 5243, 29, 'R'),
(111521, 5245, 29, 'Chủng tộc'),
(111522, 5246, 29, 'Chủng tộc và Dân tộc'),
(111523, 5247, 29, 'Chủng tộc/Dân tộc'),
(111524, 5248, 29, 'Radio'),
(111525, 5249, 29, 'Nút radio'),
(111526, 5251, 29, 'Phạm vi'),
(111527, 5252, 29, 'Phát ban'),
(111528, 5253, 29, 'Tỷ giá'),
(111529, 5254, 29, 'Tỷ lệ'),
(111530, 5255, 29, 'Nguyên Báo cáo'),
(111531, 5256, 29, 'Re Xác định'),
(111532, 5257, 29, 'Re Quy trình Xác định được hoàn thành'),
(111533, 5258, 29, 'Re Xác định quá trình đang diễn ra'),
(111534, 5259, 29, 'Re-xác định tập tin sẽ được lưu trong'),
(111535, 5260, 29, 'Re-tai nạn thương tích?'),
(111536, 5261, 29, 'Mở cửa lại'),
(111537, 5262, 29, 'Đã mở cửa lại'),
(111538, 5263, 29, 'Phản ứng'),
(111539, 5264, 29, 'Phản ứng'),
(111540, 5265, 29, 'Đã đọc'),
(111541, 5268, 29, 'Tên thật'),
(111542, 5269, 29, 'Thực sự xóa'),
(111543, 5270, 29, 'Lý do'),
(111544, 5271, 29, 'Lý do Qua đời'),
(111545, 5272, 29, 'Lý do qua đời'),
(111546, 5274, 29, 'Lý do giới thiệu'),
(111547, 5275, 29, 'Lý do đến khám'),
(111548, 5276, 29, 'Lý do / Biểu mẫu'),
(111549, 5277, 29, 'Biên lai'),
(111550, 5278, 29, 'Biên lai thanh toán'),
(111551, 5279, 29, 'Tiếp nhận được tạo ra'),
(111552, 5280, 29, 'Giấy biên nhận của Báo cáo Phương thức thanh toán'),
(111553, 5281, 29, 'Biên lai Tóm tắt thông tin'),
(111554, 5282, 29, 'Nhận được'),
(111555, 5283, 29, 'Received By'),
(111556, 5284, 29, 'Nhận được fax'),
(111557, 5287, 29, 'Receiver'),
(111558, 5288, 29, 'Nhận ID'),
(111559, 5289, 29, 'Nhận ID (ISA08)'),
(111560, 5290, 29, 'Nhận ID vòng loại (ISA07)'),
(111561, 5292, 29, 'Gần đây mật khẩu không được cho phép.'),
(111562, 5293, 29, 'Người nhận'),
(111563, 5294, 29, 'Danh sách người nhận là rỗng'),
(111564, 5295, 29, 'Tên người nhận'),
(111565, 5296, 29, 'Người nhận của Công khai các'),
(111566, 5298, 29, 'Khuyến nghị'),
(111567, 5300, 29, 'Khuyến nghị'),
(111568, 5301, 29, 'Các khuyến nghị và điều trị'),
(111569, 5302, 29, 'Khuyến nghị của chuyên gia'),
(111570, 5303, 29, 'Ghi'),
(111571, 5304, 29, 'Bản ghi đã tồn tại'),
(111572, 5310, 29, 'Ghi lại và lập biểu đồ thay đổi thể trạng.'),
(111573, 5311, 29, 'Ghi lại thông tin cá nhân.'),
(111574, 5312, 29, 'Ghi Tiết lộ'),
(111575, 5313, 29, 'Hồ sơ của Fitness'),
(111576, 5314, 29, 'Hồ sơ thanh toán'),
(111577, 5315, 29, 'Ghi lại Yêu cầu ngày'),
(111578, 5316, 29, 'Ghi lại tình trạng hút thuốc cho các bệnh nhân từ 13 tuổi trở lên.'),
(111579, 5317, 29, 'Hồ sơ'),
(111580, 5318, 29, 'hồ sơ được tìm thấy'),
(111581, 5319, 29, 'hồ sơ được tìm thấy.'),
(111582, 5320, 29, 'Việc sử dụng giải trí ma túy'),
(111583, 5321, 29, 'Giải trí Thuốc'),
(111584, 5322, 29, 'Trực tràng'),
(111585, 5323, 29, 'Kiểm tra thực tràng'),
(111586, 5324, 29, 'trực tràng'),
(111587, 5325, 29, 'Chuyển hướng'),
(111588, 5326, 29, 'Đỏ'),
(111589, 5327, 29, 'giảm:'),
(111590, 5328, 29, 'Giới thiệu'),
(111591, 5329, 29, 'Giới thiệu Bởi'),
(111592, 5330, 29, 'Giới thiệu Ngày'),
(111593, 5331, 29, 'Giới thiệu Đến'),
(111594, 5332, 29, 'Phân loại tài liệu tham khảo (mức độ rủi ro)'),
(111595, 5333, 29, 'Phạm vi tham chiếu các kết quả'),
(111596, 5334, 29, 'Tài liệu tham khảo Lý do'),
(111597, 5336, 29, 'Tên và chữ ký người giới thiệu'),
(111598, 5337, 29, 'Giới thiệu'),
(111599, 5338, 29, 'Giới thiệu Bởi'),
(111600, 5339, 29, 'Thẻ Giới thiệu'),
(111601, 5340, 29, 'Ngày Giới thiệu'),
(111602, 5341, 29, 'Biểu mẫu Giới thiệu'),
(111603, 5342, 29, 'BIỂU MẪU GIỚI THIỆU'),
(111604, 5343, 29, 'Mã số Giới thiệu'),
(111605, 5345, 29, 'Nguồn Giới thiệu'),
(111606, 5346, 29, 'Nguồn Giới thiệu cho Lần khám'),
(111607, 5347, 29, 'Giới thiệu Cho'),
(111608, 5348, 29, 'Các giới thiệu'),
(111609, 5349, 29, 'Báo cáo Giới thiệu'),
(111610, 5350, 29, 'Được giới thiệu bởi'),
(111611, 5351, 29, 'Được giới thiệu Bởi'),
(111612, 5352, 29, 'Giới thiệu cho'),
(111613, 5353, 29, 'Giới thiệu'),
(111614, 5355, 29, 'Chẩn đoán của Người giới thiệu'),
(111615, 5356, 29, 'Chẩn đoán của người giới thiệu'),
(111616, 5357, 29, 'Bác sĩ và thực hành giới thiệu'),
(111617, 5358, 29, 'Ưu tiên Nhà cung cấp'),
(111618, 5359, 29, 'Mua lại theo toa này'),
(111619, 5360, 29, 'Mua lại theo toa này'),
(111620, 5361, 29, 'mua lại theo toa này'),
(111621, 5362, 29, 'Bình thường phản xạ'),
(111622, 5363, 29, 'Làm mới'),
(111623, 5368, 29, 'Từ chối Để nhà nước'),
(111624, 5369, 29, 'reg_re'),
(111625, 5370, 29, 'đăng ký'),
(111626, 5372, 29, 'Đã đăng ký'),
(111627, 5373, 29, 'đã đăng ký'),
(111628, 5375, 29, 'Ngày đăng ký'),
(111629, 5376, 29, 'Mẫu đăng ký'),
(111630, 5377, 29, 'Phục hồi chức năng'),
(111631, 5381, 29, 'Liên quan Đến'),
(111632, 5382, 29, 'Liên quan'),
(111633, 5383, 29, 'Vấn đề Liên quan'),
(111634, 5385, 29, 'Mối quan hệ / Trẻ em'),
(111635, 5386, 29, 'Sự liên quan'),
(111636, 5387, 29, 'Mối quan hệ'),
(111637, 5388, 29, 'Trật tự của các thực thể này tương đối'),
(111638, 5389, 29, 'Thân nhân'),
(111639, 5399, 29, 'Các thông tin Y tế chuyển tiếp từ tài khoản người dùng này.'),
(111640, 5400, 29, 'ID relay Y tế'),
(111641, 5403, 29, 'Tôn Giáo'),
(111642, 5406, 29, 'Login lần sau'),
(111643, 5407, 29, 'Remdr'),
(111644, 5408, 29, 'Hãy nhớ Cơ sở Đã chọn'),
(111645, 5409, 29, 'Nhắc nhở'),
(111646, 5410, 29, 'Khoảng thời gian nhắc nhở'),
(111647, 5411, 29, 'Chưa Gửi Nhắc nhở'),
(111648, 5412, 29, 'Đã gửi Nhắc nhở ngày'),
(111649, 5413, 29, 'Nhắc nhở'),
(111650, 5414, 29, 'Nộp vào'),
(111651, 5416, 29, 'Loại bỏ'),
(111652, 5419, 29, 'Loại bỏ Nhóm'),
(111653, 5420, 29, 'Loại bỏ Biểu mẫu Nhóm'),
(111654, 5421, 29, 'Loại bỏ hỗ trợ cho chủng ngừa'),
(111655, 5422, 29, 'Loại bỏ hỗ trợ cho phpMyAdmin'),
(111656, 5423, 29, 'Loại bỏ hỗ trợ cho đơn thuốc'),
(111657, 5425, 29, 'Loại bỏ các tính năng Chart Tracker'),
(111658, 5426, 29, 'Thận Stones'),
(111659, 5427, 29, 'Đổi tên'),
(111660, 5428, 29, 'Đổi tên Nhóm'),
(111661, 5429, 29, 'Người lập'),
(111662, 5430, 29, 'Rendering nhà cung cấp'),
(111663, 5431, 29, 'Rendering Số nhà cung cấp'),
(111664, 5432, 29, 'Sắp xếp lại'),
(111665, 5433, 29, 'Sắp xếp lại Đồng'),
(111666, 5434, 29, 'Sắp xếp lại các điểm đã đạt được'),
(111667, 5436, 29, 'Cấp Độ'),
(111668, 5438, 29, 'Lặp đi lặp lại sự kiện'),
(111669, 5439, 29, 'Lặp đi lặp lại Thông tin:'),
(111670, 5440, 29, 'Lặp đi lặp lại'),
(111671, 5444, 29, 'Trả lời ngày'),
(111672, 5445, 29, 'Trả lời Từ'),
(111673, 5446, 29, 'Báo cáo'),
(111674, 5447, 29, 'Báo cáo - lâm sàng'),
(111675, 5449, 29, 'Báo cáo bằng'),
(111676, 5457, 29, 'Báo cáo tình trạng'),
(111677, 5458, 29, 'Báo cáo Tổng số'),
(111678, 5460, 29, 'Có thể báo cáo'),
(111679, 5461, 29, 'Đã báo cáo'),
(111680, 5462, 29, 'Ngày Báo cáo'),
(111681, 5463, 29, 'Báo cáo'),
(111682, 5467, 29, 'Yêu cầu bỏ qua - tuyên bố xử lý đã được chạy!'),
(111683, 5474, 29, 'Yêu cầu dịch vụ'),
(111684, 5475, 29, 'Yêu cầu các mật khẩu mạnh'),
(111685, 5476, 29, 'Yêu cầu mật khẩu độc đáo'),
(111686, 5477, 29, 'Yêu cầu'),
(111687, 5479, 29, 'Thiếu thông tin phải có: Vui lòng chọn tập tin EDI-271 để tải lên'),
(111688, 5480, 29, 'Thiếu thông tin phải có: Xin vui lòng nhập Tên'),
(111689, 5481, 29, 'Thiếu thông tin phải có: Xin vui lòng nhập Họ'),
(111690, 5482, 29, 'Thiếu thông tin phải có: Xin vui lòng nhập Tên Đăng nhập'),
(111691, 5483, 29, 'Các trường bắt buộc'),
(111692, 5484, 29, 'Yêu cầu'),
(111693, 5485, 29, 'DÀNH RIÊNG'),
(111694, 5486, 29, 'Dành riêng'),
(111695, 5487, 29, 'Dành riêng để định ra Thời gian Nghỉ phép Theo kế hoạch'),
(111696, 5488, 29, 'Dành riêng để định ra thời điểm nhà cung cấp bắt đầu không thể hẹn gặp.'),
(111697, 5489, 29, 'Dành riêng để định ra thời diểm một sự kiện không xảy ra như dự kiến.'),
(111698, 5490, 29, 'Dành riêng để định ra thời điểm nhà cung cấp bắt đầu có thể hẹn gặp.'),
(111699, 5491, 29, 'Thiết lập lại'),
(111700, 5492, 29, 'Thiết lập lại các Giây chứng nhận Portal ngoại vi'),
(111701, 5493, 29, 'Thiết lập lại các Giây chứng nhận Portal tại chỗ'),
(111702, 5495, 29, 'Resn'),
(111703, 5496, 29, 'Đã giải quyết'),
(111704, 5497, 29, 'Hô hấp'),
(111705, 5498, 29, 'Hô hấp nỗ lực unlabored'),
(111706, 5499, 29, 'Hô hấp'),
(111707, 5501, 29, 'Giới hạn người dùng không được ủy quyền vào các cơ sở trong quản trị người dùng.'),
(111708, 5502, 29, 'Hạn chế Người với Cơ sở'),
(111709, 5503, 29, 'Hạn chế đào tạo'),
(111710, 5504, 29, 'Kết quả'),
(111711, 5506, 29, 'Kết quả Status'),
(111712, 5507, 29, 'Kết quả tình trạng hoặc bất thường là mất tích'),
(111713, 5508, 29, 'Kết quả, sử dụng% như là một ký tự đại diện'),
(111714, 5510, 29, 'Kết quả và'),
(111715, 5511, 29, 'Kết quả tìm thấy Đối với Tìm kiếm'),
(111716, 5512, 29, 'Kết quả từ Tập đoàn'),
(111717, 5515, 29, 'Kết quả mỗi trang'),
(111718, 5516, 29, 'Kết quả / chi tiết'),
(111719, 5517, 29, 'Võng mạc thi'),
(111720, 5518, 29, 'Rút lại phải:'),
(111721, 5519, 29, 'Quay trở lại'),
(111722, 5520, 29, 'Quay trở lại ở trên một phần thanh toán của bạn'),
(111723, 5521, 29, 'Trở về lịch'),
(111724, 5527, 29, 'Quay trở lại giá trị gia tăng'),
(111725, 5528, 29, 'Quay trở lại Xem trang'),
(111726, 5529, 29, 'Trả lại để chơi'),
(111727, 5534, 29, 'Đánh giá của PMH:'),
(111728, 5535, 29, 'Đánh giá Các Cơ quan'),
(111729, 5536, 29, 'Đánh giá Việc kiểm tra các Cơ quan'),
(111730, 5537, 29, 'Đánh giá'),
(111731, 5538, 29, 'Sửa đổi'),
(111732, 5539, 29, 'Viêm khớp dạng thấp'),
(111733, 5540, 29, 'Rheumotoid Arthritis'),
(111734, 5541, 29, 'Ngay'),
(111735, 5542, 29, 'Tai Phải'),
(111736, 5543, 29, 'tai phải'),
(111737, 5545, 29, 'Bên phải:'),
(111738, 5546, 29, 'Ù tai'),
(111739, 5547, 29, 'Ù tai'),
(111740, 5549, 29, 'Yếu tố Nguy cơ'),
(111741, 5550, 29, 'Mức Rủi ro'),
(111742, 5551, 29, 'RLL:'),
(111743, 5552, 29, 'ROM'),
(111744, 5560, 29, 'Danh sách'),
(111745, 5561, 29, 'Đường dùng'),
(111746, 5562, 29, 'Đường dùng, nếu áp dụng'),
(111747, 5563, 29, 'Được chỉ định dùng'),
(111748, 5564, 29, 'Hàng'),
(111749, 5565, 29, 'RRR mà không MOR'),
(111750, 5566, 29, 'Chà:'),
(111751, 5567, 29, 'Chất chà:'),
(111752, 5568, 29, 'Quy tắc'),
(111753, 5569, 29, 'Thêm Quy tắc'),
(111754, 5570, 29, 'Chi tiết Quy tắc'),
(111755, 5572, 29, 'Chỉnh sửa Quy tắc'),
(111756, 5575, 29, 'Đặt Quy tắc'),
(111757, 5578, 29, 'Quy tắc'),
(111758, 5580, 29, 'Xác lập Quy tắc'),
(111759, 5581, 29, 'Đang Chạy Lệnh: '),
(111760, 5582, 29, 'Vỡ'),
(111761, 5583, 29, 'Tiếng Nga'),
(111762, 5584, 29, 'Tên thuốc'),
(111763, 5585, 29, 'Tên thuốc'),
(111764, 5598, 29, 'RxNorm'),
(111765, 5599, 29, 'RxNorm Cơ sở dữ liệu'),
(111766, 5600, 29, 'S'),
(111767, 5601, 29, 'S.S.'),
(111768, 5602, 29, 'S3:'),
(111769, 5603, 29, 'S4:'),
(111770, 5604, 29, 'SA ** Để đọc các giấy phép xin vui lòng đọc các tài liệu / license.txt hoặc ghé thăm * http://www.gnu.org/copyleft/gpl.html ** / / / ============ ================================================== =========== / / '),
(111771, 5605, 29, 'Bán'),
(111772, 5606, 29, 'Bán hàng'),
(111773, 5607, 29, 'Doanh số bán Item'),
(111774, 5608, 29, 'Doanh số bán hàng Báo cáo sản phẩm'),
(111775, 5609, 29, 'Nước bọt'),
(111776, 5610, 29, 'Cùng ngày'),
(111777, 5611, 29, 'Samoa'),
(111778, 5612, 29, 'Ví dụ'),
(111779, 5613, 29, 'Xử phạt Loại'),
(111780, 5617, 29, 'Thứ 7'),
(111781, 5618, 29, 'Thứ 7 & CN'),
(111782, 5619, 29, 'Thứ Bảy'),
(111783, 5620, 29, 'Lưu'),
(111784, 5621, 29, 'LƯU'),
(111785, 5622, 29, 'Lưu và Đóng'),
(111786, 5624, 29, 'Lưu và Phát thuốc');
INSERT INTO `lang_definitions` VALUES
(111787, 5626, 29, 'Lưu Bản mới'),
(111788, 5627, 29, 'Lưu thành ghi chú mới'),
(111789, 5628, 29, 'Lưu Cài đặt Giấy chứng nhận'),
(111790, 5629, 29, 'Lưu Thay đổi'),
(111791, 5630, 29, 'Lưu Biểu mẫu'),
(111792, 5631, 29, 'Lưu Tiêm chủng'),
(111793, 5632, 29, 'Lưu Trường Mới'),
(111794, 5633, 29, 'Lưu Nhóm mới'),
(111795, 5634, 29, 'Lưu Danh sách mới'),
(111796, 5635, 29, 'Lưu khuôn mẫu mới'),
(111797, 5637, 29, 'Lưu Thông tin cá nhân Bệnh nhân'),
(111798, 5638, 29, 'Lưu thành công cho ID biểu đồ'),
(111799, 5639, 29, 'Lưu giao dịch'),
(111800, 5641, 29, 'Quét'),
(111801, 5642, 29, 'Quét Encounter Lưu ý'),
(111802, 5643, 29, 'Máy quét thư mục'),
(111803, 5644, 29, 'Máy quét Trong'),
(111804, 5645, 29, 'Lịch trình'),
(111805, 5646, 29, 'Lịch trình thiết bị:'),
(111806, 5647, 29, 'TRƯỜNG GHI CHÚ'),
(111807, 5648, 29, 'Chứng vẹo cột sống'),
(111808, 5651, 29, 'SE'),
(111809, 5652, 29, 'Địa chỉ SE'),
(111810, 5653, 29, 'Thành phố của SE'),
(111811, 5654, 29, 'Quốc gia của SE'),
(111812, 5655, 29, 'Địa phương của SE'),
(111813, 5656, 29, 'Mã Bưu chính của SE'),
(111814, 5657, 29, 'Tiểu bang của SE'),
(111815, 5658, 29, 'Mã Zip của SE'),
(111816, 5659, 29, 'Tìm kiếm'),
(111817, 5661, 29, 'tìm'),
(111818, 5662, 29, 'tìm lần nữa'),
(111819, 5664, 29, 'Tìm theo:'),
(111820, 5665, 29, 'Tìm'),
(111821, 5666, 29, 'Tìm:'),
(111822, 5668, 29, 'Tìm trong'),
(111823, 5669, 29, 'Tìm kiếm hay Thêm bệnh nhân'),
(111824, 5670, 29, 'Tìm kiếm thanh toán'),
(111825, 5672, 29, 'Kết quả tìm kiếm:'),
(111826, 5673, 29, 'Tìm kiếm chọn lọc'),
(111827, 5674, 29, 'Chuỗi tìm kiếm không phù hợp với danh sách trong cơ sở dữ liệu'),
(111828, 5675, 29, 'Chuỗi tìm kiếm nên có ít nhất ba ký tự'),
(111829, 5676, 29, 'Tìm kiếm văn bản'),
(111830, 5677, 29, 'Tìm kiếm các sự kiện'),
(111831, 5678, 29, 'Tìm kiếm /'),
(111832, 5679, 29, 'Tìm kiếm / Thêm hãng bảo hiểm'),
(111833, 5680, 29, 'Tìm kiếm cho các cuộc hẹn'),
(111834, 5681, 29, 'Tìm kiếm ...'),
(111835, 5682, 29, 'Sử dụng Dây an toàn trên xe'),
(111836, 5683, 29, 'Sử dụng dây an toàn trên xe'),
(111837, 5684, 29, 'Thứ hai'),
(111838, 5687, 29, 'Thứ hai'),
(111839, 5688, 29, 'Bảo hiểm Thứ hai'),
(111840, 5689, 29, 'Dữ liệu Bảo hiểm Thứ hai'),
(111841, 5690, 29, 'Nhà cung cấp Bảo hiểm Thứ hai'),
(111842, 5691, 29, 'Loại Chăm sóc Thứ hai'),
(111843, 5698, 29, 'An ninh'),
(111844, 5699, 29, 'Xem Tất cả'),
(111845, 5700, 29, 'Quyền Xem'),
(111846, 5701, 29, 'Xem Biểu đồ Tăng trưởng'),
(111847, 5702, 29, 'Xem tin nhắn từ các thiết lập cuối cùng của tuyên bố tạo ra'),
(111848, 5704, 29, 'Từng thấy kể từ'),
(111849, 5707, 29, 'Động kinh'),
(111850, 5708, 29, 'Sel'),
(111851, 5709, 29, 'Chọn'),
(111852, 5710, 29, 'chọn'),
(111853, 5712, 29, 'Chọn một bối cảnh'),
(111854, 5715, 29, 'Chọn một người dùng'),
(111855, 5716, 29, 'Chọn tất cả'),
(111857, 5720, 29, 'Chọn thể loại'),
(111858, 5722, 29, 'Chọn hộp kiểm tương ứng để xóa'),
(111859, 5723, 29, 'Chọn tiêu chí để Hủy bỏ'),
(111860, 5725, 29, 'Chọn dữ liệu yêu cầu cho De Xác định'),
(111861, 5726, 29, 'Chọn dữ liệu được bao gồm trong De Xác định dữ liệu'),
(111862, 5727, 29, 'Chọn ngày'),
(111863, 5728, 29, 'Chọn đội hình mong muốn'),
(111864, 5729, 29, 'Chọn Chẩn đoán'),
(111865, 5730, 29, 'Chọn Chẩn đoán cho De Xác định yêu cầu'),
(111866, 5731, 29, 'Chọn thuốc'),
(111867, 5732, 29, 'Chọn thuốc'),
(111868, 5733, 29, 'Chọn Thuốc cho De Xác định yêu cầu'),
(111869, 5734, 29, 'Chọn EDI-271 tập tin'),
(111870, 5736, 29, 'Chọn lĩnh vực'),
(111871, 5737, 29, 'Chọn Fields'),
(111872, 5738, 29, 'Chọn để in'),
(111873, 5739, 29, 'Chọn Chủng ngừa'),
(111874, 5740, 29, 'Chọn Chủng ngừa cho De Xác định yêu cầu'),
(111875, 5741, 29, 'Chọn bảo hiểm, bằng cách gõ'),
(111876, 5742, 29, 'Chọn Bản sao'),
(111877, 5744, 29, 'Chọn Ngôn ngữ'),
(111878, 5746, 29, 'Chọn một hay nhiều mã chẩn đoán để xác nhận dịch vụ'),
(111879, 5754, 29, 'Chọn các mục cấu hình để kết xuất'),
(111880, 5755, 29, 'Chọn vấn đề chủ yếu chịu trách nhiệm về bất kỳ sự kiện bị nhỡ vào ngày này'),
(111881, 5759, 29, 'Chọn Người dùng'),
(111882, 5760, 29, 'Chọn Người dùng Từ Danh sách Thả xuống'),
(111883, 5761, 29, 'Chọn ngôn ngữ, nếu có, có thể được lựa chọn lúc đăng nhập. (Chỉ thích hợp nếu tắt Cho phép Mọi Ngôn ngữ ở trên)'),
(111884, 5762, 29, 'Chọn Yes để xác nhận việc xóa nhóm'),
(111885, 5765, 29, 'Được chọn'),
(111886, 5766, 29, 'Lần khám Được chọn'),
(111887, 5767, 29, 'Chọn cái này để tạo một tin nhắn phải được từng người nhận xử lý (đây không phải là công việc nhóm).'),
(111888, 5768, 29, 'Bản thân'),
(111889, 5769, 29, 'Tự trả'),
(111890, 5771, 29, 'Gửi'),
(111891, 5772, 29, 'Gửi một Lời nhắc có Ngày'),
(111892, 5773, 29, 'Gửi một lời nhắc'),
(111893, 5774, 29, 'Đang gửi'),
(111894, 5775, 29, 'Gửi tin nhắn'),
(111895, 5776, 29, 'Gửi Một loạt Lời nhắc'),
(111896, 5777, 29, 'Gửi lời nhắc cho các bệnh nhân theo sở thích của bệnh nhân để phòng ngừa / theo dõi chăm sóc.'),
(111897, 5778, 29, 'Gửi tóm tắt với Giới thiệu tham gia'),
(111898, 5779, 29, 'Gửi tập tin này'),
(111899, 5788, 29, 'Tên người gửi'),
(111900, 5789, 29, 'Tên người gửi ID'),
(111901, 5790, 29, 'Tên người gửi ID (ISA06)'),
(111902, 5791, 29, 'Tên người gửi ID vòng loại (ISA05)'),
(111903, 5794, 29, 'Sự nhạy cảm'),
(111904, 5795, 29, 'Mức nhạy cảm:'),
(111905, 5796, 29, 'Cảm giác kỳ thi bình thường'),
(111906, 5799, 29, 'Người Gửi, Để Trống Là Tất cả'),
(111907, 5801, 29, 'Ngày Gửi'),
(111908, 5802, 29, 'Thư đã Gửi'),
(111909, 5803, 29, 'Gửi hồ sơ y tế?'),
(111910, 5804, 29, 'Gửi thành công'),
(111911, 5807, 29, 'đã gửi đến máy in.'),
(111912, 5808, 29, 'Người Nhận, Để Trống Là Tất cả'),
(111913, 5812, 29, 'Tháng Chín'),
(111914, 5813, 29, 'Ly thân'),
(111915, 5814, 29, 'Tháng Chín'),
(111916, 5815, 29, 'TT'),
(111917, 5816, 29, 'Trình tự'),
(111918, 5821, 29, 'Dịch vụ'),
(111919, 5822, 29, 'Thể loại Dịch vụ'),
(111920, 5823, 29, 'Mã Dịch vụ'),
(111921, 5825, 29, 'Mã Dịch vụ'),
(111922, 5826, 29, 'Ngày Dịch vụ'),
(111923, 5827, 29, 'Ngày Dịch vụ:'),
(111924, 5829, 29, 'Vị trí Dịch vụ'),
(111925, 5831, 29, 'Dịch vụ cung cấp bởi chuyên gia'),
(111926, 5834, 29, 'Dịch vụ'),
(111927, 5835, 29, 'Dịch vụ theo Thể loại'),
(111928, 5836, 29, 'Dịch vụ cung cấp'),
(111929, 5837, 29, 'Dịch vụ cung cấp'),
(111930, 5838, 29, 'Dịch vụ / sản phẩm'),
(111931, 5839, 29, 'Phiên Loại'),
(111932, 5840, 29, 'Thiết lập'),
(111933, 5841, 29, 'Thiết lập một cookie cơ sở để nhớ cơ sở được chọn giữa các lần đăng nhập.'),
(111934, 5845, 29, 'Thiết lập này để đường dẫn tuyệt đối đầy đủ. Đối với việc tạo chứng chỉ máy khách SSL cho HTTPS.'),
(111935, 5846, 29, 'Thiết lập Để'),
(111936, 5847, 29, 'Thiết lập về Mặc định'),
(111937, 5848, 29, 'Thiết lập số phiên bản trong cơ sở dữ liệu ...'),
(111938, 5849, 29, 'Cài đặt'),
(111939, 5851, 29, 'Nghiêm trọng Đau nửa đầu'),
(111940, 5853, 29, 'Mức độ nghiêm trọng of Pain'),
(111941, 5854, 29, 'Mức độ nghiêm trọng of Pain:'),
(111942, 5855, 29, 'Giới tính'),
(111943, 5856, 29, 'Bệnh Truyền qua đường Tình dục'),
(111944, 5858, 29, 'Mã băm (Hash) Sha-1'),
(111945, 5859, 29, 'Chia sẻ'),
(111946, 5860, 29, 'Lệnh hệ thống để in từ máy chủ.'),
(111947, 5864, 29, 'Khó thở'),
(111948, 5865, 29, 'Khó Thở'),
(111949, 5866, 29, 'Khó Thở 2'),
(111950, 5867, 29, 'Shot Ghi'),
(111951, 5868, 29, 'Shot Ghi lại như của:'),
(111952, 5870, 29, 'nên là như nnnnn nnnn-nn'),
(111953, 5871, 29, 'Nên có hai chữ cái'),
(111954, 5872, 29, 'nên chứa 10 chữ số'),
(111955, 5873, 29, 'nên chứa chỉ có 10 chữ số'),
(111956, 5874, 29, 'Vai'),
(111957, 5875, 29, 'Vai + xương đòn'),
(111958, 5876, 29, 'Vai vấn đề'),
(111959, 5877, 29, 'Hiển thị'),
(111960, 5880, 29, 'Hiện tất cả'),
(111961, 5883, 29, 'Tất cả Giao dịch'),
(111962, 5884, 29, 'Hiển thị như Busy'),
(111963, 5885, 29, 'Hiện có thẩm quyền Chỉ'),
(111964, 5886, 29, 'Times có sẵn'),
(111965, 5887, 29, 'Hiện cả hai hệ Mỹ và hệ mét (đơn vị chính là hệ mét)'),
(111966, 5888, 29, 'Hiện cả hai hệ Mỹ và hệ mét (đơn vị chính là hệ Mỹ)'),
(111967, 5889, 29, 'Hiển thị Chi tiết'),
(111968, 5891, 29, 'Hiển thị Đồ thị'),
(111969, 5892, 29, 'Hiện lơ lửng văn bản trên sự kiện mouseover?'),
(111970, 5893, 29, 'Bao nhiêu sự kiện trên trang quản trị?'),
(111971, 5896, 29, 'Hiện Trình đơn'),
(111972, 5897, 29, 'Chỉ hiển thị hệ mét'),
(111973, 5898, 29, 'Hiện Ghi chú'),
(111974, 5901, 29, 'Hiện Ghi chú Bệnh nhân'),
(111975, 5904, 29, 'Hiển thị tiểu học Hoàn thành'),
(111976, 5905, 29, 'Hiện Các nhắc nhở'),
(111977, 5906, 29, 'Hiện Báo cáo'),
(111978, 5907, 29, 'Hiện tìm kiếm / trình liên kết trong khối?'),
(111979, 5910, 29, 'Các hình thức nhà nước tùy chỉnh cho widget danh sách add (sẽ yêu cầu tiêu đề và tên viết tắt).'),
(111980, 5913, 29, 'Hiện Unbilled Chỉ'),
(111981, 5914, 29, 'Hiện chỉ có ở Hoa Kỳ'),
(111982, 5920, 29, 'Anh chị em ruột'),
(111983, 5921, 29, 'Tế bào hình liềm'),
(111984, 5922, 29, 'Sig'),
(111985, 5923, 29, 'Sigma / Soi ruột già'),
(111986, 5925, 29, 'Ký kết quả từ phòng thí nghiệm (ghi, addonly tùy chọn)'),
(111987, 5926, 29, 'Đăng ký Kết quả'),
(111988, 5927, 29, 'Chữ ký'),
(111989, 5929, 29, 'Chữ ký:'),
(111990, 5930, 29, 'Toa thuốc Đã ký'),
(111991, 5932, 29, 'Đáng kể Sưng:'),
(111992, 5934, 29, 'Đơn giản hóa Đồng Chi trả'),
(111993, 5935, 29, 'Đơn giản hóa Thông tin cá nhân'),
(111994, 5936, 29, 'Đơn giản hóa Đơn thuốc'),
(111995, 5937, 29, 'Kể từ khi'),
(111996, 5938, 29, 'Trân trọng,'),
(111997, 5940, 29, 'Độc thân'),
(111998, 5941, 29, 'Single-lựa chọn danh sách'),
(111999, 5942, 29, 'Danh sách lựa chọn duy nhất với khả năng để thêm vào danh sách'),
(112000, 5946, 29, 'Xoang vấn đề'),
(112001, 5947, 29, 'Xoang phẫu thuật'),
(112002, 5948, 29, 'Xoang dịu dàng:'),
(112003, 5949, 29, 'Viêm xoang'),
(112004, 5951, 29, 'Site ID'),
(112005, 5953, 29, 'Site ID LLC LibreEHR Hỗ trợ dịch vụ Lab Exchange.'),
(112006, 5956, 29, 'Kích thước'),
(112007, 5957, 29, 'Kích phải là một số giữa 1 và 999'),
(112008, 5958, 29, 'Kích thước / Danh sách'),
(112009, 5959, 29, 'Da'),
(112010, 5960, 29, 'Ung thư da'),
(112011, 5961, 29, 'Da bệnh'),
(112012, 5962, 29, 'Skin khác'),
(112013, 5963, 29, 'Bỏ qua Việc xác thực cho Ghi chú Bệnh nhân'),
(112014, 5964, 29, 'Bỏ qua phần'),
(112015, 5965, 29, 'Bỏ qua bãi chứa SQL-Ledger - không được thực hiện cho máy chủ Windows'),
(112016, 5967, 29, 'Giấc ngủ Patterns'),
(112017, 5968, 29, 'Ngủ mẫu'),
(112018, 5969, 29, 'Ngủ'),
(112019, 5970, 29, 'Tiếng Slovak'),
(112020, 5972, 29, 'Sm nợ w / o'),
(112021, 5973, 29, 'Cache Smarty đã được giải tỏa'),
(112022, 5974, 29, 'Hút thuốc, hiện không biết tình trạng'),
(112023, 5976, 29, 'Tình trạng Hút thuốc'),
(112024, 5977, 29, 'Cho SMS'),
(112025, 5978, 29, 'Cổng tin nhắn SMS'),
(112026, 5979, 29, 'Khóa API cho Cổng Tin nhắn SMS'),
(112027, 5980, 29, 'Khóa API cho Cổng Tin nhắn SMS'),
(112028, 5981, 29, 'Mật khẩu cho Cổng Tin nhắn SMS'),
(112029, 5982, 29, 'Tên đăng nhập cho Cổng Tin nhắn SMS'),
(112030, 5983, 29, 'Thông báo Tin nhắn SMS'),
(112031, 5984, 29, 'Giờ Thông báo Tin nhắn SMS'),
(112032, 5985, 29, 'Gửi SMS trước'),
(112033, 5986, 29, 'Đã gửi SMS'),
(112034, 5987, 29, 'Nội dung tin nhắn, Có thể dùng thẻ: ***NAME***, ***PROVIDER***, ***DATE***, ***STARTTIME***, ***ENDTIME***<br>Ví dụ Kính gửi ***NAME***'),
(112035, 5988, 29, 'Cài đặt Thông báo Tin nhắn SMS / Email'),
(112036, 5989, 29, 'SMTP mật khẩu cho xác thực'),
(112037, 5992, 29, 'SMTP Server Hostname'),
(112038, 5993, 29, 'SMTP Server Port Number'),
(112039, 5994, 29, 'SMTP tài cho xác thực'),
(112040, 5995, 29, 'SNOMED'),
(112041, 6001, 29, 'SNOMED Cơ sở dữ liệu'),
(112042, 6004, 29, 'Ngáy'),
(112043, 6005, 29, 'SOAP'),
(112044, 6006, 29, 'Xã hội khó khăn'),
(112045, 6009, 29, 'Lịch sử xã hội:'),
(112046, 6010, 29, 'Số An Sinh Xã Hội'),
(112047, 6011, 29, 'dung dịch uống'),
(112048, 6013, 29, 'Soma Context'),
(112049, 6014, 29, 'Một số ủy quyền không được hiển thị. Click vào đây để xem tất cả'),
(112050, 6015, 29, 'Một số mã không được hiển thị.'),
(112051, 6016, 29, 'Một số cuộc gặp gỡ không được hiển thị. Click vào đây để xem tất cả.'),
(112052, 6017, 29, 'Một số lỗi đã xảy ra trong quá trình nhận dạng De'),
(112053, 6018, 29, 'Một số lưu ý không được hiển thị.'),
(112054, 6020, 29, 'một số từ'),
(112055, 6023, 29, 'Một cái gì đó đã đi sai. Vui lòng thử lại.'),
(112056, 6024, 29, 'Thời khoảng Sắp Đến hạn (Nhắc nhở Lâm sàng)'),
(112057, 6025, 29, 'Thời khoảng Sắp Đến hạn (Nhắc nhở bệnh nhân)'),
(112058, 6026, 29, 'Đau họng'),
(112059, 6028, 29, 'Xin lỗi, có một vấn đề tải lên tập tin của bạn'),
(112060, 6029, 29, 'Sắp xếp theo'),
(112061, 6030, 29, 'Sắp xếp theo'),
(112062, 6031, 29, 'Sắp xếp bởi Checksum'),
(112063, 6032, 29, 'Sắp xếp bởi bình luận'),
(112064, 6033, 29, 'Sắp xếp bởi người sử dụng màn hình CRT'),
(112065, 6034, 29, 'Sắp xếp theo ngày'),
(112066, 6035, 29, 'Sắp xếp theo ngày / thời gian'),
(112067, 6036, 29, 'Sắp xếp bởi sự kiện'),
(112068, 6037, 29, 'Sắp xếp của Tập đoàn'),
(112069, 6040, 29, 'Sắp xếp bởi PatientID'),
(112070, 6041, 29, 'Sắp xếp bởi thành công'),
(112071, 6043, 29, 'Sắp xếp bởi người'),
(112072, 6044, 29, 'Sắp xếp bởi vắc-xin'),
(112073, 6045, 29, 'Sắp xếp Giảm'),
(112074, 6046, 29, 'Sắp xếp kết quả theo'),
(112075, 6047, 29, 'Sắp xếp Tăng'),
(112076, 6048, 29, 'Nguồn'),
(112077, 6049, 29, 'Tập tin Nguồn'),
(112078, 6050, 29, 'Đường dẫn Tập tin nguồn'),
(112079, 6051, 29, 'Nguồn được cho mã '),
(112080, 6052, 29, 'Nguồn Lô'),
(112081, 6057, 29, 'Nguồn:'),
(112082, 6060, 29, 'Khoảng trắng'),
(112083, 6061, 29, 'KHOẢNG TRẮNG'),
(112084, 6062, 29, 'Tiếng Tây Ban Nha'),
(112085, 6063, 29, 'Tiếng Tây Ban Nha (Mỹ Latin)'),
(112086, 6064, 29, 'Tiếng Tây Ban Nha (Tây Ban Nha)'),
(112087, 6068, 29, 'Chuyên gia'),
(112088, 6069, 29, 'Tên và chữ ký chuyên gia'),
(112089, 6071, 29, 'Chuyên khoa'),
(112090, 6072, 29, 'Hệ thống Đặc biệt'),
(112091, 6073, 29, 'Chuyên khoa:'),
(112092, 6074, 29, 'Cụ thể'),
(112093, 6075, 29, 'Ứng dụng Cụ thể'),
(112094, 6076, 29, 'Specific Contraceptive Service'),
(112095, 6077, 29, 'Kết quả Cụ thể'),
(112096, 6078, 29, 'Dịch vụ Cụ thể'),
(112097, 6079, 29, 'Quy định'),
(112098, 6080, 29, 'Chỉ định định dạng cho mã số. # = chữ số, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112099, 6081, 29, 'Chỉ định định dạng cho mã số. # = chữ số, @ = chữ cái, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112100, 6082, 29, 'Chỉ định định dạng cho các số tham chiếu hoá đơn. # = chữ số, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112101, 6083, 29, 'Chỉ định định dạng cho các số tham chiếu hoá đơn. # = chữ số, @ = chữ cái, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112102, 6084, 29, 'Chỉ định định dạng cho sản phẩm lĩnh vực NDC. # = chữ số, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112103, 6085, 29, 'Chỉ định định dạng cho sản phẩm lĩnh vực NDC. # = chữ số, @ = chữ cái, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112104, 6086, 29, 'Chỉ định định dạng cho mã số bệnh nhân bên ngoài. # = chữ số, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112105, 6087, 29, 'Chỉ định định dạng cho mã số bệnh nhân bên ngoài. # = chữ số, @ = chữ cái, * = ký tự bất kỳ. Để trống nếu không dùng.'),
(112106, 6088, 29, 'Mẫu'),
(112107, 6089, 29, 'Mẫu số / định danh'),
(112108, 6090, 29, 'Mẫu Loại'),
(112109, 6092, 29, 'Lời dặn của Bác sĩ'),
(112110, 6093, 29, 'Chất diệt tinh trùng'),
(112111, 6094, 29, 'Cắt lách'),
(112112, 6095, 29, 'Vợ/chồng'),
(112113, 6097, 29, 'Đờm'),
(112114, 6098, 29, 'Đờm:'),
(112115, 6099, 29, 'subcutaneous'),
(112116, 6102, 29, 'Squad'),
(112117, 6103, 29, 'Squad thành viên'),
(112118, 6104, 29, 'Đội'),
(112119, 6105, 29, 'SRH'),
(112120, 6106, 29, 'SRH - Kế hoạch hoá gia đình'),
(112121, 6107, 29, 'SRH không Kế hoạch hoá gia đình'),
(112122, 6108, 29, 'SRH Giới thiệu tham gia'),
(112123, 6109, 29, 'SRH Chơi Mẫu'),
(112124, 6110, 29, 'Srv ngày'),
(112125, 6111, 29, 'SS'),
(112126, 6112, 29, 'Quản Lý SSL Certificate'),
(112127, 6113, 29, 'SSN'),
(112128, 6114, 29, 'Ổn định'),
(112129, 6116, 29, 'Tiêu chuẩn'),
(112130, 6117, 29, 'Tiêu chuẩn Mã'),
(112131, 6118, 29, 'Tiêu chuẩn các biện pháp'),
(112132, 6122, 29, 'Tiêu chuẩn Tên'),
(112133, 6124, 29, 'Bắt đầu'),
(112134, 6125, 29, 'Bắt đầu (yyyy-mm-dd): '),
(112135, 6128, 29, 'Ngày bắt đầu'),
(112136, 6129, 29, 'Ngày bắt đầu tại Phòng khám này'),
(112137, 6130, 29, 'Ngày bắt đầu không nên lớn hơn Ngày Kết thúc'),
(112138, 6131, 29, 'Ngày bắt đầu:'),
(112139, 6132, 29, 'Ngày bắt đầu:'),
(112140, 6133, 29, 'Thời gian bắt đầu'),
(112141, 6134, 29, 'Ngày bắt đầu'),
(112142, 6135, 29, 'stat'),
(112143, 6136, 29, 'Tiểu bang'),
(112144, 6137, 29, 'Loại Dữ liệu Tiểu bang'),
(112145, 6138, 29, 'Số g.phép Tiểu bang'),
(112146, 6139, 29, 'Số Giấy phép Tiểu bang'),
(112147, 6140, 29, 'Danh sách tiểu bang'),
(112148, 6141, 29, 'Danh sách nhà nước (viết, addonly tùy chọn)'),
(112149, 6142, 29, 'Danh sách Widget nhà nước Tuỳ chỉnh lĩnh vực'),
(112150, 6143, 29, 'Tiểu bang hoặc Tỉnh'),
(112151, 6144, 29, 'Tiểu bang/Địa phương'),
(112152, 6145, 29, 'Tiểu bang/Giáo xứ'),
(112153, 6146, 29, 'BẢNG TÓM TẮT'),
(112154, 6147, 29, 'báo cáo và cập nhật hoá đơn.'),
(112155, 6148, 29, 'Báo cáo đã gửi:'),
(112156, 6149, 29, 'báo cáo, hóa đơn sẽ không được cập nhật.'),
(112157, 6150, 29, 'Tĩnh văn bản'),
(112158, 6151, 29, 'Thống kê'),
(112159, 6152, 29, 'Thống kê'),
(112160, 6153, 29, 'Tình trạng'),
(112161, 6156, 29, 'Hiện trạng'),
(112162, 6158, 29, 'Các Couns STD / AIDS'),
(112163, 6159, 29, 'Stength và điều'),
(112164, 6169, 29, 'Cứng mối nối'),
(112165, 6170, 29, 'Độ cứng'),
(112166, 6171, 29, 'Chứng khoán tháng'),
(112167, 6172, 29, 'Dạ dày Pains'),
(112168, 6174, 29, 'Lưu trữ Hash'),
(112169, 6175, 29, 'Căng thẳng cơ bắp'),
(112170, 6176, 29, 'Dòng'),
(112171, 6177, 29, 'Đường phố'),
(112172, 6178, 29, 'Địa chỉ'),
(112173, 6179, 29, 'Số nhà và Tên đường'),
(112174, 6180, 29, 'Sức mạnh'),
(112175, 6182, 29, 'Strep Throat'),
(112176, 6183, 29, 'Căng thẳng gãy xương'),
(112177, 6184, 29, 'Stress Test'),
(112178, 6185, 29, 'Tai biến mạch máu não'),
(112179, 6186, 29, 'Mạnh mật khẩu có nghĩa là ít nhất 8 ký tự, và ít nhất ba: một số, chữ viết thường, một ký tự hoa, ký tự đặc biệt.'),
(112180, 6188, 29, 'Kiểu biểu mẫu được sử dụng cho việc thêm bệnh nhân mới'),
(112181, 6189, 29, 'Tiểu thể loại'),
(112182, 6190, 29, 'Tổng phụ'),
(112183, 6191, 29, 'Tiểu thể loại'),
(112184, 6192, 29, 'tiểu thể loại'),
(112185, 6193, 29, 'tiêm dưới da'),
(112186, 6194, 29, 'Tiêu đề'),
(112187, 6195, 29, 'Chủ quan (Subjective)'),
(112188, 6196, 29, 'Ngậm dưới lưỡi'),
(112189, 6197, 29, 'ngậm dưới lưỡi'),
(112190, 6198, 29, 'Gửi'),
(112191, 6199, 29, 'gửi'),
(112192, 6200, 29, 'Gửi Tất cả Nội dung'),
(112193, 6202, 29, 'Gửi Sự kiện'),
(112194, 6203, 29, 'gửi biểu mẫu'),
(112195, 6204, 29, 'Gửi Nội dung Được chọn'),
(112196, 6205, 29, 'Đã gửi'),
(112197, 6206, 29, 'Đã gửi bởi'),
(112198, 6207, 29, 'Số truy cập nộp EDI (PER06)'),
(112199, 6208, 29, 'Người đăng ký'),
(112200, 6209, 29, 'Địa chỉ Người đăng ký'),
(112201, 6213, 29, 'Công ty của Người đăng ký'),
(112202, 6214, 29, 'Công ty của Người đăng ký (SE)'),
(112203, 6215, 29, 'Địa chỉ Công ty của Người đăng ký'),
(112204, 6216, 29, 'Thành phố Công ty của Người đăng ký'),
(112205, 6217, 29, 'Quốc gia của Công ty của Người đăng ký'),
(112206, 6218, 29, 'Tiểu bang của Công ty của Người đăng ký'),
(112207, 6221, 29, 'Mã Zip của Công ty của Người đăng ký'),
(112208, 6225, 29, 'Điện thoại Người đăng ký'),
(112209, 6226, 29, 'Mối quan hệ Với Người đăng ký'),
(112210, 6227, 29, 'Mối quan hệ được chọn không là "bản thân" nhưng tên thì giống! Điều này có thực sự ĐÚNG không?'),
(112211, 6228, 29, 'Mối quan hệ được chọn không là "bản thân" nhưng số An sinh Xã hội (SS) thì giống!'),
(112212, 6229, 29, 'Mối quan hệ được chọn là "bản thân" nhưng tên thì khác! Điều này có thực sự ĐÚNG không?'),
(112213, 6230, 29, 'Mối quan hệ được chọn là "bản thân" nhưng số An sinh Xã hội (SS) thì khác!'),
(112214, 6231, 29, 'Giới tính Người đăng ký'),
(112215, 6237, 29, 'Thay thế'),
(112216, 6238, 29, 'cho phép thay thế'),
(112217, 6240, 29, 'Thành công'),
(112218, 6241, 29, 'thành công'),
(112219, 6242, 29, 'Nhận xác nhận thành công của kết quả phòng thí nghiệm'),
(112220, 6243, 29, 'Thành công nhận được kết quả phòng thí nghiệm'),
(112221, 6244, 29, 'Kết quả thành công lấy từ phòng thí nghiệm Exchange Network'),
(112222, 6246, 29, 'Bổ sung thành công thể loại'),
(112223, 6247, 29, 'bổ sung thành công vào loại,'),
(112224, 6248, 29, 'Thành công Đã bị xóa'),
(112225, 6250, 29, 'Cài đặt thành công cơ sở dữ liệu.'),
(112226, 6252, 29, 'Thành công thay đổi'),
(112227, 6253, 29, 'Thành công Saved.Would bạn muốn Phân bổ?'),
(112228, 6254, 29, 'Thành công Saved.Would bạn thích để phân phối?'),
(112229, 6256, 29, 'thành công được lưu trữ.'),
(112230, 6257, 29, 'Nâng cấp thành công cơ sở dữ liệu.'),
(112231, 6259, 29, 'thành công.'),
(112232, 6260, 29, 'Tự tử'),
(112233, 6261, 29, 'Tóm tắt thông tin'),
(112234, 6262, 29, 'Tóm tắt'),
(112235, 6265, 29, 'CN'),
(112236, 6267, 29, 'Chủ Nhật'),
(112237, 6268, 29, 'Superbill'),
(112238, 6269, 29, 'Superbill Codes'),
(112239, 6270, 29, 'Cục Superbill Codes'),
(112240, 6271, 29, 'Superbill Báo cáo'),
(112241, 6274, 29, 'Superbills, đôi khi được gọi là Gặp Các hình thức định tuyến Váy, là một phần thiết yếu của hầu hết các thực hành y tế.'),
(112242, 6275, 29, 'Superuser'),
(112243, 6276, 29, 'Giám sát'),
(112244, 6278, 29, 'Giám sát Doctor DEA'),
(112245, 6279, 29, 'Giám sát tên bác sĩ đầu tiên'),
(112246, 6280, 29, 'Giám sát tên Doctor cuối'),
(112247, 6281, 29, 'Giám sát Doctor NPI'),
(112248, 6282, 29, 'Giám sát Doctor UPIN'),
(112249, 6283, 29, 'Tên nhà cung cấp cơ sở'),
(112250, 6284, 29, 'Hỗ trợ các sự kiện lịch áp dụng cho nhiều nhà cung cấp'),
(112251, 6285, 29, 'Hỗ trợ kết xuất / kết nhập các dữ liệu cấu hình thông qua trang Backup.'),
(112252, 6286, 29, 'Hỗ trợ Sự kiện Nhiều Nhà cung cấp'),
(112253, 6288, 29, 'Hỗ trợ mã hóa / giải mã TripleDES.'),
(112254, 6289, 29, 'Bề mặt Loại'),
(112255, 6290, 29, 'Phẫu thuật'),
(112256, 6291, 29, 'Phẫu thuật'),
(112257, 6293, 29, 'Đình chỉ'),
(112258, 6294, 29, 'đình chỉ'),
(112259, 6295, 29, 'Svc ngày'),
(112260, 6296, 29, 'Svc ngày:'),
(112261, 6299, 29, 'Đổ mồ hôi:'),
(112262, 6300, 29, 'Thụy Điển'),
(112263, 6301, 29, 'Sưng'),
(112264, 6302, 29, 'Sưng phải'),
(112265, 6303, 29, 'Sưng mối nối'),
(112266, 6304, 29, 'Sưng hạch bạch huyết'),
(112267, 6305, 29, 'Biểu tượng được sử dụng như là điểm thập phân cho tiền tệ. Không được sử dụng nếu số chữ số thập phân là 0.'),
(112268, 6306, 29, 'Dấu hiệu dùng để phân cách hàng ngàn cho tiền tệ.'),
(112269, 6307, 29, 'Các triệu chứng'),
(112270, 6308, 29, 'Đồng bộ hóa'),
(112271, 6309, 29, 'Đồng bộ hóa dịch với bảng ngôn ngữ tùy chỉnh.'),
(112272, 6310, 29, 'Đồng bộ mới tùy chỉnh liên tục:'),
(112273, 6311, 29, 'Đồng bộ mới tùy chỉnh ngôn ngữ:'),
(112274, 6312, 29, 'Đồng bộ mới định nghĩa (Ngôn ngữ, Constant, Definition):'),
(112275, 6313, 29, 'Sự bất tỉnh'),
(112276, 6314, 29, 'Hội chứng giám sát'),
(112277, 6315, 29, 'Hội chứng giám sát không báo cáo vấn đề'),
(112278, 6317, 29, 'Viêm màng hoạt dịch, viêm bao hoạt dịch, va đập'),
(112279, 6318, 29, 'Hệ thống'),
(112280, 6322, 29, 'T'),
(112281, 6323, 29, '3 lần/ngày'),
(112282, 6324, 29, 'T.V.'),
(112283, 6325, 29, 'Bảng'),
(112284, 6327, 29, 'Lỗi khi tạo bảng'),
(112285, 6328, 29, 'Lỗi khi cập nhật bảng'),
(112286, 6330, 29, 'viên'),
(112287, 6332, 29, 'Tiếng Tagal'),
(112288, 6335, 29, 'Hãy'),
(112289, 6336, 29, 'Hãy bảo hiểm, từ trên xuống'),
(112290, 6337, 29, 'Hãy thanh toán Từ, từ trên xuống'),
(112291, 6338, 29, 'Takeback'),
(112292, 6339, 29, 'Đưa dài'),
(112293, 6340, 29, 'Vùng Chuyển hướng Cao'),
(112294, 6347, 29, 'Mục tiêu ngày'),
(112295, 6351, 29, 'Nhóm mục tiêu / Hành động'),
(112296, 6354, 29, 'ID thuế'),
(112297, 6355, 29, 'Thuế suất'),
(112298, 6356, 29, 'Thuế'),
(112299, 6357, 29, 'Phân loại tư duy'),
(112300, 6358, 29, 'Td'),
(112301, 6359, 29, 'Tổng quan về đội ngũ chấn thương'),
(112302, 6360, 29, 'Nhóm Roster'),
(112303, 6361, 29, 'Nhóm Roster Xem'),
(112304, 6362, 29, 'Team / Squad'),
(112305, 6363, 29, 'Điện thoại'),
(112306, 6364, 29, 'Mã điện thoại quốc gia'),
(112307, 6366, 29, 'Nhiệt độ'),
(112308, 6367, 29, 'Vị trí đo Nhiệt độ'),
(112309, 6368, 29, 'Phương pháp đo Nhiệt độ'),
(112310, 6369, 29, 'Nhiệt độ'),
(112311, 6370, 29, 'Khuôn mẫu'),
(112312, 6371, 29, 'Tên Khuôn mẫu'),
(112313, 6372, 29, 'Tên khuôn mẫu không có thể bắt đầu với những con số.'),
(112314, 6373, 29, 'Khuôn mẫu:'),
(112315, 6374, 29, 'Khuôn mẫu'),
(112316, 6375, 29, 'Temporal động mạch'),
(112317, 6376, 29, 'Gân chấn thương'),
(112318, 6377, 29, 'Viêm gân / osis / viêm bao hoạt dịch'),
(112319, 6378, 29, 'Dự kiến ​​Hoá đơn Tài liệu tham khảo'),
(112320, 6379, 29, 'Thứ ba'),
(112321, 6380, 29, 'Bảo hiểm Thứ ba'),
(112322, 6381, 29, 'Dữ liệu Bảo hiểm Thứ ba'),
(112323, 6382, 29, 'Nhà cung cấp Bảo hiểm Thứ ba'),
(112324, 6383, 29, 'Lên kế hoạch Xét nghiệm'),
(112325, 6384, 29, 'Kiểm tra hệ thống'),
(112326, 6385, 29, 'Văn bản'),
(112327, 6386, 29, 'Văn bản Chẩn đoán'),
(112328, 6387, 29, 'Trường văn bản'),
(112329, 6393, 29, 'Text-ngày'),
(112330, 6394, 29, 'văn bản ngày'),
(112331, 6395, 29, 'Textarea'),
(112332, 6396, 29, 'textarea'),
(112333, 6397, 29, 'Textbox'),
(112334, 6398, 29, 'textbox'),
(112335, 6399, 29, 'Hộp danh sách'),
(112336, 6400, 29, 'hộp danh sách'),
(112337, 6401, 29, 'Thái'),
(112338, 6402, 29, 'Cảm ơn'),
(112339, 6403, 29, 'Cảm ơn bạn đã lựa chọn'),
(112340, 6404, 29, 'Các nút ''Clear'' sẽ loại bỏ tất cả các chú thích.'),
(112341, 6405, 29, 'Những tuyên bố trên không thành công'),
(112342, 6406, 29, 'Các máy chủ Apache SSL chứng chỉ và khóa công khai'),
(112343, 6407, 29, 'Giấy chứng nhận Certificate Authority'),
(112344, 6408, 29, 'Các tập tin yêu cầu bồi thường: '),
(112345, 6410, 29, 'Khóa riêng tương ứng'),
(112346, 6413, 29, 'mã tấn công từ chối'),
(112347, 6414, 29, 'mã Nhóm tấn công từ chối'),
(112348, 6415, 29, 'Các hình thức đích đã được đóng lại'),
(112349, 6416, 29, 'Các hình thức đích đã được đóng lại, tôi không thể hành động theo lựa chọn của bạn.'),
(112350, 6418, 29, 'Bảo vệ môi trường, bệnh viện đủ điều kiện hoặc CAH tiếp nhận một bệnh nhân từ một thiết lập khác chăm sóc hoặc nhà cung cấp chăm sóc hoặc tin rằng một cuộc gặp gỡ là có liên quan cần thực hiện hòa giải thuốc.'),
(112351, 6421, 29, 'Bảo vệ môi trường, bệnh viện đủ điều kiện hoặc CAH chuyển tiếp bệnh nhân của họ đến một thiết lập khác chăm sóc hoặc nhà cung cấp chăm sóc hoặc đề cập bệnh nhân của họ đến một nhà cung cấp dịch vụ chăm sóc nên cung cấp bản tóm tắt hồ sơ chăm sóc cho mỗi sự chuyển tiếp chăm sóc hoặc giới thiệu.'),
(112352, 6422, 29, 'Các sự kiện (s) đã được phê duyệt.'),
(112353, 6423, 29, 'Các sự kiện (s) đã được ẩn.'),
(112354, 6424, 29, 'Các dữ liệu xuất khẩu xuất hiện trong vùng văn bản dưới đây. Bạn có thể sao chép và dán nó vào một thư điện tử hoặc bất kỳ điểm đến mong muốn khác.'),
(112355, 6426, 29, 'Các dữ liệu xuất khẩu xuất hiện trong vùng văn bản dưới đây. Bạn có thể sao chép và dán nó vào một thư điện tử hoặc bất kỳ điểm đến mong muốn khác.'),
(112356, 6427, 29, 'Các dữ liệu xuất khẩu xuất hiện trong vùng văn bản dưới đây. Bạn có thể sao chép và dán nó vào một thư điện tử hoặc bất kỳ điểm đến mong muốn khác.'),
(112357, 6429, 29, 'Các tập tin có thể không được thành công đổi tên, lỗi này thường liên quan đến vấn đề quyền truy cập vào hệ thống lưu trữ.'),
(112358, 6434, 29, 'Sự kiện lịch sau đây đã được thêm vào:'),
(112359, 6435, 29, 'Sự kiện lịch sau đây đã được modifed:'),
(112360, 6436, 29, 'Các loại sau đây sẽ được loại bỏ khỏi Danh sách thể loại của bạn'),
(112361, 6437, 29, 'Việc phát hành cơ sở dữ liệu sau đây được cài đặt hiện thời'),
(112362, 6439, 29, 'Các tập tin EDI sau đây đã được tải lên'),
(112363, 6440, 29, 'Thành viên đăng nhập khẩn cấp sau đây được kích hoạt:'),
(112364, 6441, 29, 'Các lỗi sau đây xảy ra'),
(112365, 6444, 29, 'Các lĩnh vực sau đây được yêu cầu'),
(112366, 6446, 29, 'Các lĩnh vực sau đây phải được điền để gửi yêu cầu.'),
(112367, 6449, 29, 'Tên máy của máy ATNA kho kiểm toán.'),
(112368, 6450, 29, 'Cửa sổ ban đầu là trang tìm kiếm hóa đơn. Ở phía trên, bạn có thể nhập vào một nguồn (ví dụ như kiểm tra số), thanh toán ngày và kiểm tra số lượng. Lý do cho các nguồn và ngày trả tiền là để bạn don ''t phải nhập họ và hơn một lần nữa cho mỗi yêu cầu bồi thường. Số tiền mà bạn nhập vào sẽ được giảm cho mỗi hóa đơn được đưa ra một phần thanh toán, và hy vọng sẽ kết thúc tại số không khi bạn đang thực hiện.'),
(112369, 6456, 29, 'Nhãn xuất hiện trên biểu mẫu'),
(112370, 6457, 29, 'Số lượng ký tự không được vượt quá'),
(112371, 6460, 29, 'Thể loại mới sẽ là một thể loại phụ của '),
(112372, 6461, 29, 'Mật khẩu mới không được trùng với mật khẩu hiện tại.'),
(112373, 6462, 29, 'Các ô nhập mật khẩu mới không giống nhau.'),
(112374, 6465, 29, 'Trang làm việc sẽ được chuyển đến Thông tin cá nhân. Bạn có thể sửa ô nhập quốc gia và nhấp chọn NewCorp lại.'),
(112375, 6466, 29, 'Mật khẩu phải có ít nhất tám ký tự, và không nên'),
(112376, 6468, 29, 'Yêu cầu hồ sơ bệnh nhân đã được ghi nhận.'),
(112377, 6469, 29, 'Nhắc nhở bệnh nhân đã được gửi'),
(112378, 6470, 29, 'Nhắc nhở bệnh nhân đã được cập nhật'),
(112379, 6472, 29, 'Các khoản thanh toán được niêm yết không thể đi dưới date.This này đảm bảo rằng sau khi bài báo cáo cuối cùng không ai cho những ngày trước đó.'),
(112380, 6475, 29, 'Các thông tin còn lại dưới đây chỉ áp dụng nếu bạn gửi bài bằng tay, hoặc nếu bạn đang làm điều chỉnh hướng dẫn sử dụng.'),
(112381, 6477, 29, 'Các tài liệu được yêu cầu là không có mặt tại vị trí mong muốn trên hệ thống tập tin hoặc không có đủ quyền để truy cập nó.'),
(112382, 6480, 29, 'Cột Source và ngày được sao chép từ trang đầu tiên, do đó, thông thường bạn sẽ không cần phải chạm vào những người. Bạn có thể đặt một số tiền thanh toán trong cột phải trả tiền, số tiền điều chỉnh trong cột Điều chỉnh, hoặc cả hai. Bạn cũng có thể nhấp vào "W" ở bên phải để tự động tính toán một giá trị điều chỉnh mà viết phần còn lại của phí cho khoản mục đó.'),
(112383, 6484, 29, 'Granularity thời gian của lịch và khoảng thời gian nhỏ nhất trong vài phút cho một khe cắm hẹn.'),
(112384, 6485, 29, 'Nhãn dịch sẽ xuất hiện trên hình thức trong ngôn ngữ hiện tại'),
(112385, 6486, 29, 'Tiêu đề dịch sẽ xuất hiện trong ngôn ngữ hiện tại'),
(112386, 6487, 29, 'Bản dịch của mô tả trong ngôn ngữ hiện tại'),
(112387, 6488, 29, 'Các bảng dịch được đồng bộ.'),
(112388, 6489, 29, 'Các loại thực thể này'),
(112389, 6490, 29, 'Mã nhà cung cấp cụ thể xác định thủ tục này hoặc kết quả'),
(112390, 6491, 29, 'Các X12 tập tin cũng như các báo cáo kết quả đầu ra HTML được lưu trữ trong "kỷ nguyên" thư mục con của thư mục cài đặt chính LibreEHR. Bạn sẽ muốn tham khảo những lưu trữ theo thời gian. URL là'),
(112391, 6492, 29, 'Các tập tin zip sẽ bao gồm các mục sau đây'),
(112392, 6493, 29, 'Bảng màu'),
(112393, 6495, 29, 'Điều trị tiêm'),
(112394, 6496, 29, 'Có'),
(112395, 6497, 29, 'Hiện tại không có quy định'),
(112396, 6498, 29, 'Có lỗi với trình của bạn. Chúng được nêu dưới đây.'),
(112397, 6500, 29, 'Không có bảng xếp hạng đã kiểm tra ra.'),
(112398, 6501, 29, 'Không có tiết lộ nào được thu âm cho bệnh nhân này.'),
(112399, 6502, 29, 'Không có phản hồi và những đề nghị, gợi ý mới'),
(112400, 6503, 29, 'Không có ghi chú trong hồ sơ của bệnh nhân này.'),
(112401, 6504, 29, 'Không có giao dịch trong hồ sơ của bệnh nhân này.'),
(112402, 6505, 29, 'Hiện đã có một lỗi khi gửi thư đến'),
(112403, 6506, 29, 'Đã có một thể loại được đặt tên là'),
(112404, 6507, 29, 'Đã là một tiểu thể loại có tên là'),
(112405, 6508, 29, 'Đã có một mục được đặt tên là'),
(112406, 6509, 29, 'Đã có một yêu cầu mở hồ sơ bệnh nhân.'),
(112407, 6510, 29, 'Không có mục COA cho AR tài khoản '),
(112408, 6511, 29, 'Không có mục COA cho tài khoản tiền mặt '),
(112409, 6512, 29, 'Không có mục COA cho tài khoản thu nhập '),
(112410, 6513, 29, 'Không có bệnh nhân hiện tại'),
(112411, 6515, 29, 'Không có trận đấu cho id hóa đơn'),
(112412, 6516, 29, 'Không có trận đấu cho id hóa đơn = '),
(112413, 6517, 29, 'Có bộ phận không có mục nhập cho các dịch vụ ID '),
(112414, 6520, 29, 'Có lỗi trong quá trình xử lý yêu cầu của bạn.'),
(112415, 6523, 29, 'Dày phải:'),
(112416, 6524, 29, 'Đùi'),
(112417, 6525, 29, 'Đùi + chấn thương gân kheo'),
(112418, 6527, 29, 'Những điều đó trở lại văn phòng có thể đọc và nhập nhưng không thay đổi'),
(112419, 6528, 29, 'Những điều mà trở lại văn phòng có thể đọc và sửa đổi'),
(112420, 6531, 29, 'Những điều mà các bác sĩ lâm sàng có thể đọc và nhập nhưng không thay đổi'),
(112421, 6532, 29, 'Những điều mà các bác sĩ lâm sàng có thể đọc và sửa đổi'),
(112422, 6535, 29, 'Những điều mà tân có thể đọc và nhập nhưng không thay đổi'),
(112423, 6536, 29, 'Những điều mà trước văn phòng có thể đọc và sửa đổi'),
(112424, 6539, 29, 'Những điều mà bác sĩ có thể đọc và nhập nhưng không thay đổi'),
(112425, 6540, 29, 'Những điều mà các bác sĩ có thể đọc và sửa đổi'),
(112426, 6542, 29, 'Thứ ba'),
(112427, 6544, 29, 'Hành động này KHÔNG THỂ được hoàn tác.'),
(112428, 6545, 29, 'Hành động này không thể được hoàn tác.'),
(112429, 6547, 29, 'Hành động này sẽ được ghi nhận'),
(112430, 6551, 29, 'Năm Nay'),
(112431, 6554, 29, 'Tuyên bố này đã được denied.Reason:'),
(112432, 6555, 29, 'Tuyên bố này đã được chuyển tiếp đến cấp độ tiếp theo.'),
(112433, 6556, 29, 'Đây là loại mã không chấp nhận mối quan hệ.'),
(112434, 6557, 29, 'Bối cảnh này có chứa các loại, trong đó sẽ bị xóa. Bạn vẫn muốn tiếp tục không?'),
(112435, 6558, 29, 'Điều này xác định các cuộc hẹn hiển thị trên lịch.'),
(112436, 6559, 29, 'Điều này xác định lược đồ màu sắc được sử dụng cho cuộc hẹn'),
(112437, 6561, 29, 'Lần khám Này'),
(112438, 6562, 29, 'Đã lập hóa đơn cho lần khám này. Nếu bạn cần phải thay nó, bạn phải xóa lần tính tiền.'),
(112439, 6564, 29, 'Chưa có tính năng này'),
(112440, 6565, 29, 'Tính năng này là rất thử nghiệm và không kiểm tra đầy đủ. Sử dụng tại rủi ro của riêng bạn!'),
(112441, 6566, 29, 'Số hóa đơn này đã được thay đổi thành '),
(112442, 6572, 29, 'vị trí này'),
(112443, 6575, 29, 'Module này là ở chế độ thử nghiệm. Cơ sở dữ liệu sẽ không được thay đổi.'),
(112444, 6576, 29, 'Module này thúc đẩy mục hiệu quả dữ liệu EOB.'),
(112445, 6577, 29, 'Đầu Tháng đến Nay'),
(112446, 6581, 29, 'Trang này nội tuyến sẽ bao gồm các trang đăng nhập, do đó chúng tôi không phải bấm login lần sau mỗi khi.'),
(112447, 6582, 29, 'Bệnh nhân này không có hoạt động.'),
(112448, 6583, 29, 'ID bệnh nhân đã được sử dụng!'),
(112449, 6584, 29, 'Sản phẩm này chỉ cho phép một trong rất nhiều mỗi kho.'),
(112450, 6591, 29, 'Bước này sẽ tạo ra một tập tin mà bạn có để tiết kiệm để sử dụng trong tương lai. Các tập tin không thể được tạo ra một lần nữa. Bạn có muốn tiếp tục?'),
(112451, 6592, 29, 'Người dùng này không phải là một thành viên của nhóm nào'),
(112452, 6595, 29, 'Chuyến viếng thăm này bắt đầu sử dụng biện pháp tránh thai mới'),
(112453, 6596, 29, 'Chuyến thăm này sẽ cần một dịch vụ, giới thiệu hình thức hoặc thủ tục GCAC.'),
(112454, 6597, 29, 'Đây từng là biểu mẫu Thể trạng cũ chỉ theo hệ mét, giờ không còn phù hợp.'),
(112455, 6598, 29, 'Đầu Tuần đến Nay'),
(112456, 6600, 29, 'Điều này sẽ kích hoạt việc báo cáo CCR (Hồ sơ Sự liên tục Chăm sóc) và CCD (Tài liệu Sự liên tục Chăm sóc).'),
(112457, 6602, 29, 'Điều này sẽ cho phép lựa chọn của việc ngôn ngữ gỡ lỗi (''giả'').'),
(112458, 6606, 29, 'Điều này sẽ tạo ra một bản sao lưu ở định dạng tar và sau đó gửi nó đến trình duyệt web của bạn để bạn có thể lưu nó'),
(112459, 6607, 29, 'Điều này sẽ tắt các tính năng mã hóa và giải mã tài liệu, và giấu chúng trong giao diện người dùng.'),
(112460, 6613, 29, 'Điều này sẽ buộc các Thành phần Hóa đơn trong màn hình Tóm tắt Bệnh nhân luôn luôn được mở.'),
(112461, 6619, 29, 'Điều này sẽ sử dụng danh sách chủng ngừa tùy chỉnh hơn là danh sách tiêm chủng CVX tiêu chuẩn.'),
(112462, 6622, 29, 'Lồng ngực cột sống'),
(112463, 6623, 29, 'Nghìn / CU.MM'),
(112464, 6625, 29, 'Cổ họng'),
(112465, 6626, 29, 'Cổ họng ung thư'),
(112466, 6627, 29, 'Cổ họng ung thư phẫu thuật'),
(112467, 6628, 29, 'Huyết khối / Tai biến mạch máu não'),
(112468, 6629, 29, 'Thứ 5'),
(112469, 6630, 29, 'Thứ Năm'),
(112470, 6631, 29, 'Thứ Năm'),
(112471, 6632, 29, 'Tuyến giáp bình thường'),
(112472, 6633, 29, 'Tuyến giáp vấn đề'),
(112473, 6634, 29, 'TIA'),
(112474, 6636, 29, 'TID'),
(112475, 6638, 29, 'Thời gian'),
(112476, 6639, 29, 'Định dạng Hiển thị Thời gian'),
(112477, 6640, 29, 'Tăng thời gian cho Add (phút 1-60)'),
(112478, 6641, 29, 'Thời gian lựa chọn'),
(112479, 6647, 29, 'Đặt thời gian sự kiện'),
(112480, 6648, 29, 'Times mảng (N / A)'),
(112481, 6649, 29, 'Dấu thời gian và Tiêu đề'),
(112482, 6650, 29, 'TIN'),
(112483, 6651, 29, 'Ù tai'),
(112484, 6652, 29, 'Danh xưng'),
(112485, 6653, 29, 'Tiêu đề V'),
(112486, 6654, 29, 'TitleCols phải là một số giữa 1 và 999'),
(112487, 6655, 29, 'Danh xưng'),
(112488, 6656, 29, 'TM ''S:'),
(112489, 6657, 29, 'TMS / EAMs / EE, ext mũi'),
(112490, 6658, 29, 'Đến'),
(112491, 6659, 29, 'ĐẾN'),
(112492, 6660, 29, 'để'),
(112493, 6661, 29, 'đường dẫn tuyệt đối của tập tin'),
(112494, 6662, 29, 'Để thêm ghi chú, xin vui lòng bấm vào '),
(112495, 6663, 29, 'Để thêm ghi chú, xin vui lòng nhấn vào đây'),
(112496, 6664, 29, 'Vùng bị ảnh hưởng'),
(112497, 6665, 29, 'khu vực bị ảnh hưởng'),
(112498, 6666, 29, 'Để tự động mở hình thức quy định. Một số đội thể thao sử dụng football_injury_audit ở đây.'),
(112499, 6667, 29, 'Thanh toán Xem'),
(112500, 6668, 29, 'vào thể loại'),
(112501, 6669, 29, 'Xem lâm sàng'),
(112502, 6670, 29, 'Để tiền phụ phí'),
(112503, 6672, 29, 'Để ded''ble'),
(112504, 6673, 29, 'Để DEMs'),
(112505, 6674, 29, 'Vô hiệu hoá SSL giấy chứng nhận phía khách hàng, nhận xét trên dòng trong tập tin cấu hình Apache và thiết lập'),
(112506, 6675, 29, 'Vô hiệu hóa HTTPS, bình luận những dòng trên trong tập tin cấu hình Apache và khởi động lại máy chủ Apache.'),
(112507, 6676, 29, 'Để kích hoạt tính năng Khách hàng bên ssl giấy chứng nhận'),
(112508, 6677, 29, 'Kích hoạt tính năng Khách hàng bên xác thực giấy chứng nhận SSL, HTTPS được kích hoạt.'),
(112509, 6678, 29, 'Để kích hoạt HTTPS chỉ, thực hiện các thay đổi trên và khởi động lại máy chủ Apache. Nếu bạn muốn cấu hình giấy chứng nhận phía khách hàng, xin vui lòng cấu hình chúng trong phần tiếp theo.'),
(112510, 6679, 29, 'Để Enctr'),
(112511, 6680, 29, 'Để lọc theo giới tính'),
(112512, 6681, 29, 'Lịch Sử'),
(112513, 6682, 29, 'Để vấn đề'),
(112514, 6683, 29, 'Để liên kết lần khám / tư vấn này đến ​​một rắc rối hiện tại, hãy nhấp vào '),
(112515, 6684, 29, 'Để liên kết lần khám / tư vấn này đến ​​một rắc rối hiện tại, hãy nhấp vào rắc rối ở trên để đánh dấu nó rồi nhấn [Lưu]. Giữ [Ctrl] để chọn nhiều rắc rối.'),
(112516, 6685, 29, 'để đăng nhập lại'),
(112517, 6686, 29, 'Để ghi lại sự tiết lộ, xin vui lòng bấm vào'),
(112518, 6687, 29, 'để chạy'),
(112519, 6688, 29, 'Để thiết lập truy cập https với xác thực có chứng chỉ của khách hàng, hãy làm như sau'),
(112520, 6689, 29, 'Lên Da'),
(112521, 6690, 29, 'lên da'),
(112522, 6691, 29, 'lần đến này?'),
(112523, 6693, 29, 'Gửi:'),
(112524, 6694, 29, 'Gửi: '),
(112525, 6695, 29, 'TO_CITY'),
(112526, 6696, 29, 'TO_FAX'),
(112527, 6697, 29, 'TO_FNAME'),
(112528, 6698, 29, 'TO_LNAME'),
(112529, 6699, 29, 'TO_MNAME'),
(112530, 6700, 29, 'TO_ORGANIZATION'),
(112531, 6703, 29, 'TO_POSTAL'),
(112532, 6704, 29, 'TO_STATE'),
(112533, 6705, 29, 'TO_STREET'),
(112534, 6706, 29, 'TO_TITLE'),
(112535, 6707, 29, 'TO_VALEDICTORY'),
(112536, 6708, 29, 'Thuốc lá'),
(112537, 6709, 29, 'Can thiệp Ngưng hút Thuốc lá'),
(112538, 6710, 29, 'Can thiệp Ngưng hút Thuốc lá (CQM)'),
(112539, 6712, 29, 'Hút thuốc lá'),
(112540, 6713, 29, 'Đánh giá Việc hút Thuốc lá'),
(112541, 6714, 29, 'Đánh giá Việc hút Thuốc lá (CQM)'),
(112542, 6715, 29, 'Hôm nay'),
(112543, 6716, 29, 'TODAY'),
(112544, 6717, 29, 'hôm nay'),
(112545, 6718, 29, 'Cân đối trong Hôm nay'),
(112546, 6719, 29, 'Tiền công trong Hôm nay'),
(112547, 6720, 29, 'Ngày Hôm nay'),
(112548, 6721, 29, 'Sự kiện trong Hôm nay'),
(112549, 6724, 29, 'Token ID for the LibreEHR Support LLC Lab Exchange Service.'),
(112550, 6726, 29, 'Thuật cắt hạch (Tonsillectomy)'),
(112551, 6728, 29, 'Trên'),
(112552, 6730, 29, 'Chủ đề'),
(112553, 6731, 29, 'Tổng số'),
(112554, 6732, 29, 'tổng số'),
(112555, 6733, 29, 'Tổng số hành động có hiệu lực'),
(112556, 6734, 29, 'Tổng số lời nhắc có hiệu lực sau khi cập nhật'),
(112557, 6735, 29, 'Tổng số lời nhắc có hiệu lực trước khi cập nhật'),
(112558, 6737, 29, 'Tổng số tiền còn thiếu'),
(112559, 6738, 29, 'Tổng số Tiền đã Thanh toán'),
(112560, 6740, 29, 'Tổng số Tiền'),
(112561, 6741, 29, 'Tổng số Tiền'),
(112562, 6742, 29, 'Tổng số Khách hàng'),
(112563, 6743, 29, 'Tổng số Chi phí'),
(112564, 6744, 29, 'Tổng phân phối cho các số kiểm tra sau đây là không đầy đủ'),
(112565, 6746, 29, 'Tổng số nhắc nhở không được gửi qua email'),
(112566, 6747, 29, 'Tổng số nhắc nhở không được gửi qua điện thoại'),
(112567, 6748, 29, 'Tổng số cho'),
(112568, 6749, 29, 'Tổng số cho '),
(112569, 6750, 29, 'Tổng cộng cho thể loại'),
(112570, 6751, 29, 'Tổng bất hoạt nhắc nhở'),
(112571, 6752, 29, 'Tổng mới nhắc nhở'),
(112572, 6755, 29, 'Tổng số của Chích ngừa'),
(112573, 6756, 29, 'Tổng số các vấn đề'),
(112574, 6758, 29, 'Tổng số của bệnh nhân'),
(112575, 6760, 29, 'Tổng số bệnh nhân cân bằng'),
(112576, 6761, 29, 'Tổng số bệnh nhân'),
(112577, 6764, 29, 'Hồ sơ Tổng số được tìm thấy'),
(112578, 6765, 29, 'Tổng số SRH & Kế hoạch hoá gia đình'),
(112579, 6766, 29, 'Tổng số thành công nhắc nhở gửi qua email'),
(112580, 6767, 29, 'Tổng số thành công nhắc nhở gửi qua điện thoại'),
(112581, 6770, 29, 'Tổng không thay đổi nhắc nhở'),
(112582, 6771, 29, 'Tổng số tin nhắn chưa gửi nhắc nhở quá trình sau khi gửi'),
(112583, 6772, 29, 'Tổng số tin nhắn chưa gửi nhắc nhở sau khi cập nhật'),
(112584, 6773, 29, 'Tổng số tin nhắn chưa gửi nhắc nhở quá trình trước khi gửi'),
(112585, 6774, 29, 'Tổng số tin nhắn chưa gửi nhắc nhở trước khi cập nhật'),
(112586, 6775, 29, 'Tổng số cập nhật nhắc nhở'),
(112587, 6776, 29, 'Tổng số'),
(112588, 6777, 29, 'Tổng số của'),
(112589, 6778, 29, 'Tổng số của '),
(112590, 6785, 29, 'Đào tạo Loại'),
(112591, 6786, 29, 'Giao dịch'),
(112592, 6787, 29, 'Giao dịch'),
(112593, 6788, 29, 'giao dịch'),
(112594, 6789, 29, 'Giao dịch không thành công, không đủ số lượng trong rất nhiều điểm đến'),
(112595, 6790, 29, 'Giao dịch không thành công, số lượng ít hơn không'),
(112596, 6791, 29, 'Giao dịch loại'),
(112597, 6792, 29, 'giao dịch'),
(112598, 6793, 29, 'Giao dịch'),
(112599, 6794, 29, 'Giao dịch (viết tùy chọn)'),
(112600, 6795, 29, 'Các giao dịch / Giới thiệu tham gia'),
(112601, 6797, 29, 'Chuyển'),
(112602, 6799, 29, 'Chuyển giao không thành công, không đủ số lượng trong rất nhiều nguồn'),
(112603, 6804, 29, 'Chuyển'),
(112604, 6806, 29, 'Chuyển tiếp / Chuyển hay Chăm sóc?'),
(112605, 6807, 29, 'Dịch Nhóm Điều khiển Truy cập'),
(112606, 6808, 29, 'Dịch Thể loại Cuộc hẹn'),
(112607, 6809, 29, 'Dịch Thể loại Tài liệu'),
(112608, 6810, 29, 'Dịch các Bố trí'),
(112609, 6811, 29, 'Dịch các Danh sách'),
(112610, 6812, 29, 'Dịch Tựa đề Ghi chú cho Bệnh nhân'),
(112611, 6813, 29, 'dịch cái này'),
(112612, 6814, 29, 'Bản dịch'),
(112613, 6815, 29, 'Bản dịch'),
(112614, 6819, 29, 'Chấn thương'),
(112615, 6820, 29, 'Điều trị'),
(112616, 6822, 29, 'Điều trị Mục tiêu'),
(112617, 6823, 29, 'Điều trị Kế hoạch'),
(112618, 6826, 29, 'Điều trị:'),
(112619, 6827, 29, 'Điều trị: '),
(112620, 6828, 29, 'Mở'),
(112621, 6829, 29, 'trftime (month_format, mktime (0, 0, 0, $ i, 1, 2000))); $ month_value'),
(112622, 6830, 29, 'Điểm kích hoạt / hội chứng ngăn / DOMS / chuột rút'),
(112623, 6831, 29, 'Trimalleolar'),
(112624, 6832, 29, 'Trunk và bụng'),
(112625, 6837, 29, 'muỗng cà phê'),
(112626, 6839, 29, 'TTS');
INSERT INTO `lang_definitions` VALUES
(112627, 6840, 29, 'Bệnh lao'),
(112628, 6841, 29, 'Thứ 3'),
(112629, 6842, 29, 'Thứ 3 & Thứ 5'),
(112630, 6843, 29, 'Thứ Ba'),
(112631, 6844, 29, 'Ung bướu'),
(112632, 6845, 29, 'Tiếng Thổ Nhĩ Kỳ'),
(112633, 6848, 29, 'hai lần mỗi ngày'),
(112634, 6850, 29, 'Màng nhi'),
(112635, 6851, 29, 'Loại'),
(112636, 6852, 29, 'Id Loại Name.3 tối thiểu ký tự (bao gồm cả khoảng trắng).'),
(112637, 6853, 29, 'Loại cột hiển thị kết quả tìm kiếm bệnh nhân'),
(112638, 6854, 29, 'Loại của Công bố'),
(112639, 6855, 29, 'Loại sự kiện'),
(112640, 6856, 29, 'Loại bố trí màn hình'),
(112641, 6857, 29, 'Nhập hoặc quét nhận dạng bệnh nhân ở đây'),
(112642, 6859, 29, 'Các loại đơn Đặt hàng và Kết quả'),
(112643, 6864, 29, 'UCSMC mã được cung cấp bởi Đại học Calgary Trung tâm Y học Thể Thao'),
(112644, 6866, 29, 'Loét'),
(112645, 6867, 29, 'Viêm loét đại tràng'),
(112646, 6868, 29, 'Loét:'),
(112647, 6871, 29, 'Không thể để tạo ra'),
(112648, 6876, 29, 'Chưa được áp dụng'),
(112649, 6877, 29, 'Chưa chọn'),
(112650, 6879, 29, 'Truy cập trái phép để ePrescription'),
(112651, 6880, 29, 'Truy cập trái phép.'),
(112652, 6882, 29, 'Unbilled Chỉ'),
(112653, 6884, 29, 'dưới lưỡi'),
(112654, 6885, 29, 'Thiếu cân'),
(112655, 6886, 29, 'Không được chẩn đoán'),
(112656, 6887, 29, 'Chưa phân phối'),
(112657, 6888, 29, 'Chưa phân phối'),
(112658, 6889, 29, 'Chưa phân phối được'),
(112659, 6890, 29, 'Xóa lần Tính tiền này'),
(112660, 6892, 29, 'Độc đáo Khách hàng'),
(112661, 6893, 29, 'Con người có thể đọc được định danh duy nhất cho loại này'),
(112662, 6894, 29, 'Bổ sung - Vui học New Khách hàng'),
(112663, 6895, 29, 'Số định danh duy nhất cho loại này'),
(112664, 6896, 29, 'Độc đáo lên Bệnh nhân'),
(112665, 6897, 29, 'Bệnh nhân lên độc đáo Báo cáo'),
(112666, 6898, 29, 'Độc đáo SP'),
(112667, 6899, 29, 'Đơn vị'),
(112668, 6900, 29, 'Các đơn vị'),
(112669, 6901, 29, 'cái'),
(112670, 6903, 29, 'Đơn vị cho Biểu mẫu Đến khám'),
(112671, 6904, 29, 'Các đơn vị phải là một số'),
(112672, 6905, 29, 'Các đơn vị không được định nghĩa'),
(112673, 6906, 29, 'Các đơn vị / L'),
(112674, 6907, 29, 'Không biết'),
(112675, 6910, 29, 'Không biết đã hút thuốc bao giờ chưa'),
(112676, 6911, 29, 'Không biết hoặc N/A'),
(112677, 6914, 29, 'Công ty chưa được đặt tên bảo hiểm'),
(112678, 6915, 29, 'Chưa đăng ký'),
(112679, 6918, 29, 'Bỏ chọn tất cả'),
(112680, 6919, 29, 'Không được lựa chọn'),
(112681, 6920, 29, 'Không quy định'),
(112682, 6921, 29, 'không có cấu trúc'),
(112683, 6924, 29, 'cho đến'),
(112684, 6925, 29, 'Không kịp thời nộp hồ sơ'),
(112685, 6926, 29, 'Chưa sử dụng'),
(112686, 6927, 29, 'UOR'),
(112687, 6928, 29, 'Lên đến'),
(112688, 6929, 29, 'Cuộc hẹn Sắp tới'),
(112689, 6930, 29, 'Sự kiện Sắp tới'),
(112690, 6931, 29, 'Cập nhật'),
(112691, 6932, 29, 'cập nhật'),
(112692, 6933, 29, 'Cập nhật Hoạt động'),
(112693, 6934, 29, 'Cập nhật tập tin'),
(112694, 6935, 29, 'Cập nhật Thông tin'),
(112695, 6936, 29, 'Cập nhật Danh sách'),
(112696, 6937, 29, 'Cập nhật Số của Nhà cung cấp'),
(112697, 6938, 29, 'Cập nhật Mục được Chọn'),
(112698, 6939, 29, 'Cập nhật các biến sau đây trong tập tin'),
(112699, 6940, 29, 'Cập nhật Thông tin Người dùng'),
(112700, 6942, 29, 'Không được phép cập nhật thông tin cá nhân.'),
(112701, 6946, 29, 'Nâng cấp'),
(112702, 6947, 29, 'Nâng cấp Cơ sở dữ liệu'),
(112703, 6948, 29, 'Việc nâng cấp cơ sở dữ liệu LibreEHR bao gồm các Thủ tục, Chức năng và các bảng cần thiết cho quá trình nhận dạng'),
(112704, 6949, 29, 'Việc nâng cấp sẽ tiếp tục'),
(112705, 6950, 29, 'UPIN'),
(112706, 6951, 29, 'Tải lên'),
(112707, 6954, 29, 'Tải dữ liệu cấu hình lên'),
(112708, 6955, 29, 'Tải Tài liệu lên'),
(112709, 6956, 29, 'Tải lên thất bại!'),
(112710, 6957, 29, 'Tải hình lên'),
(112711, 6958, 29, 'Tải tập tin kết nhập lên:'),
(112712, 6961, 29, 'Báo cáo việc Tải lên'),
(112713, 6963, 29, 'Tải tập tin này lên:'),
(112714, 6964, 29, 'Khi nhấp vào một số hóa đơn "cửa sổ đăng hướng dẫn sử dụng" xuất hiện. Ở đây bạn có thể thay đổi vào ngày đáo hạn và ghi chú cho hoá đơn, lựa chọn bên người mà bạn gửi bài, và chọn bảo hiểm cho tất cả paymants dự kiến ​​sẽ nhận được. Quan trọng nhất, cho mỗi mã thanh toán số tiền đã được tính phí, bạn có thể nhập thông tin thanh toán và điều chỉnh.'),
(112715, 6965, 29, 'Khi tìm kiếm bạn đang trình bày với một danh sách các hoá đơn. Bạn có thể click vào một trong các số hoá đơn để mở một cửa sổ thứ hai, đó là nhập dữ liệu trang cho hướng dẫn đăng. Bạn cũng có thể nhấp chuột vào một tên bệnh nhân nếu bạn muốn nhập một lưu ý rằng các nhân viên văn phòng phía trước sẽ nhìn thấy khi bệnh nhân kiểm tra, và bạn có thể chọn các hoá đơn xuất hiện trên báo cáo bệnh nhân và in các báo cáo.'),
(112716, 6966, 29, 'Trên cánh tay'),
(112717, 6968, 29, 'Tình huống khẩn cấp'),
(112718, 6970, 29, 'Nước tiểu'),
(112719, 6971, 29, 'Nước tiểu Dribbling'),
(112720, 6972, 29, 'Nước tiểu Tần số'),
(112721, 6973, 29, 'Nước tiểu do dự'),
(112722, 6974, 29, 'Nước tiểu Microalbumin'),
(112723, 6975, 29, 'Nước tiểu suối'),
(112724, 6976, 29, 'Nước tiểu Tình huống khẩn cấp'),
(112725, 6977, 29, 'URL'),
(112726, 6979, 29, 'URL để tìm hỗ trợ về LibreEHR.'),
(112727, 6981, 29, 'URL cho Gateway điện thoại. Tự động dịch vụ VoIP được cung cấp bởi Maviq. Vui lòng truy cập http://signup.maviq.com để biết thêm thông tin.'),
(112728, 6986, 29, 'Chỉ số sử dụng (ISA15)'),
(112729, 6988, 29, 'Sử dụng 24 giờ định dạng thời gian?'),
(112730, 6990, 29, 'Sử dụng chứng nhận EHR công nghệ để xác định các nguồn tài nguyên giáo dục bệnh nhân cụ thể và cung cấp các nguồn lực cho bệnh nhân nếu thích hợp.'),
(112731, 6991, 29, 'Dùng Bảng Biểu phí'),
(112732, 6992, 29, 'Sử dụng CPOE cho các đơn đặt hàng thuốc trực tiếp vào bất kỳ chuyên viên y tế được cấp phép có thể nhập lệnh vào hồ sơ y tế cho mỗi nhà nước, hướng dẫn địa phương và chuyên nghiệp.'),
(112733, 6997, 29, 'Sử dụng Danh sách Chủng ngừa Tuỳ chỉnh'),
(112734, 6999, 29, 'Sử dụng Phạm vi Ngày'),
(112735, 7000, 29, 'Sử dụng mặc định'),
(112736, 7001, 29, 'Sử dụng Tùy chọn Delete để loại bỏ.'),
(112737, 7002, 29, 'Sử dụng phong cách ngày quốc tế?'),
(112738, 7003, 29, 'Sử dụng tên tập tin nguồn'),
(112739, 7004, 29, 'Sử dụng các trường dưới đây để mua hàng hoặc chuyển giao.'),
(112740, 7005, 29, 'Sử dụng tính năng này chỉ với các trang web mới được cài đặt, '),
(112741, 7006, 29, 'Sử dụng các chủ đề?'),
(112742, 7007, 29, 'Người dùng'),
(112743, 7009, 29, 'Người dùng / Nhóm'),
(112744, 7010, 29, 'Quản trị Người dùng'),
(112745, 7011, 29, 'Quản trị Người dùng và Cơ sở'),
(112746, 7012, 29, 'Quản trị Người dùng và Nhóm'),
(112747, 7014, 29, 'Giấy chứng nhận xác thực người dùng được vô hiệu hóa'),
(112748, 7015, 29, 'Tự Định nghĩa'),
(112749, 7016, 29, 'Vùng Tự Định nghĩa 11'),
(112750, 7017, 29, 'Vùng Tự Định nghĩa 12'),
(112751, 7018, 29, 'Thông tin Tự Định nghĩa'),
(112752, 7019, 29, 'Danh mục Tự Định nghĩa 1'),
(112753, 7020, 29, 'Danh mục Tự Định nghĩa 2'),
(112754, 7021, 29, 'Danh mục Tự Định nghĩa 3'),
(112755, 7022, 29, 'Danh mục Tự Định nghĩa 4'),
(112756, 7023, 29, 'Danh mục Tự Định nghĩa 5'),
(112757, 7024, 29, 'Danh mục Tự Định nghĩa 6'),
(112758, 7025, 29, 'Danh mục Tự Định nghĩa 7'),
(112759, 7026, 29, 'Văn bản Tự Định nghĩa 1'),
(112760, 7027, 29, 'Văn bản Tự Định nghĩa 2'),
(112761, 7028, 29, 'Văn bản Tự Định nghĩa 3'),
(112762, 7029, 29, 'Văn bản Tự Định nghĩa 4'),
(112763, 7030, 29, 'Văn bản Tự Định nghĩa 5'),
(112764, 7031, 29, 'Văn bản Tự Định nghĩa 6'),
(112765, 7032, 29, 'Văn bản Tự Định nghĩa 7'),
(112766, 7033, 29, 'Văn bản Tự Định nghĩa 8'),
(112767, 7034, 29, 'Người sử dụng Tên'),
(112768, 7039, 29, 'Hướng dẫn sử dụng'),
(112769, 7040, 29, 'Người sử dụng những thành viên'),
(112770, 7041, 29, 'User Name'),
(112771, 7042, 29, 'Tên người dùng hoặc tên máy chủ không thể để trống'),
(112772, 7043, 29, 'Tên người dùng hoặc chủ nhà'),
(112773, 7046, 29, 'Người sử dụng Cài đặt'),
(112774, 7047, 29, 'Thiết lập Của Người dùng'),
(112775, 7049, 29, 'Tên đăng nhập'),
(112776, 7051, 29, 'Tên người dùng cho cổng điện thoại. Tự động dịch vụ VoIP được cung cấp bởi Maviq. Vui lòng truy cập http://signup.maviq.com để biết thêm thông tin.'),
(112777, 7052, 29, 'Tên người dùng cho SMS Gateway'),
(112778, 7053, 29, 'Tên người dùng cho SMS Gateway.'),
(112779, 7055, 29, 'Tên đăng nhập:'),
(112780, 7056, 29, 'Người sử dụng'),
(112781, 7057, 29, 'Người dùng / Nhóm / Logs Quản trị'),
(112782, 7058, 29, 'sử dụng php <a href="http://php.net/strftime"> strftime </ a> định dạng'),
(112783, 7059, 29, 'Nhiễm trùng tiểu'),
(112784, 7062, 29, 'VACATION'),
(112785, 7063, 29, 'Kỳ nghỉ'),
(112786, 7064, 29, 'Vắc-xin'),
(112787, 7065, 29, 'Âm đạo nhẫn'),
(112788, 7066, 29, 'Bài diển văn'),
(112789, 7067, 29, 'xác nhận tính hợp lệ'),
(112790, 7068, 29, 'Giá trị'),
(112791, 7069, 29, 'Giá trị 1'),
(112792, 7070, 29, 'Giá trị 2'),
(112793, 7072, 29, 'Giá trị nên là Numeric'),
(112794, 7073, 29, 'Var1'),
(112795, 7074, 29, 'Var2'),
(112796, 7075, 29, 'biến một để chạy kịch bản nâng cấp de-nhận dạng'),
(112797, 7076, 29, 'Varicella 1'),
(112798, 7077, 29, 'Varicella 2'),
(112799, 7078, 29, 'Dây tinh mạch trường'),
(112800, 7079, 29, 'Mạch điều kiện'),
(112801, 7080, 29, 'Mạch máu bị thương'),
(112802, 7081, 29, 'Mạch máu Phẫu thuật'),
(112803, 7083, 29, 'Nhà cung cấp'),
(112804, 7084, 29, 'Phiên bản'),
(112805, 7085, 29, 'Vertigo'),
(112806, 7087, 29, 'Cựu chiến binh Kế hoạch'),
(112807, 7088, 29, 'VFC'),
(112808, 7089, 29, 'Tiếng Việt'),
(112809, 7090, 29, 'xem'),
(112810, 7091, 29, 'Xem'),
(112811, 7092, 29, 'Xem Dị ứng'),
(112812, 7097, 29, 'Xem Báo cáo bệnh nhân toàn diện'),
(112813, 7100, 29, 'Xem tài liệu'),
(112814, 7101, 29, 'Xem gặp phải'),
(112815, 7103, 29, 'Xem các sự kiện trong một cửa sổ popup?'),
(112816, 7108, 29, 'Xem Trang 1'),
(112817, 7109, 29, 'Xem Page 2'),
(112818, 7111, 29, 'Xem Bệnh nhân'),
(112819, 7116, 29, 'Xem cuộc gặp gỡ liên quan'),
(112820, 7121, 29, 'Xem / Chỉnh sửa Dị ứng'),
(112821, 7122, 29, 'Xem / chỉnh sửa vấn đề'),
(112822, 7123, 29, 'Xem / In'),
(112823, 7124, 29, 'Xem:'),
(112824, 7125, 29, 'VISA'),
(112825, 7126, 29, 'VISA / MC / AMEX / Dis'),
(112826, 7127, 29, '/ Chấn thương nội tạng thiệt hại / phẫu thuật'),
(112827, 7133, 29, 'Thể loại Đến khám:'),
(112828, 7134, 29, 'Ngày Đến khám'),
(112829, 7135, 29, 'Ngày đến khám'),
(112830, 7137, 29, 'Biểu mẫu Đến khám'),
(112831, 7138, 29, 'Lịch sử Đến khám'),
(112832, 7140, 29, 'Đến khám'),
(112833, 7141, 29, 'Đến khám Từ'),
(112834, 7142, 29, 'Thể trạng'),
(112835, 7143, 29, 'Thể trạng'),
(112836, 7144, 29, 'Thể trạng (Hệ mét)'),
(112837, 7146, 29, 'Lời nhắn'),
(112838, 7147, 29, 'Đã gửi Lời nhắn'),
(112839, 7149, 29, 'Ói mửa'),
(112840, 7151, 29, 'W'),
(112841, 7152, 29, 'CV Eo'),
(112842, 7153, 29, 'Chu vi Eo'),
(112843, 7154, 29, 'Chờ đợi'),
(112844, 7155, 29, 'Đi ngang'),
(112845, 7157, 29, 'Walt Pennington'),
(112846, 7158, 29, 'Kho hàng'),
(112847, 7161, 29, 'Kho'),
(112848, 7162, 29, 'Ấm áp'),
(112849, 7163, 29, 'Cảnh báo'),
(112850, 7164, 29, 'CẢNH BÁO'),
(112851, 7166, 29, 'Cảnh báo, Số Kiểm tra đã tồn tại trong cơ sở dữ liệu'),
(112852, 7168, 29, 'Cảnh báo: đã tạo ra lần khám cho bệnh nhân này ngày hôm nay!'),
(112853, 7170, 29, 'Cảnh báo: Mã bệnh nhân không phải là duy nhất!'),
(112854, 7171, 29, 'Chú ý: Điều này sẽ ghi đè lên thông tin cấu hình với dữ liệu từ các tập tin được tải lên!'),
(112855, 7173, 29, 'Cảnh báo'),
(112856, 7175, 29, 'đã tải lên'),
(112857, 7177, 29, 'Chúng tôi đánh giá cao thanh toán kịp thời số dư đến hạn'),
(112858, 7178, 29, 'chúng ta đã thấy bệnh nhân trên của bạn để đánh giá và điều trị tại phòng khám ngoại trú tâm thần học của chúng tôi. Cảm ơn bạn đã giới thiệu này.'),
(112859, 7179, 29, 'Điểm yếu'),
(112860, 7181, 29, 'Tìm kiếm Web'),
(112861, 7182, 29, 'Website'),
(112862, 7183, 29, 'Liên kết website Cổng thông tin bệnh nhân tại chỗ.'),
(112863, 7184, 29, 'Thứ 4'),
(112864, 7185, 29, 'Thứ Tư'),
(112865, 7186, 29, 'Tuần'),
(112866, 7187, 29, 'tuần'),
(112867, 7188, 29, 'Xem theo Tuần'),
(112868, 7189, 29, 'Tuần'),
(112869, 7190, 29, 'Hàng tuần Exposures'),
(112870, 7192, 29, 'Tuần'),
(112871, 7193, 29, 'Trọng lượng'),
(112872, 7194, 29, 'Đánh giá Trọng lượng và Tư vấn cho Trẻ em và Thanh thiếu niên'),
(112873, 7195, 29, 'Đánh giá Trọng lượng và Tư vấn cho Trẻ em và Thanh thiếu niên (CQM)'),
(112874, 7196, 29, 'Thay đổi Trọng lượng'),
(112875, 7197, 29, 'Giảm Cân'),
(112876, 7198, 29, 'Phòng khám giảm cân'),
(112877, 7199, 29, 'Chào mừng'),
(112878, 7202, 29, 'Được tính là gì?'),
(112879, 7203, 29, 'Khó thở:'),
(112880, 7204, 29, 'Thở khò khè'),
(112881, 7205, 29, 'Thở khò khè:'),
(112882, 7208, 29, 'Trường hợp có thể có liên quan được quét hoặc tài liệu giấy được tìm thấy?'),
(112883, 7211, 29, 'Cột sống'),
(112884, 7212, 29, 'Da trắng'),
(112885, 7213, 29, 'Ai'),
(112886, 7214, 29, 'Ai trả lời?'),
(112887, 7215, 29, 'Góa chồng/vợ'),
(112888, 7217, 29, 'Độ rộng khung chuyển hướng bên trái, tính theo điểm ảnh'),
(112889, 7221, 29, 'Với lựa chọn:'),
(112890, 7222, 29, 'với tên cũ'),
(112891, 7224, 29, 'Với người mà chúng tôi có thể để lại tin nhắn?'),
(112892, 7225, 29, 'Khấu trừ'),
(112893, 7226, 29, 'trong vòng vài giờ'),
(112894, 7227, 29, 'trong vòng vài giờ:'),
(112895, 7228, 29, 'trong vòng vài phút'),
(112896, 7229, 29, 'trong vòng vài phút:'),
(112897, 7232, 29, 'không Update'),
(112898, 7233, 29, 'Chứng kiến'),
(112899, 7234, 29, 'tuần'),
(112900, 7235, 29, 'WNL'),
(112901, 7237, 29, 'Phụ nữ'),
(112902, 7238, 29, 'Chỉ phụ nữ'),
(112903, 7240, 29, 'Làm việc'),
(112904, 7241, 29, 'Ghi chú công việc'),
(112905, 7242, 29, 'Điện thoại công việc'),
(112906, 7243, 29, 'Số điện thoại Công việc'),
(112907, 7244, 29, 'Liên quan công việc?'),
(112908, 7245, 29, 'Công việc / Giáo dục / Sở thích'),
(112909, 7246, 29, 'Công việc / Trường học Ghi chú'),
(112910, 7247, 29, 'ngày làm việc'),
(112911, 7249, 29, 'Bồi Thường Lao Động Chương Trình Sức Khỏe'),
(112912, 7252, 29, 'Tệ hơn nữa'),
(112913, 7253, 29, 'Bạn có muốn số tiền cân đối để áp dụng cho tài khoản toàn cầu?'),
(112914, 7254, 29, 'Bạn có muốn chúng được đánh dấu như đã xóa.'),
(112915, 7255, 29, 'Bạn có muốn Phân bổ?'),
(112916, 7256, 29, 'Bạn có muốn huỷ bỏ phân phối cho các bệnh nhân này?'),
(112917, 7257, 29, 'Bạn có muốn xóa phân phối thanh toán?'),
(112918, 7258, 29, 'Bạn có muốn xóa thanh toán?'),
(112919, 7259, 29, 'Bạn có muốn Sửa đổi và Kết thúc thanh toán?'),
(112920, 7260, 29, 'Bạn có muốn Sửa đổi khoản thanh toán?'),
(112921, 7261, 29, 'Bạn có muốn đăng bài và Kết thúc thanh toán?'),
(112922, 7262, 29, 'Bạn có muốn Đăng thanh toán?'),
(112923, 7263, 29, 'Bạn có muốn lưu lại không?'),
(112924, 7264, 29, 'Cổ tay'),
(112925, 7265, 29, 'Cổ tay và tay'),
(112926, 7266, 29, 'Cổ tay vấn đề'),
(112927, 7267, 29, 'viết'),
(112928, 7268, 29, 'giảm bớt'),
(112929, 7270, 29, 'wsome'),
(112930, 7271, 29, 'WT'),
(112931, 7273, 29, 'x hủy bỏ'),
(112932, 7274, 29, 'x hủy bỏ'),
(112933, 7275, 29, 'X-quang'),
(112934, 7276, 29, 'Giải thích X-Quang:'),
(112935, 7277, 29, 'Giải thích X-Quang:'),
(112936, 7278, 29, 'Chỉ cho X12: Yêu cầu bồi thường Thay thế '),
(112937, 7279, 29, 'Đối tác X12'),
(112938, 7280, 29, 'Đối tác X12'),
(112939, 7284, 29, 'Y'),
(112940, 7285, 29, 'Năm'),
(112941, 7286, 29, 'năm'),
(112942, 7287, 29, 'Theo năm'),
(112943, 7288, 29, 'Năm'),
(112944, 7289, 29, 'Năm'),
(112945, 7292, 29, 'CÓ'),
(112946, 7293, 29, 'Có'),
(112947, 7294, 29, 'có'),
(112948, 7295, 29, 'CÓ!'),
(112949, 7296, 29, 'Có, Xóa và Ghi nhận'),
(112950, 7298, 29, 'Có / Không'),
(112951, 7299, 29, 'Có:'),
(112952, 7300, 29, 'Tiếng Yiddish'),
(112953, 7303, 29, 'Bạn là vĩnh viễn thay thế mẫu hiện tại. Bạn có chắc bạn muốn tiếp tục?'),
(112954, 7304, 29, 'Bạn đang trong giai đoạn nhập Grace. Thay đổi mật khẩu của bạn trước khi'),
(112955, 7305, 29, 'Bạn không được phép xoá sự kiện này'),
(112956, 7306, 29, 'Bạn không được phép chỉnh sửa sự kiện này'),
(112957, 7307, 29, 'Bạn không được phép cho việc này.'),
(112958, 7308, 29, 'Bạn không được phép truy cập vào đội hình.'),
(112959, 7309, 29, 'Bạn không được phép thêm / chỉnh sửa các vấn đề'),
(112960, 7310, 29, 'Bạn không được phép lên lịch các cuộc hẹn.'),
(112961, 7311, 29, 'Bạn không được phép để xem cuộc gặp gỡ này.'),
(112962, 7313, 29, 'Bạn không thể truy cập chức năng này trực tiếp.'),
(112963, 7314, 29, 'Bạn không thể truy cập vào trang trực tiếp.'),
(112964, 7315, 29, 'Bạn không thể thêm một giá trị trống cho một danh mục cụ thể!'),
(112965, 7316, 29, 'Bạn không thể thêm một giá trị trống cho tiểu thể loại!'),
(112966, 7317, 29, 'Bạn không thể thêm một giá trị trống cho một mục!'),
(112967, 7318, 29, 'Bạn không thể nhập một ngày trong tương lai với một giá trị hoàn thành của YES.'),
(112968, 7319, 29, 'Bạn đã không chọn bất kỳ hành động.'),
(112969, 7320, 29, 'Bạn không có quyền truy cập để xem / chỉnh sửa ghi chú'),
(112970, 7321, 29, 'Bạn đã cố gắng để làm thay đổi nội dung mà bị khoá. Hủy bỏ các khóa, nếu bạn muốn làm điều này. Để mở khóa, loại bỏ các dòng / * lock :: * / '''),
(112971, 7322, 29, 'Bạn đã đăng xuất thành công.'),
(112972, 7323, 29, 'Bạn chỉ có thể tải lên các file .txt'),
(112973, 7325, 29, 'Bạn có thể đặt văn bản ở đây là đơn khiếu nại mặc định trong các hình thức gặp bệnh nhân mới.'),
(112974, 7326, 29, 'Bạn phải nhập một chuỗi mật khẩu để mã hóa tài liệu'),
(112975, 7329, 29, 'Trước tiên, bạn phải lựa chọn hoặc thêm một bệnh nhân'),
(112976, 7330, 29, 'Trước tiên, bạn phải lựa chọn hoặc tạo ra một cuộc gặp gỡ.'),
(112977, 7331, 29, 'Bạn phải chọn một thể loại ghé thăm'),
(112978, 7332, 29, 'Bạn phải chọn một thể loại chuyến thăm.'),
(112979, 7333, 29, 'Bạn phải chọn một số lĩnh vực để tiếp tục.'),
(112980, 7334, 29, 'Bạn cần được chạy thử nghiệm này nếu yêu cầu bồi thường này xuất hiện để tạo ra thành công, nhưng các tập tin đòi bồi thường thực tế không chứa bất kỳ dữ liệu hoặc chỉ phần chưa hoàn thành số lượng dữ liệu được cho là để chứa. Rõ ràng với tuyên bố HCFA, vì họ là con người có thể đọc được, với X12 tuyên bố nó là một quá trình khó khăn hơn để xác định nếu yêu cầu bồi thường là đúng hoàn toàn.'),
(112981, 7335, 29, 'Bạn nên chọn ít nhất một bối cảnh'),
(112982, 7336, 29, 'Bạn nên chọn ít nhất một nhà cung cấp'),
(112983, 7339, 29, 'Ngày cuối cùng của bạn là không hợp lệ'),
(112984, 7340, 29, 'Sự kiện của bạn đã bị xóa.'),
(112985, 7341, 29, 'Sự kiện của bạn đã được sửa đổi.'),
(112986, 7342, 29, 'Sự kiện của bạn đã được gửi.'),
(112987, 7343, 29, 'Tập tin của bạn quá lớn'),
(112988, 7345, 29, 'Tên danh sách của bạn đã được thay đổi để đáp ứng các yêu cầu đặt tên.'),
(112989, 7347, 29, 'Tên của bạn cho thể loại này, thủ tục hoặc kết quả'),
(112990, 7349, 29, 'Mật khẩu của bạn hết hạn. Xin vui lòng thay đổi mật khẩu của bạn.'),
(112991, 7350, 29, 'Mật khẩu của bạn Ngày hết hạn trên'),
(112992, 7351, 29, 'Mật khẩu của bạn hết hạn ngày hôm nay. Xin vui lòng thay đổi mật khẩu của bạn.'),
(112993, 7353, 29, 'Cấu hình PostCalendar của bạn đã được thiết lập lại để sử dụng mặc định.'),
(112994, 7354, 29, 'Cấu hình PostCalendar của bạn đã được cập nhật.'),
(112995, 7355, 29, 'Tần số của bạn lặp đi lặp lại phải là số nguyên.'),
(112996, 7356, 29, 'Tần số lặp đi lặp lại của bạn phải có ít nhất 1.'),
(112997, 7357, 29, 'Ngày bắt đầu của bạn lớn hơn so với ngày cuối cùng của bạn'),
(112998, 7358, 29, 'Ngày bắt đầu của bạn là không hợp lệ'),
(112999, 7359, 29, 'Trình của bạn không thành công.'),
(113000, 7360, 29, 'năm-tháng-ngày'),
(113001, 7361, 29, 'NĂM-THÁNG-NGÀY'),
(113002, 7362, 29, 'năm-tháng-ngày ngày được gán cho tài liệu này'),
(113003, 7363, 29, 'năm-tháng-ngày ngày hủy'),
(113004, 7364, 29, 'năm-tháng-ngày ngày sinh'),
(113005, 7365, 29, 'năm-tháng-ngày Ngày Sinh'),
(113006, 7366, 29, 'năm-tháng-ngày ngày hết hạn'),
(113007, 7367, 29, 'năm-tháng-ngày ngày khởi phát hoặc nhập viện'),
(113008, 7368, 29, 'năm-tháng-ngày ngày khởi phát, phẫu thuật, hay bắt đầu điều trị'),
(113009, 7369, 29, 'năm-tháng-ngày ngày mua hoặc chuyển nhượng'),
(113010, 7370, 29, 'năm-tháng-ngày ngày hết bệnh hoặc sự điều trị'),
(113011, 7371, 29, 'năm-tháng-ngày Ngày trở lại để chơi'),
(113012, 7372, 29, 'năm-tháng-ngày Ngày làm dịch vụ'),
(113013, 7373, 29, 'năm-tháng-ngày ngày của lá thư này'),
(113014, 7374, 29, 'năm-tháng-ngày ngày trở lại để chơi'),
(113015, 7375, 29, 'năm-tháng-ngày ngày của tài liệu'),
(113016, 7376, 29, 'năm-tháng-ngày ngày của sự kiện hay bắt đầu từ ngày'),
(113017, 7381, 29, 'năm-tháng-ngày  giờ:phút:giây'),
(113018, 7383, 29, 'năm-tháng-ngày ngày cuối của sự kiện này'),
(113019, 7387, 29, 'Không'),
(113020, 7389, 29, 'Zip'),
(113021, 7390, 29, 'Mã Zip'),
(113022, 7391, 29, 'Zip/Quốc gia:'),
(113023, 7392, 29, 'Tiếng Zulu'),
(113024, 7393, 29, ' nhưng đã '),
(113025, 7394, 29, ' không thể truy cập.'),
(113026, 7395, 29, 'Bạn có thực sự muốn xóa'),
(113027, 7396, 29, 'Thuốc'),
(113028, 7397, 29, 'email không được gửi'),
(113029, 7398, 29, 'từ'),
(113030, 7399, 29, 'đã được tạo ra. '),
(113031, 7400, 29, 'đã được mở lại.'),
(113032, 7401, 29, 'Lịch sử'),
(113033, 7402, 29, 'không phải là một số'),
(113034, 7403, 29, 'đã sẵn sàng để thanh toán lại.'),
(113035, 7404, 29, 'LLL:'),
(113036, 7405, 29, 'Rất nhiều'),
(113037, 7406, 29, 'Medicaid gốc tham khảo số '),
(113038, 7407, 29, 'min'),
(113039, 7408, 29, 'không tìm thấy!'),
(113040, 7409, 29, 'Pecularities trong nhiều trình duyệt có thể có nghĩa rằng đầu ra dưới đây vào màn hình của bạn giật đột ngột và lâu dài có được tạm dừng vài giây mà nó xuất hiện như là mặc dù mọi thứ có thể đã bị rơi. Đó không phải là trường hợp, bạn cuối cùng sẽ thấy sản lượng đến từng dòng. Có thể có số thứ tự xuất hiện bên dưới, điều này là để chỉ ra rằng mặc dù không có gì khác có thể được hiển thị có hoạt động xảy ra. Những con số này sẽ được xen kẽ với các nội dung thanh toán và đó là bình thường.'),
(113041, 7410, 29, 'theo toa đã đạt đến giới hạn của nó về'),
(113042, 7411, 29, 'cho đến khi'),
(113043, 7412, 29, 'update không thành công, không phải trong cơ sở dữ liệu?'),
(113044, 7413, 29, 'được đánh dấu như lập hoá đơn chỉ.'),
(113045, 7414, 29, 'đã được xếp hàng đợi thành công.'),
(113046, 7415, 29, '! Còn lại w / o chuyến thăm'),
(113047, 7416, 29, 'Mã số'),
(113048, 7417, 29, '" đã được kiểm tra trong cài đặt PostCalendar!'),
(113049, 7418, 29, '# Ins / vây vấn đề'),
(113050, 7419, 29, '# của viên nén:'),
(113051, 7420, 29, '$'),
(113052, 7421, 29, '$ Mã thực hiện'),
(113053, 7422, 29, '$label (năm-tháng-ngày): '),
(113054, 7423, 29, '%'),
(113055, 7424, 29, '% Hủy bỏ <24h'),
(113056, 7425, 29, '% Hủy bỏ <24h '),
(113057, 7426, 29, 'phải tồn tại nhưng lại không có.'),
(113058, 7427, 29, '(% để tìm chuỗi bất kỳ, _ để tiềm ký tự bất kỳ)'),
(113059, 7428, 29, '([ctrl] + nhấp để chọn nhiều người nhận)'),
(113060, 7429, 29, '(Quay lại)'),
(113061, 7430, 29, '(Nhấp vào đây để chỉnh sửa)'),
(113062, 7431, 29, '(Việc gửi Email được thực hiện ngay, trong khi VOIP tự động sẽ được gửi đến các nhà cung cấp dịch vụ để xử lý tiếp.)'),
(113063, 7432, 29, '(Nhiều hơn)'),
(113064, 7433, 29, '(Bệnh nhân Mới)'),
(113065, 7434, 29, '(Ghi chú và Ủy quyền)'),
(113066, 7435, 29, '(Ghi chú Bệnh nhân)'),
(113067, 7436, 29, '(Chọn một trong số này, hoặc gõ tiêu đề của riêng bạn)'),
(113068, 7437, 29, '(Giữ Shift) Bấm vào hoặc kéo để thay đổi giá trị'),
(113069, 7438, 29, '* Đã nhắc nhở'),
(113070, 7439, 29, '** Xin di chuyển phẫu thuật đến các Vấn đề!'),
(113071, 7440, 29, '*Yêu cầu'),
(113072, 7441, 29, '+ Đã vẽ biểu đồ'),
(113073, 7442, 29, '- Không có'),
(113074, 7445, 29, '.'),
(113075, 7446, 29, '0'),
(113076, 7447, 29, '0-10'),
(113077, 7448, 29, '0-24'),
(113078, 7451, 29, '1'),
(113079, 7452, 29, '1 = Bắc Mỹ. Xem danh sách các mã quốc gia khác tại http://www.wtng.info/.'),
(113080, 7453, 29, '1 Ngày Sau'),
(113081, 7454, 29, '1 Tháng Sau'),
(113082, 7455, 29, '1 Tuần Sau'),
(113083, 7456, 29, '1 Năm Sau'),
(113084, 7457, 29, '1.Nghỉ ngơi 2. Chườm nước đá trong hai ngày 3. Bó chặt, để nguyên băng, trừ khi bàn chân tê dần hoặc chuyển màu nhợt nhạt 4. Nâng cao bàn chân và cẳng chân'),
(113085, 7458, 29, '11-14'),
(113086, 7459, 29, '12 giờ'),
(113087, 7460, 29, '15-19'),
(113088, 7462, 29, '2'),
(113089, 7463, 29, '2 Ngày Sau'),
(113090, 7464, 29, '2 Tháng Sau'),
(113091, 7465, 29, '2 Tuần Sau'),
(113092, 7466, 29, '2 Năm Sau'),
(113093, 7468, 29, '20-24'),
(113094, 7477, 29, '2111-13'),
(113095, 7478, 29, '24 giờ'),
(113096, 7479, 29, '25 +'),
(113097, 7480, 29, '25-29'),
(113098, 7481, 29, 'lần thứ 2'),
(113099, 7482, 29, '3 Ngày Sau'),
(113100, 7483, 29, '3 tháng'),
(113101, 7484, 29, '3 Tháng Sau'),
(113102, 7485, 29, '3 lần mỗi ngày'),
(113103, 7486, 29, '3 Tuần Sau'),
(113104, 7487, 29, '30-34'),
(113105, 7488, 29, '35-39'),
(113106, 7489, 29, 'lần thứ 3'),
(113107, 7490, 29, '4 Ngày Sau'),
(113108, 7491, 29, '4 tháng'),
(113109, 7492, 29, '4 Tháng Sau'),
(113110, 7493, 29, '4 lần mỗi ngày'),
(113111, 7494, 29, '4 Tuần Sau'),
(113112, 7495, 29, '40-44'),
(113113, 7496, 29, '45 +'),
(113114, 7497, 29, '465,9, URI'),
(113115, 7498, 29, '466,0, viêm phế quản cấp tính NOS'),
(113116, 7499, 29, '486,0, viêm phổi, cấp tính'),
(113117, 7500, 29, '491,21, COPD trầm trọng hơn'),
(113118, 7501, 29, '491,8, viêm phế quản, mãn tính'),
(113119, 7502, 29, '493,92, hen suyễn, Exac cấp tính.'),
(113120, 7503, 29, '496,0, COPD'),
(113121, 7504, 29, 'lần thứ 4'),
(113122, 7505, 29, '5 Ngày Sau'),
(113123, 7506, 29, '5 Tháng Sau'),
(113124, 7507, 29, '5 Tuần Sau'),
(113125, 7508, 29, '519,7, Co thắt phế quản'),
(113126, 7509, 29, 'lần thứ 5'),
(113127, 7510, 29, '6 Ngày Sau'),
(113128, 7511, 29, '6 tháng'),
(113129, 7512, 29, '6 Tháng Sau'),
(113130, 7513, 29, '6 Tuần Sau'),
(113131, 7514, 29, 'lần thứ 6'),
(113132, 7515, 29, '7 Tháng Sau'),
(113133, 7516, 29, '8 Tháng Sau'),
(113134, 7517, 29, '824,0 Gãy xương, mắt cá giữa, kín'),
(113135, 7518, 29, '824,2 Gãy xương, mắt cá bên, kín'),
(113136, 7519, 29, '824,6 Gãy xương,3 Mắt cá , kín'),
(113137, 7520, 29, '825,32 Gãy xương, Xương ghe (mắt cá)'),
(113138, 7521, 29, '825,35 Gãy xương, cơ sở của 5 (thứ 5) xương bàn chân'),
(113139, 7522, 29, '845,00 mắt cá chân bị bong gân NOS'),
(113140, 7523, 29, '845,01 Bong gân giữa ( cơ Delta)'),
(113141, 7524, 29, '845,02 Bong gân, Calcaneal fibular'),
(113142, 7525, 29, '9 Tháng Sau'),
(113143, 7526, 29, '99212 Thành lập - không biến chứng'),
(113144, 7527, 29, '99213 Thành lập - Ít phức tạp'),
(113145, 7528, 29, '< Trong phòng kiểm tra'),
(113146, 7529, 29, '> Kiểm tra ra'),
(113147, 7531, 29, '? Không đến'),
(113148, 7532, 29, '@ Đã đến'),
(113149, 7533, 29, '[Thay đổi xem]'),
(113150, 7534, 29, '[Ngày khám trước]'),
(113151, 7535, 29, '[Số ngày từ lần khám trước]'),
(113152, 7536, 29, '[EOBs]'),
(113153, 7537, 29, '[Xuất OFX]'),
(113154, 7538, 29, '[Không nên]'),
(113155, 7539, 29, '[Số lần gặp]'),
(113156, 7540, 29, '[Báo cáo]'),
(113157, 7541, 29, '[Chọn tất cả]'),
(113158, 7542, 29, '[SQL-Ledger]'),
(113159, 7543, 29, '[Bắt đầu xử lý theo khối]'),
(113160, 7544, 29, '[Xem Đăng nhập]'),
(113161, 7545, 29, '[Xem Báo cáo có thể in]'),
(113162, 7546, 29, '_PC_DUR_HOURS'),
(113163, 7547, 29, '_PC_DUR_MINUTES'),
(113164, 7548, 29, '_PC_LOCALE'),
(113165, 7549, 29, '~ Đến muộn'),
(113166, 7, 30, 'van szukseg egy eloszto'),
(113167, 1, 31, 'nje'),
(113168, 2, 31, 'Numer fature'),
(113169, 3, 31, 'Nje certifikate klienti per perdoruesin me te drejta administrimi'),
(113170, 7, 31, 'Nevojitet nje distributor'),
(113171, 8, 31, 'Nje formular konsulte tek GCAC duhet shtuar tek kjo vizite'),
(113172, 9, 31, 'Numri i lotit nevojitet'),
(113173, 10, 31, 'Numri i lotit nevojitet!'),
(113174, 11, 31, 'shkronje e vogel'),
(113175, 12, 31, 'numer'),
(113176, 14, 31, 'Ne sistem aktualisht egziston nje pacient me kete numer identifikimi (ID).'),
(113177, 15, 31, 'Ne sistem aktualisht egziston nje pacient me kete emer.'),
(113178, 16, 31, 'Nee pacient me kete SS egziston aktualisht.'),
(113179, 19, 31, 'Per cdo vizite mund te specifikohet personi rekomandues.'),
(113180, 20, 31, 'Numri referues IPPF kerkohet!'),
(113181, 21, 31, 'Nje karakter special'),
(113182, 22, 31, 'Nje vlere unike per te identifikuar kete fushe, e padukshme per perduruesin'),
(113183, 24, 31, 'a.c.'),
(113184, 25, 31, 'a.m.'),
(113185, 26, 31, 'A/F Niveli i djathte:'),
(113186, 27, 31, 'AB'),
(113187, 28, 31, 'Shkurtim'),
(113188, 29, 31, 'Abces:'),
(113189, 30, 31, 'Abdominal'),
(113190, 31, 31, 'I Afte te Perballoje Pesha kater (4) hapat:'),
(113191, 32, 31, 'Abn'),
(113192, 33, 31, 'ABN1'),
(113193, 34, 31, 'Anormal'),
(113194, 35, 31, 'Analize gjaku jo normale'),
(113195, 36, 31, 'Rritje flokesh jo normale'),
(113196, 37, 31, 'Mamograme jo normale'),
(113197, 39, 31, 'Abort'),
(113198, 40, 31, 'Probleme aborti'),
(113199, 41, 31, 'Metode aborti'),
(113200, 42, 31, 'Kategori aborti'),
(113201, 43, 31, 'Aborte'),
(113202, 44, 31, 'Rreth kalendarit'),
(113203, 46, 31, 'Mungesa nga diagnoza'),
(113204, 47, 31, 'Prano detyren'),
(113205, 48, 31, 'Prano pagesen per'),
(113206, 49, 31, 'Pranim pagese per'),
(113207, 50, 31, 'Pranon detyren'),
(113208, 51, 31, 'Kontroll aksesi'),
(113209, 52, 31, 'Lista e administrimit te kontrollit te aksesit'),
(113210, 54, 31, 'Aksesi nuk lejohet'),
(113211, 56, 31, 'Akseso portalin e pacientit tuaj'),
(113212, 59, 31, 'Emer llogarie'),
(113213, 62, 31, 'Kontabilitet'),
(113214, 64, 31, 'Dhimbje'),
(113215, 65, 31, 'Kerkohet njohje nga ISA14'),
(113216, 66, 31, 'Njohje, licensim dhe certifikim'),
(113217, 67, 31, 'ACL'),
(113218, 68, 31, 'Administrimi i ACL'),
(113219, 69, 31, 'Nuk shte autorizuar administrimi i ACL'),
(113220, 71, 31, 'Akne'),
(113221, 72, 31, 'Akt'),
(113222, 73, 31, 'Date akti'),
(113223, 74, 31, 'Veprim'),
(113224, 75, 31, 'Veprime'),
(113225, 77, 31, 'Aktivizo rapotimet CCR/CCD'),
(113226, 78, 31, 'Aktiv'),
(113227, 79, 31, 'Lajmerim aktiv'),
(113228, 80, 31, 'Rregulla lajmerimi aktiv'),
(113229, 81, 31, 'Lajmerime/kujtese aktive'),
(113230, 82, 31, 'Takim aktiv'),
(113231, 84, 31, 'Liste aktive'),
(113232, 85, 31, 'Pacient aktive'),
(113233, 86, 31, 'Plane aktive'),
(113234, 87, 31, 'Aktivitet'),
(113235, 88, 31, 'Lloj aktiviteti'),
(113236, 92, 31, 'Kornike akute'),
(113237, 93, 31, 'shto'),
(113238, 94, 31, 'Shto'),
(113239, 95, 31, 'SHTO'),
(113240, 96, 31, 'Shto nje kompani'),
(113241, 98, 31, 'Shto nje farmaci'),
(113242, 100, 31, 'shto nje ngjarje per '),
(113243, 101, 31, 'Shto si shenim te ri'),
(113244, 102, 31, 'Shto si "i Ri"'),
(113245, 104, 31, 'Shto buton'),
(113246, 105, 31, 'Shto Butona per Karakteret e Vecanta, Tekst per tu afishuar ne krye te edituesit per t''ju shtuar tekstit me ane te Klikimit'),
(113247, 106, 31, 'Shto kategori'),
(113248, 107, 31, 'Shto konstante'),
(113249, 108, 31, 'Shto kontext'),
(113250, 109, 31, 'Shto pagese plani sigurimi'),
(113251, 110, 31, 'Shto kriter'),
(113252, 111, 31, 'Shto buton te modifikueshem'),
(113253, 112, 31, 'Shto diagnoze'),
(113254, 113, 31, 'Shto medikament'),
(113255, 114, 31, 'Shto takim'),
(113256, 115, 31, 'Shto shenime mbi takimin'),
(113257, 116, 31, 'Shto facilitetin'),
(113258, 117, 31, 'Shto fushe'),
(113259, 118, 31, 'Shto linja e meposhteme tek file i konfigurimit te Apache-s'),
(113260, 119, 31, 'Shto Grup'),
(113261, 120, 31, 'Shto kod ICD'),
(113262, 121, 31, 'Shto imunizim'),
(113263, 122, 31, 'Shtimi nuk eshte autorizuar'),
(113264, 123, 31, 'Shto ankese'),
(113265, 125, 31, 'Shto nje gjuhe'),
(113266, 126, 31, 'Shto te Re'),
(113267, 127, 31, 'Shto te re'),
(113268, 128, 31, 'Shto kategori te re: '),
(113269, 129, 31, 'Shto certifikata te reja tek file i konfigurimit te Apache-s'),
(113270, 132, 31, 'Shto grup te ri'),
(113271, 134, 31, 'Shto nje lot te ri dhe transaksion'),
(113272, 135, 31, 'Shto shenim te ri'),
(113273, 136, 31, 'Shto shenim te ri'),
(113274, 137, 31, 'Shto partner te ri'),
(113275, 140, 31, 'Shto shenim'),
(113276, 141, 31, 'Shto te dhena pacienti'),
(113277, 142, 31, 'Shto recete'),
(113278, 144, 31, 'Shto numer provideri'),
(113279, 145, 31, 'Shto rehabilitim'),
(113280, 146, 31, 'Shto rregull'),
(113281, 147, 31, 'Shto'),
(113282, 148, 31, 'Shto ne listen e mjekimeve'),
(113283, 149, 31, 'Shto nivel maksimal'),
(113284, 150, 31, 'Shto transaksion'),
(113285, 151, 31, 'Shto perdorues'),
(113286, 152, 31, 'Shto perdoruesin tek nje grup'),
(113287, 153, 31, 'Shto/Modifiko eRx'),
(113288, 154, 31, 'Shto/Modifik Transaksionin e Pacientit'),
(113289, 155, 31, 'u shtua'),
(113290, 156, 31, 'Nuk lejohet shtimi i te dhenave demografike.'),
(113291, 158, 31, 'Sindrom Addison-i'),
(113292, 159, 31, 'Sindroma e Addison-it'),
(113293, 160, 31, 'Atribute shtese'),
(113294, 161, 31, 'Diagnoze shtese:'),
(113295, 162, 31, 'Te dhena historike shtese'),
(113296, 163, 31, 'Shenime historike shtese'),
(113297, 164, 31, 'Informacion i metejshem'),
(113298, 165, 31, 'Laboratore shtese'),
(113299, 166, 31, 'Shenime shtese'),
(113300, 168, 31, 'Shenime shtese:'),
(113301, 169, 31, 'Shenime shtese: '),
(113302, 170, 31, 'Shenime te tjera per examinimin X-RAY:'),
(113303, 172, 31, 'vetem mund te shtohet'),
(113304, 173, 31, 'Liber adresash'),
(113305, 174, 31, 'Liber adresash'),
(113306, 175, 31, 'Adresa'),
(113307, 178, 31, 'Liber adresash'),
(113308, 179, 31, 'Te dhena per adresen e komapnise qe kryen proceduren'),
(113309, 180, 31, 'Te dhena per adresen e distributorit'),
(113310, 181, 31, 'Te dhena per adresen e shitesit'),
(113311, 182, 31, 'Llojet e librit te adresave'),
(113312, 187, 31, 'Adresa 1'),
(113313, 188, 31, 'Adresa 2'),
(113314, 189, 31, 'MARRESI'),
(113315, 190, 31, 'Ndryshim'),
(113316, 191, 31, 'Shuma e ndryshuar'),
(113317, 192, 31, 'Rregullo'),
(113318, 193, 31, 'Rregullim'),
(113319, 194, 31, 'Shuma e rregullimit'),
(113320, 195, 31, 'Arsyeja e rregullimit'),
(113321, 196, 31, 'Vlera e regullimit per kodin '),
(113322, 197, 31, 'Rregullime'),
(113323, 198, 31, 'Administri rregullime'),
(113324, 199, 31, 'Administrator'),
(113325, 200, 31, 'Emaili i Administratorit'),
(113326, 201, 31, 'Administruar nepermjet'),
(113327, 202, 31, 'E administruar'),
(113328, 203, 31, 'Administruat nga'),
(113329, 206, 31, 'Administrim'),
(113330, 208, 31, 'Administratore'),
(113331, 209, 31, 'Administratoret mund te bejne cdo gje'),
(113332, 212, 31, 'Matje peshe rutine dhe vizite pasuese'),
(113333, 213, 31, 'Matje peshe rutine dhe vizite pasuese (CQM)'),
(113334, 214, 31, 'Direktive e avancuara'),
(113335, 215, 31, 'Direktiva te avancuara'),
(113336, 216, 31, 'Paralajmerim per direktiva te avancuara'),
(113337, 218, 31, 'E avancuar'),
(113338, 219, 31, 'Keshille'),
(113339, 221, 31, 'Ndikon normalisht'),
(113340, 223, 31, 'Telefonata pas orarit te punes'),
(113341, 225, 31, 'Pas kryerjes se konfigurimeve te mesiperme, importoni certifikaten e klientit adminstrator ne browserin e internetit dhe ristartoni serverin Apache (passwordi bosh)'),
(113342, 226, 31, 'Pas ruajtjes se PDF-se, klikoni [Shiko Loget] per te pare per gabime'),
(113343, 227, 31, 'Pas ruajtjes se fileve TEKST, klikoni [Shiko Loget] per te pare per gabime'),
(113344, 228, 31, 'Pasi te keni ruajtur batch-in, kliko "Shiko Logun" per te parre gabimet.'),
(113345, 230, 31, 'Pasi te korrigjohen te dhenat, kliko butonin "Ruaj".'),
(113346, 233, 31, 'Perseri'),
(113347, 234, 31, 'Mosha'),
(113348, 235, 31, 'Moshe nga'),
(113349, 236, 31, 'Kategoria e moshes'),
(113350, 237, 31, 'Te dhenat mbi moshen jane jashte normave.'),
(113351, 239, 31, 'Formati i moshes per "forma e moshes" nuk eshte i vlefshem'),
(113352, 240, 31, 'Formati i moshes per "mosha deri ne" nuk eshte i vlefshem'),
(113353, 241, 31, 'Formulari i moshes'),
(113354, 243, 31, 'Mosha maksimale'),
(113355, 244, 31, 'Mosha minimale'),
(113356, 245, 31, 'Intervali i moshes'),
(113357, 247, 31, 'Kollonat e vjetersimit:'),
(113358, 249, 31, 'Shqip'),
(113359, 250, 31, 'Alkol'),
(113360, 251, 31, 'Konsum alkoli'),
(113361, 253, 31, 'Numerim njoftim'),
(113362, 255, 31, 'Njoftime'),
(113363, 258, 31, 'ALEUT'),
(113364, 259, 31, 'Te gjitha'),
(113365, 260, 31, 'TE GJITHA'),
(113366, 261, 31, 'Te gjitha (Sistemim i Formatit A)'),
(113367, 262, 31, 'Te gjitha (Sistemim i Formatit B)'),
(113368, 263, 31, 'Te gjitha ( te grumbulluara)'),
(113369, 266, 31, 'Te gjitha kategorite'),
(113370, 268, 31, 'Te gjitha kodet'),
(113371, 269, 31, 'Gjithe diten'),
(113372, 270, 31, 'Ngjarje pergjate tere dites'),
(113373, 271, 31, 'Te gjitha fushat demografikle, me kerkim dhe verifikim te duplikateve'),
(113374, 272, 31, 'Te gjitha zyrat'),
(113375, 273, 31, 'Te gjitha demtimet/problemet/shqetesimet'),
(113376, 274, 31, 'Lejohen te gjitha gjuhet'),
(113377, 276, 31, 'Emri i plote ose i pjesshem'),
(113378, 277, 31, 'Mbiemri i plote ose i pjesshem'),
(113379, 278, 31, 'Emri i kompanise i plote ose i pjesshem'),
(113380, 280, 31, 'Te gjitha produktet'),
(113381, 281, 31, 'Te gjithe mjeket'),
(113382, 282, 31, 'Te gjitha te egzaminuara dhe negative:'),
(113383, 283, 31, 'Te gjitha temat'),
(113384, 284, 31, 'Te gjithe perdoruesit'),
(113385, 285, 31, 'Alergjik'),
(113386, 286, 31, 'Alergjite'),
(113387, 287, 31, 'Alergjite:'),
(113388, 288, 31, 'Alergji'),
(113389, 289, 31, 'Importimi i te dhenave te alergjive perfundoi me sukses'),
(113390, 291, 31, 'Reaksion alergjik'),
(113391, 294, 31, 'Aloko'),
(113392, 295, 31, 'Lejo'),
(113393, 296, 31, 'Lejo te gjitha gjuhet te jene te pranishme tek menuja gjate logimit.'),
(113394, 297, 31, 'Lejo krijimin e ankesave qe permbajne diagnozen por jo procedurat apo kostot. Shumica e klinikave nuk e pelqejne kete.'),
(113395, 298, 31, 'Lejo kontrollin per gabime te gjuheve'),
(113396, 299, 31, 'Lejo E-mail'),
(113397, 300, 31, 'Lejohet komunikimi me e-mail?'),
(113398, 301, 31, 'Lejohet e-mail?'),
(113399, 302, 31, 'Lejo Ankesat e Takimeve'),
(113400, 303, 31, 'Lejo shkembimin e te dhenave shendetesore'),
(113401, 304, 31, 'Lejo shkembimin e te dhenave mbi vaksinimin'),
(113402, 305, 31, 'Lejo perdorimin e regjistrit te imunizimit'),
(113403, 306, 31, 'Lejo mesazhet postare'),
(113404, 308, 31, 'Lejo portalin e pacientit'),
(113405, 309, 31, 'Lejo SMS'),
(113406, 310, 31, 'Lejo SMS (mesazh tekst)?'),
(113407, 311, 31, 'Lejo qe ngjarjet e shtuara te behen aktive menjehere?'),
(113408, 312, 31, 'Lejohen mesazhet telefonike?'),
(113409, 313, 31, 'Lejo qe perdoruesit te publikojne Ngjarjet Globale?'),
(113410, 314, 31, 'Lejo qe perdoruesit te publikojne Kalendarin Personal'),
(113411, 315, 31, 'Lejo mesazhet zanore'),
(113412, 316, 31, 'Lejuar'),
(113413, 317, 31, 'Gjuhet e lejuara'),
(113414, 318, 31, 'Lejuar(c)'),
(113415, 323, 31, 'Aktualisht ekziston'),
(113416, 324, 31, 'Aktualisht ekziston.'),
(113417, 325, 31, 'Identifikuesi eshte aktualisht ne perdorim, zgjidh nje tjeter'),
(113418, 326, 31, 'Titulli eshte aktualisht ne perdorim, zgjidh nje tjeter'),
(113419, 327, 31, 'Adrese dytesore'),
(113420, 328, 31, 'Alterno'),
(113421, 329, 31, 'Ne menyre alternative,Ju mund te perdorni faqen e kerkimit per te ngarkuar nje cek elektronik (X12 835) qe keni marre nga pale e paguar ose nga zyra e shkembimit te ceqeve. Ju mund ta bene kete duke klikuar tek butoni Shfletoj dhe duke perzgjedhur filen qe doni te ngarkoni, dhe me pas duke kliuar tek Kerko per te bere ngarkimin dhe per te afishuar faturat perkatese. Ne kete rast parametrat e tjere te permendur me siper nuk aplikohen dhe do te injorohen. Procesi i ngarkimit e ruan filen por akoma nuk e proceson permbajtjen e files -- kjo gje kryhet me vehte sic pershkruhet me poshte.'),
(113422, 330, 31, 'AM'),
(113423, 331, 31, 'Programi AM'),
(113424, 332, 31, 'AMC'),
(113425, 333, 31, 'Gjurmimi i AMC'),
(113426, 338, 31, 'Permireso Nyjen Egzistuese'),
(113427, 343, 31, 'Indian Amerikan'),
(113428, 344, 31, 'Indian Amerikan ose Autokton nga Alaska'),
(113429, 345, 31, 'AMEX'),
(113430, 346, 31, 'Amharic'),
(113431, 347, 31, 'Shuma'),
(113432, 349, 31, 'Shuma per tu paguar'),
(113433, 350, 31, 'Shuma e prapambetur'),
(113434, 351, 31, 'Shuma per kete vizite'),
(113435, 352, 31, 'Shuma e paguar'),
(113436, 353, 31, 'Shuma:'),
(113437, 354, 31, 'Shuma e faturuar'),
(113438, 355, 31, 'Data e mbarimit duhet me e vone se data e fillimit per ngjarjet e perseritura!'),
(113439, 357, 31, 'Nje gabim ndodhi gjate marrjes se pemes se struktures se LibreEHR'),
(113440, 358, 31, 'Nje gabim ndodhi gjate marrjes se pemes se struktures se phpGACL'),
(113441, 359, 31, 'Nje gabim ndodhi gjate marrjes se pemes se struktures se SQL-Ledger'),
(113442, 360, 31, 'Nje ceshtjee paplote GCAC eshte krijuar dhe eshte lidhur. Dikush do te duhet ta plotesoje ate me vone.'),
(113443, 362, 31, 'Nje gabim i papritur ka ndodhur.'),
(113444, 363, 31, 'Shkronje e madhe'),
(113445, 365, 31, 'Dhe'),
(113446, 366, 31, 'DHE'),
(113447, 367, 31, 'dhe'),
(113448, 368, 31, 'dhe '),
(113449, 369, 31, 'dhe te gjithe te dhenat vartese? Veprimi do te logohet.'),
(113450, 370, 31, 'dhe modifikuesi'),
(113451, 371, 31, 'dhe procesuar.'),
(113452, 372, 31, 'ristarto serverin Apache.'),
(113453, 373, 31, 'dhe Arsyeja eshte'),
(113454, 374, 31, 'Anemi'),
(113455, 375, 31, 'Artikulacioni i kycit te kembes'),
(113456, 376, 31, 'Kyci i kembes + thembra'),
(113457, 377, 31, 'Formulari i vleresimit te kycit te kembes'),
(113458, 378, 31, 'Probleme te kycit te kembes'),
(113459, 379, 31, 'Ankylosing Sondlilitis'),
(113460, 380, 31, 'Artrit i shtylles (Ankylosing Spondylitis)'),
(113461, 381, 31, 'Anoreksia'),
(113462, 382, 31, 'Nje tjeter gje qe ju mund te bene tek dritarja e postimit eshte, te kerkoni nje fature dytesore. Ne rast se slektoni checkbox-in perpara ruajtjes, atehere ankesa origjinale do te hapet dhe do te vendoset ne rradhe tek faqja e faturimit, dhe do te procesohet gjate faturimit te rradhes.'),
(113463, 383, 31, 'para'),
(113464, 384, 31, 'nl e anusit, asnje mase/dhimbje rektale'),
(113465, 385, 31, 'Ankth'),
(113466, 386, 31, 'Cfaredo'),
(113467, 387, 31, 'Cfaredo kategorie'),
(113468, 388, 31, 'Cdo pjese e kodit te kerkuar ose pershkrimi i tij'),
(113469, 389, 31, 'Cdo pjese e specialitetit te kerkuar'),
(113470, 390, 31, 'Cdo pjese e kodit identifikues te medikamentit ose emrit'),
(113471, 391, 31, 'Cdo pjese e kodit identifikues te imunizuesit ose te emrit te tij'),
(113472, 392, 31, 'Cdo pjese e emrit te pacientit ose "Mbiemer, Emer" ose "X-Y"'),
(113473, 394, 31, 'Kodi API per derguesin e SMS-ve.'),
(113474, 395, 31, 'Apnea'),
(113475, 396, 31, 'Paraqitje'),
(113476, 397, 31, 'Paraqitje:'),
(113477, 398, 31, 'Shto kete shenim'),
(113478, 399, 31, 'Shto ne shenimin ekzistues'),
(113479, 400, 31, 'Shto ne kete shenim'),
(113480, 401, 31, 'Shto ne kete shenim'),
(113481, 402, 31, 'Apendoktomi'),
(113482, 404, 31, 'Pacientet e aplikueshem'),
(113483, 406, 31, 'Emri i aplikacionit per faqen e logimit dhe titulli i dritares kryesore.'),
(113484, 407, 31, 'Kodi marres i aplikimit (GS03 - Ne rast banke, ISA08 do te perdoret)'),
(113485, 408, 31, 'Kodi dergues i aplikimit (GS02)'),
(113486, 409, 31, 'Titulli i aplikimit'),
(113487, 410, 31, 'I aplikohet formularit te te dhenave vitale dhe karteles se rritjes'),
(113488, 412, 31, 'Beji ndryshimet vetem per kete event, per kete event dhe te gjitha eventet pasuese apo per te gjitha eventet?'),
(113489, 413, 31, 'apliko mbi zonen e afektuar'),
(113490, 414, 31, 'apliko mbi lekure'),
(113491, 415, 31, 'Apliko'),
(113492, 416, 31, 'Aplikimi i permiresimit ne faqe'),
(113493, 417, 31, 'Orar takimi/vizite'),
(113494, 418, 31, 'Data e orarit te vizites/takimit'),
(113495, 419, 31, 'Stili i afishimit te orarit te takimit/vizites'),
(113496, 420, 31, 'Rregull njoftimi per orarin e takimit/vizites'),
(113497, 421, 31, 'Statusi i orarit te takimit/vizites'),
(113498, 422, 31, 'Statuset e orareve te takimit/vizites'),
(113499, 423, 31, 'Takim ndermjet'),
(113500, 424, 31, 'Ngjyra e Takimit/Njgarjes'),
(113501, 425, 31, 'Orare Takimesh'),
(113502, 426, 31, 'Orare Takimesh (write optional)'),
(113503, 427, 31, 'Orare Takimesh (write,wsome optional)'),
(113504, 430, 31, 'Orare takimesh dhe Takime'),
(113505, 431, 31, 'Raport mbi oraret e takimeve'),
(113506, 432, 31, 'Raport oraresh takimi - takimesh'),
(113507, 434, 31, 'Aprovoj'),
(113508, 436, 31, 'Aprovuar'),
(113509, 437, 31, 'Administrimi i ngjarjeve te aprovuara'),
(113510, 440, 31, 'Orar-Takim'),
(113511, 441, 31, 'Orare'),
(113512, 442, 31, 'Prill'),
(113513, 443, 31, 'Prill'),
(113514, 444, 31, 'Arabisht'),
(113515, 447, 31, 'A duhet te perkthehen emrat e grupit te kontrollit te aksesit?'),
(113516, 448, 31, 'A duhet te perkthehen emrat e kategorive te takimit?'),
(113517, 449, 31, 'A duhet te perkthehen emrat e kategorive te dokmentave?'),
(113518, 450, 31, 'Paguhet per kete lloj?'),
(113519, 451, 31, 'A duhet te perkthehen titujt e shenimeve te pacienteve?'),
(113520, 452, 31, 'A jane ruajtur koded ne tabelat e jashtme sql (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2))?'),
(113521, 453, 31, 'A jeni i pregatitur per te plotesuar nje ceshtje te re GCAC per kete vizite?'),
(113522, 454, 31, 'A jeni i sigurte se doni te postoni sot?'),
(113523, 455, 31, 'Jeni te sigurt nese doni te aprovoni keto evente?'),
(113524, 457, 31, 'Jeni te sigurt nese doni ta fshini plotesisht kete formular?'),
(113525, 459, 31, 'Jeni te sigurt nese doni te fshini kete deklarate?'),
(113526, 460, 31, 'Jeni te sigurt nese doni te fshini kete event?'),
(113527, 461, 31, 'Jeni te sigurt nese doni te fshini kete element nga databaza?'),
(113528, 462, 31, 'Jeni te sigurt nese doni te fshini kete shenim?'),
(113529, 464, 31, 'Jeni te sigurt nese doni te ndryshoni keto evente?'),
(113530, 465, 31, 'Jeni te sigurt nese doni te fshihni keto evente?'),
(113531, 467, 31, 'Jeni te sigurt nese doni te shihni keto evente?'),
(113532, 468, 31, 'Jeni te sigurt nese doni te fshini te grupin me emer'),
(113533, 469, 31, 'Jeni te sigurt nese doni te fshini te gjithe listen'),
(113534, 470, 31, 'Jeni te sigurt nese doni te fshini fushen ne'),
(113535, 471, 31, 'Jeni te sigurt nese doni te fshini fushat e zgjedhura?'),
(113536, 472, 31, 'Jeni te sigurt nese doni te vazhdoni me kete veprim?'),
(113537, 473, 31, 'Zone e papercaktuar'),
(113538, 474, 31, 'Krah'),
(113539, 475, 31, 'Armenisht'),
(113540, 477, 31, 'Aritmi'),
(113541, 478, 31, 'Artrit'),
(113542, 479, 31, 'Artrit / semundje e degradimit te nyjeve lidhese'),
(113543, 480, 31, 'Artrit / semundje e degradimit te nyjeve lidhese'),
(113544, 481, 31, 'si'),
(113545, 482, 31, 'sipas'),
(113546, 484, 31, 'aziatik'),
(113547, 487, 31, 'vleresim'),
(113548, 488, 31, 'Caktuar'),
(113549, 489, 31, 'Ndihmes'),
(113550, 490, 31, 'Azme'),
(113551, 491, 31, 'tek'),
(113552, 492, 31, 'Eshte i domosdoshem te pakten nje parameter kerkimi nese zgjidhni "Te gjitha".'),
(113553, 493, 31, 'Ne Navikul'),
(113554, 494, 31, 'Ne Navikul:'),
(113555, 495, 31, 'Ekip atletike'),
(113556, 497, 31, 'Demtim atletik'),
(113557, 498, 31, 'certificate CA per auditim ATNA'),
(113558, 499, 31, 'prites per auditimin ATNA'),
(113559, 500, 31, 'certificate lokale per auditim ATNA'),
(113560, 501, 31, 'porte per auditimin ATNA'),
(113561, 503, 31, 'Kujdes'),
(113562, 504, 31, 'Drejtuar'),
(113563, 509, 31, 'Backupe te logeve te auditimit'),
(113564, 510, 31, 'Te ndryshme ne lidhje me loget e auditimit'),
(113565, 511, 31, 'Rradha e logimit te auditimit'),
(113566, 512, 31, 'Logimi i auditimit te te dhenave te pacientit'),
(113567, 513, 31, 'Kalendari i logimit te auditimit');
INSERT INTO `lang_definitions` VALUES
(113568, 514, 31, 'Administrimi i sigurese i logimit te auditimit'),
(113569, 515, 31, 'SELECT Query i logimit te auditimit'),
(113570, 516, 31, 'Gusht'),
(113571, 517, 31, 'Gusht'),
(113572, 519, 31, 'Autorizim'),
(113573, 520, 31, 'Autorizim/shenime'),
(113574, 523, 31, 'Grup autorizimi'),
(113575, 524, 31, 'Satusi i autorizimit'),
(113576, 525, 31, 'Autorizime'),
(113577, 526, 31, 'Autorizo'),
(113578, 527, 31, 'Autorizo - cdo takim'),
(113579, 528, 31, 'Autorizo - takimet personale'),
(113580, 530, 31, 'I autorizuar'),
(113581, 531, 31, 'Vetem te autorizuara'),
(113582, 532, 31, 'Dergo automatikisht'),
(113583, 535, 31, 'Krijo automatikisht takime te reja.'),
(113584, 536, 31, 'Te krijuara automatikisht'),
(113585, 537, 31, 'Llogaritje te automatizuara matjesh'),
(113586, 542, 31, 'Llogaritje te automatizuara matjesh (progresive)'),
(113587, 543, 31, 'Matje te automatizuara'),
(113588, 544, 31, 'Automatike'),
(113589, 546, 31, 'Automatikisht krijo nje takim te ri kur statusi i caktimit te takimit eshte "@" (arrived).'),
(113590, 549, 31, 'Automjet mjekesor'),
(113591, 550, 31, 'ruajtur automatikisht'),
(113592, 551, 31, 'Kategori te disponueshme'),
(113593, 552, 31, 'Kohe e disponueshme'),
(113594, 557, 31, 'Mesatarja mujore'),
(113595, 558, 31, 'C''vendosje / frakture e cvendosur'),
(113596, 559, 31, 'C''vendosje e maleolit lateral'),
(113597, 560, 31, 'C''vendosje e maleolit medial '),
(113598, 561, 31, 'E bazuar ne ndergjegjesim'),
(113599, 562, 31, 'Axillary'),
(113600, 565, 31, 'Dy here ne dite (bis in die)'),
(113601, 566, 31, 'Pas'),
(113602, 567, 31, 'pas'),
(113603, 568, 31, '8 vizita te shkuara'),
(113604, 569, 31, '11 vizita te shkuara'),
(113605, 570, 31, '5 vizita te shkuara'),
(113606, 571, 31, '4 vizita te shkuara'),
(113607, 572, 31, '9 vizita te shkuara'),
(113608, 573, 31, '1 vizite e shkuar'),
(113609, 574, 31, 'Dhembje e shpines'),
(113610, 575, 31, 'Probleme te shpines'),
(113611, 576, 31, '7 vizita te shkuara'),
(113612, 577, 31, '6 vizita te shkuara'),
(113613, 578, 31, 'Nderhyrje kirurgjikale ne shpine'),
(113614, 579, 31, '10 vizita te shkuara'),
(113615, 580, 31, '3 vizita te shkuara'),
(113616, 581, 31, 'Kthehu tek faqja e Aministrimit'),
(113617, 584, 31, 'Kthehu tek Pacienti'),
(113618, 585, 31, 'Kthehu tek perdoruesit'),
(113619, 586, 31, 'Kthehu tek Permbledhja'),
(113620, 587, 31, '12 vizita te shkuara'),
(113621, 588, 31, '2 vizita te shkuara'),
(113622, 590, 31, 'Backup'),
(113623, 591, 31, 'File i backupit eshte krijuar. Tani do te filloje shkarkimi.'),
(113624, 593, 31, 'Backupi u krijua me sukses ne'),
(113625, 594, 31, 'Cek i pavlefshem'),
(113626, 595, 31, 'Borxh i pashleyeshem'),
(113627, 596, 31, 'Bahasa Indonezi'),
(113628, 597, 31, 'Balance'),
(113629, 598, 31, 'Balance'),
(113630, 599, 31, 'balance'),
(113631, 600, 31, 'Shuma e balances'),
(113632, 601, 31, 'Shuma e mbetur per t''u paguar'),
(113633, 603, 31, 'Draft bankar'),
(113634, 607, 31, 'Baza e Metarsalit te peste (5-te)'),
(113635, 608, 31, 'Baza e Metarsalit te peste (5-te):'),
(113636, 612, 31, 'Utilitet per komunikim ne grup'),
(113637, 613, 31, 'Hyrje per pagese ne grup'),
(113638, 614, 31, 'Pagesa ne grup'),
(113639, 615, 31, 'Procesimin ne grup filloi; kjo do te kerkoje pak kohe.'),
(113640, 616, 31, 'Rezultate e grupit'),
(113641, 617, 31, 'BatchCom'),
(113642, 619, 31, 'sepse kjo ID nuk ekziston.'),
(113643, 620, 31, 'Fillim'),
(113644, 621, 31, 'Data e fillimit'),
(113645, 623, 31, 'Data e fillimit te sherbimit'),
(113646, 624, 31, 'Ora e fillimit te eventeve kalendarike ditore'),
(113647, 626, 31, 'Gromesime'),
(113648, 628, 31, 'Bengali'),
(113649, 630, 31, 'midis'),
(113650, 633, 31, 'Bilaterale'),
(113651, 634, 31, 'Bilaterale:'),
(113652, 636, 31, 'Data e faturimit:'),
(113653, 637, 31, 'Faturim/Mbledhje'),
(113654, 638, 31, 'Faturuar'),
(113655, 640, 31, 'Faturim'),
(113656, 641, 31, 'Faturim (write optional)'),
(113657, 642, 31, 'Ne vemendje te faturimit'),
(113658, 644, 31, 'Kodi i faturimit per sherbimin e kerkuar'),
(113659, 645, 31, 'kodet e faturimit'),
(113660, 646, 31, 'Te dhenat e faturimit'),
(113661, 647, 31, 'Departamenti i faturimit'),
(113662, 648, 31, 'Ndertesa e faturimit'),
(113663, 649, 31, 'Informacioni i faturimit'),
(113664, 650, 31, 'Vendndodhja e faturimit'),
(113665, 655, 31, 'Menaxheri i faturimit'),
(113666, 656, 31, 'Shenime te faturimit'),
(113667, 657, 31, 'Shenime te faturimit per '),
(113668, 658, 31, 'Shenime te faturimit:'),
(113669, 659, 31, 'Rezultatet e kerkimit te faturimit:'),
(113670, 660, 31, 'Raportet e faturimit'),
(113671, 661, 31, 'Statusi i faturimit'),
(113672, 662, 31, 'Statusi i faturimit = i pa faturuar'),
(113673, 663, 31, 'faturim per '),
(113674, 665, 31, 'Biopsi'),
(113675, 666, 31, 'Datelindja'),
(113676, 669, 31, 'e zeze'),
(113677, 670, 31, 'Pneumoconiosis "Mushkeri e zeze"'),
(113678, 671, 31, 'I zi ose afro-amerikan'),
(113679, 672, 31, 'Kancer i fshikezes urinare'),
(113680, 673, 31, 'Infeksion i fshikezes urinare'),
(113681, 674, 31, 'Formular bosh'),
(113682, 675, 31, 'probleme hemoragjike'),
(113683, 676, 31, 'Pika te padukshme'),
(113684, 677, 31, 'Fryrje'),
(113685, 678, 31, 'I Bllokuar'),
(113686, 679, 31, 'Gjak'),
(113687, 680, 31, 'Tensioni i gjakut'),
(113688, 681, 31, 'Tensioni i gjakut'),
(113689, 682, 31, 'Hemoragji nga hunda'),
(113690, 683, 31, 'Shoqata Blue Cross Blue Shield'),
(113691, 684, 31, 'Linjat me njyre blu ne kete raport jane te karakterit informues. Lnjat me ngjyre te zeze tregojne per informacione egzistuese. Linjat me ngjyre jeshile tregojne per ndryshime qe jane aplikuar me sukses. Linjat me ngjyre te kuqe tregojne per gabime ose ndryshime qe nuk jane aplikuar; keto duhet te procesohen manualisht. Aktualisht, ankesat e refuzuara ose pagesat qe duhen rimbursuar, nuk trajtohen automatikisht per rrjedhoj do te shfaqen me te kuqe.'),
(113692, 685, 31, 'shikim i turbullt'),
(113693, 686, 31, 'Indeksi i mases trupore'),
(113694, 687, 31, 'Gjendja e indeksit te mases trupore'),
(113695, 689, 31, 'zone e trupit'),
(113696, 690, 31, 'pjese e trupit'),
(113697, 691, 31, 'pjese e trupit, nese eshte e pershtatshme'),
(113698, 692, 31, 'Dhimbje kocke:'),
(113699, 693, 31, 'Dhimbje kocke: Maleoli Medial'),
(113700, 694, 31, 'Bolean'),
(113701, 696, 31, 'Larva Parazitesh'),
(113702, 697, 31, 'Te dy veshet'),
(113703, 698, 31, 'te dy veshet'),
(113704, 699, 31, 'Fund'),
(113705, 701, 31, 'Kutia 10 A. Ne lidhje me punen '),
(113706, 702, 31, 'Kutia 10 B. Aksident automobilistik '),
(113707, 703, 31, 'Kutia 10 C. Aksident tjeter '),
(113708, 706, 31, 'Kutia 15. Data e te njejtes semundje apo semundjeje te ngjashme (vvvv-mm-dd):'),
(113709, 708, 31, 'Kutia 16. Data e fillimit te paaftesise per te punuar (vvvv-mm-dd):'),
(113710, 709, 31, 'Kutia 16. Data e mbarimit te paaftesise per te punuar (vvvv-mm-dd):'),
(113711, 710, 31, 'Kutia 18. Data e shtrimit ne spital (vvvv-mm-dd): '),
(113712, 711, 31, 'Kutia 18. Data e daljes nga spitali (vvvv-mm-dd): '),
(113713, 712, 31, 'Kutia 20. Eshte perdorur laborator i jashtem?'),
(113714, 713, 31, 'Kutia 22. Kodi (ICD-9) i ri-aplikimi te te ndihmes mjekesore. '),
(113715, 714, 31, 'Kutia 23. Nr. i autorizimit te mparshem. '),
(113716, 715, 31, 'Tensioni arterial'),
(113717, 716, 31, 'Tensioni arterial diastolic'),
(113718, 717, 31, 'Tensioni arterial sistolic'),
(113719, 719, 31, 'TAD'),
(113720, 721, 31, 'TAS'),
(113721, 722, 31, 'Portugalisht'),
(113722, 723, 31, 'Gjoks'),
(113723, 724, 31, 'Biopsi gjoksi'),
(113724, 725, 31, 'Rrjedhje gjoksi'),
(113725, 726, 31, 'Semundje gjoksi'),
(113726, 727, 31, 'Ekzaminim gjoksi'),
(113727, 728, 31, 'Mase gjoksi'),
(113728, 730, 31, 'Zhurma te frymemarrjes:'),
(113729, 732, 31, 'Thyerje e kockave'),
(113730, 734, 31, 'Formular per bronkitin'),
(113731, 735, 31, 'Kerkoj'),
(113732, 736, 31, 'Kerko per te dhenat'),
(113733, 737, 31, 'Hematome'),
(113734, 739, 31, 'Fryerje djathtas:'),
(113735, 741, 31, 'Urinim me djegie'),
(113736, 742, 31, 'Urinim Me Djegie'),
(113737, 744, 31, 'I zene'),
(113738, 745, 31, 'por akoma i paprocesuar.'),
(113739, 746, 31, 'Gluteus'),
(113740, 747, 31, 'Gluteus + Sacro-ileic'),
(113741, 748, 31, 'nga'),
(113742, 749, 31, 'Nga'),
(113743, 750, 31, 'nga goja'),
(113744, 751, 31, 'Nga/Burimi'),
(113745, 752, 31, 'Nga:'),
(113746, 753, 31, 'C'),
(113747, 754, 31, 'Certifikate CA per verifikiin e serverit RFC 5425 TLS syslog'),
(113748, 755, 31, 'Jetegjatesia e kashese ne seconda'),
(113749, 756, 31, 'Ta hedh ne kashe shabllonin e daljes?'),
(113750, 757, 31, 'Konsum kafeine'),
(113751, 758, 31, 'Kalendar'),
(113752, 759, 31, 'Ora kalendarike e mbylljes'),
(113753, 760, 31, 'Interval kalendarik'),
(113754, 761, 31, 'Ekrani i kalendarit'),
(113755, 762, 31, 'Parametrat e kalendarit'),
(113756, 763, 31, 'Ora kalendarike e hapjes'),
(113757, 764, 31, 'Kalendar UI'),
(113758, 765, 31, 'Pamja kalendarike'),
(113759, 766, 31, 'Thirrja per te addForm() shkon ketu.<br>'),
(113760, 767, 31, 'Kalori'),
(113761, 768, 31, 'Kamboxhian'),
(113763, 774, 31, 'Anullo'),
(113764, 775, 31, 'Anullo ndryshimet'),
(113765, 776, 31, 'Anulluar'),
(113766, 777, 31, 'Kancer'),
(113767, 778, 31, 'Egzaminim rutine: Kancer i kolonit'),
(113768, 779, 31, 'Egzaminim rutine: Mamogram'),
(113769, 780, 31, 'Egzaminim rutine: Pap test'),
(113770, 781, 31, 'Egzaminim rutine: Kancer i prostates'),
(113771, 782, 31, 'Nuk mund te shtohen keto te dhena, sepse ekzistojne ne sistem!'),
(113772, 783, 31, 'Nuk mund te shtohen keto te dhena, sepse ekzistojne ne sistem!'),
(113773, 785, 31, 'nuk mund te konvertohet ne JPEG. Ndoshta programi ImageMagick nuk eshte instaluar?'),
(113774, 787, 31, 'nuk mund te afishohet drejt perse-drejti pasi ky lloj nuk suportohet nga browseri.'),
(113775, 788, 31, 'nuk mund te afishohet drejt perse-drejti pasi ky lloj nuk suportohet nga browseri.'),
(113776, 789, 31, 'nuk mund te afishohet drejt perse-drejti pasi ky lloj nuk suportohet nga browseri.'),
(113777, 790, 31, 'Nuk mund te krijohet'),
(113778, 795, 31, 'Nuk gjendet '),
(113779, 796, 31, 'Nuk gjendet skedari'),
(113780, 799, 31, 'Nuk mund te gjindet klienti nga ID e SQL-Ledger'),
(113781, 800, 31, 'nuk mund te gjindet referenca postscript e dokumentit ne '),
(113782, 801, 31, 'Nuk mund te provideri nga ID e SQL-Ledger pnedhenes= '),
(113783, 802, 31, 'Nuk mund te ndryshohen pagesat. Shuma e pashperndare eshte negative.'),
(113784, 803, 31, 'Nuk mund te hapet '),
(113785, 804, 31, 'Nuk mund te aplikosh per sigurim. Entiteti i zgjedhur per te paguar eshte pacient.'),
(113786, 805, 31, 'Nuk mund te aplikosh per pacienti. Entiteti i zgjedhur per te paguar eshte sigurimi.'),
(113787, 806, 31, 'Nuk mund te aplikohen pagesat. Shuma e pashperndare eshte negative.'),
(113788, 807, 31, 'Nuk mund te lexohet'),
(113789, 808, 31, 'Nuk mund te lexohet direktoria'),
(113790, 809, 31, 'Nuk mund te behen ndryshime pasi nuk po modifikohet nje e dhene ekzistuese!'),
(113791, 810, 31, 'Kapitalizo'),
(113792, 812, 31, 'kapsule'),
(113793, 813, 31, 'karte'),
(113794, 814, 31, 'Kataterizim Kardiak'),
(113795, 815, 31, 'Eko kardiake'),
(113796, 816, 31, 'Kardiovaskulare'),
(113797, 821, 31, 'Kartilago / kondral / demtim i diskut'),
(113798, 822, 31, 'Demtim i kartilagjenit'),
(113799, 823, 31, 'Pulsimet Cartoidale nl, pulsimet pedaluese nl'),
(113800, 824, 31, 'para ne dore'),
(113801, 825, 31, 'Para ne dore'),
(113802, 826, 31, 'Pare ne dore te marra'),
(113803, 827, 31, 'Vertetimi i marrjes se parave nga provideri'),
(113804, 829, 31, 'Kirurgji katarakti'),
(113805, 830, 31, 'Katarkt'),
(113806, 831, 31, 'Kategori'),
(113807, 832, 31, 'Kategori per'),
(113808, 833, 31, 'Kategori'),
(113809, 834, 31, 'kategori'),
(113810, 835, 31, 'Kategori '),
(113811, 836, 31, 'Detaje te kategorise'),
(113812, 837, 31, 'Limite te kategorise'),
(113813, 838, 31, 'Emri i kategorise'),
(113814, 839, 31, 'Emri i kategorise eshte bosh'),
(113815, 840, 31, 'Kategori/titull'),
(113816, 841, 31, 'kaukazian'),
(113817, 842, 31, 'Shkakton printimin ne recete te informacionit te Takimit/Providerit primar'),
(113818, 850, 31, 'CDR'),
(113819, 852, 31, 'Celular'),
(113820, 853, 31, 'Celular'),
(113821, 855, 31, 'Nr Celulari'),
(113822, 856, 31, 'Certifikim qendror'),
(113823, 857, 31, 'Amerikano Jugor/Qendror'),
(113824, 858, 31, 'Informacion teknik: Certificate Authority crt file location cannot be empty'),
(113825, 859, 31, 'Informacion teknik: Certificate Authority key file location cannot be empty'),
(113826, 860, 31, 'Informacion teknik: Certificate to send to RFC 5425 TLS syslog server.'),
(113827, 861, 31, 'Perdoreus i certifikuar'),
(113828, 862, 31, 'Certifikata'),
(113829, 864, 31, 'ChampUS'),
(113830, 865, 31, 'ChampUSVA'),
(113831, 866, 31, 'ndrysho'),
(113832, 867, 31, 'Ndrysho'),
(113833, 868, 31, 'Ndrysho aktivitetin'),
(113834, 870, 31, 'Ndryshime ne pamje'),
(113835, 871, 31, 'Ndryshime ne pamje'),
(113836, 874, 31, 'Ndryshuar'),
(113837, 875, 31, 'Zorre e ndryshuar'),
(113838, 877, 31, 'Karakteristika'),
(113839, 878, 31, 'Karaktere te mbetura'),
(113840, 879, 31, 'Komision'),
(113841, 880, 31, 'Rregullimi i komisionit'),
(113842, 881, 31, 'Komision i koduar'),
(113843, 882, 31, 'Komisionet'),
(113844, 883, 31, 'Kartele'),
(113845, 884, 31, 'Aktiviteti i karteles'),
(113846, 885, 31, 'Raport i aktivitetit te karteles'),
(113847, 886, 31, 'ID Kartele'),
(113848, 887, 31, 'ID Kartele:'),
(113849, 889, 31, 'Aktivitete i vendndodhjes se grafikut'),
(113850, 890, 31, 'Shenim ne kartele'),
(113851, 891, 31, 'Numer Kartele'),
(113852, 892, 31, 'Vendndodhjet e ruajtjes se grafikut'),
(113853, 893, 31, 'Ndjekesi i grafikut'),
(113854, 894, 31, 'Ndjekesi i grafikut'),
(113855, 895, 31, 'Grafike te perfunduar'),
(113856, 896, 31, 'Nxirr grafikun'),
(113857, 898, 31, 'Kontroll'),
(113858, 899, 31, 'kontroll'),
(113859, 900, 31, 'Kontrollo gjithshka'),
(113860, 902, 31, 'Kontrollo shumen'),
(113861, 903, 31, 'Kontrollo daten'),
(113862, 904, 31, 'Kontrollo diferencat ne perkthim bazuar ne tabelen e perkthimit'),
(113863, 906, 31, 'Hyrje ne'),
(113864, 907, 31, 'Kontrollo te dhenat hyrese'),
(113865, 909, 31, 'Kontrollo rezultatet e analizave laboratorike'),
(113866, 912, 31, 'Kontrollo numrin'),
(113867, 915, 31, 'Kontrollo pagesen'),
(113868, 916, 31, 'Kontrollo kutine nese ky eshte nje file i koduar'),
(113869, 917, 31, 'Zgjidhe kete nese deshironi qe providert te shikojne te gjitha takimet dhe jo vetem te tyret.'),
(113870, 919, 31, 'Kontrollo/Data EOB:'),
(113871, 920, 31, 'Kontrollo/Nr EOB:'),
(113872, 921, 31, 'Kontrollo/Numer reference'),
(113873, 922, 31, 'Kontrollo/Numer reference'),
(113874, 923, 31, 'Lista e checkbox'),
(113875, 924, 31, 'Lista e checkbox'),
(113876, 925, 31, 'checkbox me tekst'),
(113877, 926, 31, 'checkbox me tekst'),
(113878, 928, 31, 'E selektuar'),
(113879, 929, 31, 'Kuti e selektuar = Po, bosh = jo'),
(113880, 932, 31, 'Checkout'),
(113881, 933, 31, 'Kontrollo shumen'),
(113882, 934, 31, 'Kraharori'),
(113883, 935, 31, 'CTAB kraharori'),
(113884, 936, 31, 'Dhimbje kraharori'),
(113885, 937, 31, 'Dhimbje kraharori:'),
(113886, 938, 31, 'Dhimbje kraharori'),
(113887, 940, 31, 'Chg'),
(113888, 942, 31, 'Ankesa shefit'),
(113889, 943, 31, 'Femije'),
(113890, 945, 31, 'Statusi i vaksinimit pediatrik'),
(113891, 946, 31, 'Ethe'),
(113892, 947, 31, 'Kinez'),
(113893, 948, 31, 'Kinez'),
(113894, 949, 31, 'Kinez'),
(113895, 951, 31, 'Zgjedhje'),
(113896, 952, 31, 'Cholecystectomy'),
(113897, 954, 31, 'Cholecystectomy'),
(113898, 955, 31, 'Zgjidh'),
(113899, 956, 31, 'Zgjidhni nje seksion dhe klikoni nje objekt ne te; me pas ne seksionin tjeter ju do te shikoni objektet e lidhur te ngjyrosur, ju mund te klikoni ne kete seksion dhe te fshini lidhjet.'),
(113900, 957, 31, 'Kritere zgjedhjeje'),
(113901, 962, 31, 'Liste zgjedhjeje'),
(113902, 965, 31, 'Zgjidhni formatin e printimit per kete raport takimi'),
(113903, 967, 31, 'Bronshit kronik'),
(113904, 968, 31, 'Dhimbje kronike e nyjeve'),
(113905, 969, 31, 'Zemundje Kronike e Veshkes (CKD)'),
(113906, 970, 31, 'Chronic synovitis / effusion / joint pain / gout'),
(113907, 971, 31, 'Kronik/perserites'),
(113908, 973, 31, 'Cirrhosis i melcise'),
(113909, 974, 31, 'Cirrhosis i melcise'),
(113910, 975, 31, 'Qytet'),
(113911, 976, 31, 'Emer qyteti'),
(113912, 977, 31, 'Qytet, shtet'),
(113913, 978, 31, 'Qytet, Kod Postar'),
(113914, 979, 31, 'Qytet/Shtet'),
(113915, 980, 31, 'Kerkese'),
(113916, 981, 31, 'Kerkese '),
(113917, 983, 31, 'Testi i kerkeses perfundoi se egzekutuari'),
(113918, 984, 31, 'Lloj kerkese'),
(113919, 985, 31, 'Kerkesa i gjeneruar tek file'),
(113920, 986, 31, 'Kerkesa i gjeneruar tek file '),
(113921, 987, 31, 'Kerkesat'),
(113922, 988, 31, 'Klasifikim'),
(113923, 989, 31, 'I qarte'),
(113924, 991, 31, 'Parto gjithshka'),
(113925, 992, 31, 'Pastro te dhenat HL7'),
(113926, 993, 31, 'Arsyetim i qarte'),
(113927, 994, 31, 'Informacion teknik: Clear Smarty Cache'),
(113928, 995, 31, 'Informacion teknik: Clearing house info required for EDI 270 batch creation.'),
(113929, 996, 31, 'Numer CLIA'),
(113930, 997, 31, 'Kliko'),
(113931, 998, 31, 'Kliko ''Eksporto'' per te eksportuar Kategorite, Nen-kategorite, Objektet, Permbajtjen tek nje file tekst. Cdo ngjashmeri e ketij file me nje file XML eshte e rastesishme. Etiketat e hapjes dhe mbylljes duhet te jene ne te njejten linje, duhet te jene me karaktere kapitale dhe pa hapesire. Per te importuar, shfletoni per tek file dhe klikoni tek ''Import''.Ne rast se te dhenat jane teresisht ndryshe, ato do te inkorporohen me te dhenat egzistuese. Nese ka te emertime objektesh te ngjashme, emrat e vjeter do te mbahen dhe emrat e rinj do te ruhen duke shtuar nje numer ne fundt te tij.'),
(113932, 999, 31, 'Klikoni mbi nje vend ne grafik per te shtuar nje shenim, klikoni perseri per ta hequr ate.'),
(113933, 1000, 31, 'Informacion teknik:'),
(113934, 1001, 31, 'kliko per me shume'),
(113935, 1005, 31, 'Kliko ketu'),
(113936, 1006, 31, 'Kliko ketu per te shtuar nje pacient te ri.'),
(113937, 1007, 31, 'Kliko pr te shtuar nje status te ri ndryshimi te demtimit dhe modifko aktivitetin ditor'),
(113938, 1008, 31, 'Kliko ketu per te zgjedhur nje date'),
(113939, 1009, 31, 'Kliko ketu per te zgjedhur nje date dhe ore'),
(113940, 1010, 31, 'Kliko ketu per te zgjedhur nje date fillimi'),
(113941, 1020, 31, 'Kliko ketu per te kerkuar'),
(113942, 1021, 31, 'kliko ketu per te perditesuar prioritetin, kategorine dhe detajet e nofkes'),
(113943, 1022, 31, 'Kliko ketu per t''i pare te gjitha.'),
(113944, 1023, 31, 'Kliko ketu per te pare dhe bere grafik'),
(113945, 1025, 31, 'Kliko ketu per te pare dhe bere grafik per te gjitha te rendesishmet.'),
(113946, 1026, 31, 'Kliko ketu per te pare te dhenat e pacientit.'),
(113947, 1027, 31, 'Kliko ketu per ti pare te gjitha.'),
(113948, 1029, 31, 'Informacion teknik: Click Install button to install database release from the following date'),
(113949, 1030, 31, 'Klikoni ne cdo fashe kohore per ta rritur ate'),
(113950, 1031, 31, 'Klikoni Emri i Pacientit per te hapur filen e pacientit'),
(113951, 1032, 31, 'Klikoni Rifresko pe te pare te gjitha rezultatet, ose ju lutem specifkoni kriteret e kerkimit me siper per te pare rezultatet specifike.'),
(113952, 1034, 31, 'Kliko per te shtuar komponente te reja'),
(113953, 1035, 31, 'Kliko per te shtuar konsulta te reja'),
(113954, 1037, 31, 'Kliko per te shkarkuar'),
(113955, 1038, 31, 'Kliko per te modifikuar'),
(113956, 1040, 31, 'Kliko per te modifikuar kete ngjarje'),
(113957, 1041, 31, 'Kliko per te gjeneruar raportin'),
(113958, 1043, 31, 'Kliko per te printuar'),
(113959, 1044, 31, 'Kliko per te marre (shtuar) nje lot te ri'),
(113960, 1045, 31, 'Klik per te zgjedhur'),
(113961, 1046, 31, 'Kliko Per te Zgjedhur'),
(113962, 1047, 31, 'Informacion teknik: Click to select an industry-standard code for this procedure'),
(113963, 1048, 31, 'Kliko per te zgjedhur nje kod procedure opsional'),
(113964, 1050, 31, 'Kliko per te zgjedhur apo ndryshuar kodin CVX'),
(113965, 1051, 31, 'Kliko per te zgjedhur apo ndryshura diagnozat'),
(113966, 1052, 31, 'Kliko per te zgjedhur apo ndryshuar kodet e sherbimit'),
(113967, 1053, 31, 'Kliko per te zgjedhur pacient'),
(113968, 1054, 31, 'Kliko per te zgjedhur kodin e lidhur'),
(113969, 1055, 31, 'Kliko per te zgjedhur sherbimet qe do te kryen ne rast se ky rezultat eshte anormal'),
(113970, 1056, 31, 'Kliko per te zgjedhur proceduren e deshiruar'),
(113971, 1058, 31, 'Kliko per te pare'),
(113972, 1059, 31, 'Kliko per te pare ose modifikuar'),
(113973, 1060, 31, 'Kliko per te pare/modifikuar'),
(113974, 1061, 31, 'Informacion teknik: Click Upgrade button to upgrade database release from the following date'),
(113975, 1063, 31, 'Kliko:'),
(113976, 1064, 31, 'Informacion teknik: Client Certificate Expiration Days'),
(113977, 1065, 31, 'Informacion teknik: Client certificate validation period'),
(113978, 1066, 31, 'Informacion teknik: Client certificate validity should be a valid number.'),
(113979, 1067, 31, 'Kopjim klienti'),
(113980, 1069, 31, 'Permbledhje e historise mjeksore te klientit'),
(113981, 1072, 31, 'Profili i klientit - Klient i ri'),
(113982, 1073, 31, 'Profili i klientit - Klient unik'),
(113983, 1074, 31, 'Kliente'),
(113984, 1075, 31, 'Klinike'),
(113985, 1076, 31, 'Kopjim Klinike'),
(113986, 1077, 31, 'Te dhena ditore te klinikes'),
(113987, 1078, 31, 'ID e klinikes'),
(113988, 1079, 31, 'Klinike'),
(113989, 1080, 31, 'Menaxhuesi i notitifkimit te regullave te vendimarjes klinike'),
(113990, 1083, 31, 'Planet klinike'),
(113991, 1084, 31, 'Masat cilesore klinike (CQM)'),
(113992, 1087, 31, 'Kujtese klinike'),
(113993, 1088, 31, 'Raport klinike'),
(113994, 1089, 31, 'Kategorite e veprimieve te rregullave klinike'),
(113995, 1090, 31, 'Objekt vperimi i rregullave klinike'),
(113996, 1091, 31, 'Metodat e filtrimit te rregullave klinike'),
(113997, 1092, 31, 'Metodat e shenjestres se rregullave klinike'),
(113998, 1093, 31, 'Rregullave klinike'),
(113999, 1094, 31, 'Intervalet e moshes se rregullave klinike'),
(114000, 1095, 31, 'Krahasimet e rregullave klinike'),
(114001, 1096, 31, 'Llojet e takimeve te rregullave klinike'),
(114002, 1097, 31, 'Opsionet e kujtesave te detyrave per tu bere te rregullave klinike'),
(114003, 1098, 31, 'Opsionet e c''aktivizimit te kujtesave te rregullave klinike'),
(114004, 1099, 31, 'Intervalet e kujtesave te rregullave klinike'),
(114005, 1100, 31, 'Metodat e kujtesave te rregullave klinike'),
(114006, 1101, 31, 'Intervalet e shenjestrave te rregullave klinike'),
(114007, 1102, 31, 'Shenjestrat klinike'),
(114008, 1106, 31, 'Klinicistet'),
(114009, 1107, 31, 'Klon'),
(114010, 1108, 31, 'Klono viziten e shkurar'),
(114011, 1109, 31, 'Mbyll'),
(114012, 1111, 31, 'mbyll dritare'),
(114013, 1112, 31, 'E mbyllur'),
(114014, 1113, 31, 'cm'),
(114015, 1114, 31, 'Kufijte e CMS 1500'),
(114016, 1118, 31, 'ID e CMS'),
(114017, 1127, 31, 'CN2-12 e paprekur'),
(114018, 1128, 31, 'Pagese e perbashket'),
(114019, 1129, 31, 'Pagese e perbashket e paguar'),
(114020, 1130, 31, 'Pagese e perbashket'),
(114021, 1131, 31, 'Kod'),
(114022, 1132, 31, 'kod'),
(114023, 1133, 31, 'Gjetes i kodit'),
(114024, 1134, 31, 'Kodi duhet te jete dy germa jo kapitale'),
(114025, 1135, 31, 'Kod ose simbol qe tregon monedhen'),
(114026, 1136, 31, 'Teksti i kodit'),
(114027, 1138, 31, 'lloj kodi'),
(114028, 1141, 31, 'Llojet e kodeve'),
(114029, 1143, 31, 'I koduar'),
(114030, 1144, 31, 'Kodet'),
(114031, 1145, 31, 'Kodim'),
(114032, 1147, 31, 'Kodim - i cdo takimi (write,wsome optional)'),
(114033, 1148, 31, 'Kodim - i takimit tim (write,wsome optional)'),
(114034, 1149, 31, 'Kodimi nuk eshte autorizuar'),
(114035, 1150, 31, 'Kafe'),
(114036, 1152, 31, 'Sigurim i perbashket'),
(114037, 1153, 31, 'Coll w/o'),
(114038, 1154, 31, 'Permbyllje'),
(114039, 1155, 31, 'permbyllje'),
(114040, 1156, 31, 'Permbyll Gjithshka'),
(114041, 1157, 31, 'Permbyll gjithshka'),
(114042, 1158, 31, 'permbyll gjithshka'),
(114043, 1161, 31, 'Koleksione'),
(114044, 1162, 31, 'Raport koleksionesh'),
(114045, 1163, 31, 'Kancer i zorres'),
(114046, 1164, 31, 'Grafi e kancerit te zorres'),
(114047, 1165, 31, 'Operacion i kancerit te zorres'),
(114048, 1166, 31, 'Colonoscopy'),
(114049, 1167, 31, 'colonoscopy'),
(114050, 1168, 31, 'Ngjyre'),
(114051, 1169, 31, 'Ngjyre:Shkurtim'),
(114052, 1170, 31, 'Kolone'),
(114053, 1171, 31, 'Kolonat'),
(114054, 1172, 31, 'Lote te kombinuara'),
(114055, 1173, 31, 'Presje'),
(114056, 1174, 31, 'Koment'),
(114057, 1175, 31, 'Komente'),
(114058, 1176, 31, 'Komentet e ketij rezultati apo rekomandimi'),
(114059, 1177, 31, 'Commercial Insurance Co.'),
(114060, 1178, 31, 'Bej ndryshimet'),
(114061, 1180, 31, 'Komunikimet'),
(114062, 1182, 31, 'Kompani'),
(114063, 1183, 31, 'Emri i kompanise'),
(114064, 1184, 31, 'I plote'),
(114065, 1186, 31, 'I plotesuar'),
(114066, 1188, 31, 'I plotesuar?'),
(114067, 1190, 31, 'Komplikacione nga ofruesi i sherbimit'),
(114068, 1191, 31, 'Komplikacione aborti'),
(114069, 1192, 31, 'Komponent'),
(114070, 1193, 31, 'Computer Aided Medical Ordering System'),
(114071, 1194, 31, 'Perfundime'),
(114072, 1199, 31, 'Konfigurime'),
(114073, 1200, 31, 'Konfigurime Eksport/Import'),
(114074, 1202, 31, 'Informacion teknik: Configure Apache and LibreEHR to use Client side SSL certificates.'),
(114075, 1203, 31, 'Informacion teknik: Configure Apache to use Client side SSL certificates'),
(114076, 1204, 31, 'Informacion teknik: Configure Apache to use HTTPS.'),
(114077, 1205, 31, 'Informacion teknik: Configure LIBREEHR to use Client side SSL certificates'),
(114078, 1208, 31, 'Konfirmo krijimin e pacientit te ri'),
(114079, 1209, 31, 'Konfirmo fjalekalimin e ri'),
(114080, 1210, 31, 'Konfirmo pagesen'),
(114081, 1214, 31, 'Congenital'),
(114082, 1215, 31, 'Conjuntiva, pupils'),
(114083, 1217, 31, 'Lidhesa'),
(114084, 1218, 31, 'Konstante'),
(114085, 1219, 31, 'emer konstante'),
(114086, 1220, 31, 'Emri i konstantes eshte bosh'),
(114087, 1221, 31, 'konstante'),
(114088, 1222, 31, 'Kapsllek'),
(114089, 1223, 31, 'Kushtetuese'),
(114090, 1226, 31, 'Pershkrim i shkurter kushtetues'),
(114091, 1227, 31, 'Kontakt'),
(114092, 1228, 31, 'Kontakti me email'),
(114093, 1229, 31, 'Adresa e kontaktit me email'),
(114094, 1231, 31, 'Info rreth kontaktit'),
(114095, 1232, 31, 'Lente kontakti'),
(114096, 1236, 31, 'Emri i kontaktit'),
(114097, 1237, 31, 'Personi i kontaktit'),
(114098, 1239, 31, 'Numri i telefonit te kontaktit'),
(114099, 1240, 31, 'Kontakto ZMG, LLC (zmghealth@gmail.com) per nenshkrim tek sherbimi eRx'),
(114100, 1241, 31, 'kontakto se paku tre nga kater objektet :'),
(114101, 1243, 31, 'Permbajtje'),
(114102, 1244, 31, 'permbajtje'),
(114103, 1245, 31, 'Kontekst'),
(114104, 1246, 31, 'Emri i kontekstit nuk mund te jete bosh'),
(114105, 1247, 31, 'Vazhdo'),
(114106, 1248, 31, 'Continuity of Care Document (CCD)'),
(114107, 1249, 31, 'Continuity of Care Record (CCR)'),
(114108, 1251, 31, 'Kontraceptim'),
(114109, 1252, 31, 'Ceshtej kontraceptimi'),
(114110, 1253, 31, 'Komplikim kontraceptiv (specifiko)'),
(114111, 1254, 31, 'Metode kontraceptive'),
(114112, 1255, 31, 'Produkte kontraceptive'),
(114113, 1256, 31, 'Sherbime kontraceptive te nisur me pare'),
(114114, 1257, 31, 'Fillim kontracpetivi'),
(114115, 1258, 31, 'ID e kontrollit'),
(114116, 1259, 31, 'Nr. i kontrollit'),
(114117, 1261, 31, 'BASHKE PAGUES'),
(114118, 1262, 31, 'Bashke pagues'),
(114119, 1263, 31, 'BashkePagues'),
(114120, 1264, 31, 'Bashkepagues jo pozitiv'),
(114121, 1266, 31, 'Bashke pagesa'),
(114122, 1267, 31, 'COPD'),
(114123, 1268, 31, 'Kopjoni faqet tek grafiku i pacientit'),
(114124, 1269, 31, 'Kopjoni vlerat'),
(114125, 1270, 31, 'Duke kopjuar filen e databases. Kjo do disa kohe...'),
(114126, 1271, 31, 'Shenim e drejte autori'),
(114127, 1273, 31, 'Coronary Artery Bypass'),
(114128, 1274, 31, 'Coronary Artery Bypass Graft (CABG)'),
(114129, 1275, 31, 'I korrigjuar'),
(114130, 1277, 31, 'CouchDB'),
(114131, 1278, 31, 'CouchDB Connection Failed.'),
(114132, 1279, 31, 'CouchDB Database'),
(114133, 1280, 31, 'CouchDB database name'),
(114134, 1281, 31, 'CouchDB host'),
(114135, 1282, 31, 'CouchDB HostName'),
(114136, 1283, 31, 'CouchDB Log Enable'),
(114137, 1284, 31, 'CouchDB Password'),
(114138, 1285, 31, 'CouchDB Port'),
(114139, 1286, 31, 'CouchDB port'),
(114140, 1288, 31, 'CouchDB UserName'),
(114141, 1289, 31, 'Kolle'),
(114142, 1290, 31, 'Kolle:'),
(114143, 1294, 31, 'Nuk mund te lexoj filen'),
(114144, 1296, 31, 'Nuk mund te dergoj email per nje problem ne server, '),
(114145, 1297, 31, 'Nuk mund te dergoj email per nje problem ne server. '),
(114146, 1298, 31, 'Couldn''t create backup dir:'),
(114147, 1299, 31, 'Couldn''t remove dir:'),
(114148, 1300, 31, 'Couldn''t remove old backup file:'),
(114149, 1301, 31, 'Couldn''t remove old export file:'),
(114150, 1302, 31, 'Coumadin Management - INR Monitoring'),
(114151, 1303, 31, 'Keshillim me metode'),
(114152, 1304, 31, 'Keshillim'),
(114153, 1305, 31, 'aktivitete keshillimi'),
(114154, 1306, 31, 'FORMA E KONDRA-BILETES'),
(114155, 1307, 31, 'Kondra-Bilete'),
(114156, 1308, 31, 'Shtet'),
(114157, 1309, 31, 'Lloji i te dhenave te shtetit'),
(114158, 1310, 31, 'Liste shtetesh'),
(114159, 1311, 31, 'Liste shtetesh (write,addonly optional)'),
(114160, 1312, 31, 'Emri i shtetit duhet te perfaqesoht me dy germa. (Psh. United States eshte US)'),
(114161, 1313, 31, 'Qark'),
(114162, 1315, 31, 'Kupon'),
(114163, 1318, 31, 'CPT'),
(114164, 1319, 31, 'CPT Code'),
(114165, 1320, 31, 'CPT Codes'),
(114166, 1321, 31, 'CPT4 Procedure/Service'),
(114167, 1322, 31, 'CPTII Performance Measures'),
(114168, 1323, 31, 'CQM'),
(114169, 1325, 31, 'krem'),
(114170, 1326, 31, 'Krijo nje certifikate SSL ne ane te Klientit per cdo perdorues ose makineri klienti'),
(114171, 1329, 31, 'Krijo nje Ngjarje'),
(114172, 1330, 31, 'Krijo dhe shkarko nje "backup" te plote'),
(114173, 1332, 31, 'Krijo Backup'),
(114174, 1333, 31, 'Krijo pakete'),
(114175, 1334, 31, 'Krijo Certifikate Klienti'),
(114176, 1335, 31, 'Krijo certifikate SSL ne ane te klientit'),
(114177, 1336, 31, 'Krijo Duplikim'),
(114178, 1339, 31, 'Krijo ceshtje te re'),
(114179, 1340, 31, 'Krijo Pacient te Ri'),
(114180, 1344, 31, 'Krijo Shenim Pacienti'),
(114181, 1346, 31, 'Krijo Vizite'),
(114182, 1347, 31, 'E Krijuar'),
(114183, 1348, 31, 'Krijo skedar exporti'),
(114184, 1351, 31, 'Krijuesi'),
(114185, 1352, 31, 'kredit'),
(114186, 1353, 31, 'Karte Krediti'),
(114187, 1354, 31, 'Kredite'),
(114188, 6307, 31, 'Simptoma'),
(114189, 6313, 31, 'Sinkop'),
(114190, 6318, 31, 'Sistem'),
(114191, 1, 32, 'A'),
(114192, 2, 32, 'Kontrola čísla nebo číla požadavku k identifikaci platby'),
(114193, 3, 32, 'Klientský certifikát pro správce'),
(114194, 4, 32, 'Je připojen klinický dokument'),
(114195, 5, 32, 'Je připojen klinický dokument'),
(114196, 7, 32, 'Distributor je vyžadován'),
(114197, 8, 32, 'K návštěvě musí být připojen GCAC formulář'),
(114198, 9, 32, 'Požadováno více čísel'),
(114199, 10, 32, 'Požadováno více čísel'),
(114200, 11, 32, 'malé písmeno'),
(114201, 12, 32, 'Číslo'),
(114202, 14, 32, 'Pacient s tímto ID již existuje'),
(114203, 15, 32, 'Pacient tohoto jména již existuje'),
(114204, 16, 32, 'pacient s tímto SS již existuje'),
(114205, 17, 32, 'Kladné číslo  zobrazí předchozí návštěvy ve widgetu souhrnných údajů pacienta. Záporné číslo  zobrazí předchozí návštěvy v sestupném pořadí'),
(114206, 18, 32, 'Kladné číslo  zobrazí předchozí návštěvy ve widgetu souhrnných údajů pacienta.'),
(114207, 19, 32, 'Ka každé návštěvě je nutné zadat zdroj doporučení'),
(114208, 20, 32, 'Je vyžadován související IPPF kód'),
(114209, 21, 32, 'Speciální znak'),
(114210, 22, 32, 'Unikátní identifikátor pole není pro uživatele viditelný'),
(114211, 23, 32, 'Tento pacient má již existující dnešní návštěvu. Volbou CANCEL ji otevřete nebo volnou OK  založíte novou'),
(114212, 24, 32, 'a.c'),
(114213, 25, 32, 'dopoledne'),
(114214, 26, 32, 'A/F Level Right:'),
(114215, 27, 32, 'AB'),
(114216, 28, 32, 'Zkrácení'),
(114217, 29, 32, 'Absces'),
(114218, 30, 32, 'Abdominální'),
(114219, 31, 32, 'Schopnost zatížit (4) kroky'),
(114220, 32, 32, 'Abn'),
(114221, 33, 32, 'ABN1'),
(114222, 34, 32, 'Abnormální'),
(114223, 35, 32, 'Abnormální krevní test'),
(114224, 36, 32, 'Patologie růstu vlasů'),
(114225, 37, 32, 'Patologický mamogram'),
(114226, 39, 32, 'Potrat'),
(114227, 40, 32, 'Potíže související s potraty'),
(114228, 41, 32, 'Metoda potratu'),
(114229, 42, 32, 'Kategorie potratu'),
(114230, 43, 32, 'Potraty'),
(114231, 44, 32, 'O kalendáři'),
(114232, 46, 32, 'Chybí diagnóza'),
(114233, 47, 32, 'Přijmout ustanovení'),
(114234, 48, 32, 'Přijetí platby za'),
(114235, 49, 32, 'Přijetí platby za'),
(114236, 50, 32, 'O kalendáři'),
(114237, 51, 32, 'Kontrola přístupu'),
(114238, 52, 32, 'Správa kontroly přístupu'),
(114239, 53, 32, 'Datum přístupu'),
(114240, 54, 32, 'Přístup není povolen'),
(114241, 55, 32, 'Přístup není autorizován'),
(114242, 56, 32, 'Přístup do pacientského portálu'),
(114243, 57, 32, 'Nehoda'),
(114244, 59, 32, 'Název účtu'),
(114245, 62, 32, 'Účetnictví'),
(114246, 64, 32, 'Bolesti'),
(114247, 65, 32, 'Požadovaná potvrzení'),
(114248, 66, 32, 'Poděkování, licence a certifikace'),
(114249, 67, 32, 'ACL'),
(114250, 68, 32, 'Správa ACL'),
(114251, 69, 32, 'Správa ACL není autorizována'),
(114252, 70, 32, 'Úspěšná aktualizace ACL'),
(114253, 71, 32, 'Akné'),
(114254, 72, 32, 'Výkon'),
(114255, 73, 32, 'Datum výkonu'),
(114256, 74, 32, 'Akce'),
(114257, 75, 32, 'Akce'),
(114258, 77, 32, 'Aktivovat CCR/CCD reporting'),
(114259, 78, 32, 'Aktivní'),
(114260, 79, 32, 'Aktivní upozornění'),
(114261, 80, 32, 'Pravidla pro aktivní upozornění'),
(114262, 81, 32, 'Aktivní upozornění/připomenutí'),
(114263, 82, 32, 'Aktivní vyšetření'),
(114264, 84, 32, 'Aktivní seznam'),
(114265, 85, 32, 'Aktivní pacient'),
(114266, 86, 32, 'Aktivní plány'),
(114267, 87, 32, 'Aktivita'),
(114268, 88, 32, 'Typ aktivity'),
(114269, 90, 32, 'Akutní otrava/odstranění'),
(114270, 91, 32, 'Akutní manifestace chronického onemocnění'),
(114271, 92, 32, 'Akutní nebo chronický'),
(114272, 93, 32, 'Přidat'),
(114273, 94, 32, 'Přidat'),
(114274, 95, 32, 'Přidat'),
(114275, 96, 32, 'Přidat společnost'),
(114276, 98, 32, 'Přidat lékárnu'),
(114277, 100, 32, 'Přidat akci '),
(114278, 101, 32, 'Přidat novou poznámku'),
(114279, 102, 32, 'Přidat jako nový'),
(114280, 104, 32, 'Přidat tlačítko'),
(114281, 105, 32, 'Přidat tlačítko pro speciální znak, text pro zobrazení v menu editoru'),
(114282, 106, 32, 'Přidat kategorii'),
(114283, 107, 32, 'Přidat konstantu'),
(114284, 108, 32, 'Přidat kontext'),
(114285, 109, 32, 'Přidat spoluplátce'),
(114286, 110, 32, 'Přidat kriteria'),
(114287, 111, 32, 'Přidat volitelné tlačítko'),
(114288, 112, 32, 'Přidat diagnózu'),
(114289, 113, 32, 'Přidat léčivo'),
(114290, 114, 32, 'Přidat vyšetření'),
(114291, 115, 32, 'Přidat vyšetření'),
(114292, 116, 32, 'Přidat zařízení'),
(114293, 117, 32, 'Přidat pole'),
(114294, 118, 32, 'Přidat následující řádky do konfiguračního souboru Apache'),
(114295, 119, 32, 'Přidat skupinu'),
(114296, 120, 32, 'Přidat MKN kód'),
(114297, 121, 32, 'Přidat očkování'),
(114298, 122, 32, 'Není oprávnění přidat !'),
(114299, 123, 32, 'Přidat problém'),
(114300, 124, 32, 'Přidat položku ke sledování'),
(114301, 125, 32, 'Přidat jazyk'),
(114302, 126, 32, 'Přidat nový'),
(114303, 127, 32, 'Přidat nový'),
(114304, 128, 32, 'Přidat novou kategorii '),
(114305, 129, 32, 'Přidat nový certifikát do konfiguračního souboru Apache'),
(114306, 130, 32, 'Přidat novou součást'),
(114307, 131, 32, 'Přidat nové součásti'),
(114308, 132, 32, 'Přidat novou skupinu'),
(114309, 133, 32, 'Přidat nový problém'),
(114310, 134, 32, 'Přidat nové množství a transakci'),
(114311, 135, 32, 'Přidat novou poznámku'),
(114312, 136, 32, 'Přidat novou poznámku'),
(114313, 137, 32, 'Přidat nového partnera'),
(114314, 138, 32, 'Přidat nového pacienta'),
(114315, 140, 32, 'Přidat poznámku'),
(114316, 141, 32, 'Přidat záznam pacienta'),
(114317, 142, 32, 'Přidat předpis'),
(114318, 143, 32, 'Přidat proceduru'),
(114319, 144, 32, 'Přidat číslo poskytovatele'),
(114320, 145, 32, 'Přidat rehabilitaci'),
(114321, 146, 32, 'Přidat roli'),
(114322, 147, 32, 'Přidat do'),
(114323, 148, 32, 'Přidat do seznamu léků'),
(114324, 149, 32, 'Přidat nejvyšší úroveň'),
(114325, 150, 32, 'Přidat transakci'),
(114326, 151, 32, 'Přidat uživatele'),
(114327, 152, 32, 'Přidat uživatele do skupiny'),
(114328, 153, 32, 'Přidat/editovat eRx'),
(114329, 154, 32, 'Přidat/editovat transakci pacienta'),
(114330, 155, 32, 'Přidáno'),
(114331, 156, 32, 'Přidání demografických údajů není autorizováno'),
(114332, 157, 32, 'Přidání položky ke sledování  selhalo'),
(114333, 158, 32, 'Adissonský syndrom'),
(114334, 159, 32, 'Adissonský syndrom'),
(114335, 160, 32, 'Další atributy'),
(114336, 161, 32, 'Další diagnózy'),
(114337, 162, 32, 'Doplňková anamnéza'),
(114338, 163, 32, 'Doplňující poznámka k anamnéze'),
(114339, 164, 32, 'Doplňující informace'),
(114340, 165, 32, 'Doplňující laboratoře'),
(114341, 166, 32, 'Doplňující poznámky'),
(114342, 167, 32, 'Doplňující poznámky pro tento závěr nebo doporučení'),
(114343, 168, 32, 'Doplňující poznámky'),
(114344, 169, 32, 'Doplňující poznámky '),
(114345, 170, 32, 'Doplňující poznámky k RDG metodě'),
(114346, 171, 32, 'Additionally, the corresponding US Snomed Extension Package can be imported separately after installing the International (English version) Snomed Release'),
(114347, 173, 32, 'Adresář'),
(114348, 174, 32, 'Adresář'),
(114349, 175, 32, 'Adresa'),
(114350, 178, 32, 'Adresář'),
(114351, 179, 32, 'Adresářový údaj společnosti poskytující tuto proceduru'),
(114352, 180, 32, 'Položka adresáře pro distributora'),
(114353, 181, 32, 'Položka adresáře pro prodejce'),
(114354, 182, 32, 'Typy adresářů'),
(114355, 183, 32, 'Adresní štítek'),
(114356, 187, 32, 'Adresa 1'),
(114357, 188, 32, 'Adresa 2'),
(114358, 189, 32, 'Adresát'),
(114359, 190, 32, 'Adj'),
(114360, 191, 32, 'Adj amount'),
(114361, 192, 32, 'Přizpůsobit'),
(114362, 193, 32, 'Přizpůsobení'),
(114363, 194, 32, 'Přizpůsobit množství'),
(114364, 195, 32, 'Přizpůsobit důvody'),
(114365, 196, 32, 'Přizpůsobit hodnotu kódu '),
(114366, 197, 32, 'Úpravy'),
(114367, 198, 32, 'Správa přizpůsobení'),
(114368, 199, 32, 'Administrátor'),
(114369, 200, 32, 'E-mail adresa administrátora'),
(114370, 201, 32, 'Spravovat přes'),
(114371, 202, 32, 'Podáván'),
(114372, 203, 32, 'Spravován'),
(114373, 204, 32, 'Spravované datum'),
(114374, 205, 32, 'Spravovaná stránka'),
(114375, 206, 32, 'Správa'),
(114376, 207, 32, 'Správa stránky'),
(114377, 208, 32, 'Administrátoři'),
(114378, 209, 32, 'Administrátor má neomezený přístup'),
(114379, 210, 32, 'Datum přijetí'),
(114380, 212, 32, 'Sledování hmotnosti u dospělých'),
(114381, 213, 32, 'Sledování hmotnosti u dospělých (CQM)'),
(114382, 214, 32, 'Navrhnout opatření'),
(114383, 215, 32, 'Navrhnout opatření'),
(114384, 216, 32, 'Upozornění k navrhovaným opatřením'),
(114385, 218, 32, 'Pokrčočilý'),
(114386, 219, 32, 'Pokyn, ponaučení'),
(114387, 220, 32, 'daleko'),
(114388, 221, 32, 'Affect normal'),
(114389, 222, 32, 'Afrikaans'),
(114390, 223, 32, 'Volání po vyhrazených hodinách'),
(114391, 224, 32, 'After migration from the old password mechanisms where passwords are stored in the users table without salt is complete, this flag should be set to false so that only authentication by the new method is possible'),
(114392, 225, 32, 'Po provedení výše zmíněné konfigurace, importujte klientský certifikát do prohlížeče a restartujte Apache server ( prázdné heslo)'),
(114393, 226, 32, 'Po uložení souboru PDF, klikněte na [Prohlédnout log] ke kontrole chyb'),
(114394, 227, 32, 'Po uložení souboru TEXT, klikněte na [Prohlédnout log] ke kontrole chyb'),
(114395, 228, 32, 'Po uložení dávky, klikněte na [Prohlédnout log] ke kontrole chyb'),
(114396, 229, 32, 'Odpovídající sloupec bude poté zobrazovat ID vybraného pacienta, nebo 0 k vytvoření'),
(114397, 230, 32, 'Po vložení správné informace, klikněte na tlačítko Uložit'),
(114398, 231, 32, 'Po nahrání klikněte na tlačítko " IMPORT"'),
(114399, 232, 32, 'Plánování následné péče'),
(114400, 233, 32, 'Znovu'),
(114401, 234, 32, 'Věk'),
(114402, 235, 32, 'Dle věku'),
(114403, 236, 32, 'Věková kategorie'),
(114404, 237, 32, 'Zadaný věk je mimo rozsah'),
(114405, 238, 32, 'Formát zobrazení věku'),
(114406, 239, 32, 'Věk zadán ve špatném formátu'),
(114407, 240, 32, 'Horní věková hranice je ve špatném formátu'),
(114408, 241, 32, 'Věk od'),
(114409, 242, 32, 'Věk v letech pro zobrazení změny formátu'),
(114410, 243, 32, 'Věk maximálně'),
(114411, 244, 32, 'Věk minimálně'),
(114412, 245, 32, 'Rozsah věku'),
(114413, 247, 32, 'Sloupce věku'),
(114414, 248, 32, 'Akan'),
(114415, 249, 32, 'Albánský'),
(114416, 250, 32, 'Alkohol'),
(114417, 251, 32, 'Spotřeba alkoholu'),
(114418, 252, 32, 'Užívání alkoholu'),
(114419, 253, 32, 'Počet varování'),
(114420, 255, 32, 'Výstrahy'),
(114421, 258, 32, 'ALEUT'),
(114422, 259, 32, 'Všechno'),
(114423, 260, 32, 'Všechno'),
(114424, 261, 32, 'Všchno ( řazeno ve formátu A )'),
(114425, 262, 32, 'Všchno ( řazeno ve formátu B )'),
(114426, 263, 32, 'Všechno ( úhrnem )'),
(114427, 265, 32, 'Všechny automatizované měřící výpočty ( AMC )'),
(114428, 266, 32, 'Všechny kategorie'),
(114429, 267, 32, 'Všechna měření klinické kvality (CQM)'),
(114430, 268, 32, 'Všechny kódy'),
(114431, 269, 32, 'Všechny dny'),
(114432, 270, 32, 'Všechny denní události'),
(114433, 271, 32, 'Všechny demografické údaje s vyhledáváním a kontrolou duplicit'),
(114434, 272, 32, 'Všechna zařízení'),
(114435, 273, 32, 'Všechny úrazy/problémy/potíže'),
(114436, 274, 32, 'Všechny jazyky povoleny'),
(114437, 275, 32, 'Všechna oficální měření klinické kvality (CQM) Skupiny měření'),
(114438, 276, 32, 'Celé nebo část jména'),
(114439, 277, 32, 'Celé nebo část příjmení'),
(114440, 278, 32, 'Celý nebo část názvu organizace'),
(114441, 279, 32, 'Všichni pacienti'),
(114442, 280, 32, 'Všechny produkty'),
(114443, 281, 32, 'Všichni poskytovatelé'),
(114444, 282, 32, 'Všechny provedené kontroly negativní'),
(114445, 283, 32, 'Všechna témata'),
(114446, 284, 32, 'Všichni uživatelé'),
(114447, 285, 32, 'Alergický'),
(114448, 286, 32, 'Alergie'),
(114449, 287, 32, 'Alergie :'),
(114450, 288, 32, 'Alergie'),
(114451, 289, 32, 'Vložení alergie úspěšně provedeno'),
(114452, 290, 32, 'Seznam alergií'),
(114453, 291, 32, 'Alergická reakce'),
(114454, 294, 32, 'Přidělit'),
(114455, 295, 32, 'Povolit'),
(114456, 296, 32, 'Při přihlášení umožnit výběr ze všech kazyků'),
(114457, 297, 32, 'Umožnit vytvoření požadavků obsahujících diagnózy ale ne procedury nebo ceny. Většina pracovišť toto nevyužívá.'),
(114458, 298, 32, 'Povolit ladění'),
(114459, 299, 32, 'Povolit e-mail'),
(114460, 300, 32, 'Povolit e-mailové zprávy ?'),
(114461, 301, 32, 'Povolit e-mail ?'),
(114462, 302, 32, 'Povolit požadavky na vyšetření'),
(114463, 303, 32, 'Povolit výměnu zdravotních údajů'),
(114464, 304, 32, 'Sdílet informace o očkování'),
(114465, 305, 32, 'Povolit použití očkovacího registru'),
(114466, 306, 32, 'Povolit mailovou zprávu'),
(114467, 308, 32, 'Povolit pacientský portál'),
(114468, 309, 32, 'Povolit SMS'),
(114469, 310, 32, 'Povolit SMS zprávy ?'),
(114470, 311, 32, 'Povolit předložené události jako ihned aktivní ?'),
(114471, 312, 32, 'Povolit telefonické zprávy ?'),
(114472, 313, 32, 'Umožnit uživatelům publikovat globální události'),
(114473, 314, 32, 'Povolit uživateli zveřejnit osobní kalendář'),
(114474, 315, 32, 'Povolit hlasové zprávy'),
(114475, 316, 32, 'Povoleno'),
(114476, 317, 32, 'Povolené jazyky'),
(114477, 318, 32, 'Povoleno (c)'),
(114478, 319, 32, 'Povolit požadavky na vyšetření'),
(114479, 320, 32, 'Umožňuje e-podpis individuálních formulářů'),
(114480, 321, 32, 'Umožňuje mail'),
(114481, 322, 32, 'Umožňuje hlasové zprávy'),
(114482, 323, 32, 'Již existuje'),
(114483, 324, 32, 'Již existuje'),
(114484, 325, 32, 'Již používán, zvolte jiný identifikátor'),
(114485, 326, 32, 'Již používán, zvolte jiný název'),
(114486, 327, 32, 'Alternativní adresa'),
(114487, 328, 32, 'Upravit'),
(114488, 330, 32, 'AM'),
(114489, 331, 32, 'Program AM'),
(114490, 332, 32, 'AMC'),
(114491, 333, 32, 'Sledování AMC'),
(114492, 334, 32, 'AMC-2011'),
(114493, 335, 32, 'AMC-2014'),
(114494, 338, 32, 'Opravit stávající poznámku'),
(114495, 339, 32, 'Oprava Z'),
(114496, 340, 32, 'Oprava Stav'),
(114497, 341, 32, 'Změny'),
(114498, 342, 32, 'Změny pro'),
(114499, 343, 32, 'American Indian'),
(114500, 344, 32, 'American Indian or Alaska Native'),
(114501, 345, 32, 'AMEX'),
(114502, 346, 32, 'Amharic'),
(114503, 347, 32, 'Množství'),
(114504, 348, 32, 'Spravované množství'),
(114505, 351, 32, 'Částka pro tuto návštěvu'),
(114506, 352, 32, 'Částka zaplacena'),
(114507, 353, 32, 'Částka:'),
(114508, 354, 32, 'Část. zaúčtována'),
(114509, 355, 32, 'Pro opakující se události musí být zadáno konečné datum později než počáteční'),
(114510, 356, 32, 'Chyba při podpisu formuláře'),
(114511, 357, 32, 'Chyba při zálohování stromového webového adresáře LibreEHR'),
(114512, 358, 32, 'Chyba při zálohování stromového webového adresáře phpGACL'),
(114513, 359, 32, 'Chyba při zálohování stromového webového adresáře SQL-Ledger'),
(114514, 360, 32, 'Nekompletní záznam GCAC.  Je potřeba ho později doplnit'),
(114515, 362, 32, 'Vyskytla se neočekávaná chyba'),
(114516, 363, 32, 'Velké písmeno'),
(114517, 365, 32, 'A'),
(114518, 366, 32, 'A'),
(114519, 367, 32, 'a'),
(114520, 368, 32, 'a '),
(114521, 369, 32, 'a všechna podřízená data ? Tato akce bude logována'),
(114522, 370, 32, 'a modifikátor'),
(114523, 371, 32, 'a zpracováno'),
(114524, 372, 32, 'a restartujte server Apache'),
(114525, 373, 32, 'a příčina je'),
(114526, 374, 32, 'Anémie'),
(114527, 375, 32, 'Hlezno'),
(114528, 376, 32, 'Hlezno + pata'),
(114529, 377, 32, 'Formulář vyšetření hlezna'),
(114530, 378, 32, 'Problémy s hleznem'),
(114531, 379, 32, 'Ankylozující spondylitis'),
(114532, 380, 32, 'Ankylozující spondylitis'),
(114533, 381, 32, 'Anorexie'),
(114534, 382, 32, 'Jinou činnost , kterou zde lze provést je  požadavek na sekundární účtování. Pokud zaškrtnete  tuto položku  před uložením , pak bude původní požadavek znovu otevřen a zařazen na stránku účtů a proveden  v příštím  běhu účtování.'),
(114535, 384, 32, 'Normální tonus  análního sfinkteru, nebolestivý,  reszistence nepřítomná'),
(114536, 385, 32, 'Úzkost'),
(114537, 386, 32, 'Libovolný'),
(114538, 387, 32, 'Libovolná kategorie'),
(114539, 388, 32, 'Libovolná část požadovaného  kódu nebo jeho popis'),
(114540, 389, 32, 'Libovolná část požadované specializace'),
(114541, 390, 32, 'Libovolná část ID nebo názvu léčiva'),
(114542, 391, 32, 'Libovolná část ID nebo názvu očkování'),
(114543, 392, 32, 'Libovolná část  jména pacienta, nebo "poslední, první, nebo "X-Y"'),
(114544, 393, 32, 'Jakákoliv jiná relevantní infotrmace'),
(114545, 394, 32, 'Klíč API pro SMS bránu'),
(114546, 395, 32, 'Apnoe'),
(114547, 396, 32, 'Vzhled'),
(114548, 397, 32, 'Vzhled:'),
(114549, 398, 32, 'Přidat tuto poznámku'),
(114550, 399, 32, 'Přidat k existující poznámce'),
(114551, 400, 32, 'Přidat do této poznámky'),
(114552, 401, 32, 'Přidat do této poznámky'),
(114553, 402, 32, 'Appendektomie'),
(114554, 403, 32, 'Appendektomie'),
(114555, 404, 32, 'Vybraní pacienti'),
(114556, 405, 32, 'Program'),
(114557, 406, 32, 'Název programu  pro přihlašovací stránku a název hlavního okna'),
(114558, 407, 32, 'Příjmový kód aplikace ( GS03 - pokud nebude zadáno, bude použit ISA08 )'),
(114559, 408, 32, 'Kód odesílatele aplikace  (GS02)'),
(114560, 409, 32, 'Název aplikace'),
(114561, 410, 32, 'Použitelné na formuláři vitálních funkcí a růstových grafech'),
(114562, 411, 32, 'Použitelné na formuláři vitálních funkcí'),
(114563, 412, 32, 'Aplikovat změny pouze na  aktuální událost, aktuální a všechny budoucí výskyty nebo na všechny výskyty ?'),
(114564, 413, 32, 'aplikovat na postiženou oblast'),
(114565, 414, 32, 'aplikovat na kůži'),
(114566, 415, 32, 'Aplikace'),
(114567, 416, 32, 'Aplikuji  záplatu'),
(114568, 417, 32, 'Návštěva'),
(114569, 418, 32, 'Datum návštěvy'),
(114570, 419, 32, 'Zobrazení návštěvy'),
(114571, 420, 32, 'Pavidlo připomenutí návštěvy'),
(114572, 421, 32, 'Stav návštěvy'),
(114573, 422, 32, 'Stavy návštěv'),
(114574, 423, 32, 'Příjem v období mezi'),
(114575, 424, 32, 'Barva příjmu / události'),
(114576, 425, 32, 'Návštěvy'),
(114577, 426, 32, 'Návštěvy ( volitelné právo zápisu )'),
(114578, 427, 32, 'Návštěvy ( právo zápisu, úplné/částečné )'),
(114579, 430, 32, 'Návštěvy  a vyšetření'),
(114580, 431, 32, 'Report návštěv'),
(114581, 432, 32, 'Návštěvy - vyšetření report'),
(114582, 434, 32, 'Povolit'),
(114583, 435, 32, 'Povolit pacienta z Pacien/Klient ->Import-> Nevyřízená povolení'),
(114584, 436, 32, 'Potvrzeno'),
(114585, 437, 32, 'Správa schválených akcí'),
(114586, 438, 32, 'Úspěšně povoleno'),
(114587, 440, 32, 'Náv - Vyš'),
(114588, 441, 32, 'Návš.'),
(114589, 442, 32, 'Duben'),
(114590, 443, 32, 'Duben'),
(114591, 444, 32, 'Arabský'),
(114592, 445, 32, 'Aragonský'),
(114593, 446, 32, 'Archiv'),
(114594, 447, 32, 'Jsou přeloženy názvy skupin pro kontroly přístupu ?'),
(114595, 448, 32, 'jsou názvy kategorií příjmů k překladu ?'),
(114596, 449, 32, 'Jsou názvy kategorií dokumentů k překladu ?'),
(114597, 450, 32, 'Jsou definovány polpatky pro tento typ ?'),
(114598, 451, 32, 'Jsou názvy poznámek k pacientovi přeloženy ?'),
(114599, 452, 32, 'jsou kódy uloženy v externích SQL tabulkách (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(114600, 453, 32, 'Jste připraveni  dokončit novou GCAG kategorii pro tuto návštěvu ?'),
(114601, 454, 32, 'Jste připraveni k odeslání za dnešek ?'),
(114602, 455, 32, 'Chcete potvrdit tyto akce ?'),
(114603, 457, 32, 'Opravdu chcete kompletně smazat tento formulář ?'),
(114604, 458, 32, 'Jste si jisti smazáním ?'),
(114605, 459, 32, 'Jste si jiti smazáním této položky ?'),
(114606, 460, 32, 'Opravdu chcete smazat tuto událost ?'),
(114607, 461, 32, 'Opravdu chcete smazat tuto položku z databáze ?'),
(114608, 462, 32, 'Opravdu chcete smazat tuto poznámku ?'),
(114609, 464, 32, 'Opravdu chcete upravit tyto události ?'),
(114610, 465, 32, 'Opravdu chcete skrýt tyto události ?'),
(114611, 466, 32, 'Jste si jisti opětovným přenosem ?'),
(114612, 467, 32, 'Opravdu chcete prohlížet tyto události ?'),
(114613, 468, 32, 'Jste si jisti, že chcete odstranit celou skupinu s tímto názvem'),
(114614, 469, 32, 'Opravdu chcete smazat celý seznam ?'),
(114615, 470, 32, 'Opravdu chcete smazat pole v'),
(114616, 471, 32, 'Opravdu chcete smazat vybraná pole ?'),
(114617, 472, 32, 'Opravdu chcete pokračovat v těchto činnostech ?'),
(114618, 473, 32, 'Oblast není upřesněna'),
(114619, 474, 32, 'Paže'),
(114620, 475, 32, 'Arménský'),
(114621, 477, 32, 'Arytmie'),
(114622, 478, 32, 'Arthritis'),
(114623, 479, 32, 'Arthritis / degenartivní kloubní postižení');
INSERT INTO `lang_definitions` VALUES
(114624, 480, 32, 'Arthritis / degenartivní kloubní postižení'),
(114625, 481, 32, 'jak'),
(114626, 483, 32, 'ACS'),
(114627, 484, 32, 'Asijský'),
(114628, 485, 32, 'Asamský'),
(114629, 487, 32, 'Zhodnocení'),
(114630, 488, 32, 'Přidelění'),
(114631, 489, 32, 'Asistent'),
(114632, 490, 32, 'Asthma bronchiale'),
(114633, 491, 32, 'v'),
(114634, 492, 32, 'Při výběru všech položek je vyžadován alespoň jeden vyhledávací parametr'),
(114635, 493, 32, 'Na os naviculare'),
(114636, 494, 32, 'Na os naviculare'),
(114637, 495, 32, 'Atletický tým'),
(114638, 496, 32, 'Atletický tým'),
(114639, 497, 32, 'Atletický/Úraz'),
(114640, 498, 32, 'CA certifikát ANTA auditu'),
(114641, 499, 32, 'ANTA audit host'),
(114642, 500, 32, 'Lokální certifikát ANTA auditu'),
(114643, 501, 32, 'Port ANTA auditu'),
(114644, 503, 32, 'Výstraha'),
(114645, 504, 32, 'Výstraha'),
(114646, 506, 32, 'Audit požadavků na CDR'),
(114647, 509, 32, 'Audit logování záloh'),
(114648, 510, 32, 'Audit logování různých'),
(114649, 511, 32, 'Audit logování příkazů'),
(114650, 512, 32, 'Audit logování záznamů pacienta'),
(114651, 513, 32, 'Audit logování plánování'),
(114652, 514, 32, 'Audit logování správy zabezpečení'),
(114653, 515, 32, 'Audit logování vybrané položky'),
(114654, 516, 32, 'Srp'),
(114655, 517, 32, 'Srpen'),
(114656, 519, 32, 'Aut.'),
(114657, 520, 32, 'Aut./poznámky'),
(114658, 523, 32, 'Autorizační skupina'),
(114659, 524, 32, 'Stav autorizace'),
(114660, 525, 32, 'Autorizace'),
(114661, 526, 32, 'Autorizovat'),
(114662, 527, 32, 'Autorizovat - jakékoliv návštěvy'),
(114663, 528, 32, 'Autorizovat - moje návštěvy'),
(114664, 529, 32, 'Authorize.net'),
(114665, 530, 32, 'Autorizováno'),
(114666, 531, 32, 'Pouze autorizováno'),
(114667, 532, 32, 'Automatické odeslání'),
(114668, 535, 32, 'Auto - vytvoření nového vyšetření'),
(114669, 536, 32, 'Automaticky generováno'),
(114670, 537, 32, 'Automatizované měřící výpočty ( AMC )'),
(114671, 538, 32, 'Automatizované měřící výpočty ( AMC ) - 2011'),
(114672, 539, 32, 'Automatizované měřící výpočty ( AMC ) - 2014'),
(114673, 542, 32, 'Automatizované měřící výpočty ( AMC ) Sledování'),
(114674, 543, 32, 'Automatizované měření (AMC)'),
(114675, 544, 32, 'Automatický'),
(114676, 546, 32, 'Automaticky vytvořit novou návštěvu pokud je  status návštěvy nastaven na "@" (dostavil se)'),
(114677, 550, 32, 'Automaticky uloženo'),
(114678, 551, 32, 'Dostupné kategorie'),
(114679, 552, 32, 'Dostupné časy'),
(114680, 553, 32, 'Dostupné stopy'),
(114681, 554, 32, 'Avarský'),
(114682, 556, 32, 'Avestan'),
(114683, 557, 32, 'Měsíční průměr'),
(114684, 558, 32, 'Avulze / Avulzní zlomenina'),
(114685, 559, 32, 'Avulze laterálního kotníku'),
(114686, 560, 32, 'Avulze mediálního kotníku '),
(114687, 562, 32, 'Axilární'),
(114688, 563, 32, 'Aymara'),
(114689, 564, 32, 'Azerbaijani'),
(114690, 565, 32, 'dvakrát denně'),
(114691, 566, 32, 'Zpět'),
(114692, 567, 32, 'Zpět'),
(114693, 568, 32, '9 návštěv zpět'),
(114694, 569, 32, '11 návštěv zpět'),
(114695, 570, 32, '5 návštěv zpět'),
(114696, 571, 32, '4 návštěvy zpět'),
(114697, 572, 32, '9 návštěv zpět'),
(114698, 573, 32, '1 návštěva zpět'),
(114699, 574, 32, 'Bolest zad'),
(114700, 575, 32, 'Vertebrogenní obtíže'),
(114701, 576, 32, '7 návštěv zpět'),
(114702, 577, 32, '6 návštěv zpět'),
(114703, 578, 32, 'Spinální chirurgie'),
(114704, 579, 32, '10 návštěv zpět'),
(114705, 580, 32, '3 návštěvy zpět'),
(114706, 581, 32, 'Sptátky na stránku administrace'),
(114707, 583, 32, 'Zpět k pacientovi'),
(114708, 584, 32, 'Zpět k pacientovi'),
(114709, 585, 32, 'Zpět k uživateli'),
(114710, 586, 32, 'Zpět na zobrazení'),
(114711, 587, 32, '12 návštěv zpět'),
(114712, 588, 32, '2 návštěvy zpět'),
(114713, 589, 32, 'Služby na pozadí'),
(114714, 590, 32, 'Záloha'),
(114715, 591, 32, 'Záloha byla vytvořena je k dispozici ke stažení'),
(114716, 592, 32, 'Seznam záloh'),
(114717, 593, 32, 'Záloha úspěšně přijata'),
(114718, 594, 32, 'Chybné ověření'),
(114719, 595, 32, 'Chybná pohledávka'),
(114720, 596, 32, 'Bahasa Indonesia'),
(114721, 597, 32, 'Vyváženost'),
(114722, 598, 32, 'Rovnováha'),
(114723, 599, 32, 'rovnováha'),
(114724, 600, 32, 'Zůstatek množství'),
(114725, 601, 32, 'Debetové saldo'),
(114726, 602, 32, 'Bambara'),
(114727, 604, 32, 'Štítek s čárovým kódem'),
(114728, 605, 32, 'Typ štítku čárového kódu'),
(114729, 606, 32, 'Typ čárového kódu pro tisk štítků z vyskakovacího okna vlevo'),
(114730, 607, 32, 'Base pátého matatarsu'),
(114731, 608, 32, 'Base pátého metatarsu:'),
(114732, 609, 32, 'Bashkir'),
(114733, 610, 32, 'Basque'),
(114734, 611, 32, 'hromadný požadavek'),
(114735, 612, 32, 'Nástroj hromadníé komunikace'),
(114736, 613, 32, 'Hromadný platební příkaz'),
(114737, 614, 32, 'Hromadné platby'),
(114738, 615, 32, 'Dávková zpracování zahájeno. Může to chvíli trvat.'),
(114739, 616, 32, 'Hromadné výsledky'),
(114740, 617, 32, 'BatchCom'),
(114741, 618, 32, 'Počkejte  prosím, některé soubory vyžadují delší zpracování'),
(114742, 619, 32, 'Protože toto ID neexistuje'),
(114743, 620, 32, 'Začátek'),
(114744, 621, 32, 'Počáteční datum'),
(114745, 623, 32, 'Datum zahájení služby RRRR-MM-DD'),
(114746, 624, 32, 'Počáteční hodina dne v kalendáři'),
(114747, 625, 32, 'Belarusian'),
(114748, 626, 32, 'Belching'),
(114749, 628, 32, 'Bengali'),
(114750, 629, 32, 'Bengali- Bangla'),
(114751, 630, 32, 'mezi'),
(114752, 631, 32, 'Obousměrný'),
(114753, 632, 32, 'Bihari'),
(114754, 633, 32, 'Bilaterálně'),
(114755, 634, 32, 'Bilaterálně:'),
(114756, 636, 32, 'Datum zúčtování'),
(114757, 638, 32, 'Zaúčtováno'),
(114758, 640, 32, 'Účtování'),
(114759, 641, 32, 'Účtování ( volitelné právo zápisu)'),
(114760, 644, 32, 'Účetní kód pro požadovanou položku'),
(114761, 645, 32, 'Účetní kódy'),
(114762, 646, 32, 'Účetní data'),
(114763, 647, 32, 'Účetní oddělení'),
(114764, 648, 32, 'Účetní jednotka'),
(114765, 649, 32, 'Účetní informace'),
(114766, 650, 32, 'Účetní místo'),
(114767, 655, 32, 'Účetní manažer'),
(114768, 656, 32, 'Účetní poznámka'),
(114769, 657, 32, 'Účetní poznámka pro '),
(114770, 658, 32, 'Účetní poznámka'),
(114771, 660, 32, 'Účetní report'),
(114772, 661, 32, 'Účetní status'),
(114773, 662, 32, 'Účetní status=Nezaúčtováno'),
(114774, 663, 32, 'Účtováno do '),
(114775, 665, 32, 'Biopsie'),
(114776, 666, 32, 'Datum narození'),
(114777, 667, 32, 'Narození-24 měsíců'),
(114778, 668, 32, 'Bislama'),
(114779, 669, 32, 'Černý'),
(114780, 670, 32, 'Antrakóza'),
(114781, 671, 32, 'Černoch nebo Afroameričan'),
(114782, 672, 32, 'Ca močového měchýře'),
(114783, 673, 32, 'Infekce močového měchýře'),
(114784, 674, 32, 'Prázdné formuláře'),
(114785, 675, 32, 'Krvácivé projevy'),
(114786, 676, 32, 'Krevní skvrny'),
(114787, 677, 32, 'Meteorismus'),
(114788, 678, 32, 'Blokováno'),
(114789, 679, 32, 'Krev'),
(114790, 680, 32, 'Krevní tlak'),
(114791, 681, 32, 'Krevní tlak'),
(114792, 682, 32, 'Krvácení z nosu'),
(114793, 684, 32, 'Modré řádky v tomto reportu jsou pouze informativní. Černé řádky zobrazují již dříve existující informace. Zeleně jsou označeny úspěšně aplikované změny. Červeně jsou označeny chyby nebo změny, které se nepodařilo aplikovat ( tyto musí být zpracovány manuálně). Aktuálně odmítnuté požadavky nejsou zahrnuté automaticky a proto jsou označeny červeně.'),
(114794, 685, 32, 'Rozmazaný vizus'),
(114795, 686, 32, 'BMI'),
(114796, 687, 32, 'BMI status'),
(114797, 689, 32, 'Oblast těla'),
(114798, 690, 32, 'Strana těla'),
(114799, 691, 32, 'Strana těla, pokud je potřeba.'),
(114800, 692, 32, 'Kostní bolestivost'),
(114801, 693, 32, 'Kostní bolestivost: Mediální malleolus'),
(114802, 694, 32, 'Boolean'),
(114803, 695, 32, 'Bosnian'),
(114804, 697, 32, 'Obě uši'),
(114805, 698, 32, 'obě uši'),
(114806, 699, 32, 'Dole'),
(114807, 700, 32, 'Dolní hranice (px)'),
(114808, 701, 32, 'BOX 10 A. ve vztahu k zaměstnání '),
(114809, 702, 32, 'BOX 10 B. Autohavárie '),
(114810, 703, 32, 'BOX 10 C. Jiná nehoda '),
(114811, 704, 32, 'BOX 14 kvalifikátor data'),
(114812, 705, 32, 'BOX 15 jiný kvalifikátor data'),
(114813, 706, 32, 'BOX 15. Datum shodného nebo podobného onemocnění (rrrr-mm-dd):'),
(114814, 707, 32, 'BOX 15. Datum shodného nebo podobného onemocnění/jiné datum (rrrr-mm-dd):'),
(114815, 708, 32, 'Pracovní neschopnost od (rrrrr-mm-dd)'),
(114816, 709, 32, 'Pracovní neschopnost do (rrrrr-mm-dd)'),
(114817, 710, 32, 'BOX 18. Datum hospitalizace od (rrrr-mm-dd): '),
(114818, 711, 32, 'BOX 18. Datum hospitalizace do (rrrr-mm-dd): '),
(114819, 712, 32, 'BOX 20. Je použita externí laboratoř ?'),
(114820, 713, 32, 'BOX 22. Kód ICD-9 '),
(114821, 714, 32, 'BOX 23. Číslo přednostní autorizace '),
(114822, 715, 32, 'TK'),
(114823, 716, 32, 'TK diastolický'),
(114824, 717, 32, 'TK systolický'),
(114825, 719, 32, 'TKd'),
(114826, 721, 32, 'TKs'),
(114827, 722, 32, 'Brazilská portugalština'),
(114828, 723, 32, 'Prsa'),
(114829, 724, 32, 'Biopsie prsu'),
(114830, 725, 32, 'Výtok z prsní bradavky'),
(114831, 726, 32, 'Onemocnění prsu'),
(114832, 727, 32, 'Vyšetření prsu'),
(114833, 728, 32, 'Hmotnost prsu'),
(114834, 730, 32, 'Dechové akustické fenomeny'),
(114835, 731, 32, 'Breton'),
(114836, 732, 32, 'Kostní zlomeniny'),
(114837, 733, 32, 'poškozený formulář'),
(114838, 734, 32, 'Bronchiální formulář'),
(114839, 735, 32, 'Procházet'),
(114840, 736, 32, 'Vyhledat záznam'),
(114841, 737, 32, 'Podlitina/hemathom'),
(114842, 738, 32, 'Bulharský'),
(114843, 739, 32, 'Prominující doprava:'),
(114844, 740, 32, 'Barmský'),
(114845, 741, 32, 'Pálení při močení'),
(114846, 742, 32, 'Pálení při močení'),
(114847, 743, 32, 'Telefon do zaměstnání'),
(114848, 744, 32, 'Zaneprázněn'),
(114849, 745, 32, 'ale dosud není zpracováno'),
(114850, 746, 32, 'Hýždě'),
(114851, 747, 32, 'Hýždě + SIS'),
(114852, 748, 32, 'kým / čím'),
(114853, 749, 32, 'kým / čím'),
(114854, 750, 32, 'per os'),
(114855, 753, 32, 'C'),
(114856, 754, 32, 'CA certifikát pro verifikaci  RFC 5425 TLS syslog serveru'),
(114857, 755, 32, 'časový cyklus pro cache ( sekundy)'),
(114858, 756, 32, 'Cache template výstup'),
(114859, 757, 32, 'Spotřeba kofeinu'),
(114860, 758, 32, 'Kalendář'),
(114861, 759, 32, 'Poslední hodina kalendáře'),
(114862, 760, 32, 'Kalendářní období'),
(114863, 761, 32, 'Obrazovka kalendáře'),
(114864, 762, 32, 'Nastavení kalendáře'),
(114865, 763, 32, 'První hodina kalendáře'),
(114866, 764, 32, 'Uživatelské rozhraní kalendáře'),
(114867, 765, 32, 'Zobrazení kalendáře'),
(114868, 767, 32, 'Kalorie'),
(114869, 768, 32, 'Kambodžský'),
(114871, 774, 32, 'Zrušit'),
(114872, 775, 32, 'Zrušit změny'),
(114873, 776, 32, 'Zrušeno'),
(114874, 777, 32, 'Onkol. onemocnění'),
(114875, 778, 32, 'Onkologický screening: Screenning Ca tlustého střeva'),
(114876, 779, 32, 'Onkologický screening: Mammograf'),
(114877, 780, 32, 'Onkologický screening: Výtěr z krku'),
(114878, 781, 32, 'Onkologický screening: Screenning Ca prostaty'),
(114879, 782, 32, 'Nelze přidat položku , protože již existuje'),
(114880, 783, 32, 'Nelze přidat/aktualizovat položku z důvodu existence duplikátu'),
(114881, 784, 32, 'Nelze archivovat, ignorováno.'),
(114882, 785, 32, 'Nelze převést do JPEG, protože ImageMagick není instalováno'),
(114883, 786, 32, 'Nelze smazat, ignorováno'),
(114884, 787, 32, 'Nelze zobrazit v řadě za sebou, protože typ není podporován prohlížečem'),
(114885, 788, 32, 'Nelze zobrazit v řadě za sebou, protože typ není podporován prohlížečem'),
(114886, 789, 32, 'Nelze zobrazit v řadě za sebou, protože typ není podporován prohlížečem'),
(114887, 790, 32, 'Nelze vytvořit'),
(114888, 791, 32, 'Nelze vytvořit soubor'),
(114889, 792, 32, 'Nelze smazat (from SFTP server) soubor'),
(114890, 793, 32, 'Nelze smazat soubor'),
(114891, 794, 32, 'nelze určit jméno cílového souboru'),
(114892, 795, 32, 'Nelze nalézt '),
(114893, 796, 32, 'Nelze nalézt cílový soubor'),
(114894, 799, 32, 'Nelze najít pacienta z SQL-Ledger customer id'),
(114895, 800, 32, 'Nelze najít odkaz na postcrip dokument v '),
(114896, 801, 32, 'Nelze najít poskytovatele z SQL-Ledger zaměstnanci '),
(114897, 802, 32, 'Nelze modifikovat platbu . Bilance je negativní'),
(114898, 803, 32, 'Nelze otevřít '),
(114899, 804, 32, 'Nelze odeslat ke zpracování pojištění. Plátce je pacient'),
(114900, 805, 32, 'Nelze odeslat . Plátcem je pojišťovna.'),
(114901, 806, 32, 'Nelze odeslat platbu . Bilance je nagativní.'),
(114902, 807, 32, 'Nelze přečíst'),
(114903, 808, 32, 'Nelze vstoupit do adresáře'),
(114904, 809, 32, 'Nelze aktualizovat, protože editujete neexistující položku !'),
(114905, 810, 32, 'Velká písmena'),
(114906, 811, 32, 'Vše vekým písmem'),
(114907, 812, 32, 'capsula'),
(114908, 813, 32, 'Karta'),
(114909, 814, 32, 'Srdeční katetrizace'),
(114910, 815, 32, 'Echokardiografie'),
(114911, 816, 32, 'Kardiovaskulární'),
(114912, 821, 32, 'Chrupavka / chondrální / diskopathie'),
(114913, 822, 32, 'Poranění chrupavky'),
(114914, 823, 32, 'Pulsace karotid  v normě, pulsace a.dorsalis pedis v normě'),
(114915, 824, 32, 'Hotovost'),
(114916, 825, 32, 'Hotovost'),
(114917, 826, 32, 'Příjem hotovosti'),
(114918, 827, 32, 'Hotovost přijatá poskytovatelem'),
(114919, 828, 32, 'Catalan- Valencian'),
(114920, 829, 32, 'Operace šedého zákalu'),
(114921, 830, 32, 'Šedý zákal'),
(114922, 831, 32, 'Kategorie'),
(114923, 832, 32, 'Kategorie pro'),
(114924, 833, 32, 'Kategorie'),
(114925, 834, 32, 'kategorie'),
(114926, 835, 32, 'Kategorie '),
(114927, 836, 32, 'Detaily kategorie'),
(114928, 837, 32, 'Limity kategorie'),
(114929, 838, 32, 'Název kategorie'),
(114930, 839, 32, 'Chybí název kategorie'),
(114931, 840, 32, 'Kategorie/Název'),
(114932, 841, 32, 'Kavkazský'),
(114933, 846, 32, 'CCR souhlas'),
(114934, 847, 32, 'CCR přehled pacienta'),
(114935, 848, 32, 'CCR přehled and schválení pacienta'),
(114936, 850, 32, 'CDR'),
(114937, 851, 32, 'Priorita zprcování CDR reportu'),
(114938, 852, 32, 'Buňka'),
(114939, 853, 32, 'Mobilní telefon'),
(114940, 854, 32, 'Číslo mobilního telefonu'),
(114941, 855, 32, 'Číslo mobilního telefonu'),
(114942, 856, 32, 'Centrální certifikace'),
(114943, 857, 32, 'Centrální/Jižní Amerika'),
(114944, 858, 32, 'CRT soubor  certifikaqční autority nemůže být prázdný'),
(114945, 859, 32, 'Soubor s klíčem certifikační autority nemůže být prázdý'),
(114946, 860, 32, 'Certifikát k odeslání  na RFC 5425 TLS syslog server'),
(114947, 861, 32, 'Uživatel certifikátu'),
(114948, 862, 32, 'Certifikáty'),
(114949, 863, 32, 'Chamorro'),
(114950, 864, 32, 'ChampUS'),
(114951, 865, 32, 'ChampUSVA'),
(114952, 866, 32, 'Změna'),
(114953, 867, 32, 'Změna'),
(114954, 868, 32, 'Změnit aktivitu'),
(114955, 869, 32, 'Zněna selhala! Nelze se připojit ke CouchDB'),
(114956, 870, 32, 'Zraková změna'),
(114957, 871, 32, 'Zraková změna'),
(114958, 872, 32, 'Změn hesla'),
(114959, 874, 32, 'Změněno'),
(114960, 875, 32, 'Změny na tračníku'),
(114961, 876, 32, 'Změna ID pacienta pro dokument'),
(114962, 877, 32, 'Vlastnosti'),
(114963, 878, 32, 'Zbývá znaků'),
(114964, 879, 32, 'Poplatek'),
(114965, 880, 32, 'Přizpůsobení platby'),
(114966, 881, 32, 'Zakódovaná platba'),
(114967, 882, 32, 'Poplatky'),
(114968, 883, 32, 'Graf'),
(114969, 884, 32, 'Graf aktivity'),
(114970, 886, 32, 'Graf ID'),
(114971, 887, 32, 'Graf ID:'),
(114972, 888, 32, 'Štítek grafu'),
(114973, 889, 32, 'Graf umístění a aktivit'),
(114974, 890, 32, 'Graf poznámka'),
(114975, 891, 32, 'Číslo grafu'),
(114976, 892, 32, 'Graf umístění úložišť'),
(114977, 897, 32, 'Čečenský'),
(114978, 898, 32, 'Zkontrolovat'),
(114979, 899, 32, 'Zkontrolovat'),
(114980, 900, 32, 'Zkontrolovat vše'),
(114981, 902, 32, 'Zkontrolovat množství'),
(114982, 903, 32, 'Zkontrolovat datum'),
(114983, 904, 32, 'Zkontrolujte rozdíly v překladu podle uživatelské tabulky překladu'),
(114984, 907, 32, 'Zkontrolujte vstupní data'),
(114985, 908, 32, 'Zkontrolujte položky pro zobrazení grafem'),
(114986, 909, 32, 'Zkontrolujte  laboratorní výsledky'),
(114987, 910, 32, 'Zkontrolujte položky označené jako prohlédnuté'),
(114988, 911, 32, 'Zkontrolujte číslo'),
(114989, 912, 32, 'Zkontrolujte číslo'),
(114990, 915, 32, 'Zkontrolujte platbu'),
(114991, 916, 32, 'Zaškrtněte pole, pokud se jedná o zašifrovaný soubor'),
(114992, 917, 32, 'Zaškrtněte, pokud chcete, aby poskytovatelé viděli všechny události ve výchozím nastavení a ne jen v jejich vlastním.'),
(114993, 918, 32, 'Zaškrtněte k vytvoření problému z této diagnózy'),
(114994, 923, 32, 'Seznam zaškrtávacích polí'),
(114995, 924, 32, 'Seznam zaškrtávacích polí'),
(114996, 927, 32, 'Výše zobrazená zaškrtávací pole pro odmítnutí nebo smazání HL7 souboru.'),
(114997, 928, 32, 'Označeno'),
(114998, 929, 32, 'Označené pole = ano, prázdné = ne'),
(114999, 931, 32, 'Uzamčení pole  zabrání dalším úpravám formulářů této události'),
(115000, 933, 32, 'Kontrolní součet'),
(115001, 934, 32, 'Hrudník'),
(115002, 935, 32, 'auskultace hrudníku'),
(115003, 936, 32, 'Bolest na hrudi'),
(115004, 937, 32, 'Bolest na hrudi:'),
(115005, 938, 32, 'Bolesti na hrudi'),
(115006, 940, 32, 'Změna'),
(115007, 941, 32, 'Chichewa- Chewa- Nyanja'),
(115008, 942, 32, 'Hlavní obtíže'),
(115009, 943, 32, 'Dítě'),
(115010, 945, 32, 'Dosavadní očkování'),
(115011, 946, 32, 'zimnice'),
(115012, 947, 32, 'Čínský'),
(115013, 948, 32, 'Čínština ( Zjednodušená )'),
(115014, 949, 32, 'Čínština ( Tradiční )'),
(115015, 950, 32, 'chiropraxe'),
(115016, 951, 32, 'Možnosti'),
(115017, 952, 32, 'Cholecystektomie'),
(115018, 953, 32, 'Cholecystektomie'),
(115019, 954, 32, 'Cholecystektomie'),
(115020, 955, 32, 'Zvolit'),
(115021, 956, 32, 'Vyberte si oddíl a klepněte na položku v něm; pak v druhé části uvidíte zvýrazněné související položky. Můžete pak  v tomto oddíle přidávat a odstraňovat vztahy.'),
(115022, 957, 32, 'Zvolte kriteria'),
(115023, 958, 32, 'Zvolte stahování nebo zobrazení za sebou'),
(115024, 959, 32, 'vyberte soubor'),
(115025, 960, 32, 'Vyberte ze seznamu'),
(115026, 961, 32, 'Vyberte směr rozvržení'),
(115027, 962, 32, 'Vyberte seznam'),
(115028, 963, 32, 'Vyberte velikost papíru'),
(115029, 964, 32, 'Zvolte preferovaný jazyk pro PDF'),
(115030, 965, 32, 'Zvolte tiskový formát pro tisk tohoto vyšetření'),
(115031, 967, 32, 'Chronická bronchitis'),
(115032, 968, 32, 'Chronické arthralgie'),
(115033, 969, 32, 'Chronické onemocnění ledvin'),
(115034, 970, 32, 'Chronická synovitis'),
(115035, 971, 32, 'Chronický/Rekurentní'),
(115036, 972, 32, 'Chuvash'),
(115037, 973, 32, 'Jaterní cirhosa'),
(115038, 974, 32, 'Jaterní cirhosa'),
(115039, 975, 32, 'Město'),
(115040, 976, 32, 'Název města'),
(115041, 977, 32, 'Město, Stát'),
(115042, 978, 32, 'Město, Stát, PSČ'),
(115043, 979, 32, 'město/Stát'),
(115044, 980, 32, 'Požadavek'),
(115045, 981, 32, 'Požadavek '),
(115046, 982, 32, 'Stav zpracování požadavku'),
(115047, 983, 32, 'Ukončen testovací požadavek'),
(115048, 984, 32, 'Typ požadavku'),
(115049, 985, 32, 'Požadavek byl vygenerován  do spisu'),
(115050, 986, 32, 'Požadavek byl vygenerován  do spisu '),
(115051, 987, 32, 'Požadavky'),
(115052, 988, 32, 'Klasifikace'),
(115053, 989, 32, 'Vymazat'),
(115054, 990, 32, 'Vyčistit data aktivního pacienta'),
(115055, 991, 32, 'Vymazat vše'),
(115056, 992, 32, 'Vymazat HL7 data'),
(115057, 993, 32, 'vyčistit odůvodnění'),
(115058, 994, 32, 'Vyčistit Smarty cache'),
(115059, 995, 32, 'Čistí se domovská informace pro dávku  EDI 270'),
(115060, 996, 32, 'Číslo CLIA'),
(115061, 997, 32, 'Kliknout'),
(115062, 998, 32, 'Klikněte na "export" pro export kategorie, podkategorie, položky, údaje o obsahu do textového souboru. Jakákoliv podobnost tohoto souboru s XML souborem, je čistě náhodná. Značky pro otevírání a zavírání musí být na stejném řádku, musí obsahovat malá písmena bez mezer. Chcete-li importovat, vyhledejte soubor a klikněte na "import". Pokud se jedná o zcela odlišná data, pak budou sloučena s  již existujícími daty. Pokud existují podobné názvy položek, bude staré názvy zachovány a nové uloženy  s  číslem na konci.'),
(115063, 999, 32, 'Klikem na obrázek přidáte novou poznámku, dalším klikem poznámku smažete'),
(115064, 1000, 32, 'Klikem na Stáhnout cerifikát stáhnete certifikát vsouboru ssl.zip'),
(115065, 1001, 32, 'Klikněte pro další'),
(115066, 1002, 32, 'Klikněte pro více podrobností'),
(115067, 1003, 32, 'Klikněte pro shrnutí objednávky'),
(115068, 1004, 32, 'Klikněte pro výsledky'),
(115069, 1005, 32, 'Klikněte zde'),
(115070, 1006, 32, 'Klikněte zde pro přidání nového pacienta'),
(115071, 1007, 32, 'Kikněte zde k zadání nového stavu úrazových změn a k editaci denních aktivit'),
(115072, 1008, 32, 'Klikněte zde a zvolte datum'),
(115073, 1009, 32, 'Klikněte zde a zvolte datum a čas'),
(115074, 1010, 32, 'Klikněte zde a zvole počáteční datum'),
(115075, 1011, 32, 'Klikněte zde pro volbu času a data'),
(115076, 1012, 32, 'Klikněte zde pro volbu času a data OD'),
(115077, 1013, 32, 'Klikněte zde pro volbu času a data DO'),
(115078, 1014, 32, 'Klikněte zde pro konfiguraci modulu'),
(115079, 1016, 32, 'Klikněte zde pro deaktivaci modulu'),
(115080, 1018, 32, 'Klikněte zde pro aktivaci modulu'),
(115081, 1019, 32, 'Klikněte zde pro instalaci modulu'),
(115082, 1020, 32, 'klikněte zde pro hledání'),
(115083, 1021, 32, 'klikněte zde k aktualizaci priorit, kategorie a přezdívky'),
(115084, 1022, 32, 'Klikněte zde pro zobrazení všech údajů'),
(115085, 1023, 32, 'Klikněte zde pro zobrazení a grafické znázornění'),
(115086, 1024, 32, 'Klikněte zde pro zobrazení a grafické znázornění laboratorních dat'),
(115087, 1025, 32, 'Klikněte zde pro zobrazení a grafické znázornění vitálních funkcí'),
(115088, 1026, 32, 'Klikněte zde pro zobrazení detailů pacienta'),
(115089, 1027, 32, 'Klikem zde zobrazíte všechny'),
(115090, 1028, 32, 'Klikněte zde pro zobrazení/úpravu podrobností'),
(115091, 1029, 32, 'Klikem na INSTALOVAT nainstalujete verzi databáze od následujícího data'),
(115092, 1030, 32, 'Klikněte na jakýkoliv časový úsek k jeho prodloužení'),
(115093, 1031, 32, 'Klikem na jméno pacienta otevřete jeho soubor'),
(115094, 1032, 32, 'Klikem na OBNOVIT zobrazíte všechny výsledky nebo zadejte vyhledávací kriteria pro podrobnější hledání'),
(115095, 1033, 32, 'Klikněte pro přidání diagnózy'),
(115096, 1034, 32, 'Klikem přidáte novou součást'),
(115097, 1035, 32, 'Klikem přidáte novou konzultaci'),
(115098, 1036, 32, 'Klikněte pro výber diagnózy'),
(115099, 1037, 32, 'Klikněte ke stažení'),
(115100, 1038, 32, 'Klikněte pro úpravy'),
(115101, 1039, 32, 'Klikněte pro úpravu popisu'),
(115102, 1040, 32, 'Klikněte pro úpravy této události'),
(115103, 1041, 32, 'Klikněte pro vygenerování zprávy'),
(115104, 1042, 32, 'Klikněte na odpovídajícího pacienta'),
(115105, 1043, 32, 'Klikněte pro tisk'),
(115106, 1044, 32, 'Klikněte pro získání ( přidání ) nového množství'),
(115107, 1045, 32, 'Klikněte pro výběr'),
(115108, 1046, 32, 'Klikněte pro výběr'),
(115109, 1047, 32, 'Klikněte pro výběr standardního kódu této procedury'),
(115110, 1048, 32, 'Klikněte pro výběr volitelného kódu této procedury'),
(115111, 1049, 32, 'Klikněte pro výběr nebo změnu kódování'),
(115112, 1050, 32, 'Klikněte pro výběr nebo změnu CVX kódu'),
(115113, 1051, 32, 'Klikněte pro výběr nebo změnu diagnózy'),
(115114, 1052, 32, 'Klikněte pro výběr nebo změnu kódů služby'),
(115115, 1053, 32, 'Klikněte pro výběr pacienta'),
(115116, 1054, 32, 'Klikněte pro výběr odpovídajícího kódu'),
(115117, 1055, 32, 'Klikněte pro výběr služeb k ověření abnormálních výsledků'),
(115118, 1056, 32, 'Klikněte pro výběr požadované procedury'),
(115119, 1057, 32, 'Klikněte pro seřazení'),
(115120, 1058, 32, 'Klikněte pro zobrazení'),
(115121, 1059, 32, 'Klikněte pro zobrazení nebo úpravy'),
(115122, 1060, 32, 'Klikněte pro zobrazení/úpravy'),
(115123, 1061, 32, 'Klikem na tlačítko AKTUALIZOVAT provedete upgrade databáze od následujícího data'),
(115124, 1062, 32, 'Klikněte výše pro označení odpovídajícího pacienta'),
(115125, 1063, 32, 'Klikněte:'),
(115126, 1064, 32, 'Zbývající dny do expirace klientského certifikátu'),
(115127, 1065, 32, 'Čas pro ověření klienstkého certifikátu'),
(115128, 1066, 32, 'Platnost klienteského certifikátu musí být platné číslo'),
(115129, 1067, 32, 'Kopie pro klienta'),
(115130, 1069, 32, 'Anamnestický souhrn klienta'),
(115131, 1070, 32, 'Jméno klienta'),
(115132, 1071, 32, 'Číslo klienta'),
(115133, 1072, 32, 'Profil klienta - Noví klienti'),
(115134, 1073, 32, 'Profil klienta - Unikátní klienti'),
(115135, 1074, 32, 'Klienti'),
(115136, 1075, 32, 'Klinika'),
(115137, 1076, 32, 'Kopie pro klienta'),
(115138, 1077, 32, 'Denní klinické záznamy'),
(115139, 1078, 32, 'ID kliniky'),
(115140, 1079, 32, 'Klinický'),
(115141, 1081, 32, 'Anamnéza'),
(115142, 1083, 32, 'Klinické plány'),
(115143, 1084, 32, 'Klinická měření kvality (CQM)'),
(115144, 1085, 32, 'Klinická měření kvality (CQM) - 2011'),
(115145, 1086, 32, 'Klinická měření kvality (CQM) - 2014'),
(115146, 1087, 32, 'Klinické upomínky'),
(115147, 1088, 32, 'Klinická hlášení'),
(115148, 1089, 32, 'Kategorie akcí klinických pravidel'),
(115149, 1090, 32, 'Položka akcí klinických pravidel'),
(115150, 1091, 32, 'Metoda filtrování pro klinická pravidla'),
(115151, 1092, 32, 'Cílová metoda klinických pravidel'),
(115152, 1093, 32, 'Klinická pravidla'),
(115153, 1094, 32, 'Věkový interval klinických pravidel'),
(115154, 1095, 32, 'Porovnání klinických pravidel'),
(115155, 1096, 32, 'Typy klinických pravidel vyšetření'),
(115156, 1102, 32, 'Klinické cíle'),
(115157, 1103, 32, 'Klinický termín'),
(115158, 1104, 32, 'Kódy klinických termínů'),
(115159, 1106, 32, 'klinický pracovník'),
(115160, 1107, 32, 'Vytvořit kopii'),
(115161, 1108, 32, 'Vytvořit kopii poslední návštěvy'),
(115162, 1109, 32, 'Zavřít'),
(115163, 1110, 32, 'Zavřít okno'),
(115164, 1111, 32, 'Zavřít okno'),
(115165, 1112, 32, 'Uzavřeno'),
(115166, 1113, 32, 'cm'),
(115167, 1114, 32, 'CMS 1500 Okraje'),
(115168, 1115, 32, 'CMS 1500 Formát papíru'),
(115169, 1116, 32, 'CMS 1500: BOX 31 Formát'),
(115170, 1117, 32, 'CMS 1500: Datum  v  BOXu 31 ( podpis)'),
(115171, 1118, 32, 'CMS ID'),
(115172, 1119, 32, 'CMS Portál'),
(115173, 1120, 32, 'Přihlášení do CMS Portál'),
(115174, 1121, 32, 'Přihlašovací ID CMS Portálu'),
(115175, 1122, 32, 'CMS Portál není zaveden !'),
(115176, 1123, 32, 'Heslo pro CMS Portál'),
(115177, 1124, 32, 'Požadavek pro CMS Portál'),
(115178, 1125, 32, 'Adresa stránky CMS Portálu'),
(115179, 1126, 32, 'uživatelské jméno CMS Portálu'),
(115180, 1127, 32, 'CN-12 intaktní'),
(115181, 1131, 32, 'Kód'),
(115182, 1132, 32, 'kód'),
(115183, 1133, 32, 'Vyhledávač kódu'),
(115184, 1134, 32, 'Kód je tvořen dvěma malými písmeny'),
(115185, 1135, 32, 'Kód nebo symbol měny'),
(115186, 1136, 32, 'Text kódu'),
(115187, 1137, 32, 'Typ kódu'),
(115188, 1138, 32, 'typ kódu'),
(115189, 1139, 32, 'Typ kódu nebyl rozpoznán'),
(115190, 1140, 32, 'Typ kódu nebyl dosud definován'),
(115191, 1141, 32, 'Typy kódu'),
(115192, 1142, 32, 'Kód (y)'),
(115193, 1143, 32, 'Kódováno'),
(115194, 1144, 32, 'Kódy'),
(115195, 1145, 32, 'Kódování'),
(115196, 1146, 32, 'Kódování ( kliknout pro vzdělávání )'),
(115197, 1147, 32, 'Kódování - libovolné vyšetření ( právo zápisu, vše/částečné)'),
(115198, 1148, 32, 'Kódování - moje vyšetření  ( právo zápisu, vše/částečné)'),
(115199, 1149, 32, 'Není oprávnění ke kódování'),
(115200, 1150, 32, 'Káva'),
(115201, 1151, 32, 'Užívání kávy'),
(115202, 1152, 32, 'Připojištění'),
(115203, 1153, 32, 'Zavřít'),
(115204, 1154, 32, 'Zavřít'),
(115205, 1155, 32, 'Zavřít'),
(115206, 1156, 32, 'Sbalit vše'),
(115207, 1157, 32, 'Sbalit vše'),
(115208, 1158, 32, 'Sbalit vše'),
(115209, 1160, 32, 'Datum sběru'),
(115210, 1161, 32, 'Sběry'),
(115211, 1163, 32, 'Ca tlustého střeva'),
(115212, 1164, 32, 'Screening Ca tlustého střeva'),
(115213, 1165, 32, 'Operace Ca tlustého střeva'),
(115214, 1166, 32, 'Kolonoskopie'),
(115215, 1167, 32, 'kolonoskopie'),
(115216, 1168, 32, 'Barva'),
(115217, 1170, 32, 'Sloupec'),
(115218, 1171, 32, 'Sloupce'),
(115219, 1173, 32, 'Čárka'),
(115220, 1174, 32, 'Komentář'),
(115221, 1175, 32, 'Komentáře'),
(115222, 1176, 32, 'Komentáře k tomuto výsledku nebo doporučení'),
(115223, 1177, 32, 'Komerční pojištění'),
(115224, 1178, 32, 'Potvrdit změny'),
(115225, 1179, 32, 'Komunikace'),
(115226, 1180, 32, 'Komunikace'),
(115227, 1182, 32, 'Podnik'),
(115228, 1183, 32, 'Jméno podniku'),
(115229, 1184, 32, 'Dokončit'),
(115230, 1186, 32, 'Dokončeno'),
(115231, 1188, 32, 'Dokončeno ?'),
(115232, 1190, 32, 'Komplikace na straně poskytovatele služby'),
(115233, 1191, 32, 'Komplikace při potratu'),
(115234, 1192, 32, 'Součásti'),
(115235, 1193, 32, 'Elektronické objednávky a žádanky'),
(115236, 1194, 32, 'Závěry'),
(115237, 1198, 32, 'Konfig'),
(115238, 1199, 32, 'Konfigurace'),
(115239, 1200, 32, 'Export/import konfigurace'),
(115240, 1201, 32, 'Konfigurace úspěšně uložena'),
(115241, 1202, 32, 'Nakonfigurujte Apache a LibreEHR pro použití klientských SSL certifikátů'),
(115242, 1203, 32, 'Nakonfigurujte Apache pro použití klientských SSL certifikátů'),
(115243, 1204, 32, 'Nakonfigurujte Apache pro použití HTTPS'),
(115244, 1205, 32, 'Nakonfigurujte LibreEHR pro použití klientských SSL certifikátů'),
(115245, 1208, 32, 'Potvrďte založení nového pacienta'),
(115246, 1209, 32, 'Potvrďte nové heslo'),
(115247, 1210, 32, 'Potvrďte platbu'),
(115248, 1214, 32, 'Kongenitální'),
(115249, 1215, 32, 'Spojivka, zornice'),
(115250, 1216, 32, 'Chyba spojení'),
(115251, 1217, 32, 'Konektory'),
(115252, 1218, 32, 'Konstanta'),
(115253, 1219, 32, 'Název konstanty'),
(115254, 1220, 32, 'Název konstanty je prázdný'),
(115255, 1221, 32, 'Konstanty'),
(115256, 1222, 32, 'Obstipace'),
(115257, 1223, 32, 'Konstituční'),
(115258, 1226, 32, 'Stručný popis konzultace'),
(115259, 1227, 32, 'Kontakt'),
(115260, 1228, 32, 'Kontaktní e-mail'),
(115261, 1229, 32, 'Kontaktní e-mailová adresa'),
(115262, 1230, 32, 'Kontaktujte přímo EMR k odběru služby phiMAil Direct messaging'),
(115263, 1231, 32, 'kontaktní informace'),
(115264, 1232, 32, 'Kontaktní čočky'),
(115265, 1233, 32, 'Contact Medical Information Integration, LLC at http://mi-squared.com for Lab Exchange Service.'),
(115266, 1234, 32, 'Contact Medical Information Integration, LLC at http://mi-squared.com or ZH Healthcare at http://zhservices.com for subscribing the eRx service'),
(115267, 1236, 32, 'Kontaktní jméno'),
(115268, 1237, 32, 'Kontaktní osoba'),
(115269, 1238, 32, 'Kontaktní telefon'),
(115270, 1239, 32, 'Kontaktní telefonní číslo'),
(115271, 1240, 32, 'Contact ZMG, LLC (zmghealth@gmail.com) for subscribing the eRx service'),
(115272, 1241, 32, 'obsahovat  minimálně 3 ze 4 následujících položek'),
(115273, 1242, 32, 'Název kontejneru - skupiny'),
(115274, 1243, 32, 'Obash'),
(115275, 1244, 32, 'obsah'),
(115276, 1245, 32, 'Kontaxt'),
(115277, 1246, 32, 'Kontextové jméno nemůže být prázdné'),
(115278, 1247, 32, 'Pokračovat'),
(115279, 1248, 32, 'Continuity of Care Document (CCD)'),
(115280, 1249, 32, 'Continuity of Care Record (CCR)'),
(115281, 1251, 32, 'Antikoncepce'),
(115282, 1253, 32, 'Komplikace antikoncepce ( k upřesnění )'),
(115283, 1254, 32, 'Metoda antikoncepce'),
(115284, 1255, 32, 'Antikoncepční produkty'),
(115285, 1257, 32, 'Antikoncepce od'),
(115286, 1258, 32, 'Kontrolní ID'),
(115287, 1259, 32, 'Kontrolní No.'),
(115288, 1261, 32, 'COPAY'),
(115289, 1262, 32, 'Copay'),
(115290, 1263, 32, 'CoPay'),
(115291, 1267, 32, 'CHOPN'),
(115292, 1268, 32, 'Zkopírovat stránky to grafu pacienta'),
(115293, 1269, 32, 'Kopírovat hodnoty'),
(115294, 1270, 32, 'Kopírování souboru databáze. To vyžaduje určitý čas.'),
(115295, 1271, 32, 'Upozornění na autorská práva'),
(115296, 1272, 32, 'Cornish'),
(115297, 1273, 32, 'Koronární bypass'),
(115298, 1274, 32, 'Aortokoronární bypass  (CABG)'),
(115299, 1275, 32, 'Opraveno'),
(115300, 1276, 32, 'Korsický'),
(115301, 1277, 32, 'CouchDB'),
(115302, 1278, 32, 'Chyba spojení s CouchDB'),
(115303, 1279, 32, 'CouchDB databáze'),
(115304, 1280, 32, 'Jméno CouchDB databáze'),
(115305, 1281, 32, 'CouchDB host'),
(115306, 1282, 32, 'Jméno hosta CouchDB databáze'),
(115307, 1283, 32, 'Logování CouchDB zapnuto'),
(115308, 1284, 32, 'Heslo CouchDB'),
(115309, 1285, 32, 'Port CouchDB'),
(115310, 1286, 32, 'CouchDB port'),
(115311, 1287, 32, 'Uložení CouchDB selhalo'),
(115312, 1288, 32, 'Uživatelské jméno CouchDB'),
(115313, 1289, 32, 'Kašel'),
(115314, 1290, 32, 'Kašel:'),
(115315, 1291, 32, 'nelze se připojit k serveru'),
(115316, 1293, 32, 'nelze otevřít tabulku'),
(115317, 1294, 32, 'Soubor nelze přečíst'),
(115318, 1295, 32, 'nelze číst soubor'),
(115319, 1296, 32, 'Problémy na serveru. E-mail nelze odeslat '),
(115320, 1297, 32, 'Mail nelze odeslat z důvodu chyby serveru '),
(115321, 1298, 32, 'Nelze vytvořit adresář pro zálohy'),
(115322, 1299, 32, 'Adresář nelze smazat'),
(115323, 1300, 32, 'Nelze smazat starý soubor zálohy'),
(115324, 1301, 32, 'Nelze smazat starý soubor exportu'),
(115325, 1302, 32, 'Coumadin Management - INR Monitoring'),
(115326, 1304, 32, 'Poradenství'),
(115327, 1305, 32, 'poradenské aktiivty'),
(115328, 1308, 32, 'Země'),
(115329, 1309, 32, 'Typ dat příslušné země'),
(115330, 1310, 32, 'Seznam zemí'),
(115331, 1311, 32, 'Seznam zemí ( na výběr právo zápisu vše/částečně )'),
(115332, 1312, 32, 'Jméno země by mělo být uvedeno dvěma písmeny. ( Příklad: United States - US)'),
(115333, 1313, 32, 'Okres'),
(115334, 1315, 32, 'poukázka'),
(115335, 1318, 32, 'Klinické vyšetření pacienta (KVP)'),
(115336, 1319, 32, 'Kód KVP'),
(115337, 1320, 32, 'KVP kódy'),
(115338, 1321, 32, 'CPT4 Procedure/Service'),
(115339, 1322, 32, 'CPTII Performance Measures'),
(115340, 1323, 32, 'Průběžné řízení jakosti (CQM)'),
(115341, 1324, 32, 'Trhlinky:'),
(115342, 1325, 32, 'krém'),
(115343, 1326, 32, 'Vytvořit klinetský certifikát SSL pro každé zařízení uživatele nebo klienta'),
(115344, 1327, 32, 'Vytvořit klinetský certifikát SSL pro každé jméno hosta uživatele nebo klienta'),
(115345, 1328, 32, 'vytvořit nové sledování'),
(115346, 1329, 32, 'Vytvořit událost'),
(115347, 1330, 32, 'Vytvořit a stáhnout kompletní zálohu'),
(115348, 1331, 32, 'Vytvořit a modifikovat sledování'),
(115349, 1332, 32, 'Vytvořit zálohu'),
(115350, 1333, 32, 'Vytvořit dávku'),
(115351, 1334, 32, 'Vytvořit klientský certifikát'),
(115352, 1335, 32, 'Vytvořit klinetský certifikát SSL'),
(115353, 1336, 32, 'Vytvořit kopii'),
(115354, 1337, 32, 'Vytvořit vyšetření'),
(115355, 1338, 32, 'Vytvořit zálohu protokolu událostí'),
(115356, 1339, 32, 'Založit nový problém'),
(115357, 1340, 32, 'Založit nového pacienta'),
(115358, 1341, 32, 'Vytvořit nové sledování'),
(115359, 1344, 32, 'Vytvořit poznámku k pacientovi'),
(115360, 1345, 32, 'Vytvořit SSL certifikační autoritu a serverové certifikáty'),
(115361, 1346, 32, 'Vytvořit návštěvu'),
(115362, 1347, 32, 'Vytvořeno'),
(115363, 1348, 32, 'Vytváří se soubor exportu'),
(115364, 1349, 32, 'Vytvoření nového sledování selhalo'),
(115365, 1350, 32, 'Vytvoření tohotou souboru u vzdáleného hosta selhalo'),
(115366, 1351, 32, 'Tvůrce'),
(115367, 1352, 32, 'kredit'),
(115368, 1353, 32, 'Kreditní karta'),
(115369, 1354, 32, 'Kredity'),
(115370, 1355, 32, 'Cree'),
(115371, 1356, 32, 'Kritéria'),
(115372, 1357, 32, 'Chorvatský'),
(115373, 1358, 32, 'Crohnova choroba'),
(115374, 1359, 32, 'Crohnova choroba'),
(115375, 1360, 32, 'CSV export'),
(115376, 1361, 32, 'CSV soubor'),
(115377, 1362, 32, 'CSv tabulky'),
(115378, 1363, 32, 'mm3'),
(115379, 1364, 32, 'Kubánský'),
(115380, 1365, 32, 'Desetinná místa měny'),
(115381, 1366, 32, 'Symbol pro oddělení desetinného místa  měny'),
(115382, 1367, 32, 'Symbol měny'),
(115383, 1368, 32, 'Oddělovač tisíců příslušné měny'),
(115384, 1369, 32, 'Aktuální'),
(115385, 1370, 32, 'Aktuální spotřeba alkoholu'),
(115386, 1371, 32, 'Aktuální konsultace'),
(115387, 1372, 32, 'Aktuální kriteria'),
(115388, 1373, 32, 'Barevné zvýraznění aktuálního dne'),
(115389, 1374, 32, 'Aktuálně pravidelný denní kuřák'),
(115390, 1375, 32, 'Aktuální jméno souboru bylo změněno na'),
(115391, 1376, 32, 'Aktuální haš'),
(115392, 1377, 32, 'Aktuální umístění'),
(115393, 1378, 32, 'Současná medikace'),
(115394, 1379, 32, 'Aktuální heslo'),
(115395, 1380, 32, 'Aktuální pacient'),
(115396, 1382, 32, 'Aktuální stav užívání rekreačních drog'),
(115397, 1383, 32, 'Aktuálně příležitosný kuřák'),
(115398, 1385, 32, 'Aktuální hodnota'),
(115399, 1386, 32, 'Aktuálně aktivní'),
(115400, 1387, 32, 'Aktuálně v běhu'),
(115401, 1388, 32, 'V tuto chvíli zde nejsou žádná zařízení'),
(115402, 1389, 32, 'Cushingův syndrom'),
(115403, 1390, 32, 'Cushingův syndrom'),
(115404, 1392, 32, 'Uživatelský'),
(115405, 1393, 32, 'Uživatelský vstup ?'),
(115406, 1394, 32, 'Uživatelská tabulka'),
(115407, 1396, 32, 'CVX Kód'),
(115408, 1397, 32, 'Mapování CVX kódu'),
(115409, 1398, 32, 'CVX imunizace'),
(115410, 1399, 32, 'cyklus'),
(115411, 1400, 32, 'CYP'),
(115412, 1401, 32, 'CYP faktor'),
(115413, 1402, 32, 'CYP hlášení'),
(115414, 1403, 32, 'Český'),
(115415, 1404, 32, 'D'),
(115416, 1405, 32, 'Dilatace a kyretáž'),
(115417, 1406, 32, 'Dieta a cvičení'),
(115418, 1407, 32, 'Datum narození'),
(115419, 1408, 32, 'denně'),
(115420, 1409, 32, 'Denní záznamy'),
(115421, 1410, 32, 'Dánský'),
(115422, 1411, 32, 'Podobné údaje jsoujiž v databázi, změňte prosím kód a / nebo popis'),
(115423, 1412, 32, 'Podobné údaje jsoujiž v databázi, změňte název konstanty'),
(115424, 1413, 32, 'datové sloupce'),
(115425, 1416, 32, 'Chyba dat'),
(115426, 1417, 32, 'Data z'),
(115427, 1420, 32, 'Typy dat'),
(115428, 1421, 32, 'Databáze'),
(115429, 1422, 32, 'Databáze není instalována'),
(115430, 1423, 32, 'Databázová záplata ( patch)'),
(115431, 1424, 32, 'Databázová hlášení'),
(115432, 1425, 32, 'Upgrade databáze úspěšný.'),
(115433, 1426, 32, 'Datové sloupce musí být číslem  mezi 1 a 999'),
(115434, 1427, 32, 'Datum'),
(115435, 1428, 32, 'Datum'),
(115436, 1429, 32, 'Datum a Čas spravovány'),
(115437, 1431, 32, 'Darum spravováno'),
(115438, 1432, 32, 'Datum a čas odběru vzorku'),
(115439, 1433, 32, 'Datum a čas pozorování'),
(115440, 1435, 32, 'Datum a čas získání vzorku'),
(115441, 1436, 32, 'Datum nemůže být  vyšší než dnešní'),
(115442, 1437, 32, 'Datum zahájení antikoncepce'),
(115443, 1438, 32, 'Datum vytvořeno'),
(115444, 1439, 32, 'Datum úmrtí'),
(115445, 1440, 32, 'Datum zničeno'),
(115446, 1441, 32, 'Formát zobrazení data'),
(115447, 1442, 32, 'Formát data pro "konec návštěvy" není platný'),
(115448, 1443, 32, 'Formát data pro "začátek návštěvy" není platný'),
(115449, 1444, 32, 'Formát data pro "příští návštěvu" není platný'),
(115450, 1445, 32, 'Formát data pro "dosud nepozorováno" není platný'),
(115451, 1446, 32, 'Formát data pro "pozorováno od" není platný'),
(115452, 1447, 32, 'Datum získání informací o stavu Imunizace'),
(115453, 1448, 32, 'Chybí datum pro tento kód '),
(115454, 1450, 32, 'Datum bankovního vkladu rrr-mm-dd'),
(115455, 1451, 32, 'Datum účtování'),
(115456, 1452, 32, 'Datum narození'),
(115457, 1453, 32, 'datum narození'),
(115458, 1454, 32, 'Datum narození'),
(115459, 1455, 32, 'Datum přístupu'),
(115460, 1456, 32, 'Datum úrazu'),
(115461, 1458, 32, 'datum platby rrr-mm-dd'),
(115462, 1459, 32, 'Datum odeslání'),
(115463, 1460, 32, 'Datum odpovědi'),
(115464, 1461, 32, 'Datum hlášení'),
(115465, 1462, 32, 'Datum služby'),
(115466, 1463, 32, 'Datum služby'),
(115467, 1464, 32, 'Datum služby = dnes'),
(115468, 1465, 32, 'Datum služby = mm/dd/rrrr'),
(115469, 1466, 32, 'Datum služby:'),
(115470, 1467, 32, 'Datum podpisu'),
(115471, 1468, 32, 'Datum změny  statutu'),
(115472, 1469, 32, 'Datum  tohoto nařízení'),
(115473, 1470, 32, 'Datum tohoto hlášení'),
(115474, 1474, 32, 'Výběr data'),
(115475, 1475, 32, 'Výběr data'),
(115476, 1476, 32, 'datum odesláno'),
(115477, 1477, 32, 'Datum, kdy byla zpráva odeslána'),
(115478, 1478, 32, 'datum čas'),
(115479, 1479, 32, 'Hodnoty data nemohou být prázdné'),
(115480, 1480, 32, 'Datum/Návšt'),
(115481, 1481, 32, 'Datum/Poznámky'),
(115482, 1483, 32, 'Datum/Čas'),
(115483, 1484, 32, 'Datum:'),
(115484, 1485, 32, 'Dated Message Log'),
(115485, 1486, 32, 'Den'),
(115486, 1487, 32, 'den'),
(115487, 1489, 32, 'Denní pohled'),
(115488, 1490, 32, 'Den ( dny)'),
(115489, 1491, 32, 'Den ( dny) Po-Pá'),
(115490, 1492, 32, 'dny'),
(115491, 1493, 32, 'Dny'),
(115492, 1494, 32, 'dny'),
(115493, 1495, 32, 'Dny a hry chybí'),
(115494, 1496, 32, 'Dnů od posledního vyšetření'),
(115495, 1497, 32, 'Dny chybí'),
(115496, 1498, 32, 'Dnů ve sloupci'),
(115497, 1500, 32, 'Dnů/Sloup.:'),
(115498, 1501, 32, 'Databáze je instalována'),
(115499, 1502, 32, 'DD/MM/RRRR'),
(115500, 1503, 32, 'Deidentifikace'),
(115501, 1504, 32, 'Deindentifikační proces dokončen'),
(115502, 1505, 32, 'Deindentifikační proces pokračuje'),
(115503, 1506, 32, 'Deindentifikační proces zahájen a běží na pozadí'),
(115504, 1507, 32, 'Deidentifikovaná data mohou být nekompletní'),
(115505, 1508, 32, 'Deindentifikační soubory budou uloženy v'),
(115506, 1511, 32, 'neslyšící'),
(115507, 1512, 32, 'ladící informace'),
(115508, 1514, 32, 'Ladění'),
(115509, 1515, 32, 'Pros'),
(115510, 1516, 32, 'Zesnulý'),
(115511, 1517, 32, 'Prosinec'),
(115512, 1518, 32, 'desetiny liber nebo libry a unce oddělené #(např. 5#4)'),
(115513, 1519, 32, 'upřesnění odmítnuto'),
(115514, 1520, 32, 'odečítatelný'),
(115515, 1522, 32, 'Výchozí'),
(115516, 1523, 32, 'Výchozí zobrazení kalendáře'),
(115517, 1524, 32, 'Výchozí ID  formuláře vyšetření'),
(115518, 1526, 32, 'Výchozí zařízení'),
(115519, 1527, 32, 'Výchozí jazyk'),
(115520, 1528, 32, 'Výchozí jazyk pokud jiný není povolen nebo zvolen'),
(115521, 1529, 32, 'Výchozí seznam ( na výběr právo zápisovat/přidat'),
(115522, 1530, 32, 'Výchozí metoda'),
(115523, 1531, 32, 'Výchozí počet dnů pro expiraci hesla'),
(115524, 1532, 32, 'Výchozí expirační lhůta hesla ve dnech. 0 znamená, že tato funkce je uzamčena.'),
(115525, 1533, 32, 'Výchozí země pacienta'),
(115526, 1535, 32, 'Výchozí priorita'),
(115527, 1536, 32, 'Výchozí poskytovatel'),
(115528, 1537, 32, 'Výchozí rozsah'),
(115529, 1538, 32, 'Výchozí důvod návštěvy'),
(115530, 1540, 32, 'Výchozí nastavení'),
(115531, 1541, 32, 'Výchozí stav zaškrtávacího pole v novém okně seznamu pacientů'),
(115532, 1542, 32, 'Výchozí šablona'),
(115533, 1546, 32, 'Výchozí jednotky'),
(115534, 1547, 32, 'Výchozí hodnota'),
(115535, 1548, 32, 'Výchozí sklad'),
(115536, 1549, 32, 'Výchozí X12 partner'),
(115537, 1550, 32, 'Výchozí/Globální'),
(115538, 1551, 32, 'Smazat'),
(115539, 1552, 32, 'smazat'),
(115540, 1553, 32, 'Odložené opakování (> 12 Mo)'),
(115541, 1554, 32, 'Smazat'),
(115542, 1555, 32, 'smazat'),
(115543, 1556, 32, 'Smazat kategorie s ID: '),
(115544, 1557, 32, 'Smazat kategorii'),
(115545, 1559, 32, 'Smazání selhalo !'),
(115546, 1560, 32, 'Smazat skupinu'),
(115547, 1561, 32, 'Smazat seznam'),
(115548, 1562, 32, 'Smazat stránky'),
(115549, 1563, 32, 'Smazat pacienta, vyšetření, formulář, problém, platbu, účtování nebo transakci'),
(115550, 1565, 32, 'Smazat řádek'),
(115551, 1566, 32, 'Smazat vybrané položky'),
(115552, 1567, 32, 'Smazat vybrané požadavky'),
(115553, 1568, 32, 'Smazání úspěšné'),
(115554, 1569, 32, 'Smazat tento dokument'),
(115555, 1570, 32, 'Smazat tento formulář'),
(115556, 1571, 32, 'Smazat tuto poznámku'),
(115557, 1572, 32, 'Úspěšně smazáno'),
(115558, 1573, 32, 'Úspěšně smazáno'),
(115559, 1574, 32, 'Mazání'),
(115560, 1575, 32, 'Odstranění této události nelze vrátit zpět. Není možná následná obnova. Jste si jisti, že chcete smazat tuto událost?'),
(115561, 1576, 32, 'Potvrzeno droučení'),
(115562, 1577, 32, 'Potvrzení není povoleno pro specifikovanou adresu'),
(115563, 1578, 32, 'Potvrzení není aktuálně povoleno pro specifikovanou adresu'),
(115564, 1579, 32, 'Doručení přiloženého klinického dokumetu na vyžádání pacienta.'),
(115565, 1580, 32, 'Doručení přiloženého klinického dokumetu na vyžádání pacienta.'),
(115566, 1581, 32, 'Demence'),
(115567, 1582, 32, 'Demografické údaje'),
(115568, 1583, 32, 'Demografické údaje ( volotelně právo zapisovat/přidat)'),
(115569, 1585, 32, 'Kritéria filtru pro demografické údaje'),
(115570, 1586, 32, 'Demografické údaje nejsou autorizované'),
(115571, 1587, 32, 'Demografické údaje nejsou autorizované'),
(115572, 1588, 32, 'Zamítnuto'),
(115573, 1589, 32, 'Jmenovatel'),
(115574, 1590, 32, 'Stomatologický'),
(115575, 1591, 32, 'Seznam stomatologických obtíží'),
(115576, 1592, 32, 'Stomatologické problémy'),
(115577, 1593, 32, 'Moduly - závislosti'),
(115578, 1594, 32, 'Problémy - závislosti'),
(115579, 1595, 32, 'V závislosti na typu účtu, který testujete, uvidíte HCFA jako výstup na prázdnou stránku v rámci HCFA účtování. Pokud testujete požadavek X12, uvidíte mnoho řádků poněkud zkomolených textů a informací. Zkomolený text je formát X12 EDI 4010A. Občas uvidíte podivné znaky, které vypadají jako kostky domino. Jde o normální kontrolní znaky.'),
(115580, 1596, 32, 'Datum vkladu'),
(115581, 1597, 32, 'datum vkladu nemůže být novější než dnešní.'),
(115582, 1598, 32, 'Datum vkladu:'),
(115583, 1599, 32, 'Depresivní'),
(115584, 1600, 32, 'Deprese'),
(115585, 1602, 32, 'Popis'),
(115586, 1603, 32, 'popis'),
(115587, 1604, 32, 'Popis je výchozí text'),
(115588, 1605, 32, 'Popis odhalení'),
(115589, 1606, 32, 'Popis procedury nebo výsledného kódu'),
(115590, 1607, 32, 'Přklad popisu'),
(115591, 1608, 32, 'Požadované jméno souboru'),
(115592, 1609, 32, 'Cíl'),
(115593, 1610, 32, 'Jméno cílového souboru'),
(115594, 1612, 32, 'Zničit'),
(115595, 1613, 32, 'Zničeno'),
(115596, 1614, 32, 'Zničené léky'),
(115597, 1615, 32, 'Hlášení o zničených lécích'),
(115598, 1616, 32, 'Detail'),
(115599, 1617, 32, 'Detaily'),
(115600, 1619, 32, 'Vývojové abnormality'),
(115601, 1620, 32, 'Diabetes'),
(115602, 1621, 32, 'Diabetes mellitus'),
(115603, 1622, 32, 'Diabetes: sledování krevního tlaku'),
(115604, 1623, 32, 'Diabetes: Oční vyšetření'),
(115605, 1624, 32, 'Diabetes: Oční vyšetření'),
(115606, 1625, 32, 'Diabetes: Vyšetření nohou'),
(115607, 1626, 32, 'Diabetes: Vyšetření nohou'),
(115608, 1627, 32, 'Diabetes: HbA1c kontroly'),
(115609, 1628, 32, 'Diabetes: Hemoglobin A1C'),
(115610, 1629, 32, 'Diabetes: LDL sledování & kontroly'),
(115611, 1630, 32, 'Diabetes: Microalbuminurie'),
(115612, 1631, 32, 'Diag'),
(115613, 1632, 32, 'Diagnózy'),
(115614, 1633, 32, 'Diagnóza'),
(115615, 1634, 32, 'Kód diagnózy'),
(115616, 1635, 32, 'Kódy diagnóz'),
(115617, 1636, 32, 'Datum diagnózy'),
(115618, 1637, 32, 'Diagnóza musí být kódována k odpovídajícímu vyšetření'),
(115619, 1638, 32, 'Jméno diagnózy'),
(115620, 1639, 32, 'Diagnostické hlášení'),
(115621, 1640, 32, 'Diagnostické hlášení'),
(115622, 1641, 32, 'Pouze diagnostická hlášení'),
(115623, 1642, 32, 'Označení diagnózy'),
(115624, 1643, 32, 'Diagnóza:'),
(115625, 1644, 32, 'Diagnóza: '),
(115626, 1645, 32, 'Diagnostické testy:'),
(115627, 1646, 32, 'Dialýza'),
(115628, 1648, 32, 'Průjem'),
(115629, 1650, 32, 'Diktát'),
(115630, 1651, 32, 'Diktát: '),
(115631, 1652, 32, 'Obdrželi jste kopii HIPAA oznámení'),
(115632, 1653, 32, 'Difusní:'),
(115633, 1654, 32, 'Digitálně podepsáno:'),
(115634, 1657, 32, 'Direct mail'),
(115635, 1658, 32, 'Log Direct zpráv'),
(115636, 1659, 32, 'Direct zpráva příijata'),
(115637, 1660, 32, 'Direct zprávy jsou aktuálně nedostupné'),
(115638, 1661, 32, 'Odeslání Direct zprávy selhalo'),
(115639, 1663, 32, 'Jméno ředitele'),
(115640, 1664, 32, 'Mazání adresáře selhalo, pokračuji.'),
(115641, 1665, 32, 'Invalidita'),
(115642, 1666, 32, 'Nepřístupné'),
(115643, 1667, 32, 'Deaktivovat kalendář'),
(115644, 1668, 32, 'Deaktivovat Chart tracker'),
(115645, 1669, 32, 'Deaktivovat'),
(115646, 1670, 32, 'Deaktivovat staré metrické formuláře vitálních funkcí'),
(115647, 1672, 32, 'Deaktivovat phpMyAdmin'),
(115648, 1673, 32, 'Deaktivovat preskripci'),
(115649, 1674, 32, 'Deaktivovat uživatelské skupiny'),
(115650, 1675, 32, 'deaktivováno'),
(115651, 1676, 32, 'Deaktivováno'),
(115652, 1678, 32, 'DISC'),
(115653, 1679, 32, 'zrušit'),
(115654, 1680, 32, 'Zrušeno'),
(115655, 1681, 32, 'Výtok'),
(115656, 1682, 32, 'Výtok z uretry'),
(115657, 1694, 32, 'Sleva'),
(115658, 1695, 32, 'výše slevy'),
(115659, 1696, 32, 'Úroveň slevy'),
(115660, 1697, 32, 'Procentuální sleva'),
(115661, 1698, 32, 'Sleva jako peněžní hodnota'),
(115662, 1699, 32, 'Slevy při platbě jsou stanoveny jako peněžní částka nikoliv procentuálně'),
(115663, 1700, 32, 'Diskrétní výsledky'),
(115664, 1701, 32, 'Onemocnění'),
(115665, 1702, 32, 'Dislokace'),
(115666, 1703, 32, 'Odesl. #'),
(115667, 1704, 32, 'Odeslání'),
(115668, 1705, 32, 'Odeslat přijatý dokument'),
(115669, 1706, 32, 'Vyjmuto'),
(115670, 1707, 32, 'Zobrazit pokročilé instrukce na stránce demografických údajů'),
(115671, 1708, 32, 'Zobrazit dokumenty'),
(115672, 1709, 32, 'Zobrazit termíny události v bloku ?'),
(115673, 1711, 32, 'Zobrazit počet událostí ?'),
(115674, 1713, 32, 'Zobrazit umístěšní v bloku ?'),
(115675, 1714, 32, 'Zobrazit jméno'),
(115676, 1715, 32, 'Zobrazit kalendář ?'),
(115677, 1718, 32, 'Zobrazit dnešní události v bloku ?'),
(115678, 1720, 32, 'Zobrazit nadcházející události v bloku ?'),
(115679, 1721, 32, 'Zobrazit sloupce'),
(115680, 1722, 32, 'Zobrazení následujícího čísla nejčerstvějších publikací'),
(115681, 1723, 32, 'Zobrazení následujícího čísla nejčerstvějších poznámek'),
(115682, 1724, 32, 'Zobrazení následujícího čísla nejčerstvějších poznámek'),
(115683, 1725, 32, 'Distribuce'),
(115684, 1726, 32, 'Distribuce'),
(115685, 1727, 32, 'Distributor'),
(115686, 1729, 32, 'Diverticulitis'),
(115687, 1730, 32, 'Operace divertikulitidy'),
(115688, 1731, 32, 'Diverticulitis'),
(115689, 1732, 32, 'Operace divertikulitidy'),
(115690, 1733, 32, 'Rozvedený/á'),
(115691, 1734, 32, 'Vertigo:'),
(115692, 1735, 32, 'Neměnit');
INSERT INTO `lang_definitions` VALUES
(115693, 1737, 32, 'Nezobrazovat alergie nahrané do NewCrop'),
(115694, 1739, 32, 'Nezobrazovat medikace nahrané do NewCrop'),
(115695, 1742, 32, 'Nezobrazovat kalendář'),
(115696, 1745, 32, 'Není nutné autorizovat poznámku k pacientovi'),
(115697, 1746, 32, 'Pokyn neresuscitovat'),
(115698, 1747, 32, 'Neukládat'),
(115699, 1748, 32, 'nenahrazovat'),
(115700, 1749, 32, 'nic nedělat'),
(115701, 1751, 32, 'Opravdu chcete smazat'),
(115702, 1752, 32, 'Opravdu chcete smazat výběr ?'),
(115703, 1753, 32, 'Opravdu chcete smazat tuto skupinu'),
(115704, 1754, 32, 'Opravdu chcete smazat ?'),
(115705, 1755, 32, 'Opravdu chcete pokračovat ?'),
(115706, 1756, 32, 'Opravdu to chcete smazat ?'),
(115707, 1757, 32, 'Chcete smazat ?'),
(115708, 1758, 32, 'Chcete odstranit tento záznam ?'),
(115709, 1759, 32, 'Chcete pokračovat v přidání tohoto pacienta ?'),
(115710, 1760, 32, 'Chcete pokračovat s novým jménem ?'),
(115711, 1761, 32, 'Chcete nenávratně smazat tento imunizační záznam ?'),
(115712, 1762, 32, 'Dat.nar.'),
(115713, 1763, 32, 'Dat.nar není zadáno, prosím zadejte jej, je-li to možné'),
(115714, 1764, 32, 'Dokumenty'),
(115715, 1765, 32, 'Lékař'),
(115716, 1766, 32, 'Lékař:'),
(115717, 1767, 32, 'Jméno a podpis lékaře'),
(115718, 1768, 32, 'Dokument'),
(115719, 1769, 32, 'dokument'),
(115720, 1770, 32, 'Kategorie dokumentu'),
(115721, 1771, 32, 'Kategorie dokumentu pro laboratorní výsledky neexistuje'),
(115722, 1772, 32, 'Název kategorie dokumentu pro úložiště elektronicky přijatých laboratorních výsledků'),
(115723, 1774, 32, 'Kategorie dokumentu nebo odstranit'),
(115724, 1775, 32, 'Dokument nelze přesunout k ID pacienta'),
(115725, 1777, 32, 'Datum dokumentu'),
(115726, 1778, 32, 'Datum dokumentu a problému úspěšně aktualizováno'),
(115727, 1779, 32, 'ID dokumentu'),
(115728, 1780, 32, 'Dokument přesunut do nové kategorie'),
(115729, 1781, 32, 'Dokument přesunut pod ID pacienta'),
(115730, 1783, 32, 'Kontrola integrity dokumentu úspěšně dokončena'),
(115731, 1784, 32, 'Metoda úložení dokumentu'),
(115732, 1785, 32, 'Dokument byl úspěšně přejmenován'),
(115733, 1786, 32, 'Dokument byl úspěšně připojen k vyšetření'),
(115734, 1787, 32, 'Správa šablon dokumentů'),
(115735, 1788, 32, 'Šablony dokumentů'),
(115736, 1789, 32, 'Dokument(y)'),
(115737, 1790, 32, 'Úložiště pro dokumenty/Obrazová dokumentace'),
(115738, 1791, 32, 'Dokumenty'),
(115739, 1792, 32, 'Dokumenty ( právo zápisovat/přidat volitelně)'),
(115740, 1794, 32, 'Námahová dušnost'),
(115741, 1796, 32, 'Neodpovídá číslu PV1 vyšetření'),
(115742, 1797, 32, 'zřejmě neplatný údaj'),
(115743, 1799, 32, 'Tuzemský partner'),
(115744, 1800, 32, 'Neukládat'),
(115745, 1801, 32, 'Neukládat'),
(115746, 1802, 32, 'Neukládat změny'),
(115747, 1803, 32, 'Hotovo'),
(115748, 1804, 32, 'Hotovo s:'),
(115749, 1805, 32, 'Hotovo. Bude obratem  odesláno ke stažení.'),
(115750, 1807, 32, 'Dávkování'),
(115751, 1809, 32, 'Dvojklik pro editaci'),
(115752, 1810, 32, 'Dvojité  vidění'),
(115753, 1811, 32, 'Stažení'),
(115754, 1814, 32, 'Rozhodně stáhnout'),
(115755, 1815, 32, 'Stáhnout platební údaj, odeslat ke zúčtování a označit jako zuaúčtované'),
(115756, 1817, 32, 'Stáhnout certifikáty'),
(115757, 1818, 32, 'Stáhnout konfigurační data'),
(115758, 1819, 32, 'Stáhnout šablonu dokumentu pro tohoto pacienta a návštěvu'),
(115759, 1820, 32, 'stáhnout  zašifrovaný soubor'),
(115760, 1824, 32, 'Stáhnout nebo smazat šablonu'),
(115761, 1825, 32, 'Stáhnout PDF'),
(115762, 1827, 32, 'Stáhnout vybrané hlášky'),
(115763, 1830, 32, 'Dr.'),
(115764, 1831, 32, 'Zachytit k přetažení'),
(115765, 1832, 32, 'Únik moči'),
(115766, 1833, 32, 'ID řidičského průkazu nebo OP'),
(115767, 1834, 32, 'Lék'),
(115768, 1835, 32, 'Vyhledávač léků'),
(115769, 1836, 32, 'Formuláře léků'),
(115770, 1837, 32, 'Chybí ID léku !'),
(115771, 1838, 32, 'Lékové intervaly podání'),
(115772, 1840, 32, 'Název léku'),
(115773, 1841, 32, 'Způsob podání'),
(115774, 1845, 32, 'Lékové jednotky'),
(115775, 1846, 32, 'Léky'),
(115776, 1847, 32, 'Léky a produkty'),
(115777, 1848, 32, 'Sucho v ústech (xerostomie)'),
(115778, 1849, 32, 'DSMIV Diagnóza'),
(115779, 1850, 32, 'Difterický  tetanus 1'),
(115780, 1851, 32, 'Difterický  tetanus 2'),
(115781, 1852, 32, 'Difterický  tetanus 3'),
(115782, 1853, 32, 'Difterický  tetanus 4'),
(115783, 1854, 32, 'Difterický  tetanus 5'),
(115784, 1861, 32, 'Datum platby'),
(115785, 1862, 32, 'Datum platby mm/dd/rrrrr nebo rrrr-mm-dd'),
(115786, 1863, 32, 'Datum platby:'),
(115787, 1866, 32, 'Blíží se konec platnosti'),
(115788, 1867, 32, 'Stav platby'),
(115789, 1868, 32, 'Aktualizace stavu platby'),
(115790, 1876, 32, 'Duplicitní ID v řádku'),
(115791, 1877, 32, 'Duplicitní jméno v řádku'),
(115792, 1878, 32, 'VArování duplicity'),
(115793, 1880, 32, 'trvání'),
(115794, 1881, 32, 'Trvání'),
(115795, 1882, 32, 'Holandský'),
(115796, 1884, 32, 'Dysfágie'),
(115797, 1885, 32, 'Dušnost:'),
(115798, 1886, 32, 'Dysurie'),
(115799, 1888, 32, 'E-preskripce ?'),
(115800, 1889, 32, 'E-reporty'),
(115801, 1890, 32, 'e-Rx'),
(115802, 1892, 32, 'e-Rx obnovení'),
(115803, 1893, 32, 'Každý příjemce musí nastavit své vlastní zprávy jako dokončené.'),
(115804, 1894, 32, 'Časná rekurence (<2 Měs)'),
(115805, 1895, 32, 'Uši'),
(115806, 1896, 32, 'EKG'),
(115807, 1897, 32, 'e-žádanky'),
(115808, 1898, 32, 'Edém'),
(115809, 1904, 32, 'Upravit'),
(115810, 1905, 32, 'upravit'),
(115811, 1906, 32, 'Upravit Alergie'),
(115812, 1907, 32, 'Upravit kategorie'),
(115813, 1908, 32, 'Upravit definice'),
(115814, 1909, 32, 'Upravit definice'),
(115815, 1910, 32, 'Upravit diagnózy pro'),
(115816, 1911, 32, 'Upravit zveřejnění'),
(115817, 1912, 32, 'Upravit zařízení'),
(115818, 1913, 32, 'Upravit zařízení'),
(115819, 1914, 32, 'Upravit informace o zařízení'),
(115820, 1915, 32, 'Upravit uživatelské údaje týkající se zařízení'),
(115821, 1916, 32, 'Upravit soubor v'),
(115822, 1917, 32, 'Upravit formulář'),
(115823, 1918, 32, 'Upravit globální nastavení'),
(115824, 1919, 32, 'Úpravy nejsou autorizovány !'),
(115825, 1920, 32, 'Upravit rozvržení'),
(115826, 1921, 32, 'Upravit seznam'),
(115827, 1922, 32, 'Upravit platbu'),
(115828, 1923, 32, 'Upravit strukturu'),
(115829, 1924, 32, 'Upravit uživatele'),
(115830, 1925, 32, 'Upravit uživatelské nastavení'),
(115831, 1926, 32, 'Upravit zadaná data'),
(115832, 1927, 32, 'Úpravy selhaly'),
(115833, 1928, 32, 'Vzdělávání'),
(115834, 1930, 32, 'Vzdělávací materiály pro'),
(115835, 1932, 32, 'Datum účinnosti'),
(115836, 1934, 32, 'účinnost'),
(115837, 1935, 32, 'Identifikační číslo zaměstnavatele'),
(115838, 1936, 32, 'Ejakulace'),
(115839, 1937, 32, 'Loket'),
(115840, 1938, 32, 'Problémy s loktem'),
(115841, 1939, 32, 'Elektronicky'),
(115842, 1942, 32, 'Elektronické převody'),
(115843, 1943, 32, 'Elektronické reporty'),
(115844, 1944, 32, 'Způsobilost'),
(115845, 1948, 32, 'Způsobilý'),
(115846, 1949, 32, 'e-mail'),
(115847, 1950, 32, 'email'),
(115848, 1951, 32, 'emailová adresa'),
(115849, 1952, 32, 'chybí emailová adresa'),
(115850, 1953, 32, 'E-mailová adresa odesílatele upomínek pacientům. Odpovědi na upomínky pacientů budou směrovány na tuto adresu. Je důležité použít adresu z klinické domény, aby se zabránilo přesunu upomínek do spamu.'),
(115851, 1954, 32, 'E-mailová adresa pro příjem upozornění správy'),
(115852, 1955, 32, 'E-mailová adresa pro příjem zpráv nutných k nouzovému uživatelskému přihlášení'),
(115853, 1956, 32, 'E-mail autor.'),
(115854, 1957, 32, 'Batchcom email'),
(115855, 1958, 32, 'E-mailové upozornění'),
(115856, 1959, 32, 'Hodiny e-mailových upozornění'),
(115857, 1960, 32, 'Hlášení emailových upozornění'),
(115858, 1961, 32, 'Nejdřív pošlete e-mail'),
(115859, 1962, 32, 'Odesílatel e-mailu'),
(115860, 1963, 32, 'E-mail odeslán'),
(115861, 1964, 32, 'E-mail odeslán'),
(115862, 1965, 32, 'Předmět e-mailu'),
(115863, 1966, 32, 'Text e-mailu , užívané označení: ***JMÉNO***, např. Vážený/á ***JMÉNO***'),
(115864, 1967, 32, 'Text e-mailu , užívané označení: ***JMÉNO***, např. Vážený/á ***JMÉNO***{{Nepřekládat prvek  ***JMÉNO*** této konstanty}}'),
(115865, 1968, 32, 'metoda přenosu e-mailu'),
(115866, 1969, 32, 'E-mail byl odeslán na následující adresy'),
(115867, 1971, 32, 'Emergency kontakt'),
(115868, 1972, 32, 'Kontaktní osoba emergency'),
(115869, 1973, 32, 'Kontaktní telefon emergency'),
(115870, 1974, 32, 'Nouzová antikoncepce'),
(115871, 1975, 32, 'Nouzové přihlášení'),
(115872, 1976, 32, 'Nouzový login ACL je vybrán.Uživatel je stále v aktivním stavu, prosím deaktivujte uživatele. Aktivujte pouze v naléhavých situacích. Navštivte Sparáva-> Uživatelé pro aktivaci nebo deaktivaci.'),
(115873, 1977, 32, 'Přihlašovací email pro nouzové přihlášení bude zaslán pouze tehdy, pokud jsou nakonfigurovány následující nastavení v souboru  interface/ globals.php :'),
(115874, 1978, 32, 'E-mailová adresa pro nouzové přihlášení'),
(115875, 1979, 32, 'Nouzový uživatel může dělat cokoliv'),
(115876, 1980, 32, 'pohotovostní telefon'),
(115877, 1981, 32, 'Emoční / Behaviorální stav & komplikace'),
(115878, 1982, 32, 'Emfysém'),
(115879, 1983, 32, 'Zaměstnanec'),
(115880, 1984, 32, 'Zaměstnavatel'),
(115881, 1985, 32, 'Adresa zaměstnavatele'),
(115882, 1986, 32, 'Data zaměstnavatele'),
(115883, 1987, 32, 'Jméno zaměstnavatele'),
(115884, 1988, 32, 'PRÁZDNÉ'),
(115885, 1989, 32, 'Prázdné'),
(115886, 1990, 32, 'Prázdné heslo není povoleno'),
(115887, 1991, 32, 'Prázdná hodnota v "Hodiny e-mailu"'),
(115888, 1992, 32, 'Prázdná hodnota v "Odesílatel e-mailu"'),
(115889, 1993, 32, 'Prázdná hodnota v "Předmět e-mailu"'),
(115890, 1994, 32, 'Prázdná hodnota v "Text e-mailu"'),
(115891, 1995, 32, 'Prázdná hodnota v "Jméno poskytovatele"'),
(115892, 1996, 32, 'Prázdná hodnota v "Heslo"'),
(115893, 1997, 32, 'Prázdná hodnota v "SMS hodiny"'),
(115894, 1998, 32, 'Prázdná hodnota v "SMS text"'),
(115895, 1999, 32, 'Prázdná hodnota v "Uživatelské jméno"'),
(115896, 2001, 32, 'Zapnutí'),
(115897, 2006, 32, 'Zapnout AMC výzvy'),
(115898, 2008, 32, 'Zapnout hlášení AMC'),
(115899, 2009, 32, 'Zapnout sledování AMC'),
(115900, 2011, 32, 'Zapnout ATNA audit'),
(115901, 2012, 32, 'Zapnout šifrování  logu auditu'),
(115902, 2013, 32, 'Zapnout audit logování'),
(115903, 2015, 32, 'Zapnout reporting pro  automatizované měřící výpočty ( AMC )'),
(115904, 2016, 32, 'Zapnout klientský SSL'),
(115905, 2017, 32, 'Zapnout autentizaci klienstkého certifikátu SSL'),
(115906, 2019, 32, 'Zapnout Clinical Decision Rules (CDR)'),
(115907, 2022, 32, 'Zapnout reportování měření klinického měření (CQM)'),
(115908, 2023, 32, 'Zapnout vyskakovací okno klinických upozornění'),
(115909, 2024, 32, 'zapnout widget klinických upozornění'),
(115910, 2025, 32, 'zapnout CMS portál'),
(115911, 2027, 32, 'Zapnout reportování CQM'),
(115912, 2028, 32, 'Zapnout historii EDI ( electronic data interchange )  v levém menu'),
(115913, 2030, 32, 'povolit poplatky v levém menu'),
(115914, 2031, 32, 'Zapnout podporu pro Hylafax'),
(115915, 2033, 32, 'zapnout zprávy o stavu importu pro NewCorp erx'),
(115916, 2037, 32, 'Zapnout laboratorní výměnu'),
(115917, 2038, 32, 'Povolit přepínač zámku'),
(115918, 2039, 32, 'povolit log  pro nahrávání/stahování dokumentů do CouchDB'),
(115919, 2040, 32, 'Povolit logování všech SQL SELECT dotazů.'),
(115920, 2041, 32, 'Povolit logování aktivit souvisejících se zálohováním'),
(115921, 2042, 32, 'Povolit logování dotazů CDR ( clinical data repository)'),
(115922, 2043, 32, 'povolit logování různých aktivit.'),
(115923, 2044, 32, 'Povolit logování objednávkových aktivit'),
(115924, 2045, 32, 'Povolit logování modifikací záznamů pacientů'),
(115925, 2046, 32, 'Povolit logování plánovacích aktivit'),
(115926, 2047, 32, 'Povolit logování bezpečnostních a správcovských aktivit'),
(115927, 2049, 32, 'povolit NewCorp eRx službu'),
(115928, 2051, 32, 'Povolit externí pacientský portál'),
(115929, 2052, 32, 'Povolit externí pacientský portál'),
(115930, 2053, 32, 'Povolit interní pacientský portál'),
(115931, 2055, 32, 'Povolit interní pacientský portál'),
(115932, 2056, 32, 'Povolit widget upomínek pacientům.'),
(115933, 2057, 32, 'Povolit službu zpráv direct phiMailu'),
(115934, 2058, 32, 'Povolit výzvy k automatizovaným měřícím výpočtům (AMC)'),
(115935, 2061, 32, 'Povolit podporu skeneru'),
(115936, 2064, 32, 'Povolit Medical information Integration, LLC Lab Exchange service'),
(115937, 2065, 32, 'Povolit podporu LibreEHR pro LLC Lab Exchange služby'),
(115938, 2066, 32, 'Povolit autentizaci uživatelských certifikátů'),
(115939, 2067, 32, 'Povolit ZMG, LLC eRx službu'),
(115940, 2068, 32, 'Povoleno'),
(115941, 2070, 32, 'Povoluje starý panel poplatků pro zadávání účetních kódů a plateb. Nedoporučuje se povolit.'),
(115942, 2071, 32, 'Vyš'),
(115943, 2072, 32, 'Vyšetření'),
(115944, 2073, 32, 'Vyšetření'),
(115945, 2074, 32, 'vyšetření'),
(115946, 2075, 32, 'Vyšetření '),
(115947, 2076, 32, 'vyšetření akutního pacienta nebo vyšetření na pohotovosti'),
(115948, 2080, 32, 'data vyšetření'),
(115949, 2081, 32, 'Datum vyšetření'),
(115950, 2084, 32, 'EDI záznam vyšetření'),
(115951, 2086, 32, 'Formulář vyšetření'),
(115952, 2087, 32, 'Vyšetření zdravotního stavu a chování'),
(115953, 2088, 32, 'Historie vyšetření'),
(115954, 2089, 32, 'ID vyšetření'),
(115955, 2090, 32, 'vyšetření chřipky'),
(115956, 2091, 32, 'Číslo vyšetření'),
(115957, 2095, 32, 'vyšetření pro ergoterapii'),
(115958, 2097, 32, 'vyšetření ambulantního pacienta'),
(115959, 2099, 32, 'Vyšetření - velikost papíru'),
(115960, 2100, 32, 'Platba vyšetření'),
(115961, 2101, 32, 'vyšetření těhotné'),
(115962, 2102, 32, 'preventivní vyšetření - individuální poradenství'),
(115963, 2103, 32, 'preventivní vyšetření starších 40 let'),
(115964, 2104, 32, 'preventivní vyšetření - skupinové poradenství'),
(115965, 2105, 32, 'preventivní vyšetření - další služby'),
(115966, 2106, 32, 'preventivní vyšetření starších 18 let'),
(115967, 2107, 32, 'psychiatrické a psychologické vyšetření'),
(115968, 2108, 32, 'Statistiky vyšetření'),
(115969, 2109, 32, 'Souhrn vyšetření'),
(115970, 2110, 32, 'Vyšetření bylo  kódováno'),
(115971, 2111, 32, 'Vyšetření'),
(115972, 2112, 32, 'Vyšetření: vyšetření neakutního hospitalizovaného, ambulantního pacienta nebo oftalmologické vyšetření'),
(115973, 2113, 32, 'Vyšetření'),
(115974, 2114, 32, 'Vyšetření a formuláře'),
(115975, 2115, 32, 'Vyšetření a formuláře'),
(115976, 2116, 32, 'Vyšetření nebyla autorizována'),
(115977, 2117, 32, 'Report vyšetření'),
(115978, 2118, 32, 'Sekce vyšetření'),
(115979, 2120, 32, 'Šifrování'),
(115980, 2121, 32, 'Konec'),
(115981, 2122, 32, 'Konec (rrr-mm-dd): '),
(115982, 2123, 32, 'Konečné datum'),
(115983, 2124, 32, 'Konečné datum'),
(115984, 2126, 32, 'Konečné datum musí být vyšší než počáteční'),
(115985, 2127, 32, 'Konečné datum:'),
(115986, 2130, 32, 'Konec hlášení'),
(115987, 2131, 32, 'Konečný čas'),
(115988, 2133, 32, 'Datum ukonční služby rrrr-mm-dd'),
(115989, 2134, 32, 'Datum ukonční služby mm/dd/rrrr pokud chcete zadat rozsah'),
(115990, 2135, 32, 'Konečná denní hodina pro událost kalendáře'),
(115991, 2137, 32, 'endokrinní'),
(115992, 2138, 32, 'Endoskopie'),
(115993, 2141, 32, 'Anglický'),
(115994, 2142, 32, 'Anglický '),
(115995, 2143, 32, 'Angličtina ( indická )'),
(115996, 2144, 32, 'Angličtina ( standardní )'),
(115997, 2145, 32, 'Enscript příkaz Hylafaxu'),
(115998, 2146, 32, 'Ujistěte se , že LibreEHR má právo zápisu do složky'),
(115999, 2147, 32, 'ORL výtok'),
(116000, 2148, 32, 'Bolest ORL původu'),
(116001, 2150, 32, 'Zadejte opravu'),
(116002, 2151, 32, 'Zadejte zde obsah dopisu'),
(116003, 2152, 32, 'Zadejte root heslo databáze'),
(116004, 2153, 32, 'Zadejte uživatelské jméno root přístupu k  databázi'),
(116005, 2154, 32, 'Zadejte diagnózu'),
(116006, 2155, 32, 'Zadejte  léčivo'),
(116007, 2156, 32, 'Zadejte vyšetření'),
(116008, 2157, 32, 'Zadejte číslo vyšetření'),
(116009, 2158, 32, 'Zadejte očkování'),
(116010, 2159, 32, 'Zadejte klíč'),
(116011, 2160, 32, 'Zadejte nová data'),
(116012, 2161, 32, 'Zadejte nový stát'),
(116013, 2162, 32, 'Zadejte direct adresu příjemce'),
(116014, 2163, 32, 'Zadejte LOINC kód této procedury'),
(116015, 2164, 32, 'Zadejte reidentifikační kód'),
(116016, 2165, 32, 'Výše zadejte vyhledávací kritéria'),
(116017, 2166, 32, 'Chybně zadáno'),
(116018, 2167, 32, 'položky'),
(116019, 2168, 32, 'Vlivy prostředí'),
(116020, 2176, 32, 'Epilepsie'),
(116021, 2178, 32, 'ERA'),
(116022, 2179, 32, 'ERA soubory'),
(116023, 2181, 32, 'Vymazat'),
(116024, 2182, 32, 'Erekce'),
(116025, 2183, 32, 'Chyba'),
(116026, 2184, 32, 'CHYBA'),
(116027, 2185, 32, 'Chyba při potvrzení příjemce  laboratorních výsledků'),
(116028, 2187, 32, 'Chyba při získávání výsledků z Lab Exchange Network'),
(116029, 2188, 32, 'Chyba ve výběru "Pohlaví"'),
(116030, 2189, 32, 'Chyba ve výběru "HIPPA"'),
(116031, 2190, 32, 'Chyba ve výběru "Process"'),
(116032, 2191, 32, 'Chyba ve výběru "SMS brány"'),
(116033, 2192, 32, 'Chyba ve výběru "Řadit podle"'),
(116034, 2193, 32, 'Chyba souboru nebo gzip komprese '),
(116035, 2194, 32, 'Chyba při volně ANO nebo NE'),
(116036, 2195, 32, 'Chyba při otevírání nahraných  dat pro čtení'),
(116037, 2196, 32, 'Chyba při zpracování souboru'),
(116038, 2197, 32, 'Chyba při nahrávání'),
(116039, 2198, 32, 'Chyba při mazání zprávy'),
(116040, 2199, 32, 'Chyba při obdržení výsledků z Lab Exchange Network'),
(116041, 2200, 32, 'Chyba při získávání hodnot'),
(116042, 2201, 32, 'Chyba při ukládání dokumentu'),
(116043, 2202, 32, 'Chyba přidělování přístupových práv k souboru pro uživatele LibreEHR'),
(116044, 2205, 32, 'Chyba při registraci formuláře'),
(116045, 2206, 32, 'Chyba při ukládání do souboru'),
(116046, 2208, 32, 'Chyba zápisu do souboru'),
(116047, 2209, 32, 'v nových výsledcích  se objevily chyby'),
(116048, 2210, 32, 'Chyba , soubor neexistuje'),
(116049, 2211, 32, 'CHYBA, nelze shromáždit data ze serveru'),
(116050, 2212, 32, 'Chyba , nelze vytvořit klientský certifikát'),
(116051, 2213, 32, 'Chyba, nelze vytvořit admin.p12 certifikát'),
(116052, 2214, 32, 'Chyba, nelze vytvořit certifikát certifikační autority'),
(116053, 2215, 32, 'Chyba, nelze vytvořit serverový certifikát'),
(116054, 2216, 32, 'Chyba, nelze otevřít soubor'),
(116055, 2217, 32, 'Chyba, ověření uživatelských certifikátů není v LibreEHR povoleno'),
(116056, 2218, 32, 'Chyba, je potřeba nainstalovat modul Archive/Tar.php'),
(116057, 2219, 32, 'CHYBA: nelze otevřít tabulku .sql. Poškozený formulář ?'),
(116058, 2220, 32, 'Chyba: duplicitní ID v řádku'),
(116059, 2221, 32, 'Chyba: duplicitní jméno v řádku'),
(116060, 2222, 32, 'CHYBA: Pole'),
(116061, 2223, 32, 'CHYBA: Chybí modul ZipArchive PHP'),
(116062, 2224, 32, 'CHYBA: Chybí ICD složka pro import'),
(116063, 2225, 32, 'Chyba: hesla si neodpovídají. Prosím, prověďte kontrolu.'),
(116064, 2226, 32, 'Chyba: hesla si neodpovídají. Prosím, prověďte kontrolu.'),
(116065, 2227, 32, 'Chyba: soubor neexistuje'),
(116066, 2228, 32, 'CHYBA: Následující proměnné obsahují  chybné znaky'),
(116067, 2229, 32, 'CHYBA: Nelze kopírovat soubor'),
(116068, 2230, 32, 'Chyba: Nelze vytvořit archiv ke stažení'),
(116069, 2231, 32, 'CHYBA: Nelze vytvořit Zip archiv'),
(116070, 2232, 32, 'CHYBA: nelze rozbalit soubor'),
(116071, 2233, 32, 'CHYBA: Nelze nahrát soubor do databáze'),
(116072, 2234, 32, 'CHYBA: Nelze nastavit číslo verze'),
(116073, 2235, 32, 'Chyby'),
(116074, 2236, 32, 'Stav účtu eRx'),
(116075, 2237, 32, 'eRx logy'),
(116076, 2238, 32, 'ERX jméno'),
(116077, 2239, 32, 'ERX heslo'),
(116078, 2240, 32, 'ERX Role'),
(116079, 2241, 32, 'ERX Uživatel'),
(116080, 2242, 32, 'Erytém'),
(116081, 2243, 32, 'e-Podpis'),
(116082, 2244, 32, 'e-Podpis log'),
(116083, 2245, 32, 'Eskimák'),
(116084, 2246, 32, 'Esperanto'),
(116085, 2247, 32, 'Založený pacient'),
(116086, 2248, 32, 'Estonský'),
(116087, 2249, 32, 'Etnikum'),
(116088, 2250, 32, 'Etnikum nebo rasa'),
(116089, 2251, 32, 'Seznam etnik-ras ( na výběr právo zapisovat/přidat )'),
(116090, 2252, 32, 'ETIN'),
(116091, 2253, 32, 'Událost'),
(116092, 2254, 32, 'Počátek události'),
(116093, 2255, 32, 'Kategorie události'),
(116094, 2256, 32, 'Datum události'),
(116095, 2257, 32, 'Popis události'),
(116096, 2258, 32, 'Detaily události'),
(116097, 2259, 32, 'Neopakující se událost'),
(116098, 2260, 32, 'Trvání události'),
(116099, 2261, 32, 'Trvání události v minutách'),
(116100, 2263, 32, 'Místo události'),
(116101, 2264, 32, 'Opakování události každý'),
(116102, 2266, 32, 'Počáteční čas události'),
(116103, 2267, 32, 'Název události'),
(116104, 2268, 32, 'Název události'),
(116105, 2269, 32, 'Webstránka události'),
(116106, 2270, 32, 'Události'),
(116107, 2271, 32, 'Události pro'),
(116108, 2272, 32, 'Otevření události v novém okně'),
(116109, 2273, 32, 'každ.'),
(116110, 2274, 32, 'každ.'),
(116111, 2275, 32, 'každé 3 hodiny'),
(116112, 2276, 32, 'každé 4 hodiny'),
(116113, 2277, 32, 'každých 5 hodin'),
(116114, 2278, 32, 'každých 6 hodin'),
(116115, 2279, 32, 'každých 8 hodin'),
(116116, 2280, 32, 'Každý čtvrtý'),
(116117, 2281, 32, 'Každý druhý'),
(116118, 2282, 32, 'Každý třetí'),
(116119, 2283, 32, 'Každý, každý druhý, každý třetí, atd.'),
(116120, 2285, 32, 'Výsledky vyšetření a testů'),
(116121, 2286, 32, 'Výsleky všetření'),
(116122, 2289, 32, 'Klinické vyšetření'),
(116123, 2290, 32, 'Den klinického vyšetření'),
(116124, 2291, 32, 'Příklad'),
(116125, 2292, 32, 'Příklady'),
(116126, 2293, 32, 'Vyš/Testy'),
(116127, 2294, 32, 'S výjimkou'),
(116128, 2295, 32, 'Excesivní slzotok'),
(116129, 2296, 32, 'Vyjmutí pacienti'),
(116130, 2297, 32, 'Výjimky'),
(116131, 2298, 32, 'Exclusive Provider Organization (EPO)'),
(116132, 2300, 32, 'Cvičení'),
(116133, 2301, 32, 'Cvičební vzory'),
(116134, 2302, 32, 'Cvičební vzory'),
(116135, 2303, 32, 'Existuje'),
(116136, 2304, 32, 'Odejít z administrace'),
(116137, 2306, 32, 'Rozšířit'),
(116138, 2307, 32, 'rozšířit'),
(116139, 2308, 32, 'Rozšířit vše'),
(116140, 2311, 32, 'Rozšířené zobrazení'),
(116141, 2313, 32, 'Expirace'),
(116142, 2314, 32, 'Datum expirace'),
(116143, 2315, 32, 'Expiruje'),
(116144, 2316, 32, 'expiruje v'),
(116145, 2317, 32, 'Export'),
(116146, 2318, 32, 'Exportovat jako CSV'),
(116147, 2319, 32, 'Export konfigurace'),
(116148, 2322, 32, 'Export  demografických údajů pacienta'),
(116149, 2323, 32, 'Export PQRI reportu'),
(116150, 2325, 32, 'Export vybraných jako CSV'),
(116151, 2327, 32, 'Exportovat do CSV'),
(116152, 2328, 32, 'Exportovat do externího účetního systému'),
(116153, 2332, 32, 'Externí'),
(116154, 2334, 32, 'Externí data načtena'),
(116155, 2335, 32, 'Nástroj improtu externí databáze'),
(116156, 2336, 32, 'Externí ID'),
(116157, 2337, 32, 'Externí Id'),
(116158, 2338, 32, 'Externí identifikátor'),
(116159, 2339, 32, 'Pouze externí'),
(116160, 2342, 32, 'Externí doporučení'),
(116161, 2343, 32, 'Doporučení externích kontrol'),
(116162, 2344, 32, 'Externí doporučení ?'),
(116163, 2345, 32, 'Externí doporučení'),
(116164, 2346, 32, 'Rozbalit .zip soubor'),
(116165, 2347, 32, 'Rozbaluji soubor. To může chvíli trvat...'),
(116166, 2348, 32, 'Exudát'),
(116167, 2349, 32, 'Oční podráždění'),
(116168, 2350, 32, 'Oční bolesti'),
(116169, 2351, 32, 'Oční zarudnutí'),
(116170, 2352, 32, 'Oči'),
(116171, 2353, 32, 'F'),
(116172, 2354, 32, 'RA krevních onemocnění'),
(116173, 2355, 32, 'RA ženského hirsutismu/strií'),
(116174, 2356, 32, 'Zařízení'),
(116175, 2357, 32, 'Zařízení'),
(116176, 2358, 32, 'zařízení'),
(116177, 2359, 32, 'Správa zařízení'),
(116178, 2360, 32, 'Město zařízení'),
(116179, 2361, 32, 'Kód zařízení'),
(116180, 2362, 32, 'Kód země zařízení'),
(116181, 2363, 32, 'Fax zařízení'),
(116182, 2364, 32, 'Jméno zařízení'),
(116183, 2365, 32, 'Identifokační číslo zařízení'),
(116184, 2366, 32, 'Zařízení - Telefon'),
(116185, 2367, 32, 'Specifické uživatelské informace zařízení'),
(116186, 2368, 32, 'Zařízení - Stát'),
(116187, 2369, 32, 'Zařízení -  Ulice'),
(116188, 2370, 32, 'Zařízení - PSČ'),
(116189, 2372, 32, 'Zařízení:'),
(116190, 2373, 32, 'Selhání'),
(116191, 2374, 32, 'Selhání'),
(116192, 2375, 32, 'Selhání'),
(116193, 2376, 32, 'Neuspěšní pacienti'),
(116194, 2377, 32, 'Selhalo přidání pacienta na portál'),
(116195, 2378, 32, 'Selhalo generování unikátního jména souboru'),
(116196, 2379, 32, 'Vytvoření selhalo'),
(116197, 2380, 32, 'Selhalo  vytvoření dočasné složky. CouchDB nebude pracovat'),
(116198, 2382, 32, 'Selhalo'),
(116199, 2383, 32, 'selhání'),
(116200, 2384, 32, 'Selhání'),
(116201, 2385, 32, 'ZPRÁVA O SELHÁNÍ: Odeslání direct zprávy selhalo'),
(116202, 2390, 32, 'Rodinná anamnéza'),
(116203, 2391, 32, 'Rodinná anamnéza glaukomu'),
(116204, 2392, 32, 'Rodinná anamnéza:'),
(116205, 2394, 32, 'Rodinná platba'),
(116206, 2395, 32, 'Počet členů rodiny'),
(116207, 2397, 32, 'Faerské ostrovy'),
(116208, 2398, 32, 'Farsi'),
(116209, 2400, 32, 'Otec'),
(116210, 2401, 32, 'Anamnéza otce'),
(116211, 2402, 32, 'Únava'),
(116212, 2403, 32, 'Unavený'),
(116213, 2404, 32, 'Fax'),
(116214, 2405, 32, 'Počet faxů'),
(116215, 2406, 32, 'Číslo faxu'),
(116216, 2408, 32, 'Fax/Scan'),
(116217, 2409, 32, 'Přijmout faxem'),
(116218, 2410, 32, 'Odeslat faxem'),
(116219, 2411, 32, 'Vlastnosti'),
(116220, 2412, 32, 'Úno'),
(116221, 2413, 32, 'Únor'),
(116222, 2415, 32, 'ID léčiva'),
(116223, 2418, 32, 'Platba'),
(116224, 2419, 32, 'platba'),
(116225, 2420, 32, 'Platba není povolena'),
(116226, 2423, 32, 'Platba'),
(116227, 2424, 32, 'Žena'),
(116228, 2425, 32, 'Angina pectoris u ženy'),
(116229, 2426, 32, 'Ženský kondom'),
(116230, 2430, 32, 'Ženské symptomy'),
(116231, 2433, 32, 'Získávám následující soubor z portálu'),
(116232, 2434, 32, 'Horečka'),
(116233, 2435, 32, 'Horečka:'),
(116234, 2436, 32, 'RA krevních onemocnění'),
(116235, 2437, 32, 'Fibromy'),
(116236, 2438, 32, 'Pole'),
(116237, 2439, 32, 'Položka ''název'' pole nesmí být NULL'),
(116238, 2443, 32, 'Chybějící pole !'),
(116239, 2447, 32, 'Soubor'),
(116240, 2448, 32, 'soubor v adresáři Dokumentace s instrukcemi jak automatizovat proces tvorby backup logů'),
(116241, 2449, 32, 'umístění souboru'),
(116242, 2450, 32, 'Správa souborů'),
(116243, 2453, 32, 'Přístupová práva k souboru přidělena uživateli LibreEHR'),
(116244, 2454, 32, 'Získání souboru z CouchDB selhalo'),
(116245, 2455, 32, 'Spisovna'),
(116246, 2456, 32, 'Soubor k nahrání'),
(116247, 2457, 32, 'Soubor k nahrání'),
(116248, 2458, 32, 'Soubor se stejným jménem  již v umístní existuje:'),
(116249, 2459, 32, 'Jméno souboru'),
(116250, 2460, 32, 'Jméno souboru musí končit ".pdf"'),
(116251, 2461, 32, 'Soubory'),
(116252, 2463, 32, 'Vyplňte jakýkoliv  z řádků níže.'),
(116253, 2464, 32, 'Zde vyplňte pouze pokud odesíláte notifikace pacientům'),
(116254, 2465, 32, 'Vyplňte hodnoty níže'),
(116255, 2467, 32, 'Vyplňte řádek.'),
(116256, 2468, 32, 'Filtr'),
(116257, 2469, 32, 'Filtr pro konstanty'),
(116258, 2470, 32, 'Filtr pro definice'),
(116259, 2471, 32, 'ziltrováno z'),
(116260, 2472, 32, 'filtry'),
(116261, 2473, 32, 'Filtry'),
(116262, 2474, 32, 'Finální'),
(116263, 2475, 32, 'Konečná diagnóza'),
(116264, 2476, 32, 'Konečná diagnóza specialisty'),
(116265, 2478, 32, 'Finanční'),
(116266, 2479, 32, 'Finančí uzávěrka (rrrrr-mm-dd)'),
(116267, 2480, 32, 'Finančí reportování - cokoliv'),
(116268, 2481, 32, 'Finančí reportování - moje vyšetření'),
(116269, 2482, 32, 'Datum finanční rozvahy'),
(116270, 2483, 32, 'Finanční souhr podle kódu služby'),
(116271, 2484, 32, 'Najít'),
(116272, 2485, 32, 'Najít dostupné'),
(116273, 2486, 32, 'Najít dostupné návštěvy'),
(116274, 2487, 32, 'Najít pacienta'),
(116275, 2488, 32, 'Najít edukační materiály pro pacienty'),
(116276, 2489, 32, 'Nálezy'),
(116277, 2490, 32, 'Nálezy dle specialistů'),
(116278, 2492, 32, 'Ukončit platby'),
(116279, 2493, 32, 'ukončeno'),
(116280, 2494, 32, 'Finský'),
(116281, 2495, 32, 'První'),
(116282, 2497, 32, 'První den týdne'),
(116283, 2498, 32, 'První jméno'),
(116284, 2499, 32, 'První jméno'),
(116285, 2500, 32, 'První jméno:'),
(116286, 2501, 32, 'První návštěva nebo konzultace'),
(116287, 2503, 32, 'Fyzická zdatnost'),
(116288, 2504, 32, 'Úroveň fyzické zdatnosti'),
(116289, 2505, 32, 'Dnenší úroveň fyzické zdatnosti tohoto hráče'),
(116290, 2506, 32, 'Testování fyzické zdatnosti'),
(116291, 2507, 32, 'Fyzikiá zdatnost  a schopnost hrát'),
(116292, 2508, 32, 'Opravit data vyšetření'),
(116293, 2509, 32, 'Opravit to'),
(116294, 2511, 32, 'Flatulence'),
(116295, 2512, 32, 'Tok'),
(116296, 2514, 32, 'Chřipková sezóna'),
(116297, 2515, 32, 'Chřipková sezóna'),
(116298, 2516, 32, 'Očkování proti chřipce'),
(116299, 2517, 32, 'Problémy elektrolytové rovnováhy a bilance tekutin'),
(116300, 2518, 32, 'FMS'),
(116301, 2519, 32, 'Velikost papíru folio'),
(116302, 2520, 32, 'Sledovat manuálně'),
(116303, 2521, 32, 'Postupujte podle instrukcí k instalaci nebo upgradu následující databáze'),
(116304, 2522, 32, 'Sledování'),
(116305, 2524, 32, 'Důvod sledování'),
(116306, 2525, 32, 'Následující  je nová uživatelská konstanta:'),
(116307, 2526, 32, 'Následující je nový uživatelský jazyk:'),
(116308, 2527, 32, 'Následující je nová definice (Jazyk, Konstanta, Definice):'),
(116309, 2529, 32, 'Následné služby'),
(116310, 2531, 32, 'Potravinová intolerance'),
(116311, 2532, 32, 'Noha'),
(116312, 2533, 32, 'Problémy nohou'),
(116313, 2534, 32, 'Noha:'),
(116314, 2535, 32, 'Fotbalové úrazy'),
(116315, 2536, 32, 'Fotbalový úraz'),
(116316, 2537, 32, 'Hlášení  fotbalového poranění'),
(116317, 2538, 32, 'Typ obuvi'),
(116318, 2539, 32, 'pro'),
(116319, 2540, 32, 'Pro'),
(116320, 2541, 32, 'Pro kód'),
(116321, 2543, 32, 'Pro žádanky o vyšetření'),
(116322, 2544, 32, 'Například:'),
(116323, 2547, 32, 'pro fakturu'),
(116324, 2550, 32, 'pro pacienta'),
(116325, 2552, 32, 'Pro pracoviště/lékaře poskytující vyžádanou péči'),
(116326, 2555, 32, 'pro:'),
(116327, 2556, 32, 'Vynutit otevření widgetu účtování'),
(116328, 2557, 32, 'Vynutit vytvoření nového pacienta'),
(116329, 2558, 32, 'Vynutit zobrazení'),
(116330, 2559, 32, 'Předloktí'),
(116331, 2562, 32, 'Element formuláře nenalezen'),
(116332, 2563, 32, 'Formulář úspěšně podepsán'),
(116333, 2564, 32, 'Formát'),
(116334, 2565, 32, 'formát'),
(116335, 2566, 32, 'Formát zobrazení věku'),
(116336, 2567, 32, 'Formát kódu léčiva není korektkní'),
(116337, 2568, 32, 'Formát zobrazení většiny datumových údajů.'),
(116338, 2569, 32, 'Formát zobrazení většiny časových údajů.'),
(116339, 2570, 32, 'Formátované hlášení'),
(116340, 2571, 32, 'Exkuřák'),
(116341, 2572, 32, 'Formuláře'),
(116342, 2573, 32, 'Správa formulářů'),
(116343, 2575, 32, 'Přeposlat'),
(116344, 2576, 32, 'Přeposlat stránky faxem'),
(116345, 2577, 32, 'Přeposláno'),
(116346, 2579, 32, 'Čtvrtý'),
(116347, 2581, 32, 'Zlomenina'),
(116348, 2582, 32, 'Fractura os naviculare'),
(116349, 2583, 32, 'Zlomenina  zevního kotníku'),
(116350, 2584, 32, 'Zlomenina vnitřního kotníku'),
(116351, 2585, 32, 'zlomenina base V (pátého) metatarsu'),
(116352, 2590, 32, 'Frekvence'),
(116353, 2591, 32, 'Časté nachlazení'),
(116354, 2592, 32, 'Častá nemocnost'),
(116355, 2593, 32, 'Pát'),
(116356, 2594, 32, 'Pátek'),
(116357, 2595, 32, 'Z'),
(116358, 2596, 32, 'Z'),
(116359, 2597, 32, 'z/od'),
(116360, 2598, 32, 'Datum OD nemůže být vyšší než DO'),
(116361, 2599, 32, 'Z/Od:'),
(116362, 2600, 32, 'Z/Od: '),
(116363, 2601, 32, 'Z_MĚSTO'),
(116364, 2602, 32, 'Z_E-MAIL'),
(116365, 2603, 32, 'Z_JMENO'),
(116366, 2604, 32, 'Z_PRIJMENI'),
(116367, 2606, 32, 'Z_TELEFON'),
(116368, 2607, 32, 'Z_MOBIL'),
(116369, 2608, 32, 'Z_POŠTOVNÍ_ADRESA'),
(116370, 2609, 32, 'Z_STÁT'),
(116371, 2610, 32, 'Z_ULICE'),
(116372, 2611, 32, 'Z_NÁZEV'),
(116373, 2613, 32, 'Styk se zákaznky'),
(116374, 2614, 32, 'Styk se zákazníky - příjmy'),
(116375, 2615, 32, 'Styk se zákazníky - příjmy - hlášení'),
(116376, 2617, 32, 'frontálně vpravo:'),
(116377, 2619, 32, 'Celé jméno'),
(116378, 2620, 32, 'Plná cesta k umístění obsahujícímu MySQL spustitelné soubory'),
(116379, 2621, 32, 'Plná cesta k umístění obsahujícímu Perl spustitelné soubory'),
(116380, 2622, 32, 'Plná cesta k umístění pro zálohu logu událostí'),
(116381, 2623, 32, 'Plná cesta k umístění pro dočasné soubory.'),
(116382, 2625, 32, 'Pný trénink'),
(116383, 2626, 32, 'Plně uhrazeno'),
(116384, 2631, 32, 'budoucí'),
(116385, 2633, 32, 'G'),
(116386, 2634, 32, 'G/DL'),
(116387, 2636, 32, 'Stav žlučníku'),
(116388, 2637, 32, 'Cholecystolithiasa'),
(116389, 2639, 32, 'Hry'),
(116390, 2640, 32, 'Hra zmeškána'),
(116391, 2641, 32, 'hry/události'),
(116392, 2642, 32, 'Hry/události zmeškány'),
(116393, 2644, 32, 'Gastritis'),
(116394, 2645, 32, 'Bolesti žaludku'),
(116395, 2646, 32, 'Gastrointestinální'),
(116396, 2647, 32, 'GCAC statistický report'),
(116397, 2648, 32, 'GCAC statistika'),
(116398, 2649, 32, 'GCAC formulář návštěvy chybí'),
(116399, 2650, 32, 'Pohlaví'),
(116400, 2651, 32, 'Pohlaví '),
(116401, 2652, 32, 'Obecný'),
(116402, 2653, 32, 'Seznam obecných problémů'),
(116403, 2655, 32, 'Kategorie obecné služby'),
(116404, 2656, 32, 'Generovat'),
(116405, 2657, 32, 'Vytvořit a stáhnout CMS 1500 pohledávky'),
(116406, 2658, 32, 'Vytvořit a stáhnout HCFA 1500 pohledávky'),
(116407, 2659, 32, 'Vytvořit a stáhnout X12 dávku'),
(116408, 2660, 32, 'Generovat a stáhnout X12 hromadnou žádankou o vyšetření'),
(116409, 2663, 32, 'Vytvořit a odeslat  medikaci elektronicky'),
(116410, 2664, 32, 'Vytvořit CMS 1500'),
(116411, 2665, 32, 'Vytvořitt CMS 1500 PDF'),
(116412, 2666, 32, 'Vytvořitt CMS 1500 TEXT'),
(116413, 2667, 32, 'Vytvořit HCFA'),
(116414, 2668, 32, 'Vytvořit fakturu'),
(116415, 2669, 32, 'Vytvořit dopis'),
(116416, 2670, 32, 'Vytvořit sdělení týkající se '),
(116417, 2671, 32, 'Vytvořit PQRI report ( metoda A )'),
(116418, 2673, 32, 'Vytvořit PQRI report ( metoda E )'),
(116419, 2677, 32, 'Vytvořit report'),
(116420, 2678, 32, 'Vytvořit uživatelské jméno a heslo pro'),
(116421, 2679, 32, 'Vytvořit X12'),
(116422, 2680, 32, 'Vytvořit X12 setkání'),
(116423, 2682, 32, 'Vytvořeno'),
(116424, 2683, 32, 'Generuje'),
(116425, 2684, 32, 'Urogenitální'),
(116426, 2687, 32, 'Němčina'),
(116427, 2691, 32, 'Get HL7'),
(116428, 2692, 32, 'Glaukom'),
(116429, 2693, 32, 'Rodinná anamméza glaukomu'),
(116430, 2694, 32, 'Globální'),
(116431, 2696, 32, 'Globální ID'),
(116432, 2697, 32, 'Globální nastavení'),
(116433, 2698, 32, 'Globální'),
(116434, 2699, 32, 'GM/DL'),
(116435, 2700, 32, 'přejít'),
(116436, 2701, 32, 'Přejít'),
(116437, 2704, 32, 'Přejít na'),
(116438, 2705, 32, 'Přejít do týdne'),
(116439, 2706, 32, 'Přejít na dnešek'),
(116440, 2707, 32, 'Cíl A'),
(116441, 2708, 32, 'Cíle a metody'),
(116442, 2709, 32, 'Cíl B'),
(116443, 2710, 32, 'Cíl C'),
(116444, 2711, 32, 'Stupeň poškození'),
(116445, 2712, 32, 'Stupeň:'),
(116446, 2713, 32, 'gramů'),
(116447, 2720, 32, 'Větší než'),
(116448, 2721, 32, 'Větší nebo rovno'),
(116449, 2722, 32, 'Řečtina'),
(116450, 2723, 32, 'Moderní řečtina'),
(116451, 2724, 32, 'Skupina'),
(116452, 2725, 32, 'Název skupiny'),
(116453, 2726, 32, 'Názvy skupin nemohou být prázdné'),
(116454, 2727, 32, 'Názvy skupin nemohou začínat čísly nebo mezerami'),
(116455, 2728, 32, 'Názvy skupin nemohou začínat čísly'),
(116456, 2729, 32, 'Číslo skupiny'),
(116457, 2730, 32, 'Skupinová platba'),
(116458, 2731, 32, 'Skupina:'),
(116459, 2732, 32, 'Jméno skupiny'),
(116460, 2733, 32, 'Nastavení přístupů a skupin'),
(116461, 2734, 32, 'Růstová křivka'),
(116462, 2735, 32, 'Růstová-křívka'),
(116463, 2736, 32, 'gtt ( kapky )'),
(116464, 2739, 32, 'Jméno opatrovníka'),
(116465, 2741, 32, 'Gynekologické vyšetření'),
(116466, 2742, 32, 'h'),
(116467, 2743, 32, 'h.s'),
(116468, 2744, 32, 'H/O Hepatitis'),
(116469, 2745, 32, 'úspěšně smazáno. Všechny přítomné subkategorie byly přesunuty níže.'),
(116470, 2746, 32, 'Hemathom / modřiny'),
(116471, 2747, 32, 'HAI status'),
(116472, 2750, 32, 'Ruka + prsty'),
(116473, 2751, 32, 'Problémy s rukou'),
(116474, 2752, 32, 'Harddisk'),
(116475, 2753, 32, 'Utrpení'),
(116476, 2754, 32, 'připojeno k návštěvě'),
(116477, 2755, 32, 'po lhůtě'),
(116478, 2756, 32, 'Kontrolní součet'),
(116479, 2757, 32, 'Kontrolní součet pro tento soubor neexistuje. Nový kontrolní součet byl vytvořen.'),
(116480, 2758, 32, 'Kontrolní součet nesedí. Integrita dat je v ohrožení'),
(116481, 2761, 32, 'Hazardní aktivity'),
(116482, 2762, 32, 'Hazardní aktivity'),
(116483, 2763, 32, 'HCFA levá hranice v bodech'),
(116484, 2764, 32, 'HCFA hranice'),
(116485, 2765, 32, 'HCFA horní hranice v bodech'),
(116486, 2766, 32, 'HCPCD Procedura/Služba'),
(116487, 2768, 32, 'Hlava'),
(116488, 2769, 32, 'Obvod hlavy'),
(116489, 2770, 32, 'Obvod hlavy'),
(116490, 2771, 32, 'Bolesti hlavy'),
(116491, 2772, 32, 'Cefalgie'),
(116492, 2773, 32, 'Zdravotnické operace'),
(116493, 2774, 32, 'Zdravotnické operace'),
(116494, 2775, 32, 'léčebné centrum/klinika'),
(116495, 2778, 32, 'Hypacusis'),
(116496, 2779, 32, 'Kardiální příhoda'),
(116497, 2780, 32, 'Srdeční onemocnění'),
(116498, 2781, 32, 'Srdeční selhání'),
(116499, 2782, 32, 'Kardiální obtíže'),
(116500, 2783, 32, 'Kardiální obtíže'),
(116501, 2784, 32, 'Kardiochirurgie'),
(116502, 2785, 32, 'Transplantace srdce'),
(116503, 2786, 32, 'SRDCE:'),
(116504, 2787, 32, 'Pálení žáhy'),
(116505, 2788, 32, 'Teplo nebo chlad'),
(116506, 2789, 32, 'Teplo nebo chlad'),
(116507, 2790, 32, 'Velmi silný kuřák'),
(116508, 2791, 32, 'Hebrejština'),
(116509, 2792, 32, 'Hebrejština (moderní)'),
(116510, 2794, 32, 'Výška'),
(116511, 2795, 32, 'Výška/Délka'),
(116512, 2796, 32, 'pomoc'),
(116513, 2797, 32, 'pomoc'),
(116514, 2798, 32, 'Hemathemesa'),
(116515, 2799, 32, 'Krev ve stolici'),
(116516, 2800, 32, 'Hematologický'),
(116517, 2801, 32, 'Hematurie'),
(116518, 2802, 32, 'Hemoglobin'),
(116519, 2803, 32, 'Hemoglobin A1C'),
(116520, 2804, 32, 'Hemoptýza'),
(116521, 2805, 32, 'Hepatitis'),
(116522, 2806, 32, 'Hepatitis A 1'),
(116523, 2807, 32, 'Hepatitis A 2'),
(116524, 2808, 32, 'Hepatitis B 1'),
(116525, 2809, 32, 'Hepatitis B 2'),
(116526, 2810, 32, 'hepatitis B 3'),
(116527, 2811, 32, 'zde'),
(116528, 2813, 32, 'Operace kýly'),
(116529, 2814, 32, 'Hernie disku'),
(116530, 2815, 32, 'Herpes'),
(116531, 2816, 32, 'hesitace ( pohybová váhavost)'),
(116532, 2817, 32, 'Ahoj, byli jste zde pro '),
(116533, 2818, 32, 'HIB vakcína 1'),
(116534, 2819, 32, 'HIB vakcína 2'),
(116535, 2820, 32, 'HIB vakcína 3'),
(116536, 2821, 32, 'HIB vakcína 4'),
(116537, 2822, 32, 'Skryté'),
(116538, 2823, 32, 'Správa skrytých událostí'),
(116539, 2824, 32, 'Skrýt'),
(116540, 2825, 32, 'Skrýt detaily'),
(116541, 2826, 32, 'Skrýt prázdné logy e-podpisu'),
(116542, 2827, 32, 'Skrýt volby pro šifrování dokumentů'),
(116543, 2828, 32, 'Skrýt nabídku'),
(116544, 2830, 32, 'Skrýt upomínky'),
(116545, 2831, 32, 'Skýt/Zobrazit sloupce'),
(116546, 2833, 32, 'Vysoký'),
(116547, 2834, 32, 'Vysoký krevní tlak'),
(116548, 2836, 32, 'Kyčel + tříslo'),
(116549, 2837, 32, 'Kyčel a tříslo'),
(116550, 2838, 32, 'Problémy s kyčlemi'),
(116551, 2839, 32, 'TEP kyčelního kloubu'),
(116552, 2840, 32, 'HIPAA vyhláška přijata'),
(116553, 2842, 32, 'Hirsutismus/Strie'),
(116554, 2847, 32, 'Anamnéza'),
(116555, 2848, 32, 'Anamnestická data'),
(116556, 2849, 32, 'Datum anamnézy'),
(116557, 2851, 32, 'Anamnéza šelestu'),
(116558, 2852, 32, 'Anamnéza není autorizována'),
(116559, 2853, 32, 'Anamnéza srdečního šelestu'),
(116560, 2855, 32, 'HIV'),
(116561, 2858, 32, 'HL7 prohlížeč'),
(116562, 2860, 32, 'HMOL/L'),
(116563, 2862, 32, 'Stiskněte CTRL pro hromadný výběr'),
(116564, 2863, 32, 'Stiskněte CTRL pro hromadný výběr položek'),
(116565, 2864, 32, 'Stiskněte CTRL pro hromadný výběr oddílů'),
(116566, 2865, 32, 'Domov'),
(116567, 2866, 32, 'Telefon domů'),
(116568, 2867, 32, 'Telefonní číslo domů'),
(116569, 2868, 32, 'Bezdomovec nebo obdobný ?'),
(116570, 2869, 32, 'Bezdomovec, atd.'),
(116571, 2870, 32, 'Bezdomovec, atd.'),
(116572, 2872, 32, 'Hostitelské jméno'),
(116573, 2873, 32, 'Hostitelské jméno nemůže být prázdné'),
(116574, 2875, 32, 'Hodina'),
(116575, 2876, 32, 'Hodiny'),
(116576, 2878, 32, 'Jak došlo ke zranění ?'),
(116577, 2879, 32, 'Jak došlo ke zranění ?'),
(116578, 2880, 32, 'Jak se o nás dozvěděli ?'),
(116579, 2881, 32, 'Kolik měsíců předchází  dotazu na nadcházející události ?'),
(116580, 2882, 32, 'NO:'),
(116581, 2883, 32, 'HT'),
(116582, 2884, 32, 'HTML'),
(116583, 2885, 32, 'HTML výstup ?'),
(116584, 2886, 32, 'Https odkaz na LibreEHR Support LLC Lab Echange Service'),
(116585, 2887, 32, 'Maďarština'),
(116586, 2888, 32, 'Hylafax adresář'),
(116587, 2889, 32, 'Hylafax Enscript příkaz'),
(116588, 2890, 32, 'Hylafax server'),
(116589, 2891, 32, 'Jméno hostitelského Hylafax serveru'),
(116590, 2892, 32, 'Hyperaktivita'),
(116591, 2893, 32, 'Hypertenze'),
(116592, 2894, 32, 'Hypertenze: Měření krevního tlaku'),
(116593, 2895, 32, 'Hypertenze: Měření krevního tlaku (CQM)'),
(116594, 2896, 32, 'Hyperthyreosa'),
(116595, 2897, 32, 'Hypothyreosa'),
(116596, 2898, 32, 'Hysterektomie'),
(116597, 2899, 32, 'Já'),
(116598, 2900, 32, 'Aktuálně jsem zaneprázdněn'),
(116599, 2901, 32, 'Nemám oprávnění ke čtení '),
(116600, 2902, 32, 'MKN'),
(116601, 2903, 32, 'MKN10 Diagnózy'),
(116602, 2904, 32, 'MKN10 Procedura/Služba'),
(116603, 2905, 32, 'MKN9'),
(116604, 2906, 32, 'MKN9 Diagnózy'),
(116605, 2907, 32, 'MKN9 Procedura/Služba'),
(116606, 2909, 32, 'ID'),
(116607, 2910, 32, 'Id'),
(116608, 2911, 32, 'ID nemůže být prázdné'),
(116609, 2912, 32, 'Občanský průkaz'),
(116610, 2914, 32, 'identifikovaný jako'),
(116611, 2915, 32, 'Identifikátor ( jednoslovně )'),
(116612, 2916, 32, 'Identifikační kód'),
(116613, 2917, 32, 'Timeout pro nečinné sezení v sekundách'),
(116614, 2919, 32, 'Jestliže formulář obsahuje kompletní data pro všechny sloupce'),
(116615, 2921, 32, 'pokud bylo zadáno, vyberte pouze ty kdo využili tuto službu'),
(116616, 2922, 32, 'V případě jména, jakákoliv část příjmení, jména'),
(116617, 2923, 32, 'Pokud platíte'),
(116618, 2924, 32, 'Pokud osoba zemřela, zadejte datum smrti'),
(116619, 2925, 32, 'V případě použití SMTP, zadejte hostitelské jméno serveru nebo IP adresu'),
(116620, 2926, 32, 'V případě použití SMTP, zadejte číslo portu TCP'),
(116621, 2927, 32, 'pokud nezaměstnaný , zadejte student'),
(116622, 2929, 32, 'Pokud měníte e-RX roli pro e-preskripci, může to mít dopady na procesy ePreskripce.'),
(116623, 2930, 32, 'Nebude-li vybráno, bude vytvořen odpovídající pacient'),
(116624, 2933, 32, 'Pokud chcete změnit typ dat nebo přidat sloupce či řádky'),
(116625, 2934, 32, 'Pokud chcete provést upgrade databáze, pak vložte databázový ZIP soubor do následujícího adresáře'),
(116626, 2936, 32, 'Ignorovat'),
(116627, 2937, 32, 'Onemocnění'),
(116628, 2938, 32, 'IM'),
(116629, 2941, 32, 'Zobrazovací metody'),
(116630, 2942, 32, 'Očkování'),
(116631, 2943, 32, 'Kód vakcinace'),
(116632, 2945, 32, 'Datum vakcinace'),
(116633, 2946, 32, 'Expirace imunizace'),
(116634, 2948, 32, 'Výobce vakcíny'),
(116635, 2952, 32, 'Název očkování'),
(116636, 2953, 32, 'Očkování'),
(116637, 2954, 32, 'Imunizovat'),
(116638, 2955, 32, 'Imunologický'),
(116639, 2956, 32, 'Implantáty'),
(116640, 2957, 32, 'Import'),
(116641, 2961, 32, 'Importovat certifikát do prohlížeče'),
(116642, 2962, 32, 'Importovat konfiguraci'),
(116643, 2964, 32, 'Importovat pacienta'),
(116644, 2965, 32, 'Importovat identifikační údaje pacienta'),
(116645, 2966, 32, 'Důležité kódy'),
(116646, 2969, 32, 'Importováno z účetnictví'),
(116647, 2972, 32, 'vylepšeno'),
(116648, 2973, 32, 'v'),
(116649, 2974, 32, 'V'),
(116650, 2975, 32, 'v obou očích'),
(116651, 2976, 32, 'v levém oku'),
(116652, 2977, 32, 'v nozdře'),
(116653, 2978, 32, 'V kanceláři'),
(116654, 2979, 32, 'v pravém oku'),
(116655, 2980, 32, 'v domě'),
(116656, 2981, 32, 'Neaktivní'),
(116657, 2982, 32, 'Dny neaktivity'),
(116658, 2983, 32, 'Doručená pošta'),
(116659, 2986, 32, 'Zahrnutí kontrolního součtu'),
(116660, 2987, 32, 'Zahrnuje dokončené'),
(116661, 2988, 32, 'Zahrnuje neaktivní uživatele'),
(116662, 2989, 32, 'Obsahuje nezařazené'),
(116663, 2990, 32, 'Obsahuje nestrukturovaná data'),
(116664, 2991, 32, 'Obsahuje životní funkce'),
(116665, 2992, 32, 'Obsahuje data vitálních funkcí ?'),
(116666, 2993, 32, 'Zařazení'),
(116667, 2994, 32, 'Příjem'),
(116668, 2995, 32, 'Příchozí výsledky vyžadující zvýšenou pozornost:'),
(116669, 2996, 32, 'Nekompletní'),
(116670, 2997, 32, 'Léčba neúplného potratu'),
(116671, 2998, 32, 'Inkontinence'),
(116672, 3000, 32, 'Nesprávné heslo!'),
(116673, 3001, 32, 'zvýšené:'),
(116674, 3003, 32, 'Neurčitý'),
(116675, 3005, 32, 'indikuje abnromalitu'),
(116676, 3006, 32, 'Indikuje aktuální aktivitu problému'),
(116677, 3008, 32, 'Indikátor pro specializovaní užití'),
(116678, 3014, 32, 'Indukovaný potrat'),
(116679, 3016, 32, 'nevhodný'),
(116680, 3017, 32, 'Infekce / Absces'),
(116681, 3018, 32, 'Infekce'),
(116682, 3020, 32, 'Neplodnost'),
(116683, 3021, 32, 'Chřipka 1'),
(116684, 3022, 32, 'Chřipka 2'),
(116685, 3023, 32, 'Očkování proti chřipce pro pacienty starší 50 let'),
(116686, 3024, 32, 'Očkování proti chřipce pro pacienty starší 50 let ( CQM )'),
(116687, 3025, 32, 'Očkovací látka proti chřipce'),
(116688, 3026, 32, 'Info'),
(116689, 3027, 32, 'Info test 1'),
(116690, 3028, 32, 'Info test 2'),
(116691, 3029, 32, 'Info test 3'),
(116692, 3030, 32, 'Info tets 4'),
(116693, 3031, 32, 'Info test 5'),
(116694, 3032, 32, 'Info test 6'),
(116695, 3034, 32, 'inhalace'),
(116696, 3035, 32, 'inhalace'),
(116697, 3036, 32, 'Úvodní léčba'),
(116698, 3037, 32, 'Prvotní uživatel'),
(116699, 3038, 32, 'Inj/Rehab'),
(116700, 3039, 32, 'Inkekční'),
(116701, 3040, 32, 'Injekce'),
(116702, 3041, 32, 'Poraněná část těla'),
(116703, 3042, 32, 'Následky úrazu'),
(116704, 3043, 32, 'Úraz'),
(116705, 3044, 32, 'Úrazový mechanismus'),
(116706, 3045, 32, 'Hlášení o úraze'),
(116707, 3047, 32, 'typ úrazu'),
(116708, 3048, 32, 'vztah k Úrazu/onemocnění'),
(116709, 3049, 32, 'V řadě za sebou'),
(116710, 3051, 32, 'Vstupní pole'),
(116711, 3052, 32, 'INR'),
(116712, 3068, 32, 'Vložit'),
(116713, 3069, 32, 'Vožení selhalo: '),
(116714, 3070, 32, 'Vložit staré události do tabulky'),
(116715, 3072, 32, 'Nespavost'),
(116716, 3073, 32, 'Prohlédnout log'),
(116717, 3074, 32, 'Inspekce'),
(116718, 3075, 32, 'Instabilita / subluxace'),
(116719, 3076, 32, 'INSTALOVAT'),
(116720, 3077, 32, 'Instalovat'),
(116721, 3078, 32, 'Instalovat sadu kódů'),
(116722, 3079, 32, 'Instalovat DB'),
(116723, 3080, 32, 'Instalované vydání'),
(116724, 3081, 32, 'Poučen'),
(116725, 3082, 32, 'Instrukce'),
(116726, 3084, 32, 'Instrukce:'),
(116727, 3086, 32, 'Diabetes mellitus insulin dependentní'),
(116728, 3087, 32, 'Pojištění'),
(116729, 3088, 32, 'Pojištění'),
(116730, 3091, 32, 'Bilance pojištění'),
(116731, 3094, 32, 'Pojišťovny'),
(116732, 3095, 32, 'Pojišťovna'),
(116733, 3096, 32, 'Hledat/Přidat pojišťovnu'),
(116734, 3098, 32, 'Údaje o pojištění'),
(116735, 3100, 32, 'Čísla pojištění'),
(116736, 3101, 32, 'Platby pojištění'),
(116737, 3103, 32, 'Poskytovatel pojištění'),
(116738, 3104, 32, 'Typy pojištění'),
(116739, 3105, 32, 'Pojištění'),
(116740, 3106, 32, 'Pojištěn'),
(116741, 3107, 32, 'Závěr při příjmu'),
(116742, 3108, 32, 'Datum příjmu'),
(116743, 3109, 32, 'Úbytek intelektu'),
(116744, 3113, 32, 'Vnitřní chyba - nebyly vybrány žádné strany !'),
(116745, 3114, 32, 'Vnitřní chyba - ID pacienta není k dispozici'),
(116746, 3115, 32, 'Vnitřní chyba přístupu k nahranému souboru!'),
(116747, 3116, 32, 'Vnitřní chyba!'),
(116748, 3117, 32, 'Vnitřní chyba, ID medikace nespecifikováno'),
(116749, 3118, 32, 'Vnitřní chyba: Nelze nalézt MSH-10'),
(116750, 3119, 32, 'Vnitřní chyba: požadavek '),
(116751, 3120, 32, 'Vnitřní chyba: vyšetření'),
(116752, 3121, 32, 'Vnitřní chyba: pid nebo návštěva chybí.'),
(116753, 3123, 32, 'Vnitřní identifikátor (pid)'),
(116754, 3126, 32, 'Interní doporučení'),
(116755, 3128, 32, 'Clo'),
(116756, 3131, 32, 'Intersticiální plicní fibróza'),
(116757, 3132, 32, 'Interval'),
(116758, 3133, 32, 'Interval ( minuty )'),
(116759, 3134, 32, 'Kontrolní interval mezi zprávami ( pro výhradně manuální kontroly nastavte 0 )'),
(116760, 3135, 32, 'Intervence'),
(116761, 3136, 32, 'Poskytnuta intervence'),
(116762, 3137, 32, 'Intolerance'),
(116763, 3139, 32, 'intramusklulárně'),
(116764, 3140, 32, 'intravenózně'),
(116765, 3141, 32, 'Uvedení'),
(116766, 3144, 32, 'Nepřípustný znak v'),
(116767, 3147, 32, 'Nepřípustná délka pro'),
(116768, 3148, 32, 'Nepřípustný nečíselný znak v'),
(116769, 3149, 32, 'Chybný nebo chybějící plátce '),
(116770, 3150, 32, 'Chybaná adresa příjemce. Zkuste to prosím znova.'),
(116771, 3151, 32, 'Chybné kódy služby'),
(116772, 3152, 32, 'Chybné označení zdroje "'),
(116773, 3153, 32, 'Chybné uživatelské jméno nebo heslo'),
(116774, 3155, 32, 'Inventarizace'),
(116775, 3156, 32, 'Inventúra'),
(116776, 3157, 32, 'Inventarizace a prodej léčiv a ostatních produktů'),
(116777, 3158, 32, 'Inventarizace a prodej léčiv'),
(116778, 3159, 32, 'Pro tuto objdnávku není dostupná inventarizace'),
(116779, 3160, 32, 'Inventární seznam'),
(116780, 3161, 32, 'Inventarizační transakce'),
(116781, 3162, 32, 'Faktura'),
(116782, 3163, 32, 'faktura'),
(116783, 3166, 32, 'Datum vystavení faktury'),
(116784, 3167, 32, 'Faktura není datována!'),
(116785, 3168, 32, 'Číslo faktury'),
(116786, 3169, 32, 'Referenční číslo faktury'),
(116787, 3173, 32, 'Faktura:'),
(116788, 3180, 32, 'IPV 1'),
(116789, 3181, 32, 'IPV 2'),
(116790, 3182, 32, 'IPV 3'),
(116791, 3183, 32, 'IPV 4'),
(116792, 3185, 32, 'Nepravidelný srdeční rytmus'),
(116793, 3186, 32, 'Dráždivost'),
(116794, 3187, 32, 'Irritace'),
(116795, 3188, 32, 'je rozdílná jazyková verze následující databáze'),
(116796, 3190, 32, 'je novější verze následující databáze'),
(116797, 3191, 32, 'je vyžadovanou položkou.'),
(116798, 3192, 32, 'je klíčovým uzlem a nelze smazat.');
INSERT INTO `lang_definitions` VALUES
(116799, 3193, 32, 'je rozšíření následující databáze'),
(116800, 3195, 32, 'je chybné umístění nebo  neznámý původ'),
(116801, 3197, 32, 'neplatné'),
(116802, 3198, 32, 'Běží PHP v bezpečném módu?'),
(116803, 3200, 32, 'Je text z formulářů přeložen?'),
(116804, 3201, 32, 'Je text seznamů přeložen?'),
(116805, 3202, 32, 'Je tento soubor šifrovaný?'),
(116806, 3203, 32, 'Jde o typ kódu pro klinický termín ?'),
(116807, 3204, 32, 'Jde o typ diagnózy ?'),
(116808, 3205, 32, 'Jde o typ kódu pro zdravotní problém ?'),
(116809, 3206, 32, 'Jde o typ medikace ?'),
(116810, 3207, 32, 'Jde o typ procedury/služby ?'),
(116811, 3208, 32, 'Je aktivní ?'),
(116812, 3209, 32, 'Jde o aktivní typ kódu ?'),
(116813, 3210, 32, 'Jde o typ kódu použitý v požadavku ?'),
(116814, 3211, 32, 'Je to opravdu OK ?'),
(116815, 3213, 32, 'jsou použity externí sql tabulky? Pokud ano, vyberte formát.'),
(116816, 3214, 32, 'příliš dlouhé'),
(116817, 3215, 32, 'ISO 639-2 kód'),
(116818, 3216, 32, 'problém'),
(116819, 3217, 32, 'problém'),
(116820, 3218, 32, 'Datum vzniku obtíží'),
(116821, 3219, 32, 'ID problému'),
(116822, 3220, 32, 'Název problému'),
(116823, 3221, 32, 'Typ problému'),
(116824, 3222, 32, 'Typy problémů'),
(116825, 3223, 32, 'Problémy'),
(116826, 3224, 32, 'Problémy (Úrazy/Zdravotní/Alergie)'),
(116827, 3225, 32, 'Problémy (Úrazy/Zdravotní/Alergie)'),
(116828, 3226, 32, 'Problémy a návštěvy'),
(116829, 3227, 32, 'Problémy  a vyšetření pro'),
(116830, 3228, 32, 'problémy neautorizovány'),
(116831, 3229, 32, 'Oblast problémů'),
(116832, 3230, 32, 'Italština'),
(116833, 3231, 32, 'Položka'),
(116834, 3232, 32, 'položka'),
(116835, 3233, 32, 'položky'),
(116836, 3234, 32, 'zavedení položek se nezdařilo'),
(116837, 3235, 32, 'IU/L'),
(116838, 3236, 32, 'IUD'),
(116839, 3237, 32, 'IV'),
(116840, 3238, 32, 'Led'),
(116841, 3239, 32, 'Leden'),
(116842, 3240, 32, 'Japonština'),
(116843, 3243, 32, 'Popis pracovního zařazení'),
(116844, 3244, 32, 'ID zaměstnání'),
(116845, 3245, 32, 'Kloubní dislokace'),
(116846, 3246, 32, 'Kloubní bolest'),
(116847, 3247, 32, 'Vymknutí kloubu'),
(116848, 3248, 32, 'Čerc'),
(116849, 3249, 32, 'Červenec'),
(116850, 3250, 32, 'Čer'),
(116851, 3251, 32, 'Červen'),
(116852, 3252, 32, 'Těsně pod kontrolní informací je modrá oblast pro vložení vyhledávacích parametrů. Můžete vyhledávat podle jména pacienta, čísla grafu, čísla vyšetření nebo data služby. Lze použít i kombinace. Můžete si také vybrat jaké faktury chcete zobrazit. Klepněte na tlačítko Hledat pro  vyhledávání.'),
(116853, 3264, 32, 'Klíč'),
(116854, 3265, 32, 'klíčové slovo'),
(116855, 3266, 32, 'kg'),
(116856, 3267, 32, 'kg/m2'),
(116857, 3269, 32, 'Karcinom ledviny'),
(116858, 3270, 32, 'Renální selhání'),
(116859, 3271, 32, 'Nefritis'),
(116860, 3272, 32, 'Nefrolithiáza'),
(116861, 3273, 32, 'Transplantace ledviny'),
(116862, 3277, 32, 'Koleno'),
(116863, 3278, 32, 'Poruchy kolenního kloubu'),
(116864, 3279, 32, 'Náhrada kolenního kloubu'),
(116865, 3286, 32, 'Lab'),
(116866, 3287, 32, 'Laboratorní dokumenty'),
(116867, 3288, 32, 'Adresa stránky pro sdílení laboratorních informací'),
(116868, 3289, 32, 'ID stránky sdílení laboratorních informací'),
(116869, 3291, 32, 'Laboratorní žádanka'),
(116870, 3292, 32, 'Laboratorní přehled'),
(116871, 3293, 32, 'Laboratorní přehled'),
(116872, 3294, 32, 'Stav laboratorního dotazu'),
(116873, 3295, 32, 'Laboratorní report'),
(116874, 3296, 32, 'Laboratorní výsledek'),
(116875, 3297, 32, 'Laboratorní výsledky'),
(116876, 3298, 32, 'Jméno kategorie laboratorních výsledků'),
(116877, 3299, 32, 'Report laboratorních výsledků'),
(116878, 3300, 32, 'Laboratorní služba'),
(116879, 3301, 32, 'Výsledky laboratorních testů'),
(116880, 3302, 32, 'Lab/Soubor'),
(116881, 3303, 32, 'Štítek'),
(116882, 3304, 32, 'Štítek nemůže bgýt prázdný'),
(116883, 3306, 32, 'Štítek pro tento typ'),
(116884, 3308, 32, 'Štítky'),
(116885, 3311, 32, 'Laboratoře'),
(116886, 3312, 32, 'Lacerace / stav kůže'),
(116887, 3313, 32, 'Lacerace/abraze'),
(116888, 3316, 32, 'Jazyk'),
(116889, 3317, 32, 'Kód jazyka'),
(116890, 3318, 32, 'Přidána jazyková definice'),
(116891, 3319, 32, 'Nástroj jazykového rozhraní'),
(116892, 3320, 32, 'Seznam jazyků ( na výběr právo zápisovat / přidat )'),
(116893, 3321, 32, 'Jméno jazyku'),
(116894, 3322, 32, 'Jazyk:'),
(116895, 3325, 32, 'Poslední'),
(116896, 3326, 32, 'Datum poslední aktivity'),
(116897, 3328, 32, 'Poslední datum platby:'),
(116898, 3329, 32, 'Poslední vyšetření prsou'),
(116899, 3330, 32, 'Minulý kalendářní rok'),
(116900, 3333, 32, 'Minulé vyšetření'),
(116901, 3334, 32, 'Poslední gynekologické vyšetření'),
(116902, 3341, 32, 'Poslední mamografické vyšetření'),
(116903, 3342, 32, 'Poslední menstruace'),
(116904, 3343, 32, 'Minulý mesíc'),
(116905, 3344, 32, 'Příjmení'),
(116906, 3345, 32, 'Příjmení'),
(116907, 3346, 32, 'Příjmení:'),
(116908, 3347, 32, 'Poslední fyzikální vyšetření'),
(116909, 3348, 32, 'Poslední vyšetření prostaty'),
(116910, 3349, 32, 'Poslední vyšetření per rectum'),
(116911, 3350, 32, 'Poslední zhodnocení'),
(116912, 3351, 32, 'Naposledy spuštěno v'),
(116913, 3352, 32, 'Naposledy uloženo'),
(116914, 3353, 32, 'Poslední Sigmoideo/koloskopie'),
(116915, 3356, 32, 'Naposledy aktualizováno'),
(116916, 3357, 32, 'Naposledy ověřeno'),
(116917, 3358, 32, 'Poslední návštěva'),
(116918, 3359, 32, 'Poslední RTG'),
(116919, 3360, 32, 'Poslední rekurence (2-12 měs)'),
(116920, 3361, 32, 'Zevní kotník'),
(116921, 3362, 32, 'Zevní kotník:'),
(116922, 3363, 32, 'Lateralita'),
(116923, 3364, 32, 'Lateralita této procedury ( pokud je použitelné)'),
(116924, 3367, 32, 'Poslední návštěva nebo konzultace'),
(116925, 3372, 32, 'Rozvržení'),
(116926, 3374, 32, 'Úpravy rozvržení'),
(116927, 3375, 32, 'Skupiny rozvržení'),
(116928, 3379, 32, 'Rozvržení'),
(116929, 3380, 32, 'libra'),
(116930, 3381, 32, 'liber'),
(116931, 3382, 32, 'LDL'),
(116932, 3383, 32, 'nechte prázdné pokud je stále aktivní'),
(116933, 3384, 32, 'Ponechte prázdné pro zachování původního jména souboru'),
(116934, 3385, 32, 'ponechte prázdné pro zachování původního hesla'),
(116935, 3386, 32, 'Zanechte zprávu s'),
(116936, 3387, 32, 'Odejít z formuláře'),
(116937, 3388, 32, 'Pokdu nezadáte heslo, dokument nebude šifrován'),
(116938, 3390, 32, 'Levý'),
(116939, 3391, 32, 'Levé ucho'),
(116940, 3392, 32, 'levé ucho'),
(116941, 3393, 32, 'Levý okraj (mm)'),
(116942, 3394, 32, 'Vlevo:'),
(116943, 3395, 32, 'Vlevo: '),
(116944, 3396, 32, 'Bolest dolní končetiny/křeče'),
(116945, 3399, 32, 'Legal formát papíru'),
(116946, 3400, 32, 'Legenda:'),
(116947, 3401, 32, 'Délka'),
(116948, 3402, 32, 'Délka modifikátoru, 0= žádná'),
(116949, 3403, 32, 'Menší než'),
(116950, 3404, 32, 'Menší nebo rovno'),
(116951, 3405, 32, 'Méně citlivé informace ( volitelně právo zapisovat, přidat)'),
(116952, 3406, 32, 'Dopis'),
(116953, 3407, 32, 'Generátor dopisu'),
(116954, 3408, 32, 'Formát papíru Dopis'),
(116955, 3409, 32, 'Místo pro podpis lékaře'),
(116956, 3410, 32, 'Místo pro podpis pacienta'),
(116957, 3411, 32, 'Stupeň naléhavosti'),
(116958, 3412, 32, 'Odpovědnost'),
(116959, 3413, 32, 'Lékařská odpovědnost'),
(116960, 3414, 32, 'ID/Licence'),
(116961, 3423, 32, 'Životní styl'),
(116962, 3424, 32, 'Charakter životního stylu'),
(116963, 3425, 32, 'Ruptura nebo distenze ligamenta'),
(116964, 3426, 32, 'Lehký kuřák'),
(116965, 3428, 32, 'Limit událostí'),
(116966, 3429, 32, 'Limity'),
(116967, 3431, 32, 'Odkaz'),
(116968, 3432, 32, 'Odkaz na pacienta'),
(116969, 3433, 32, 'Napojený'),
(116970, 3434, 32, 'Napojený dokument'),
(116971, 3435, 32, 'Napojená žádanka o výkon'),
(116972, 3436, 32, 'napojeno na dokument'),
(116973, 3437, 32, 'napojeno na objednávku výkonu'),
(116974, 3438, 32, 'Seznam'),
(116975, 3439, 32, 'Pole seznamu'),
(116976, 3440, 32, 'pole seznamu'),
(116977, 3441, 32, 'pole seznamu zapis./přidat'),
(116978, 3442, 32, 'Pole seznamu zapis./přid.'),
(116979, 3443, 32, 'Editor seznamu'),
(116980, 3444, 32, 'Seznam vyšetření'),
(116981, 3445, 32, 'Seznam skupin'),
(116982, 3446, 32, 'Seznam pojišťoven'),
(116983, 3448, 32, 'Položka seznamu nemůže začínat číslem'),
(116984, 3449, 32, 'Položka seznamu obsahuje neplatné znaky'),
(116985, 3451, 32, 'Výsledek hledání v seznamu'),
(116986, 3452, 32, 'Jméno seznamu'),
(116987, 3453, 32, 'Jména seznamů nemohou začínat čísly'),
(116988, 3454, 32, 'Seznam předpisů a receptů'),
(116989, 3457, 32, 'Naslouchající port RFC 5425 TLS Syslog serveru'),
(116990, 3458, 32, 'Seznamy'),
(116991, 3460, 32, 'Rozhodnutí o pokračování přístrojové podpory vitálních funkcí'),
(116992, 3461, 32, 'LLL:'),
(116993, 3462, 32, 'Poslední mestruace'),
(116994, 3463, 32, 'Nahrát  přehled'),
(116995, 3464, 32, 'Nahrát definice'),
(116996, 3465, 32, 'Nahrát laboratorní konfiguraci'),
(116997, 3466, 32, 'Nahrát volby OE otázek'),
(116998, 3467, 32, 'Nahrát deficinice objednávek'),
(116999, 3469, 32, 'ÚSPĚŠNĚ NAHRÁNO. Kódy vloženy'),
(117000, 3470, 32, 'NAHRÁVÁNÍ'),
(117001, 3471, 32, 'Nahrávání dat do databáze může chvíli trvat...'),
(117002, 3473, 32, 'Lokální'),
(117003, 3474, 32, 'Lokální obsah'),
(117004, 3475, 32, 'Lokální souborový systém'),
(117005, 3477, 32, 'Lokalita'),
(117006, 3478, 32, 'Umístění'),
(117007, 3479, 32, 'umístění PC s LibreEHR a může obsahovat citlivá data. Doporučujeme data ručně smazat po jejich použití.'),
(117008, 3481, 32, 'Umístění nespecifikováno'),
(117009, 3482, 32, 'Umístění pro ukládání faxů HylaFax'),
(117010, 3483, 32, 'Umístění pro ukládání skenovaných dokumentů'),
(117011, 3484, 32, 'Umístění:'),
(117012, 3485, 32, 'Zamknout'),
(117013, 3486, 32, 'Individuální uzamčení e-podepsaného formuláře'),
(117014, 3487, 32, 'Uzamčení e-podepsaných vyšetření a jejich formulářů'),
(117015, 3488, 32, 'Zamknout ?'),
(117016, 3489, 32, 'Uzamčeno'),
(117017, 3492, 32, 'Přihlášení'),
(117018, 3493, 32, 'Přihlášení'),
(117019, 3494, 32, 'Odhlášení'),
(117020, 3495, 32, 'Přihlášen'),
(117021, 3496, 32, 'Přihlášen jako'),
(117022, 3497, 32, 'Přihlášen jako: '),
(117023, 3498, 32, 'Odhlášen.'),
(117024, 3499, 32, 'Protokolování'),
(117025, 3500, 32, 'Přihlášení do systému'),
(117026, 3501, 32, 'přihlášení do systému'),
(117027, 3502, 32, 'Přihlašovací jméno uživatele WordPress pro přístup k portálu'),
(117028, 3503, 32, 'Přihlášení k vzdáleného hostu'),
(117029, 3504, 32, 'Přihlášení k vzdáleného hostu selhalo'),
(117030, 3505, 32, 'Odhlášení'),
(117031, 3506, 32, 'odhlášení'),
(117032, 3507, 32, 'Protokoly'),
(117033, 3508, 32, 'Prohlížeč protokolů'),
(117034, 3510, 32, 'Vyhledat'),
(117035, 3514, 32, 'Nízký'),
(117036, 3515, 32, 'Nízká priorita'),
(117037, 3516, 32, 'Bérec a noha'),
(117038, 3517, 32, 'Nejnižší priorita'),
(117039, 3519, 32, 'Bederní páteř'),
(117040, 3520, 32, 'OBĚD'),
(117041, 3521, 32, 'Oběd'),
(117042, 3522, 32, 'Karcinom plic'),
(117043, 3523, 32, 'Operace plicního karcinomu'),
(117044, 3524, 32, 'PLÍCE:'),
(117045, 3525, 32, 'plíce:'),
(117046, 3526, 32, 'Lupus'),
(117047, 3528, 32, 'M'),
(117048, 3529, 32, 'Kategorie MA'),
(117049, 3533, 32, 'Pošta odeslána'),
(117050, 3534, 32, 'Hlavní'),
(117051, 3535, 32, 'Hlavní adresa'),
(117052, 3536, 32, 'Hlavní část obrazovky'),
(117053, 3538, 32, 'Zachovat list aktivní medikace'),
(117054, 3540, 32, 'Modifikovat aktuální kategorie'),
(117055, 3541, 32, 'Vytvořit novou návštěvu pro'),
(117056, 3542, 32, 'Ověřte si "'),
(117057, 3545, 32, 'Malátnost:'),
(117058, 3548, 32, 'Muž'),
(117059, 3549, 32, 'Mužský kondom'),
(117060, 3550, 32, 'Mužský VSC'),
(117061, 3552, 32, 'Mamograf'),
(117062, 3553, 32, 'Spravovat'),
(117063, 3555, 32, 'Spravovat moduly'),
(117064, 3556, 32, 'Spravovat překlady'),
(117065, 3557, 32, 'Management'),
(117066, 3558, 32, 'Povinná a specifikovaná pole'),
(117067, 3561, 32, 'Manuál'),
(117068, 3562, 32, 'Manuální odeslání'),
(117069, 3563, 32, 'Výrobce'),
(117070, 3568, 32, 'Březen'),
(117071, 3569, 32, 'Rodinný stav'),
(117072, 3570, 32, 'Oznčit jako vyúčtované'),
(117073, 3571, 32, 'Oznčit jako vyúčtované, ale přeskoč účtování'),
(117074, 3572, 32, 'Označ jako vyčištěné'),
(117075, 3573, 32, 'Označ jako nevyúčtované'),
(117076, 3574, 32, 'Označ tyto reporty jako prohlédnuté'),
(117077, 3575, 32, 'Označ jako vyčištěné'),
(117078, 3576, 32, 'Ženatý/vdaná'),
(117079, 3578, 32, 'Maska'),
(117080, 3579, 32, 'Maska pro čísla faktur'),
(117081, 3580, 32, 'Maska pro ID Pacientů'),
(117082, 3581, 32, 'Maska pro ID produktů'),
(117083, 3582, 32, 'Shoda'),
(117084, 3584, 32, 'Nalezena shoda'),
(117085, 3591, 32, 'Max'),
(117086, 3592, 32, 'dosažen maximální počet souborů - znovu nahrát níže uvedená jména'),
(117087, 3594, 32, 'Maxilárně vpravo'),
(117088, 3595, 32, 'Maximální věk'),
(117089, 3596, 32, 'Maximum znaků'),
(117090, 3597, 32, 'Maximální čas nečinnosti v sekundách před odhlášením. Výchozí hodnota je 7200 ( 2 hodiny)'),
(117091, 3600, 32, 'Maximální rozumný inventář, 0 pokud není použito'),
(117092, 3601, 32, 'Maximální velikost'),
(117093, 3602, 32, 'Maximální velikost ( zadání 0 umožní jakoukoliv velikost)'),
(117094, 3603, 32, 'Květen'),
(117095, 3607, 32, 'Žádné z posledních tří hesel nelze použít při změně hesla.'),
(117096, 3609, 32, 'Kód  skupiny měření'),
(117097, 3612, 32, 'Vnitřní kotník'),
(117098, 3614, 32, 'Lékařský'),
(117099, 3615, 32, 'UPT -umělé přerušení těhotenství'),
(117100, 3617, 32, 'Anamnéza'),
(117101, 3618, 32, 'Zdravotní problém'),
(117102, 3619, 32, 'Zdravotní problém'),
(117103, 3620, 32, 'Zdravotní problém'),
(117104, 3621, 32, 'Zdravotní problém'),
(117105, 3622, 32, 'Seznam zdravotních problémů'),
(117106, 3623, 32, 'Zdravotní problémy'),
(117107, 3624, 32, 'Zdravotní záznam'),
(117108, 3625, 32, 'Zdravotní záznam #'),
(117109, 3626, 32, 'Zdravotní záznamy'),
(117110, 3627, 32, 'Zdravotní záznamy odeslány'),
(117111, 3629, 32, 'Souhrnná zpráva ybal vydána'),
(117112, 3630, 32, 'Medicínský systém'),
(117113, 3632, 32, 'Anamnéza ( volitelně právo zapisovat, přidat)'),
(117114, 3633, 32, 'Zdravotní péče část B'),
(117115, 3634, 32, 'Poskytovatel vyžádané péče je změněn'),
(117116, 3635, 32, 'Medikace'),
(117117, 3637, 32, 'Seznam zdravotních obtíží'),
(117118, 3638, 32, 'Seznam léků'),
(117119, 3639, 32, 'Provedena korekce medikace ?'),
(117120, 3640, 32, 'Medikace'),
(117121, 3641, 32, 'Medikace:'),
(117122, 3643, 32, 'Střed'),
(117123, 3644, 32, 'Spojení s MedlinePlus'),
(117124, 3646, 32, 'Mnestické problémy'),
(117125, 3647, 32, 'Muž'),
(117126, 3648, 32, 'Muž a Žena'),
(117127, 3649, 32, 'Pouze muž'),
(117128, 3650, 32, 'Menarche'),
(117129, 3651, 32, 'Menopausa'),
(117130, 3652, 32, 'Mentruační krvácení'),
(117131, 3653, 32, 'Frekvence menstruace'),
(117132, 3654, 32, 'Mentální onemocnění'),
(117133, 3655, 32, 'Text nabídky'),
(117134, 3656, 32, 'Nabídky'),
(117135, 3657, 32, 'Sloučit'),
(117136, 3658, 32, 'Sloučení kompletní'),
(117137, 3659, 32, 'Sloučit pacienty'),
(117138, 3661, 32, 'Zpráva'),
(117139, 3662, 32, 'Centrum zpráv a upomínek'),
(117140, 3663, 32, 'Obsah zprávy není prostý text a musí být uložen jako dokument.'),
(117141, 3664, 32, 'Zpráva od pacienta'),
(117142, 3665, 32, 'Zpráva odeslána'),
(117143, 3666, 32, 'Stav zprávy'),
(117144, 3667, 32, 'Název zprávy'),
(117145, 3668, 32, 'Zpráva pro pacienta'),
(117146, 3669, 32, 'Typ zprávy'),
(117147, 3670, 32, 'ZPRÁVA:'),
(117148, 3671, 32, 'Zprávy'),
(117149, 3672, 32, 'Dnešní odeslané zprávy'),
(117150, 3673, 32, 'Metoda'),
(117151, 3674, 32, 'Metoda a specifický produkt'),
(117152, 3675, 32, 'Metoda odesílání emailů.'),
(117153, 3676, 32, 'Metoda likvidace'),
(117154, 3679, 32, 'mg'),
(117155, 3680, 32, 'mg/cm3'),
(117156, 3681, 32, 'mg/2cm3'),
(117157, 3682, 32, 'mg/3cm3'),
(117158, 3683, 32, 'mg/4cm3'),
(117159, 3684, 32, 'mg/5cm3'),
(117160, 3685, 32, 'mg/100ml'),
(117161, 3686, 32, 'Prostřední'),
(117162, 3687, 32, 'Prostřední jméno'),
(117163, 3688, 32, 'Prostřední jméno'),
(117164, 3696, 32, 'Migrující nebo sezónní pracovník ?'),
(117165, 3697, 32, 'Migrující/sezónní'),
(117166, 3701, 32, 'MIME typ'),
(117167, 3702, 32, 'Mime typ'),
(117168, 3703, 32, 'Min'),
(117169, 3704, 32, 'min'),
(117170, 3705, 32, 'Minimální věk'),
(117171, 3706, 32, 'Lehká kloubní distenze +/- synovitis'),
(117172, 3708, 32, 'Minuta'),
(117173, 3709, 32, 'Minuty'),
(117174, 3710, 32, 'Minuty'),
(117175, 3716, 32, 'Různé'),
(117176, 3717, 32, 'Zmeškáno'),
(117177, 3718, 32, 'chybí'),
(117178, 3719, 32, 'Chybí povinné soubory'),
(117179, 3722, 32, 'Chybějící nebo nesprávný'),
(117180, 3724, 32, 'Chybí datum hlášení'),
(117181, 3725, 32, 'Chybí lomítko za údajem plátce '),
(117182, 3726, 32, 'Smíšený'),
(117183, 3727, 32, 'ml'),
(117184, 3728, 32, 'MM/DD/RRRR'),
(117185, 3729, 32, 'mm/hg'),
(117186, 3730, 32, 'mmhg'),
(117187, 3733, 32, 'Mobilní'),
(117188, 3734, 32, 'Mobilní telefon'),
(117189, 3735, 32, 'Mod'),
(117190, 3738, 32, 'Střední priorita'),
(117191, 3740, 32, 'Střední /Nízká priorita'),
(117192, 3741, 32, 'Modifikátor'),
(117193, 3742, 32, 'Modifikátory'),
(117194, 3743, 32, 'Modifikovat'),
(117195, 3745, 32, 'Modifikovat platbu'),
(117196, 3747, 32, 'Modul'),
(117197, 3748, 32, 'Adresář modulů nenalezen'),
(117198, 3749, 32, 'Instalátor modulů'),
(117199, 3750, 32, 'Jméno modulu'),
(117200, 3751, 32, 'Jméno modulu již existuje'),
(117201, 3752, 32, 'Moduly'),
(117202, 3753, 32, 'Pon'),
(117203, 3754, 32, 'Od Pon do Pá'),
(117204, 3755, 32, 'Pon,Stře &amp; Pá'),
(117205, 3756, 32, 'Pondělí'),
(117206, 3758, 32, 'Měsíc'),
(117207, 3759, 32, 'měsíc'),
(117208, 3760, 32, 'Měsíční zobrazení'),
(117209, 3761, 32, 'Měsíce'),
(117210, 3762, 32, 'Měsíční příjem'),
(117211, 3765, 32, 'Nalezeno více než 100 záznamů. Omezte vyhledávací kritéria'),
(117212, 3766, 32, 'Více než 50 výsledků, prosím zpřesněte vyhledávání'),
(117213, 3767, 32, 'Většina záhlaví sloupců umožňuje klikem třídit obsah sloupce'),
(117214, 3768, 32, 'Nejnovější z'),
(117215, 3769, 32, 'Nejnovější laboratorní data:'),
(117216, 3770, 32, 'Nejnovější vitální funkce z:'),
(117217, 3771, 32, 'Matka'),
(117218, 3772, 32, 'Jméno matky'),
(117219, 3773, 32, 'Anamnéza matky'),
(117220, 3774, 32, 'Ústa'),
(117221, 3775, 32, 'Přemístit'),
(117222, 3776, 32, 'Přesunout dokument do kategorie:'),
(117223, 3777, 32, 'Přesunout dolů'),
(117224, 3778, 32, 'Přesun selhal'),
(117225, 3779, 32, 'Přesunout k pacientovi'),
(117226, 3780, 32, 'Přesunout k...'),
(117227, 3781, 32, 'Přesunout výše'),
(117228, 3782, 32, 'Přesouvání'),
(117229, 3783, 32, 'Pan'),
(117230, 3785, 32, 'Paní'),
(117231, 3786, 32, 'Slečna'),
(117232, 3787, 32, 'MSH-11'),
(117233, 3788, 32, 'MSH-3.1'),
(117234, 3789, 32, 'MSH-4.1'),
(117235, 3790, 32, 'MSH-5.1'),
(117236, 3791, 32, 'MSH-6.1'),
(117237, 3793, 32, 'Typ zprávy MSH.8 není platný'),
(117238, 3794, 32, 'Kód MSP'),
(117239, 3796, 32, 'Vícejazyčné nástroje'),
(117240, 3797, 32, 'Vícečetné oblasti'),
(117241, 3798, 32, 'CTRL+Click nebo SHIFT+Click umožní nahrání více souborů v jednom okamžiku'),
(117242, 3800, 32, 'Vícero modifikátorů (max 4) může být odděleno dvojtečkou nebo mezerou (M1:M2:M3:M4)'),
(117243, 3801, 32, 'Seznam s vícečetným výberem'),
(117244, 3802, 32, 'Multirasový'),
(117245, 3803, 32, 'Šelest:'),
(117246, 3804, 32, 'Myalgie'),
(117247, 3805, 32, 'Myalgie'),
(117248, 3806, 32, 'Zarudnutí nad svalem'),
(117249, 3807, 32, 'Svalová ztuhlost'),
(117250, 3808, 32, 'Edém svalový'),
(117251, 3810, 32, 'Sval'),
(117252, 3811, 32, 'Svalové poranění'),
(117253, 3812, 32, 'Muskuloskeletální'),
(117254, 3813, 32, 'Musí být prázdné, pokud není využívána SMTP autentifikace.'),
(117255, 3814, 32, 'Vzájemně definováno'),
(117256, 3821, 32, 'N/A'),
(117257, 3822, 32, 'n/a'),
(117258, 3823, 32, 'Jméno'),
(117259, 3825, 32, 'Jméno ( kliknout pro detaily )'),
(117260, 3826, 32, 'Jméno 1'),
(117261, 3827, 32, 'Jméno 2'),
(117262, 3828, 32, 'Jméno a titul administrátora očkování'),
(117263, 3829, 32, 'Jméno v EMR'),
(117264, 3830, 32, 'Jméno musí být ve formátu codetype_code_language.pdf, např. icd9_274.11_en.pdf'),
(117265, 3831, 32, 'Jméno událostí'),
(117266, 3832, 32, 'Jméno poskytovatele pojištění'),
(117267, 3833, 32, 'Jméno poskytovatele'),
(117268, 3834, 32, 'Jméno odesílatele pro upomínky pacientům'),
(117269, 3835, 32, 'Jméno překladu'),
(117270, 3836, 32, 'Jméno/Hodnota'),
(117271, 3837, 32, 'Jméno:'),
(117272, 3838, 32, 'NARES:'),
(117273, 3840, 32, 'Nosní sliznice růžová, septum ve střední čáře'),
(117274, 3841, 32, 'Poznámky k národnosti'),
(117275, 3842, 32, 'Konfigurace poznámek k národnosti'),
(117276, 3844, 32, 'Státní příslušnost'),
(117277, 3845, 32, 'Poznámky k národnosti'),
(117278, 3852, 32, 'Nausea'),
(117279, 3854, 32, 'Navigace'),
(117280, 3855, 32, 'Naváděcí oblast zahrnuje  formuláře vyšetření'),
(117281, 3856, 32, 'Navigační oblast používá plnou výšku rámců'),
(117282, 3857, 32, 'Navigační oblast formuláře návštěv'),
(117283, 3858, 32, 'Šířka navigační oblasti'),
(117284, 3859, 32, 'Navigační menu obsahuje páry přepínačů'),
(117285, 3860, 32, 'Navigační menu je zobrazeno stromově'),
(117286, 3861, 32, 'K navigaci je použito posuvné menu'),
(117287, 3866, 32, 'Krk a šíje'),
(117288, 3867, 32, 'Problémy se šíji'),
(117289, 3868, 32, 'Pohyblivost šíje'),
(117290, 3869, 32, 'Je potřeba zadat popis'),
(117291, 3870, 32, 'Je potřeba zadat návratovou hodnotu'),
(117292, 3871, 32, 'Je potřeba zadat identifikátor'),
(117293, 3872, 32, 'Je potřeba zadat název'),
(117294, 3873, 32, 'Potřeba autorizace'),
(117295, 3874, 32, 'Potřeba zdůvodnění'),
(117296, 3875, 32, 'Potřeba dalšího vyúčtování'),
(117297, 3876, 32, 'Negativní'),
(117298, 3877, 32, 'Negativy'),
(117299, 3880, 32, 'Nervové poranění'),
(117300, 3881, 32, 'Stav nervu / nervové poranění'),
(117301, 3882, 32, 'Necitlivost'),
(117302, 3883, 32, 'Slabost svalová'),
(117303, 3884, 32, 'Neurologický'),
(117304, 3885, 32, 'Nikdy'),
(117305, 3886, 32, 'Abstinent'),
(117306, 3887, 32, 'Nekuřák'),
(117307, 3888, 32, 'Nový'),
(117308, 3889, 32, 'Nový =>'),
(117309, 3890, 32, 'Nový příjemci'),
(117310, 3892, 32, 'Nová alergie'),
(117311, 3893, 32, 'Nový požadavek na změnu'),
(117312, 3894, 32, 'Nové vyšetření'),
(117313, 3895, 32, 'Nové kategorie'),
(117314, 3896, 32, 'Nová kategorie'),
(117315, 3897, 32, 'Noví klienti'),
(117316, 3898, 32, 'Nová konzultace'),
(117317, 3900, 32, 'Nová sada definicí přidána'),
(117318, 3901, 32, 'Nový dokument'),
(117319, 3902, 32, 'Nové dokumenty'),
(117320, 3904, 32, 'Nové vyšetření'),
(117321, 3905, 32, 'Nové vyšetření vytvořeno s ID'),
(117322, 3906, 32, 'Nový formulář vyšetření'),
(117323, 3907, 32, 'Nová vyšetření nejsou autorizována'),
(117324, 3908, 32, 'Nové vyš.'),
(117325, 3909, 32, 'Nová informace o zařízení'),
(117326, 3910, 32, 'Nový soubor'),
(117327, 3911, 32, 'Nové soubory'),
(117328, 3912, 32, 'Nová skupina'),
(117329, 3913, 32, 'Nová informace o skupině'),
(117330, 3916, 32, 'Nový limit událostí'),
(117331, 3917, 32, 'Nový seznam'),
(117332, 3918, 32, 'Nové objednávky'),
(117333, 3919, 32, 'Nový odstavec'),
(117334, 3920, 32, 'Nové heslo'),
(117335, 3921, 32, 'Nový pacient'),
(117336, 3922, 32, 'NOVÝ PACIENT'),
(117337, 3923, 32, 'Nové vyšetření pacienta'),
(117338, 3924, 32, 'Nový formulář pacienta'),
(117339, 3925, 32, 'Nové ID pacienta'),
(117340, 3926, 32, 'Nová platba'),
(117341, 3927, 32, 'Nové přihlášení k portálu'),
(117342, 3929, 32, 'Nové laboratorní výsledky'),
(117343, 3930, 32, 'Nové vyhledávání'),
(117344, 3931, 32, 'Nové podání'),
(117345, 3932, 32, 'Nový uživatel'),
(117346, 3933, 32, 'Nová hodnota'),
(117347, 3934, 32, 'Nová návštěva'),
(117348, 3935, 32, 'Nový/Hledat'),
(117349, 3960, 32, 'Novější'),
(117350, 3961, 32, 'Noviny'),
(117351, 3962, 32, 'Další'),
(117352, 3964, 32, 'Další den'),
(117353, 3965, 32, 'Příští měsíc'),
(117354, 3966, 32, 'Příští měsíc ( podrž pro nabídku )'),
(117355, 3967, 32, 'Nově plánovaná série'),
(117356, 3968, 32, 'Příští týden'),
(117357, 3969, 32, 'Příští rok ( podržet pro nabídku)'),
(117358, 3970, 32, 'Přezdívka'),
(117359, 3971, 32, 'Přezdívka'),
(117360, 3973, 32, 'Noční pocení'),
(117361, 3975, 32, 'Ne'),
(117362, 3976, 32, 'NE'),
(117363, 3977, 32, 'Nepřístupné'),
(117364, 3978, 32, 'Žádná aktivní pacientské upomínky'),
(117365, 3979, 32, 'Bez adenopathie ( vyžadovány 2 oblasti )'),
(117366, 3980, 32, 'Nenalezeno žádné upřesnění pro'),
(117367, 3981, 32, 'Adnexa bez rezistence'),
(117368, 3982, 32, 'Žádné dostupné požadavky na změnu'),
(117369, 3983, 32, 'Žádné návštěvy'),
(117370, 3985, 32, 'Žádný účetní systém není aktuálně aktivní'),
(117371, 3986, 32, 'Žádné účty nezahrnují OFX export'),
(117372, 3987, 32, 'Žádné účty nezahrnují OFX export<br>'),
(117373, 3989, 32, 'Nespecifikován žádný kód'),
(117374, 3990, 32, 'Tento modul nemá definovánu žádnou konfiguraci'),
(117375, 3992, 32, 'Žádná diagnóza'),
(117376, 3993, 32, 'Nenalezen žádný dokument'),
(117377, 3994, 32, 'Nelze vytvořit žádné vyšetření'),
(117378, 3995, 32, 'Žádné konečné datum'),
(117379, 3996, 32, 'Nenalezeny žádné položky. Použijte formulář níže pro jejich zadání.'),
(117380, 3997, 32, 'Chyby nenalezeny :-)'),
(117381, 3998, 32, 'Žádné události'),
(117382, 4000, 32, 'Žádné soubory k instalaci'),
(117383, 4001, 32, 'Žádná skupina nebyla vybrána'),
(117384, 4002, 32, 'Bez hernie'),
(117385, 4005, 32, 'Žádný úraz/choroba'),
(117386, 4006, 32, 'Nenalezena žádná pojišťovna'),
(117387, 4007, 32, 'Žádné problémy'),
(117388, 4008, 32, 'Toto vyšetření bez problémů'),
(117389, 4009, 32, 'Žádné položky pro vybranou kategorii'),
(117390, 4010, 32, 'Žádné položky nebyly vybrány'),
(117391, 4024, 32, 'Žádná laboratorní data nebyla zdokumentována'),
(117392, 4025, 32, 'Pro zadané datum neexistuje žádný log soubor'),
(117393, 4027, 32, 'Bez rezistence, bez zvýšené citlivosti'),
(117394, 4028, 32, 'Źádný odpovídající pacient nenalezen pro zadaný Re identifikační kód'),
(117395, 4029, 32, 'Žádná shoda. Zkuste hledání opakovat.'),
(117396, 4030, 32, 'Nic nenalezeno'),
(117397, 4031, 32, 'Nic nenalezeno. Vytvořit nového pacienta ?'),
(117398, 4032, 32, 'Nenalezeny žádné odpovídající záznamy'),
(117399, 4033, 32, 'Žádné nové výsledky nebyly  nalezeny'),
(117400, 4034, 32, 'Žádné poznámky'),
(117401, 4035, 32, 'Bez organomegalie'),
(117402, 4037, 32, 'Nejsou uvedena žádná jiná telefonní čísla'),
(117403, 4038, 32, 'Nebyly vybrány žádné parametry'),
(117404, 4039, 32, 'Nenalezeni žádní partneři'),
(117405, 4040, 32, 'Zádné záznamy o pacientech nebyly pro vybraná kritéria nalezeny'),
(117406, 4041, 32, 'Źádný pacientský záznam nenalezen pro zadaný Re identifikační kód'),
(117407, 4042, 32, 'Bez periferního edému'),
(117408, 4043, 32, 'Žádné lékárny nenalezeny'),
(117409, 4044, 32, 'Žádné recepety nebyly nalezeny'),
(117410, 4045, 32, 'Žádné poranění/onemocnění'),
(117411, 4046, 32, 'Žádné oředchozí položky.'),
(117412, 4048, 32, 'Žádná předchozí vyšetření'),
(117413, 4049, 32, 'Žádné procedury pro toto vyšetření'),
(117414, 4051, 32, 'Žádní poskytovatelé nenalezeni'),
(117415, 4052, 32, 'Žádná vyrážka nebo abnormální léze'),
(117416, 4053, 32, 'Žádné záznamy nenalezeny'),
(117417, 4055, 32, 'Žádné záznamy nenalezeny. Rozšiřte vyhledávací kritéria.'),
(117418, 4056, 32, 'Žádné upomínky.'),
(117419, 4057, 32, 'Žádné výsledky pro výše uvedená vyhledávací kritéria nenalezeny'),
(117420, 4058, 32, 'Žádné výsledky'),
(117421, 4059, 32, 'Žádné výsledky nenalezeny'),
(117422, 4060, 32, 'Žádné výsledky  vyhledávání'),
(117423, 4061, 32, 'Žádné výsledky nenalezeny. Zkuste znovu.'),
(117424, 4062, 32, 'Žádné výsledky. Zkuste znovu.'),
(117425, 4063, 32, 'Žádné výsledky. Zkuste znovu.'),
(117426, 4064, 32, 'Žádné možnosti nastavení pro tento modul'),
(117427, 4066, 32, 'Soubor bez podpisů'),
(117428, 4067, 32, 'PND nebolestivé'),
(117429, 4068, 32, 'Žádné vpáčení kůže nebo prsní uzly'),
(117430, 4070, 32, 'Žádná tabulka nebyla vybrána. Vyberte tabulku.'),
(117431, 4071, 32, 'Varlata nebolestivé , bez rezistence'),
(117432, 4075, 32, 'Žádná návštěva'),
(117433, 4076, 32, 'Vitální funkce nebyly dokumentovány'),
(117434, 4077, 32, 'Ne. Zrušit.'),
(117435, 4080, 32, 'Nicturie'),
(117436, 4081, 32, 'Nezaplaceno'),
(117437, 4083, 32, 'Neupřesněné poranění'),
(117438, 4085, 32, 'Non Insulin Dependentní DM'),
(117439, 4086, 32, 'Neporaněný'),
(117440, 4091, 32, 'Nedefinováno'),
(117441, 4092, 32, 'Nebylo zdokumentováno'),
(117442, 4093, 32, 'Nic z výše uvedených'),
(117443, 4094, 32, 'Žádný z horních řádků nemůže být prázdný'),
(117444, 4095, 32, 'Non Insulin  dependentní diabetes'),
(117445, 4097, 32, 'Normální'),
(117446, 4099, 32, 'Normální kardiologické vyšetření :'),
(117447, 4100, 32, 'Normální kardiologické vyšetření : '),
(117448, 4101, 32, 'Normální vyšetření plic:'),
(117449, 4102, 32, 'Normální vyšetření plic: '),
(117450, 4104, 32, 'Oropharynx BPN:'),
(117451, 4107, 32, 'Normální zobrazení'),
(117452, 4108, 32, 'normální:'),
(117453, 4109, 32, 'Normálně by mělo být označeno. Bez vztahu ke kontrole přístupu.'),
(117454, 4115, 32, 'Nos'),
(117455, 4116, 32, 'Krvácení z nosu'),
(117456, 4117, 32, 'ne písmena nebo čísla'),
(117457, 4119, 32, 'Ne všechna pole jsou povinná pro všechny kódy a typy.'),
(117458, 4120, 32, 'Není možné'),
(117459, 4121, 32, 'Není možné smazat  skupinu Správce'),
(117460, 4122, 32, 'Úpravy nejsou dovoleny'),
(117461, 4123, 32, 'Není dovoleno inaktivovat všechny bezpečností objekty'),
(117462, 4124, 32, 'Není dovoleno inaktivovat cokoliv z ACL Správce.'),
(117463, 4125, 32, 'Není dovoleno odstranit správce ze skupiny Administrators'),
(117464, 4126, 32, 'Není dovoleno odstranit tohoto uživatele ze skupiny Administrators'),
(117465, 4127, 32, 'Nelze provést'),
(117466, 4128, 32, 'Nyní oprávnění pro přístup k PostCalendar modulu'),
(117467, 4129, 32, 'Chybí oprávnění'),
(117468, 4130, 32, 'Chybí oprávnění'),
(117469, 4131, 32, 'Chybí oprávnění pro tuto skupinu!'),
(117470, 4132, 32, 'Chybí oprávnění pro tuto skupinu.'),
(117471, 4133, 32, 'Není oprávnění spravovat uživatele.'),
(117472, 4134, 32, 'Chybí oprávnění podepisovat výsledky'),
(117473, 4135, 32, 'Nedostupný'),
(117474, 4137, 32, 'Nazaúčtováno'),
(117475, 4140, 32, 'Není kódováno'),
(117476, 4143, 32, 'Vyšetření neprovedeno'),
(117477, 4144, 32, 'Vyšetření neprovedeno:'),
(117478, 4145, 32, 'Vyšetření neprovedeno: '),
(117479, 4146, 32, 'nenalezeno'),
(117480, 4148, 32, 'nenalezeno!'),
(117481, 4150, 32, 'Nenainstalováno'),
(117482, 4151, 32, 'Nenainstalováno'),
(117483, 4152, 32, 'Nepozorováno od'),
(117484, 4153, 32, 'Neodesláno'),
(117485, 4154, 32, 'Dosud neodesláno'),
(117486, 4155, 32, 'Nespecifikováno'),
(117487, 4156, 32, 'Nespecifikováno.'),
(117488, 4157, 32, 'Poznámka'),
(117489, 4158, 32, 'Kódy poznámek'),
(117490, 4159, 32, 'Počítejte s tím, že proces instalace může trvat 5-10 minut'),
(117491, 4160, 32, 'Počítejte s tím, že proces aktualizace může trvat 5-10 minut'),
(117492, 4162, 32, 'Typ poznámky'),
(117493, 4164, 32, 'Poznámka: Import externích dat může trvat více než hodinu v závislosti na konfiguraci hardwaru. Příklad:  datové rabulky RxNorm obsahují více než 6 milionů řádků.'),
(117494, 4168, 32, 'Poznámka: Tento kód nebyl zadán oprávněným uživatelem. Pouze autorizované kódy mohou být nahrány do sítě Open Medical Billing pro zpracování. Pokud chcete nahrát tyto kódy, prosím vyberte oprávněného uživatele zde.'),
(117495, 4170, 32, 'Poznámka: Nahrávání souborů s duplicitními názvy způsobí, že soubory budou automaticky přejmenovány (například file.jpg bude file.1.jpg). Názvy souborů jsou považovány za unikátní v rámci  pacienta a ne kategorie.'),
(117496, 4171, 32, 'Poznámka: Nahrávání souborů s duplicitními názvy způsobí, že soubory budou automaticky přejmenovány. Například ''<i>file.jpg</i>'' bude ''<i>file.jpg1</i>''.  Názvy souborů jsou považovány za unikátní v rámci  pacienta a ne kategorie.'),
(117497, 4172, 32, 'Poznámky'),
(117498, 4173, 32, 'Poznámky - jakékoliv vyšetření ( volitelně zapisovat, přidat)'),
(117499, 4174, 32, 'Poznámky - moje vyšetření ( volitelně zapisovat, přidat)'),
(117500, 4175, 32, 'Poznámky nejsou autorizovány'),
(117501, 4176, 32, 'Nic nečeká na schválení'),
(117502, 4177, 32, 'Nic nezapsaáno'),
(117503, 4179, 32, 'Nic k importu do alergií'),
(117504, 4180, 32, 'Nic k importu do preskripcí'),
(117505, 4181, 32, 'Nic k zobrazení'),
(117506, 4182, 32, 'Nebylo nic vybráno'),
(117507, 4183, 32, 'Přijato oznámení'),
(117508, 4185, 32, 'Oznámení'),
(117509, 4186, 32, 'E-mail pro oznámení'),
(117510, 4188, 32, 'Oznámení'),
(117511, 4190, 32, 'Lis'),
(117512, 4191, 32, 'Listopad'),
(117513, 4192, 32, 'Probíhá odesílání pro'),
(117514, 4193, 32, 'Probíhá tisk'),
(117515, 4200, 32, 'Číslo'),
(117516, 4201, 32, 'Číslo lab.'),
(117517, 4204, 32, 'Počet sloupců v ročním zobrazení'),
(117518, 4211, 32, 'Počet dnů platnosti klientského certifikátu'),
(117519, 4213, 32, 'Počet desetinných míst měny . Obvykle 0-2'),
(117520, 4214, 32, 'Počet vyšetření ke zobrazení na stránce.'),
(117521, 4216, 32, 'Kolik hodin předem odesílat e-mailová oznámení ?'),
(117522, 4217, 32, 'Kolik hodin předem odesílat telefonická oznámení ?'),
(117523, 4218, 32, 'Kolik hodin předem odesílat SMS oznámení ?'),
(117524, 4222, 32, 'Počet pacientů v seznamu ke zobrazení na stránce'),
(117525, 4223, 32, 'Necitlivost'),
(117526, 4225, 32, 'Pořadí čísleného zobrazení'),
(117527, 4227, 32, 'Nutrice'),
(117528, 4228, 32, 'Nutriční'),
(117529, 4229, 32, 'O.A.F.V'),
(117530, 4230, 32, 'Saturace O2'),
(117531, 4231, 32, 'Obezita I'),
(117532, 4232, 32, 'Obezita II'),
(117533, 4233, 32, 'Obezita III'),
(117534, 4240, 32, 'Říj'),
(117535, 4241, 32, 'Říjen'),
(117536, 4244, 32, 'množství'),
(117537, 4245, 32, 'tablet'),
(117538, 4246, 32, 'každého měsíce'),
(117539, 4248, 32, 'Vypnuto'),
(117540, 4251, 32, 'Oficiální skupiny měření pro Měření klinické kvality (CQM)'),
(117541, 4252, 32, 'Offsite Https odkaz pro pacientský portál'),
(117542, 4253, 32, 'Offsite Https odkaz pro pacientský portál. (Odkaz pro pacienty)'),
(117543, 4254, 32, 'Offsite heslo pro pacientský portál'),
(117544, 4255, 32, 'Offsite heslo pro pacientský portál ( Nechte prázdné pokud nejste registrováni)'),
(117545, 4256, 32, 'Offsite ID Poskytovatele pro pacientský portál ( Nechte prázdné pokud nejste registrováni)'),
(117546, 4257, 32, 'Offsite ID Poskytovatele pro pacientský portál'),
(117547, 4258, 32, 'Offsite adresa stránky pro pacientský portál'),
(117548, 4259, 32, 'Offsite adresa stránky pro pacientský portál (Odkaz pro pacienta)'),
(117549, 4260, 32, 'Offsite uživatelské jsméno pro pacientský portál'),
(117550, 4261, 32, 'Offsite uživatelské jsméno pro pacientský portál ( Nechte prázdné pokud nejste registrováni)'),
(117551, 4262, 32, 'Offsite webové sloužby portálu selhaly'),
(117552, 4263, 32, 'Potomci'),
(117553, 4264, 32, 'RA: děti'),
(117554, 4265, 32, 'mast'),
(117555, 4267, 32, 'OK'),
(117556, 4268, 32, 'OK pro zavření vyskakovacího okna?'),
(117557, 4270, 32, 'Starý'),
(117558, 4272, 32, 'Staří klienti'),
(117559, 4274, 32, 'Starý typ rozvržení bez  levého menu'),
(117560, 4275, 32, 'Starý typ statického formuláře vez vyhledávání nebo kontroly duplikací'),
(117561, 4276, 32, 'Starší'),
(117562, 4277, 32, 'Vynechat'),
(117563, 4278, 32, 'Vynechat okraje'),
(117564, 4279, 32, 'Vynechat informace o zaměstnavateli v identifikačních údajích pacienta'),
(117565, 4280, 32, 'Vynechat zaměstnavatele'),
(117566, 4281, 32, 'Vynechat formu, cestu a interval dávkování'),
(117567, 4282, 32, 'Vynechat pojištění a některé další identifikační údaje'),
(117568, 4283, 32, 'vynechat vnitřní uživatele ?'),
(117569, 4284, 32, 'Vynechat metodu a platbu na Co-Pay panelu'),
(117570, 4285, 32, 'vynechat automatické přidělení'),
(117571, 4286, 32, 'na'),
(117572, 4287, 32, 'Zapnuto'),
(117573, 4288, 32, 'Na ruce'),
(117574, 4289, 32, 'Na objednávce'),
(117575, 4290, 32, 'Na stránce'),
(117576, 4291, 32, 'Primary Business Facility by po nastavení již nemělo být následně měněno. Změna zařízení bude mít vliv na práci s NewCrop e-recepty.'),
(117577, 4292, 32, 'Po změně hesla se musíte znovu přihlásit'),
(117578, 4297, 32, 'Podpora online'),
(117579, 4298, 32, 'Odkaz na podporu online'),
(117580, 4299, 32, 'Pouze aktivní'),
(117581, 4302, 32, 'pouze v případě účtovacího místa'),
(117582, 4303, 32, 'Pouze inaktivní'),
(117583, 4304, 32, 'Pouze mé'),
(117584, 4305, 32, 'Zobrazit pouze kódy pro hlášení diagnóz'),
(117585, 4307, 32, 'Pouze nahrát aktivní presripce'),
(117586, 4309, 32, 'Počátek aktuálních symptomů nebo choroby'),
(117587, 4310, 32, 'Počátek choroby:'),
(117588, 4311, 32, 'Počátek choroby: '),
(117589, 4312, 32, 'Počátek otoků:'),
(117590, 4313, 32, 'Počátek/datum hospitalizace'),
(117591, 4314, 32, 'Onsite adresa stránky pacientského portálu'),
(117592, 4315, 32, 'A jéje !'),
(117593, 4316, 32, 'Otevřít'),
(117594, 4318, 32, 'Otevřít v novém okně'),
(117595, 4319, 32, 'Otevřít pacienta'),
(117596, 4321, 32, 'Otevřít dnešní návštěvu'),
(117597, 4322, 32, 'Certifikační autorita je již v LibreEHR  konfigurována.'),
(117598, 4324, 32, 'Upgrade databáze LibreEHR'),
(117599, 4325, 32, 'Upgrade databáze LibreEHR pro deidentifikaci'),
(117600, 4326, 32, 'LibreEHR nepoznává příchozí soubor v adresáři contrib. To je s největší pravděpodobností proto, že je třeba konfigurovat release v tabulce supported_external_dataloads v databázi MySQL.'),
(117601, 4327, 32, 'Před vytvořením klientských certifikátů  musí být LibreEHR konfigurováno pro  využití certifikátů'),
(117602, 4328, 32, 'LibreEHR vyžaduje Javascript k ověření uživatele.'),
(117603, 4329, 32, 'Uživatelé LibreEHR'),
(117604, 4330, 32, 'Zahájení'),
(117605, 4332, 32, 'Oční'),
(117606, 4333, 32, 'Možnost'),
(117607, 4334, 32, 'Možnost uložení metody pro úložiště dokumentů.'),
(117608, 4335, 32, 'Možnosti invetury a prodeje produktů'),
(117609, 4336, 32, 'Volitelně'),
(117610, 4337, 32, 'Volitelné jméno kategorie obrázku občanského průkazu pro zobrazení na souhrnné stránce pacienta'),
(117611, 4338, 32, 'Volitelné jméno kategorie fotografií  pro zobrazení na souhrnné stránce pacienta'),
(117612, 4340, 32, 'Volitelný výchozí rozsah pro manuální zadávání výsledků'),
(117613, 4341, 32, 'Volitelné výchozí jednotky pro manuální zadávání výsledků'),
(117614, 4342, 32, 'Volitelné jméno cílového umístění'),
(117615, 4343, 32, 'Volitelné jméno léku . Použijte symbol % jako zástupný znak.'),
(117616, 4344, 32, 'Volitelné jméno nebo kód imunizace. Použijte symbol % jako zástupný znak.'),
(117617, 4345, 32, 'Volitelné informace o této události'),
(117618, 4346, 32, 'Volitelné číslené množství. Použijte symbol % jako zástupný znak.'),
(117619, 4347, 32, 'Volitelné číselné ID pacienta'),
(117620, 4348, 32, 'Volitelný kód procedury'),
(117621, 4349, 32, 'Volitelný kód procedury/služby'),
(117622, 4350, 32, 'Možnosti'),
(117623, 4351, 32, 'Nebo'),
(117624, 4352, 32, 'NEBO'),
(117625, 4353, 32, 'nebo vybrat'),
(117626, 4354, 32, 'nebo kliknout a táhnout pro rychlejší výběr'),
(117627, 4357, 32, 'nebo vyber z inventáře'),
(117628, 4358, 32, 'nebo pro snížení použijte klávesu Shift'),
(117629, 4359, 32, 'Nebo nahrát ERA soubor:'),
(117630, 4360, 32, 'Orálně'),
(117631, 4361, 32, 'orální sliznice klidná, růžová , hrdlo čisté'),
(117632, 4362, 32, 'Pořadí'),
(117633, 4363, 32, 'Typy objednávek a výsledků'),
(117634, 4364, 32, 'Objednávkový katalog'),
(117635, 4365, 32, 'Datum objednávky'),
(117636, 4366, 32, 'Popis objednávky'),
(117637, 4367, 32, 'Objednat z'),
(117638, 4368, 32, 'ID objednávky'),
(117639, 4369, 32, 'Objednávka musí být číslem  mezi 1- 999'),
(117640, 4370, 32, 'Jméno objednávky'),
(117641, 4371, 32, 'Objednávkové priority'),
(117642, 4373, 32, 'Výsledky objednávek'),
(117643, 4374, 32, 'Stav objednávky'),
(117644, 4375, 32, 'Stavy objednávky'),
(117645, 4376, 32, 'Souhrn objednávky'),
(117646, 4377, 32, 'Sledování objednávky'),
(117647, 4378, 32, 'Typ objednávky'),
(117648, 4380, 32, 'Typ Objednávky/Výsledku'),
(117649, 4381, 32, 'Objednáno'),
(117650, 4382, 32, 'Řateno podle'),
(117651, 4383, 32, 'Objednaná procedura'),
(117652, 4384, 32, 'Žadatel'),
(117653, 4385, 32, 'Cesta objednávek'),
(117654, 4386, 32, 'Orgánové poranění'),
(117655, 4387, 32, 'Organizace'),
(117656, 4388, 32, 'Jméno organizace'),
(117657, 4389, 32, 'Jméno organizační jednotky'),
(117658, 4390, 32, 'Organizace'),
(117659, 4391, 32, 'orientovaný x 3'),
(117660, 4392, 32, 'Originální'),
(117661, 4393, 32, 'Originální Checksum'),
(117662, 4396, 32, 'NOSOHLTAN: '),
(117663, 4397, 32, 'Ortopnoe'),
(117664, 4398, 32, 'OS'),
(117665, 4399, 32, 'Osteoarthrósa'),
(117666, 4401, 32, 'Osteopatie'),
(117667, 4402, 32, 'Jiný'),
(117668, 4403, 32, 'jiný'),
(117669, 4404, 32, 'Jiný (upřesněte)'),
(117670, 4405, 32, 'Jiný - upřesněný'),
(117671, 4408, 32, 'Jiné poranění nebylo jinde specifikováno'),
(117672, 4410, 32, 'jiný měsíc'),
(117673, 4412, 32, 'Jiné poznámky'),
(117674, 4413, 32, 'Jiné související příznaky'),
(117675, 4414, 32, 'Jiné související příznaky:'),
(117676, 4416, 32, 'Jiné poranění související s přepětím/přetížením'),
(117677, 4417, 32, 'Jiný chirurgický'),
(117678, 4420, 32, 'Jiní'),
(117679, 4421, 32, 'jinak zničíte odkazy na existující data.'),
(117680, 4424, 32, 'MIMO'),
(117681, 4425, 32, 'Mimo pracoviště'),
(117682, 4427, 32, 'Závěr'),
(117683, 4428, 32, 'Outlook'),
(117684, 4429, 32, 'Typ výstupu'),
(117685, 4430, 32, 'Propuštění - celkový stav'),
(117686, 4432, 32, 'Nadužívání'),
(117687, 4433, 32, 'Přehled'),
(117688, 4434, 32, 'Nadváha'),
(117689, 4435, 32, 'Přepsat HIPPA volby'),
(117690, 4437, 32, 'Saturace O2'),
(117691, 4438, 32, 'oz'),
(117692, 4439, 32, 'P'),
(117693, 4441, 32, 'odpoledne'),
(117694, 4444, 32, 'Pediatrický'),
(117695, 4445, 32, 'Strana'),
(117696, 4446, 32, 'Stránky'),
(117697, 4447, 32, 'Zaplaceno'),
(117698, 4449, 32, 'Zaplaceno'),
(117699, 4450, 32, 'Placeno přes'),
(117700, 4451, 32, 'Bolest'),
(117701, 4453, 32, 'Palpitace'),
(117702, 4455, 32, 'Mázek'),
(117703, 4456, 32, 'Papír'),
(117704, 4457, 32, 'Velikost papíru'),
(117705, 4458, 32, 'Paralýza'),
(117706, 4463, 32, 'Partner'),
(117707, 4464, 32, 'Jméno partnera'),
(117708, 4467, 32, 'Heslo'),
(117709, 4468, 32, 'Heslo zašifrovaného dokumentu'),
(117710, 4469, 32, 'Předchozí pacienti'),
(117711, 4472, 32, 'Heslo'),
(117712, 4473, 32, 'Změna hesla'),
(117713, 4474, 32, 'Změna hesla úspěšná'),
(117714, 4475, 32, 'Změna hesla úspěšná'),
(117715, 4476, 32, 'Heslo nesplňuje minimální požadavky. Mělo by obsahovat alespoň tři ze čtyř následujících položek: číslo, malé písmeno, velké písmeno, speciální znak (ne písmeno nebo číslo).'),
(117716, 4477, 32, 'Doba platnosti hesla'),
(117717, 4479, 32, 'Heslo pro telefonní bránu. Automatizované VOIP služby poskytované Maviq. Prosím, navštivte http://signup.maviq.com pro více informací.'),
(117718, 4480, 32, 'Heslo pro SMS bránu'),
(117719, 4481, 32, 'Heslo pro SMS bránu'),
(117720, 4482, 32, 'Heslo výše uvedeného uživatele'),
(117721, 4483, 32, 'Bezpečností nastavení hesla bylo právě upgradováno'),
(117722, 4484, 32, 'Heslo pro připojení ke CouchDB'),
(117723, 4485, 32, 'Heslo je příliš krátké. Požadováno minimálně 8 znaků.'),
(117724, 4486, 32, 'Heslo:'),
(117725, 4487, 32, 'Heslo nesouhlasí'),
(117726, 4488, 32, 'Poslední vyšetření'),
(117727, 4489, 32, 'Widget pro zobrazení posledních vyšetření'),
(117728, 4494, 32, 'Seznam posledních vyšetření'),
(117729, 4495, 32, 'Poslední vyšetření'),
(117730, 4496, 32, 'Poslední vyšetření a dokumenty'),
(117731, 4497, 32, 'Poslední vyšetření pro'),
(117732, 4498, 32, 'Vložit HL7 data'),
(117733, 4499, 32, 'Vložit data k importu do textové oblasti níže'),
(117734, 4502, 32, 'Záplata'),
(117735, 4508, 32, 'Cesta pro zálohu logu událostí'),
(117736, 4509, 32, 'Cesta k souboru CA certifikátu'),
(117737, 4510, 32, 'Cesta k souboru CA klíče'),
(117738, 4511, 32, 'Cesta k MySQL spustitelným souborům'),
(117739, 4512, 32, 'Cesta k Perl spustitelným souborům'),
(117740, 4513, 32, 'Cesta k dočasným souborům'),
(117741, 4514, 32, 'Pacient'),
(117742, 4515, 32, 'pacient'),
(117743, 4516, 32, 'PACIENT'),
(117744, 4517, 32, 'Adresa pacienta'),
(117745, 4518, 32, 'Chybí adresa pacienta'),
(117746, 4521, 32, 'Alergie pacienta'),
(117747, 4522, 32, 'Alergie pacienta'),
(117748, 4523, 32, 'Návštěva pacienta'),
(117749, 4528, 32, 'ID grafu pacienta'),
(117750, 4531, 32, 'Město bydliště pacienta'),
(117751, 4532, 32, 'Město bydliště pacienta chybí'),
(117752, 4533, 32, 'Komunikace pacienta odeslána'),
(117753, 4534, 32, 'Komunikace pacienta odeslána'),
(117754, 4535, 32, 'Země pobytu pacienta'),
(117755, 4536, 32, 'Země pobytu pacienta chybí. Současně nemáte nastavenou výchozí zemi pacienta v globálním nastavení.'),
(117756, 4539, 32, 'Data pacienta'),
(117757, 4541, 32, 'Datum narození pacienta chybí'),
(117758, 4542, 32, 'Detaily pacienta'),
(117759, 4543, 32, 'Dat. nar. pacienta'),
(117760, 4544, 32, 'Dokument pacienta'),
(117761, 4545, 32, 'Edukace pacienta'),
(117762, 4546, 32, 'Materiály pro edukaci pacienta'),
(117763, 4547, 32, 'Vyšetření pacienta'),
(117764, 4548, 32, 'Formulář vyšetření pacienta'),
(117765, 4549, 32, 'Vyšetření pacienta'),
(117766, 4550, 32, 'Vyhledávání pacientů'),
(117767, 4551, 32, 'Jméno pacienta'),
(117768, 4553, 32, 'Jméno pacienta chybí'),
(117769, 4558, 32, 'Pohlaví pacienta'),
(117770, 4559, 32, 'Pohlaví pacienta chybí'),
(117771, 4560, 32, 'Pacient nemá oprávnění pro pacientský portál'),
(117772, 4561, 32, 'Anamnéza pacienta'),
(117773, 4562, 32, 'Anamnéza / Životní styl pacienta'),
(117774, 4563, 32, 'Pacient - Telefon domů'),
(117775, 4564, 32, 'ID pacienta'),
(117776, 4565, 32, 'ID pacienta'),
(117777, 4566, 32, 'Občanský průkaz pacienta'),
(117778, 4567, 32, 'Název kategorie ID pacienta'),
(117779, 4568, 32, 'Imunizace pacienta'),
(117780, 4569, 32, 'Informace pacientovi'),
(117781, 4570, 32, 'Instrukce pacientovi'),
(117782, 4573, 32, 'Problémy pacienta'),
(117783, 4574, 32, 'Typ štítku pacienta'),
(117784, 4575, 32, 'Příjmení pacienta'),
(117785, 4577, 32, 'Příjmení pacienta chybí'),
(117786, 4581, 32, 'Seznam pacientů'),
(117787, 4582, 32, 'Sloupce seznamu pacientů'),
(117788, 4584, 32, 'Nové okno seznamu pacientů'),
(117789, 4585, 32, 'Velikost stránky seznamu pacientů'),
(117790, 4586, 32, 'Chyba vyhledávání pacienta'),
(117791, 4587, 32, 'Zdravotní problémy pacienta'),
(117792, 4588, 32, 'Medikace pacienta'),
(117793, 4589, 32, 'Jméno pacienta'),
(117794, 4590, 32, 'Jméno a adresa pacienta'),
(117795, 4593, 32, 'Jméno pacienta je povinné'),
(117796, 4595, 32, 'Poznámka k pacientovi'),
(117797, 4596, 32, 'Typ poznámky k pacientovi'),
(117798, 4597, 32, 'Poznámky k pacientovi'),
(117799, 4598, 32, 'Poznámky k pacientovi ( volitelně právo zapisovat, přidat)'),
(117800, 4599, 32, 'Číslo pacienta'),
(117801, 4600, 32, 'Platba pacienta'),
(117802, 4602, 32, 'Název kategorie fotografie pacienta'),
(117803, 4603, 32, 'Pacientský portál'),
(117804, 4604, 32, 'Problémy připojení k pacientskému portálu'),
(117805, 4605, 32, 'Pacientský portál je vypnutý'),
(117806, 4606, 32, 'Přihlášení k pacientskému portálu'),
(117807, 4607, 32, 'Webová adresa pacientského portálu'),
(117808, 4608, 32, 'Tištěná zpráva pacienta'),
(117809, 4609, 32, 'Zpráva se záznamy pacienta'),
(117810, 4610, 32, 'Požadavek na záznamy pacienta'),
(117811, 4611, 32, 'Požadavek na záznamy pacienta'),
(117812, 4613, 32, 'Pacientská připomínka'),
(117813, 4614, 32, 'Dávkové zpracování pacientských připomínek'),
(117814, 4615, 32, 'Priorita tvorby pacientských připomínek'),
(117815, 4616, 32, 'Pravidla pacientských připomínek'),
(117816, 4617, 32, 'E-mail odesílatele pro upomínky pacientům'),
(117817, 4618, 32, 'Jméno odesílatele pro upomínky pacientům'),
(117818, 4619, 32, 'Pacientské připomínky'),
(117819, 4620, 32, 'Zpráva pacienta'),
(117820, 4621, 32, 'Požadavek pacienta'),
(117821, 4622, 32, 'Lékařská zpráva vyžádaná pacientem'),
(117822, 4623, 32, 'Výsledky pacienta'),
(117823, 4624, 32, 'Styl vyhledávání  výsedků pacienta'),
(117824, 4625, 32, 'Obrazovka pro Hledání/Přidání paceinta'),
(117825, 4626, 32, 'Nastavení pacienta'),
(117826, 4627, 32, 'Stav pacienta'),
(117827, 4629, 32, 'Souhrn pacienta'),
(117828, 4630, 32, 'Transakce pacienta'),
(117829, 4632, 32, 'Pacienti v databázi odpovídající zadaným demografickým údajům.'),
(117830, 4633, 32, 'Pacient/Klient'),
(117831, 4634, 32, 'Pacient:'),
(117832, 4635, 32, 'PacientID'),
(117833, 4636, 32, 'Pacienti'),
(117834, 4637, 32, 'Pacienti zpracováni'),
(117835, 4640, 32, 'Datum platby:'),
(117836, 4641, 32, 'Stav platby'),
(117837, 4643, 32, 'Plátce'),
(117838, 4644, 32, 'Typ plátce'),
(117839, 4647, 32, 'Platba'),
(117840, 4648, 32, 'platba'),
(117841, 4668, 32, 'proc. % řádků'),
(117842, 4669, 32, 'PDF'),
(117843, 4670, 32, 'Stažení vybraných prohlášení ve formátu PDF'),
(117844, 4671, 32, 'Jazyk PDF'),
(117845, 4672, 32, 'Pánev a hýždě'),
(117846, 4673, 32, 'Pemphigus'),
(117847, 4674, 32, 'Nevyřízený/á'),
(117848, 4675, 32, 'Nevyřízená schválení'),
(117849, 4677, 32, 'Zbývající vyšetření'),
(117850, 4679, 32, 'Nevyřízené objednávky'),
(117851, 4685, 32, 'Vředová choroba gastroduodenální'),
(117852, 4686, 32, 'Za vyšetření'),
(117853, 4687, 32, 'za minutu'),
(117854, 4688, 32, 'Intransaálně'),
(117855, 4689, 32, 'intranasálně'),
(117856, 4690, 32, 'Perorálně'),
(117857, 4691, 32, 'perorálně'),
(117858, 4692, 32, 'Per rectum'),
(117859, 4693, 32, 'per rectum'),
(117860, 4694, 32, 'Procento'),
(117861, 4697, 32, 'Percentil'),
(117862, 4698, 32, 'Perforace vpravo'),
(117863, 4699, 32, 'Vyhledat'),
(117864, 4700, 32, 'Provést tuto akci'),
(117865, 4703, 32, 'Vyšetřující laboratoř'),
(117866, 4705, 32, 'Tečka');
INSERT INTO `lang_definitions` VALUES
(117867, 4706, 32, 'Časové období během kterého se lze přihlásit s expirovaným heslem'),
(117868, 4707, 32, 'Peroperační péče'),
(117869, 4708, 32, 'Periferní'),
(117870, 4712, 32, 'Osoba'),
(117871, 4713, 32, 'Personalizace'),
(117872, 4717, 32, 'Lékárny'),
(117873, 4718, 32, 'Lékárna'),
(117874, 4720, 32, 'Pneumothorax'),
(117875, 4721, 32, 'phiMail umožňuje odesáílání CCD'),
(117876, 4722, 32, 'phiMail umožňuje odesáílání CCR'),
(117877, 4723, 32, 'Intreval kontroly zpráv phiMailu v minutách'),
(117878, 4724, 32, 'Uživatel notifikací phiMailu'),
(117879, 4725, 32, 'heslo pro phiMail'),
(117880, 4726, 32, 'adresa serveru phiMailu'),
(117881, 4727, 32, 'uživatelské jméno phiServeru'),
(117882, 4729, 32, 'Telefon'),
(117883, 4730, 32, 'Seznam telefonních hovorů'),
(117884, 4733, 32, 'Heslo pro telefonní bránu'),
(117885, 4734, 32, 'URL telefonní brány'),
(117886, 4735, 32, 'Uživatelské jméno telefonní brány'),
(117887, 4736, 32, 'Telefon domů'),
(117888, 4737, 32, 'Hodiny telefonických upozornění'),
(117889, 4738, 32, 'Telefonní číslo'),
(117890, 4739, 32, 'Telefonní číslo'),
(117891, 4740, 32, 'Fotofobie'),
(117892, 4741, 32, 'Fotografie'),
(117893, 4742, 32, 'PHP komprimováno'),
(117894, 4743, 32, 'Kód PHP CURL musí být na vašem serveru zapnut'),
(117895, 4744, 32, 'PHP extrahováno'),
(117896, 4745, 32, 'kontrola přístupu php-GACL je vypnuta'),
(117897, 4746, 32, 'PHP-gacl není instalováno'),
(117898, 4747, 32, 'Fyzikální vyšetření'),
(117899, 4749, 32, 'Požadavek lékaře'),
(117900, 4750, 32, 'Podpis lékaře'),
(117901, 4752, 32, 'Lékaři'),
(117902, 4753, 32, 'vybrat'),
(117903, 4754, 32, 'vybrat'),
(117904, 4755, 32, 'Vybrat CSS téma'),
(117905, 4757, 32, 'Zánětlivé onemocnění v oblasti pánve'),
(117906, 4758, 32, 'Velikost tablety'),
(117907, 4759, 32, 'Tablety'),
(117908, 4760, 32, 'Pro instalaci umístěte databázový .zip soubor v následujícím adresáři'),
(117909, 4761, 32, 'Přesuňte stažený .zip soubor ICD10 do následujícího adresáře'),
(117910, 4762, 32, 'Přesuňte stažený .zip soubor ICD9 do následujícího adresáře'),
(117911, 4763, 32, 'Přesuňte stažený .zip soubor RxNorm do následujícího adresáře'),
(117912, 4764, 32, 'Přesuňte stažený .zip soubor Snomed do následujícího adresáře'),
(117913, 4767, 32, 'Prostý text'),
(117914, 4768, 32, 'Plán'),
(117915, 4771, 32, 'Jméno plánu'),
(117916, 4779, 32, 'Plán:'),
(117917, 4782, 32, 'Plány:'),
(117918, 4784, 32, 'Hráč'),
(117919, 4785, 32, 'Herní pozice'),
(117920, 4786, 32, 'Prosím volejte pokud je něktará výše uvedená informace neplatná'),
(117921, 4787, 32, 'Prosím změňte  heslo.'),
(117922, 4788, 32, 'Prosím  vyberte soubor'),
(117923, 4789, 32, 'Prosím zvolte pacienta'),
(117924, 4790, 32, 'Prosím proveďte platný výběr ze seznamu'),
(117925, 4791, 32, 'Prosím proveďte platný výběr.'),
(117926, 4792, 32, 'Prosím vyberte hodnotu pro'),
(117927, 4793, 32, 'Prosím vyberte rozsah období a klikněte na Obnovit pro zobrazení výsledků.'),
(117928, 4794, 32, 'Prosím vyberte správně formátovaný EDI-271 soubor.'),
(117929, 4795, 32, 'Klikněte na Stáhnout pro stažení deidentifikovaných dat'),
(117930, 4796, 32, 'Klikněte na Stáhnout pro stažení reidentifikovaných dat'),
(117931, 4797, 32, 'Prosím zavřete okno.'),
(117932, 4798, 32, 'Prosím porovnejte nové jméno'),
(117933, 4800, 32, 'Prosím opravte hodnoty před aplikováním změn!'),
(117934, 4801, 32, 'Prosím vytvořte následující adresář před dalším krokem'),
(117935, 4804, 32, 'Prosím nepoužívetje tlačítko pro aktualizaci  nebo obnovení ve vašem prohlížeči pro  tuto stránku před uplynutím minimálně 10 minut.'),
(117936, 4805, 32, 'PROSÍM ZAPNĚTE CURL ROZŠÍŘENÍ'),
(117937, 4806, 32, 'PROSÍM ZAPNĚTE CURL ROZŠÍŘENÍ'),
(117938, 4807, 32, 'PROSÍM ZAPNĚTE SOAP ROZŠÍŘENÍ'),
(117939, 4808, 32, 'PROSÍM ZAPNĚTE XML ROZŠÍŘENÍ'),
(117940, 4810, 32, 'Prosím zadejte datum.'),
(117941, 4812, 32, 'Prosím zadejte zprávu'),
(117942, 4813, 32, 'Prosím zadejte peněžní obnos za použití pouze znaků čísel a desetinnmého místa'),
(117943, 4814, 32, 'Prosím zadejte nové heslo'),
(117944, 4815, 32, 'Prosím zadejte název!'),
(117945, 4816, 32, 'Prosím zadejte platnou Direct Adresu výše.'),
(117946, 4817, 32, 'Prosím zadejte alespoň jméno položky'),
(117947, 4819, 32, 'Prosím zadejte platný reidentifikační kód'),
(117948, 4820, 32, 'Prosím zadejte koncové datum vyšší než datum počáteční !'),
(117949, 4821, 32, 'Prosím zadejte nový řetězec k vyhledávání'),
(117950, 4822, 32, 'Prosím zadejte platný reidentifikační kód'),
(117951, 4823, 32, 'Prosím zadejte heslo'),
(117952, 4824, 32, 'Prosím vyplňte číslo ověření'),
(117953, 4826, 32, 'Prosím vyplňte datum'),
(117954, 4827, 32, 'Prosím vyplňte platební obnos'),
(117955, 4828, 32, 'Prosím vyplňte kategorii platby'),
(117956, 4831, 32, 'Prosím vyplňte je  před pokračováním.'),
(117957, 4832, 32, 'Prosím označte důvod návštěvy'),
(117958, 4833, 32, 'Prosím vložte výše vyhledávací kritéria a klikem na Odeslat zahajte generování zprávy'),
(117959, 4834, 32, 'Prosím vložte výše vyhledávací kritéria a klikem na Odeslat přejděte k prohlížení výsledků.'),
(117960, 4835, 32, 'Prosím vložte výše vyhledávací kritéria a klikem na Odeslat přejděte k prohlížení výsledků (Výsledky budou zobrazeny ve vyskakovacím okně).'),
(117961, 4836, 32, 'Prosím znovu se přihlaste.'),
(117962, 4837, 32, 'Vezměte prosím na vědomí, že generování vyúčtování je složitý proces a může trvat velmi dlouho (až několik minut). Váš webový prohlížeč se může zdát neaktivní.'),
(117963, 4838, 32, 'Vezměte na vědomí , že konstanty jsou citlivé na velikost písmen a je povolen libovolný řetězec'),
(117964, 4839, 32, 'Prosím použijte pouze písmena'),
(117965, 4840, 32, 'Prosím použijte pouze písmena bez mezer'),
(117966, 4841, 32, 'Prosím zaplaťte tento obnos'),
(117967, 4842, 32, 'Prosím přesuňte instalační soubory do následujícího adresáře'),
(117968, 4844, 32, 'Resetujte heslo'),
(117969, 4845, 32, 'Restartujte Apache server před zahájením deidentifikace.'),
(117970, 4846, 32, 'Podívejte se do přiloženého PDF'),
(117971, 4847, 32, 'Prosím vyberte'),
(117972, 4849, 32, 'Prosím vyberte jazyk'),
(117973, 4850, 32, 'Prosím vyberte pacienta'),
(117974, 4853, 32, 'Prosím vyberte poskytovatele výkonu'),
(117975, 4854, 32, 'Prosím vyberte příjemce'),
(117976, 4855, 32, 'Prosím vyberte počáteční a koncové datum'),
(117977, 4856, 32, 'Prosím vyberte platného příjemce'),
(117978, 4857, 32, 'Prosím vyberte aktivní skupinu'),
(117979, 4858, 32, 'Prosím vyberte upřesňující důvod pro kód '),
(117980, 4859, 32, 'Prosím vyberte událost'),
(117981, 4860, 32, 'Prosím vyberte libovolnou volbu vyhledávání.'),
(117982, 4863, 32, 'Prosím vyberte minimálně jednu preskripci'),
(117983, 4864, 32, 'Prosím vyberte vyšetření'),
(117984, 4865, 32, 'Prosím vyberte požadované stranky ke kopírování nebo přeposlání:'),
(117985, 4866, 32, 'Prosím vyberte platební metodu'),
(117986, 4867, 32, 'Prosím vyberte typ platby.'),
(117987, 4868, 32, 'Prosím zvolte kategorii návštěvy'),
(117988, 4870, 32, 'Prosím znastavte'),
(117989, 4871, 32, 'Prosím nastavte proměnnou de-identification_config zpět na 0'),
(117990, 4873, 32, 'Prosím zahajte nový proces deidentifikace'),
(117991, 4874, 32, 'Prosím upgradujte LibreEHR databázi pro zahrnutí deidentifikačních procedur, funkcí a tabulek.'),
(117992, 4875, 32, 'Prosím koukněte do logu chyb deidentifikace pro více podrobností'),
(117993, 4876, 32, 'Prosím přejděte za chvíli na na obrazovku deidentifikace'),
(117994, 4877, 32, 'Prosím přejděte za chvíli na obrazovku reidentifikace'),
(117995, 4878, 32, 'Prosím přejděte za chvíli na obrazovku'),
(117996, 4890, 32, 'Pneumokoková vakcína'),
(117997, 4891, 32, 'Pneumonie - vakcinace'),
(117998, 4892, 32, 'Pneumonie - vakcinančí status pro starší dospělé'),
(117999, 4893, 32, 'Pneumonie - vakcinančí status pro starší dospělé (CQM)'),
(118000, 4894, 32, 'Podiatrický'),
(118001, 4895, 32, 'Podiatrie'),
(118002, 4901, 32, 'Polydipsie'),
(118003, 4902, 32, 'Polypy'),
(118004, 4903, 32, 'Polyurie'),
(118005, 4904, 32, 'Nechutenství'),
(118006, 4905, 32, 'Oběhová nedostatečnost'),
(118007, 4906, 32, 'Hypacusis'),
(118008, 4907, 32, 'K prohlížení reportu musí být zapnuta vyskakovací okna'),
(118009, 4909, 32, 'Vyskakovací okna'),
(118010, 4910, 32, 'Portál'),
(118011, 4911, 32, 'Aktivity portálu'),
(118012, 4912, 32, 'ID portálu'),
(118013, 4913, 32, 'Portál ID  neodpovídá  požadavku z protálu !'),
(118014, 4914, 32, 'Chybí heslo pro portál'),
(118015, 4915, 32, 'Portálové požadavky'),
(118016, 4916, 32, 'Portrét'),
(118017, 4921, 32, 'Pozice'),
(118018, 4922, 32, 'Pozitivní'),
(118019, 4926, 32, 'Zadní rýma ( Post nasal drip )'),
(118020, 4928, 32, 'Pooperační'),
(118021, 4930, 32, 'Odeslat k datu'),
(118022, 4933, 32, 'Popotratová péče'),
(118023, 4934, 32, 'Popotratová antikoncepce'),
(118024, 4936, 32, 'Sledování po potratu'),
(118025, 4937, 32, 'Poštovní'),
(118026, 4938, 32, 'Poštovní kód'),
(118027, 4939, 32, 'Poštovní kód'),
(118028, 4945, 32, 'Odesláno na'),
(118029, 4953, 32, 'Praxe'),
(118030, 4954, 32, 'Výchozí nastavení praxe'),
(118031, 4955, 32, 'Nastavení praxe'),
(118032, 4963, 32, 'Volba'),
(118033, 4964, 32, 'Volby'),
(118034, 4965, 32, 'Preferovaná kategorie událostí'),
(118035, 4966, 32, 'Preferovaný jazyk'),
(118036, 4967, 32, 'Preferovaná lékárna'),
(118037, 4969, 32, 'Těhotenský test'),
(118038, 4970, 32, 'Předběžný'),
(118039, 4971, 32, 'Přípravy pro generování zprávy'),
(118040, 4973, 32, 'Předpis'),
(118041, 4975, 32, 'Historie předpisů'),
(118042, 4976, 32, 'Import historie předpisů úspěšně dokončen'),
(118043, 4977, 32, 'Označení předpisu'),
(118044, 4979, 32, 'Preskripce'),
(118045, 4985, 32, 'Současný'),
(118046, 4986, 32, 'Stěžuje si'),
(118047, 4987, 32, 'Uvádí potíže(e)'),
(118048, 4988, 32, 'Zmáčkněte Pokračovat pro provedení'),
(118049, 4989, 32, 'Pracovní diagnóza'),
(118050, 4990, 32, 'Pracovní diagnóza dle specialistů'),
(118051, 4991, 32, 'Předch.'),
(118052, 4992, 32, 'Předch. Med/Oper Hx'),
(118053, 4993, 32, 'Předch. měs. (podržte pro nabídku)'),
(118054, 4994, 32, 'Předch. rok (podržte pro nabídku)'),
(118055, 4995, 32, 'Preventivní péče'),
(118056, 4998, 32, 'Náhled události'),
(118057, 5000, 32, 'Náhled'),
(118058, 5001, 32, 'Předchozí'),
(118059, 5002, 32, 'Předchozí konzultace'),
(118060, 5003, 32, 'Předchozí den'),
(118061, 5004, 32, 'Předchozí historie/Screening'),
(118062, 5005, 32, 'Předchozí měsíc'),
(118063, 5006, 32, 'Předchozí týden'),
(118064, 5007, 32, 'Cena'),
(118065, 5009, 32, 'Cenová úroveň'),
(118066, 5010, 32, 'Cenová úroveň:'),
(118067, 5011, 32, 'Ceny'),
(118068, 5012, 32, 'Primární'),
(118069, 5022, 32, 'Primární poj'),
(118070, 5023, 32, 'Primární pojištění'),
(118071, 5024, 32, 'Data primárního pojištění'),
(118072, 5025, 32, 'Poskytovatel primárního pojištění'),
(118073, 5026, 32, 'Primární poskytovatel'),
(118074, 5027, 32, 'Tisk'),
(118075, 5028, 32, 'Tisk (HTML)'),
(118076, 5029, 32, 'Print (PDF)'),
(118077, 5030, 32, 'Tiskové změny'),
(118078, 5031, 32, 'Tisk libovolného vyšetření'),
(118079, 5032, 32, 'Tisk prázdného poukazu na ošetření'),
(118080, 5033, 32, 'Tiskový příkaz'),
(118081, 5034, 32, 'Datum tisku'),
(118082, 5039, 32, 'Tiskový formát'),
(118083, 5042, 32, 'Tisková zpráva'),
(118084, 5043, 32, 'Vícečetný tisk'),
(118085, 5046, 32, 'Tisk poznámek'),
(118086, 5047, 32, 'Tisk strany 1'),
(118087, 5048, 32, 'Tisk strany 2'),
(118088, 5049, 32, 'Tisk adresního štítku pacienta'),
(118089, 5052, 32, 'Tisk záznamu'),
(118090, 5053, 32, 'Tisk vybraných záznamů'),
(118091, 5056, 32, 'Tisk tohoto vyšetření'),
(118092, 5057, 32, 'Tisk této poznámky'),
(118093, 5058, 32, 'Tisk této poznámky'),
(118094, 5061, 32, 'Tiskové zobrazení'),
(118095, 5064, 32, 'Vytištěno'),
(118096, 5066, 32, 'Tisk výsledků:'),
(118097, 5067, 32, 'Tisk vynechán, viz testovací výstup v'),
(118098, 5068, 32, 'Tisk vynechán, viz testovací výstup v '),
(118099, 5072, 32, 'Priorita'),
(118100, 5073, 32, 'Priorita '),
(118101, 5074, 32, 'Soukromý'),
(118102, 5075, 32, 'Problém'),
(118103, 5077, 32, 'Seznam problémů'),
(118104, 5078, 32, 'Problémy'),
(118105, 5081, 32, 'Kat. proc.'),
(118106, 5085, 32, 'Proc. výsl.'),
(118107, 5086, 32, 'Procedura'),
(118108, 5087, 32, 'Strana těla pro aplikaci procedury'),
(118109, 5089, 32, 'Kód procedury'),
(118110, 5090, 32, 'Kódy procedury'),
(118111, 5091, 32, 'Lateralizace procedury'),
(118112, 5092, 32, 'Název procedury'),
(118113, 5098, 32, 'Výběr procedury'),
(118114, 5099, 32, 'Poskytovatel procedury'),
(118115, 5100, 32, 'Poskytovatel procedury'),
(118116, 5101, 32, 'Poskytovatelé procedury'),
(118117, 5102, 32, 'Report procedury'),
(118118, 5104, 32, 'Abnormální výsledek procedury'),
(118119, 5105, 32, 'Stavy výsledku procedury'),
(118120, 5106, 32, 'Výsledky procedury'),
(118121, 5107, 32, 'Cesty procedury'),
(118122, 5108, 32, 'Typy vzorků procedury'),
(118123, 5109, 32, 'Report statistik procedur'),
(118124, 5110, 32, 'Typ procedury'),
(118125, 5111, 32, 'Typy  procedury'),
(118126, 5116, 32, 'Zpracovat a odeslat upomínku'),
(118127, 5117, 32, 'Zpracovat ERA soubor'),
(118128, 5118, 32, 'Zpracovat nové soubory pro CSV záznamy'),
(118129, 5119, 32, 'Zpracovat upomínky'),
(118130, 5120, 32, 'Zpracování bude chvíli trvat'),
(118131, 5121, 32, 'Zpracováno'),
(118132, 5122, 32, 'Zpracoval/a :'),
(118133, 5123, 32, 'Datum zpracování'),
(118134, 5124, 32, 'Úspěšně zpracováno'),
(118135, 5125, 32, 'Zpracovávání'),
(118136, 5126, 32, 'Zpracování a odesální upomínek pacientům'),
(118137, 5127, 32, 'Zpracovávání upomínek pacientům'),
(118138, 5128, 32, 'Čas zpracování'),
(118139, 5129, 32, 'Produkt'),
(118140, 5131, 32, 'Produkce'),
(118141, 5132, 32, 'Produkty'),
(118142, 5135, 32, 'Poznámky k průběhu'),
(118143, 5136, 32, 'Karcinom prostaty'),
(118144, 5137, 32, 'Screening karcinomu prostaty'),
(118145, 5138, 32, 'Vyšetření prostaty'),
(118146, 5139, 32, 'Prostatické obtíže'),
(118147, 5140, 32, 'Prostata nezvětšená,nebolestivá  bez nodulů'),
(118148, 5141, 32, 'Protokol'),
(118149, 5142, 32, 'Zadejte absolutní cestu'),
(118150, 5143, 32, 'Zadejte absolutní cestu k souboru'),
(118151, 5145, 32, 'Poskytuje klinický souhrn pro každou návštěvu pacienta'),
(118152, 5146, 32, 'Na vyžádání poskytuje elektronickou kopii zdravotních informací pacientů ( zahrnuje výsledky diagnostických testů, seznam problémů, seznam medikace, lékové alergie ).'),
(118153, 5149, 32, 'Zadat platnou e-mailovou adresu'),
(118154, 5150, 32, 'Je poskytnut klinický souhrn ?'),
(118155, 5151, 32, 'Jsou poskytnuty edukační zdroje ?'),
(118156, 5152, 32, 'Poskytovatel'),
(118157, 5153, 32, 'ID poskytovatele'),
(118158, 5154, 32, 'ID poskytovatele'),
(118159, 5159, 32, 'Číslo poskytovatele'),
(118160, 5160, 32, 'Vztahy s poskytovatelem'),
(118161, 5162, 32, 'Poskytovatel:'),
(118162, 5163, 32, 'Poskytovatelé'),
(118163, 5169, 32, 'Psych. diagnóza'),
(118164, 5170, 32, 'Psych. medikace'),
(118165, 5171, 32, 'Psychiatrický'),
(118166, 5173, 32, 'Psychiatrická diagnóza'),
(118167, 5174, 32, 'Psychiatrické vyšetření'),
(118168, 5175, 32, 'Psychiatrická anamnéza'),
(118169, 5177, 32, 'Psychiatrická medikace'),
(118170, 5178, 32, '% pac.'),
(118171, 5179, 32, 'Pac. poznámky'),
(118172, 5180, 32, 'Pac. poznámky/auth.'),
(118173, 5181, 32, 'Pac. přeplatky'),
(118174, 5188, 32, 'PT_MESTO'),
(118175, 5189, 32, 'PT_DATNAR'),
(118176, 5190, 32, 'PT_EMAIL'),
(118177, 5191, 32, 'PT_JMENO'),
(118178, 5192, 32, 'PT_PRIJMENI'),
(118179, 5193, 32, 'PT_JMENO2'),
(118180, 5194, 32, 'PT_MOBIL'),
(118181, 5195, 32, 'PT_TEL_DOMU'),
(118182, 5196, 32, 'PT_PSC'),
(118183, 5198, 32, 'PT_STAT'),
(118184, 5199, 32, 'PT_ULICE'),
(118185, 5201, 32, 'Veřejný'),
(118186, 5205, 32, 'Pulmonální'),
(118187, 5206, 32, 'Pulz'),
(118188, 5208, 32, 'Nákup'),
(118189, 5210, 32, 'Nákupy'),
(118190, 5213, 32, 'á 3h'),
(118191, 5214, 32, 'á 4h'),
(118192, 5215, 32, 'á 5h'),
(118193, 5216, 32, 'á 6h'),
(118194, 5217, 32, 'á 8h'),
(118195, 5218, 32, 'denně'),
(118196, 5222, 32, 'Množ.'),
(118197, 5223, 32, 'MNOŽ..'),
(118198, 5224, 32, 'Kvalita'),
(118199, 5225, 32, 'Měření kvality (CQM)'),
(118200, 5226, 32, 'Kvantita'),
(118201, 5229, 32, 'Množství zřejmě nelze použít'),
(118202, 5231, 32, 'Označení otázky'),
(118203, 5232, 32, 'Fronta dávkového zpracování HCFA'),
(118204, 5233, 32, 'Fronta dávkového zpracování a tisku HCFA'),
(118205, 5234, 32, 'Fronta dávkového zpracování UB-92'),
(118206, 5235, 32, 'Fronta dávkového zpracování a tisku UB-92'),
(118207, 5236, 32, 'Čeká na zpracování'),
(118208, 5237, 32, 'Správa událostí ke zpracování'),
(118209, 5241, 32, 'Ukončit'),
(118210, 5242, 32, 'Abstinence od'),
(118211, 5245, 32, 'Rasa'),
(118212, 5246, 32, 'Rasa a etnikum'),
(118213, 5247, 32, 'Rasa/Etnikum'),
(118214, 5249, 32, 'Radio tlačítka (přepínače)'),
(118215, 5251, 32, 'Rozmezí'),
(118216, 5252, 32, 'Vyrážky'),
(118217, 5254, 32, 'Poměr'),
(118218, 5256, 32, 'Reidentifikace'),
(118219, 5257, 32, 'Proces reidentifikace je kompletní'),
(118220, 5258, 32, 'Proces reidentifikace stále běží'),
(118221, 5259, 32, 'Redidentifikační soubory budou uloženy v'),
(118222, 5260, 32, 'Opakované poranění ?'),
(118223, 5261, 32, 'Znovuotevření'),
(118224, 5262, 32, 'Znovu otevřeno'),
(118225, 5263, 32, 'Reakce'),
(118226, 5264, 32, 'Reakce'),
(118227, 5265, 32, 'Číst'),
(118228, 5267, 32, 'Anamnéze pouze ke čtení'),
(118229, 5268, 32, 'Skutečné jméno'),
(118230, 5269, 32, 'Skutečně smazat'),
(118231, 5270, 32, 'Důvod'),
(118232, 5272, 32, 'Přičina smrti'),
(118233, 5274, 32, 'Důvod odeslání'),
(118234, 5275, 32, 'Důvod návštěvy'),
(118235, 5276, 32, 'Důvod/Formulář'),
(118236, 5277, 32, 'Příjmový doklad'),
(118237, 5278, 32, 'Příjmový doklad pro platbu'),
(118238, 5279, 32, 'Příjmový doklad vygenerován'),
(118239, 5280, 32, 'Hlášení příjmových dokladů dle platební metody'),
(118240, 5281, 32, 'Souhrn platebních dokladů'),
(118241, 5282, 32, 'Přijato'),
(118242, 5283, 32, 'Přijato kým'),
(118243, 5284, 32, 'Přijaté faxy'),
(118244, 5285, 32, 'Přijato, neprohlíženo'),
(118245, 5287, 32, 'Příjemce'),
(118246, 5288, 32, 'ID příjemce'),
(118247, 5289, 32, 'ID příjemce (ISA08)'),
(118248, 5291, 32, 'ID příjemce'),
(118249, 5292, 32, 'Poslední 3 hesla nejsou povolena'),
(118250, 5293, 32, 'Příjemce'),
(118251, 5294, 32, 'Seznam příjemců je prázdný'),
(118252, 5295, 32, 'Jméno příjemce'),
(118253, 5298, 32, 'Doporučení'),
(118254, 5299, 32, 'Doporučení pro návaznou péči'),
(118255, 5300, 32, 'Doporučení'),
(118256, 5301, 32, 'Doporučení a léčba'),
(118257, 5302, 32, 'Doporučení dle specialisty'),
(118258, 5303, 32, 'Záznam'),
(118259, 5304, 32, 'Záznam již existuje'),
(118260, 5310, 32, 'Změny  v záznamech a grafech vitálních funkcí'),
(118261, 5311, 32, 'Záznam demografických údajů'),
(118262, 5314, 32, 'Záznam platby'),
(118263, 5315, 32, 'Záznam data požadavku'),
(118264, 5316, 32, 'Zaznamenat kuřáctví pacientů starších 13 let'),
(118265, 5317, 32, 'Záznamy'),
(118266, 5318, 32, 'záznamy nalezeny'),
(118267, 5319, 32, 'záznamy nalezeny.'),
(118268, 5320, 32, 'Rekreační užívání drog'),
(118269, 5321, 32, 'Rekreační drogy'),
(118270, 5322, 32, 'Rektální'),
(118271, 5323, 32, 'Rektální vyšetření'),
(118272, 5324, 32, 'rektálně'),
(118273, 5325, 32, 'Přesměrování'),
(118274, 5326, 32, 'Zarudnutí'),
(118275, 5327, 32, 'Redukovaný:'),
(118276, 5328, 32, 'Odeslat'),
(118277, 5329, 32, 'Odeslat kým'),
(118278, 5330, 32, 'Datum odeslání'),
(118279, 5331, 32, 'Odeslat kam'),
(118280, 5333, 32, 'Rozsah referenčních hodnot výsledků'),
(118281, 5335, 32, 'Odesílající'),
(118282, 5336, 32, 'Jméno a podpis odesílajícího'),
(118283, 5337, 32, 'Odeslání'),
(118284, 5340, 32, 'Datum odeslání'),
(118285, 5357, 32, 'Odesílající lékař a praxe'),
(118286, 5358, 32, 'Odesílající poskytovatel'),
(118287, 5362, 32, 'Normální reflexy'),
(118288, 5363, 32, 'Obnovit'),
(118289, 5365, 32, 'Obnova upomínek'),
(118290, 5370, 32, 'registrace'),
(118291, 5372, 32, 'Registrován'),
(118292, 5373, 32, 'registrován'),
(118293, 5374, 32, 'Registrované moduly'),
(118294, 5375, 32, 'Datum registrace'),
(118295, 5376, 32, 'Registrační formulář'),
(118296, 5377, 32, 'Rehabilitace'),
(118297, 5379, 32, 'Odmítnuto'),
(118298, 5380, 32, 'Možnost relapsu'),
(118299, 5381, 32, 'Související s'),
(118300, 5382, 32, 'Související'),
(118301, 5383, 32, 'Související problém'),
(118302, 5384, 32, 'Související poznámky pacienta'),
(118303, 5385, 32, 'Vztahy/Děti'),
(118304, 5386, 32, 'Vztahy'),
(118305, 5387, 32, 'Vztah'),
(118306, 5388, 32, 'Relativní zařazení této entity'),
(118307, 5389, 32, 'Příbuzní'),
(118308, 5390, 32, 'Hypertenze v příbuzenstvu'),
(118309, 5391, 32, 'Karcinom v příbuzenstvu'),
(118310, 5392, 32, 'Diabetes v příbuzenstvu'),
(118311, 5393, 32, 'Epilepsie v příbuzenstvu'),
(118312, 5394, 32, 'Srdeční choroby v příbuzenstvu'),
(118313, 5395, 32, 'Duševní choroby v příbuzenstvu'),
(118314, 5396, 32, 'CMP v příbuzenstvu'),
(118315, 5397, 32, 'Sebevraždy v příbuzenstvu'),
(118316, 5398, 32, 'TBC v příbuzenstvu'),
(118317, 5402, 32, 'Datum vydání'),
(118318, 5403, 32, 'Náboženství'),
(118319, 5406, 32, 'Znovupřihlášení'),
(118320, 5407, 32, 'Upom.'),
(118321, 5408, 32, 'Zapamatovat vybrané zařízení'),
(118322, 5409, 32, 'Upozornění'),
(118323, 5410, 32, 'Intervaly upozornění'),
(118324, 5411, 32, 'Upomínky nejsou dosud nastavené'),
(118325, 5413, 32, 'Upomínky'),
(118326, 5415, 32, 'Vzdálený host'),
(118327, 5416, 32, 'Smazat'),
(118328, 5419, 32, 'Smazat skupinu'),
(118329, 5420, 32, 'Smazat formulář skupiny'),
(118330, 5421, 32, 'Smaže podporu pro imunizace'),
(118331, 5422, 32, 'Smaže podporu pro phpMyAdmin'),
(118332, 5423, 32, 'Smaže podporu preskrice'),
(118333, 5426, 32, 'Nefrolithiáza'),
(118334, 5427, 32, 'Přejmenovat'),
(118335, 5428, 32, 'Přejmenovat skupinu'),
(118336, 5432, 32, 'Přeobjednat'),
(118337, 5436, 32, 'Opak.'),
(118338, 5437, 32, 'Opakovat nové heslo'),
(118339, 5438, 32, 'Opakující se událost'),
(118340, 5439, 32, 'Opakující se informace:'),
(118341, 5441, 32, 'NAHRADIT'),
(118342, 5442, 32, 'nahradit celou sadu kódů'),
(118343, 5443, 32, 'nahrazeno'),
(118344, 5444, 32, 'Datum odpovědi'),
(118345, 5445, 32, 'Odpověď od'),
(118346, 5446, 32, 'Zpráva'),
(118347, 5447, 32, 'Klinická zpráva'),
(118348, 5463, 32, 'Zprávy'),
(118349, 5465, 32, 'Vyžádat si popis'),
(118350, 5466, 32, 'Chybí požadavek na ID !'),
(118351, 5467, 32, 'Požadavek ignorován - zpracování požadavku již probíhá !'),
(118352, 5469, 32, 'Stav požadavku'),
(118353, 5470, 32, 'Typ požadavku'),
(118354, 5471, 32, 'Typ požadavku není implementován'),
(118355, 5472, 32, 'Požadováno kým'),
(118356, 5473, 32, 'Požadované datum'),
(118357, 5474, 32, 'Požadovaná služba'),
(118358, 5475, 32, 'Je vyžadováno silné heslo'),
(118359, 5476, 32, 'Je vyžadováno unikátní heslo'),
(118360, 5477, 32, 'Vyžadováno'),
(118361, 5479, 32, 'Chybí požadované pole. Vyberte prosím EDI-271 soubor k nahrání'),
(118362, 5480, 32, 'Chybí požadované pole: Prosím  zadejte  jméno'),
(118363, 5481, 32, 'Chybí požadované pole: Prosím  zadejte  příjmení'),
(118364, 5482, 32, 'Chybí požadované pole: Prosím  zadejte  uživatelské jméno'),
(118365, 5483, 32, 'Požadovaná pole'),
(118366, 5484, 32, 'Požadavky'),
(118367, 5485, 32, 'REZERVOVÁNO'),
(118368, 5486, 32, 'Rezervováno'),
(118369, 5491, 32, 'Reset'),
(118370, 5496, 32, 'Vyřešeno'),
(118371, 5497, 32, 'Respirace'),
(118372, 5499, 32, 'Respirační'),
(118373, 5504, 32, 'Výsledek'),
(118374, 5505, 32, 'Jméno výsledku'),
(118375, 5506, 32, 'Stav výsledku'),
(118376, 5508, 32, 'Výsledek, použijte % jako zástupný znak'),
(118377, 5509, 32, 'Výsledky'),
(118378, 5510, 32, 'Výsledky a'),
(118379, 5512, 32, 'Skupiny výsledků'),
(118380, 5513, 32, 'Pouze výsledky'),
(118381, 5514, 32, 'Cesta k výsledkům'),
(118382, 5515, 32, 'Výsledků na stránku'),
(118383, 5516, 32, 'Výsledky/Detaily'),
(118384, 5517, 32, 'Vyšetření sítnice'),
(118385, 5521, 32, 'Návrat do kalendáře'),
(118386, 5530, 32, 'Opětovné použití 3 předchozích hesel není možné!'),
(118387, 5532, 32, 'Posoudit & Schválit'),
(118388, 5537, 32, 'Zhodnoceno'),
(118389, 5538, 32, 'Revize'),
(118390, 5539, 32, 'Revmatodiní artritis'),
(118391, 5540, 32, 'Revmatodiní artritis'),
(118392, 5542, 32, 'Pravé ucho'),
(118393, 5543, 32, 'pravé ucho'),
(118394, 5546, 32, 'Tinnitus'),
(118395, 5547, 32, 'Tinnitus'),
(118396, 5549, 32, 'Rizikové faktory'),
(118397, 5550, 32, 'Úroveň rizika'),
(118398, 5552, 32, 'Rozsah pohybu (ROM)'),
(118399, 5561, 32, 'Cesta'),
(118400, 5564, 32, 'Řádky'),
(118401, 5568, 32, 'Pravidlo'),
(118402, 5569, 32, 'Přidání pravidla'),
(118403, 5570, 32, 'Detail pravidla'),
(118404, 5572, 32, 'Editace pravidla'),
(118405, 5578, 32, 'Pravidla'),
(118406, 5580, 32, 'Konfigurace pravidel'),
(118407, 5581, 32, 'Běžící příkaz: '),
(118408, 5582, 32, 'Ruptura'),
(118409, 5605, 32, 'Prodej'),
(118410, 5606, 32, 'Prodeje'),
(118411, 5607, 32, 'Prodeje po položkách'),
(118412, 5610, 32, 'Stejný den'),
(118413, 5612, 32, 'Vzorek'),
(118414, 5617, 32, 'Sob'),
(118415, 5618, 32, 'Sob &amp; Ned'),
(118416, 5619, 32, 'Sobota'),
(118417, 5620, 32, 'Uložit'),
(118418, 5621, 32, 'ULOŽIT'),
(118419, 5622, 32, 'Uložit a zavřít'),
(118420, 5623, 32, 'Uložit a smazat požadavek'),
(118421, 5626, 32, 'Uožit jako nový'),
(118422, 5627, 32, 'Uložit jako novou poznámku'),
(118423, 5628, 32, 'Uložit nastavení certifikátů'),
(118424, 5629, 32, 'Uožit změny'),
(118425, 5630, 32, 'Uložit formulář'),
(118426, 5631, 32, 'Uložit imunizace'),
(118427, 5632, 32, 'Uložit nové pole'),
(118428, 5633, 32, 'Uložit novou skupinu'),
(118429, 5634, 32, 'Uložit nový seznam'),
(118430, 5635, 32, 'Uložit novou šablonu'),
(118431, 5637, 32, 'Uložit personální údaje pacienta'),
(118432, 5639, 32, 'Uložit transakci'),
(118433, 5640, 32, 'Úspěšně uloženo'),
(118434, 5641, 32, 'Skenováno'),
(118435, 5642, 32, 'Skenovaná poznámka k vyšetření'),
(118436, 5643, 32, 'Adresář pro skener'),
(118437, 5645, 32, 'plán/plánovat'),
(118438, 5648, 32, 'Skolióza'),
(118439, 5650, 32, 'Screening/ Testování'),
(118440, 5652, 32, 'SE Adresa'),
(118441, 5653, 32, 'SE Město'),
(118442, 5654, 32, 'SE Země'),
(118443, 5655, 32, 'SE Lokalita'),
(118444, 5656, 32, 'SE Poštovní kód'),
(118445, 5657, 32, 'SE Stát'),
(118446, 5658, 32, 'SE Zip Kód'),
(118447, 5659, 32, 'Hledat'),
(118448, 5661, 32, 'hledat'),
(118449, 5662, 32, 'hledat znovu'),
(118450, 5663, 32, 'Hledat ve všech sloupcích'),
(118451, 5667, 32, 'Hledat v'),
(118452, 5668, 32, 'Hledat v'),
(118453, 5669, 32, 'Hledat nebo Přidat pacienta'),
(118454, 5670, 32, 'Hledat platbu'),
(118455, 5671, 32, 'Výsledky vyhledávání'),
(118456, 5672, 32, 'Výsledky vyhledávání:'),
(118457, 5673, 32, 'Hledat vybrané'),
(118458, 5674, 32, 'Vyhledávaný řetězec neodpovídá položkám v databázi'),
(118459, 5675, 32, 'Vyhledávaný řetězec by měl mít minimálně 3 znaky'),
(118460, 5676, 32, 'Hledat text'),
(118461, 5677, 32, 'Hledat události'),
(118462, 5678, 32, 'Hledat/Přidat'),
(118463, 5680, 32, 'Hledání návštěvy'),
(118464, 5681, 32, 'Hledám...'),
(118465, 5684, 32, 'Druhý'),
(118466, 5687, 32, 'Sekundární'),
(118467, 5693, 32, 'ID sekce'),
(118468, 5694, 32, 'ID a název sekce nemohou být prázdné'),
(118469, 5695, 32, 'Jméno sekce'),
(118470, 5696, 32, 'Sekce úspěšně uložena'),
(118471, 5698, 32, 'Bezpečnost'),
(118472, 5699, 32, 'Prohlédnout vše'),
(118473, 5700, 32, 'Prohlédnout autorizace'),
(118474, 5701, 32, 'Prohlédnout  růstový graf'),
(118475, 5702, 32, 'Prohlédnout zprávy z naposledy generované sady požadavků'),
(118476, 5704, 32, 'Pozorováno od'),
(118477, 5705, 32, 'Jméno segmentu'),
(118478, 5707, 32, 'Křeče'),
(118479, 5708, 32, 'Vyb.'),
(118480, 5709, 32, 'Vybrat'),
(118481, 5710, 32, 'vybrat'),
(118482, 5711, 32, 'Vybrat součást'),
(118483, 5712, 32, 'Vybrat kontext'),
(118484, 5713, 32, 'Vybrat procenta z řádků nebo vybrat datum'),
(118485, 5714, 32, 'Vybrat časové rozpětí'),
(118486, 5715, 32, 'Vybrat uživatele'),
(118487, 5716, 32, 'Vybrat vše'),
(118488, 5717, 32, 'Vybrat datum změny'),
(118489, 5718, 32, 'Vybrat změny k tisku'),
(118491, 5720, 32, 'Vybrat  kategorii'),
(118492, 5721, 32, 'Vybrat komunikační volby'),
(118493, 5722, 32, 'Vybrat odpovídající checkboxy k vymazání'),
(118494, 5723, 32, 'Vybrat kritéria ke smazání'),
(118495, 5724, 32, 'Vybrat CSV tabulku'),
(118496, 5725, 32, 'Vybrat data nutná pro reidentifikaci'),
(118497, 5726, 32, 'Vybrat data pro zahrnutí do deidentifikace'),
(118498, 5727, 32, 'Vybrat datum'),
(118499, 5729, 32, 'Vybrat diagnózu'),
(118500, 5730, 32, 'Vybrat diagnózu pro deidentifikační požadavek'),
(118501, 5731, 32, 'Vybrat léčivo'),
(118502, 5732, 32, 'Vybrat léčiva'),
(118503, 5733, 32, 'Vybrat léčiva pro deidentifikační požadavek'),
(118504, 5734, 32, 'Vybrat EDI-271 soubor'),
(118505, 5735, 32, 'Vybrat vyšetření'),
(118506, 5736, 32, 'Vybrat pole'),
(118507, 5737, 32, 'Vybrat pole'),
(118508, 5738, 32, 'Vybrat pro tisk'),
(118509, 5739, 32, 'Vybrat imunizace'),
(118510, 5740, 32, 'Vybrat imunizace pro deidentifikační požadavek'),
(118511, 5742, 32, 'Vybrat problém'),
(118512, 5743, 32, 'Vybrat položky'),
(118513, 5744, 32, 'Vybrat jazyk'),
(118514, 5746, 32, 'Vyberte jeden nebo více kódů diagnóz pro zdůvodnění služby'),
(118515, 5747, 32, 'Vyberte jeden nebo více souborů k nahrátí'),
(118516, 5748, 32, 'Vybrat výstup'),
(118517, 5750, 32, 'Vyberte kým požadováno'),
(118518, 5752, 32, 'Vybrat zdroj'),
(118519, 5753, 32, 'Vybrat šablonu'),
(118520, 5754, 32, 'Vybrat položky konfigurace k exportu'),
(118521, 5756, 32, 'Vyberte tisk adresního štítku pacienta z vyskakovacího okna v levé části obrazovky'),
(118522, 5759, 32, 'Vybrat uživatele'),
(118523, 5760, 32, 'Vyberte uživatele ze seznamu'),
(118524, 5761, 32, 'Vyberte jazyky pro přihlašování'),
(118525, 5762, 32, 'Vyberte ANO pro smazání skupiny'),
(118526, 5765, 32, 'Vybráno'),
(118527, 5766, 32, 'Vybrané  vyšetření'),
(118528, 5769, 32, 'Samoplátce'),
(118529, 5771, 32, 'Odeslat'),
(118530, 5774, 32, 'Odesílání probíhá'),
(118531, 5775, 32, 'Odeslat zprávu'),
(118532, 5776, 32, 'Odeslat připomenutí hromadně'),
(118533, 5779, 32, 'Odeslat tento soubor'),
(118534, 5780, 32, 'Odeslat tuto zprávu'),
(118535, 5781, 32, 'Odeslat komu'),
(118536, 5784, 32, 'Odeslat všem'),
(118537, 5786, 32, 'Odeslat na portál'),
(118538, 5787, 32, 'Odeslat na portál'),
(118539, 5788, 32, 'Odesílatel'),
(118540, 5789, 32, 'ID odesílatele'),
(118541, 5790, 32, 'ID odesílatele (ISA06)'),
(118542, 5792, 32, 'ID odesílatele'),
(118543, 5793, 32, 'Odesílání komu'),
(118544, 5795, 32, 'Citlivost:'),
(118545, 5796, 32, 'Vyšetření čití bpn'),
(118546, 5797, 32, 'Odesláno'),
(118547, 5798, 32, 'Odesláno - Potvrzeno'),
(118548, 5799, 32, 'Odesláno kým, ponechte prázdné pro výběr všech'),
(118549, 5800, 32, 'Odesláno kým:'),
(118550, 5801, 32, 'Datum odeslání'),
(118551, 5803, 32, 'Odeslané lékařské zprávy ?'),
(118552, 5804, 32, 'Odesláno úspěšně'),
(118553, 5807, 32, 'odesláno do tiskárny'),
(118554, 5808, 32, 'Odesláno komu, nechte prázdné pro výběr všech'),
(118555, 5809, 32, 'Odesláno komu:'),
(118556, 5810, 32, 'Odesláno, ale doručení nebylo dosud potvrzeno.'),
(118557, 5811, 32, 'Odesláno, nepřijato'),
(118558, 5812, 32, 'Zář.'),
(118559, 5813, 32, 'Odloučený'),
(118560, 5814, 32, 'Září'),
(118561, 5819, 32, 'Server může být offline'),
(118562, 5820, 32, 'Zpráva serveru:'),
(118563, 5821, 32, 'Služba'),
(118564, 5822, 32, 'Kategorie služby'),
(118565, 5823, 32, 'Kód služby'),
(118566, 5825, 32, 'Kódy služeb'),
(118567, 5826, 32, 'Datum služby'),
(118568, 5827, 32, 'Datum služby :'),
(118569, 5829, 32, 'Umístění služby'),
(118570, 5830, 32, 'Název služby'),
(118571, 5831, 32, 'Služba poskytovaná specialistou'),
(118572, 5834, 32, 'Služby'),
(118573, 5835, 32, 'Služby podle kategorie'),
(118574, 5836, 32, 'Služby poskytnuté'),
(118575, 5837, 32, 'Služby poskytnuté'),
(118576, 5838, 32, 'Služby/Produkty'),
(118577, 5839, 32, 'Typ sezení'),
(118578, 5840, 32, 'Nastavit'),
(118579, 5843, 32, 'Nastavit prioritu zpracování pro CDR zprávy'),
(118580, 5844, 32, 'Nastavit prioritu zpracování pro pacientské připomínky ( v plném klinickém módu)'),
(118581, 5847, 32, 'Nastavit na výchozí'),
(118582, 5848, 32, 'Nastavení čísla verze v databázi'),
(118583, 5849, 32, 'Nastavení'),
(118584, 5851, 32, 'Těžká migréna'),
(118585, 5853, 32, 'Stupeň bolesti'),
(118586, 5854, 32, 'Stupeň bolesti'),
(118587, 5855, 32, 'Pohlaví'),
(118588, 5856, 32, 'Sexuálně přenosné choroby'),
(118589, 5859, 32, 'Sdílení'),
(118590, 5863, 32, 'Krátký popis'),
(118591, 5864, 32, 'Dušnost'),
(118592, 5865, 32, 'Dušnost'),
(118593, 5866, 32, 'Dušnost 2'),
(118594, 5869, 32, 'Mělo by být povoleno'),
(118595, 5870, 32, 'Mělo by být jako nnnn-nnnn-nn'),
(118596, 5871, 32, 'Mělo by obsahovat 2 písmena'),
(118597, 5872, 32, 'Má obsahovat 10 čísel'),
(118598, 5873, 32, 'Má obsahovat pouze 10 čísel'),
(118599, 5874, 32, 'Rameno'),
(118600, 5875, 32, 'Rameno + klíční kost'),
(118601, 5876, 32, 'Problémy s ramenem'),
(118602, 5877, 32, 'Zobrazit'),
(118603, 5878, 32, 'Zobrazit aktivní'),
(118604, 5880, 32, 'Zobrazit vše'),
(118605, 5881, 32, 'Zobrazit všechny procedury'),
(118606, 5883, 32, 'Zobrazit všechny transakce'),
(118607, 5884, 32, 'Zobrazit jako zaneprázdněný'),
(118608, 5885, 32, 'Zobrazit pouze oprávněné'),
(118609, 5886, 32, 'Zobrazit dostupné časy'),
(118610, 5887, 32, 'Zobrazit jak US tak metrické jednotky ( hlavní jednotky jsou metrické)'),
(118611, 5888, 32, 'Zobrazit jak US tak metrické jednotky ( hlavní jednotky jsou US)'),
(118612, 5889, 32, 'Zobrazit detaily'),
(118613, 5890, 32, 'Zobrazit pouze chyby ?'),
(118614, 5891, 32, 'Zobrazit graf'),
(118615, 5892, 32, 'Zobrazit plovoucí text při přejetí myší ?'),
(118616, 5893, 32, 'Kolik událostí zobrazit na stránce správy ?'),
(118617, 5894, 32, 'Zobrazit neaktivní'),
(118618, 5896, 32, 'Zobrazit menu'),
(118619, 5897, 32, 'Zobrazit pouze metrické'),
(118620, 5898, 32, 'Zobrazit poznámky'),
(118621, 5901, 32, 'Zobrazit poznámky k pacientovi'),
(118622, 5905, 32, 'Zobrazit připomínky'),
(118623, 5906, 32, 'Zobrazit zprávu'),
(118624, 5915, 32, 'Zobrazení'),
(118625, 5916, 32, 'Zobrazení výsledků'),
(118626, 5918, 32, 'RA - sourozenci'),
(118627, 5920, 32, 'Sourozenci'),
(118628, 5923, 32, 'Sigmoideo - colonoskopie'),
(118629, 5927, 32, 'Podpis'),
(118630, 5929, 32, 'Podpis:'),
(118631, 5932, 32, 'Významný otok:'),
(118632, 5933, 32, 'Zjednodušeně'),
(118633, 5935, 32, 'Zjednodušené personální údaje'),
(118634, 5936, 32, 'Zjednodušené preskripce'),
(118635, 5937, 32, 'Od'),
(118636, 5938, 32, 'Srdečně,'),
(118637, 5946, 32, 'Problémy PND'),
(118638, 5947, 32, 'Chirurgie PND'),
(118639, 5948, 32, 'Citlivost PND'),
(118640, 5949, 32, 'Sinusitis'),
(118641, 5950, 32, 'Stránka'),
(118642, 5951, 32, 'ID stránky'),
(118643, 5957, 32, 'Velikost musí být číslo mezi 1 -999'),
(118644, 5958, 32, 'Velikost/Seznam'),
(118645, 5959, 32, 'Kůže'),
(118646, 5960, 32, 'Kožní nádor'),
(118647, 5961, 32, 'Kožní onemocnění'),
(118648, 5963, 32, 'Přeskočit ověření poznámky k pacientovi'),
(118649, 5964, 32, 'Vynechávám sekci'),
(118650, 5967, 32, 'Kvalita spánku'),
(118651, 5968, 32, 'Kvalita spánku'),
(118652, 5969, 32, 'Spánek'),
(118653, 5974, 32, 'Aktuální stav kuřáctví neznámý'),
(118654, 5976, 32, 'Kuřáctví'),
(118655, 5977, 32, 'SMS opráv.'),
(118656, 5978, 32, 'SMS brána'),
(118657, 5979, 32, 'API klíč SMS brány'),
(118658, 5980, 32, 'API klíč SMS brány'),
(118659, 5981, 32, 'Heslo SMS brány'),
(118660, 5982, 32, 'Uživatelské jméno pro SMS bránu'),
(118661, 5983, 32, 'SMS upozornění'),
(118662, 5984, 32, 'Hodiny pro SMS upozornění'),
(118663, 5985, 32, 'Odeslat SMS před'),
(118664, 5986, 32, 'SMS odeslána'),
(118665, 5988, 32, 'SMS/Email upozornění bylo odesláno'),
(118666, 5989, 32, 'SMTP heslo pro ověření'),
(118667, 5992, 32, 'Jméno hosta SMTP serveru'),
(118668, 5993, 32, 'Číslo portu SMTP serveru'),
(118669, 5994, 32, 'Ověření uživatele SMTP'),
(118670, 6004, 32, 'chrápání'),
(118671, 6005, 32, 'SOZD'),
(118672, 6006, 32, 'Sociální rozdíly'),
(118673, 6009, 32, 'SA'),
(118674, 6011, 32, 'řešení'),
(118675, 6015, 32, 'Některé kódy nebyly zobrazeny.'),
(118676, 6016, 32, 'Některá vyšetření nebyla zobrazena. Klikem zde zobrazíte vše.'),
(118677, 6017, 32, 'Během identifikace se objevily chyby.'),
(118678, 6018, 32, 'Některé poznámky nebyly zobrazeny'),
(118679, 6021, 32, 'Někdo jiný změnil tuto návštěvu. Zruště stránku a zkuste to znovu.'),
(118680, 6023, 32, 'Něco se pokazilo :-) Zkuste to znovu'),
(118681, 6026, 32, 'Bolesti v krku'),
(118682, 6028, 32, 'Omouváme se , ale došlo k problému při nahrávání souboru.'),
(118683, 6029, 32, 'Seřadit podle'),
(118684, 6030, 32, 'Seřadit podle'),
(118685, 6031, 32, 'Seřadit podle kontrolního součtu'),
(118686, 6032, 32, 'Seřadit podle komentářů'),
(118687, 6034, 32, 'Seřadit podle data'),
(118688, 6035, 32, 'Seřadit podle data/času'),
(118689, 6036, 32, 'Seřadit podle události'),
(118690, 6037, 32, 'Seřadit podle skupiny'),
(118691, 6038, 32, 'Seřadit podle nového kontrolního součtu'),
(118692, 6039, 32, 'Seřadit podle strarého kontrolního součtu'),
(118693, 6040, 32, 'Seřadit podle ID Pacienta'),
(118694, 6043, 32, 'Seřadit podle uživatele'),
(118695, 6044, 32, 'Seřadit podle vakcíny'),
(118696, 6045, 32, 'Seřadit sestupně'),
(118697, 6046, 32, 'Seřadit výsledky podle'),
(118698, 6047, 32, 'Seřadit vzestupně'),
(118699, 6048, 32, 'Zdroj'),
(118700, 6049, 32, 'Zdrojový soubor'),
(118701, 6050, 32, 'Cesta ke zdrojovému souboru'),
(118702, 6051, 32, 'Pro kód chybí zdroj '),
(118703, 6052, 32, 'Zdrojové množství'),
(118704, 6054, 32, 'Zdrojový pacient'),
(118705, 6055, 32, 'Zdrojový pacient nemá datum narození'),
(118706, 6056, 32, 'Zdrojový pacient nenalezen'),
(118707, 6057, 32, 'Zdroj:'),
(118708, 6060, 32, 'Prostor'),
(118709, 6061, 32, 'PROSTOR'),
(118710, 6066, 32, 'Nejsou povoleny speciální znaky'),
(118711, 6068, 32, 'Specialista'),
(118712, 6069, 32, 'Jméno a podpis specialisty'),
(118713, 6071, 32, 'Specializace'),
(118714, 6073, 32, 'Specializace:'),
(118715, 6074, 32, 'Specifický'),
(118716, 6077, 32, 'Specifické výsledky'),
(118717, 6078, 32, 'Specifická služba'),
(118718, 6079, 32, 'Specifikováno'),
(118719, 6088, 32, 'Vzorek'),
(118720, 6089, 32, 'číslo/identifikátor vzorku'),
(118721, 6090, 32, 'Typ vzorku'),
(118722, 6093, 32, 'Spermicid'),
(118723, 6094, 32, 'Splenektomie'),
(118724, 6095, 32, 'manžel(ka)'),
(118725, 6112, 32, 'Správa SSL certifikátů'),
(118726, 6114, 32, 'Stabilita'),
(118727, 6117, 32, 'Standarní kód'),
(118728, 6118, 32, 'Standardní měření'),
(118729, 6119, 32, 'Standardní měření (aktivní upozornění)'),
(118730, 6120, 32, 'Standardní měření (pasivní upozornění)'),
(118731, 6121, 32, 'Standardní měření (Pacientské upomínky)'),
(118732, 6122, 32, 'Standardní jméno'),
(118733, 6124, 32, 'Začátek'),
(118734, 6125, 32, 'Začátek (rrrr-mm-dd): '),
(118735, 6126, 32, 'Začít jinou zprávu'),
(118736, 6128, 32, 'Datum počátku'),
(118737, 6129, 32, 'Počáteční datum této kliniky'),
(118738, 6130, 32, 'Počáteční datum by nemělo být vyšší než koncové'),
(118739, 6131, 32, 'Počáteční datum:'),
(118740, 6132, 32, 'Počáteční datum:'),
(118741, 6133, 32, 'Čas začátku:'),
(118742, 6134, 32, 'Počáteční datum:'),
(118743, 6144, 32, 'Stát/Lokalita'),
(118744, 6150, 32, 'Statický text'),
(118745, 6151, 32, 'Statistika'),
(118746, 6154, 32, 'Stav přijetí'),
(118747, 6155, 32, 'Stav požadavku'),
(118748, 6164, 32, 'Kroky instalace DCM IV databáze'),
(118749, 6165, 32, 'Kroky instalace ICD 10 databáze'),
(118750, 6166, 32, 'Kroky instalace ICD 9 databáze'),
(118751, 6167, 32, 'Kroky instalace RxNorm databáze'),
(118752, 6168, 32, 'Kroky instalace Snomed databáze'),
(118753, 6169, 32, 'kloubní ztuhlost'),
(118754, 6170, 32, 'ztuhlost'),
(118755, 6172, 32, 'Bolesti břicha'),
(118756, 6175, 32, 'Svalové napětí'),
(118757, 6176, 32, 'Proud'),
(118758, 6177, 32, 'Ulice'),
(118759, 6178, 32, 'Adresa ulice'),
(118760, 6179, 32, 'Ulice a číslo'),
(118761, 6180, 32, 'Síla'),
(118762, 6182, 32, 'Streptokoková pharyngitis'),
(118763, 6185, 32, 'CMP'),
(118764, 6186, 32, 'Silné heslo znamená alespoň 8 znaků a alespoň tři znaky jako jsou : číslo, malé písmeno, velké písmeno, speciální znak.'),
(118765, 6187, 32, 'Styl'),
(118766, 6189, 32, 'Podkategorie'),
(118767, 6191, 32, 'Podkategorie'),
(118768, 6192, 32, 'podkategorie'),
(118769, 6193, 32, 'podkožně'),
(118770, 6195, 32, 'Subjektivně'),
(118771, 6196, 32, 'Sublinguálně'),
(118772, 6197, 32, 'sublinguálně'),
(118773, 6237, 32, 'Substituce'),
(118774, 6240, 32, 'Úspěch'),
(118775, 6241, 32, 'úspěch'),
(118776, 6242, 32, 'Příjem laboratorních výsledků byl úspěšně potvrzen'),
(118777, 6243, 32, 'Laboratorní výsledky úspěšně přijaty'),
(118778, 6246, 32, 'Kategorie úspěšně přidána'),
(118779, 6247, 32, 'přidání do kategorie bylo úspěšné'),
(118780, 6248, 32, 'Úspěšně smazáno'),
(118781, 6250, 32, 'Databáze byla úspěšně  instalována.'),
(118782, 6251, 32, 'Následující databáze byla úspěšně instalována.'),
(118783, 6252, 32, 'Úspěšně modifikováno'),
(118784, 6253, 32, 'Úspěšně uloženo. Chcete alokovat ?'),
(118785, 6254, 32, 'Úspěšně uloženo. Chcete distribuovat ?'),
(118786, 6256, 32, 'Úspěšně uloženo.'),
(118787, 6257, 32, 'Upgrade databáze byl úspěšný.'),
(118788, 6258, 32, 'Upgrade následující databáze byl úspěšný.'),
(118789, 6259, 32, 'úspěšně.'),
(118790, 6260, 32, 'Sebevražda'),
(118791, 6261, 32, 'Souhrn'),
(118792, 6262, 32, 'Souhrn'),
(118793, 6265, 32, 'Ne'),
(118794, 6267, 32, 'Neděle'),
(118795, 6289, 32, 'Typ povrchu'),
(118796, 6290, 32, 'Operace'),
(118797, 6291, 32, 'Operace'),
(118798, 6299, 32, 'Pocení:'),
(118799, 6301, 32, 'Otok'),
(118800, 6303, 32, 'Otok kloubů'),
(118801, 6304, 32, 'Lymfadenopatie'),
(118802, 6305, 32, 'Symbol pro oddělení desetinného místa měny. Nepoužije se pokud je desetinné místo 0.'),
(118803, 6306, 32, 'Symbol pro oddělení tisíců měny.'),
(118804, 6307, 32, 'Přiznaky'),
(118805, 6308, 32, 'Synchronizace'),
(118806, 6313, 32, 'Synkopa'),
(118807, 6318, 32, 'Systém'),
(118808, 6325, 32, 'Tabulka'),
(118809, 6327, 32, 'Vytvoření tabulky selhalo'),
(118810, 6328, 32, 'Aktualizace tabulky selhalo'),
(118811, 6329, 32, 'Tabulky'),
(118812, 6364, 32, 'Mezinárodní předvolba'),
(118813, 6369, 32, 'Teplota'),
(118814, 6370, 32, 'Šablona'),
(118815, 6371, 32, 'Jméno šablony'),
(118816, 6372, 32, 'Jména šablon nemohou začínat čísly'),
(118817, 6373, 32, 'Šablona:'),
(118818, 6374, 32, 'Šablony'),
(118819, 6375, 32, 'Arteria temporalis'),
(118820, 6376, 32, 'Poranění šlachy'),
(118821, 6386, 32, 'Textová diagnóza'),
(118822, 6387, 32, 'Textové pole'),
(118823, 6395, 32, 'Textová oblast'),
(118824, 6396, 32, 'textová oblast'),
(118825, 6402, 32, 'Děkujeme'),
(118826, 6403, 32, 'Děkujeme, že jste si vybrali'),
(118827, 6404, 32, 'Tlačítko "Vyčistit" odstraní všechny anotace'),
(118828, 6616, 32, 'To sloučí dva grafy pacienta do jednoho. To je užitečné v případě, že pacient byl kopírován omylem. Pokud se tak stane často, opravte vaše  procedury.'),
(118829, 6617, 32, 'Toto vám nezabrání v přechodu na stránku e-Preskripce'),
(118830, 6619, 32, 'Bude použit přednostně  uživatelský list vakcinací před jeho standardní CVX formou'),
(118831, 6622, 32, 'Hrudní páteř'),
(118832, 6625, 32, 'Dutina ústní'),
(118833, 6626, 32, 'Karcinom dutiny ústní'),
(118834, 6627, 32, 'Operace karcinomu dutiny ústní'),
(118835, 6628, 32, 'Trombóza/CMP'),
(118836, 6629, 32, 'Čt'),
(118837, 6630, 32, 'Čtvrtek'),
(118838, 6631, 32, 'Čtvrtek'),
(118839, 6632, 32, 'Štítná žláza bpn.'),
(118840, 6633, 32, 'Problémy se štítnou žlázou'),
(118841, 6638, 32, 'Čas'),
(118842, 6639, 32, 'Formát zobrazení'),
(118843, 6640, 32, 'Čas pro přidání (1-60 minut)'),
(118844, 6641, 32, 'Výběr času'),
(118845, 6642, 32, 'Otevřená časová pozice, ukládám událost.'),
(118846, 6647, 32, 'Načasované události'),
(118847, 6649, 32, 'Časová značka a text'),
(118848, 6655, 32, 'Tituly'),
(118849, 6661, 32, 'do absolutní cesty k souboru'),
(118850, 6662, 32, 'Klikněte pro přidání poznámek '),
(118851, 6663, 32, 'Klikněte zde pro přidání poznámek'),
(118852, 6664, 32, 'Do dotčené oblasti'),
(118853, 6665, 32, 'do dotčené oblasti'),
(118854, 6668, 32, 'do kategorie'),
(118855, 6671, 32, 'Musí být zadáno pozdější datum než datum od !'),
(118856, 6674, 32, 'Pro vypnutí klientských SSL certifikátů, zakomentujte výše uvedené řádky v konfiguraci Appache a nastavte'),
(118857, 6675, 32, 'Pro vypnutí HTTP, zakomentujte výše uvedené řádky v konfiguraci Appache a restartujte Apache server'),
(118858, 6676, 32, 'Pro povolení klientských SSL certifikátů'),
(118859, 6677, 32, 'Pro zapnutí ověření klientských SSL certifikátů musí být zapnuto HTTPS'),
(118860, 6678, 32, 'Pro povolení pouze  HTTPS, proveďte výše uvedené změny a restartujte server Apache. Chcete-li nastavit také klientské certifikáty, prosím nakonfigurujte je  v další sekci.'),
(118861, 6680, 32, 'Filtorovat podle pohlaví'),
(118862, 6683, 32, 'Pro propojení tohoto vyšetření /konzultace s existujícím problémem klikněte '),
(118863, 6684, 32, 'Pro propojení tohoto vyšetření /konzultace s existujícím problémem klikem označte požadovaný problém a klikněte na [Uložit]. Pro výběr  více problému držte stisknutou klávesu [Ctrl].'),
(118864, 6685, 32, 'přihlásit se znovu'),
(118865, 6688, 32, 'Pro nastavení http přístupu přes klientský certifikát proveďte následující'),
(118866, 6691, 32, 'k této návštěvě ?'),
(118867, 6692, 32, 'K nahrátí dokumentu CCR u již existujícího pacienta použijte volbu v  Souhrnném okno pacienta->Dokumenty. Pro nahrátí dokumentů nového pacienta použijte  volbu Různé->Nový dokument.'),
(118868, 6693, 32, 'Do:'),
(118869, 6694, 32, 'Do: '),
(118870, 6708, 32, 'Tabák'),
(118871, 6711, 32, 'Užívání tabákových výrobků'),
(118872, 6712, 32, 'Užívání tabákových výrobků'),
(118873, 6715, 32, 'Dnes'),
(118874, 6716, 32, 'DNES'),
(118875, 6717, 32, 'dnes'),
(118876, 6718, 32, 'Dnešní bilance'),
(118877, 6719, 32, 'Dnešní platby'),
(118878, 6720, 32, 'Dnešní datum'),
(118879, 6721, 32, 'Dnešní události'),
(118880, 6722, 32, 'Přepnout vše'),
(118881, 6726, 32, 'Tonsilektomie'),
(118882, 6727, 32, 'tonsilektomie'),
(118883, 6728, 32, 'Nahoře'),
(118884, 6729, 32, 'Horní okraj (mm)'),
(118885, 6730, 32, 'Téma'),
(118886, 6731, 32, 'Celkový'),
(118887, 6732, 32, 'celkový'),
(118888, 6738, 32, 'Celkově zaplacené množství'),
(118889, 6740, 32, 'Celková platba'),
(118890, 6741, 32, 'Celkem platby'),
(118891, 6742, 32, 'Celkem klientů'),
(118892, 6743, 32, 'Celkové náklady'),
(118893, 6746, 32, 'Celkem neúspěšně odeslaných  mailových upomínek'),
(118894, 6748, 32, 'Celkem za'),
(118895, 6749, 32, 'Celkem za '),
(118896, 6750, 32, 'Celkem za kategorii'),
(118897, 6752, 32, 'Celkem nových upomínek'),
(118898, 6753, 32, 'Celkový počet návštěv'),
(118899, 6755, 32, 'Celkový počet imunizací'),
(118900, 6756, 32, 'Celkový počet problémů'),
(118901, 6758, 32, 'Celkový počet pacientů'),
(118902, 6761, 32, 'Celkem pacientů'),
(118903, 6764, 32, 'Celkem nalezených záznamů'),
(118904, 6766, 32, 'Celkem úspěšně odeslaných e-mailových upomínek'),
(118905, 6776, 32, 'Součty'),
(118906, 6777, 32, 'Součty pro'),
(118907, 6784, 32, 'Sledování'),
(118908, 6785, 32, 'Typ tréninku'),
(118909, 6786, 32, 'Provést transakci'),
(118910, 6787, 32, 'Transakce'),
(118911, 6788, 32, 'transakce'),
(118912, 6790, 32, 'Transakce selhala, množství je menší než 0'),
(118913, 6791, 32, 'Typ transakce'),
(118914, 6792, 32, 'transactions'),
(118915, 6793, 32, 'Transakce'),
(118916, 6794, 32, 'Transakce (volitelně zapisovat)'),
(118917, 6795, 32, 'Transakce/Doporučení'),
(118918, 6797, 32, 'Převod'),
(118919, 6798, 32, 'Datum převodu'),
(118920, 6800, 32, 'Souhrn při předání'),
(118921, 6801, 32, 'Převod do/k'),
(118922, 6804, 32, 'Převody'),
(118923, 6806, 32, 'Přesun/Převod péče ?'),
(118924, 6807, 32, 'Přeložit skupiny pro kontrolu přístupu'),
(118925, 6808, 32, 'Přeložit kategorie návštěv'),
(118926, 6809, 32, 'Přeložit kategorie dokumentů'),
(118927, 6810, 32, 'Přeložit rozhraní'),
(118928, 6811, 32, 'Přeložit seznamy'),
(118929, 6812, 32, 'Přeložit název poznámky k pacientovi'),
(118930, 6813, 32, 'přeložit'),
(118931, 6814, 32, 'Překlad'),
(118932, 6815, 32, 'Překlady'),
(118933, 6816, 32, 'Odeslat'),
(118934, 6817, 32, 'Odeslání selhalo'),
(118935, 6818, 32, 'Odeslat vybrané objednávky'),
(118936, 6819, 32, 'Trauma'),
(118937, 6820, 32, 'Léčba'),
(118938, 6822, 32, 'Léčebné cíle'),
(118939, 6823, 32, 'Léčebný plán'),
(118940, 6824, 32, 'Plánovaná léčba'),
(118941, 6825, 32, 'Léčba podána'),
(118942, 6826, 32, 'Léčba:'),
(118943, 6827, 32, 'Léčba: '),
(118944, 6828, 32, 'Tendence'),
(118945, 6830, 32, 'Trigger point / kompartment syndrom / DOMS / křeče'),
(118946, 6831, 32, 'Trimaleolární'),
(118947, 6832, 32, 'Trup a břicho'),
(118948, 6833, 32, 'Důvěryhodné adresy direct Emailu'),
(118949, 6834, 32, 'Důvěryhodné e-maily'),
(118950, 6835, 32, 'Pokus o vytvoření uživatele s již existujícím uživatelským jménem.'),
(118951, 6840, 32, 'Tuberkulóza'),
(118952, 6841, 32, 'Út'),
(118953, 6842, 32, 'Út &amp; Čt'),
(118954, 6843, 32, 'Úterý'),
(118955, 6844, 32, 'Nádor'),
(118956, 6848, 32, 'dvakrát denně'),
(118957, 6850, 32, 'Bubínek'),
(118958, 6851, 32, 'Typ'),
(118959, 6852, 32, 'Zadejte ID nebo Jméno. Minimálně 3 znaky včetně mezer.'),
(118960, 6853, 32, 'Typy sloupců zobrazených ve výsledcích hledání pacienta'),
(118961, 6854, 32, 'Způsob odhalení'),
(118962, 6855, 32, 'Typ událostí'),
(118963, 6856, 32, 'Typ rozvržení obrazovky'),
(118964, 6857, 32, 'Zde napiště nebo naskenujte identifikátor pacienta'),
(118965, 6858, 32, 'Zde napiště svou zprávu'),
(118966, 6859, 32, 'Typy objednávek a výsledků'),
(118967, 6866, 32, 'Ulcerace'),
(118968, 6867, 32, 'Collitis ulcerosa'),
(118969, 6868, 32, 'Vředy:'),
(118970, 6869, 32, 'Chyba přístupu k adresáři'),
(118971, 6870, 32, 'Chyba přístupu k URL');
INSERT INTO `lang_definitions` VALUES
(118972, 6871, 32, 'Nelze vytvořit'),
(118973, 6872, 32, 'Nelze vytvořit podadresář s dokumenty pacienta'),
(118974, 6873, 32, 'Nelze najít data v tomto souboru'),
(118975, 6875, 32, 'Nelze upravit konfiguraci aplikace. Prosím přidejte právo zápisu k'),
(118976, 6876, 32, 'Nepoužito'),
(118977, 6877, 32, 'Nepřiřazeno'),
(118978, 6878, 32, 'Chybí oprávnění'),
(118979, 6879, 32, 'Neoprávněný přístup do ePreskripce'),
(118980, 6880, 32, 'Neoprávněný přístup.'),
(118981, 6881, 32, 'Nazaúčtováno'),
(118982, 6882, 32, 'Pouze nezaúčtováno'),
(118983, 6884, 32, 'pod jazykem'),
(118984, 6885, 32, 'Podváha'),
(118985, 6886, 32, 'Nediagnostikovaný'),
(118986, 6887, 32, 'Nedistribuovaný'),
(118987, 6892, 32, 'Unikátní klienti'),
(118988, 6894, 32, 'Unikátní nový klient'),
(118989, 6895, 32, 'Unikátní číslelný identifikátor pro tento typ'),
(118990, 6896, 32, 'Unikátní vyšetření pacienti'),
(118991, 6899, 32, 'Jednotka'),
(118992, 6900, 32, 'Jednotky'),
(118993, 6901, 32, 'jednotky'),
(118994, 6902, 32, 'Jednotky použité pro výsledky'),
(118995, 6903, 32, 'Jednotky pro formuláře návštěv'),
(118996, 6904, 32, 'Jednotky musí být čísla'),
(118997, 6905, 32, 'Jednotky nejsou definované'),
(118998, 6906, 32, 'Jednotky/L'),
(118999, 6907, 32, 'Neznámý'),
(119000, 6908, 32, 'neznámý (viz log)'),
(119001, 6910, 32, 'Neznámo, zda kdy kouřil/a'),
(119002, 6911, 32, 'Neznámý nebo N/A'),
(119003, 6912, 32, 'Neznámé ID uživatele'),
(119004, 6913, 32, 'odpojit pacienta'),
(119005, 6915, 32, 'Neregistrováno'),
(119006, 6916, 32, 'Neregistrované moduly'),
(119007, 6918, 32, 'Zrušit výběr všeho'),
(119008, 6919, 32, 'Nevybráno'),
(119009, 6920, 32, 'Nespecifikováno'),
(119010, 6921, 32, 'nestrukturalizováno'),
(119011, 6922, 32, 'NEPODPOROVANÝ databázový soubor k nahrátí'),
(119012, 6924, 32, 'dokud'),
(119013, 6926, 32, 'Nepoužívá se'),
(119014, 6928, 32, 'do'),
(119015, 6929, 32, 'Nadcházející návštěvy'),
(119016, 6930, 32, 'Nadcházející  události'),
(119017, 6931, 32, 'Aktualizace'),
(119018, 6932, 32, 'Aktualizace'),
(119019, 6933, 32, 'Aktivní aktualizace'),
(119020, 6934, 32, 'Aktualizace souborů'),
(119021, 6936, 32, 'Aktualizace seznamu'),
(119022, 6937, 32, 'Aktualizace čísla poskytovatele'),
(119023, 6938, 32, 'Aktualizace vybraných položek'),
(119024, 6939, 32, 'Aktualizace následujících proměnných v souboru.'),
(119025, 6940, 32, 'Aktualizace uživatelských informací.'),
(119026, 6942, 32, 'Aktualizace demografických údajů není povolena.'),
(119027, 6943, 32, 'Aktualizace výchozích globálních nastavení'),
(119028, 6944, 32, 'Aktualizace indikátorů verze'),
(119029, 6946, 32, 'Upgrade'),
(119030, 6947, 32, 'Aktualizace databáze'),
(119031, 6948, 32, 'Aktualizace LibreEHR zahrnující procedury, funkce a tabulky potřebné pro deidentifikaci.'),
(119032, 6949, 32, 'Upgrade bude pokračovat'),
(119033, 6951, 32, 'Nahrát'),
(119034, 6952, 32, 'Nahrát šablonu'),
(119035, 6953, 32, 'Nahrát a instalovat'),
(119036, 6954, 32, 'Nahrát data konfigurace'),
(119037, 6955, 32, 'Nahrát dokument'),
(119038, 6956, 32, 'Nahrání selhalo!'),
(119039, 6957, 32, 'Nahrát obrázek do'),
(119040, 6958, 32, 'Nahrát soubor importu:'),
(119041, 6959, 32, 'Nahrát edukační materiál ve formátu .PDF do'),
(119042, 6960, 32, 'Nahrání proběhlo úspěšně'),
(119043, 6961, 32, 'Nahrát zprávu'),
(119044, 6962, 32, 'nahrát soubor .xml  do kategorie CCR'),
(119045, 6963, 32, 'Nahrát tento soubor:'),
(119046, 6968, 32, 'Naléhavost'),
(119047, 6970, 32, 'Moč'),
(119048, 6971, 32, 'Dribbling moči'),
(119049, 6972, 32, 'Frekvence močení'),
(119050, 6973, 32, 'Opožděná mikce'),
(119051, 6974, 32, 'Microalbuminurie'),
(119052, 6975, 32, 'Proud moči'),
(119053, 6976, 32, 'Močová urgence'),
(119054, 6977, 32, 'URL'),
(119055, 6979, 32, 'URL podpory LibreEHR.'),
(119056, 6981, 32, 'URL pro telefonní bránu. Automatická VOIP služba poskytovaná Maviq. Please visit http://signup.maviq.com for more information.'),
(119057, 6982, 32, 'URL stránky WordPressu podporující portál'),
(119058, 6985, 32, 'Použití'),
(119059, 6986, 32, 'Použít indikátor (ISA15)'),
(119060, 6987, 32, 'Pro setřídění obsahu sloupce použijte znak %'),
(119061, 6988, 32, 'Použít 24 hodinový formát ?'),
(119062, 6991, 32, 'Použít panel poplatků'),
(119063, 6997, 32, 'Použít vlastní imunizační seznam'),
(119064, 6999, 32, 'Použít datumové rozmezí'),
(119065, 7000, 32, 'Použít výchozí'),
(119066, 7001, 32, 'Použít volbu SMAZAT pro odstranění'),
(119067, 7002, 32, 'Použít styl mezinárodního data?'),
(119068, 7003, 32, 'Použít jméno zdrojového souboru'),
(119069, 7004, 32, 'Pro nákup nebo převod použijte  pole níže'),
(119070, 7005, 32, 'Tuto vlastnost použít pouze v případě instalace nových stránek '),
(119071, 7007, 32, 'Uživatelé'),
(119072, 7009, 32, 'Uživatelé/Skupiny'),
(119073, 7010, 32, 'Správa uživatelů'),
(119074, 7011, 32, 'Správa uživatelů a zařízení'),
(119075, 7012, 32, 'Správa skupin a uživatelů'),
(119076, 7013, 32, 'Uživatel nemůže být smazán'),
(119077, 7014, 32, 'Ověření certifikátu uživatele není povoleno'),
(119078, 7015, 32, 'Uživatelsky definováno'),
(119079, 7016, 32, 'Uživatelsky definovaná oblast 11'),
(119080, 7017, 32, 'Uživatelsky definovaná oblast 12'),
(119081, 7018, 32, 'Uživatelsky definované pole'),
(119082, 7019, 32, 'Uživatelsky definovaný seznam 1'),
(119083, 7020, 32, 'Uživatelsky definovaný seznam 2'),
(119084, 7021, 32, 'Uživatelsky definovaný seznam 3'),
(119085, 7022, 32, 'Uživatelsky definovaný seznam 4'),
(119086, 7023, 32, 'Uživatelsky definovaný seznam 5'),
(119087, 7024, 32, 'Uživatelsky definovaný seznam 6'),
(119088, 7025, 32, 'Uživatelsky definovaný seznam 7'),
(119089, 7026, 32, 'Uživatelsky definovaný text 1'),
(119090, 7027, 32, 'Uživatelsky definovaný text 2'),
(119091, 7028, 32, 'Uživatelsky definovaný text 3'),
(119092, 7029, 32, 'Uživatelsky definovaný text 4'),
(119093, 7030, 32, 'Uživatelsky definovaný text 5'),
(119094, 7031, 32, 'Uživatelsky definovaný text 6'),
(119095, 7032, 32, 'Uživatelsky definovaný text 7'),
(119096, 7033, 32, 'Uživatelsky definovaný text 8'),
(119097, 7034, 32, 'Jméno uživatele'),
(119098, 7039, 32, 'Uživatelský manuál'),
(119099, 7040, 32, 'Členství uživatele'),
(119100, 7041, 32, 'Uživatelské jméno'),
(119101, 7042, 32, 'Jméno uživatele nebo hosta nesmí být prázdné'),
(119102, 7043, 32, 'Jméno uživatele nebo hosta'),
(119103, 7046, 32, 'Uživatelské nastavení'),
(119104, 7047, 32, 'Specifické uživatelsé nastavení'),
(119105, 7048, 32, 'Nové heslo uživatele'),
(119106, 7049, 32, 'Uživatelské jméno'),
(119107, 7052, 32, 'Uživatelské jméno pro SMS bránu'),
(119108, 7053, 32, 'Uživatelské jméno pro SMS bránu.'),
(119109, 7054, 32, 'Uživatelské jméno:'),
(119110, 7055, 32, 'Uživatelské jméno:'),
(119111, 7056, 32, 'Uživatelé'),
(119112, 7057, 32, 'Správa Uživatelů/Skupin/Logů'),
(119113, 7058, 32, 'použití php <a href="http://php.net/strftime">strftime</a> formát'),
(119114, 7062, 32, 'DOVLENÁ'),
(119115, 7063, 32, 'Dovolená'),
(119116, 7064, 32, 'Vakcína'),
(119117, 7067, 32, 'ověřit platnost'),
(119118, 7068, 32, 'Hodnota'),
(119119, 7069, 32, 'Hodnota 1'),
(119120, 7070, 32, 'Hodnota 2'),
(119121, 7072, 32, 'Hodnota musí být numerická'),
(119122, 7073, 32, 'Var1'),
(119123, 7074, 32, 'Var2'),
(119124, 7076, 32, 'Varicella 1'),
(119125, 7077, 32, 'Varicella 2'),
(119126, 7078, 32, 'Varixy'),
(119127, 7079, 32, 'Stav cévního systému'),
(119128, 7080, 32, 'Cévní poranění'),
(119129, 7081, 32, 'Cévní chirurgie'),
(119130, 7083, 32, 'Prodejce'),
(119131, 7084, 32, 'Verze'),
(119132, 7090, 32, 'zobrazit'),
(119133, 7091, 32, 'Zobrazit'),
(119134, 7092, 32, 'Zobrazit alergie'),
(119135, 7093, 32, 'Zobrazit x12-835 ERA soubor'),
(119136, 7094, 32, 'Zobrazit x12 text hromadného požadavku'),
(119137, 7097, 32, 'Zobrazit kompletní zprávu pacienta'),
(119138, 7098, 32, 'Zobrazit CSV tabulky'),
(119139, 7100, 32, 'Zobrazit dokument'),
(119140, 7101, 32, 'Zobrazit návštěvu'),
(119141, 7102, 32, 'Zobrazit ERA x12 text'),
(119142, 7103, 32, 'Zobrazit události ve vyskakovacím okně'),
(119143, 7104, 32, 'Zobrazit specifické uživatelské informace o zařízení'),
(119144, 7106, 32, 'Zobrazit lokální x12 soubor'),
(119145, 7107, 32, 'Zobrazit log'),
(119146, 7108, 32, 'Zobrazit stranu 1'),
(119147, 7109, 32, 'Zobrazit stranu 2'),
(119148, 7110, 32, 'Zobrazit předešlé a budoucí upomínky'),
(119149, 7111, 32, 'Zobrazit pacienta'),
(119150, 7116, 32, 'Zobrazit související návštěvy'),
(119151, 7117, 32, 'Zobrazit report'),
(119152, 7118, 32, 'Zobrazit soubor README'),
(119153, 7121, 32, 'Zobrazit/upravit alergie'),
(119154, 7122, 32, 'Zobrazit/upravit problém'),
(119155, 7123, 32, 'Zobrazit/Tisk'),
(119156, 7124, 32, 'Zobrazení:'),
(119157, 7127, 32, 'Orgánové poškození/trauma/operace'),
(119158, 7132, 32, 'Kategorie návštěvy:'),
(119159, 7133, 32, 'Kategorie návštěvy:'),
(119160, 7134, 32, 'Datum návštěvy'),
(119161, 7135, 32, 'Datum návštěvy'),
(119162, 7137, 32, 'Formuláře návštěv'),
(119163, 7138, 32, 'Historie návštěv'),
(119164, 7140, 32, 'Návštěvy'),
(119165, 7141, 32, 'Návštěvy od'),
(119166, 7143, 32, 'Vitální funkce'),
(119167, 7144, 32, 'Vitální funkce (metric)'),
(119168, 7145, 32, 'Volby formuláře vitálních funkcí'),
(119169, 7146, 32, 'Hlas'),
(119170, 7147, 32, 'Hlasová zpráva odeslána'),
(119171, 7149, 32, 'Zvracení'),
(119172, 7152, 32, 'Obv. pasu'),
(119173, 7153, 32, 'Obvod pasu'),
(119174, 7154, 32, 'Čekání'),
(119175, 7158, 32, 'Skladiště'),
(119176, 7159, 32, 'Skladiště maximum, 0 pokud není použito'),
(119177, 7160, 32, 'Skladiště minimum, 0 pokud není použito'),
(119178, 7161, 32, 'Skladiště'),
(119179, 7162, 32, 'Teplo(ý)'),
(119180, 7163, 32, 'Varování'),
(119181, 7164, 32, 'VAROVÁNÍ'),
(119182, 7166, 32, 'Varování: Zkontrolujte zda číslo již existuje v databázi.'),
(119183, 7167, 32, 'Varování: Seznam problémů pacienta obsahuje nejednoznačné kódy!'),
(119184, 7168, 32, 'Varování: Tento pacient má již dnes jednu návštěvu založenou !'),
(119185, 7170, 32, 'Varování: ID Pacienta není unikátní'),
(119186, 7171, 32, 'VAROVÁNÍ: Dojde k přepisu konfigurace daty z nahrávaného souboru !!!'),
(119187, 7173, 32, 'Varování'),
(119188, 7175, 32, 'bylo již nahráno'),
(119189, 7176, 32, 'nenalezeno'),
(119190, 7177, 32, 'Ceníme si rychlé platby'),
(119191, 7178, 32, 'měli jsme v ambulantní psychiatrické  péči výše uvedeného pacienta. Děkujeme za doporučení.'),
(119192, 7179, 32, 'Slabost'),
(119193, 7181, 32, 'Webové vyhledávání'),
(119194, 7183, 32, 'webový odkaz pro onsite Pacientský portál'),
(119195, 7184, 32, 'Stře'),
(119196, 7185, 32, 'Středa'),
(119197, 7186, 32, 'Týden'),
(119198, 7187, 32, 'týden'),
(119199, 7188, 32, 'Týdenní zobrazení'),
(119200, 7189, 32, 'Týden(y)'),
(119201, 7190, 32, 'Týdenní expozice'),
(119202, 7191, 32, 'týdny'),
(119203, 7192, 32, 'Týdny'),
(119204, 7193, 32, 'Hmotnost'),
(119205, 7196, 32, 'Změna hmotnosti'),
(119206, 7197, 32, 'Úbytek hmotnosti'),
(119207, 7199, 32, 'Vítejte'),
(119208, 7202, 32, 'Co je zahrnuto?'),
(119209, 7203, 32, 'Pískoty, vrzoty:'),
(119210, 7204, 32, 'Stridor'),
(119211, 7205, 32, 'Stridor:'),
(119212, 7207, 32, 'Po dokončení klikněte na Odeslat ( níže) pro provedení změn.'),
(119213, 7208, 32, 'Kde lze nalézt související skenované nebo papírové dokumenty ?'),
(119214, 7212, 32, 'Bilý'),
(119215, 7213, 32, 'Kdo'),
(119216, 7214, 32, 'Kdo odpověděl?'),
(119217, 7215, 32, 'Ovdovělý(á)'),
(119218, 7216, 32, 'Šířka'),
(119219, 7217, 32, 'šířka levého navigačního rámce v pixelech'),
(119220, 7220, 32, 's preferovaným jazykem'),
(119221, 7221, 32, 'S vybraným:'),
(119222, 7222, 32, 'se starým jménem'),
(119223, 7224, 32, 'Komu lze zanechat zprávu ?'),
(119224, 7225, 32, 'Odepřeno'),
(119225, 7226, 32, 'během hodin'),
(119226, 7227, 32, 'během hodin:'),
(119227, 7228, 32, 'během minut'),
(119228, 7229, 32, 'během minut:'),
(119229, 7230, 32, 'Bez zařízení'),
(119230, 7231, 32, 'Bez poskytovatele'),
(119231, 7232, 32, 'Bez aktualizace'),
(119232, 7233, 32, 'Svědek'),
(119233, 7237, 32, 'Žena'),
(119234, 7238, 32, 'Pouze ženy'),
(119235, 7240, 32, 'Práce'),
(119236, 7241, 32, 'PRACOVNÍ POZNÁMKA'),
(119237, 7242, 32, 'Telefon do práce'),
(119238, 7243, 32, 'Telefonní číslo  do práce ?'),
(119239, 7244, 32, 'Související s prací ?'),
(119240, 7245, 32, 'Zaměstnání/Vzdělání/Koníčky'),
(119241, 7246, 32, 'Zaměstnání/Škola poznámka'),
(119242, 7247, 32, 'Pracovní den'),
(119243, 7251, 32, 'Makám...zkrátka mi to bude chvilku trvat'),
(119244, 7252, 32, 'Horší'),
(119245, 7254, 32, 'Chcete je označit jako  vyčištěné ?'),
(119246, 7256, 32, 'Přejete si zrušit distribuci této platby ?'),
(119247, 7257, 32, 'Přejete si odstranit platební distribuci ?'),
(119248, 7258, 32, 'Přejete si odstranit platby ?'),
(119249, 7259, 32, 'Přejete si upravit a ukončit platby ?'),
(119250, 7260, 32, 'Přejete si upravit platby ?'),
(119251, 7261, 32, 'Přejete si odeslat a ukončit platby ?'),
(119252, 7262, 32, 'Přejete si odeslat platby ?'),
(119253, 7263, 32, 'Přejete si uložit ?'),
(119254, 7264, 32, 'Zápěstí'),
(119255, 7265, 32, 'Zápěstí a ruka'),
(119256, 7266, 32, 'Problémy se zápěstím'),
(119257, 7267, 32, 'zapsat'),
(119258, 7269, 32, 'Zapsat jedenkrát'),
(119259, 7273, 32, 'x zrušeno'),
(119260, 7274, 32, 'x zrušeno'),
(119261, 7275, 32, 'RTG'),
(119262, 7276, 32, 'Zhodnocení RTG:'),
(119263, 7277, 32, 'Zhodnocení RTG:'),
(119264, 7278, 32, 'X12 pouze : Změna požadavku '),
(119265, 7279, 32, 'X12 Partner'),
(119266, 7280, 32, 'X12 Partneři'),
(119267, 7281, 32, 'x12 text'),
(119268, 7285, 32, 'Rok'),
(119269, 7286, 32, 'rok'),
(119270, 7287, 32, 'Roční zobrazení'),
(119271, 7288, 32, 'Rok(y)'),
(119272, 7289, 32, 'Roky'),
(119273, 7290, 32, 'Roky a měsíce'),
(119274, 7291, 32, 'Roky, měsíce a dny'),
(119275, 7292, 32, 'ANO'),
(119276, 7293, 32, 'Ano'),
(119277, 7294, 32, 'ano'),
(119278, 7295, 32, 'ANO !'),
(119279, 7296, 32, 'Ano, Smazat a logovat'),
(119280, 7298, 32, 'Ano/Ne'),
(119281, 7299, 32, 'Ano:'),
(119282, 7303, 32, 'Chcete přepsat stávající šablonu. Jste se jistí ?'),
(119283, 7304, 32, 'Jste v ochranné přihlašovací lhůtě. Nejpre změňte své heslo.'),
(119284, 7305, 32, 'Nemáte oprávnění mazat tuto událost'),
(119285, 7306, 32, 'Nemáte povolení k úpravám této události'),
(119286, 7307, 32, 'Nemáte oprávnění k této činnosti'),
(119287, 7308, 32, 'Nejste oprávněni k přístupu  k této skupině.'),
(119288, 7309, 32, 'Nejste oprávněni k přidávání/editaci problémů.'),
(119289, 7310, 32, 'Nejste oprávnění k objednávání vyšetření.'),
(119290, 7311, 32, 'Nejste oprávněni prohlížet toto vyšetření.'),
(119291, 7312, 32, 'Odesíláte znovu staré vyšetření ?'),
(119292, 7313, 32, 'K této funkci nelze přistupovat přímo.'),
(119293, 7314, 32, 'K této stránce nelze přistupovat přímo.'),
(119294, 7315, 32, 'Pro tuto kategorii nelze zadat prázdnou hodnotu !'),
(119295, 7316, 32, 'Pro tuto subkategorii nelze zadat prázdnou hodnotu !'),
(119296, 7317, 32, 'Pro tuto položku nelze zadat prázdnou hodnotu !'),
(119297, 7319, 32, 'Není vybrána žádná akce'),
(119298, 7320, 32, 'Nejste oprávněni prohlížet/editovat tuto poznámku'),
(119299, 7321, 32, 'Pokoušíte se upravit zamčený obsah. Odemkněte dokument odstraněním řádku ''/*lock::*/'''),
(119300, 7322, 32, 'Odhlášení bylo úspěšné'),
(119301, 7323, 32, 'Lze nahrávat pouze .txt soubory'),
(119302, 7324, 32, 'Volitelně můžete nahrát HL7 výsledek ze souboru'),
(119303, 7325, 32, 'Zde můžete vložit text jako popis hlavního problému pacienta'),
(119304, 7326, 32, 'Pro kódování dokumentu musíte zadat heslo'),
(119305, 7327, 32, 'Pro změnu uživatelských hesel musíte zadat své vlastní heslo. Prázdné heslo neprovede žádnou změnu'),
(119306, 7329, 32, 'Nejprve musíte zvolit nebo přidat pacienta'),
(119307, 7330, 32, 'Nejprve musíte zvolit nebo vytvořit vyšetření'),
(119308, 7331, 32, 'Musíte zvolit kategorii návštěvy'),
(119309, 7332, 32, 'Musíte zvolit kategorii návštěvy'),
(119310, 7333, 32, 'Pro pokračování musíte zvolit některé pole'),
(119311, 7335, 32, 'Musíte zvolit nejméně jeden kontext'),
(119312, 7336, 32, 'Musíte vybrat nejméně jednoho poskytovatele'),
(119313, 7338, 32, 'Vaše klinická zpráva'),
(119314, 7339, 32, 'Vaše konečné datum je chybné'),
(119315, 7340, 32, 'Vaše událost byla smazána'),
(119316, 7341, 32, 'Vaše událost byla upravena.'),
(119317, 7342, 32, 'Vaše událost byla odeslána'),
(119318, 7343, 32, 'Váš soubor je příliž velký'),
(119319, 7344, 32, 'Vaše laboratorní výsledky'),
(119320, 7345, 32, 'Vaše jméno musí být změněno, aby splňovalo požadavky'),
(119321, 7346, 32, 'Vaše zpráva byla předána k odeslání pro'),
(119322, 7347, 32, 'Vaše jméno pro tuto kategorii, proceduru nebo výsledek.'),
(119323, 7348, 32, 'Vaše heslo'),
(119324, 7349, 32, 'Vaše heslo expirovalo. Změňte jej.'),
(119325, 7350, 32, 'Vaše heslo expiruje'),
(119326, 7351, 32, 'Vaše heslo dnes expiruje. Změňte jej.'),
(119327, 7352, 32, 'Vaše heslo je váš podpis'),
(119328, 7353, 32, 'Vaše konfigurace PostCalendar byla resetována na výchozí nastavení'),
(119329, 7354, 32, 'Vaše konfigurace PostCalendar byla aktualizována'),
(119330, 7355, 32, 'Vaše opakovací frekvence musí být celé číslo'),
(119331, 7356, 32, 'Vaše frekvence opakování musí být nejméně 1'),
(119332, 7357, 32, 'Vaše počáteční datum je vyšší naž končené'),
(119333, 7358, 32, 'Vaše počáteční datum je neplatné'),
(119334, 7359, 32, 'Vaše podání selhalo.'),
(119335, 7360, 32, 'rrrr-mm-dd'),
(119336, 7361, 32, 'RRRR-MM-DD'),
(119337, 7362, 32, 'rrrr-mm-dd datum spojené s tímto dokumentem'),
(119338, 7363, 32, 'rrrr-mm-dd datum zničeno'),
(119339, 7364, 32, 'rrrr-mm-dd datum narození'),
(119340, 7365, 32, 'rrrr-mm-dd Datum narození'),
(119341, 7366, 32, 'rrrr-mm-dd datum expirace'),
(119342, 7367, 32, 'rrrr-mm-dd Datum začátku hospitalizace'),
(119343, 7368, 32, 'rrrr-mm-dd datum počátku, operace nebo začátku medikace'),
(119344, 7369, 32, 'rrrr-mm-dd datum nákupu nebo převodu'),
(119345, 7370, 32, 'rrrr-mm-dd datum úzdravy nebo ukončení medikace'),
(119346, 7372, 32, 'rrrr-mm-dd Datum služby'),
(119347, 7373, 32, 'rrrr-mm-dd  datum tohoto dopisu'),
(119348, 7375, 32, 'rrrr-mm-dd datum dokumentu'),
(119349, 7376, 32, 'rrrr-mm-dd  datum události nebo datum počátku'),
(119350, 7377, 32, 'rrrr-mm-dd H:m Datum ukončení'),
(119351, 7378, 32, 'rrrr-mm-dd H:m Datum ukončení'),
(119352, 7379, 32, 'rrrr-mm-dd H:m Datum počátku'),
(119353, 7380, 32, 'rrrr-mm-dd H:m Datum počátku'),
(119354, 7381, 32, 'rrrr-mm-dd hh:mm:ss'),
(119355, 7382, 32, 'rrrr-mm-dd Hodiny(24):minuty'),
(119356, 7383, 32, 'rrrr-mm-dd poslední datum této události'),
(119357, 7387, 32, 'Nula'),
(119358, 7389, 32, 'Zip'),
(119359, 7390, 32, 'Zip kód'),
(119360, 7391, 32, 'Zip/Země'),
(119361, 7394, 32, ' nelze otevřít pro chybu přístupu.'),
(119362, 7395, 32, 'Opravdu chcete smazat'),
(119363, 7396, 32, 'Léčivo'),
(119364, 7397, 32, 'emaily odeslány'),
(119365, 7398, 32, 'z'),
(119366, 7399, 32, 'vytvořeno '),
(119367, 7400, 32, 'znovuotevřeno'),
(119368, 7401, 32, 'Historie'),
(119369, 7402, 32, 'není číslo'),
(119370, 7403, 32, 'připraveno pro znovuzaúčtování'),
(119371, 7408, 32, 'nenalezeno !'),
(119372, 7411, 32, 'dokud'),
(119373, 7412, 32, 'aktualizace selhala. Chybějící položka databáze ?'),
(119374, 7413, 32, 'úspěšně označeno jako pouze zaúčtované'),
(119375, 7414, 32, 'úspěšně zařazeno'),
(119376, 7416, 32, '" pro kód'),
(119377, 7417, 32, '" je zatrženo v nastavení PostCalendar!'),
(119378, 7419, 32, '# tablet:'),
(119379, 7421, 32, '$ Kódování dokončeno'),
(119380, 7422, 32, '$popis(rrrr-mm-dd): '),
(119381, 7424, 32, '% Zrušeno <  24h'),
(119382, 7425, 32, '% Zrušeno <  24h '),
(119383, 7426, 32, ''' měl by existovat, ale není tomu tak.'),
(119384, 7427, 32, '(% odpovídá libovolnému řetězci, _ odpovídá libovolnému znaku)'),
(119385, 7428, 32, '([ctrl] + klik pro výběr více příjemců)'),
(119386, 7429, 32, '(Zpět)'),
(119387, 7430, 32, '(Kliknout pro úpravy)'),
(119388, 7431, 32, '(E-mail je doručen  okamžitě. Mezitím je automatický VOIP odeslán poskytovateli služeb pro další zpracování.)'),
(119389, 7432, 32, '(Více)'),
(119390, 7433, 32, '(Nový pacient)'),
(119391, 7434, 32, '(Poznámky a oprávnění)'),
(119392, 7435, 32, '(Poznámky pacienta)'),
(119393, 7436, 32, '(Vyberte některý název nebo  napišete svůj vlastní)'),
(119394, 7437, 32, 'Klávesa Shift nebo táhnout pro změnu položky'),
(119395, 7438, 32, '* Připomínka vytvořena'),
(119396, 7439, 32, '**Přesuňte prosím operace do problémů'),
(119397, 7440, 32, '*Požadováno'),
(119398, 7442, 32, '- Nic'),
(119399, 7443, 32, '--Vše--'),
(119400, 7444, 32, '-- Vybrat roli--'),
(119401, 7453, 32, 'Zítra'),
(119402, 7454, 32, 'Za měsíc'),
(119403, 7455, 32, 'Za týden'),
(119404, 7456, 32, 'Za 1 rok'),
(119405, 7457, 32, '1. Klid 2. Dva dny ledovat 3. Komprese dokud  nedojde ke změně barvy kůže nebo necitlivosti 4. Zvýšená poloha končetiny'),
(119406, 7459, 32, '12 hodin'),
(119407, 7461, 32, 'první'),
(119408, 7463, 32, 'Za 2 dny'),
(119409, 7464, 32, 'Za 2 měsíce'),
(119410, 7465, 32, 'Za 2 týdny'),
(119411, 7466, 32, 'Za 2 roky'),
(119412, 7467, 32, '2-20 let'),
(119413, 7478, 32, '24 hodin'),
(119414, 7481, 32, 'druhý'),
(119415, 7482, 32, 'Za 3 dny'),
(119416, 7483, 32, '3 měsíce'),
(119417, 7484, 32, 'Za 3 měsíce'),
(119418, 7485, 32, '3x denně'),
(119419, 7486, 32, 'Za 3 týdny'),
(119420, 7489, 32, 'třetí'),
(119421, 7490, 32, 'Za 4 dny'),
(119422, 7491, 32, '4 měsíce'),
(119423, 7492, 32, 'Za 4 měsíce'),
(119424, 7493, 32, '4x denně'),
(119425, 7494, 32, 'Za 4 týdny'),
(119426, 7498, 32, '466.0, Bronchitis acuta'),
(119427, 7499, 32, '486.0, akutní pneumonie'),
(119428, 7500, 32, '491.21, exacerbace CHOPN'),
(119429, 7501, 32, '491.8, Bronchitis chronica'),
(119430, 7502, 32, '493.92, Asthma, akutní exacerbace'),
(119431, 7503, 32, '496.0, CHOPN'),
(119432, 7504, 32, 'čtvrtý'),
(119433, 7505, 32, 'Za 5 dnů'),
(119434, 7506, 32, 'Za 5 měsíců'),
(119435, 7507, 32, 'Za 5 týdnů'),
(119436, 7508, 32, '519.7, Bronchospasmus'),
(119437, 7509, 32, 'pátý'),
(119438, 7510, 32, 'za 6 dnů'),
(119439, 7511, 32, '6 měsíců'),
(119440, 7512, 32, 'za 6 měsíců'),
(119441, 7513, 32, 'Za 6 týdnů'),
(119442, 7514, 32, 'šestý'),
(119443, 7515, 32, 'za 7 měsíců'),
(119444, 7516, 32, 'za 8 měsíců'),
(119445, 7517, 32, '824.0 Fraktura mediálního malleolu , uzavřená'),
(119446, 7518, 32, '824.2 Fraktura zevního kotníku , uzavřená'),
(119447, 7519, 32, '824.6 uzavřená trimaleolární zklomenina'),
(119448, 7520, 32, '825.32 Fraktura Os naviculare ( kotník )'),
(119449, 7521, 32, '825.35 Fraktura baze V metatarsu'),
(119450, 7522, 32, '845.00 distorze NOS'),
(119451, 7523, 32, '845.01 Distorze Medial (Deltoid) Lig.'),
(119452, 7524, 32, '845.02 Distorze, Calcaneal fibular'),
(119453, 7525, 32, 'Za 9 měsíců'),
(119454, 7528, 32, '< na vyšetřovně'),
(119455, 7531, 32, '? Nezobrazovat'),
(119456, 7532, 32, '@ dostavil se'),
(119457, 7533, 32, '[Změnit zobrazení]'),
(119458, 7534, 32, '[Datum posledního vyšetření]'),
(119459, 7535, 32, '[Počet dnů od posledního vyšetření]'),
(119460, 7536, 32, '[EOBs]'),
(119461, 7538, 32, '[nedoporučuje se]'),
(119462, 7539, 32, '[Počet vyšetření]'),
(119463, 7540, 32, '[Reporty]'),
(119464, 7541, 32, '[Vybrat vše]'),
(119465, 7543, 32, '[Zahájit dávkové zpracování]'),
(119466, 7544, 32, '[Zobrazit log]'),
(119467, 7545, 32, '[Zobrazit tištěný report]'),
(119468, 7549, 32, '~ pozdní příchod'),
(119469, 1, 33, 'А'),
(119470, 2, 33, 'Номер чеку та ідентифікаційний номер платежу'),
(119471, 3, 33, 'Сертифікат клієнта для користувача admin'),
(119472, 4, 33, 'Медичний документ приєднано'),
(119473, 5, 33, 'Медичний документ приєднано.'),
(119474, 7, 33, 'Вимагається дистрибютор'),
(119475, 8, 33, 'GCAC форма повина бути додана до цього відвідування.'),
(119476, 9, 33, 'Вимагається номер партії'),
(119477, 10, 33, 'Вимагається номер партії'),
(119478, 11, 33, 'Літера нижнього реєстру'),
(119479, 12, 33, 'Номер'),
(119480, 14, 33, 'Пацієнт з цим ID вже існує'),
(119481, 15, 33, 'Пацієнт з цим іменем вже існує'),
(119482, 16, 33, 'Пацієнт з цим SS (інд. податк. ном.) вже існує'),
(119483, 17, 33, 'Додатнє число покаже кількість попередніх прийомів на віджеті у вікні з загальною інформацією про пацієнта (негативне число покаже послідовність прийомів в порядку спадання)'),
(119484, 18, 33, 'Додатнє число покаже кількість попередніх прийомів на віджеті у вікні з загальною інформацією про пацієнта.'),
(119485, 19, 33, 'Джерело направлення може вимагатися при кожному відвідуванні'),
(119486, 20, 33, 'Відповідний код IPPF є необхідним!'),
(119487, 21, 33, 'Спеціальний символ'),
(119488, 22, 33, 'Унікальне значення ідентифікації цього поля, не видиме для користувача'),
(119489, 23, 33, 'Для цього пацієнта існує запис про візит на сьогдні. Натисніть Відмінити щоб відкрити існуючий та ОК щоб створити ще один новий'),
(119490, 24, 33, 'Перед їжею'),
(119491, 25, 33, 'До полудня'),
(119492, 26, 33, 'A/F Рівень'),
(119493, 27, 33, 'Астматичний бронхіт'),
(119494, 28, 33, 'Скорочення'),
(119495, 29, 33, 'Абсцес'),
(119496, 30, 33, 'Черевний'),
(119497, 31, 33, 'Здатність переносити вагу (4 фази):'),
(119498, 32, 33, 'Аномальний'),
(119499, 33, 33, 'Відхилення від норми 1'),
(119500, 34, 33, 'Аномальний, з відхиленням від норми'),
(119501, 35, 33, 'Аналіз крові з відхиленням від норми'),
(119502, 36, 33, 'Аномальний ріст волосся'),
(119503, 37, 33, 'Мамограма з відхиленням від норми'),
(119504, 39, 33, 'Переривання вагітності'),
(119505, 40, 33, 'Проблеми переривання вагітності'),
(119506, 41, 33, 'Методи переривання вагітності'),
(119507, 42, 33, 'Категорії пов''язані з перериванням вагітності'),
(119508, 43, 33, 'Аборти'),
(119509, 44, 33, 'Про календар'),
(119510, 46, 33, 'Відсутність за діагнозом'),
(119511, 47, 33, 'Прийняти призначення'),
(119512, 48, 33, 'Прийняти оплату за'),
(119513, 49, 33, 'Прийняти оплату за'),
(119514, 50, 33, 'Особа, що приймає призначення'),
(119515, 51, 33, 'Контроль доступу'),
(119516, 52, 33, 'Адміністрування через список управління доступом (ACL)'),
(119517, 53, 33, 'Дата доступу'),
(119518, 54, 33, 'Доступ не дозволено'),
(119519, 55, 33, 'Не уповноважений для доступу'),
(119520, 56, 33, 'Доступ до Вашого Порталу Пацієнта'),
(119521, 57, 33, 'Нещасний випадок'),
(119522, 59, 33, 'Назва облікового запису'),
(119523, 62, 33, 'Облік'),
(119524, 64, 33, 'Болі'),
(119525, 65, 33, 'Запит на підтвердження'),
(119526, 66, 33, 'Підтвердження, ліцензії та сертифікати'),
(119527, 67, 33, 'Керування доступом'),
(119528, 68, 33, 'Управління списком контролю доступу'),
(119529, 69, 33, 'Управління списком контролю доступу не дозволено'),
(119530, 70, 33, 'Список контролю доступу оновлено успішно'),
(119531, 71, 33, 'Акне'),
(119532, 72, 33, 'Акт'),
(119533, 73, 33, 'Дата підписання акту'),
(119534, 74, 33, 'Дія'),
(119535, 75, 33, 'Дії'),
(119536, 77, 33, 'Активувати повідомлення CCR / CCD'),
(119537, 78, 33, 'Активний'),
(119538, 79, 33, 'Активне повідомлення'),
(119539, 80, 33, 'Правила передачі активних повідомлень'),
(119540, 81, 33, 'Поточні сповіщення / нагадування'),
(119541, 82, 33, 'Активне звернення'),
(119542, 84, 33, 'Поточна зустріч'),
(119543, 85, 33, 'Поточний пацієнт'),
(119544, 86, 33, 'Поточні програми'),
(119545, 87, 33, 'Діяльність'),
(119546, 88, 33, 'Вид діяльності'),
(119547, 90, 33, 'Гостра інтоксикація / абстіненція'),
(119548, 91, 33, 'Гострий прояв хронічного захворювання'),
(119549, 92, 33, 'Гострий або хронічний'),
(119550, 93, 33, 'додати'),
(119551, 94, 33, 'Додати'),
(119552, 95, 33, 'ДОДАТИ'),
(119553, 96, 33, 'Додати компанію'),
(119554, 98, 33, 'Додати аптеку'),
(119555, 100, 33, 'додати подію для '),
(119556, 101, 33, 'Додати як новий запис'),
(119557, 102, 33, 'Додати як новий пункт'),
(119558, 104, 33, 'Додати кнопки'),
(119559, 105, 33, 'Додати кнопки для спеціальних діаграм, текстів для відображення вгорі Редактора для включення в текст при натисканні'),
(119560, 106, 33, 'Додати категорію'),
(119561, 107, 33, 'Додати константу'),
(119562, 108, 33, 'Додати режим роботи'),
(119563, 109, 33, 'Додати оплату пацієнта'),
(119564, 110, 33, 'Додати критерії'),
(119565, 111, 33, 'Додати кнопку користувача'),
(119566, 112, 33, 'Додати діагноз'),
(119567, 113, 33, 'Додати ліки'),
(119568, 114, 33, 'Додати звернення'),
(119569, 115, 33, 'Додати звернення / запис'),
(119570, 116, 33, 'Додати медичний заклад'),
(119571, 117, 33, 'Додати поле'),
(119572, 118, 33, 'Додайте наступні рядки в конфігураційний файл Apache'),
(119573, 119, 33, 'Додати групу'),
(119574, 120, 33, 'Додати код МКХ (Міжнародної класифікації захворювань)'),
(119575, 121, 33, 'Додати вакцинацію'),
(119576, 122, 33, 'Добавлення не дозволено'),
(119577, 123, 33, 'Додати проблему'),
(119578, 124, 33, 'Додати елемент для відслідковування'),
(119579, 125, 33, 'Додати мову'),
(119580, 126, 33, 'Додати Нове'),
(119581, 127, 33, 'Додати нове'),
(119582, 128, 33, 'Додати нову категорію '),
(119583, 129, 33, 'Додати нові сертифікати в конфігураційний файл Apache'),
(119584, 130, 33, 'Додати новий компонент'),
(119585, 131, 33, 'Додати нові компоненти'),
(119586, 132, 33, 'Додати нову групу'),
(119587, 133, 33, 'Додати нову проблему'),
(119588, 134, 33, 'Додати нову партію чи транзакцію'),
(119589, 135, 33, 'Додати Новий Запис'),
(119590, 136, 33, 'Додати новий запис'),
(119591, 137, 33, 'Додати нового партнера'),
(119592, 138, 33, 'Додати нового пацієнта'),
(119593, 140, 33, 'Додати запис'),
(119594, 141, 33, 'Додати запис пацієнта'),
(119595, 142, 33, 'Додати призначення/рецепт'),
(119596, 143, 33, 'Дадати процедуру'),
(119597, 144, 33, 'Додати номер постачальника'),
(119598, 145, 33, 'Додати реабілітацію'),
(119599, 146, 33, 'Додати правило'),
(119600, 147, 33, 'Додати до'),
(119601, 148, 33, 'Додати до списку препаратів'),
(119602, 149, 33, 'Додати верхній рівень'),
(119603, 150, 33, 'Додати транзакцію'),
(119604, 151, 33, 'Додати користувача'),
(119605, 152, 33, 'Додати користувача до групи'),
(119606, 153, 33, 'Додати / змінити eRx (електронне призначення лікаря/рецепт)'),
(119607, 154, 33, 'Додати / змінити транзакцію по пацієнтові'),
(119608, 155, 33, 'доповнено'),
(119609, 156, 33, 'Додавання персональних даних не дозволено.'),
(119610, 157, 33, 'Додати елемент для відслідковування не вдалося'),
(119611, 158, 33, 'Синдром Еддісона'),
(119612, 159, 33, 'Синдром Еддісона'),
(119613, 160, 33, 'Додаткові елементи'),
(119614, 161, 33, 'Додатковий діагноз:'),
(119615, 162, 33, 'Додатковий анамнез'),
(119616, 163, 33, 'Додаткові записи в історію хвороби'),
(119617, 164, 33, 'Додаткова інформація'),
(119618, 165, 33, 'Додаткові лабораторні дослідження'),
(119619, 166, 33, 'Додаткові примітки'),
(119620, 167, 33, 'Додаткові примітки для цих результатів чи рекомендацій'),
(119621, 168, 33, 'Додаткові примітки:'),
(119622, 169, 33, 'Додаткові примітки: '),
(119623, 170, 33, 'Додаткові записи до рентген-дослідження:'),
(119624, 171, 33, 'Додтково, пакет розширення SNOMED (відповідний для США) може бути імпортовано окремо після встановлення версї SNOMED Міжнародний (англійська версія)'),
(119625, 172, 33, 'тільки додавання'),
(119626, 173, 33, 'Адресний довідник'),
(119627, 174, 33, 'Адресний довідник'),
(119628, 175, 33, 'Адреса'),
(119629, 178, 33, 'Адресний довідник'),
(119630, 179, 33, 'Запис в адресному довіднику для компанії, що виконує цю операцію'),
(119631, 180, 33, 'Запис адресному довіднику для дистрибютора'),
(119632, 181, 33, 'Запис адресному довіднику для виробника'),
(119633, 182, 33, 'Види адресних довідників'),
(119634, 183, 33, 'Адресна мітка'),
(119635, 187, 33, 'Адреса 1'),
(119636, 188, 33, 'Адреса 2'),
(119637, 189, 33, 'АДРЕСАТ'),
(119638, 190, 33, 'Коригувати'),
(119639, 191, 33, 'Кількість коригувань'),
(119640, 192, 33, 'Коригувати'),
(119641, 193, 33, 'Коригування'),
(119642, 194, 33, 'Кільк. коригувань'),
(119643, 195, 33, 'Причини коригування'),
(119644, 196, 33, 'Значення коригування для коду '),
(119645, 197, 33, 'Виправлення'),
(119646, 198, 33, 'Налаштування адм.'),
(119647, 199, 33, 'Адмін.'),
(119648, 200, 33, 'Електронна адреса admin'),
(119649, 201, 33, 'Виконувати через'),
(119650, 202, 33, 'Налаштований'),
(119651, 203, 33, 'Налаштований через'),
(119652, 204, 33, 'Дата адміністрування'),
(119653, 205, 33, 'Адміністрований сайт'),
(119654, 206, 33, 'Адміністрування'),
(119655, 207, 33, 'Адміністрування сайту'),
(119656, 208, 33, 'Адміністратори'),
(119657, 209, 33, 'Адміністратори мають необмежений доступ'),
(119658, 210, 33, 'Дата згоди'),
(119659, 212, 33, 'Скрінінг ваги дорослого та диспансерне обстеження'),
(119660, 213, 33, 'Скрінінг ваги дорослого та диспансерне обстеження (CQM)'),
(119661, 214, 33, 'Попередня інструкція'),
(119662, 215, 33, 'Попередні інструкції'),
(119663, 216, 33, 'Попередження про попередню інструкції'),
(119664, 218, 33, 'Вдосконалений'),
(119665, 219, 33, 'Порада'),
(119666, 220, 33, 'Здалеку'),
(119667, 221, 33, 'Вплинути на норму'),
(119668, 222, 33, 'Африкаанс'),
(119669, 223, 33, 'Дзвінки в неробочий час'),
(119670, 224, 33, 'Коли завершено міграцію зі старого механізму паролів де вони зберігаються в таблиці користувачів і без солі, цей прапоець повинен бути встановлений в FALSE, після чого буде можлива лише аутентифікація за новим методом'),
(119671, 225, 33, 'Після завершення вказаних налаштувань імпортуйте сертифікат клієнта admin в браузер і перезавантажте сервер Apache (порожній пароль).'),
(119672, 226, 33, 'Після збереження PDF натисніть [Перегляд журналу] для перевірки помилок.'),
(119673, 227, 33, 'Після збереження файлу (файлів) TEXT натисніть [Перегляд журналу] для перевірки помилок.'),
(119674, 228, 33, 'Після збереження пакета натисніть [Перегляд журналу] для перевірки помилок.'),
(119675, 229, 33, 'Після цього стовбець Співпадіння буде показувати ID вибраного пацієнта, або 0 для створення'),
(119676, 230, 33, 'Після правильного введення інформації натисніть кнопку Зберегти.'),
(119677, 231, 33, 'Після вивантаження натисніть кнопку "Імпорт"'),
(119678, 232, 33, 'Планування догляду за виздоровлюючим'),
(119679, 233, 33, 'Повторно'),
(119680, 234, 33, 'Вік'),
(119681, 235, 33, 'Вік за'),
(119682, 236, 33, 'Вікова категорія'),
(119683, 237, 33, 'Дані по віку відсутні'),
(119684, 238, 33, 'Формат відображення віку'),
(119685, 239, 33, 'Формат віку "вік від" не дійсний'),
(119686, 240, 33, 'Формат віку "вік до" не дійсний'),
(119687, 241, 33, 'Вік від'),
(119688, 242, 33, 'Вік в роках щоб відобразити зміну формату'),
(119689, 243, 33, 'Вік макс'),
(119690, 244, 33, 'Вік мін'),
(119691, 245, 33, 'Віковий діапазон'),
(119692, 247, 33, 'Стовпці віку:'),
(119693, 249, 33, 'Албанська'),
(119694, 250, 33, 'Алкоголь'),
(119695, 251, 33, 'Вживання алкоголю'),
(119696, 252, 33, 'Використання алкоголю'),
(119697, 253, 33, 'Кількість повідомлень'),
(119698, 255, 33, 'Сповіщення'),
(119699, 258, 33, 'Алеутський'),
(119700, 259, 33, 'Всі'),
(119701, 260, 33, 'Всі'),
(119702, 261, 33, 'Всі (формат зіставлення A)'),
(119703, 262, 33, 'Всі (формат зіставлення B)'),
(119704, 263, 33, 'Всі (сукупні)'),
(119705, 265, 33, 'Всі автоматично розраховані одиниці (АРО)'),
(119706, 266, 33, 'Всі категорії'),
(119707, 268, 33, 'Всі коди'),
(119708, 269, 33, 'Весь день'),
(119709, 270, 33, 'Подія на весь день'),
(119710, 271, 33, 'Всі поля персональних даних з пошуком і перевіркою на повтори'),
(119711, 272, 33, 'Всі об''єкти'),
(119712, 273, 33, 'Всі травми / Проблеми / аспекти'),
(119713, 274, 33, 'Дозволені всі мови'),
(119714, 276, 33, 'Ім''я або його фрагмент'),
(119715, 277, 33, 'Прізвище або його фрагмент'),
(119716, 278, 33, 'Назва організації або фрагмент назви'),
(119717, 279, 33, 'Всі пацієнти'),
(119718, 280, 33, 'Вся продукція'),
(119719, 281, 33, 'Всі провайдери'),
(119720, 282, 33, 'Всі були розглянуті і негативні'),
(119721, 283, 33, 'Всі розділи'),
(119722, 284, 33, 'Всі користувачі'),
(119723, 285, 33, 'Алергічний'),
(119724, 286, 33, 'Алергії'),
(119725, 287, 33, 'Алергії:'),
(119726, 288, 33, 'Алергія'),
(119727, 289, 33, 'Імпорт інформації про алергії успішно завершено'),
(119728, 290, 33, 'Перелік відомих алергій'),
(119729, 291, 33, 'Алергічна реакція'),
(119730, 294, 33, 'Внести'),
(119731, 295, 33, 'Дозволити'),
(119732, 296, 33, 'Дозволити вибирати всі доступні мови в меню входу в систему.'),
(119733, 297, 33, 'Дозволяє створення заявок які містять діагнози, але не процедури чи оплати. Для більшості клінік це не потрібно.'),
(119734, 298, 33, 'Дозволити налагодження мови'),
(119735, 299, 33, 'Дозволити e-mail'),
(119736, 300, 33, 'Дозволити електронні повідомлення?'),
(119737, 301, 33, 'Дозволити e-mail?'),
(119738, 302, 33, 'Дозволити запит звернення'),
(119739, 303, 33, 'Дозволити обмін інформацією про здоров''я'),
(119740, 304, 33, 'Дозволити обмін інформацією про вакцинацію'),
(119741, 305, 33, 'Дозволити використання реєстру вакцинації'),
(119742, 306, 33, 'Дозволити передачу повідомлень поштою'),
(119743, 308, 33, 'Дозволити портал пацієнтів'),
(119744, 309, 33, 'Дозволити СМС'),
(119745, 310, 33, 'Дозволити СМС (текстове повідомлення)'),
(119746, 311, 33, 'Дозволити негайну активацію поточних подій?'),
(119747, 312, 33, 'Дозволити телефонні повідомлення?'),
(119748, 313, 33, 'Дозволити користувачам опубліковувати загальні події'),
(119749, 314, 33, 'Дозволити користувачам опубліковувати персональний календар'),
(119750, 315, 33, 'Дозволити голосові повідомлення'),
(119751, 316, 33, 'Дозволено'),
(119752, 317, 33, 'Дозволені мови'),
(119753, 318, 33, 'Дозволено'),
(119754, 319, 33, 'Дозволяє Е-підпис для вмісту випадку'),
(119755, 320, 33, 'Дозволяє Е-підписування індивідуальних форм'),
(119756, 321, 33, 'Дозволяє пошту'),
(119757, 322, 33, 'Дозволяє голосові повідомлення'),
(119758, 323, 33, 'вже існує'),
(119759, 324, 33, 'вже існує.'),
(119760, 325, 33, 'Вже використовується, виберіть інший ідентифікатор'),
(119761, 326, 33, 'Вже використовується, виберіть інший заголовок'),
(119762, 327, 33, 'Альтернативна адреса'),
(119763, 328, 33, 'інший'),
(119764, 329, 33, 'Також можна використовувати сторінку пошуку для завантаження файлу електронного грошового переказу (X12 835), який ви отримали від платника або розрахункового центру. Це можна зробити, натиснувши кнопку "Огляд" і вибравши файл для завантаження, а потім натиснувши Пошук, щоб виконати завантаження і відображення відповідних рахунків-фактур. У цьому випадку інші параметри, зазначені вище, не застосовуються, і будуть проігноровані. Завантаження зберігає файл, але ще не обробляє його вміст - це буде зроблено окремо, як описано нижче.'),
(119765, 330, 33, 'До полудня'),
(119766, 331, 33, 'Ранкова програма'),
(119767, 332, 33, 'Автоматичний розрахунок одиниць (АРО)'),
(119768, 333, 33, 'Відстеження АРО'),
(119769, 334, 33, 'АРО-2011'),
(119770, 335, 33, 'АРО-2014'),
(119771, 338, 33, 'Виправити існуючий запис'),
(119772, 339, 33, 'Форма покращення'),
(119773, 340, 33, 'Стан покращення'),
(119774, 341, 33, 'Покращення'),
(119775, 342, 33, 'Покращення для'),
(119776, 343, 33, 'Американський індіанець'),
(119777, 344, 33, 'Американський індіанець або уродженець Аляски'),
(119778, 345, 33, 'AMEX (Амерікан Експрес)'),
(119779, 346, 33, 'Амхарська'),
(119780, 347, 33, 'Сума'),
(119781, 348, 33, 'Сума керована'),
(119782, 349, 33, 'Підсумковий платіж'),
(119783, 350, 33, 'Сума минулого балансу'),
(119784, 351, 33, 'Сума для цього відвідування'),
(119785, 352, 33, 'Виплачена сума'),
(119786, 353, 33, 'Сума:'),
(119787, 354, 33, 'Кільк. рахунків'),
(119788, 355, 33, 'Для повторюваних подій дата кінця повинна бути пізніше дати початку!'),
(119789, 356, 33, 'При підписуванні форми сталася помилка'),
(119790, 357, 33, 'При формуванні дампу дерева веб-каталогу LibreEHR сталася помилка'),
(119791, 358, 33, 'Під час формування дампу дерева веб-каталогу phpGACL сталася помилка'),
(119792, 359, 33, 'Під час формування дампу дерева веб-каталогу для регістра SQL сталася помилка'),
(119793, 360, 33, 'Створено незавершену категорію GCAC. ЇЇ необхідно заверити пізніше'),
(119794, 362, 33, 'Непередбачена помилка.'),
(119795, 363, 33, 'Буква верхнього реєстру'),
(119796, 365, 33, 'і'),
(119797, 366, 33, 'І'),
(119798, 367, 33, 'і'),
(119799, 368, 33, 'і '),
(119800, 369, 33, 'і всі додаткові дані? Цю дію буде запротоколовано'),
(119801, 370, 33, 'і модифіковані'),
(119802, 371, 33, 'і оброблені.'),
(119803, 372, 33, 'і перезавантажте сервер Apache.'),
(119804, 373, 33, 'і Причина полягає в'),
(119805, 374, 33, 'Анемія'),
(119806, 375, 33, 'Гомілковостопний суглоб'),
(119807, 376, 33, 'Гомілковостопний суглоб + п''ята'),
(119808, 377, 33, 'Бланк обстеження гомілковостопного суглоба'),
(119809, 378, 33, 'Проблеми гомілковостопного суглоба'),
(119810, 379, 33, 'Анкілозуючий спондиліт'),
(119811, 380, 33, 'Анкілозуючий спондиліт'),
(119812, 381, 33, 'Анорексія'),
(119813, 382, 33, 'У вікні відправки також можна зробити повторний запит рахунку. Якщо ви виберете цю кнопку перед збереженням, то на сторінці рахунків буде знову відкрито початковий запит, поставлено в чергу і буде опрацьовано при наступному запуску сторінки рахунків.'),
(119814, 383, 33, 'частка'),
(119815, 384, 33, 'Тонус анального сфінктера звичайний, безболісний, пухлинних утворень немає'),
(119816, 385, 33, 'Тривожність'),
(119817, 386, 33, 'Будь-який'),
(119818, 387, 33, 'Будь-яка категорія'),
(119819, 388, 33, 'Будь-який фрагмент необхідного коду або його опису'),
(119820, 389, 33, 'Будь-який фрагмент назви необхідної спеціальності'),
(119821, 390, 33, 'Будь-який фрагмент назви медикаменту'),
(119822, 391, 33, 'Будь-який фрагмент назви вакцинації'),
(119823, 392, 33, 'Будь-який фрагмент ПІБ пацієнта, чи "прізвище, імя", чи "А-Я"'),
(119824, 393, 33, 'Будь-яка інша відповідна інформація'),
(119825, 394, 33, 'Ключ API для шлюзу СМС'),
(119826, 395, 33, 'Апое'),
(119827, 396, 33, 'Зовнішній вигляд'),
(119828, 397, 33, 'Зовнішній вигляд:'),
(119829, 398, 33, 'Додати цей запис');
INSERT INTO `lang_definitions` VALUES
(119830, 399, 33, 'Додати до існуючої записи'),
(119831, 400, 33, 'Додати до цього запису'),
(119832, 401, 33, 'Додати до цього запису'),
(119833, 402, 33, 'Апендектомія'),
(119834, 403, 33, 'апендектомія'),
(119835, 404, 33, 'Відповідні пацієнти'),
(119836, 405, 33, 'Програма'),
(119837, 406, 33, 'Ім''я програми для сторінки входу і основного заголовка вікна.'),
(119838, 407, 33, 'Код отримувача програми (GS03 - Якщо бланк ISA08 буде використовуватися)'),
(119839, 408, 33, 'Код відправника програми (GS02)'),
(119840, 409, 33, 'Назва програми'),
(119841, 410, 33, 'Застосовується у формі життєво важливих показників та діаграмі фізичного розвитку'),
(119842, 411, 33, 'Застосовується у формі життєво важливих показників'),
(119843, 412, 33, 'Застосувати зміни лише до поточного події чи до всіх подальших дій?'),
(119844, 413, 33, 'нанести на уражені ділянки'),
(119845, 414, 33, 'нанести на шкіру'),
(119846, 415, 33, 'Застосування'),
(119847, 416, 33, 'Застосувати виправлення до сайту'),
(119848, 417, 33, 'Запис на прийом'),
(119849, 418, 33, 'Дата прийому'),
(119850, 419, 33, 'Стиль відображення запису на прийом'),
(119851, 420, 33, 'Правило нагадування про запис на прийом'),
(119852, 421, 33, 'Статус прийому'),
(119853, 422, 33, 'Статуси прийому'),
(119854, 423, 33, 'Запис на прийом за період'),
(119855, 424, 33, 'Колір для прийому/події'),
(119856, 425, 33, 'Записи на прийом'),
(119857, 426, 33, 'Записи на прийом (право запису - на вибір)'),
(119858, 427, 33, 'Записи на прийом (на вибір - право записувати все/частково)'),
(119859, 430, 33, 'Записи на прийом і звертання'),
(119860, 431, 33, 'Звіт про прийоми'),
(119861, 432, 33, 'Звіт про прийоми-звертання'),
(119862, 434, 33, 'Підтвердити'),
(119863, 435, 33, 'Підтвердити пацієнта з Пацієнт/Клієнт->Імпорт->Оцікує підтвердження'),
(119864, 436, 33, 'Підтверджено'),
(119865, 437, 33, 'Керування підтвердженими подіями'),
(119866, 438, 33, 'Підтверджено успішно'),
(119867, 440, 33, 'Прийоми-зустрічі'),
(119868, 441, 33, 'Прийоми-зустрічі'),
(119869, 442, 33, 'Квіт.'),
(119870, 443, 33, 'Квітень'),
(119871, 444, 33, 'Арабська'),
(119872, 445, 33, 'Арагонська'),
(119873, 446, 33, 'Архів'),
(119874, 447, 33, 'Чи треба перекладати назви груп управління доступом?'),
(119875, 448, 33, 'Чи треба перекладати назви категорій прийому?'),
(119876, 449, 33, 'Чи треба перекладати назви категорій документів?'),
(119877, 450, 33, 'Для цього типу оплата передбачена?'),
(119878, 451, 33, 'Чи треба перекладати заголовки запису по пацієнту?'),
(119879, 452, 33, 'Чи зберігаються коди в зовнішніх таблицях SQL (0-ні, 1-МКБ-10, 2-SNOMED (RF1), 3-SNOMED (RF2))?'),
(119880, 453, 33, 'Чи Ви готові завершити нову GCAC категорію для цього візиту?'),
(119881, 454, 33, 'Чи Ви готові зробити запис за сьогодні?'),
(119882, 455, 33, 'Чи Ви готові підтвердити ці події?'),
(119883, 457, 33, 'Чи Ви готові повністю видалити цю форму?'),
(119884, 459, 33, 'Чи Ви готові видалити цю публікацію?'),
(119885, 460, 33, 'Чи Ви готові видалити цю подію?'),
(119886, 461, 33, 'Чи Ви готові видалити цей пункт з бази даних?'),
(119887, 462, 33, 'Чи Ви готові видалити цей запис?'),
(119888, 464, 33, 'Чи Ви готові змінити ці події?'),
(119889, 465, 33, 'Чи Ви готові приховати ці події?'),
(119890, 467, 33, 'Чи Ви готові відкрити ці події?'),
(119891, 468, 33, 'Чи Ви готові видалити всю групу?'),
(119892, 469, 33, 'Чи Ви готові видалити список цілком?'),
(119893, 470, 33, 'Чи Ви готові видалити поля в'),
(119894, 471, 33, 'Чи Ви готові видалити вибрані поля?'),
(119895, 472, 33, 'Чи Ви готові продовжити ці дії?'),
(119896, 473, 33, 'Не вказана область'),
(119897, 474, 33, 'Рука'),
(119898, 475, 33, 'Вірменська'),
(119899, 477, 33, 'Аритмія'),
(119900, 478, 33, 'Артрит'),
(119901, 479, 33, 'Артрит / деструктивне захворювання суглобів'),
(119902, 480, 33, 'Артрит / деструктивне захворювання суглобів'),
(119903, 481, 33, 'як'),
(119904, 482, 33, 'Як з'),
(119905, 484, 33, 'Азіатський'),
(119906, 485, 33, 'Асамський'),
(119907, 487, 33, 'Оцінка'),
(119908, 488, 33, 'Призначено'),
(119909, 489, 33, 'Асистент'),
(119910, 490, 33, 'Астма'),
(119911, 491, 33, 'в'),
(119912, 492, 33, 'Якщо Ви вибрали "Все", то хоча б один параметр пошуку необхідний'),
(119913, 493, 33, 'У човноподібній кістці'),
(119914, 494, 33, 'У човноподібній кістці:'),
(119915, 495, 33, 'Спортивна команда'),
(119916, 496, 33, 'Спортивна команда'),
(119917, 497, 33, 'Спортивна/травма'),
(119918, 498, 33, 'Сертифікат CA аудиту ATNA'),
(119919, 499, 33, 'Хост аудиту ATNA'),
(119920, 500, 33, 'Місцевий сертифікат для аудиту ATNA'),
(119921, 501, 33, 'Порт аудиту ATNA'),
(119922, 503, 33, 'Увага'),
(119923, 504, 33, 'Увага'),
(119924, 506, 33, 'Аудит інструменту CDR-запитів'),
(119925, 507, 33, 'Аудит журналу розтину'),
(119926, 508, 33, 'Аудит журналу звіту про розтин'),
(119927, 509, 33, 'Резервне копіювання журналу аудиту'),
(119928, 510, 33, 'Різноманітна реєстрація аудиту'),
(119929, 511, 33, 'Призначення журналу аудиту'),
(119930, 512, 33, 'Аудит журнал записів пацієнта'),
(119931, 513, 33, 'Планування Аудит реєстрації'),
(119932, 514, 33, 'Аудит реєстрація управління безпекою'),
(119933, 515, 33, 'Аудит реєстрація запиту SELECT'),
(119934, 516, 33, 'Серп.'),
(119935, 517, 33, 'Серпень'),
(119936, 519, 33, 'Авторизувати'),
(119937, 520, 33, 'Авторизувати / Записи'),
(119938, 523, 33, 'Авторизована група'),
(119939, 524, 33, 'Статус авторизації'),
(119940, 525, 33, 'Авторизація'),
(119941, 526, 33, 'Дозволити'),
(119942, 527, 33, 'Дозволити - будь-які звернення'),
(119943, 528, 33, 'Дозволити - мої звернення'),
(119944, 529, 33, 'Authorize.net'),
(119945, 530, 33, 'Уповноважений'),
(119946, 531, 33, 'Тільки уповноважений'),
(119947, 532, 33, 'Автоматична відправка'),
(119948, 535, 33, 'Створити нове звернення автоматично'),
(119949, 536, 33, 'Авто-створені'),
(119950, 537, 33, 'Автоматичний розрахунок одиниць вимірювання (AMC)'),
(119951, 538, 33, 'Автоматичний розрахунок одиниць вимірювання (AMC) - 2011'),
(119952, 539, 33, 'Автоматичний розрахунок одиниць вимірювання (AMC) - 2014'),
(119953, 542, 33, 'Відстеження автоматичного розрахунку одиниць вимірювання (AMC)'),
(119954, 543, 33, 'Автоматична одиниця виміру (AMC)'),
(119955, 544, 33, 'Автоматично'),
(119956, 546, 33, 'Створює нове звернення автоматично, коли статус прийому встановлюється на "@" (прибув).'),
(119957, 549, 33, 'Медицина автокатастроф'),
(119958, 550, 33, 'автоматично збережений'),
(119959, 551, 33, 'Доступні категорії'),
(119960, 552, 33, 'Доступний час'),
(119961, 553, 33, 'Доступні треки'),
(119962, 554, 33, 'Аварський'),
(119963, 555, 33, 'Мітки Авері для друку етикетоа для пацієнтів в лівому вікні навігації'),
(119964, 556, 33, 'Авестійська'),
(119965, 557, 33, 'Всередньому щомісячно'),
(119966, 558, 33, 'Розрив/перелом з авульсією'),
(119967, 559, 33, 'Авульсія латеральної щиколотки'),
(119968, 560, 33, 'Авульсія медіальної кісточки '),
(119969, 561, 33, 'На основі інформованості'),
(119970, 562, 33, 'Пахвовий'),
(119971, 563, 33, 'Аймара'),
(119972, 564, 33, 'Азербайджанська'),
(119973, 565, 33, 'двічі на день'),
(119974, 566, 33, 'Назад'),
(119975, 567, 33, 'назад'),
(119976, 568, 33, 'Вісім відвідувань назад'),
(119977, 569, 33, 'Одинадцять відвідувань назад'),
(119978, 570, 33, 'П''ять відвідувань назад'),
(119979, 571, 33, 'Чотири відвідування назад'),
(119980, 572, 33, 'Дев''ять відвідувань назад'),
(119981, 573, 33, 'Одне відвідування назад'),
(119982, 574, 33, 'Спинний біль'),
(119983, 575, 33, 'Проблеми з спиною'),
(119984, 576, 33, 'Сім відвідувань назад'),
(119985, 577, 33, 'Шість відвідувань назад'),
(119986, 578, 33, 'Хірургія хребта'),
(119987, 579, 33, 'Десять відвідувань назад'),
(119988, 580, 33, 'Три відвідування назад'),
(119989, 581, 33, 'Назад до сторінки адміністрування'),
(119990, 582, 33, 'Назад до випадку'),
(119991, 583, 33, 'Назад до пацієнта'),
(119992, 584, 33, 'Назад до пацієнта'),
(119993, 585, 33, 'Назад до користувачів'),
(119994, 586, 33, 'Назад до перегляду'),
(119995, 587, 33, 'Дванадцять відвідувань назад'),
(119996, 588, 33, 'Два відвідування назад'),
(119997, 589, 33, 'Фонові сервіси'),
(119998, 590, 33, 'Резервна копія'),
(119999, 591, 33, 'Файл резервного копіювання створено.Теперь буде розпочато вивантаження.'),
(120000, 592, 33, 'Список резервних копій'),
(120001, 593, 33, 'Резервна копія прийнята'),
(120002, 594, 33, 'Фальшивий чек'),
(120003, 595, 33, 'Найбільший борг'),
(120004, 596, 33, 'Бахаса Індонезія'),
(120005, 597, 33, 'Баланс'),
(120006, 598, 33, 'Баланс'),
(120007, 599, 33, 'баланс'),
(120008, 600, 33, 'Баланс (кільк.)'),
(120009, 601, 33, 'Дебетове сальдо'),
(120010, 603, 33, 'Банківський розрахунок'),
(120011, 604, 33, 'Мітка з штрихкодом'),
(120012, 605, 33, 'Тип мітки з штрихкодом'),
(120013, 606, 33, 'Тип штрихкоду для друку міток з штрихкодом в лівому вікні навігації'),
(120014, 607, 33, 'Основа п''ятої (5-ї) метатарсальної кістки'),
(120015, 608, 33, 'Основа п''ятої (5-ї) метатарсальної кістки:'),
(120016, 609, 33, 'Башкирська'),
(120017, 610, 33, 'Баскська'),
(120018, 611, 33, 'Пакетна вимога'),
(120019, 612, 33, 'Інструмент пакетної передачі даних'),
(120020, 613, 33, 'Введення групової оплати'),
(120021, 614, 33, 'Групові оплати'),
(120022, 615, 33, 'Ініційована пакетна обробка; вона може зайнятий час.'),
(120023, 616, 33, 'Пакетні результати'),
(120024, 617, 33, 'Пакетна передача'),
(120025, 618, 33, 'Зачекайте, обробка декількох файлів займе кілька хвилин!'),
(120026, 619, 33, 'оскільки дане id не існує.'),
(120027, 620, 33, 'Початок'),
(120028, 621, 33, 'Дата початку'),
(120029, 623, 33, 'Дата початку обслуговування рррр-мм-дд'),
(120030, 624, 33, 'Початкова година дня для календарних подій.'),
(120031, 625, 33, 'Білоруська'),
(120032, 626, 33, 'Відрижка'),
(120033, 628, 33, 'Бенгальська'),
(120034, 630, 33, 'між'),
(120035, 631, 33, 'Двонаправлений'),
(120036, 632, 33, 'Біхарі'),
(120037, 633, 33, 'Білатерально'),
(120038, 634, 33, 'Білатерально:'),
(120039, 636, 33, 'Дата рахунку:'),
(120040, 637, 33, 'Рахунки / підрахунок'),
(120041, 638, 33, 'Сплачений'),
(120042, 640, 33, 'Рахунки'),
(120043, 641, 33, 'Рахунки (право запису - на вибір)'),
(120044, 642, 33, 'Попередження по платежу'),
(120045, 644, 33, 'Білінговий код для запитуваної послуги'),
(120046, 645, 33, 'Білінгові коди'),
(120047, 646, 33, 'Дата платежу'),
(120048, 647, 33, 'Розрахункове відділення'),
(120049, 648, 33, 'Розрахунковий об''єкт'),
(120050, 649, 33, 'Інформація по розрахунках'),
(120051, 650, 33, 'Розміщення бухгалтерії'),
(120052, 655, 33, 'Менеджер по розрахунках'),
(120053, 656, 33, 'Розрахунковий запис'),
(120054, 657, 33, 'Розрахунковий запис для '),
(120055, 658, 33, 'Розрахунковий запис:'),
(120056, 659, 33, 'Результати запиту по розрахунках'),
(120057, 660, 33, 'Звіт по розрахунках'),
(120058, 661, 33, 'Статус рахунку'),
(120059, 662, 33, 'Статус рахунку = не оплачений'),
(120060, 663, 33, 'рахунок в '),
(120061, 665, 33, 'Біопсія'),
(120062, 666, 33, 'Дата народження'),
(120063, 667, 33, 'Народжений-24 місяці'),
(120064, 669, 33, 'Чорношкірий'),
(120065, 670, 33, 'Антракоз'),
(120066, 671, 33, 'Чорношкірий або афро-американець'),
(120067, 672, 33, 'Рак сечового міхура'),
(120068, 673, 33, 'Інфекції сечового міхура'),
(120069, 674, 33, 'Порожні бланки'),
(120070, 675, 33, 'Проблеми кровотечі'),
(120071, 676, 33, 'Сліпі плями'),
(120072, 677, 33, 'Вздуття живота'),
(120073, 678, 33, 'Блокований'),
(120074, 679, 33, 'Кров'),
(120075, 680, 33, 'Артеріальний тиск'),
(120076, 681, 33, 'Артеріальний тиск'),
(120077, 682, 33, 'Носова кровотеча'),
(120078, 683, 33, 'Медичне страхове товариство "Синій Хрест і Синій Щит"'),
(120079, 684, 33, 'Сині рядки в цьому звіті є довідковими. Чорні рядки показують інформацію, яка існувала раніше. Зелені рядки показують зміни, які були успішно внесені. Червоні лінії позначають помилки або зміни, які не були зроблені; вони повинні бути виконані вручну. В даний час відхилення вимоги і відкат оплати автоматично не обробляються, і тому вони будуть відображатися червоним.'),
(120080, 685, 33, 'Нечіткий зір'),
(120081, 686, 33, 'ІМТ - індекс маси тіла'),
(120082, 687, 33, 'Статус ІМТ'),
(120083, 689, 33, 'Область тіла'),
(120084, 690, 33, 'Ділянка тіла'),
(120085, 691, 33, 'Ділянка тіла, якщо застосовується'),
(120086, 692, 33, 'Кісткова крихкість:'),
(120087, 693, 33, 'Кісткова крихкість: медіальна кісточка'),
(120088, 694, 33, 'Булевий'),
(120089, 695, 33, 'Боснійська'),
(120090, 696, 33, 'Низ'),
(120091, 697, 33, 'Обидва вуха'),
(120092, 698, 33, 'обидва вуха'),
(120093, 699, 33, 'Нижній'),
(120094, 700, 33, 'Нижнє поле (рх)'),
(120095, 701, 33, 'ПОЛЕ 10 A. Виробнича травма '),
(120096, 702, 33, 'ПОЛЕ 10 B. Автомобільна травма '),
(120097, 703, 33, 'ПОЛЕ 10 C. Інші пошкодження '),
(120098, 704, 33, 'ПОЛЕ 14 Визначник дати'),
(120099, 705, 33, 'ПОЛЕ 15 Інший визначник дати'),
(120100, 706, 33, 'ПОЛЕ 15. Дата того самого чи схожого захворювання (рік-місяць-число)'),
(120101, 707, 33, 'ПОЛЕ 15. Дата того самого чи схожого захворювання / Інша дата (рік-місяць-число)'),
(120102, 708, 33, 'ПОЛЕ 16. Непрацездатний з дати (рік-місяць-число):'),
(120103, 709, 33, 'ПОЛЕ 16. Непрацездатний до дати (рік-місяць-число):'),
(120104, 710, 33, 'ПОЛЕ 18. Дата госпіталізації з (рік-місяць-число): '),
(120105, 711, 33, 'ПОЛЕ 18. Госпіталізація до дати (рік-місяць-число): '),
(120106, 712, 33, 'ПОЛЕ 20. Зовнішня лабораторія використовується?'),
(120107, 713, 33, 'ПОЛЕ 22. Код повторно наданої медичної допомоги (ICD-9) '),
(120108, 714, 33, 'ПОЛЕ 23. Номер попередньої авторизації '),
(120109, 715, 33, 'Кров''яний тиск'),
(120110, 716, 33, 'Діастолічний АТ'),
(120111, 717, 33, 'Систолічний АТ'),
(120112, 719, 33, 'АТд'),
(120113, 721, 33, 'АТс'),
(120114, 722, 33, 'Португалець бразильського походження'),
(120115, 723, 33, 'Молочна залоза'),
(120116, 724, 33, 'Біопсія молочної залози'),
(120117, 725, 33, 'Виділення з соска'),
(120118, 726, 33, 'Захворювання молочної залози'),
(120119, 727, 33, 'Обстеження молочної залози'),
(120120, 728, 33, 'Новоутворення молочної залози'),
(120121, 730, 33, 'Шуми при диханні:'),
(120122, 731, 33, 'Бретонська'),
(120123, 732, 33, 'Пошкодження скелета'),
(120124, 733, 33, 'пошкоджена форма'),
(120125, 734, 33, 'Форма бронхіту'),
(120126, 735, 33, 'Переглянути'),
(120127, 736, 33, 'Переглянути для запису'),
(120128, 737, 33, 'Забій / гематома'),
(120129, 738, 33, 'Болгарська'),
(120130, 739, 33, 'Набряк з правого боку:'),
(120131, 740, 33, 'Бірманський'),
(120132, 741, 33, 'Печіння при сечовипусканні'),
(120133, 742, 33, 'Печіння при сечовипусканні'),
(120134, 743, 33, 'Робочий телефон'),
(120135, 744, 33, 'Зайнятий'),
(120136, 745, 33, 'але ще не оброблено.'),
(120137, 746, 33, 'Сідниці'),
(120138, 747, 33, 'Сідниці + S.I.'),
(120139, 748, 33, 'через'),
(120140, 749, 33, 'Через'),
(120141, 750, 33, 'перорально'),
(120142, 751, 33, 'Через / Джерело'),
(120143, 752, 33, 'Через:'),
(120144, 753, 33, 'С'),
(120145, 754, 33, 'Сертифікат CA для підтвердження сервера syslog TLS RFC 5425.'),
(120146, 755, 33, 'Час життя кешу (в секундах)'),
(120147, 756, 33, 'Шаблон кешу виконаний?'),
(120148, 757, 33, 'Вживання кофеїну'),
(120149, 758, 33, 'Календар'),
(120150, 759, 33, 'Календарний години закінчення'),
(120151, 760, 33, 'Календарний період'),
(120152, 761, 33, 'Відображення календаря'),
(120153, 762, 33, 'Налаштування календаря'),
(120154, 763, 33, 'Час початку реєстрації'),
(120155, 764, 33, 'Вигляд календаря користувача'),
(120156, 765, 33, 'Перегляд календаря'),
(120157, 766, 33, 'Виклик addForm () робиться тут. <br>'),
(120158, 767, 33, 'Калорії'),
(120159, 768, 33, 'Камбоджійський'),
(120161, 774, 33, 'Скасувати'),
(120162, 775, 33, 'Скасувати зміни'),
(120163, 776, 33, 'Скасовано'),
(120164, 777, 33, 'Рак'),
(120165, 778, 33, 'Скринінг раку: скринінг раку товстого кишечника'),
(120166, 779, 33, 'Скринінг раку: мамографія'),
(120167, 780, 33, 'Скринінгу раку: Мазок Папаніколау'),
(120168, 781, 33, 'Скринінг раку: скринінг раку передміхурової залози'),
(120169, 782, 33, 'Не вдалося додати цей запис, оскільки він вже існує!'),
(120170, 783, 33, 'Не вдалося додати / поновити цей запис, оскільки дублікат вже існує!'),
(120171, 784, 33, 'не може бути досягнуто, проігноровано'),
(120172, 785, 33, 'Не вдалося перетворити в JPEG. Можливо не встановлено програму ImageMagick?'),
(120173, 786, 33, 'не може бути видаено, проігноровано'),
(120174, 787, 33, 'Не може бути відображений в мережі тому, що його тип не підтримується браузером.'),
(120175, 788, 33, 'Не може бути відображений в мережі тому, що його тип не підтримується браузером.'),
(120176, 789, 33, 'Не може бути відображений в мережі тому, що його тип не підтримується браузером.'),
(120177, 790, 33, 'Не вдалося створити'),
(120178, 795, 33, 'Не вдалося знайти '),
(120179, 796, 33, 'Не вдається знайти призначене ім''я файлу'),
(120180, 799, 33, 'Не вдалося знайти пацієнта за ID користувача в SQL-реєстрі'),
(120181, 800, 33, 'Не вдалося знайти посилання на документ postscript в '),
(120182, 801, 33, 'Не вдалося знайти фахівця з SQL-реєстру службовців '),
(120183, 802, 33, 'Не вдається змінити платежі. Залишок негативний.'),
(120184, 803, 33, 'Неможливо відрити '),
(120185, 804, 33, 'Не вдалося відправити для страхування. Обраною особою для платежу є пацієнт.'),
(120186, 805, 33, 'Не вдалося відправити пацієнту. Обраним об''єктом для платежу є страховка.'),
(120187, 806, 33, 'Не вдається відправити платежі. Залишок негативний.'),
(120188, 807, 33, 'Неможливо прочитати'),
(120189, 808, 33, 'Неможливо прочитати директорію'),
(120190, 809, 33, 'Не вдалося оновити, тому що ви не відредагували існуючий запис!'),
(120191, 810, 33, 'З великої літери'),
(120192, 811, 33, 'Все з великої літери'),
(120193, 812, 33, 'капсула'),
(120194, 813, 33, 'Карта'),
(120195, 814, 33, 'Коронарне зондування'),
(120196, 815, 33, 'ЕхоКГ'),
(120197, 816, 33, 'Серцево-судинний'),
(120198, 821, 33, 'Пошкодження хряща / суглоба / диска'),
(120199, 822, 33, 'Травма хряща'),
(120200, 823, 33, 'Каротидна пульсація в нормі, пульс на стопахв нормі'),
(120201, 824, 33, 'готівка'),
(120202, 825, 33, 'Готівка'),
(120203, 826, 33, 'Поступлення готівки'),
(120204, 827, 33, 'Поступлення готівки через провайдера'),
(120205, 828, 33, 'Каталонсько-Валенсійський'),
(120206, 829, 33, 'Хірургія катаракти'),
(120207, 830, 33, 'Катаракта'),
(120208, 831, 33, 'Категорії'),
(120209, 832, 33, 'Категорії для'),
(120210, 833, 33, 'Категорія'),
(120211, 834, 33, 'категорія'),
(120212, 835, 33, 'категорія '),
(120213, 836, 33, 'Відомості про категорію'),
(120214, 837, 33, 'Обмеження по категорії'),
(120215, 838, 33, 'Назва категорії'),
(120216, 839, 33, 'Назва категорії пуста'),
(120217, 840, 33, 'Категорія / заголовок'),
(120218, 841, 33, 'Кавказець'),
(120219, 842, 33, 'Підтверджені підстави для виводу інформації по звертанню чи первинному спеціалісту'),
(120220, 846, 33, 'CCR: Затвердити'),
(120221, 847, 33, 'CCR: Переглянути пацієнта'),
(120222, 848, 33, 'CCR: Переглянути і затвердити'),
(120223, 850, 33, 'CDR'),
(120224, 851, 33, 'Порядок обробки звітів CDR'),
(120225, 852, 33, 'Клітина'),
(120226, 853, 33, 'Мобільний телефон'),
(120227, 855, 33, 'Номер мобільного телефону'),
(120228, 856, 33, 'Основний сертифікат'),
(120229, 857, 33, 'Уродженець центральної чи південної Америки'),
(120230, 858, 33, 'Розташування файлу Сертифікату Авторизації crt не може бути порожнім'),
(120231, 859, 33, 'Розташування файлу Сертифікату Авторизації key не може бути порожнім'),
(120232, 860, 33, 'Сертифікат для відправки на сервер syslog RFC 5425 TLS'),
(120233, 861, 33, 'Сертифікат користувача'),
(120234, 862, 33, 'Сертифікати'),
(120235, 863, 33, 'Чаморро'),
(120236, 864, 33, 'Програма медичного обслуговування членів сімей військовослужбовців Америки'),
(120237, 865, 33, 'Програма медичного обслуговування членів сімей військовослужбовців Америки'),
(120238, 866, 33, 'змінити'),
(120239, 867, 33, 'Змінити'),
(120240, 868, 33, 'Змінити діяльність'),
(120241, 869, 33, 'Помилка внесення змін! Помилка підключення до CouchDB?'),
(120242, 870, 33, 'Зміни зору'),
(120243, 871, 33, 'Зміни зору'),
(120244, 872, 33, 'Змінити пароль'),
(120245, 874, 33, 'Змінений'),
(120246, 875, 33, 'Змінений кишечник'),
(120247, 876, 33, 'Зміна ID пацієнта для документів'),
(120248, 877, 33, 'Особливості'),
(120249, 878, 33, 'залишилось символів'),
(120250, 879, 33, 'Оплата'),
(120251, 880, 33, 'Коригування оплати'),
(120252, 881, 33, 'Код оплати'),
(120253, 882, 33, 'Оплати'),
(120254, 883, 33, 'Карта/діаграма'),
(120255, 884, 33, 'Активністьдіаграми'),
(120256, 885, 33, 'Розрахункова діаграма звіту про діяльність'),
(120257, 886, 33, 'ID карти'),
(120258, 887, 33, 'ID карти:'),
(120259, 888, 33, 'Мітка картки'),
(120260, 889, 33, 'Активність розміщення карти'),
(120261, 890, 33, 'Запис в карті'),
(120262, 891, 33, 'Номер картки'),
(120263, 892, 33, 'Місце зберігання карти'),
(120264, 893, 33, 'Відстеження карти'),
(120265, 894, 33, 'Відстеж. карти'),
(120266, 895, 33, 'Закриті перевірені карти'),
(120267, 896, 33, 'Закриті карти'),
(120268, 897, 33, 'Чеченська'),
(120269, 898, 33, 'Перевірити'),
(120270, 899, 33, 'перевірити'),
(120271, 900, 33, 'вибрати всі'),
(120272, 902, 33, 'Перевірити кількість'),
(120273, 903, 33, 'Дата перевірки'),
(120274, 904, 33, 'Перевірити відмінності перекладів за допомогою мовної таблиці користувача.'),
(120275, 906, 33, 'Позначте по'),
(120276, 907, 33, 'Позначте дані вводу'),
(120277, 908, 33, 'Перевірити елементи на графіку'),
(120278, 909, 33, 'Перевірка лабораторних результатів'),
(120279, 910, 33, 'Позначка свідчить про перегляд'),
(120280, 911, 33, 'Позначте №'),
(120281, 912, 33, 'Позначте номер'),
(120282, 915, 33, 'Позначте оплату'),
(120283, 916, 33, 'Якщо файл є зашифрований, відзначте це поле'),
(120284, 917, 33, 'Позначте тут, якщо потрібно, щоб фахівці бачили всі записи на прийом за замовчуванням, а не тільки свої власні.'),
(120285, 918, 33, 'Позначте щоб створити проблему з цього діагноза'),
(120286, 919, 33, 'Дата реєстрації або EOB:'),
(120287, 920, 33, 'Номер реєстрації або EOB:'),
(120288, 921, 33, 'Номер рег. / Напр.'),
(120289, 922, 33, 'Номер реєстрації або напряму'),
(120290, 923, 33, 'Група прапорців з множинним вибором'),
(120291, 924, 33, 'список прапорців'),
(120292, 925, 33, 'прапорець з текстом'),
(120293, 926, 33, 'Прапорець з текстом'),
(120294, 927, 33, 'Прапорець вище показує чи Ви бажаєте відхилити і видалити HL7 файл'),
(120295, 928, 33, 'перевірений'),
(120296, 929, 33, 'Прапорець є = так, пусто = ні'),
(120297, 931, 33, 'Встановлення прапорця блокування забороняє будь-які майбутні зміни форм у цьому випадку.'),
(120298, 932, 33, 'Розрахунок'),
(120299, 933, 33, 'Контрольна сума'),
(120300, 934, 33, 'Груди'),
(120301, 935, 33, 'Двостороння аускультація грудної клітки'),
(120302, 936, 33, 'Біль у грудях'),
(120303, 937, 33, 'Біль у грудях:'),
(120304, 938, 33, 'Болі в грудях'),
(120305, 940, 33, 'Змін.'),
(120306, 942, 33, 'Основна скарга'),
(120307, 943, 33, 'дитина'),
(120308, 945, 33, 'Статус дитячої імунізації (СДІ)'),
(120309, 946, 33, 'Озноби'),
(120310, 947, 33, 'Китайська'),
(120311, 948, 33, 'Китайська (спрощена)'),
(120312, 949, 33, 'Китайська (традиційна)'),
(120313, 950, 33, 'Мануальний терапевт'),
(120314, 951, 33, 'Вибірково'),
(120315, 952, 33, 'холецистектомія'),
(120316, 953, 33, 'Холецистектомія'),
(120317, 954, 33, 'холецистектомія'),
(120318, 955, 33, 'Виберіть'),
(120319, 956, 33, 'Виберіть розділ і клацніть у ньому на пункт; потім в іншому розділі побачите пов''язані виділені пункти, і зможете клікнути в цьому розділі для додавання або видалення зв"язків.'),
(120320, 957, 33, 'Виберіть критерій'),
(120321, 958, 33, 'Виберіть Завантажити або вбудоване вiдтворення'),
(120322, 959, 33, 'Виберіть файл'),
(120323, 960, 33, 'Виберіть з списку'),
(120324, 961, 33, 'Виберіть напрямок компоновки'),
(120325, 962, 33, 'Виберіть список'),
(120326, 963, 33, 'Виберіть розмір паперу'),
(120327, 964, 33, 'Виберіть мовні вподобання для PDF'),
(120328, 965, 33, 'Виберіть формат друку для звіту по цьому зверненню.'),
(120329, 967, 33, 'хронічний бронхіт'),
(120330, 968, 33, 'Хронічні суглобові болі'),
(120331, 969, 33, 'Хронічна ниркова недостатність (ХНН)'),
(120332, 970, 33, 'Хронічний синовіїт / випіт / суглобний біль / подагра'),
(120333, 971, 33, 'Хронічний / рецедивний'),
(120334, 972, 33, 'Чуваш'),
(120335, 973, 33, 'Цироз печінки'),
(120336, 974, 33, 'Цироз печінки'),
(120337, 975, 33, 'Місто'),
(120338, 976, 33, 'Назва міста'),
(120339, 977, 33, 'Місто, область'),
(120340, 978, 33, 'Місто, поштовий індекс'),
(120341, 979, 33, 'Місто / Область'),
(120342, 980, 33, 'Вимога'),
(120343, 981, 33, 'Вимога '),
(120344, 982, 33, 'Стан вимоги'),
(120345, 983, 33, 'Тест на вимогу завершено'),
(120346, 984, 33, 'Тип вимоги'),
(120347, 985, 33, 'Вимога була згенерована в файл'),
(120348, 986, 33, 'Вимога була згенерована в файл '),
(120349, 987, 33, 'Вимоги'),
(120350, 988, 33, 'Класифікація'),
(120351, 989, 33, 'Очистити'),
(120352, 990, 33, 'Очистити акивного пацієнта'),
(120353, 991, 33, 'Очистити все'),
(120354, 992, 33, 'Очистити HL7 дані'),
(120355, 993, 33, 'Чітке обгрунтування'),
(120356, 994, 33, 'Очистити кеш Smarty'),
(120357, 995, 33, 'Для створення пакету EDI 270 потрібна точна домашня інформація'),
(120358, 996, 33, 'Номер CLIA'),
(120359, 997, 33, 'Натисніть'),
(120360, 998, 33, 'Натисніть "Експорт", щоб експортувати категорію, підкатегорію, пункт, дані вмісту в текстовий файл. Будь-яка подібність цього файлу з файлом XML є чисто випадковою. Відкриті та закриті теги повинні бути в одному рядку, в нижньому регістрі без пропусків. Для імпорту знайдіть файл та натисніть "Імпорт". Якщо дані зовсім інші, він об''єднається з існуючими даними. Якщо є схожі найменування пунктів, старий буде залишений, а новий збережений з додаванням в кінці номера.'),
(120361, 999, 33, 'Клацніть місце в графіку для додавання нової анотації, клікніть його ще раз для видалення'),
(120362, 1000, 33, 'Натисніть Завантажити сертифікат для завантаження сертифікатів в файл ssl.zip'),
(120363, 1001, 33, 'клацніть для подробиць'),
(120364, 1002, 33, 'Натисніть для більш детальної інформації'),
(120365, 1003, 33, 'Натисніть дя підсумку по замовленню'),
(120366, 1004, 33, 'Натисніть для результатів'),
(120367, 1005, 33, 'Натисніть тут'),
(120368, 1006, 33, 'Натисніть тут для додавання нового пацієнта.'),
(120369, 1007, 33, 'Клікніть тут для додавання зміненого статусу нової травми і змініть щоденну активність'),
(120370, 1008, 33, 'Натисніть тут для вибору дати'),
(120371, 1009, 33, 'Натисніть тут для вибору дати і часу'),
(120372, 1010, 33, 'Натисніть тут для вибору початкової дати'),
(120373, 1020, 33, 'натисніть тут для пошуку'),
(120374, 1021, 33, 'клікніть тут, щоб оновити пріоритет, категорію і параметри настройки нікнейму'),
(120375, 1022, 33, 'Натисніть тут, щоб переглянути всі'),
(120376, 1023, 33, 'Натисніть тут для перегляду і графічного представлення'),
(120377, 1025, 33, 'Натисніть тут для перегляду та графічного представлення всіх життєво важливих показників.'),
(120378, 1026, 33, 'Клікніть тут для перегляду відомостей про пацієнта'),
(120379, 1027, 33, 'Натисніть тут для перегляду їх всіх.'),
(120380, 1028, 33, 'Натисніть тут щоб переглянути/змінити детальну інформацію'),
(120381, 1029, 33, 'Натисніть кнопку Встановити для установки версії бази даних з вказаної дати'),
(120382, 1030, 33, 'Клацніть по будь-якій частині часу для її збільшення'),
(120383, 1031, 33, 'Натисніть на Імя Пацієнта, щоб відкрити Файл Пацієнта'),
(120384, 1032, 33, 'Натисніть Оновити для огляду всіх результатів, або введіть вище критерій пошуку для перегляду окремих результатів.'),
(120385, 1033, 33, 'Натисніть щоб додати діагноз'),
(120386, 1034, 33, 'Натисніть для додавання нових компонентів'),
(120387, 1035, 33, 'Клацніть для додавання нової консультації'),
(120388, 1037, 33, 'Натисніть для завантаження'),
(120389, 1038, 33, 'Натисніть для редагування'),
(120390, 1039, 33, 'Натисніть для редагування опису'),
(120391, 1040, 33, 'Клацніть для зміни цієї події'),
(120392, 1041, 33, 'Натисніть щоб генерувати звіт'),
(120393, 1043, 33, 'Натисніть для друку'),
(120394, 1044, 33, 'Клацніть для отримання (додавання) нової партії'),
(120395, 1045, 33, 'Натисніть для вибору'),
(120396, 1046, 33, 'Натисніть для вибору'),
(120397, 1047, 33, 'Натисніть для вибору стандартного коду для цієї процедури'),
(120398, 1048, 33, 'Натисніть для вибору опціонального коду процедури'),
(120399, 1050, 33, 'Натисніть для вибору або зміни коду вакцинації'),
(120400, 1051, 33, 'Натисніть для вибору або зміни діагнозу'),
(120401, 1052, 33, 'Натисніть для вибору або зміни кодів послуг'),
(120402, 1053, 33, 'Натисніть для вибору пацієнта'),
(120403, 1054, 33, 'Натисніть для вибору пов''язаного коду'),
(120404, 1055, 33, 'Якщо цей результат дає відхилення від норми, клацніть для вибору надання допомоги'),
(120405, 1056, 33, 'Клацніть для вибору необхідної процедури'),
(120406, 1057, 33, 'Натисніть для сортування'),
(120407, 1058, 33, 'Натисніть для перегляду'),
(120408, 1059, 33, 'Натисніть для перегляду або зміни'),
(120409, 1060, 33, 'Натисніть для перегляду / зміни'),
(120410, 1061, 33, 'Натисніть кнопку Модернізувати для модернізації версії бази даних з вказаної дати'),
(120411, 1063, 33, 'Натисніть:'),
(120412, 1064, 33, 'Термін дії Сертифіката Клієнта в днях'),
(120413, 1065, 33, 'Допустимий період терміну дії Сертифіката клієнта'),
(120414, 1066, 33, 'Дійсний Сертифіката клієнта повиненн бути допустимим номером.'),
(120415, 1067, 33, 'Копія для клієнта'),
(120416, 1069, 33, 'Виписка з історії хвороби пацієнта'),
(120417, 1070, 33, 'Ім''я клієнта'),
(120418, 1071, 33, 'Номер клієнта'),
(120419, 1072, 33, 'Клієнтський профіль - нові клієнти'),
(120420, 1073, 33, 'Клієнтський профіль - унікальні клієнти'),
(120421, 1074, 33, 'Клієнти'),
(120422, 1075, 33, 'Клініка'),
(120423, 1076, 33, 'Копія для клініки'),
(120424, 1077, 33, 'Щоденні записи в клініці'),
(120425, 1078, 33, 'ID клініки'),
(120426, 1079, 33, 'Клінічний'),
(120427, 1080, 33, 'Менеджер тривожних сповіщень для клінічних правил'),
(120428, 1081, 33, 'Історія хвороби'),
(120429, 1083, 33, 'Клінічні програми'),
(120430, 1084, 33, 'Клінічна одиниця вимірювання якості (CQM)'),
(120431, 1087, 33, 'Клінічні нагадування'),
(120432, 1088, 33, 'Клінічні звіти'),
(120433, 1089, 33, 'Категорія діяльності для клінічних правил'),
(120434, 1090, 33, 'О"бєкт впливу для клінічних правил'),
(120435, 1091, 33, 'Методи фільтрації для клінічних правил'),
(120436, 1092, 33, 'Цільові методи для клінічних правил'),
(120437, 1093, 33, 'Клінічні правила'),
(120438, 1094, 33, 'Вікові інтревали для клінічних правил'),
(120439, 1095, 33, 'Порівняння для клінічних правил'),
(120440, 1096, 33, 'Типи звертань для клінічних правил'),
(120441, 1097, 33, 'Клінічні правила варіантів виконання нагадування'),
(120442, 1098, 33, 'Варіанти зняття нагадувань для клінічних правил'),
(120443, 1099, 33, 'Методи нагадувагь для клінічних правил'),
(120444, 1100, 33, 'Методи нагадувань для клінічних правил'),
(120445, 1101, 33, 'Плановані інтервали для клінічних правил'),
(120446, 1102, 33, 'Клінічні цілі'),
(120447, 1103, 33, 'Клінічний темін'),
(120448, 1104, 33, 'Код(и) клінічного терміну'),
(120449, 1106, 33, 'Клініцисти'),
(120450, 1107, 33, 'клонувати'),
(120451, 1108, 33, 'Клонувати минуле відвідування'),
(120452, 1109, 33, 'Закрити'),
(120453, 1111, 33, 'закрити вікно'),
(120454, 1112, 33, 'Закритий'),
(120455, 1113, 33, 'см'),
(120456, 1114, 33, 'Поля CMS 1500'),
(120457, 1118, 33, 'ID для CMS'),
(120458, 1127, 33, 'Неушкоджений CN2-12'),
(120459, 1128, 33, 'Доплата'),
(120460, 1129, 33, 'Доплату внесено'),
(120461, 1130, 33, 'ДОПЛАТА'),
(120462, 1131, 33, 'Код'),
(120463, 1132, 33, 'код'),
(120464, 1133, 33, 'Пошук коду'),
(120465, 1134, 33, 'Код повинен мати дві літери в нижньому регістрі'),
(120466, 1135, 33, 'Код або символ для позначення валюти'),
(120467, 1136, 33, 'Текст Коду'),
(120468, 1138, 33, 'тип коду'),
(120469, 1141, 33, 'Типи Кодів'),
(120470, 1142, 33, 'Код(и)'),
(120471, 1143, 33, 'Кодовано'),
(120472, 1144, 33, 'Коди'),
(120473, 1145, 33, 'Індексація'),
(120474, 1147, 33, 'Індексація - будь-які звернення (на вибір - право записувати все/частково)'),
(120475, 1148, 33, 'Індексація - мої звернення (на вибір - право записувати все/частково)'),
(120476, 1149, 33, 'Доступ до шифрування не дозволено'),
(120477, 1150, 33, 'Кава'),
(120478, 1152, 33, 'Спільне страхування'),
(120479, 1153, 33, 'Згорнути'),
(120480, 1154, 33, 'Згорнути'),
(120481, 1155, 33, 'приховати'),
(120482, 1156, 33, 'Згорнути Все'),
(120483, 1157, 33, 'Згорнути все'),
(120484, 1158, 33, 'згорнути всі'),
(120485, 1160, 33, 'Дата збору'),
(120486, 1161, 33, 'Збори'),
(120487, 1162, 33, 'Звіт за зборами'),
(120488, 1163, 33, 'Рак товстого кишечника'),
(120489, 1164, 33, 'Скринінг раку товстого кишечника'),
(120490, 1165, 33, 'Хірургія раку товстого кишечника'),
(120491, 1166, 33, 'Колоноскопія'),
(120492, 1167, 33, 'колоноскопія'),
(120493, 1168, 33, 'колір'),
(120494, 1169, 33, 'Колір: скор.'),
(120495, 1170, 33, 'стовпець'),
(120496, 1171, 33, 'стовпці'),
(120497, 1172, 33, 'Об''єднані партії'),
(120498, 1173, 33, 'кома'),
(120499, 1174, 33, 'Коментар'),
(120500, 1175, 33, 'Коментарі'),
(120501, 1176, 33, 'Коментарі для цього результату або рекомендації'),
(120502, 1177, 33, 'Компанія комерційного страхування.'),
(120503, 1178, 33, 'завершені зміни'),
(120504, 1180, 33, 'зв''язок'),
(120505, 1182, 33, 'компанія'),
(120506, 1183, 33, 'Найменування компанії'),
(120507, 1184, 33, 'завершити'),
(120508, 1186, 33, 'завершене'),
(120509, 1188, 33, 'Завершене?'),
(120510, 1190, 33, 'Ускладнення по спеціалістах, що надають послуги'),
(120511, 1191, 33, 'Ускладнення аборту'),
(120512, 1192, 33, 'Компоненти'),
(120513, 1193, 33, 'Автоматизована система медичних призначень'),
(120514, 1194, 33, 'Висновки'),
(120515, 1199, 33, 'Налаштування'),
(120516, 1200, 33, 'Налаштування експорту / імпорту'),
(120517, 1202, 33, 'Налаштувати Apache і LibreEHR для використання сертифікатів SSL клієнта.'),
(120518, 1203, 33, 'Налаштувати Apache для використання сертифікатів SSL на стороні клієнта'),
(120519, 1204, 33, 'Налаштувати Apache для використання HTTPS.'),
(120520, 1205, 33, 'Налаштувати LibreEHR для використання сертифікатів SSL клієнта.'),
(120521, 1208, 33, 'Підтвердіть реєстрацію нового пацієнта'),
(120522, 1209, 33, 'Підтвердіть новий пароль'),
(120523, 1210, 33, 'Підтвердіть оплату'),
(120524, 1214, 33, 'Вроджений'),
(120525, 1215, 33, 'Коньюктива, зіниці'),
(120526, 1217, 33, 'Конектор'),
(120527, 1218, 33, 'Константа'),
(120528, 1219, 33, 'найменування константи'),
(120529, 1220, 33, 'Найменування константи пусте'),
(120530, 1221, 33, 'константи'),
(120531, 1222, 33, 'Закреп'),
(120532, 1223, 33, 'Загальносистемне'),
(120533, 1226, 33, 'Короткий опис консультації'),
(120534, 1227, 33, 'Контакт'),
(120535, 1228, 33, 'Контактний e-mail'),
(120536, 1229, 33, 'Контактна адреса e-mail'),
(120537, 1230, 33, 'Зв''язатися з EMR Direct для підписки на службу повідомлень phiMail Direct'),
(120538, 1231, 33, 'контактна іформація'),
(120539, 1232, 33, 'Контактні лінзи'),
(120540, 1233, 33, 'Зв''язатися з Medical Information Integration, LLC на http://mi-squared.com для служби Lab Exchange.');
INSERT INTO `lang_definitions` VALUES
(120541, 1234, 33, 'Зв''язатися з Medical Information Integration, LLC на http://mi-squared.com чи ZH Healthcare на http://zhservices.com для підписки на службу eRx'),
(120542, 1236, 33, 'контактна особа'),
(120543, 1237, 33, 'Контактна особа'),
(120544, 1239, 33, 'Контактний номер телефону'),
(120545, 1240, 33, 'Зверніться на ZMG, LLC (zmghealth@gmail.com) для підписки на послугу eRx'),
(120546, 1241, 33, 'містить, принаймні, три з чотирьох наступних пунктів:'),
(120547, 1242, 33, 'Ім''я Контейнеру-Групи'),
(120548, 1243, 33, 'Зміст'),
(120549, 1244, 33, 'зміст'),
(120550, 1245, 33, 'Контекст'),
(120551, 1246, 33, 'Найменування контексту не може бути порожнім'),
(120552, 1247, 33, 'Тривати'),
(120553, 1248, 33, 'Стандартизований медичний документ (HL7 CCD)'),
(120554, 1249, 33, 'Стандартизований медичний запис (HL7 CCR)'),
(120555, 1250, 33, 'Взаємні клієнти'),
(120556, 1251, 33, 'Контрацепція'),
(120557, 1252, 33, 'Аспекти контрацепції'),
(120558, 1253, 33, 'Ускладнення контрацепції (вказати)'),
(120559, 1254, 33, 'Спосіб контрацепції'),
(120560, 1255, 33, 'Контрацептивні вироби'),
(120561, 1256, 33, 'Попередньо розпочаті послуги з контрацепції'),
(120562, 1257, 33, 'Початок контрацепції'),
(120563, 1258, 33, 'Контрольний ID'),
(120564, 1259, 33, 'Контрольнийномер'),
(120565, 1261, 33, 'ДОПЛАТА'),
(120566, 1262, 33, 'Доплата'),
(120567, 1263, 33, 'Доплата'),
(120568, 1264, 33, 'Доплата не передбачається'),
(120569, 1266, 33, 'Доплати'),
(120570, 1267, 33, 'ХОЗЛ'),
(120571, 1268, 33, 'Копіювати сторінки в карту пацієнта'),
(120572, 1269, 33, 'Копіювати значення'),
(120573, 1270, 33, 'Копіювання файлу бази даних. Це займе деякий час ...'),
(120574, 1271, 33, 'Повідомлення про авторські права'),
(120575, 1273, 33, 'Коронарне шунтування'),
(120576, 1274, 33, 'Коронарне шунтування трансплантатом'),
(120577, 1275, 33, 'Виправлене'),
(120578, 1277, 33, 'CouchDB'),
(120579, 1278, 33, 'CouchDB Збій підключення'),
(120580, 1279, 33, 'CouchDB База даних'),
(120581, 1280, 33, 'CouchDB ім''я бази даних'),
(120582, 1281, 33, 'CouchDB хост'),
(120583, 1282, 33, 'CouchDB ім''я хоста'),
(120584, 1283, 33, 'CouchDB логи увімкнено'),
(120585, 1284, 33, 'CouchDB пароль'),
(120586, 1285, 33, 'CouchDB порт'),
(120587, 1286, 33, 'CouchDB порт'),
(120588, 1288, 33, 'CouchDB ім''я користувача'),
(120589, 1289, 33, 'Кашель'),
(120590, 1290, 33, 'Кашель:'),
(120591, 1294, 33, 'Не вдалося прочитати файл'),
(120592, 1296, 33, 'Не вдалося відправити email через проблеми сервера, '),
(120593, 1297, 33, 'Не вдалося відправити email через проблеми сервера. '),
(120594, 1298, 33, 'Не вдалося створити директорію резервного копіювання:'),
(120595, 1299, 33, 'Не вдалося видалити директорію:'),
(120596, 1300, 33, 'Не вдалося видалити старий файл резервного копіювання:'),
(120597, 1301, 33, 'Не вдалося видалити старий файл експорту:'),
(120598, 1302, 33, 'Менеджмент Кумадіна - контроль міжнародного нормалізаційного індексу'),
(120599, 1303, 33, 'Реком. за способом'),
(120600, 1304, 33, 'Консультування'),
(120601, 1305, 33, 'Консультативна робота'),
(120602, 1306, 33, 'ОБЛІКОВА ФОРМА НАПРАВЛЕННЯ'),
(120603, 1307, 33, 'Обліковий направлення'),
(120604, 1308, 33, 'Країна'),
(120605, 1309, 33, 'Тип даних по країні'),
(120606, 1310, 33, 'Список країн'),
(120607, 1311, 33, 'Список країн (на вибір - право записувати все/частково)'),
(120608, 1312, 33, 'Найменування країни має бути представлено двома буквами. (Наприклад: Сполучені штати позначено US)'),
(120609, 1313, 33, 'країна'),
(120610, 1315, 33, 'Купон'),
(120611, 1318, 33, 'Клінічне обстеження хворого (КОХ)'),
(120612, 1319, 33, 'Код (КОХ)'),
(120613, 1320, 33, 'Коди (КОХ)'),
(120614, 1321, 33, 'КОХ4 Процедури/Послуги'),
(120615, 1322, 33, 'КОХІІ вимірювання продуктивності'),
(120616, 1323, 33, 'Безперервне управління якістю (CQM)'),
(120617, 1324, 33, 'Вологі хрипи:'),
(120618, 1325, 33, 'крем'),
(120619, 1326, 33, 'Створити сертифікат SSL клієнта для кожного користувача або клієнтської машини.'),
(120620, 1327, 33, 'Створити сертифікат SSL клієнта або для користувача, або для імені клієнта.'),
(120621, 1329, 33, 'Створити подію'),
(120622, 1330, 33, 'Створити і завантажити повну резервну копію'),
(120623, 1332, 33, 'Створити резервну копію'),
(120624, 1333, 33, 'Створити партію'),
(120625, 1334, 33, 'Створити клієнтський сертифікат'),
(120626, 1335, 33, 'Створити сертифікати SSL на стороні клієнта.'),
(120627, 1336, 33, 'Створити дублікат'),
(120628, 1338, 33, 'Створити резервне копіювання журналу подій'),
(120629, 1339, 33, 'Створити нову проблему'),
(120630, 1340, 33, 'Оформити нового пацієнта'),
(120631, 1342, 33, 'Створити повноваження для зовнішнього порталу'),
(120632, 1343, 33, 'Створити повноваження для внутрішнього порталу'),
(120633, 1344, 33, 'Створити запис по пацієнтові'),
(120634, 1345, 33, 'Створює довірений сертифікат SSL і сертифікати сервера.'),
(120635, 1346, 33, 'Створити відвідування'),
(120636, 1347, 33, 'Створено'),
(120637, 1348, 33, 'Створення файлу експорту'),
(120638, 1350, 33, 'Збій створення цього файлу на віддаленому хості'),
(120639, 1351, 33, 'Творець'),
(120640, 1352, 33, 'кредит'),
(120641, 1353, 33, 'Кредитна карта'),
(120642, 1354, 33, 'Кредити'),
(120643, 1356, 33, 'Критерій'),
(120644, 1358, 33, 'Хвороба Крона'),
(120645, 1359, 33, 'Хвороба Крона'),
(120646, 1360, 33, 'Експорт CSV'),
(120647, 1361, 33, 'файл CSV'),
(120648, 1362, 33, 'таблиці CSV'),
(120649, 1363, 33, 'куб.мм'),
(120650, 1364, 33, 'Кубинець'),
(120651, 1365, 33, 'Розміщення десяткового знаку для валюти'),
(120652, 1366, 33, 'Символ десяткового знаку для валюти'),
(120653, 1367, 33, 'грошовий визначник'),
(120654, 1368, 33, 'Роздільник тисячної валюти'),
(120655, 1369, 33, 'Поточне'),
(120656, 1370, 33, 'Поточне вживання алкоголю'),
(120657, 1371, 33, 'Поточна констультація'),
(120658, 1372, 33, 'Поточний критерій'),
(120659, 1373, 33, 'Колір виділення поточного дня'),
(120660, 1374, 33, 'Палить кожного дня на даний час'),
(120661, 1375, 33, 'Поточне ім''я файлу було змінено на'),
(120662, 1376, 33, 'Поточний хеш'),
(120663, 1377, 33, 'Поточне місце перебування'),
(120664, 1378, 33, 'поточні препарати'),
(120665, 1379, 33, 'Поточний пароль'),
(120666, 1380, 33, 'Поточний пацієнт'),
(120667, 1382, 33, 'Поточні рекреаційні наркотики'),
(120668, 1383, 33, 'Палить не кожен день на даний час'),
(120669, 1386, 33, 'Активний на даний час'),
(120670, 1387, 33, 'В даний час виконується'),
(120671, 1388, 33, 'В даний час допомога не надається'),
(120672, 1389, 33, 'синдром Кушинга'),
(120673, 1390, 33, 'синдром Кушинга'),
(120674, 1392, 33, 'Користувальницький'),
(120675, 1393, 33, 'Користувальницький ввід?'),
(120676, 1394, 33, 'Користувальницька таблиця'),
(120677, 1396, 33, 'Код вакцинації (CVX)'),
(120678, 1397, 33, 'Відображення коду вакцинації (CVX)'),
(120679, 1398, 33, 'CVX вакцинація'),
(120680, 1399, 33, 'Цикл'),
(120681, 1400, 33, 'Цитохром P450'),
(120682, 1401, 33, 'Фактор цитохрому P450'),
(120683, 1402, 33, 'Повідомлення про цитохром P450'),
(120684, 1403, 33, 'Чеська'),
(120685, 1404, 33, 'Дата'),
(120686, 1405, 33, 'Розширення та кюретаж'),
(120687, 1406, 33, 'Дієта та фізичне навантаження'),
(120688, 1407, 33, 'Дата нар.'),
(120689, 1408, 33, 'щоденно'),
(120690, 1409, 33, 'Щоденний запис'),
(120691, 1410, 33, 'Данська'),
(120692, 1411, 33, 'Подібні дані вже є в базі даних, змініть код і / або опис'),
(120693, 1412, 33, 'Подібні дані вже є в базі даних, змініть ім''я константи'),
(120694, 1413, 33, 'Стовп. даних'),
(120695, 1416, 33, 'Помилка в даних'),
(120696, 1420, 33, 'Тип даних'),
(120697, 1421, 33, 'База даних'),
(120698, 1422, 33, 'База даних не встановлена.'),
(120699, 1423, 33, 'Виправлення бази даних'),
(120700, 1424, 33, 'Звіти бази даних'),
(120701, 1425, 33, 'Оновлення бази даних завершено.'),
(120702, 1426, 33, 'Стовпці даних повинні бути числом між 1 і 999'),
(120703, 1427, 33, 'Дата'),
(120704, 1428, 33, 'ДАТА'),
(120705, 1429, 33, 'Керовані дата і час'),
(120706, 1431, 33, 'Керована дата'),
(120707, 1432, 33, 'Дата і час взяття зразка'),
(120708, 1433, 33, 'Дата і час цього спостереження'),
(120709, 1435, 33, 'Дата і час, коли біовзірець був зібраний'),
(120710, 1436, 33, 'Дата не може бути дальшою ніж сьогоднішня'),
(120711, 1437, 33, 'Дата спочатку наданої послуги по контрацепції'),
(120712, 1438, 33, 'Дата створення'),
(120713, 1439, 33, 'Дата смерті'),
(120714, 1440, 33, 'Дата знищення'),
(120715, 1441, 33, 'Формат відображення дати'),
(120716, 1442, 33, 'Формат дати для "Закінчення прийому" не допустимий'),
(120717, 1443, 33, 'Формат дати для "Початок прийому" не допустимий'),
(120718, 1444, 33, 'Формат дати для "Наступний прийом" не допустимий'),
(120719, 1445, 33, 'Формат дати для "не бачив з" не допустимий'),
(120720, 1446, 33, 'Формат дати для "з тих пір бачив" не допустимий'),
(120721, 1447, 33, 'Надані інформаційні заявки про дату проведення вакцинації'),
(120722, 1448, 33, 'Дата для коду пропущена '),
(120723, 1449, 33, 'Основний критерій дати'),
(120724, 1450, 33, 'Дата банківського внеску рррр-мм-дд'),
(120725, 1451, 33, 'Дата рахунку'),
(120726, 1452, 33, 'Дата народження'),
(120727, 1453, 33, 'Дата народження'),
(120728, 1454, 33, 'Дата народження'),
(120729, 1455, 33, 'Дата поступлення'),
(120730, 1456, 33, 'Дата травми'),
(120731, 1458, 33, 'Дата оплати рррр-мм-дд'),
(120732, 1459, 33, 'Дата направлення'),
(120733, 1460, 33, 'Дата відповіді'),
(120734, 1461, 33, 'Дата звіту'),
(120735, 1462, 33, 'Дата послуги'),
(120736, 1463, 33, 'Дата послуги'),
(120737, 1464, 33, 'Дата послуги = сьогодні'),
(120738, 1465, 33, 'Дата послуги мм / дд / рррр'),
(120739, 1466, 33, 'Дата послуги:'),
(120740, 1467, 33, 'Дата підписання'),
(120741, 1468, 33, 'Дата зіни статусу'),
(120742, 1469, 33, 'Дата цього призначення'),
(120743, 1470, 33, 'Дата цього звіту'),
(120744, 1471, 33, 'Дата заявки по видимому набору інформації'),
(120745, 1472, 33, 'Призначена дати'),
(120746, 1475, 33, 'селектор дати'),
(120747, 1476, 33, 'Дата відправлення'),
(120748, 1477, 33, 'Дата коли повідомлення було вислане'),
(120749, 1479, 33, 'Значення дати не може бути порожнім.'),
(120750, 1480, 33, 'Дата / призн.'),
(120751, 1481, 33, 'Дата / запису'),
(120752, 1482, 33, 'Остання дата або записи'),
(120753, 1483, 33, 'Дата / час'),
(120754, 1484, 33, 'Дата:'),
(120755, 1485, 33, 'датовані повідомлення журналу'),
(120756, 1486, 33, 'День'),
(120757, 1487, 33, 'день'),
(120758, 1489, 33, 'Огляд за день'),
(120759, 1490, 33, 'Днів'),
(120760, 1491, 33, 'Дні Пн-Пт'),
(120761, 1492, 33, 'дні'),
(120762, 1493, 33, 'Дні'),
(120763, 1494, 33, 'днів тому'),
(120764, 1495, 33, 'Дні і проекти пропущені'),
(120765, 1496, 33, 'Днів від останнього звернення'),
(120766, 1497, 33, 'пропущені дні'),
(120767, 1498, 33, 'Днів в стовпці:'),
(120768, 1500, 33, 'Дні / стовп.:'),
(120769, 1501, 33, 'БД встановлена'),
(120770, 1502, 33, 'ДД-ММ-РРРР'),
(120771, 1503, 33, 'Деідентифікація'),
(120772, 1504, 33, 'Процес деідентифікації завершений'),
(120773, 1505, 33, 'Триває обробка деідентіфікаціі'),
(120774, 1506, 33, 'Обробка деідентіфікаціі запущена і йде у фоновому режимі'),
(120775, 1507, 33, 'Дані деідентіфікаціі не можуть бути виконані'),
(120776, 1508, 33, 'Файли деідентіфікаціі будуть збережені в'),
(120777, 1509, 33, 'Управління з контролю за поширенням наркотиків'),
(120778, 1511, 33, 'Глухий'),
(120779, 1512, 33, 'Відлагоджувальна інформація'),
(120780, 1514, 33, 'Відлагодження'),
(120781, 1515, 33, 'Грудень'),
(120782, 1516, 33, 'ПОМЕРЛІ'),
(120783, 1517, 33, 'Грудень'),
(120784, 1518, 33, 'Десятки фунтів або фунтів і унцій, розділених # (наприклад, 5 # 4)'),
(120785, 1520, 33, 'Відрахування'),
(120786, 1521, 33, 'Виконання відрахувань'),
(120787, 1522, 33, 'За замовчуванням'),
(120788, 1523, 33, 'Вид календаря за замовчуванням'),
(120789, 1524, 33, 'ID форми звернення за замовчуванням'),
(120790, 1526, 33, 'Послуга за замовчуванням'),
(120791, 1527, 33, 'Мова за замовчуванням'),
(120792, 1528, 33, 'Мова за замовчуванням якщо іншої не дозволено або не вибрано.'),
(120793, 1529, 33, 'Список за замовчуванням (на вибір - право записувати/добавляти)'),
(120794, 1530, 33, 'Метод за замовчуванням'),
(120795, 1531, 33, 'Закінчення строку дії пароля за замовчуванням.'),
(120796, 1532, 33, 'Закінчення строку дії пароля в днях за замовчуванням. 0 означає, що ця функція відключена.'),
(120797, 1533, 33, 'Країна пацієнта за замовчуванням'),
(120798, 1535, 33, 'Пріоритет за замовчуванням'),
(120799, 1536, 33, 'Спеціаліст по замовчуванню'),
(120800, 1537, 33, 'Діапазон за замовчуванням'),
(120801, 1538, 33, 'Причина відвідування за замовчуванням'),
(120802, 1540, 33, 'Налаштування за замовчуванням'),
(120803, 1541, 33, 'Стан за замовчуванням прапорців в списку пацієнтів для нового вікна'),
(120804, 1542, 33, 'Шаблон за замовчуванням'),
(120805, 1546, 33, 'Одиниці виміру за замовчуванням'),
(120806, 1547, 33, 'Значення за замовчуванням'),
(120807, 1548, 33, 'Склад за замовчуванням'),
(120808, 1549, 33, 'Партнер X12 за замовчуванням'),
(120809, 1550, 33, 'За замовчуванням / глобально'),
(120810, 1551, 33, 'Видалити'),
(120811, 1552, 33, 'видалити'),
(120812, 1553, 33, 'Затримка повторення (> 12 міс.)'),
(120813, 1554, 33, 'Видалити'),
(120814, 1555, 33, 'видалити'),
(120815, 1556, 33, 'Видалити категорії з ID: '),
(120816, 1557, 33, 'Видалити категорію'),
(120817, 1559, 33, 'Збій видалення!'),
(120818, 1560, 33, 'Видалити групу'),
(120819, 1561, 33, 'Видалити список'),
(120820, 1562, 33, 'Видалити сторінки'),
(120821, 1563, 33, 'Видалити пацієнта, звернення, форму, проблему, документ, оплату, рахунок або транзакцію'),
(120822, 1565, 33, 'Видалити рядок'),
(120823, 1566, 33, 'Видалити вибрані пункти'),
(120824, 1568, 33, 'Видалення завершено.'),
(120825, 1569, 33, 'Видалити цей документ'),
(120826, 1570, 33, 'Видалити цю форму'),
(120827, 1571, 33, 'Видалити цей запис'),
(120828, 1573, 33, 'Видалення успішно виконано.'),
(120829, 1574, 33, 'Видалення'),
(120830, 1575, 33, 'Видалення цієї події не може бути відмінено. Відновлення буде неможливим після завершення. Ви дійсно хочете видалити цю подію?'),
(120831, 1576, 33, 'Доставку підтверджено'),
(120832, 1578, 33, 'В даний час не допускається доставка до зазначеного Direct Address.'),
(120833, 1580, 33, 'Паієнт зробив запит на доставку приєднаного клінічного документу'),
(120834, 1581, 33, 'Деменція'),
(120835, 1582, 33, 'Персональні дані'),
(120836, 1583, 33, 'Персональні дані (на вибір - право записувати/добавляти)'),
(120837, 1585, 33, 'Критерій відбору персональних даних'),
(120838, 1586, 33, 'Немає дозволу на доступ до персональних даних'),
(120839, 1587, 33, 'Немає дозволу на доступ до персональних даних.'),
(120840, 1588, 33, 'Заборонено'),
(120841, 1589, 33, 'Знаменник'),
(120842, 1590, 33, 'Стоматологічний'),
(120843, 1591, 33, 'Перелік стоматологічних проблем'),
(120844, 1592, 33, 'Стоматологічні проблеми'),
(120845, 1595, 33, 'При перевірці вимоги X 12, в залежності від типу, рахунки HCFA будуть виглядати як вивід порожньої сторінки, побачите багато рядків з дещо спотвореним текстом та інформацією. Цей спотворений текст є форматом X 12 EDI 4010A. Іноді будете бачити дивні символи, які виглядають як доміно або хвилясто, це керуючі символи, такі як подача сторінки і є звичайними.'),
(120846, 1596, 33, 'Дата внесення'),
(120847, 1597, 33, 'Дата внесення не може бути пізніше сьогоднішньої'),
(120848, 1598, 33, 'Дата внесення:'),
(120849, 1599, 33, 'Пригнічений'),
(120850, 1600, 33, 'Депресія'),
(120851, 1602, 33, 'Опис'),
(120852, 1603, 33, 'опис'),
(120853, 1605, 33, 'Опис публікації'),
(120854, 1606, 33, 'Опис цієї методики або код результату'),
(120855, 1607, 33, 'Переклад опису'),
(120856, 1609, 33, 'Місце призначення'),
(120857, 1610, 33, 'Призначене ім''я файлу'),
(120858, 1611, 33, 'Знищити партію'),
(120859, 1612, 33, 'Знищити ...'),
(120860, 1613, 33, 'Знищений'),
(120861, 1614, 33, 'Знищені препарати'),
(120862, 1615, 33, 'Звіт по знищенню препаратів'),
(120863, 1616, 33, 'Подробиця'),
(120864, 1617, 33, 'Подробиці'),
(120865, 1619, 33, 'Прогресуюче відхилення від норми'),
(120866, 1620, 33, 'Діабет'),
(120867, 1621, 33, 'Цукровий діабет'),
(120868, 1622, 33, 'Діабет: контроль артеріального тиску'),
(120869, 1623, 33, 'Діабет: офтальмологічне дослідження'),
(120870, 1624, 33, 'Діабет: офтальмологічне дослідження'),
(120871, 1625, 33, 'Діабет: дослідження стоп'),
(120872, 1626, 33, 'Діабет: дослідження стоп'),
(120873, 1627, 33, 'Діабет: нагляд за бідними HbA1c'),
(120874, 1628, 33, 'Діабет: гемоглобін A1C'),
(120875, 1629, 33, 'Діабет: контроль ліпопротеїну низької щільності'),
(120876, 1630, 33, 'Діабет: мікроальбумін сечі'),
(120877, 1631, 33, 'Д-з'),
(120878, 1632, 33, 'Діагнози'),
(120879, 1633, 33, 'Діагноз'),
(120880, 1634, 33, 'Код діагнозу'),
(120881, 1636, 33, 'Дата діагнозу'),
(120882, 1637, 33, 'Для зв"язку з зверненням діагноз повинен мати код'),
(120883, 1638, 33, 'Найменування діагнозу'),
(120884, 1639, 33, 'Звіт про діагноз'),
(120885, 1640, 33, 'Звітність про діагноз'),
(120886, 1641, 33, 'Лише звітність про діагноз'),
(120887, 1642, 33, 'Назва діагнозу'),
(120888, 1643, 33, 'Діагноз:'),
(120889, 1644, 33, 'Діагноз: '),
(120890, 1645, 33, 'Діагностичні тести:'),
(120891, 1646, 33, 'Діаліз'),
(120892, 1647, 33, 'Діафрагми/кришки'),
(120893, 1648, 33, 'Діарея'),
(120894, 1650, 33, 'Диктування'),
(120895, 1651, 33, 'Диктування: '),
(120896, 1652, 33, 'Ви отримали копію повідомлення HIPAA?'),
(120897, 1653, 33, 'Дифундувати:'),
(120898, 1654, 33, 'Цифровий підпис'),
(120899, 1657, 33, 'Direct-пошта'),
(120900, 1658, 33, 'Лог Direct-повідомлень'),
(120901, 1659, 33, 'Отримано Direct-повідомлення'),
(120902, 1660, 33, 'Direct-повідомлення наразі недосяжні.'),
(120903, 1661, 33, 'Збій надсилання Direct-повідомлення'),
(120904, 1663, 33, 'Прізвище керівника'),
(120905, 1664, 33, 'Збій видалення каталога; продовження.'),
(120906, 1665, 33, 'Непрацездатність'),
(120907, 1667, 33, 'Відключити календар'),
(120908, 1668, 33, 'Відключити відстеження карти'),
(120909, 1669, 33, 'Відключити вакцинацію'),
(120910, 1670, 33, 'Відключити стару метричну форму ЖВО'),
(120911, 1672, 33, 'Відключити phpMyAdmin'),
(120912, 1673, 33, 'Вимкнути призначення'),
(120913, 1674, 33, 'Відключити користувальницькі групи'),
(120914, 1675, 33, 'вимкнено'),
(120915, 1676, 33, 'Вимкнено'),
(120916, 1677, 33, 'Вимкнено Отримувачі доходів менше 65 років з планом "здоров"я для великих груп" (LGHP)'),
(120917, 1678, 33, 'Сигнальний комплекс, індукуючий смерть'),
(120918, 1681, 33, 'Виділення'),
(120919, 1682, 33, 'Виділення з уретри'),
(120920, 1684, 33, 'Виділіть правильно'),
(120921, 1685, 33, 'Виділіть правильно:'),
(120922, 1688, 33, 'Виділіть'),
(120923, 1689, 33, 'Опублікована інформація'),
(120924, 1690, 33, 'Тип публікування'),
(120925, 1691, 33, 'Типи публікування'),
(120926, 1692, 33, 'Публікації'),
(120927, 1694, 33, 'Знижка'),
(120928, 1695, 33, 'Розмір знижки'),
(120929, 1696, 33, 'Рівень знижки'),
(120930, 1697, 33, 'Відсоток знижки'),
(120931, 1698, 33, 'Знижка як грошова величина'),
(120932, 1699, 33, 'Знижка на розрахунковий час вводиться як грошова сума, а не відсотки.'),
(120933, 1700, 33, 'Окремий результат'),
(120934, 1701, 33, 'Хвороба'),
(120935, 1702, 33, 'Вивих'),
(120936, 1703, 33, 'Відпр. #'),
(120937, 1704, 33, 'Відправлення'),
(120938, 1705, 33, 'Відправлення отриманого документа'),
(120939, 1706, 33, 'Розподілений'),
(120940, 1707, 33, 'Відображати розширені інструкції на сторінці персональних даних.'),
(120941, 1709, 33, 'Відображати дати подій в блоці?'),
(120942, 1710, 33, 'Формат виводу для системи мір США'),
(120943, 1711, 33, 'Скільки подій відображати?'),
(120944, 1713, 33, 'Відображати розміщення в блоці?'),
(120945, 1714, 33, 'Псевдонім'),
(120946, 1715, 33, 'Відображати календар?'),
(120947, 1718, 33, 'Відображати сьогоднішні події в блоці?'),
(120948, 1719, 33, 'Відображати розділ в блоці?'),
(120949, 1720, 33, 'Відображати майбутні події в блоці?'),
(120950, 1721, 33, 'Показані колонки'),
(120951, 1722, 33, 'Відображення наступної кількості останніх публікацій:'),
(120952, 1723, 33, 'Відображення вказаної кількості останніх записів'),
(120953, 1724, 33, 'Відображення вказаної кількості останніх записів:'),
(120954, 1725, 33, 'Розподіл'),
(120955, 1726, 33, 'Розподіли'),
(120956, 1727, 33, 'Постачальник'),
(120957, 1729, 33, 'Дивертикуліт'),
(120958, 1730, 33, 'Хірургія Дівертікуліта'),
(120959, 1731, 33, 'Дивертикуліт'),
(120960, 1732, 33, 'Хірургія Дівертікуліта'),
(120961, 1733, 33, 'Розлучений'),
(120962, 1734, 33, 'Запаморочення:'),
(120963, 1735, 33, 'Не змінювати'),
(120964, 1737, 33, 'Не показувати алергію завантажену до NewCrop'),
(120965, 1739, 33, 'Не показувати ліки завантажені до NewCrop'),
(120966, 1742, 33, 'Не показувати календар.'),
(120967, 1744, 33, 'Не інвентаризувати і не реалізовувати ніяку продукцію'),
(120968, 1745, 33, 'Не вимагає повноважень для записів про пацієнта'),
(120969, 1746, 33, 'Не реанімувати порядок'),
(120970, 1747, 33, 'не зберігати'),
(120971, 1748, 33, 'не замінювати'),
(120972, 1749, 33, 'нічого не робити'),
(120973, 1751, 33, 'Дійсно потрібно видалити'),
(120974, 1752, 33, 'Дійсно потрібно видалити вибране?'),
(120975, 1753, 33, 'Дійсно потрібно видалити цю групу'),
(120976, 1755, 33, 'Продовжити?'),
(120977, 1756, 33, 'Це потрібно видалити?'),
(120978, 1757, 33, 'Видалити?'),
(120979, 1758, 33, 'Видалити цей запис?'),
(120980, 1759, 33, 'Продовжити додавання нового пацієнта?'),
(120981, 1760, 33, 'Продовжити з новим найменуванням?'),
(120982, 1761, 33, 'Цей запис по вакціінаціі потрібно видалити НАЗАВЖДИ?'),
(120983, 1762, 33, 'Дата / нар.'),
(120984, 1763, 33, 'Дата народження пропущена, при можливості вкажіть'),
(120985, 1764, 33, 'Документи'),
(120986, 1765, 33, 'Лікар'),
(120987, 1766, 33, 'Лікар:'),
(120988, 1767, 33, 'Прізвище та підпис лікаря'),
(120989, 1768, 33, 'Документ'),
(120990, 1769, 33, 'документ'),
(120991, 1770, 33, 'Категорії документа'),
(120992, 1775, 33, 'Документ не може бути переміщений для пацієнта з ID'),
(120993, 1777, 33, 'Дата документа'),
(120994, 1778, 33, 'Дата документа і питання успішно оновлені'),
(120995, 1779, 33, 'ID документу'),
(120996, 1780, 33, 'Документ переміщено в нову категорію'),
(120997, 1781, 33, 'Документ переміщено до пацієнта з ID'),
(120998, 1783, 33, 'Документ пройшов перевірку цілісності.'),
(120999, 1784, 33, 'Метод збереження документу'),
(121000, 1785, 33, 'Документ успішно перейменований.'),
(121001, 1790, 33, 'Збереження документа / зображення'),
(121002, 1791, 33, 'Документи'),
(121003, 1792, 33, 'Документи (на вибір - право записувати/добавляти)'),
(121004, 1794, 33, 'Задишка при фізичному навантаженні'),
(121005, 1796, 33, 'не відповідає PV1 числу звернень'),
(121006, 1797, 33, 'здається, не дійсні'),
(121007, 1798, 33, 'Цей тип допускає пов''язані коди?'),
(121008, 1799, 33, 'Вітчизняний партнер'),
(121009, 1800, 33, 'Не зберігати'),
(121010, 1801, 33, 'Не зберігати'),
(121011, 1802, 33, 'Не зберігати зміни'),
(121012, 1803, 33, 'Готово'),
(121013, 1804, 33, 'Виконано з:'),
(121014, 1805, 33, 'Готово. Тепер буде відправлене ​​завантаження.'),
(121015, 1806, 33, 'Доз.'),
(121016, 1807, 33, 'Дозування'),
(121017, 1809, 33, 'двічі клацніть для редагування'),
(121018, 1810, 33, 'Двоїння в очах'),
(121019, 1811, 33, 'Завантажити'),
(121020, 1814, 33, 'Завантажити в будь-якому разі'),
(121021, 1815, 33, 'Завантажує файл рахунку, вносить в баланс і маркує як оплату'),
(121022, 1817, 33, 'Завантажити сертифікати'),
(121023, 1818, 33, 'Завантажити дані налаштувань'),
(121024, 1820, 33, 'завантажити шифрований файл'),
(121025, 1825, 33, 'Завантажити PDF'),
(121026, 1827, 33, 'Завантажити вибрані заявки'),
(121027, 1828, 33, 'Перевірка лікаря'),
(121028, 1829, 33, 'Відвідування лікаря'),
(121029, 1830, 33, 'Д-р'),
(121030, 1831, 33, 'Препарат для переміщення'),
(121031, 1832, 33, 'Підтікання сечі'),
(121032, 1833, 33, 'Водійські права або державний ID'),
(121033, 1834, 33, 'Препарат'),
(121034, 1835, 33, 'Пошуковик препаратів'),
(121035, 1836, 33, 'Форми препаратів'),
(121036, 1837, 33, 'ID препарату пропущений!'),
(121037, 1838, 33, 'Частота прийому препарату'),
(121038, 1839, 33, 'Облік препарату'),
(121039, 1840, 33, 'Найменування препарату'),
(121040, 1841, 33, 'Спосіб введення препарату'),
(121041, 1845, 33, 'Одиниці виміру препарату'),
(121042, 1846, 33, 'Препарати'),
(121043, 1847, 33, 'Препарати та вироби'),
(121044, 1848, 33, 'Сухість у роті'),
(121045, 1849, 33, 'DSMIV діагноз'),
(121046, 1850, 33, 'Дифтеритичний тетанус 1'),
(121047, 1851, 33, 'Дифтеритичний тетанус 2'),
(121048, 1852, 33, 'Дифтеритичний тетанус 3'),
(121049, 1853, 33, 'Дифтеритичний тетанус 4'),
(121050, 1854, 33, 'Дифтеритичний тетанус 5'),
(121051, 1855, 33, 'АКДС 1'),
(121052, 1856, 33, 'АКДС 2'),
(121053, 1857, 33, 'АКДС 3'),
(121054, 1858, 33, 'АКДС 4'),
(121055, 1859, 33, 'АКДС 5'),
(121056, 1860, 33, 'належний'),
(121057, 1861, 33, 'Дата оплати'),
(121058, 1862, 33, 'Дата оплати мм/дд/рррр або рррр-мм-дд'),
(121059, 1863, 33, 'Дата оплати:'),
(121060, 1864, 33, 'Термін стах.'),
(121061, 1865, 33, 'Термін опл.'),
(121062, 1866, 33, 'Термін дії підходить до завершення'),
(121063, 1867, 33, 'Призначений статус'),
(121064, 1868, 33, 'Оновлення статусу оплати'),
(121065, 1869, 33, 'Формування дампу бази даних LibreEHR'),
(121066, 1870, 33, 'Формування дампу дерева веб-каталогу LibreEHR'),
(121067, 1871, 33, 'Формування дампу бази даних phpGACL'),
(121068, 1872, 33, 'Формування дампу дерева веб-каталогу phpGACL'),
(121069, 1873, 33, 'Формування дампу бази даних регістра SQL'),
(121070, 1874, 33, 'Формування дампу дерева веб-каталогу регістра SQL'),
(121071, 1875, 33, 'Перевірка на дублювання'),
(121072, 1876, 33, 'Дубльований ID в рядку'),
(121073, 1877, 33, 'Дублювання ім’я в рядку'),
(121074, 1878, 33, 'ПОПЕРЕДЖЕННЯ ПРО ДУБЛЮВАННЯ'),
(121075, 1879, 33, 'Тривала довіреність'),
(121076, 1880, 33, 'тривалість'),
(121077, 1881, 33, 'Тривалість'),
(121078, 1882, 33, 'Голландська'),
(121079, 1883, 33, 'Звіт Dx'),
(121080, 1884, 33, 'Дисфагія'),
(121081, 1885, 33, 'Задишка'),
(121082, 1886, 33, 'Розлад сечовипускання'),
(121083, 1888, 33, 'Е-Призначення?'),
(121084, 1889, 33, 'Е-Звіт'),
(121085, 1890, 33, 'e-Rx'),
(121086, 1892, 33, 'Відновлення e-Rx'),
(121087, 1893, 33, 'Кожен одержувач повинен встановити свої поідомлення як завершені'),
(121088, 1894, 33, 'Ранній рецидив (2 міс)'),
(121089, 1895, 33, 'Вуха'),
(121090, 1896, 33, 'ЕКГ'),
(121091, 1897, 33, 'eClaims'),
(121092, 1898, 33, 'Набряк'),
(121093, 1899, 33, 'edi історія'),
(121094, 1900, 33, 'edi історія'),
(121095, 1901, 33, 'Історія EDI (по оплатах) для зберігання та інтерпретації файлів відповідей EDI претензій'),
(121096, 1902, 33, 'Завантаження файлу EDI-271'),
(121097, 1903, 33, 'Завантаження файлу-відповіді EDI-271'),
(121098, 1904, 33, 'Редагувати'),
(121099, 1905, 33, 'редагувати'),
(121100, 1906, 33, 'Редагувати алергії'),
(121101, 1907, 33, 'Редагувати категорії'),
(121102, 1908, 33, 'Редагувати визначення'),
(121103, 1909, 33, 'Редагувати визначення'),
(121104, 1910, 33, 'Редагувати діагнози для'),
(121105, 1911, 33, 'Редагувати пояснення'),
(121106, 1912, 33, 'Редагувати медичні заклади'),
(121107, 1913, 33, 'Редагувати медичний заклад'),
(121108, 1914, 33, 'Редагувати інформацію про медичний заклад'),
(121109, 1915, 33, 'Редагувати інформацію про користувача специфічну для медичного закладу'),
(121110, 1916, 33, 'Редагувати файл в'),
(121111, 1917, 33, 'Редагувати форму'),
(121112, 1918, 33, 'Редагувати глобальні настройки'),
(121113, 1919, 33, 'Редагування не дозволено'),
(121114, 1920, 33, 'Редагувати макет'),
(121115, 1921, 33, 'Редагувати список'),
(121116, 1922, 33, 'Редагувати платіж'),
(121117, 1923, 33, 'Редагувати структуру'),
(121118, 1924, 33, 'Редагувати користувача'),
(121119, 1925, 33, 'Редагувати настройки користувача'),
(121120, 1928, 33, 'Освіта'),
(121121, 1929, 33, 'Дата отримання освіти'),
(121122, 1931, 33, 'ел. ред. * Детальніше див Ліцензію на вільне програмне забезпечення GNU. ** Разом з цією програмою ви повинні були отримати примірник GPL GNU *; Якщо ні, то пишіть у вільному '),
(121123, 1932, 33, 'Фактична дата'),
(121124, 1934, 33, 'ефективність'),
(121125, 1935, 33, 'Ідентифікаційний номер роботодавця'),
(121126, 1936, 33, 'Еякуляції'),
(121127, 1937, 33, 'Лікоть'),
(121128, 1938, 33, 'проблеми ліктя'),
(121129, 1939, 33, 'Електронний'),
(121130, 1942, 33, 'Електронні перекази'),
(121131, 1943, 33, 'Електронні звіти'),
(121132, 1944, 33, 'Придатність'),
(121133, 1945, 33, 'Придатність 270 пакетного запиту'),
(121134, 1946, 33, 'Прийнятність відповіді'),
(121135, 1947, 33, 'Право на статус Вакцини для Дітей для поствленої вакцини'),
(121136, 1948, 33, 'Придатний'),
(121137, 1949, 33, 'e-mail'),
(121138, 1951, 33, 'Адреса e-mail'),
(121139, 1953, 33, 'Адреса електронної пошти відправника для нагадування пацієнта. Відповіді на нагадування пацієнтові будуть відправлені на цю адресу. Важливо використовувати адресу вашої клініки, щоб уникнути збору нагадувань в папці небажаної пошти'),
(121140, 1954, 33, 'Адреса e-mail, якщо є, для отримання адміністративних повідомлень.'),
(121141, 1955, 33, 'Адреса e-mail, якщо є, для отриманняекстрених повідомлень про активацію логінокористувача.'),
(121142, 1956, 33, 'Авторизована Email'),
(121143, 1957, 33, 'E-mail від пакетної обробки'),
(121144, 1958, 33, 'Email сповіщення'),
(121145, 1959, 33, 'Години email сповіщення'),
(121146, 1960, 33, 'Звіт email сповіщення'),
(121147, 1961, 33, 'Надіслати e-mail перед'),
(121148, 1962, 33, 'Відправник e-mail'),
(121149, 1963, 33, 'Відправлення e-mail'),
(121150, 1964, 33, 'Email відправлено до'),
(121151, 1965, 33, 'Тема e-mail'),
(121152, 1966, 33, 'Текст e-mail, вживаються позначення: ***ІМ''Я***, напр. Шановний ***ІМ''Я***'),
(121153, 1967, 33, 'Текст e-mail, вживаються позначення: ***NAME***, напр. Шановний ***NAME***{{Не перекладайте ***NAME*** елемент цієї константи.}}'),
(121154, 1968, 33, 'Метод передачі e-mail'),
(121155, 1969, 33, 'E-mail відправлений за наступними адресами'),
(121156, 1971, 33, 'Екстренний зв"язок'),
(121157, 1972, 33, 'Контактна особа для екстренного зв"язку'),
(121158, 1973, 33, 'Номер телефону для екстреного зв''язку'),
(121159, 1974, 33, 'Екстренна контрацепція'),
(121160, 1975, 33, 'Вхід в систему в надзвичайній ситуації'),
(121161, 1976, 33, 'Обрано надзвичайний вхід в систему ACL. Користувач все ще в активному стані, прохання деактивувати цього користувача та активувати, за необхідності, при надзвичайній ситуації. Для активації або деактивації див. Адміністрування-> Користувачі.'),
(121162, 1977, 33, 'Надзвичайний e-mail активації входу в систему буде задіяний, лише якщо у файлі interface/globals.php задані наступні параметри:'),
(121163, 1978, 33, 'Адреса e-mail надзвичайного входу в систему'),
(121164, 1979, 33, 'Користувач надзвичайного входу в систему може робити все'),
(121165, 1980, 33, 'Екстренний телефон'),
(121166, 1981, 33, 'Емоційні / поведінкові умови і ускладнення'),
(121167, 1982, 33, 'Емфізема'),
(121168, 1983, 33, 'Службовець'),
(121169, 1984, 33, 'Роботодавець'),
(121170, 1985, 33, 'Адреса роботодавця'),
(121171, 1986, 33, 'Дата прийому на роботу'),
(121172, 1987, 33, 'Ім"я роботодавця'),
(121173, 1988, 33, 'ПОРОЖНЬО'),
(121174, 1989, 33, 'Пусте'),
(121175, 1990, 33, 'Порожній пароль не дозволений'),
(121176, 1991, 33, 'Пусте значення в "Час e-mail"'),
(121177, 1992, 33, 'Пусте значення в "Відправник e-mail"'),
(121178, 1993, 33, 'Пусте значення в "Тема e-mail"'),
(121179, 1994, 33, 'Пусте значення в "Текст e-mail"'),
(121180, 1995, 33, 'Пусте значення для "Прізвище фахівця"'),
(121181, 1996, 33, 'Пусте значення в "Пароль"'),
(121182, 1997, 33, 'Пусте значення в "Час SMS"'),
(121183, 1998, 33, 'Пусте значення в "Текст SMS"'),
(121184, 1999, 33, 'Пусте значення для "Ім''я користувача"'),
(121185, 2006, 33, 'Увімкнути виклик AMC'),
(121186, 2008, 33, 'Увімкнути звіт AMC'),
(121187, 2009, 33, 'Увімкнути відстеження AMC'),
(121188, 2011, 33, 'Увімкнути аудит ATNA'),
(121189, 2013, 33, 'Увімкнути аудит запису інформації'),
(121190, 2014, 33, 'Увімкнути відстеження аудиту та ідентифікації приладу (ATNA).'),
(121191, 2015, 33, 'Увімкнути звітність автоматичного обчислення одиниці виміру (AMC)'),
(121192, 2016, 33, 'Увімкнути сертифікат клієнта SSL'),
(121193, 2017, 33, 'Вмикає ідентифікацію сертифіката SSL для клієнта.'),
(121194, 2019, 33, 'Увімкнути клінічні правила висновків (CDR)'),
(121195, 2022, 33, 'Увімкнути звітністність про клінічну оцінку якості (CQM)'),
(121196, 2023, 33, 'Увімкнути спливаючі клінічні нагадування'),
(121197, 2024, 33, 'Увімкнути міні-додаток для клінічних нагадувань'),
(121198, 2027, 33, 'Увімкнути звітністність про клінічну оцінку якості (CQM)'),
(121199, 2028, 33, 'Увімкнути EDI історію в меню зліва'),
(121200, 2030, 33, 'Увімкнути оплати в лівому меню'),
(121201, 2031, 33, 'Увімкнути підтримку Hylafax'),
(121202, 2033, 33, 'Увімкнути імпорт статусного повідомлення для NewCrop ERX'),
(121203, 2037, 33, 'Увімкнути лабораторний обмін'),
(121204, 2039, 33, 'Увімкнути журнал завантаження/вивантаження документів для CouchDB'),
(121205, 2040, 33, 'Увімкнути журнал всіх запитів SELECT SQL.'),
(121206, 2041, 33, 'Увімкнути журнал активності, пов''язаної з резервним копіюванням.'),
(121207, 2042, 33, 'Увімкнути журнал запитів CDR Engine.'''),
(121208, 2043, 33, 'Увімкнути журнал змішаної активності.'),
(121209, 2044, 33, 'Увімкнути журнал активності призначень.'),
(121210, 2045, 33, 'Увімкнути журнал модифікацій записів про пацієнтів.'),
(121211, 2046, 33, 'Увімкнути журнал активності планування.'),
(121212, 2047, 33, 'Увімкнути журнал активності безпеки і адміністрування.'),
(121213, 2049, 33, 'Увімкнути службу NewCrop eRx'),
(121214, 2051, 33, 'Увімкнути портал для зовнішніх пацієнтів'),
(121215, 2052, 33, 'Увімкнути портал для зовнішніх пацієнтів.'),
(121216, 2053, 33, 'Увімкнути портал для внутрійшіх пацієнтів'),
(121217, 2055, 33, 'Увімкнути портал внутрійшіх пацієнтів.'),
(121218, 2056, 33, 'Увімкнути віджет нагадувань для пацієнтів'),
(121219, 2057, 33, 'Увімкнути сервіс повідомлень phiMail Direct'),
(121220, 2058, 33, 'Увімкнути запрошення вводу дати для автоматичного обчислення одиниці виміру (AMC)'),
(121221, 2060, 33, 'Увімкнути звітність про відстеження дати для автоматичного обчислення одиниці виміру (AMC)'),
(121222, 2061, 33, 'Увімкнути підтримку сканера'),
(121223, 2064, 33, 'Увімкнутии послуги Medical Information Integration, LLC Lab Exchange Service.'),
(121224, 2065, 33, 'Вмикає підтримку LibreEHR службою лабораторного обміну LLC.'),
(121225, 2066, 33, 'Увімкнути аутентифікацію користувача сертифіката'),
(121226, 2067, 33, 'Увімкнути службу eRx для ZMG, LLC'),
(121227, 2068, 33, 'увімкнено'),
(121228, 2070, 33, 'Вмикає стару панель з оплатою для введення кодів рахунків і платежів. Не рекомендується,краще використовуйте список оплати.'),
(121229, 2071, 33, 'Зверн.'),
(121230, 2072, 33, 'Звернення'),
(121231, 2073, 33, 'Звернення'),
(121232, 2074, 33, 'звернення'),
(121233, 2075, 33, 'Звернення '),
(121234, 2076, 33, 'екстрене надходження пацієнта в стаціонар або в відділення невідкладної допомоги'),
(121235, 2081, 33, 'Дата звернення'),
(121236, 2084, 33, 'EDI запис звернення'),
(121237, 2086, 33, 'форми звернення'),
(121238, 2087, 33, 'Звернення з приводу здоров''я і стану'),
(121239, 2088, 33, 'Хронологія звернень'),
(121240, 2089, 33, 'ID звернення'),
(121241, 2090, 33, 'стикатися з грипом'),
(121242, 2091, 33, 'Кількість звернень'),
(121243, 2093, 33, 'звернення до медсестри з приводу виписки');
INSERT INTO `lang_definitions` VALUES
(121244, 2094, 33, 'звернення для медсестринських послуг'),
(121245, 2095, 33, 'звернення для трудотерапії'),
(121246, 2096, 33, 'звернення для відвідування кабінетів'),
(121247, 2097, 33, 'амбулаторне звернення'),
(121248, 2098, 33, 'амбулаторне звернення w/PCP & obgyn'),
(121249, 2099, 33, 'Розмір сторінки звернення'),
(121250, 2100, 33, 'Оплата звернення'),
(121251, 2101, 33, 'Звернення з приводу вагітності'),
(121252, 2102, 33, 'звернення з приводу профогляду -індивідуальна співбесіда'),
(121253, 2103, 33, 'звернення з приводу профогляду в 40 років і старше'),
(121254, 2104, 33, 'звернення з приводу профогляду для групової співбесіди'),
(121255, 2105, 33, 'звернення з приводу профогляду для інших послуг'),
(121256, 2106, 33, 'звернення з приводу профогляду в 18 років і старше'),
(121257, 2107, 33, 'звернення до психіатра і психолога'),
(121258, 2108, 33, 'Статистика звернення'),
(121259, 2109, 33, 'Підсумок звернення'),
(121260, 2110, 33, 'Звернення було закодоване'),
(121261, 2111, 33, 'Звернення:'),
(121262, 2112, 33, 'Звернення: при плановому надходженні пацієнта в стаціонар, амбулаторне або до окуліста'),
(121263, 2113, 33, 'Звернення'),
(121264, 2114, 33, 'Звернення та форми'),
(121265, 2115, 33, 'Звернення &amp; Форми'),
(121266, 2116, 33, 'Доступ до звернень не дозволено'),
(121267, 2117, 33, 'Звіт по зверненнях'),
(121268, 2118, 33, 'Розділ звернень'),
(121269, 2120, 33, 'Шифрування'),
(121270, 2121, 33, 'Кінець'),
(121271, 2122, 33, 'Закінчення (рррр-мм-дд): '),
(121272, 2123, 33, 'Кінцева дата'),
(121273, 2124, 33, 'Кінцева дата'),
(121274, 2126, 33, 'Кінцева дата повинна бути пізніше початкової'),
(121275, 2127, 33, 'Кінцева дата:'),
(121276, 2131, 33, 'Кінцевий час'),
(121277, 2132, 33, 'Термінальній стадії ниркової хвороби одержувача при моноцитарному хематоксичному білку з груповому плані роботодавця'),
(121278, 2133, 33, 'Кінцева дата надання послуги рррр-мм-дд'),
(121279, 2134, 33, 'Кінцева дата надання послуг (мм/дд/рррр), якщо бажаєте ввести діапазон'),
(121280, 2135, 33, 'Завершальна годину дня для календарних подій.'),
(121281, 2136, 33, 'Ендо аномальна кров'),
(121282, 2137, 33, 'Ендокринна'),
(121283, 2138, 33, 'Ендоскопія'),
(121284, 2141, 33, 'Англійська'),
(121285, 2142, 33, 'Англійська '),
(121286, 2143, 33, 'Англійська (індійський)'),
(121287, 2144, 33, 'Англійська (стандартний)'),
(121288, 2145, 33, 'Кодувати команду, використовуючи Hylafax.'),
(121289, 2146, 33, 'Переконайтеся, що LibreEHR має право запису в каталог'),
(121290, 2147, 33, 'ЛОР відділення'),
(121291, 2148, 33, 'Отоларингологічні болі'),
(121292, 2149, 33, 'Введіть код діагнозу для виключення всіх рахунків, що не містять його'),
(121293, 2151, 33, 'Введіть тут вміст листа'),
(121294, 2152, 33, 'Введіть пароль для основної бази даних'),
(121295, 2153, 33, 'Введіть ім''я користувача основної бази даних'),
(121296, 2154, 33, 'Введіть діагноз'),
(121297, 2155, 33, 'Введіть препарати'),
(121298, 2156, 33, 'Введіть звернення'),
(121299, 2157, 33, 'Введіть номер звернення'),
(121300, 2158, 33, 'Введіть вакцинацію'),
(121301, 2159, 33, 'Введіть ключ'),
(121302, 2161, 33, 'Введіть нову область (край)'),
(121303, 2162, 33, 'Введіть Direct-адресу отримувача'),
(121304, 2164, 33, 'Введіть цей код повторної ідентифікації'),
(121305, 2165, 33, 'Вище введіть критерій пошуку'),
(121306, 2166, 33, 'Помилкове введення'),
(121307, 2167, 33, 'вхідні'),
(121308, 2168, 33, 'Навколишній'),
(121309, 2169, 33, 'Введення даних пояснення витрат (EOB)'),
(121310, 2170, 33, 'Відправлення EOB - електронні перекази'),
(121311, 2171, 33, 'Відправлення EOB - інструкції'),
(121312, 2172, 33, 'Відправлення EOB - рахунок'),
(121313, 2173, 33, 'Відправлення EOB - запис по пацієнтові'),
(121314, 2174, 33, 'Відправлення EOB - пошук'),
(121315, 2176, 33, 'Епілепсія'),
(121316, 2178, 33, 'ERA (Європейська асоціація фахівців в області захворювань нирок)'),
(121317, 2179, 33, 'ERA файли'),
(121318, 2180, 33, 'Відправлення в ERA'),
(121319, 2181, 33, 'Анулювати'),
(121320, 2182, 33, 'Ерекції'),
(121321, 2183, 33, 'Помилка'),
(121322, 2185, 33, 'Підтвердження помилки при отриманні лабораторних результатів'),
(121323, 2187, 33, 'Помилка отримання лабораторних результатів з Lab Exchange Network'),
(121324, 2188, 33, 'Помилка у виборі "Стать"'),
(121325, 2189, 33, 'Помилка у виборі "HIPAA"'),
(121326, 2190, 33, 'Помилка у виборі "Обробка"'),
(121327, 2191, 33, 'Помилка у виборі "Шлюз SMS"'),
(121328, 2192, 33, 'Помилка у виборі "Сортувати по"'),
(121329, 2193, 33, 'Помилка GZIP-стиснення файлу: '),
(121330, 2194, 33, 'Помилка для опції ТАК чи НІ'),
(121331, 2195, 33, 'Помилка відкриття для читання завантаженого файлу'),
(121332, 2196, 33, 'Помилка обробки файлу'),
(121333, 2197, 33, 'Помилка обробки вивантаження'),
(121334, 2198, 33, 'Помилка при видаленні повідомлення'),
(121335, 2199, 33, 'Помилка отримання результатів з Lab Exchange Network'),
(121336, 2200, 33, 'Помилка отримання значень.'),
(121337, 2202, 33, 'Помилка при наданні прав доступу до файлу для користувача LibreEHR.'),
(121338, 2205, 33, 'помилка при реєстрації форми!'),
(121339, 2206, 33, 'Помилка збереження в файл'),
(121340, 2208, 33, 'Помилка запису в файл'),
(121341, 2209, 33, 'в нових результатах зустрічаються помилки(а)'),
(121342, 2210, 33, 'Помилка, файл не існує'),
(121343, 2211, 33, 'ПОМИЛКА, неможливо зібрати дані з сервера'),
(121344, 2212, 33, 'Помилка, неможливо створити клієнтський сертифікат'),
(121345, 2213, 33, 'Помилка, неможливо створити сертифікат admin.p12.'),
(121346, 2214, 33, 'Помилка, неможливо створити довірений Центр Сертифікації.'),
(121347, 2215, 33, 'Помилка, неможливо створити сертифікат сервера.'),
(121348, 2216, 33, 'Помилка, неможливо відкрити файл'),
(121349, 2217, 33, 'Помилка, в LibreEHR не включена аутентифікація сертифіката користувача'),
(121350, 2218, 33, 'Помилка, необхідно встановити модуль php Archive/Tar.php.'),
(121351, 2219, 33, 'ПОМИЛКА: не вдалося відкрити table.sql, пошкоджено форму?'),
(121352, 2220, 33, 'Помилка: в рядку дублюється ID'),
(121353, 2221, 33, 'Помилка: в рядку дублюється ім''я'),
(121354, 2222, 33, 'ПОМИЛКА: поле'),
(121355, 2223, 33, 'ПОМИЛКА: пропущений архів PHP для ZipArchive'),
(121356, 2224, 33, 'ПОМИЛКА: немає каталогу імпорту ICD'),
(121357, 2225, 33, 'Помилка: невідповідний пароль. Перевірте введені дані.'),
(121358, 2226, 33, 'Помилка: невідповідний пароль. Перевірте введені дані.'),
(121359, 2227, 33, 'Помилка: файл не існує'),
(121360, 2228, 33, 'ПОМИЛКА: Наступна зміна містить неприпустимі символи.'),
(121361, 2229, 33, 'ПОМИЛКА: неможливо скопіювати цей файл.'),
(121362, 2230, 33, 'Помилка: створення архіву завантаження не доступно'),
(121363, 2231, 33, 'Помилка: створення архіву Zip не доступно.'),
(121364, 2232, 33, 'ПОМИЛКА: вилучення цього файлу не доступно.'),
(121365, 2233, 33, 'ПОМИЛКА: завантаження цього файлу в базу даних не доступно.'),
(121366, 2234, 33, 'ПОМИЛКА: установка номера версії не доступна.'),
(121367, 2235, 33, 'Помилки'),
(121368, 2236, 33, 'Статус аккаунта сервісу eRx'),
(121369, 2237, 33, 'Журнали длясервісу eRx'),
(121370, 2238, 33, 'Ім''я для сервісу eRx'),
(121371, 2239, 33, 'Пароль для сервісу eRx'),
(121372, 2240, 33, 'Роль для сервісу eRx'),
(121373, 2241, 33, 'Користувач сервісу eRx'),
(121374, 2242, 33, 'Еритема:'),
(121375, 2245, 33, 'Ескімоський'),
(121376, 2247, 33, 'Зареєстрований пацієнт'),
(121377, 2248, 33, 'Естонська'),
(121378, 2249, 33, 'Етнічна приналежність'),
(121379, 2250, 33, 'Етнічна приналежність або раса'),
(121380, 2251, 33, 'Список етносів-рас (на вибір - право записувати /добавляти)'),
(121381, 2252, 33, 'Електронно/паперовий ідентифікаційний номер (ETIN)'),
(121382, 2253, 33, 'Подія'),
(121383, 2254, 33, 'Початок події'),
(121384, 2255, 33, 'Категорія події'),
(121385, 2256, 33, 'Дата події'),
(121386, 2257, 33, 'Опис події'),
(121387, 2258, 33, 'Відомості про подію'),
(121388, 2259, 33, 'Подія не повторюється'),
(121389, 2260, 33, 'Тривалість події'),
(121390, 2261, 33, 'Тривалість події в хвилинах'),
(121391, 2262, 33, 'Оплата за фактом'),
(121392, 2263, 33, 'Місце проведення'),
(121393, 2264, 33, 'Подія повторюється кожні'),
(121394, 2265, 33, 'Подія повторюється в'),
(121395, 2266, 33, 'Початковий час події'),
(121396, 2267, 33, 'Позначення події'),
(121397, 2268, 33, 'Позначення події'),
(121398, 2269, 33, 'Фактична веб-сайт'),
(121399, 2270, 33, 'Події'),
(121400, 2271, 33, 'Події для'),
(121401, 2272, 33, 'Відкривати події в новому вікні'),
(121402, 2273, 33, 'кожен'),
(121403, 2274, 33, 'Кожні'),
(121404, 2275, 33, 'кожні 3 години'),
(121405, 2276, 33, 'кожні 4 години'),
(121406, 2277, 33, 'кожні 5 годин'),
(121407, 2278, 33, 'кожні 6 годин'),
(121408, 2279, 33, 'кожні 8 годин'),
(121409, 2280, 33, 'Кожен четвертий'),
(121410, 2281, 33, 'Кожен другий'),
(121411, 2282, 33, 'Кожен третій'),
(121412, 2283, 33, 'Кожен, кожен другий, кожен третій і т.д.'),
(121413, 2285, 33, 'Результати досліджень і аналізів'),
(121414, 2286, 33, 'Результати обстеження'),
(121415, 2289, 33, 'Обстеження'),
(121416, 2290, 33, 'Дата обстеження'),
(121417, 2291, 33, 'приклад'),
(121418, 2292, 33, 'Приклади'),
(121419, 2293, 33, 'Обстеження/Аналізи'),
(121420, 2294, 33, 'За винятком'),
(121421, 2295, 33, 'Сльозоточивість'),
(121422, 2296, 33, 'виключені пацієнти'),
(121423, 2297, 33, 'Виняток'),
(121424, 2298, 33, 'Ліцензований спеціалізована установа (EPO)'),
(121425, 2299, 33, 'Встановлена форма документу'),
(121426, 2300, 33, 'Вправа'),
(121427, 2301, 33, 'Приклади вправ'),
(121428, 2302, 33, 'Приклади вправ'),
(121429, 2303, 33, 'Існуючий'),
(121430, 2304, 33, 'Вийти з адміністрування'),
(121431, 2305, 33, 'Розгорнути'),
(121432, 2306, 33, 'Розгорнути'),
(121433, 2307, 33, 'розгорнути'),
(121434, 2308, 33, 'Розгорнути все'),
(121435, 2311, 33, 'Розгорнутий вигляд'),
(121436, 2312, 33, 'Відмітьте form_encounter.pid для  '),
(121437, 2313, 33, 'Термін дії'),
(121438, 2314, 33, 'Дата придатності'),
(121439, 2315, 33, 'Простерміновано'),
(121440, 2316, 33, 'протерміновано на'),
(121441, 2317, 33, 'Експорт'),
(121442, 2318, 33, 'Експортувати як CSV'),
(121443, 2319, 33, 'Експорт конфігурації'),
(121444, 2322, 33, 'Експорт персональних даних пацієнта'),
(121445, 2323, 33, 'Експорт звіту PQRI'),
(121446, 2325, 33, 'Експортувати вибране, як CSV'),
(121447, 2326, 33, 'Експортувати обране для збору'),
(121448, 2327, 33, 'Експортувати в CSV'),
(121449, 2328, 33, 'Експорт в зовнішню систему обліку рахунків'),
(121450, 2329, 33, 'Поїздки за кордон'),
(121451, 2330, 33, 'Поїздки за кордон'),
(121452, 2331, 33, 'Додатковий час збору'),
(121453, 2332, 33, 'Зовнішній'),
(121454, 2334, 33, 'Зовнішні дані завантажуються'),
(121455, 2335, 33, 'Утиліта імпорту зовнішньої бази даних'),
(121456, 2336, 33, 'Зовнішній ID'),
(121457, 2337, 33, 'Зовнішній id'),
(121458, 2338, 33, 'Зовнішній ідентифікатор'),
(121459, 2339, 33, 'Тільки зовнішній'),
(121460, 2342, 33, 'Зовнішнє направлення'),
(121461, 2343, 33, 'Контроль зовнішнього направлення'),
(121462, 2344, 33, 'Направлення зовнішнє?'),
(121463, 2345, 33, 'Зовнішні направлення'),
(121464, 2346, 33, 'Витягнення файлу zip'),
(121465, 2347, 33, 'Файл витягується. Це займе якийсь час ...'),
(121466, 2348, 33, 'Відокремлюване:'),
(121467, 2349, 33, 'Подразнення очей'),
(121468, 2350, 33, 'Біль в очах'),
(121469, 2351, 33, 'Гіперемія очей'),
(121470, 2352, 33, 'Очі'),
(121471, 2353, 33, 'F'),
(121472, 2354, 33, 'Сімейна історія гематологічних проблем'),
(121473, 2355, 33, 'Сімейна історія жіночого Гірсутизму / Розтяжок'),
(121474, 2356, 33, 'Медичні заклади'),
(121475, 2357, 33, 'Медичний заклад'),
(121476, 2358, 33, 'медичний заклад'),
(121477, 2359, 33, 'Адміністрація медзакладу'),
(121478, 2360, 33, 'Місто розміщення медзакладу'),
(121479, 2361, 33, 'Код медзакладу'),
(121480, 2362, 33, 'Код країни медзакладу'),
(121481, 2363, 33, 'Факс медзакладу'),
(121482, 2364, 33, 'Назва медзакладу'),
(121483, 2365, 33, 'Загальнодержавний номер-ідентифікатор медзакладу'),
(121484, 2366, 33, 'Телефон медзакладу'),
(121485, 2367, 33, 'Інформація про користувача специфічна для медзакладу'),
(121486, 2368, 33, 'Область (край) медзакладу'),
(121487, 2369, 33, 'Вулиця медзакладу'),
(121488, 2370, 33, 'Поштовий індекс медзакладу'),
(121489, 2372, 33, 'Медичний заклад:'),
(121490, 2373, 33, 'Невдача'),
(121491, 2374, 33, 'невдало'),
(121492, 2375, 33, 'Невдало'),
(121493, 2380, 33, 'Неадвча при створенні тимчасової папки. CouchDB не буде працювати.'),
(121494, 2382, 33, 'Невдало.'),
(121495, 2383, 33, 'збій'),
(121496, 2390, 33, 'Сімейний анамнез'),
(121497, 2391, 33, 'Сімейний анамнез по глаукомі'),
(121498, 2392, 33, 'Сімейний анамнез:'),
(121499, 2394, 33, 'Сімейна оплата'),
(121500, 2395, 33, 'Членів сім''ї'),
(121501, 2396, 33, 'Уява'),
(121502, 2398, 33, 'Фарсі'),
(121503, 2400, 33, 'Батько'),
(121504, 2402, 33, 'Стомлюваність'),
(121505, 2403, 33, 'Стомлений'),
(121506, 2404, 33, 'Факс'),
(121507, 2405, 33, 'Кількість факсів'),
(121508, 2406, 33, 'Номер факсу'),
(121509, 2408, 33, 'Факс/сканер'),
(121510, 2409, 33, 'Прийняти через факс'),
(121511, 2410, 33, 'Надіслати через факс'),
(121512, 2411, 33, 'Можливості'),
(121513, 2412, 33, 'Лют.'),
(121514, 2413, 33, 'Лютий'),
(121515, 2414, 33, 'Номер державного страхування найманих працівників'),
(121516, 2415, 33, 'Державний ідентифікаційний код препарату'),
(121517, 2416, 33, 'Державний електронний ідентифікаційний номер'),
(121518, 2417, 33, 'Державний податковий ідентифікаційний код'),
(121519, 2418, 33, 'Плата'),
(121520, 2419, 33, 'плата'),
(121521, 2420, 33, 'Плата не дозволена'),
(121522, 2421, 33, 'Платіжний лист'),
(121523, 2422, 33, 'Варіанти платіжних відомостей'),
(121524, 2423, 33, 'Платежі'),
(121525, 2424, 33, 'Жіноча'),
(121526, 2425, 33, 'Жіноча стенокардія'),
(121527, 2426, 33, 'Жіночі презервативи'),
(121528, 2427, 33, 'Жіночий G'),
(121529, 2428, 33, 'Жіночий LC'),
(121530, 2429, 33, 'Жіночий P'),
(121531, 2430, 33, 'Жіночі симптоми'),
(121532, 2431, 33, 'Жіноча довільна хірургічна контрацепція'),
(121533, 2434, 33, 'Лихоманка'),
(121534, 2435, 33, 'Лихоманка:'),
(121535, 2436, 33, 'Сімейна історія проблем крові '),
(121536, 2437, 33, 'Фіброми'),
(121537, 2441, 33, 'Тип поля для використання країни роботодавця або споживача в персональних даних.'),
(121538, 2442, 33, 'Тип поля для використання області (краю) роботодавця або споживача в персональних даних.'),
(121539, 2443, 33, 'Пропущено поле(я)!'),
(121540, 2447, 33, 'Файл'),
(121541, 2448, 33, 'файл в директорії Documentation для вивчення, як автоматизувати процес створення журналу резервного копіювання'),
(121542, 2449, 33, 'розташування файлу'),
(121543, 2450, 33, 'Управління файлом'),
(121544, 2453, 33, 'Право на файл, надане користувачеві LibreEHR.'),
(121545, 2454, 33, 'Невдача при отриманні файлу з CouchDB'),
(121546, 2455, 33, 'Реєстратура'),
(121547, 2456, 33, 'Файл для вивантаження'),
(121548, 2457, 33, 'Файл для вивантаження'),
(121549, 2458, 33, 'В цьому місці вже є файл з таким ім''ям:'),
(121550, 2459, 33, 'Ім''я файлу'),
(121551, 2461, 33, 'Файли'),
(121552, 2462, 33, 'Філіппінська'),
(121553, 2463, 33, 'Заповніть нижче будь-який з рядків'),
(121554, 2464, 33, 'Заповніть тут, тільки якщо відправляєте пацієнтові повідомлення через e-mail'),
(121555, 2465, 33, 'Заповніть значення нижче'),
(121556, 2467, 33, 'Заповніть цей рядок.'),
(121557, 2468, 33, 'Фільтр'),
(121558, 2469, 33, 'Фільтр для констант'),
(121559, 2470, 33, 'Фільтр для визначень'),
(121560, 2471, 33, 'фільтровано з'),
(121561, 2472, 33, 'фільтри'),
(121562, 2473, 33, 'Фільтри'),
(121563, 2474, 33, 'Кінцевий'),
(121564, 2475, 33, 'Остаточний діагноз'),
(121565, 2476, 33, 'Остаточний діагноз фахівця'),
(121566, 2478, 33, 'Фінансовий'),
(121567, 2479, 33, 'Дата фінансового закриття (рррр-мм-дд)'),
(121568, 2480, 33, 'Фінансове повідомлення – будь-яке'),
(121569, 2481, 33, 'Фінансове повідомлення - мої звернення'),
(121570, 2482, 33, 'Дата фінансового розгляду'),
(121571, 2483, 33, 'Фінансові підсумки по кодах послуг'),
(121572, 2484, 33, 'Знайти'),
(121573, 2485, 33, 'Знайти доступні'),
(121574, 2486, 33, 'Знайти доступні записи на прийом'),
(121575, 2487, 33, 'Знайти пацієнта'),
(121576, 2488, 33, 'Знайти рекомендовані матеріали для пацієнта'),
(121577, 2489, 33, 'Знайдене'),
(121578, 2490, 33, 'Знайдене по спеціалісту'),
(121579, 2491, 33, 'Штраф'),
(121580, 2492, 33, 'Остаточні платежі'),
(121581, 2493, 33, 'завершено'),
(121582, 2495, 33, 'Ім''я'),
(121583, 2497, 33, 'Перший день тижня'),
(121584, 2498, 33, 'Ім''я'),
(121585, 2499, 33, 'Ім''я'),
(121586, 2500, 33, 'Ім''я:'),
(121587, 2503, 33, 'Фізична підготовка'),
(121588, 2504, 33, 'Рівень фізичної підготовки'),
(121589, 2505, 33, 'Рівень фізичної підготовки для цього гравця в цей день'),
(121590, 2507, 33, 'Фізична підготовка до гри'),
(121591, 2508, 33, 'Зафіксувати дати звернення - будь-які звернення'),
(121592, 2509, 33, 'Зафіксуйте це'),
(121593, 2510, 33, 'Флорида'),
(121594, 2511, 33, 'Метеоризм'),
(121595, 2512, 33, 'Потік'),
(121596, 2514, 33, 'Епідемічний сезон'),
(121597, 2515, 33, 'Епідемічний сезон'),
(121598, 2516, 33, 'Щеплення від грипу'),
(121599, 2517, 33, 'Проблема водно-електролітного балансу'),
(121600, 2518, 33, 'FMS'),
(121601, 2519, 33, 'Розміри паперу Фоліо'),
(121602, 2520, 33, 'Виконати вручну'),
(121603, 2521, 33, 'Дотримуйтесь цих інструкцій щоб встановити чи оновити наступну базу даних'),
(121604, 2522, 33, 'Подальше'),
(121605, 2524, 33, 'Ввиявлена ​​причина'),
(121606, 2525, 33, 'Далі нова константа користувача:'),
(121607, 2526, 33, 'Далі нова мова користувача:'),
(121608, 2527, 33, 'Далі нове визначення (мова, константа, визначення):'),
(121609, 2529, 33, 'Надавані види допомоги'),
(121610, 2530, 33, 'Вказуються в подальшому'),
(121611, 2531, 33, 'Відраза до їжі'),
(121612, 2532, 33, 'Стопа'),
(121613, 2533, 33, 'Проблеми стоп'),
(121614, 2534, 33, 'Стопа:'),
(121615, 2535, 33, 'Футбольні травми'),
(121616, 2536, 33, 'Футбольна травма'),
(121617, 2537, 33, 'Повідомлення про футбольну травмі'),
(121618, 2538, 33, 'Тип взуття'),
(121619, 2539, 33, 'для'),
(121620, 2540, 33, 'Для'),
(121621, 2541, 33, 'Для коду'),
(121622, 2543, 33, 'Для вимог щодо поводження'),
(121623, 2544, 33, 'Наприклад:'),
(121624, 2547, 33, 'для рахунку'),
(121625, 2548, 33, 'Лише для Medicare, викликає консультанта як призначеного лікаря.'),
(121626, 2549, 33, 'місце для номеру призначення OBR'),
(121627, 2552, 33, 'Для напрямних установ/практикуючих лікарів'),
(121628, 2553, 33, 'Для минулих'),
(121629, 2554, 33, 'для змінних'),
(121630, 2555, 33, 'для:'),
(121631, 2556, 33, 'Примусове відкриття білінгового віджету'),
(121632, 2557, 33, 'Примусове оформлення нового пацієнта'),
(121633, 2558, 33, 'Примусовий показ'),
(121634, 2559, 33, 'Передпліччя'),
(121635, 2560, 33, 'Форма'),
(121636, 2561, 33, 'форма'),
(121637, 2564, 33, 'Формат'),
(121638, 2565, 33, 'формат'),
(121639, 2566, 33, 'Формат відображення віку'),
(121640, 2567, 33, 'Неправильний формат для державного коду медпрепарату (NDC)'),
(121641, 2568, 33, 'Формат, який використовується для відображення більшості дат.'),
(121642, 2569, 33, 'Формат, який використовується для відображення більшості часових інтервалів.'),
(121643, 2570, 33, 'Відформатований звіт'),
(121644, 2571, 33, 'Колишній курець'),
(121645, 2572, 33, 'Форми'),
(121646, 2573, 33, 'Управління формами'),
(121647, 2575, 33, 'Вперед'),
(121648, 2576, 33, 'Переслати факсом'),
(121649, 2577, 33, 'Перенаправлений'),
(121650, 2579, 33, 'Четвертий'),
(121651, 2581, 33, 'Перелом'),
(121652, 2582, 33, 'Перелом човноподібної кістки'),
(121653, 2583, 33, 'Перелом латеральної щиколотки'),
(121654, 2584, 33, 'Перелом медіальної кісточки'),
(121655, 2585, 33, 'Перелом основа п''ятої (5-й) метатарсальной кістки'),
(121656, 2586, 33, 'Вимагається підтримка фреймів'),
(121657, 2587, 33, 'Французька'),
(121658, 2588, 33, 'Французька (канадійська)'),
(121659, 2589, 33, 'Французька (стандартна)'),
(121660, 2590, 33, 'Частота'),
(121661, 2591, 33, 'Часті застуди'),
(121662, 2592, 33, 'Часті захворювання'),
(121663, 2593, 33, 'Пт'),
(121664, 2594, 33, 'П''ятниця'),
(121665, 2595, 33, 'З'),
(121666, 2596, 33, 'З'),
(121667, 2597, 33, 'від'),
(121668, 2598, 33, 'Дата "з" не може бути пізніше дати "по".'),
(121669, 2599, 33, 'З:'),
(121670, 2600, 33, 'З: '),
(121671, 2601, 33, 'З_МІСТО'),
(121672, 2603, 33, 'З_ІМ''Я'),
(121673, 2604, 33, 'З_ПРІЗВИЩЕ'),
(121674, 2605, 33, 'З_ПО-БАТЬКОВІ'),
(121675, 2607, 33, 'З_ТЕЛЕФОН'),
(121676, 2608, 33, 'З_ПОШТОВА_АДРЕСА'),
(121677, 2609, 33, 'З_ШТАТ'),
(121678, 2610, 33, 'З_ВУЛИЦЯ'),
(121679, 2611, 33, 'З_НАЗВА'),
(121680, 2612, 33, 'З_ПРОЩАННЯ'),
(121681, 2613, 33, 'Реєстратура'),
(121682, 2614, 33, 'Прийом в реєстратурі'),
(121683, 2615, 33, 'Звіт про прийом в реєстратурі'),
(121684, 2616, 33, 'Первинний запис'),
(121685, 2617, 33, 'Передній правий'),
(121686, 2619, 33, 'Повне ім''я'),
(121687, 2620, 33, 'Повний шлях до каталогу, що містить виконувані файли MySQL.'),
(121688, 2621, 33, 'Повний шлях до каталогу, що містить виконувані файли Perl.'),
(121689, 2622, 33, 'Повний шлях до каталогу для резервної копії журналу подій.'),
(121690, 2623, 33, 'Повний шлях до каталогу для тимчасових файлів.'),
(121691, 2624, 33, 'Повне відтворення'),
(121692, 2625, 33, 'Повне навчання'),
(121693, 2626, 33, 'Повна оплата'),
(121694, 2633, 33, 'Г'),
(121695, 2634, 33, 'г/дл'),
(121696, 2636, 33, 'Стан жовчного міхура'),
(121697, 2637, 33, 'Жовчно-кам''яна хвороба'),
(121698, 2638, 33, 'Тривалість відтворення'),
(121699, 2639, 33, 'Ігри'),
(121700, 2640, 33, 'Ігри пропущено'),
(121701, 2641, 33, 'ігри/події'),
(121702, 2642, 33, 'Ігри/події пропущено'),
(121703, 2644, 33, 'Гастрит'),
(121704, 2645, 33, 'Біль при гастриті'),
(121705, 2646, 33, 'Органи шлунково-кишкового тракту'),
(121706, 2647, 33, 'Статистичний звіт GCAC'),
(121707, 2648, 33, 'Статистика GCAC'),
(121708, 2649, 33, 'Форма відвідування GCAC пропущена'),
(121709, 2650, 33, 'Стать'),
(121710, 2651, 33, 'Стать '),
(121711, 2652, 33, 'Загальне'),
(121712, 2653, 33, 'Загальний список проблем'),
(121713, 2655, 33, 'Категорія основної послуги'),
(121714, 2657, 33, 'Створити і завантажити паперову вимога CMS 1500'),
(121715, 2658, 33, 'Створити і завантажити паперові вимогу HCFA 1500'),
(121716, 2659, 33, 'Створити і завантажити пакет X12'),
(121717, 2660, 33, 'Створити і завантажити пакет X12 для звернення'),
(121718, 2663, 33, 'Створює і передає в електронному вигляді дозволені призначення.'),
(121719, 2664, 33, 'Створити CMS 1500'),
(121720, 2665, 33, 'Створити CMS 1500 PDF'),
(121721, 2666, 33, 'Створити CMS 1500 TEXT'),
(121722, 2667, 33, 'Створити HCFA'),
(121723, 2668, 33, 'Створити рахунок'),
(121724, 2669, 33, 'Створити лист'),
(121725, 2670, 33, 'Створити лист з питання '),
(121726, 2671, 33, 'Створити звіт PQRI (Метод A)'),
(121727, 2673, 33, 'Створити звіт PQRI (Метод E)'),
(121728, 2677, 33, 'Створити звіт'),
(121729, 2678, 33, 'Створює ім''я користувача та пароль для'),
(121730, 2679, 33, 'Створити X12'),
(121731, 2680, 33, 'Створити звернення X12'),
(121732, 2682, 33, 'Створити в'),
(121733, 2683, 33, 'Створено'),
(121734, 2684, 33, 'Сечостатева'),
(121735, 2687, 33, 'Німецька'),
(121736, 2691, 33, 'Отримати HL7'),
(121737, 2692, 33, 'Глаукома'),
(121738, 2693, 33, 'Сімейний анамнез по глаукомі'),
(121739, 2694, 33, 'Глобальне'),
(121740, 2696, 33, 'Глобальний ID'),
(121741, 2697, 33, 'Глобальні налаштування'),
(121742, 2698, 33, 'Глобальні змінні'),
(121743, 2699, 33, 'гр/дл'),
(121744, 2700, 33, 'далі'),
(121745, 2701, 33, 'Далі'),
(121746, 2704, 33, 'Перейти в'),
(121747, 2705, 33, 'Перейти до тижня'),
(121748, 2706, 33, 'Перейти до сьогодні'),
(121749, 2707, 33, 'Мета А'),
(121750, 2708, 33, 'Мета і методи'),
(121751, 2709, 33, 'Мета В'),
(121752, 2710, 33, 'Мета С'),
(121753, 2711, 33, 'Тяжкість травми'),
(121754, 2712, 33, 'Ступінь'),
(121755, 2713, 33, 'грами'),
(121756, 2714, 33, 'Загальна сума'),
(121757, 2715, 33, 'Загальні суми'),
(121758, 2718, 33, 'Выдображається графічно'),
(121759, 2720, 33, 'Більше, ніж'),
(121760, 2721, 33, 'Більше, ніж або дорівнює'),
(121761, 2722, 33, 'Грецька'),
(121762, 2724, 33, 'Група'),
(121763, 2725, 33, 'Ім''я групи'),
(121764, 2726, 33, 'Імена груп не можуть бути порожніми'),
(121765, 2727, 33, 'Імена групи не можуть починатися з числа або пробілу.'),
(121766, 2728, 33, 'Імена групи не можуть починатися з чисел.'),
(121767, 2729, 33, 'Номер групи'),
(121768, 2730, 33, 'Групова оплата'),
(121769, 2731, 33, 'Група:'),
(121770, 2732, 33, 'Ім''я групи'),
(121771, 2733, 33, 'Групи і керування доступом'),
(121772, 2734, 33, 'Крива зростання'),
(121773, 2735, 33, 'Діаграма зростання'),
(121774, 2736, 33, 'gtts (краплі)'),
(121775, 2737, 33, 'Гуамській'),
(121776, 2739, 33, 'Прізвище опікуна'),
(121777, 2741, 33, 'Гінекологічне обстеження'),
(121778, 2742, 33, 'год.'),
(121779, 2743, 33, 'час сну'),
(121780, 2744, 33, 'H/O Гепатити '),
(121781, 2745, 33, 'був успішно знищений. Будь-які підкатегорії,якщо представлені, були переміщені нижче'),
(121782, 2746, 33, 'Гематома / забій'),
(121783, 2747, 33, 'Стан інгібування гемаглютинації'),
(121784, 2750, 33, 'Рука+ пальці'),
(121785, 2751, 33, 'Проблеми рук'),
(121786, 2752, 33, 'Жорсткий диск'),
(121787, 2753, 33, 'Без труднощів'),
(121788, 2754, 33, 'було зв''язано з відвідуванням'),
(121789, 2755, 33, 'з вичерпаним терміном'),
(121790, 2756, 33, 'Хеш'),
(121791, 2757, 33, 'Для цього файлу хеш не існує. Буде створений новий хеш.'),
(121792, 2758, 33, 'Хеш не співпадає. Цілісність даних була скомпрометована.'),
(121793, 2760, 33, 'Гавайський'),
(121794, 2761, 33, 'Небезпечна діяльність'),
(121795, 2762, 33, 'Небезпечна діяльність'),
(121796, 2763, 33, 'Ліве поле HCFA в точках'),
(121797, 2764, 33, 'Поля HCFA'),
(121798, 2765, 33, 'Верхнє поле HCFA в точках'),
(121799, 2766, 33, 'HCPCS Процедура/Послуга'),
(121800, 2767, 33, 'він вніс в календар '),
(121801, 2768, 33, 'Голова'),
(121802, 2769, 33, 'Окр. голови'),
(121803, 2770, 33, 'Окружність голови'),
(121804, 2771, 33, 'Головний біль'),
(121805, 2772, 33, 'Головні болі'),
(121806, 2773, 33, 'Медичні операції'),
(121807, 2774, 33, 'Заходи з охорони здоров''я'),
(121808, 2775, 33, 'Медичний центр / клініка'),
(121809, 2776, 33, 'Установа з надання медичної допомоги'),
(121810, 2777, 33, 'Страховий ризик для установ з надання медичної допомоги'),
(121811, 2778, 33, 'Втрата слуху'),
(121812, 2779, 33, 'інфаркт міокарда'),
(121813, 2780, 33, 'Вада серця'),
(121814, 2781, 33, 'Серцева недостатність'),
(121815, 2782, 33, 'Кардіальна проблема'),
(121816, 2783, 33, 'Кардіальні проблеми'),
(121817, 2784, 33, 'Кардіохірургія'),
(121818, 2785, 33, 'Пересадка серця'),
(121819, 2786, 33, 'СЕРЦЕ:'),
(121820, 2787, 33, 'Печія'),
(121821, 2788, 33, 'Жар або остуда'),
(121822, 2789, 33, 'Жар або остуда'),
(121823, 2790, 33, 'Завзятий курець'),
(121824, 2791, 33, 'Іврит'),
(121825, 2793, 33, 'ЛОР'),
(121826, 2794, 33, 'Ріст'),
(121827, 2796, 33, 'Довідка'),
(121828, 2797, 33, 'довідка'),
(121829, 2798, 33, 'Блювота кров''ю'),
(121830, 2799, 33, 'Кров''яні випорожнення'),
(121831, 2800, 33, 'Гематологія'),
(121832, 2801, 33, 'Гематурія'),
(121833, 2802, 33, 'Гемоглобін'),
(121834, 2803, 33, 'Гемоглобін А1С'),
(121835, 2804, 33, 'Кровохаркання'),
(121836, 2805, 33, 'Гепатит'),
(121837, 2806, 33, 'Гепатит А 1'),
(121838, 2807, 33, 'Гепатит А 2'),
(121839, 2808, 33, 'Гепатит В 1'),
(121840, 2809, 33, 'Гепатит В 2'),
(121841, 2810, 33, 'Гепатит В 3'),
(121842, 2811, 33, 'тут'),
(121843, 2813, 33, 'Герніопластика'),
(121844, 2814, 33, 'Грижа диску'),
(121845, 2815, 33, 'Герпес'),
(121846, 2816, 33, 'Утруднений початок сечовипускання'),
(121847, 2817, 33, 'гей, Ви тут для '),
(121848, 2818, 33, 'Hib-вакцина 1'),
(121849, 2819, 33, 'Hib-вакцина 2'),
(121850, 2820, 33, 'Hib-вакцина 3'),
(121851, 2821, 33, 'Hib-вакцина 4'),
(121852, 2822, 33, 'Прихований'),
(121853, 2823, 33, 'Управління прихованими подіями'),
(121854, 2824, 33, 'Приховати'),
(121855, 2825, 33, 'Приховати деталі'),
(121856, 2827, 33, 'Приховати опції шифрування/дешифрування у керуванні документом'),
(121857, 2828, 33, 'Приховати меню'),
(121858, 2830, 33, 'Приховати нагадування'),
(121859, 2831, 33, 'Приховати/показати стовпці'),
(121860, 2833, 33, 'Висока'),
(121861, 2834, 33, 'Підвищений артеріальний тиск'),
(121862, 2835, 33, 'Хінді'),
(121863, 2836, 33, 'Стегно+пах'),
(121864, 2837, 33, 'Стегно і пах'),
(121865, 2838, 33, 'Проблеми стегна'),
(121866, 2839, 33, 'Заміщення тазостегнового суглоба'),
(121867, 2840, 33, 'Отримувати повідомлення HIPAA (звітність і безпека медичного страхування)'),
(121868, 2842, 33, 'Гірсутизм/Стріе'),
(121869, 2843, 33, 'Латиноамериканець'),
(121870, 2844, 33, 'Латиноамериканець - інше (народжений у США)'),
(121871, 2845, 33, 'Латиноамериканець - інше (народжений не у США)'),
(121872, 2846, 33, 'Латиноамериканець або Латино'),
(121873, 2847, 33, 'Хронологія'),
(121874, 2848, 33, 'Дата збору анамнезу'),
(121875, 2849, 33, 'Дата анамнезу'),
(121876, 2851, 33, 'Шум в анамнезі'),
(121877, 2852, 33, 'Хронологія не дозволена'),
(121878, 2853, 33, 'Анамнез шуму серця'),
(121879, 2854, 33, 'Співпадіння'),
(121880, 2855, 33, 'ВІЛ'),
(121881, 2858, 33, 'Оглядач HL7'),
(121882, 2860, 33, 'нмоль/л'),
(121883, 2861, 33, 'Хмонг'),
(121884, 2862, 33, 'Утримуйте Ctrl для вибору декількох елементів'),
(121885, 2863, 33, 'Утримуйте Ctrl для вибору декількох груп'),
(121886, 2864, 33, 'Утримуйте [Ctrl] для множинного вибору або для зняття вибору'),
(121887, 2865, 33, 'На головну'),
(121888, 2866, 33, 'Домашній телефон'),
(121889, 2867, 33, 'Номер домашнього телефону'),
(121890, 2868, 33, 'Бездомний або подібне?'),
(121891, 2869, 33, 'Бездомний і т.д.'),
(121892, 2870, 33, 'Бездомний і т.д.'),
(121893, 2872, 33, 'Ім''я вузла'),
(121894, 2873, 33, 'Ім''я вузла не може бути порожнім'),
(121895, 2875, 33, 'Година'),
(121896, 2876, 33, 'Години'),
(121897, 2878, 33, 'Як сталася травма?'),
(121898, 2879, 33, 'Як сталася травма?'),
(121899, 2880, 33, 'Як Ви дізналися про нас?'),
(121900, 2881, 33, 'Скільки місяців передуватимуть майбутнім заходам?'),
(121901, 2882, 33, 'Анамнез супутніх захворювань:'),
(121902, 2883, 33, 'Пересадка серця'),
(121903, 2884, 33, 'HTML'),
(121904, 2885, 33, 'HTML вивід?'),
(121905, 2886, 33, 'Https посилання для підтримки LibreEHR службою лаб. обміну LLC.'),
(121906, 2887, 33, 'Угорська'),
(121907, 2888, 33, 'Каталог Hylafax'),
(121908, 2889, 33, 'Команда шифрування Hylafax'),
(121909, 2890, 33, 'Сервер Hylafax'),
(121910, 2891, 33, 'Ім''я вузла сервера Hylafax'),
(121911, 2892, 33, 'Гиперактивний'),
(121912, 2893, 33, 'Гіпертензія'),
(121913, 2894, 33, 'Артеріальна гіпертензія: одиниця виміру артеріального тиску'),
(121914, 2895, 33, 'Артеріальна гіпертензія: одиниця виміру артеріального тиску (CQM)'),
(121915, 2896, 33, 'Гіпертиреоз'),
(121916, 2897, 33, 'Гіпертиреоз'),
(121917, 2898, 33, 'Гістеректомия'),
(121918, 2899, 33, 'Я'),
(121919, 2900, 33, 'Я зайнятий в цей період часу.'),
(121920, 2901, 33, 'У мене немає доступу на читання '),
(121921, 2902, 33, 'МКХ'),
(121922, 2903, 33, 'МКХ10 Діагноз'),
(121923, 2904, 33, 'МКХ10 Процедура/Послуга'),
(121924, 2905, 33, 'МКХ9'),
(121925, 2906, 33, 'МКХ9 Діагноз'),
(121926, 2907, 33, 'МКХ9 Процедура/Послуга'),
(121927, 2909, 33, 'ID'),
(121928, 2910, 33, 'Id'),
(121929, 2911, 33, 'ID не може бути порожнім'),
(121930, 2912, 33, 'ID Картка'),
(121931, 2913, 33, 'ID дні'),
(121932, 2914, 33, 'ідентифікувати як'),
(121933, 2915, 33, 'ідентифікатор (одне слово)'),
(121934, 2916, 33, 'Ідентифікаційний код'),
(121935, 2917, 33, 'Секунд сесійного простою'),
(121936, 2919, 33, 'Якщо для цієї форми всі дані для всіх стовпців заповнені'),
(121937, 2920, 33, 'При використанні білінгової реабілітації введіть найменування типу коду для діагнозу.'),
(121938, 2921, 33, 'якщо вводите, то вибирайте лише ті, які мають цю службу'),
(121939, 2922, 33, 'Якщо найменування, то будь-яка частина прізвища або прізвище, ім''я'),
(121940, 2923, 33, 'якщо оплачено через'),
(121941, 2924, 33, 'Якщо людина померла, то введіть дату смерті.'),
(121942, 2925, 33, 'При використанні SMTP ім''я вузла сервера або ІР адреса'),
(121943, 2926, 33, 'При використанні SMTP номер порту TCP сервера (зазвичай 25).'),
(121944, 2927, 33, 'якщо не працює, то введіть Student'),
(121945, 2928, 33, 'Якщо РМД вибрано для відображення віку, перейдіть лише на Роки, якщо пацієнти старше цього значення в роках'),
(121946, 2929, 33, 'Якщо Ви змінюєте e-RX Role для ePrescription, то це може вплинути на технологічний процес ePrescription. Якщо ви стикаєтеся з будь-якими труднощами, контактуйте зі своїм ePrescription постачальником.'),
(121947, 2931, 33, 'Якщо Ви вибрали завантаження електронних грошових переказів, то потім вікно пошуку відображається повторно з відповідними рахунками з файлу X 12. Ви можете клікнути будь-який номер цього рахунку (як описано нижче), якщо Ви бажаєте зробити які-небудь коректування перед тим, як інформація грошового переказу буде застосована. Щоб застосувати зміни, клацають кнопку Обробити ERA Файл внизу сторінки. Це відкриє нове вікно з детальним повідомленням.'),
(121948, 2932, 33, 'Якщо Ви ввели дату оплати на сторінці пошуку, це перевизначить дату обліку платежів і коректування, що взяті з файлу X12. Такі дії можуть виявитися зручними для звітності, якщо Вам потрібно чеки, де зазначено вашу дата надсилання замість дати обробки страховою компанією. Зауважте, що це також впливатиме на дати попередніх платежів і коректувань, що розміщені у вторинній заявці.'),
(121949, 2933, 33, 'Якщо потрібно змінити типи даних або додати рядки або стовпці'),
(121950, 2934, 33, 'Якщо потрібно модернізувати базу даних, то перемістіть файл zip бази даних в наступну директорію'),
(121951, 2936, 33, 'Ігнорувати'),
(121952, 2937, 33, 'Захворювання'),
(121953, 2938, 33, 'Терапевт'),
(121954, 2941, 33, 'Сервіс обробки зображень'),
(121955, 2942, 33, 'Вакцинація'),
(121956, 2943, 33, 'Код вакцинації'),
(121957, 2945, 33, 'Дата вакцинації'),
(121958, 2946, 33, 'Дата закінчення терміну вакцинації'),
(121959, 2947, 33, 'Номер партії вакцини'),
(121960, 2948, 33, 'Виробник вакцини'),
(121961, 2949, 33, 'Реєстрація вакцинації'),
(121962, 2951, 33, 'Послуга вакцинації'),
(121963, 2952, 33, 'Назва вакцинації'),
(121964, 2953, 33, 'Вакцинації'),
(121965, 2954, 33, 'Вакцинувати'),
(121966, 2955, 33, 'Імунологія'),
(121967, 2956, 33, 'Імплантанти'),
(121968, 2957, 33, 'Імпорт'),
(121969, 2961, 33, 'Імпортувати сертификат у браузері.'),
(121970, 2962, 33, 'Налаштування імпорту'),
(121971, 2964, 33, 'Імпортувати пацієнта'),
(121972, 2965, 33, 'Імпорт особистих даних пацієнта'),
(121973, 2966, 33, 'Важливі коди'),
(121974, 2967, 33, 'ВАЖЛИВО: Цей інструмент вивантаження призначений лише для вивантаження документів для пацієнтів, що їх не введено для системи. Для вивантаження файлів для пацієнтів, що введені до системи, будь-ласка, використовуйте інтсрумент вивантаження, що знаходиться в панелі загальної інформації про пацієнта'),
(121975, 2969, 33, 'Імпортований з акаунту'),
(121976, 2972, 33, 'Нормалізований'),
(121977, 2973, 33, 'у'),
(121978, 2974, 33, 'У'),
(121979, 2975, 33, 'у кожне око'),
(121980, 2976, 33, 'у ліве око'),
(121981, 2977, 33, 'назально'),
(121982, 2978, 33, 'У кабінеті'),
(121983, 2979, 33, 'у праве око'),
(121984, 2980, 33, 'вдома'),
(121985, 2981, 33, 'Недіючий'),
(121986, 2982, 33, 'Вихідні дні'),
(121987, 2983, 33, 'Вхідна поштова скринька'),
(121988, 2986, 33, 'Включити захист контрольною сумою'),
(121989, 2987, 33, 'Включити повністю'),
(121990, 2988, 33, 'Включити неактивних користувачів'),
(121991, 2989, 33, 'Включити некатегоризованих'),
(121992, 2990, 33, 'Включити неструктуровані дані'),
(121993, 2991, 33, 'Включити життєво важливі показники'),
(121994, 2992, 33, 'Включити життєво важливі параметри?'),
(121995, 2993, 33, 'Включення'),
(121996, 2994, 33, 'Дохід'),
(121997, 2996, 33, 'Неповний'),
(121998, 2997, 33, 'Незавершене перерване лікування'),
(121999, 2998, 33, 'Нестримання');
INSERT INTO `lang_definitions` VALUES
(122000, 2999, 33, 'Включити результати клінічних лабораторних анализів у сертификовану технологію EHR, як структуровані дані.'),
(122001, 3000, 33, 'Неправильний пароль!'),
(122002, 3001, 33, 'збільшений:'),
(122003, 3002, 33, 'Компенсаційне страхування'),
(122004, 3003, 33, 'Невизначений'),
(122005, 3004, 33, 'Індійський'),
(122006, 3005, 33, 'Вказує відхилення від норми'),
(122007, 3006, 33, 'Вказує, що ця проблема у даний час активна'),
(122008, 3008, 33, 'Індикатор для спеціалізовоного використання'),
(122009, 3009, 33, 'Малозабезпечені пацієнти'),
(122010, 3010, 33, 'Звіт щодо малозабезпечених пацієнтів'),
(122011, 3011, 33, 'Малозабезпечені'),
(122012, 3014, 33, 'Що викликають аборт'),
(122013, 3016, 33, 'Непідходящий'),
(122014, 3017, 33, 'Інфекція/абсцес'),
(122015, 3018, 33, 'Інфекції'),
(122016, 3019, 33, 'Конс. по беспл.'),
(122017, 3020, 33, 'Беспліддя'),
(122018, 3021, 33, 'Грип 1'),
(122019, 3022, 33, 'Грип 2'),
(122020, 3023, 33, 'Протигрипозна вакцинація для пацієнтів віком >= 50 років'),
(122021, 3024, 33, 'Протигрипозна вакцинація для пацієнтів віком >= 50 років (CQM)'),
(122022, 3025, 33, 'Протигрипозна вакцинація'),
(122023, 3026, 33, 'Інф.'),
(122024, 3027, 33, 'Інф. тест 1'),
(122025, 3028, 33, 'Інф. тест 2'),
(122026, 3029, 33, 'Інф. тест 3'),
(122027, 3030, 33, 'Інф. тест 4'),
(122028, 3031, 33, 'Інф. тест 5'),
(122029, 3032, 33, 'Інф. тест 6'),
(122030, 3034, 33, 'інгаляції'),
(122031, 3035, 33, 'інгаляції'),
(122032, 3037, 33, 'Початковий користувач'),
(122033, 3038, 33, 'Травм./реаб.'),
(122034, 3039, 33, 'Що вводиться'),
(122035, 3040, 33, 'Ін''єкція'),
(122036, 3041, 33, 'Пошкоджена частина тіла'),
(122037, 3042, 33, 'Наслідки пошкодження'),
(122038, 3043, 33, 'Травма'),
(122039, 3044, 33, 'Механізм травми'),
(122040, 3045, 33, 'Оглядовий звіт про травму'),
(122041, 3046, 33, 'Травматологічне дослідження'),
(122042, 3047, 33, 'Тип травми'),
(122043, 3048, 33, 'Травма або супутнє захворювання'),
(122044, 3050, 33, 'Введені дані не починаються з MSH сегменту'),
(122045, 3051, 33, 'Шляхи введення'),
(122046, 3052, 33, 'Міжнародний нормалізаційний індекс (INR)'),
(122047, 3053, 33, 'Вст. 1'),
(122048, 3054, 33, 'Вст. 2 чи вст. 3'),
(122049, 3055, 33, 'Вст. Адресу'),
(122050, 3056, 33, 'Вст. корр.'),
(122051, 3057, 33, 'Вст. скріплення'),
(122052, 3058, 33, 'Вст. код'),
(122053, 3059, 33, 'Вст. Групу'),
(122054, 3060, 33, 'Вст. Ім"я'),
(122055, 3061, 33, 'Вст. переплати'),
(122056, 3062, 33, 'Вст. Поліс'),
(122057, 3063, 33, 'Вст. повернення'),
(122058, 3064, 33, 'Вст.підсумкова'),
(122059, 3065, 33, 'Вст.1'),
(122060, 3066, 33, 'Вст.2'),
(122061, 3067, 33, 'Вст.3'),
(122062, 3069, 33, 'Вставка дала збій '),
(122063, 3070, 33, 'Вставка старих подій у таблиці'),
(122064, 3072, 33, 'Безсоння'),
(122065, 3073, 33, 'Перевірити логи'),
(122066, 3074, 33, 'Експертиза'),
(122067, 3075, 33, 'Нестійкий / підвивих'),
(122068, 3076, 33, 'ВСТАНОВИТИ'),
(122069, 3077, 33, 'Встановити'),
(122070, 3079, 33, 'Встановити БД'),
(122071, 3080, 33, 'Встановлений реліз'),
(122072, 3081, 33, 'Інструктований'),
(122073, 3082, 33, 'Інструкція'),
(122074, 3084, 33, 'Інструкції:'),
(122075, 3085, 33, 'ID товару не відповідає переліку'),
(122076, 3086, 33, 'Інсулінозалежний діабет'),
(122077, 3087, 33, 'Страхівка'),
(122078, 3088, 33, 'страхівка'),
(122079, 3091, 33, 'Баланс страхівки'),
(122080, 3092, 33, 'Баланс страхівки належить'),
(122081, 3093, 33, 'Страхова комп.'),
(122082, 3094, 33, 'Страхові компанії'),
(122083, 3095, 33, 'Страхова компанія'),
(122084, 3096, 33, 'Пошук/добавлення страхової компанії'),
(122085, 3098, 33, 'Дата страхування'),
(122086, 3099, 33, 'Інформація щодо страхування у файлі'),
(122087, 3100, 33, 'Номери страхівки'),
(122088, 3101, 33, 'Оплата страхівки'),
(122089, 3103, 33, 'Страховик'),
(122090, 3106, 33, 'Застрахований'),
(122091, 3107, 33, 'Результат прийому'),
(122092, 3108, 33, 'Дата прийому'),
(122093, 3109, 33, 'Зниження інтелекту'),
(122094, 3113, 33, 'Внутрішня помилка - невибрані сторінки!'),
(122095, 3114, 33, 'Внутрішня помилка - не надано ID пацієнта!'),
(122096, 3115, 33, 'Внутрішня помилка щодо права доступу вивантаженого файлу!'),
(122097, 3116, 33, 'Внутрішня помилка!'),
(122098, 3117, 33, 'Внутрішня помилка, невказаний ID препарату!'),
(122099, 3118, 33, 'Внутрішня помилка: не можу знайти MSH-10'),
(122100, 3119, 33, 'Внутрішня помилка: вимога '),
(122101, 3120, 33, 'Внутрішня помилка: звернення '''),
(122102, 3121, 33, 'Внутрішня помилка:пропущений pid або звернення.'),
(122103, 3122, 33, 'Внутрішня помилка: ми не можемо сподіватись на звернення!'),
(122104, 3123, 33, 'Внутрішній ідентификатор (pid)'),
(122105, 3126, 33, 'Внутрішнє напавлення'),
(122106, 3127, 33, 'Затрачений внутрішній час'),
(122107, 3128, 33, 'Міжнародні Обов''язки'),
(122108, 3129, 33, 'Перекладач'),
(122109, 3130, 33, 'Потрібен перекладач?'),
(122110, 3131, 33, 'Інтерстиціальний пневмоконіоз'),
(122111, 3132, 33, 'Інтервал'),
(122112, 3133, 33, 'Інтервал (хвилини)'),
(122113, 3134, 33, 'Інтервал між перевіркою повідомлень (встаньвіть в 0 для ручної перевірки)'),
(122114, 3135, 33, 'Втручання'),
(122115, 3136, 33, 'Надане втручання'),
(122116, 3137, 33, 'Непереносимість'),
(122117, 3139, 33, 'внутрішньом''язовий'),
(122118, 3140, 33, 'внутрішньовенозний'),
(122119, 3141, 33, 'Вступ'),
(122120, 3144, 33, 'Недопустимий символ в'),
(122121, 3147, 33, 'Недопустимий символ для'),
(122122, 3148, 33, 'Недопустимий нецифровий символ в'),
(122123, 3149, 33, 'Недопустимий або пропущений платник в джерелі для коду '),
(122124, 3150, 33, 'Недопустима адреса отримувача. Спробуйте ще раз.'),
(122125, 3151, 33, 'Недійсні коди послуг'),
(122126, 3152, 33, 'Недопустиме визначення джерела "'),
(122127, 3153, 33, 'Недопустиме ім"я користувача або пароль'),
(122128, 3154, 33, 'Інвент.кіл.'),
(122129, 3155, 33, 'Товарно-матеріальні цінності'),
(122130, 3156, 33, 'Діяльність товарно-матеріальних цінностей'),
(122131, 3157, 33, 'Враховується і реалізується як лікарська, так і нелікарська продукція'),
(122132, 3158, 33, 'Лише товарно-матеріальні цінності та препарати для видачі'),
(122133, 3159, 33, 'Для цього призначення склад недоступний.'),
(122134, 3160, 33, 'Список товарно-матеріальних цінностей'),
(122135, 3161, 33, 'Транзакції щодо інвентаризації'),
(122136, 3162, 33, 'Рахунок'),
(122137, 3163, 33, 'рахунок'),
(122138, 3164, 33, 'Баланс рахунку'),
(122139, 3165, 33, 'Баланс рахунку не може бути внесений. Немає створеного звернення.'),
(122140, 3166, 33, 'Дата рахунку'),
(122141, 3167, 33, 'Не має дати на рахунку!'),
(122142, 3168, 33, 'Номер рахунку'),
(122143, 3169, 33, 'Вихідний номер рахунку'),
(122144, 3170, 33, 'Об''єднання вихідного номера рахунку, якщо використовується'),
(122145, 3171, 33, 'Об''єднання вихідного номера рахунку'),
(122146, 3172, 33, 'Об''єднання вих. номера рахунку'),
(122147, 3173, 33, 'Рахунок:'),
(122148, 3174, 33, 'МФПС'),
(122149, 3175, 33, 'МФПС аборт'),
(122150, 3176, 33, 'МФПС контрацепція'),
(122151, 3177, 33, 'Дані сексуального і репродуктивного здоров''я МФПС для'),
(122152, 3178, 33, 'Статистичний звіт МФПС'),
(122153, 3179, 33, 'Статистика МФПС'),
(122154, 3180, 33, 'ІПВ 1'),
(122155, 3181, 33, 'ІПВ 2'),
(122156, 3182, 33, 'ІПВ 3'),
(122157, 3183, 33, 'ІПВ 4'),
(122158, 3185, 33, 'Аритмія'),
(122159, 3186, 33, 'Дратівливість'),
(122160, 3187, 33, 'Роздратування'),
(122161, 3188, 33, 'є версія наступної бази даних з іншою мовою'),
(122162, 3189, 33, 'є інша версія наступної бази даних'),
(122163, 3190, 33, 'є новіша версія наступної бази даних'),
(122164, 3191, 33, 'є обов''язковим полем'),
(122165, 3192, 33, 'є вузлом root і не може бути видалений.'),
(122166, 3193, 33, 'є розширення наступної бази даних'),
(122167, 3195, 33, 'невідповідний чи невідомий'),
(122168, 3197, 33, 'не дійсний (десяткова частина OK).'),
(122169, 3198, 33, 'PHP використовує безпечний режим?'),
(122170, 3200, 33, 'Є текстом з макетів форми для перекладу?'),
(122171, 3201, 33, 'Є текстом з списку для перекладу?'),
(122172, 3202, 33, 'Цей файл закодований?'),
(122173, 3203, 33, 'Це є кодом типу клінічного терміну'),
(122174, 3204, 33, 'Це є типом діагнозу?'),
(122175, 3205, 33, 'Це є кодом типу медичної проблеми?'),
(122176, 3207, 33, 'Це є типом процедури/послуги?'),
(122177, 3208, 33, 'Це активне?'),
(122178, 3209, 33, 'Цей тип коду активний?'),
(122179, 3210, 33, 'Цей тип коду використовується у вимогах?'),
(122180, 3212, 33, 'Цей тип у листі оплати невидимий?'),
(122181, 3213, 33, 'Чи використовується зовнішня SQL таблиця? Якщо так, виберіть формат.'),
(122182, 3214, 33, 'надто довгий'),
(122183, 3216, 33, 'Проблема'),
(122184, 3217, 33, 'проблема'),
(122185, 3218, 33, 'Дата проблеми'),
(122186, 3219, 33, 'ID проблеми'),
(122187, 3220, 33, 'Назва проблеми'),
(122188, 3221, 33, 'Тип проблеми'),
(122189, 3222, 33, 'Типи проблеми'),
(122190, 3223, 33, 'Проблеми'),
(122191, 3224, 33, 'Проблеми (травми/терапія/алергія)'),
(122192, 3225, 33, 'Проблеми (травми/терапія/алергія):'),
(122193, 3226, 33, 'Проблеми та звернення'),
(122194, 3227, 33, 'Проблеми та звернення для'),
(122195, 3228, 33, 'Доступ до проблем не авторизований'),
(122196, 3229, 33, 'Розділ проблем'),
(122197, 3230, 33, 'Італійська'),
(122198, 3231, 33, 'Елемент'),
(122199, 3232, 33, 'елемент'),
(122200, 3233, 33, 'Елементів'),
(122201, 3234, 33, 'Завантаження елементів дало збій'),
(122202, 3235, 33, 'МЕ/л'),
(122203, 3236, 33, 'ВМС'),
(122204, 3237, 33, 'В/в'),
(122205, 3238, 33, 'Січ'),
(122206, 3239, 33, 'Січень'),
(122207, 3240, 33, 'Японський'),
(122208, 3241, 33, 'Жовтуха'),
(122209, 3243, 33, 'Опис роботи'),
(122210, 3244, 33, 'ID роботи'),
(122211, 3245, 33, 'Вивих суглоба'),
(122212, 3246, 33, 'Біль суглоба'),
(122213, 3247, 33, 'Розтягнення суглоба'),
(122214, 3248, 33, 'Лип'),
(122215, 3249, 33, 'Липень'),
(122216, 3250, 33, 'Черв'),
(122217, 3251, 33, 'Червень'),
(122218, 3252, 33, 'Трохи нижче в синій області знаходиться реєстраційна інформація, куди ви помістили параметри пошуку. Можете шукати по імені пацієнта, номеру карти, номеру звернення або даті надання допомоги або будь-якій їх комбінації. Також можете вибрати, чи хочете бачити всі рахунки, відкриті або лише виставлені (по пацієнтові). Клацніть кнопку пошуку для для виконання.'),
(122219, 3253, 33, 'Лише для мене'),
(122220, 3254, 33, 'Підтверджені записи'),
(122221, 3255, 33, 'Підтвердити'),
(122222, 3256, 33, 'Підтвердити/Зберегти'),
(122223, 3257, 33, 'J{{Підтвердити заголовок}}'),
(122224, 3258, 33, 'к, ось решта'),
(122225, 3264, 33, 'Ключ'),
(122226, 3265, 33, 'Ключові слова'),
(122227, 3266, 33, 'кг'),
(122228, 3267, 33, 'кг/м^2'),
(122229, 3269, 33, 'Рак нирки'),
(122230, 3270, 33, 'Ниркова недостатність'),
(122231, 3271, 33, 'Ниркова інфекція'),
(122232, 3272, 33, 'НКХ'),
(122233, 3273, 33, 'Нирковий трансплантант'),
(122234, 3277, 33, 'Коліно'),
(122235, 3278, 33, 'Проблеми коліна'),
(122236, 3279, 33, 'Заміна колінного суглобу'),
(122237, 3282, 33, 'Корейький'),
(122238, 3286, 33, 'Лаб'),
(122239, 3288, 33, 'Адреса сайту лабораторного обміну'),
(122240, 3289, 33, 'ID сайту лабораторного обміну'),
(122241, 3290, 33, 'Символьный ID лабораторного обміну'),
(122242, 3294, 33, 'Статус лабораторного запиту'),
(122243, 3295, 33, 'Лабораторний звіт'),
(122244, 3296, 33, 'Лабораторний результат'),
(122245, 3297, 33, 'Лабораторні результати'),
(122246, 3299, 33, 'Звіт про лабораторні результати'),
(122247, 3300, 33, 'Лабораторна послуга'),
(122248, 3301, 33, 'Результати лабораторних тестів'),
(122249, 3303, 33, 'Позначка'),
(122250, 3304, 33, 'Позначка не повинна бути пустою'),
(122251, 3305, 33, 'Стовпці позначки'),
(122252, 3306, 33, 'Позначка для цього типу'),
(122253, 3307, 33, 'Стовпці позначки повинні бути числом між 1 та 999'),
(122254, 3308, 33, 'Позначки'),
(122255, 3311, 33, 'Лабораторії'),
(122256, 3312, 33, 'Рвана рана / стан шкіри'),
(122257, 3313, 33, 'Розрив/садно'),
(122258, 3316, 33, 'Мова'),
(122259, 3317, 33, 'Код мови'),
(122260, 3318, 33, 'Додано визначення мови'),
(122261, 3319, 33, 'Інтерфейсний інструмент мови'),
(122262, 3320, 33, 'Список мов (на вибір - право записувати/добавляти)'),
(122263, 3321, 33, 'Назва мови'),
(122264, 3322, 33, 'Мова:'),
(122265, 3324, 33, 'Лаотський'),
(122266, 3325, 33, 'Прізвище'),
(122267, 3326, 33, 'Дата останньої активності'),
(122268, 3328, 33, 'Дата останнього рахунку:'),
(122269, 3330, 33, 'Минулий календарний рік'),
(122270, 3333, 33, 'Останнє звернення'),
(122271, 3340, 33, 'Останній обрахований рівень'),
(122272, 3343, 33, 'Минулий місяць'),
(122273, 3344, 33, 'Прізвище'),
(122274, 3345, 33, 'Прізвище'),
(122275, 3346, 33, 'Прізвище:'),
(122276, 3350, 33, 'Останній перегляд'),
(122277, 3351, 33, 'Останнього разу виконувавася о'),
(122278, 3352, 33, 'Останнє збереження'),
(122279, 3356, 33, 'Останнє поновлення через'),
(122280, 3357, 33, 'Остання перевірка у'),
(122281, 3358, 33, 'Останній візит'),
(122282, 3360, 33, 'Останнє повернення (2-12 міс.)'),
(122283, 3361, 33, 'Латеральна кісточка'),
(122284, 3362, 33, 'Латеральна кісточка:'),
(122285, 3363, 33, 'Латеральність'),
(122286, 3364, 33, 'Латеральність цієї методики, якщо можливо'),
(122287, 3365, 33, 'Латеральна дисплазія після ОІМ:'),
(122288, 3373, 33, 'На основі макету'),
(122289, 3374, 33, 'Редактор макету'),
(122290, 3375, 33, 'Групи макету'),
(122291, 3376, 33, 'Стиль макету'),
(122292, 3378, 33, 'Форми обробки візитів на основі макету'),
(122293, 3379, 33, 'Макети'),
(122294, 3380, 33, 'фунт'),
(122295, 3381, 33, 'Фунти'),
(122296, 3382, 33, 'ЛПНП'),
(122297, 3383, 33, 'залишіть поле пустим, якщо все ще активне'),
(122298, 3384, 33, 'Для збереження вихідного імені файлу залишіть поле пустим'),
(122299, 3385, 33, 'Для збереження попереднього паролю залишіть поле пустим'),
(122300, 3386, 33, 'Залишіть повідомлення з'),
(122301, 3387, 33, 'Залишіть форму'),
(122302, 3388, 33, 'Пуста контрольна фраза не шифрує цей документ'),
(122303, 3390, 33, 'Лівий'),
(122304, 3391, 33, 'Ліве вухо'),
(122305, 3392, 33, 'ліве вухо'),
(122306, 3394, 33, 'Лівий:'),
(122307, 3395, 33, 'Лівий: '),
(122308, 3396, 33, 'Біль у нозі/Судома'),
(122309, 3397, 33, 'Законний'),
(122310, 3399, 33, 'Формат паперу Legal'),
(122311, 3400, 33, 'Легенда:'),
(122312, 3401, 33, 'Довжина'),
(122313, 3402, 33, 'Довжина модифікатора, якщо не задана, то 0'),
(122314, 3403, 33, 'Менше ніж'),
(122315, 3404, 33, 'Менше ніж або рівна до'),
(122316, 3405, 33, 'Менш закрита інформація (на вибір - право записувати/добавляти)'),
(122317, 3406, 33, 'Лист'),
(122318, 3407, 33, 'Генератор листа'),
(122319, 3408, 33, 'Формат паперу Letter'),
(122320, 3409, 33, 'Фірмовий бланк, який підписує лікар'),
(122321, 3410, 33, 'Фірмовий бланк, який підписує пацієнт'),
(122322, 3411, 33, 'Рівень терміновості'),
(122323, 3412, 33, 'Відповідальність'),
(122324, 3413, 33, 'Медична відповідальність'),
(122325, 3414, 33, 'Ліцензія/ID'),
(122326, 3419, 33, 'Прізвище ліцензованого відповідального'),
(122327, 3420, 33, 'NPI ліцензованого відповідального'),
(122328, 3421, 33, 'UPIN ліцензованого відповідального'),
(122329, 3423, 33, 'Спосіб життя'),
(122330, 3424, 33, 'Статус способу життя'),
(122331, 3425, 33, 'Розрив або розтягнення зв''язки'),
(122332, 3426, 33, 'Курить небагато'),
(122333, 3428, 33, 'Обмеження подій'),
(122334, 3429, 33, 'Обмеження'),
(122335, 3431, 33, 'Посилання'),
(122336, 3432, 33, 'Посилання пацієнтові'),
(122337, 3433, 33, 'Приєднаний'),
(122338, 3434, 33, 'Приєднаний документ'),
(122339, 3435, 33, 'Приєднана процедура призначення'),
(122340, 3436, 33, 'Посилання на документ'),
(122341, 3437, 33, 'Посилання на призначену процедуру'),
(122342, 3438, 33, 'Список'),
(122343, 3439, 33, 'Поле зі списком'),
(122344, 3440, 33, 'поле зі списком'),
(122345, 3441, 33, 'поле зі списком з/доб.'),
(122346, 3442, 33, 'Поле зі списком з/доб.'),
(122347, 3443, 33, 'Редактор списку'),
(122348, 3444, 33, 'Список звернень'),
(122349, 3445, 33, 'Список груп'),
(122350, 3446, 33, 'Список страхових компаній'),
(122351, 3448, 33, 'Елементи списку не можуть починатися з числа'),
(122352, 3449, 33, 'Елементи списку містять заборонені символ(и).'),
(122353, 3451, 33, 'Вивести списки'),
(122354, 3452, 33, 'Назва списку'),
(122355, 3453, 33, 'Назва списку не може починатися з чисел'),
(122356, 3454, 33, 'Вивести призначення'),
(122357, 3455, 33, 'Список використовується через вищезгаданий варіант типу даних для країни.'),
(122358, 3456, 33, 'Список використовується через вищезгаданий варіант типа даних для області.'),
(122359, 3457, 33, 'Прослухуваний порт сервера syslog TLS RFC 5425.'),
(122360, 3458, 33, 'Списки'),
(122361, 3459, 33, 'Литовська'),
(122362, 3460, 33, 'Прижиттєвий заповіт'),
(122363, 3461, 33, 'LLL:'),
(122364, 3462, 33, 'Остання менструація'),
(122365, 3463, 33, 'Завантажити повний перелік'),
(122366, 3464, 33, 'Завантажити визначення'),
(122367, 3465, 33, 'Завантажити налаштування лабораторії'),
(122368, 3466, 33, 'Завантажити налаштування питань ОЕ'),
(122369, 3467, 33, 'Завантажити визначення призначення'),
(122370, 3468, 33, 'Завантажити питання вмісту призначення'),
(122371, 3470, 33, 'ЗАВАНТАЖЕННЯ'),
(122372, 3471, 33, 'Завантаження файлів у базу даних. Це займе деякий час…'),
(122373, 3472, 33, 'Знижене розуміння'),
(122374, 3473, 33, 'Локально'),
(122375, 3476, 33, 'Локальний'),
(122376, 3477, 33, 'Місцерозташування'),
(122377, 3478, 33, 'Розміщення'),
(122378, 3479, 33, 'Розташування машини libreehr може містити секретні дані, тому рекомендується вручну видалити їх після використання'),
(122379, 3480, 33, 'Розміщення цієї партії'),
(122380, 3481, 33, 'Невизначене розміщення'),
(122381, 3482, 33, 'Місце, де Hylafax зберігає факси.'),
(122382, 3483, 33, 'Місце, де зберігаються сканограми.'),
(122383, 3484, 33, 'Розміщення:'),
(122384, 3485, 33, 'Заблокувати'),
(122385, 3492, 33, 'Увійти'),
(122386, 3493, 33, 'Увійти'),
(122387, 3494, 33, 'Вийти'),
(122388, 3495, 33, 'Увійшов'),
(122389, 3496, 33, 'Увійшов як'),
(122390, 3497, 33, 'Увійшов як: '),
(122391, 3498, 33, 'Вийшов.'),
(122392, 3499, 33, 'Вхід'),
(122393, 3500, 33, 'Логін'),
(122394, 3501, 33, 'логін'),
(122395, 3503, 33, 'Логін до віддаленого хоста'),
(122396, 3504, 33, 'Невдалий вхід до цього віддаленого хоста'),
(122397, 3505, 33, 'Вийти'),
(122398, 3506, 33, 'вийти'),
(122399, 3507, 33, 'Журнали'),
(122400, 3508, 33, 'Оглядач журналів'),
(122401, 3510, 33, 'Знайти'),
(122402, 3511, 33, 'Партія'),
(122403, 3512, 33, 'Пропущений ID партії'),
(122404, 3513, 33, 'Номер партії'),
(122405, 3514, 33, 'Низький'),
(122406, 3515, 33, 'Низький пріоритет'),
(122407, 3516, 33, 'Вкорочена нога'),
(122408, 3517, 33, 'Найнижчий пріоритет'),
(122409, 3519, 33, 'Поперековий відділ хребта'),
(122410, 3520, 33, 'ОБІД'),
(122411, 3521, 33, 'Обід'),
(122412, 3522, 33, 'Рак легень'),
(122413, 3523, 33, 'Хірургія раку легень'),
(122414, 3524, 33, 'ЛЕГЕНІ:'),
(122415, 3525, 33, 'Легені:'),
(122416, 3526, 33, 'Вовчак'),
(122417, 3528, 33, 'М'),
(122418, 3529, 33, 'Категорія МА'),
(122419, 3530, 33, 'Відмова прийому клієнта MA'),
(122420, 3531, 33, 'Статистика MA'),
(122421, 3533, 33, 'Відправка пошти'),
(122422, 3534, 33, 'Основний'),
(122423, 3535, 33, 'Основна адреса'),
(122424, 3536, 33, 'Основна область екрану'),
(122425, 3537, 33, 'Список основної активної медикаментозної алергії.'),
(122426, 3538, 33, 'Список основного активного медикаментозного лікування.'),
(122427, 3539, 33, 'Підтримує оновлений список проблем для поточних і активних діагнозів.'),
(122428, 3540, 33, 'Створює зміни в поточних категоріях.'),
(122429, 3541, 33, 'Створити новий запис на прийом для'),
(122430, 3542, 33, 'Переконайтеся, що "'),
(122431, 3543, 33, 'Створення пакетних текстових файлів для завантаження в інформаційний центр, і буде позначеним як рахунок'),
(122432, 3545, 33, 'Дискомфорт:'),
(122433, 3548, 33, 'Чоловіча'),
(122434, 3549, 33, 'Чоловічі презервативи'),
(122435, 3550, 33, 'Чоловічий VSC'),
(122436, 3552, 33, 'Маммографія'),
(122437, 3553, 33, 'Керування'),
(122438, 3556, 33, 'Керування перекладами'),
(122439, 3557, 33, 'Керівний склад'),
(122440, 3558, 33, 'Обов''язкові й особливі поля'),
(122441, 3559, 33, 'Лише обов''язкові чи особливі поля, з перевіркою на повтори, без пошуку'),
(122442, 3560, 33, 'Лише обов''язкові чи особливі поля, з пошуком та перевіркою на повтори'),
(122443, 3561, 33, 'Керівництво'),
(122444, 3562, 33, 'Відправка вручну'),
(122445, 3563, 33, 'Виробник'),
(122446, 3565, 33, 'Бер'),
(122447, 3568, 33, 'Березень'),
(122448, 3569, 33, 'Сімейний стан'),
(122449, 3571, 33, 'Помітити як сплачене, але пропустіть виставлений рахунок'),
(122450, 3572, 33, 'Помітити як очищене'),
(122451, 3573, 33, 'Помітити як неоплачене'),
(122452, 3574, 33, 'Помітити ці звіти як переглянуті'),
(122453, 3575, 33, 'Помітити як очищене'),
(122454, 3576, 33, 'Одружений'),
(122455, 3578, 33, 'Маска'),
(122456, 3579, 33, 'Маска для номерів рахунків'),
(122457, 3580, 33, 'Маска для ID пацієнта'),
(122458, 3581, 33, 'Маска для ID продукції'),
(122459, 3582, 33, 'Відповідність'),
(122460, 3583, 33, 'Відповідність вибору'),
(122461, 3591, 33, 'Максимум'),
(122462, 3592, 33, 'досягнуто максимальне число файлів - перезавантажте названі нижче'),
(122463, 3594, 33, 'Пахвова область справа:'),
(122464, 3595, 33, 'Максимальний вік'),
(122465, 3596, 33, 'Максимум символів'),
(122466, 3597, 33, 'Максимальний простій в секундах до входу в систему.'),
(122467, 3600, 33, 'Максимально розумні запаси, 0, якщо не застосовно'),
(122468, 3601, 33, 'Максимальний розмір'),
(122469, 3602, 33, 'Максимальний розмір (щоб дозволити довільний розмір, введіть 0)'),
(122470, 3603, 33, 'Травень'),
(122471, 3604, 33, 'Мікроскопія і виділення культури'),
(122472, 3605, 33, 'мкг'),
(122473, 3607, 33, 'Означає, що жоден з трьох останніх паролів не дозволений для заміни паролю.'),
(122474, 3609, 33, 'Код групи одиниць виміру'),
(122475, 3611, 33, 'Система заходів'),
(122476, 3612, 33, 'Внутрішня область кісточки'),
(122477, 3613, 33, 'Медична допомога'),
(122478, 3614, 33, 'Медичний'),
(122479, 3615, 33, 'Медичний аборт'),
(122480, 3616, 33, 'Медична адміністрація'),
(122481, 3617, 33, 'Анамнез'),
(122482, 3618, 33, 'Медичний результат'),
(122483, 3619, 33, 'Медичний результат'),
(122484, 3620, 33, 'Медична проблема'),
(122485, 3621, 33, 'Медична проблема'),
(122486, 3622, 33, 'Перелік медичних проблем'),
(122487, 3623, 33, 'Медичні проблеми'),
(122488, 3624, 33, 'Медичний запис'),
(122489, 3625, 33, 'Медичний запис #'),
(122490, 3626, 33, 'Медичні записи'),
(122491, 3627, 33, 'Медичні записи відправлені'),
(122492, 3629, 33, 'Медичний звіт надано'),
(122493, 3630, 33, 'Медична система'),
(122494, 3631, 33, 'Тип лікування'),
(122495, 3632, 33, 'Захворювання /анамнез (на вибір - право записувати/добавляти)'),
(122496, 3633, 33, 'Частина В безкоштовної медичної допомоги'),
(122497, 3634, 33, 'Реферрер Medicare є засобом візуалізації'),
(122498, 3635, 33, 'Препарат'),
(122499, 3636, 33, 'Список медикаментозної алергії'),
(122500, 3637, 33, 'Перелік медикаментозних проблем'),
(122501, 3638, 33, 'Список ліків'),
(122502, 3639, 33, 'Узгоджене лікування виконане?'),
(122503, 3640, 33, 'Медикаменти'),
(122504, 3641, 33, 'Медикаменти:'),
(122505, 3642, 33, 'Одиниці випуску медикаменту'),
(122506, 3643, 33, 'По-батькові'),
(122507, 3645, 33, 'Статистичний звіт члена Асоціації'),
(122508, 3646, 33, 'Проблеми пам''яті'),
(122509, 3647, 33, 'Чоловіки'),
(122510, 3648, 33, 'Чоловіки та жінки'),
(122511, 3649, 33, 'Лише чоловіки'),
(122512, 3650, 33, 'Менархе'),
(122513, 3651, 33, 'Менопауза'),
(122514, 3652, 33, 'Рясна менструація'),
(122515, 3653, 33, 'Менструальний цикл'),
(122516, 3654, 33, 'Психічне захворювання'),
(122517, 3657, 33, 'Об"єднати'),
(122518, 3658, 33, 'Об"єднання завершено.'),
(122519, 3659, 33, 'Об"єднати пацієнтів'),
(122520, 3661, 33, 'Повідомлення'),
(122521, 3662, 33, 'Центр повідомлень і нагадувань'),
(122522, 3663, 33, 'Вміст повідомлення не є звичайним текстом, тому буде збережений як документ'),
(122523, 3665, 33, 'Надіслане повідомлення'),
(122524, 3666, 33, 'Статус повідомлення'),
(122525, 3669, 33, 'Тип повідомлення'),
(122526, 3670, 33, 'ПОВІДОМЛЕННЯ:'),
(122527, 3671, 33, 'Повідомлення'),
(122528, 3672, 33, 'Повідомлення, які Ви надліслали сьогодні'),
(122529, 3673, 33, 'Метод'),
(122530, 3674, 33, 'Метод і певний результат'),
(122531, 3675, 33, 'Метод для відправлення вихідних e-mail.'),
(122532, 3676, 33, 'Метод знищення'),
(122533, 3677, 33, 'Мексиканець/американець мексиканського походження/чикано'),
(122534, 3679, 33, 'мг'),
(122535, 3680, 33, 'мг/1куб.см.'),
(122536, 3681, 33, 'мг/2куб.см.'),
(122537, 3682, 33, 'мг/3куб.см.'),
(122538, 3683, 33, 'мг/4куб.см.'),
(122539, 3684, 33, 'мг/5куб.см.'),
(122540, 3685, 33, 'мг/дл'),
(122541, 3686, 33, 'Середній'),
(122542, 3687, 33, 'По-батькові'),
(122543, 3688, 33, 'По-батькові'),
(122544, 3690, 33, 'Специаліст DEA середнього рівня'),
(122545, 3691, 33, 'Ім''я відповідального середнього рівня'),
(122546, 3692, 33, 'Прізвище відповідального середнього рівня'),
(122547, 3693, 33, 'Ініціали відповідального середнього рівня'),
(122548, 3694, 33, 'UPIN відповідального середнього рівня'),
(122549, 3695, 33, 'Вираз обличчя'),
(122550, 3696, 33, 'Мігрант чи сезонний робочий?'),
(122551, 3697, 33, 'Мігрант /сезонний робочий'),
(122552, 3698, 33, 'млн/куб.мм'),
(122553, 3702, 33, 'Mime-тип'),
(122554, 3703, 33, 'Мін'),
(122555, 3704, 33, 'мін'),
(122556, 3705, 33, 'Мінімальний вік'),
(122557, 3706, 33, 'Легке розтягнення суглоба +/- синовіїт'),
(122558, 3708, 33, 'Хвилина'),
(122559, 3709, 33, 'хвилини'),
(122560, 3710, 33, 'Хвилини'),
(122561, 3712, 33, 'Інше'),
(122562, 3713, 33, 'Варіанти інших рахунків'),
(122563, 3714, 33, 'Варіанти інших рахунків для HCFA-1500'),
(122564, 3715, 33, 'Варіанти інших рахунків HCFA'),
(122565, 3716, 33, 'Різне'),
(122566, 3717, 33, 'Пропущений'),
(122567, 3718, 33, 'пропущений'),
(122568, 3719, 33, 'Пропущене обов''язкове поле'),
(122569, 3720, 33, 'Пропущена оплата'),
(122570, 3721, 33, 'Пропущений лише модифікатор'),
(122571, 3722, 33, 'Пропущений чи недійсний'),
(122572, 3723, 33, 'Пропущений PID.'),
(122573, 3724, 33, 'Пропущена дата звіту'),
(122574, 3725, 33, 'Пропущений слеш після платника для коду '),
(122575, 3726, 33, 'Змішаний'),
(122576, 3727, 33, 'мл'),
(122577, 3728, 33, 'ММ/ДД/РРРР'),
(122578, 3729, 33, 'мм. рт. ст.'),
(122579, 3730, 33, 'мм. рт. ст.'),
(122580, 3731, 33, 'Частота материнської смертності 1'),
(122581, 3732, 33, 'Частота материнської смертності 2'),
(122582, 3733, 33, 'Мобильний'),
(122583, 3734, 33, 'Мобильний телефон'),
(122584, 3735, 33, 'Модиф.'),
(122585, 3738, 33, 'Пріоритет стримування'),
(122586, 3740, 33, 'Стримування/низький пріоритет'),
(122587, 3741, 33, 'Модифікатор'),
(122588, 3742, 33, 'Модифікатори'),
(122589, 3743, 33, 'Змінений'),
(122590, 3745, 33, 'Змінені платежі'),
(122591, 3746, 33, 'Дов.модиф.'),
(122592, 3753, 33, 'Пон.'),
(122593, 3754, 33, 'з Пон по Пт'),
(122594, 3755, 33, 'Пн, Ср &amp; Пт'),
(122595, 3756, 33, 'Понеділок'),
(122596, 3758, 33, 'Місяць'),
(122597, 3759, 33, 'місяць'),
(122598, 3760, 33, 'Огляд за місяць'),
(122599, 3761, 33, 'Місяць(і)'),
(122600, 3762, 33, 'Щомісячний дохід'),
(122601, 3763, 33, 'Місяці'),
(122602, 3765, 33, 'Знайдено понад 100 записів. Будь-ласка, уточніть критерії пошуку.'),
(122603, 3766, 33, 'Понад 50 результатів. Будь-ласка, конкретизуйте пошук.'),
(122604, 3767, 33, 'Клацніть на заголовку, щоб змінити порядок сортування в стовбці (працює для більшості стовбців).'),
(122605, 3768, 33, 'Найновіший з'),
(122606, 3770, 33, 'Найновіші життєво-важливі показники від:'),
(122607, 3771, 33, 'Мати'),
(122608, 3772, 33, 'Прізвище матері'),
(122609, 3774, 33, 'Рот'),
(122610, 3775, 33, 'Перемістити'),
(122611, 3776, 33, 'Перемістити документ в категорію:'),
(122612, 3777, 33, 'Перемістіть вниз'),
(122613, 3778, 33, 'Збій переміщення!'),
(122614, 3779, 33, 'Перемістити до піцієнта'),
(122615, 3780, 33, 'Перемістити до:'),
(122616, 3781, 33, 'Перемістити вище'),
(122617, 3782, 33, 'Переміщення'),
(122618, 3783, 33, 'Пан'),
(122619, 3784, 33, 'MRN (pid)'),
(122620, 3785, 33, 'Пані'),
(122621, 3786, 33, 'Панна'),
(122622, 3787, 33, 'MSH-11'),
(122623, 3788, 33, 'MSH-3.1'),
(122624, 3789, 33, 'MSH-4.1'),
(122625, 3790, 33, 'MSH-5.1'),
(122626, 3791, 33, 'MSH-6.1'),
(122627, 3794, 33, 'Код MSP'),
(122628, 3795, 33, 'Код зменшення MSP'),
(122629, 3796, 33, 'Інструментарій пеекладу'),
(122630, 3797, 33, 'Множинні ділянки'),
(122631, 3798, 33, 'Кілька файлів можна вивантажити одночасно, вибираючи їх за допомогою CTRL+Click чи SHIFT+Click.'),
(122632, 3799, 33, 'Декілька партій'),
(122633, 3800, 33, 'Складні модифікатори можна відокремлювати двокрапками або проміжками, максимально 4 (М1:М2:М3:М4)'),
(122634, 3802, 33, 'Багатонаціональний'),
(122635, 3803, 33, 'Шум:'),
(122636, 3804, 33, 'М''язовий біль'),
(122637, 3805, 33, 'М''язові болі'),
(122638, 3806, 33, 'Гіперемія шкіри над м''язом'),
(122639, 3807, 33, 'М''язова регідність'),
(122640, 3808, 33, 'Опухлість м''за'),
(122641, 3809, 33, 'Гіпертермія в ділянці м''за'),
(122642, 3810, 33, 'М''язовий'),
(122643, 3811, 33, 'Ураження м''за'),
(122644, 3812, 33, 'Кістково-м''язовий'),
(122645, 3813, 33, 'Якщо ідентифікація через SMPT не використовується, то має бути порожнім'),
(122646, 3814, 33, 'Визначається спільно'),
(122647, 3815, 33, 'ДТП'),
(122648, 3818, 33, 'самостійно'),
(122649, 3821, 33, 'Не застос.'),
(122650, 3822, 33, 'не застос.'),
(122651, 3823, 33, 'ПІБ'),
(122652, 3825, 33, 'Назва (клацніть для уточнення)'),
(122653, 3826, 33, 'Назва 1'),
(122654, 3827, 33, 'Назва 2'),
(122655, 3828, 33, 'Назва і заголовок органу, що керує імунізацію'),
(122656, 3831, 33, 'Назва подій'),
(122657, 3832, 33, 'Назва страхової компанії'),
(122658, 3833, 33, 'Прізвище спеціаліста'),
(122659, 3834, 33, 'Прізвище того, хто відправляє нагадування для пацієнта'),
(122660, 3835, 33, 'Переклад назви'),
(122661, 3836, 33, 'Назва/значення'),
(122662, 3837, 33, 'Назва:'),
(122663, 3838, 33, 'НІЗДРІ:'),
(122664, 3839, 33, 'НІЗДРІ: Справа в нормі'),
(122665, 3840, 33, 'Слизова носа рожева, перегородка посередині'),
(122666, 3841, 33, 'Записи в національній нотації'),
(122667, 3842, 33, 'Налаштування записів в національній нотації'),
(122668, 3843, 33, 'Кнопки заміни записів в національній нотації'),
(122669, 3844, 33, 'Національність'),
(122670, 3845, 33, 'Записи в національній нотації'),
(122671, 3847, 33, 'Корінний гаваєць або інший житель островів Тихого Океану'),
(122672, 3852, 33, 'Нудота'),
(122673, 3854, 33, 'Навігація'),
(122674, 3855, 33, 'Область навігації включає варіанти звернення'),
(122675, 3856, 33, 'Область навігації використовує всю висоту вікна'),
(122676, 3857, 33, 'Форми відвідування для області навігації'),
(122677, 3858, 33, 'Ширина області навігації'),
(122678, 3859, 33, 'Меню навігації складається з кількох пар перемикачів'),
(122679, 3860, 33, 'Навігаційне меню у вигляді дерева'),
(122680, 3861, 33, 'Навігація використовує меню-слайдер'),
(122681, 3862, 33, 'NDC'),
(122682, 3863, 33, 'Дані NDC'),
(122683, 3864, 33, 'Номер NDC'),
(122684, 3866, 33, 'Шия'),
(122685, 3867, 33, 'Проблеми з шиєю'),
(122686, 3868, 33, 'Гнучкість шиї'),
(122687, 3869, 33, 'Необхідно ввести опис'),
(122688, 3870, 33, 'Необхідно ввести повернене значення'),
(122689, 3871, 33, 'Необхідно ввести ідентифікатор'),
(122690, 3872, 33, 'Необхідно ввести назву'),
(122691, 3873, 33, 'Потребує авторизації'),
(122692, 3874, 33, 'Потребує підтвердження'),
(122693, 3875, 33, 'Потребує повторного виставлення рахунку'),
(122694, 3876, 33, 'Негативний'),
(122695, 3877, 33, 'Заперечення'),
(122696, 3880, 33, 'Ушкодження нерва'),
(122697, 3881, 33, 'Неврологічний статус / ушкодження нерва'),
(122698, 3882, 33, 'Заціпеніння'),
(122699, 3883, 33, 'Слабкість'),
(122700, 3884, 33, 'Неврологічний'),
(122701, 3885, 33, 'Ніколи'),
(122702, 3886, 33, 'Не вживав алкоголь'),
(122703, 3887, 33, 'Не палив'),
(122704, 3888, 33, 'Новий'),
(122705, 3889, 33, 'Новий =>'),
(122706, 3890, 33, 'Нові отримувачі'),
(122707, 3892, 33, 'Новий вид аллергії'),
(122708, 3894, 33, 'Новий запис на прийом'),
(122709, 3895, 33, 'Нові категорії'),
(122710, 3896, 33, 'Нова категорія'),
(122711, 3897, 33, 'Нові клієнти'),
(122712, 3898, 33, 'Нова консультація'),
(122713, 3899, 33, 'Нова група'),
(122714, 3900, 33, 'Доданий новий набір визначень'),
(122715, 3901, 33, 'Новий документ'),
(122716, 3902, 33, 'Нові документи'),
(122717, 3904, 33, 'Нове звернення'),
(122718, 3905, 33, 'Нове звернення створене з id'),
(122719, 3906, 33, 'Нова форма звернення'),
(122720, 3907, 33, 'Доступ до нових звертань не дозволено'),
(122721, 3908, 33, 'Нове звертання'),
(122722, 3909, 33, 'Інформація про новий медичний заклад'),
(122723, 3910, 33, 'Новий файл'),
(122724, 3911, 33, 'Нові файли'),
(122725, 3912, 33, 'Нова група'),
(122726, 3913, 33, 'Інформація щодо нової групи'),
(122727, 3914, 33, 'Нове введення/стан'),
(122728, 3916, 33, 'Нове обмеження подій'),
(122729, 3917, 33, 'Новий список'),
(122730, 3918, 33, 'Нові призначення'),
(122731, 3919, 33, 'Новий пункт (розділ)'),
(122732, 3920, 33, 'Новий пароль'),
(122733, 3921, 33, 'Новий пацієнт'),
(122734, 3922, 33, 'НОВИЙ ПАЦІЄНТ'),
(122735, 3923, 33, 'Звернення нового пацієнта'),
(122736, 3924, 33, 'Нова форма пацієнта'),
(122737, 3925, 33, 'ID нового пацієнта'),
(122738, 3926, 33, 'Нова оплата'),
(122739, 3928, 33, 'Новий пункт'),
(122740, 3929, 33, 'Нові результати з Lab Exchange'),
(122741, 3930, 33, 'Новий пошук'),
(122742, 3931, 33, 'Новий розгляд'),
(122743, 3932, 33, 'Новий користувач'),
(122744, 3934, 33, 'Новий візит'),
(122745, 3935, 33, 'Новий/Пошук'),
(122746, 3936, 33, 'Статус рахунка NewCrop'),
(122747, 3937, 33, 'Адміністрація NewCrop'),
(122748, 3938, 33, 'Виклик NewCrop дав збій'),
(122749, 3939, 33, 'Лікар NewCrop'),
(122750, 3944, 33, 'Найменування eRx NewCrop'),
(122751, 3945, 33, 'Наименування партнера eRx NewCrop'),
(122752, 3946, 33, 'Пароль eRx NewCrop'),
(122753, 3947, 33, 'Рівень доступу eRx NewCrop'),
(122754, 3948, 33, 'Рівень доступу eRx NewCrop'),
(122755, 3949, 33, 'Адреса вузла eRx NewCrop'),
(122756, 3954, 33, 'Адреса веб-служби eRx NewCrop'),
(122757, 3955, 33, 'Менеджер NewCrop'),
(122758, 3956, 33, 'Мед. запис для NewCrop'),
(122759, 3957, 33, 'Фахівець середнього рівня NewCrop з правом призначення рецептурних препаратів'),
(122760, 3958, 33, 'Медсестра NewCrop'),
(122761, 3959, 33, 'Контролюючий лікар NewCrop'),
(122762, 3961, 33, 'Газета'),
(122763, 3962, 33, 'Наступний'),
(122764, 3964, 33, 'Наступний день'),
(122765, 3965, 33, 'Наступний місяць'),
(122766, 3966, 33, 'Наступний місяць (утримайте для меню)'),
(122767, 3967, 33, 'Наступний запланований запуск'),
(122768, 3968, 33, 'Наступний тиждень'),
(122769, 3969, 33, 'Наступний рік (утримайте для меню)'),
(122770, 3971, 33, 'Псевдонім'),
(122771, 3973, 33, 'Пітливість вночі'),
(122772, 3974, 33, 'Nl зовнішніх статевих органів, слизової вагіни, шийки матки'),
(122773, 3975, 33, 'Ні'),
(122774, 3976, 33, 'НІ'),
(122775, 3977, 33, 'Немає доступу'),
(122776, 3978, 33, 'Активних нагадувань для пацієнта немає.'),
(122777, 3979, 33, 'Аденопатії немає (обов''язково 2 ділянки)'),
(122778, 3980, 33, 'Не знайдено типу причини для коригування'),
(122779, 3981, 33, 'Немає болючості/новоутворень у придатках'),
(122780, 3983, 33, 'Записів на прийом немає'),
(122781, 3985, 33, 'На даний час біллінгова система є неактивною'),
(122782, 3986, 33, 'Для включення в експорт OFX рахунків не виявлено'),
(122783, 3987, 33, 'Для включення в експорт OFX рахунків не виявлено<br>'),
(122784, 3989, 33, 'Не вказаний код!'),
(122785, 3992, 33, 'Нема діагноза'),
(122786, 3993, 33, 'Жодних документів не знайдено'),
(122787, 3994, 33, 'Жодних звернень не було створено'),
(122788, 3995, 33, 'Немає кінцевої дати'),
(122789, 3996, 33, 'Жодного запису не знайдено. Використовуйте подану нижче форму, щоби добавити запис.'),
(122790, 3997, 33, 'Помилок не знайдено'),
(122791, 3998, 33, 'Жодних подій немає.'),
(122792, 4000, 33, 'Жодних файлів на етапі встановлення'),
(122793, 4001, 33, 'Жодна група не обрана.'),
(122794, 4002, 33, 'Немає жодних гриж.'),
(122795, 4005, 33, 'Без травми/захворювань'),
(122796, 4006, 33, 'Не знайдені страхові компанії'),
(122797, 4007, 33, 'Проблем немає'),
(122798, 4008, 33, 'Для цього звернення проблем немає'),
(122799, 4009, 33, 'У вибраній категорії немає пунктів'),
(122800, 4010, 33, 'Не обраний жодний пункт!'),
(122801, 4025, 33, 'Жодного зареєстрованого файлу немає на обрану датн'),
(122802, 4027, 33, 'Немає новоутворень, болючості'),
(122803, 4028, 33, 'Для наданого Re коду індентифікації немає відповідного запису щодо пацієнта.'),
(122804, 4029, 33, 'Жодного співпадіння. Спробуйте пошукати знову.'),
(122805, 4030, 33, 'Співпадінь не виявлено.');
INSERT INTO `lang_definitions` VALUES
(122806, 4031, 33, 'Співпадінь не виявлено. Оформити нового пацієнта?'),
(122807, 4032, 33, 'Жодних відповідних записів не знайдено'),
(122808, 4033, 33, 'Нових результатів не виявлено'),
(122809, 4034, 33, 'Немає записів'),
(122810, 4035, 33, 'Органомегалія не простежується'),
(122811, 4036, 33, 'За цей період жодних відкритих не виявлено'),
(122812, 4037, 33, 'Жодних інших телефонних номерів немає.'),
(122813, 4039, 33, 'Партнерів не знайдено'),
(122814, 4040, 33, 'Для поданих критеріїв вибору жодного запису щодо паціента не знайдено.'),
(122815, 4041, 33, 'Для поданого Re коду індентифікації жодного запису щодо пацієнта не знайдено.'),
(122816, 4042, 33, 'Немає перифирійних набряків.'),
(122817, 4043, 33, 'Жодної аптеки не знайдено'),
(122818, 4044, 33, 'Призначень не знайдено'),
(122819, 4045, 33, 'Захворювань/травм не представлено'),
(122820, 4046, 33, 'Відсутні попередні введення.'),
(122821, 4047, 33, 'Жоден медичний заклад не визначено як Основний'),
(122822, 4048, 33, 'Немає попередніх звернень'),
(122823, 4049, 33, 'Немає процедур для цього звернення'),
(122824, 4051, 33, 'Не знайдено спеціалістів'),
(122825, 4052, 33, 'Немає висипу або аномальних уражень.'),
(122826, 4053, 33, 'Записів не знайдено.'),
(122827, 4055, 33, 'Жодних записів не втявлено. Розширте критерії пошуку.'),
(122828, 4056, 33, 'Нагадувань немає'),
(122829, 4057, 33, 'Для зазначених критеріїв пошуку результатів не знайдено.'),
(122830, 4058, 33, 'Результатів немає'),
(122831, 4059, 33, 'Результатів не знайдено'),
(122832, 4060, 33, 'Під час пошуку результатів не знайдено.'),
(122833, 4061, 33, 'Результатів не знайдено, спробуйте ще раз.'),
(122834, 4062, 33, 'Результатів немає, спробуйте ще раз.'),
(122835, 4063, 33, 'Результатів немає, спробуйте ще раз.'),
(122836, 4065, 33, 'Не показувати'),
(122837, 4067, 33, 'Пазухи неболючі:'),
(122838, 4068, 33, 'Не спостерігається заглибин на шкірі чи вузлів на грудях'),
(122839, 4069, 33, 'ТАКОГО КОНТЕКСТНОГО ІМЕНІ НЕМАЄ'),
(122840, 4070, 33, 'Таблицю не вибрано! Виберіть таблицю.'),
(122841, 4071, 33, 'Яєчка неболючі, новоутворень немає'),
(122842, 4072, 33, 'Немає тремтіння і підйомів'),
(122843, 4075, 33, 'Немає відвідувань'),
(122844, 4076, 33, 'Життєво важливі показники не зареєстровані.'),
(122845, 4077, 33, 'Ні, відмінити'),
(122846, 4078, 33, 'Страхування автотранспортного засобу незалежно від винуватця зіткнення є первинним'),
(122847, 4079, 33, 'Нет:'),
(122848, 4080, 33, 'Ніктурія, нічна поліурія'),
(122849, 4081, 33, 'Не оплачено'),
(122850, 4082, 33, 'Ненаданий звіт'),
(122851, 4083, 33, 'Пошкодження невизначеного типу'),
(122852, 4084, 33, 'Неелектроннтй'),
(122853, 4085, 33, 'Не-інсулінонезалежний діабет'),
(122854, 4086, 33, 'Не застрахований'),
(122855, 4087, 33, 'Медичні аспекти, не пов''язані з сексуальним і репродуктивним здоров"ям'),
(122856, 4088, 33, 'Немедичні аспекти, не пов''язані з сексуальним і репродуктивним здоров"ям'),
(122857, 4089, 33, 'Немає'),
(122858, 4090, 33, 'немає'),
(122859, 4091, 33, 'Не визначено'),
(122860, 4092, 33, 'Жоден не зареєстрований'),
(122861, 4093, 33, 'Жоден із зазначеного вище'),
(122862, 4094, 33, 'Жодна лінійка не повинна залишатися повністю пустою'),
(122863, 4095, 33, 'Не-інсулінонезалежний діабет'),
(122864, 4096, 33, 'Також ні'),
(122865, 4097, 33, 'Звичайний'),
(122866, 4098, 33, 'Звичайний рахунок'),
(122867, 4099, 33, 'Звичайне кардіологічне обстеження:'),
(122868, 4100, 33, 'Звичайне кардіологічне обстеження: '),
(122869, 4101, 33, 'Звичайне пульмонологічне обстеження:'),
(122870, 4102, 33, 'Звичайне пульмонологічне обстеження: '),
(122871, 4103, 33, 'Звичайний візит в кабінет лікаря'),
(122872, 4104, 33, 'Звичайна ротоглотка (мезофарінкс):'),
(122873, 4105, 33, 'Звичайний справа'),
(122874, 4106, 33, 'Звичайний справа:'),
(122875, 4107, 33, 'Звичайний вигляд'),
(122876, 4108, 33, 'звичайний:'),
(122877, 4109, 33, 'Зазвичай, повинно бути перевірено. Не пов''язано з контролем доступу.'),
(122878, 4112, 33, 'Норвезька'),
(122879, 4115, 33, 'Ніс'),
(122880, 4116, 33, 'Носова кровотеча'),
(122881, 4117, 33, 'немає букви чи цифри'),
(122882, 4119, 33, 'Для кодів чи їх типів потрібні не всі поля.'),
(122883, 4120, 33, 'Не дозволено'),
(122884, 4121, 33, 'Не дозволено видаляти групу адміністраторів'),
(122885, 4122, 33, 'Редагування не дозволено'),
(122886, 4123, 33, 'Інактивація всіх об''єктів безпеки не дозволена'),
(122887, 4124, 33, 'Не дозволено інактивувати те, що стосується адміністраторів управління доступом (ACL)'),
(122888, 4125, 33, 'Видаляти користувача admin з групи адміністраторів не дозволено'),
(122889, 4126, 33, 'Видаляти цього користувача з групи адміністраторів не дозволено'),
(122890, 4127, 33, 'Не відповідний'),
(122891, 4128, 33, 'Доступ до модуля PostCalendar не дозволений'),
(122892, 4129, 33, 'Доступу немає'),
(122893, 4130, 33, 'Доступу немає'),
(122894, 4131, 33, 'Для цієї групи доступу немає!'),
(122895, 4132, 33, 'Для цієї групи доступу немає.'),
(122896, 4133, 33, 'Для керування користувачами доступу немає!'),
(122897, 4134, 33, 'Для підписування результатів доступу немає'),
(122898, 4135, 33, 'Не доступно'),
(122899, 4137, 33, 'Рахунок не виставлено'),
(122900, 4138, 33, 'Не зареєстровано'),
(122901, 4139, 33, 'Не перевірено'),
(122902, 4140, 33, 'Не закодовано'),
(122903, 4141, 33, 'Не підлягає'),
(122904, 4143, 33, 'Не обстежений'),
(122905, 4144, 33, 'Не обстежений:'),
(122906, 4145, 33, 'Не обстежений: '),
(122907, 4146, 33, 'не знайдений'),
(122908, 4148, 33, 'не знайдений!'),
(122909, 4149, 33, 'Не виходець з Іспанії чи з Латинської Америки'),
(122910, 4150, 33, 'Не встановлено'),
(122911, 4152, 33, 'Не бачив з'),
(122912, 4153, 33, 'Не відправлено'),
(122913, 4154, 33, 'Ще не відправлено'),
(122914, 4155, 33, 'Не задано'),
(122915, 4156, 33, 'Не задано.'),
(122916, 4157, 33, 'Примітка'),
(122917, 4158, 33, 'Коди приміток'),
(122918, 4159, 33, 'Зауважте, що 5-10 хвилин необхідно для повної обробки інформаціїї посля того, як ви натиснете "Встановити"'),
(122919, 4160, 33, 'Зауважте, що 5-10 хвилин необхідно для повної обробки інформаціїї посля того, як ви натиснете "Оновити"'),
(122920, 4161, 33, 'Зауважте, що аудит логів повинен бути включений вище'),
(122921, 4162, 33, 'Тип запису'),
(122922, 4163, 33, 'Примітка: полудень 12:00 є "після полудня" а не "зранку"'),
(122923, 4164, 33, 'ПРИМІТКА: Імпортування зовнішніх даних може тривати більше години, залежно від вашого апаратного забезпечення. Для прикладу, одна таблиця даних RxNorm містить більше 6 мільйонів рядків.'),
(122924, 4165, 33, 'ПРИМІТКА: зараз підтримується лише міжнарожний випуск Snomed з двома виходами на рік'),
(122925, 4166, 33, 'ПРИМІТКА: підтримується лише повний щомісячний випуск RxNorm'),
(122926, 4168, 33, 'Примітка: цей код був введений неавторизованим користувачем. Тільки дозволені коди можуть вводитися у Відкриту Біллінгову Медичну Сітку для обробки. Якщо хочете завантажити ці коди, виберіть тут авторизованого користувача.'),
(122927, 4170, 33, 'ПРИМІТКА: завантаження файлів з одинаковими назвами призведе до автоматичної зміни файлів (наприклад, file.jpg стане file.1.jpg). Назви файлів вважаються унікальними для одного паціента, а не для кожної категорії.'),
(122928, 4171, 33, 'Примітка: завантаження файлів з одинаковими назвами призведе до автоматичного перейменування файлів. Наприклад, '' file.jpg'' стане '' file.jpg.1''. Назви файлів вважаються унікальними для одного паціента, а не для кожної категорії.'),
(122929, 4172, 33, 'Записи'),
(122930, 4173, 33, 'Записи - будь-які звернення (на вибір - право записувати/добавляти)'),
(122931, 4174, 33, 'Записи - мои звернення (на вибір - право записувати/добавляти)'),
(122932, 4175, 33, 'Доступ до записів не дозволений'),
(122933, 4177, 33, 'Нічого не записано'),
(122934, 4179, 33, 'Нічого імпортувати в алергії'),
(122935, 4180, 33, 'Нічого імпортувати в призначення'),
(122936, 4181, 33, 'Нічого показувати'),
(122937, 4182, 33, 'Нічого не обрано'),
(122938, 4184, 33, 'ПОПЕРЕДЖЕННЯ:: надання чи зміна PostCalendar'),
(122939, 4185, 33, 'Повідомлення'),
(122940, 4186, 33, 'Адреса e-mail для повідомлення'),
(122941, 4188, 33, 'Повідомлення'),
(122942, 4189, 33, 'Повідомити адміністратора про вказані чи змінені події?'),
(122943, 4190, 33, 'Лист.'),
(122944, 4191, 33, 'Листопад'),
(122945, 4192, 33, 'Нова відтправка для:'),
(122946, 4193, 33, 'Друкується'),
(122947, 4194, 33, 'Друкуються заявки $stmt_count і оновленні звернення.'),
(122948, 4195, 33, 'Друкуються заявки $stmt_count і оновленні рахунки.'),
(122949, 4196, 33, 'Друкуються заявки $stmt_count; звернення не будуть обновлятися.'),
(122950, 4197, 33, 'Друкуються заявки $stmt_count; рахунки не будуть обновлятися.'),
(122951, 4198, 33, 'NPI'),
(122952, 4199, 33, 'NQF'),
(122953, 4200, 33, 'Номер'),
(122954, 4201, 33, 'Номер лаб.'),
(122955, 4204, 33, 'Кількість стовпчиків в огляді за рік.'),
(122956, 4211, 33, 'Кількість днів, впродовж яких сертифікат клієнта дійсний.'),
(122957, 4213, 33, 'Кількість цифр після десяткової коми для грошей, зазвичай 0 або 2.'),
(122958, 4214, 33, 'Кількість відображених на сторінці звернень.'),
(122959, 4215, 33, 'Кількість пропущених ігор або подій, якщо такі мали місце'),
(122960, 4216, 33, 'Кількість годин на відправку e-mail повідомлень.'),
(122961, 4217, 33, 'Кількість годин на відправку телефонограм.'),
(122962, 4218, 33, 'Кількість годин на відправку SMC-повідомлень.'),
(122963, 4221, 33, 'Кількість стовпчиків для анамнезу.'),
(122964, 4222, 33, 'Кількість пацієнтів для відображення на одній сторінці списку пацієнтів.'),
(122965, 4223, 33, 'Заціпеніння, нечутливість'),
(122966, 4224, 33, 'Нумератор'),
(122967, 4225, 33, 'Порядок відображення чисел'),
(122968, 4227, 33, 'Харчування'),
(122969, 4229, 33, 'O.A.F.V.'),
(122970, 4230, 33, 'Насичений киснем'),
(122971, 4231, 33, 'Ожиріння I ст.'),
(122972, 4232, 33, 'Ожиріння IІ ст.'),
(122973, 4233, 33, 'Ожиріння IІІ ст.'),
(122974, 4234, 33, 'Об''єктивно'),
(122975, 4237, 33, 'Професія'),
(122976, 4239, 33, 'Випадок'),
(122977, 4240, 33, 'Жов.'),
(122978, 4241, 33, 'Жовтень'),
(122979, 4242, 33, 'OD'),
(122980, 4243, 33, 'з'),
(122981, 4244, 33, 'з кількості'),
(122982, 4245, 33, 'таблеток'),
(122983, 4246, 33, 'кожний місяць'),
(122984, 4247, 33, 'Служб. записи'),
(122985, 4248, 33, 'Вимкнений'),
(122986, 4249, 33, 'Службові записи'),
(122987, 4250, 33, 'Відвідування кабінету'),
(122988, 4251, 33, 'Групи порівняння для офіційної клінічної одиниці вимірювання якості (CQM)'),
(122989, 4252, 33, 'Зовнішній Https-лінк для порталу пацієнта.'),
(122990, 4253, 33, 'Зовнішній Https-лнік для порталу пацієнта. (Портал пацієнта)'),
(122991, 4254, 33, 'Зовнішній пароль порталу пацієнтів'),
(122992, 4255, 33, 'Зовнішній пароль порталу пацієнтів (якщо не зареєстровані, то залишіть незаповненим)'),
(122993, 4256, 33, 'ID спеціаліста порталу пацієнтів'),
(122994, 4257, 33, 'ID спеціаліста порталу пацієнтів (якщо не зареєстровані, то залишіть незаповненим)'),
(122995, 4258, 33, 'Зовнішня адреса сайту порталу пацієнтів'),
(122996, 4259, 33, 'Зовнішня адреса сайту порталу пацієнтів (Зв''язок пацієнта)'),
(122997, 4260, 33, 'Зовнішнє ім''я користувача порталу пацієнтів'),
(122998, 4261, 33, 'Зовнішнє ім''я користувача порталу пацієнтів (якщо не зареєстровані, то залишіть незаповненим)'),
(122999, 4263, 33, 'Потомство'),
(123000, 4265, 33, 'мазь'),
(123001, 4267, 33, 'OK'),
(123002, 4269, 33, 'OK для зв''язку з цією датованою проблемою GCAC'),
(123003, 4270, 33, 'Старий'),
(123004, 4272, 33, 'Колишні клієнти'),
(123005, 4273, 33, 'Нестарий перелом / неправильне зростання тканин після перелому'),
(123006, 4274, 33, 'Макет старого стилю без меню зліва'),
(123007, 4275, 33, 'Статична форма старого стилю без пошуку чи перевірки на дублювання'),
(123008, 4277, 33, 'Пропустити'),
(123009, 4278, 33, 'Пропустити контури'),
(123010, 4279, 33, 'Пропускати інформацію про місце роботи в особистих даних пацієнта'),
(123011, 4280, 33, 'Пропустіть місце роботи'),
(123012, 4281, 33, 'Пропускати форму, спосіб і частоту введення, які надалі стають частиною дозування'),
(123013, 4282, 33, 'Пропускати інформацію про страхування і деякі інші пункти форми персональних даних'),
(123014, 4283, 33, 'Виключити внутрішніх користувачів?'),
(123015, 4284, 33, 'Виключення способу оплати з панелі доплати'),
(123016, 4285, 33, 'пропустити для автоматичного призначення'),
(123017, 4286, 33, 'в'),
(123018, 4287, 33, 'в'),
(123019, 4288, 33, 'на руках'),
(123020, 4289, 33, 'При призначенні'),
(123021, 4290, 33, 'на місці'),
(123022, 4291, 33, 'Після установки Основного медичного закладу його не можна змінювати. Зміна компонента вплине на роботу в ePrescription NewCrop.'),
(123023, 4292, 33, 'Після зміни свого пароля ви повинні повторно ввійти в систему.'),
(123024, 4297, 33, 'Підтримка он-лайн'),
(123025, 4298, 33, 'Посилання підтримки он-лайн'),
(123026, 4299, 33, 'Тільки активні'),
(123027, 4300, 33, 'Застосовується лише якщо спеціаліст або порівняльний список були попередньо вибрані. ПЕРВИННИЙ виберіть пацієнтів, для яких спеціаліст є первинним спеціалістом. ЗВЕРНЕННЯ виберіть всіх пацієнтів які відвідували спеціаліста'),
(123028, 4302, 33, 'Тільки для розміщення рахунків'),
(123029, 4303, 33, 'Тільки неактивні'),
(123030, 4304, 33, 'Тільки мої'),
(123031, 4305, 33, 'Показувати лише коди звітності по діагнозах'),
(123032, 4306, 33, 'Показувати лише сервісні коди кодів фінансової звітності'),
(123033, 4307, 33, 'Тільки для вивантаження активних призначень'),
(123034, 4310, 33, 'Початок захворювання:'),
(123035, 4311, 33, 'Початок захворювання: '),
(123036, 4312, 33, 'Поява новоутворення (пухл.):'),
(123037, 4313, 33, 'Дата поч./госп.'),
(123038, 4314, 33, 'Адреса сайту для портала внутрішніх пацієнтів'),
(123039, 4315, 33, 'Невдача!'),
(123040, 4316, 33, 'Відкрити'),
(123041, 4318, 33, 'Відкрити в новому вікні'),
(123042, 4321, 33, 'Відкрити відвідування за сьогодні'),
(123043, 4322, 33, 'LibreEHR вже має налаштований довірений сертификат.'),
(123044, 4323, 33, 'LibreEHR категорія додатку'),
(123045, 4324, 33, 'Модернізація бази даних LibreEHR'),
(123046, 4325, 33, 'Модернізація бази даних LibreEHR для деідентифікації'),
(123047, 4326, 33, 'LibreEHR не розпізнає файл у вхідному каталозі. Вірогідно, Вам слід налаштувати реліз в supported_external_dataloads таблиці MySQL бази даних.'),
(123048, 4327, 33, 'До того, як LibreEHR зможе створювати сертифікати клієнта, його необхідно налаштувати для використання сертифікатів.'),
(123049, 4328, 33, 'Для підтвердження користувача LibreEHR необхідно дозволити Javascript.'),
(123050, 4329, 33, 'Користувачі LibreEHR'),
(123051, 4330, 33, 'Вступ'),
(123052, 4332, 33, 'Очний'),
(123053, 4333, 33, 'Опція'),
(123054, 4334, 33, 'Опції способу збереження сховища документів.'),
(123055, 4335, 33, 'Опція для підтримки інвентаризації і реалізації матеріальних цінностей'),
(123056, 4336, 33, 'Необов''язковий'),
(123057, 4337, 33, 'Необов''язкова назва категорії для ID-карти зображення, яке можна проглянути на сторінці інформації про пациента.'),
(123058, 4338, 33, 'Необов''язкова назва категорії для фото-зображень, яке можна проглянути на сторінці інформації про пациента.'),
(123059, 4339, 33, 'Необов''язкова назва категорії документа, щоби приєднатися до сторінки даних про пацієнта. Клікніть на имені пацієнта, щоби побачити його ID-карту.'),
(123060, 4340, 33, 'Необов''язковий діапазон "за замовчуванням" для ручного внесення результатів'),
(123061, 4341, 33, 'Необов''язкові одиниці вимірювання для ручного внесення результатів'),
(123062, 4342, 33, 'Необов''язкове місце призначення'),
(123063, 4343, 33, 'Необов''язкова назва препарата, використовуйте % як знак підстановки'),
(123064, 4345, 33, 'Необов''язкова інформація про цю подію'),
(123065, 4346, 33, 'Необов''язкова кількість партії, використовуйте % як знак підстановки'),
(123066, 4347, 33, 'Необов''язковий чиловий ID пацієнта'),
(123067, 4348, 33, 'Необов''язковий код методики'),
(123068, 4349, 33, 'Необов''язковий код процедури/послуги'),
(123069, 4350, 33, 'Опції'),
(123070, 4351, 33, 'чи'),
(123071, 4352, 33, 'ЧИ'),
(123072, 4353, 33, 'або змініть'),
(123073, 4354, 33, 'або натисніть і тягніть для швидшого виділення.'),
(123074, 4356, 33, 'чи для'),
(123075, 4358, 33, 'або утримуйте Shift для зменшення'),
(123076, 4359, 33, 'або обновіть файл ERA:'),
(123077, 4360, 33, 'Перорально'),
(123078, 4361, 33, 'слизова порожнини рота рожева, глотка чиста'),
(123079, 4362, 33, 'Призначення'),
(123080, 4363, 33, 'Види призначення і результату'),
(123081, 4364, 33, 'Каталог призначень'),
(123082, 4365, 33, 'Дата призначення'),
(123083, 4367, 33, 'призначення від'),
(123084, 4368, 33, 'ID призначення'),
(123085, 4369, 33, 'Призначення повинно бути пронумерованим від 1 до 999'),
(123086, 4370, 33, 'Найменування призначення'),
(123087, 4371, 33, 'Пріоритет призначення'),
(123088, 4372, 33, 'Обробник призначень'),
(123089, 4373, 33, 'Результати призначення'),
(123090, 4374, 33, 'Статус призначення'),
(123091, 4375, 33, 'Статуси призначення'),
(123092, 4376, 33, 'Заключення по призначенню'),
(123093, 4378, 33, 'Вид призначення'),
(123094, 4380, 33, 'Вид призначення/виконання'),
(123095, 4381, 33, 'Призначено'),
(123096, 4382, 33, 'Призначено по'),
(123097, 4383, 33, 'Призначена процедура'),
(123098, 4384, 33, 'Спеціаліст, що призначає.'),
(123099, 4385, 33, 'Шлях призначення'),
(123100, 4386, 33, 'Ураження органу.'),
(123101, 4387, 33, 'Організація'),
(123102, 4388, 33, 'Назва організації'),
(123103, 4389, 33, 'Назва підрозділу організації'),
(123104, 4390, 33, 'Організації'),
(123105, 4391, 33, 'Орієнтований х 3'),
(123106, 4392, 33, 'Оригінал'),
(123107, 4396, 33, 'РОТОГЛОТКА: '),
(123108, 4397, 33, 'Ортопне'),
(123109, 4398, 33, 'OS'),
(123110, 4399, 33, 'Остеоартрити'),
(123111, 4402, 33, 'Інше'),
(123112, 4403, 33, 'інше'),
(123113, 4404, 33, 'інше (вказати)'),
(123114, 4405, 33, 'Інше - вказане'),
(123115, 4406, 33, 'Інша державна програма'),
(123116, 4407, 33, 'Інша Фінансова Адміністрація охорони здоров''я'),
(123117, 4408, 33, 'Інші незазначені пошкодження'),
(123118, 4409, 33, 'Інше джерело страхування має першочергове значення'),
(123119, 4410, 33, 'інший місяць'),
(123120, 4411, 33, 'Інші незагальнодержавні програми'),
(123121, 4412, 33, 'Інші записи'),
(123122, 4413, 33, 'Інші доречні симптоми'),
(123123, 4414, 33, 'Інші доречні симптоми:'),
(123124, 4415, 33, 'Інший відповідний пункт'),
(123125, 4416, 33, 'Інші впливи/загальне ураження'),
(123126, 4417, 33, 'Інші оперативні втручання'),
(123127, 4418, 33, 'Інші/пов''язані з периванням вагітності'),
(123128, 4420, 33, 'Інші'),
(123129, 4421, 33, 'в іншому випадку ви порушуєте посилання на/з існуючу(ої) дату(и).'),
(123130, 4422, 33, 'Правила для радіографії щиколотки (Оттава)'),
(123131, 4423, 33, 'OU'),
(123132, 4424, 33, 'НЕ ПРАЦЮЄ'),
(123133, 4425, 33, 'НЕ НА МІСЦІ'),
(123134, 4426, 33, 'Направлення закордон'),
(123135, 4427, 33, 'Наслідок'),
(123136, 4428, 33, 'Спостереження'),
(123137, 4430, 33, 'Загальний стан виділень'),
(123138, 4431, 33, 'ЗАПІЗНІЛИЙ'),
(123139, 4432, 33, 'Зловживання'),
(123140, 4433, 33, 'Загальне представлення'),
(123141, 4434, 33, 'Надмірна вага'),
(123142, 4435, 33, 'Переписати вибір HIPAA (Закон про звітність і безпеку медичного страхування)'),
(123143, 4437, 33, 'Насичення киснем'),
(123144, 4439, 33, 'Р'),
(123145, 4440, 33, 'проц.'),
(123146, 4441, 33, 'після полудня'),
(123147, 4442, 33, 'за необхідністю'),
(123148, 4443, 33, 'Житель тихоокеанських островів'),
(123149, 4444, 33, 'Педіатричний'),
(123150, 4445, 33, 'Сторінка'),
(123151, 4446, 33, 'Сторінки'),
(123152, 4447, 33, 'Оплачуваний'),
(123153, 4448, 33, 'Сума оплати, яку ви внесете'),
(123154, 4449, 33, 'Сума оплати'),
(123155, 4450, 33, 'Оплатити через'),
(123156, 4451, 33, 'Біль'),
(123157, 4453, 33, 'Сильне серцибиття'),
(123158, 4455, 33, 'Мазок Папаніколау'),
(123159, 4456, 33, 'Папір'),
(123160, 4457, 33, 'Розмір паперу'),
(123161, 4458, 33, 'Параліч'),
(123162, 4461, 33, 'Обробка HL7'),
(123163, 4463, 33, 'Партнер'),
(123164, 4464, 33, 'Найменування партнера'),
(123165, 4467, 33, 'Пароль'),
(123166, 4468, 33, 'Пароль для розшифрування документа'),
(123167, 4469, 33, 'Передані пацієнти'),
(123168, 4470, 33, 'Пасивне сповіщення'),
(123169, 4471, 33, 'Правила пасивних сповіщень'),
(123170, 4472, 33, 'Пароль'),
(123171, 4473, 33, 'Зміна пароля'),
(123172, 4474, 33, 'Пароль успішно змінено'),
(123173, 4475, 33, 'Пароль успішно змінено.'),
(123174, 4476, 33, 'Пароль не відповідає мінімальним вимогам і повинен містити не менше трьох з наступних чотирьох елементів: цифри, прописні літери, великі літери, спеціальні символи.'),
(123175, 4477, 33, 'Термін дії пароля'),
(123176, 4479, 33, 'Пароль для телефонного шлюза. Автоматизована служба VOIP надана через Maviq. Перегляньте http://signup.maviq.com для отримання додаткової інформації.'),
(123177, 4480, 33, 'Пароль для шлюза SMS'),
(123178, 4481, 33, 'Пароль для шлюза SMS.'),
(123179, 4483, 33, 'Надійність пароля недавно удосконалена.'),
(123180, 4484, 33, 'Пароль для підключення до CouchDB'),
(123181, 4485, 33, 'Пароль занадто короткий. Вимагається не менше 8 символів.'),
(123182, 4486, 33, 'Пароль:'),
(123183, 4487, 33, 'Паролі на співпадають!'),
(123184, 4488, 33, 'Минулі записи на прийом'),
(123185, 4489, 33, 'Віджет відображення минулих записів на прийом'),
(123186, 4490, 33, 'Прострочено'),
(123187, 4491, 33, 'Прострочено'),
(123188, 4492, 33, 'Найбільший інтервал очікування (клінічні нагадування)'),
(123189, 4493, 33, 'Найбільший інтервал очікування (нагадування для пацієнта)'),
(123190, 4494, 33, 'Список попередніх звертань'),
(123191, 4495, 33, 'Попередні звертання'),
(123192, 4496, 33, 'Попередні звертання і документи'),
(123193, 4497, 33, 'Прошлые обращения для'),
(123194, 4498, 33, 'Вставка HL7 даних'),
(123195, 4499, 33, 'Вставте дані для імпорту в текстове поле нижче:'),
(123196, 4500, 33, 'Придатний'),
(123197, 4502, 33, 'Виправлення'),
(123198, 4508, 33, 'Шлях для резервного копіювання журнала подій'),
(123199, 4509, 33, 'Шлях до файла сертифіката CA'),
(123200, 4510, 33, 'Шлях до файла ключа CA'),
(123201, 4511, 33, 'Шлях до бібліотек MySQL'),
(123202, 4512, 33, 'Шлях до бібліотек Perl'),
(123203, 4513, 33, 'Шлях до каталогу тимчасових файлів'),
(123204, 4514, 33, 'Пацієнт'),
(123205, 4515, 33, 'пацієнт'),
(123206, 4516, 33, 'ПАЦІЄНТ'),
(123207, 4517, 33, 'Адреса пацієнта'),
(123208, 4518, 33, 'Не вказано адресу пацієнта'),
(123209, 4521, 33, 'Алергії пацієнта'),
(123210, 4522, 33, 'Алергії пацієнта'),
(123211, 4523, 33, 'Запис на прийом'),
(123212, 4524, 33, 'Баланс пацієнта'),
(123213, 4525, 33, 'Баланс пацієнта відповідно'),
(123214, 4528, 33, 'ID карти пацієнта'),
(123215, 4529, 33, 'Перевірка пацієнта'),
(123216, 4530, 33, 'Перевірка пацієнта на '),
(123217, 4531, 33, 'Місто проживання пацієнта'),
(123218, 4532, 33, 'Не вказано місто пацієнта'),
(123219, 4533, 33, 'Встановлення зв''язку з пацієнтом.'),
(123220, 4534, 33, 'Встановлення зв''язку з пацієнтом.'),
(123221, 4535, 33, 'Країна проживання пацієнта.'),
(123222, 4536, 33, 'Не вказана країна проживання пацієнта.Ви також не втановили країни проживання пацієнта "за замовчуванням" в меню Глобальні Налаштування'),
(123223, 4537, 33, 'Сфера діяльності пацієнта'),
(123224, 4539, 33, 'Дані пацієнта'),
(123225, 4541, 33, 'Відсутня дата народження пацієнта'),
(123226, 4542, 33, 'Відомості про пацієнта'),
(123227, 4543, 33, 'Дата народження пацієнта'),
(123228, 4544, 33, 'Документ пацієнта'),
(123229, 4545, 33, 'Освіта пацієнта'),
(123230, 4546, 33, 'Відомості про освіту пацієнта'),
(123231, 4547, 33, 'Звернення пацієнта'),
(123232, 4548, 33, 'Форма звернення пацієнта'),
(123233, 4549, 33, 'Звернення пацієнта'),
(123234, 4550, 33, 'Вказівник пошуку пацієнта'),
(123235, 4551, 33, 'Ім''я пацієнта'),
(123236, 4553, 33, 'Відсутнє ім''я пацієнта'),
(123237, 4558, 33, 'Стать пацієнта'),
(123238, 4559, 33, 'Стать пацієнта не вказана'),
(123239, 4560, 33, 'Пацієнту не дозволений доступ до портала.'),
(123240, 4561, 33, 'Анамнез пацієнта'),
(123241, 4562, 33, 'Анамнез/спосіб життя пацієнта'),
(123242, 4563, 33, 'Домашній телефон пацієнта'),
(123243, 4564, 33, 'ID пацієнта'),
(123244, 4565, 33, 'Id пацієнта'),
(123245, 4566, 33, 'ID карти пацієнта'),
(123246, 4567, 33, 'Найменування категорії для ID пацієнта'),
(123247, 4568, 33, 'Вакцинація пацієнта'),
(123248, 4569, 33, 'Інформація про пацієнта'),
(123249, 4570, 33, 'Вказівки для пацієнта'),
(123250, 4571, 33, 'Здійснення страхування пацієнта'),
(123251, 4572, 33, 'Звіт про надану страховку пацієнта'),
(123252, 4573, 33, 'Проблеми пацієнта'),
(123253, 4575, 33, 'Прізвище пацієнта'),
(123254, 4577, 33, 'Відсутнє прізвище пацієнта'),
(123255, 4581, 33, 'Список пацієнтів'),
(123256, 4582, 33, 'Стовбці списку пацієнтів'),
(123257, 4584, 33, 'Нове вікно списку пацієнтів'),
(123258, 4585, 33, 'Розмір паперу списку пацієнтів'),
(123259, 4586, 33, 'Помилки пошуку пацієнта'),
(123260, 4587, 33, 'Медичні проблеми пацієнта'),
(123261, 4588, 33, 'Медикаменти для пацієнта'),
(123262, 4589, 33, 'Ім''я пацієнта'),
(123263, 4590, 33, 'Прізвище і адреса пацієнта'),
(123264, 4593, 33, 'Обов''язково вкажіть прізвище пацієнта'),
(123265, 4595, 33, 'Запис щодо пацієнта'),
(123266, 4596, 33, 'Види записів щодо пацієнта'),
(123267, 4597, 33, 'Записи щодо пацієнта'),
(123268, 4598, 33, 'Записи щодо пацієнта (на вибір - право записувати/добавляти)'),
(123269, 4599, 33, 'Номер пацієнта'),
(123270, 4600, 33, 'Виконавча оплата для пацієнта'),
(123271, 4602, 33, 'Найменування категорії для фотографії пацієнта'),
(123272, 4603, 33, 'Портал пацієнта'),
(123273, 4605, 33, 'Портал пацієнта відключений'),
(123274, 4606, 33, 'Вхід в портал пацієнта'),
(123275, 4607, 33, 'Веб-адреса портала пацієнта'),
(123276, 4608, 33, 'Друкований звіт про пацієнта'),
(123277, 4609, 33, 'Реєстраційний звіт про пацієнта'),
(123278, 4610, 33, 'Реєстраційний запит про пацієнта'),
(123279, 4611, 33, 'Реєстраційні запити про пацієнта'),
(123280, 4613, 33, 'Нагадування про пацієнта'),
(123281, 4614, 33, 'Групова обробка нагадуваннь про пацієнтів'),
(123282, 4615, 33, 'Створення послідовності обробки нагадувань про пацієнтів'),
(123283, 4616, 33, 'Правила нагадування про пацієнта'),
(123284, 4617, 33, 'E-mail відправника нагадувань про пацієнта'),
(123285, 4618, 33, 'Прізвище відправника нагадувань про пацієнта'),
(123286, 4619, 33, 'Нагадування про пацієнта'),
(123287, 4620, 33, 'Звіт про пацієнта'),
(123288, 4621, 33, 'Запит про пацієнта'),
(123289, 4622, 33, 'Історії хвороби пацієнта, на які був запит'),
(123290, 4623, 33, 'Результати щодо пацієнта'),
(123291, 4624, 33, 'Стиль проведення пошуку пацієнта'),
(123292, 4625, 33, 'Вікно Пошуку/Добавлення пацієнта'),
(123293, 4626, 33, 'Налаштування по пацієнту'),
(123294, 4627, 33, 'Стан пацієнта'),
(123295, 4629, 33, 'Резюме по пацієнту'),
(123296, 4630, 33, 'Транзакції по пацієнту'),
(123297, 4631, 33, 'Поштовий індекс пацієнта'),
(123298, 4632, 33, 'пацієнт(и) в базі даних, якому(яким) відповідає введена демографічна інформація.'),
(123299, 4633, 33, 'Пацієнт/відвідувач'),
(123300, 4634, 33, 'Пацієнт:'),
(123301, 4635, 33, 'ID пацієнта'),
(123302, 4636, 33, 'Пацієнти'),
(123303, 4637, 33, 'Оброблені пацієнти'),
(123304, 4638, 33, 'Оплата'),
(123305, 4639, 33, 'Зверніть увагу на віконечко  "Зроблено". Після завершення заповнення страховки ми будемо просити пацієнта оплатити залишок. Якщо вам не вдалося заповнити всю страховку, то сума, що залишилася не буде врахована! Також, якщо є сума, яку пацієнт повинен сплатити, встановіть визначений термін оплати, оскільки він впливатиме на визначення офіційного балансу для пацієнта.'),
(123306, 4640, 33, 'Дата оплати:'),
(123307, 4641, 33, 'Статус оплати'),
(123308, 4642, 33, 'Найменування одержувача платежу'),
(123309, 4643, 33, 'Платник'),
(123310, 4644, 33, 'Тип платника'),
(123311, 4645, 33, 'Платіж'),
(123312, 4646, 33, 'Особа, яка оплачує'),
(123313, 4647, 33, 'Оплата'),
(123314, 4648, 33, 'оплата'),
(123315, 4649, 33, 'Код корегування оплати'),
(123316, 4650, 33, 'Оплата в порівнянні з'),
(123317, 4651, 33, 'Сума до оплати'),
(123318, 4652, 33, 'Сума до оплати повинна бути в цифрах'),
(123319, 4653, 33, 'Категорія оплати'),
(123320, 4654, 33, 'Дата платежу'),
(123321, 4655, 33, 'оплата, внесена на'),
(123322, 4656, 33, 'Оплата від'),
(123323, 4657, 33, 'Шлюз оплати'),
(123324, 4658, 33, 'Вст. оплати'),
(123325, 4659, 33, 'Список оплати'),
(123326, 4660, 33, 'Метод оплати'),
(123327, 4661, 33, 'Сортування оплати за'),
(123328, 4662, 33, 'Статус оплати'),
(123329, 4663, 33, 'Тип оплати'),
(123330, 4664, 33, 'Значення оплати для кода '),
(123331, 4665, 33, 'Платежі'),
(123332, 4667, 33, 'Файл PCP'),
(123333, 4668, 33, 'Відс. (%) рядків'),
(123334, 4669, 33, 'Файл PDF'),
(123335, 4670, 33, 'Завантажити вибрані заявки як PDF'),
(123336, 4672, 33, 'Ділянка таза і сідниць'),
(123337, 4673, 33, 'Пухирчатка'),
(123338, 4674, 33, 'Незакінчений'),
(123339, 4676, 33, 'Очікуючий прод.'),
(123340, 4677, 33, 'Очікуючий продовження'),
(123341, 4678, 33, 'Очікування нових даних результатів'),
(123342, 4679, 33, 'Очікування призначень'),
(123343, 4680, 33, 'Очікуючий дослідження'),
(123344, 4681, 33, 'Очікуючі огляду'),
(123345, 4682, 33, 'Очікуючий підрахунку Rx'),
(123346, 4684, 33, 'LibreEHR для фірми Pennington v'),
(123347, 4685, 33, 'Виразкова хвороба'),
(123348, 4686, 33, 'По зверненню'),
(123349, 4687, 33, 'на хвилину'),
(123350, 4688, 33, 'Через ніздрю'),
(123351, 4689, 33, 'Через ніздрю'),
(123352, 4690, 33, 'Перорально'),
(123353, 4691, 33, 'перорально'),
(123354, 4692, 33, 'Ректально'),
(123355, 4693, 33, 'ректально'),
(123356, 4694, 33, 'Процент'),
(123357, 4697, 33, 'Процентиль'),
(123358, 4698, 33, 'Перфорований справа:'),
(123359, 4699, 33, 'Здійснити пошук'),
(123360, 4700, 33, 'Виконати цю дію'),
(123361, 4701, 33, 'Подати в процентах'),
(123362, 4703, 33, 'Виконання лабораторних послуг'),
(123363, 4705, 33, 'Період'),
(123364, 4706, 33, 'Період (в днях), коли користувач може ввійти в систему з паролем, термін дії якого закінчився.'),
(123365, 4707, 33, 'Передопераційне лікування'),
(123366, 4708, 33, 'Периферійний'),
(123367, 4709, 33, 'Дозволити "непосолені" паролі'),
(123368, 4710, 33, 'Персидська'),
(123369, 4712, 33, 'Людина, особа'),
(123370, 4713, 33, 'Персоналізація'),
(123371, 4714, 33, 'PG'),
(123372, 4715, 33, 'Апт.'),
(123373, 4716, 33, 'Загальн. апт. рахунок'),
(123374, 4717, 33, 'Аптеки'),
(123375, 4718, 33, 'Аптека'),
(123376, 4719, 33, 'Аптечне відділення'),
(123377, 4720, 33, 'Пневмоторакс'),
(123378, 4723, 33, 'Інтервал перевірки повідомлень (хвилин) phiMail'),
(123379, 4724, 33, 'попередження користувача phiMail'),
(123380, 4725, 33, 'Пароль phiMail'),
(123381, 4726, 33, 'Адреса серверу phiMail'),
(123382, 4727, 33, 'Ім''я користувача phiMail'),
(123383, 4729, 33, 'Телефон'),
(123384, 4730, 33, 'Список телефонних дзвінків'),
(123385, 4731, 33, 'Звіт списку дзвінків'),
(123386, 4733, 33, 'Пароль для телефонного шлюзу'),
(123387, 4734, 33, 'URL для телефонного шлюзу'),
(123388, 4735, 33, 'Ім''я користувача для телефонного шлюзу'),
(123389, 4737, 33, 'Час телефонограми'),
(123390, 4738, 33, 'Номер телефону'),
(123391, 4740, 33, 'Боязнь світла'),
(123392, 4741, 33, 'Фото'),
(123393, 4742, 33, 'стиснутий PHP'),
(123394, 4743, 33, 'PHP CURL модуль на вашому сервері повинен бути включений'),
(123395, 4744, 33, 'PHP витягнений'),
(123396, 4745, 33, 'Управління доступом php-GACL відключено'),
(123397, 4746, 33, 'PHP-gacl не встановлений'),
(123398, 4747, 33, 'Фізикальне обстеження'),
(123399, 4749, 33, 'Лікакський запит'),
(123400, 4750, 33, 'Підпис лікаря'),
(123401, 4752, 33, 'Лікарі'),
(123402, 4753, 33, 'вибрати'),
(123403, 4754, 33, 'Вибрати'),
(123404, 4755, 33, 'Вибрати тему CSS'),
(123405, 4756, 33, 'Пац.ID'),
(123406, 4757, 33, 'ЗЗМТ (Запальне захворювання малого тазу)'),
(123407, 4758, 33, 'Розмір таблетки'),
(123408, 4759, 33, 'Таблетки'),
(123409, 4760, 33, 'Якщо потрібна ця опція для установки, розмістіть файл zip бази даних в наступну директорію'),
(123410, 4761, 33, 'Помістіть завантажені zip-файли ICD 10 бази даних в наступний каталог'),
(123411, 4762, 33, 'Помістіть завантажені zip-файли ICD 9 бази даних в наступний каталог'),
(123412, 4763, 33, 'Помістіть завантажені zip-файли RxNorm бази даних в наступний каталог'),
(123413, 4764, 33, 'Помістіть завантажені zip-файли Snomed 10 бази даних в наступний каталог'),
(123414, 4765, 33, 'Заповнювач'),
(123415, 4766, 33, 'Заповнювач (підтримує пустий ACLs)'),
(123416, 4767, 33, 'Простий текст'),
(123417, 4768, 33, 'План'),
(123418, 4771, 33, 'Назва плану'),
(123419, 4775, 33, 'Установка плану'),
(123420, 4779, 33, 'План:'),
(123421, 4782, 33, 'Плани'),
(123422, 4784, 33, 'Гравець'),
(123423, 4785, 33, 'Ігрова позиція'),
(123424, 4786, 33, 'Подзвоніть, якщо будь-яка вищезгадана інформація є неправильною'),
(123425, 4787, 33, 'Будь-ласка, змініть ваш пароль'),
(123426, 4788, 33, 'Будь-ласка, виберіть файл'),
(123427, 4789, 33, 'Будь-ласка, виберіть пацієнта'),
(123428, 4790, 33, 'Будь-ласка, зробіть допустимий вибір зі списку'),
(123429, 4791, 33, 'Будь-ласка, зробіть допустимий вибір'),
(123430, 4792, 33, 'Будь-ласка, виберіть значення для'),
(123431, 4793, 33, 'Будь-ласка, виберіть критерії діапазону дат вище і натисніть Оновити, щоб переглянути результати'),
(123432, 4794, 33, 'Будь-ласка, виберіть відповідний EDI-271 відформатований файл'),
(123433, 4795, 33, 'Будь-ласка, натисніть Завантажити, щоб завантажити дані де-ідентифікації'),
(123434, 4796, 33, 'Будь-ласка, натисніть Завантажити, щоб завантажити дані повторної ідентифікації'),
(123435, 4797, 33, 'Будь-ласка, закрийте це вікно'),
(123436, 4798, 33, 'Будь-ласка, порівняйте нове ім''я'),
(123437, 4801, 33, 'Будь-ласка, створіть наступний каталог перед обробкою'),
(123438, 4802, 33, 'Будь-ласка, не приймайте це призначення якщо воно не було отримане у вигляді факсіміле'),
(123439, 4803, 33, 'Будь-ласка, не приймайте це призначення якщо воно не було отримане у вигляді факсіміле'),
(123440, 4804, 33, 'Будь-ласка, не використовуйте клавішу зупинки чи перезавантаження вашого браузера, поки виконується ця сторінка якщо не пройшло більше 10 хвилин, це не зупинить процес на сервері і буде споживати непотрібні ресурси'),
(123441, 4805, 33, 'БУДЬ-ЛАСКА,ВКЛЮЧІТЬ CURL РОЗШИРЕННЯ'),
(123442, 4806, 33, 'БУДЬ-ЛАСКА,ВКЛЮЧІТЬ OPENSSL РОЗШИРЕННЯ'),
(123443, 4807, 33, 'БУДЬ-ЛАСКА, ВКЛЮЧІТЬ СООП РОЗШИРЕННЯ'),
(123444, 4808, 33, 'БУДЬ-ЛАСКА, ВКЛЮЧІТЬ XML РОЗШИРЕННЯ'),
(123445, 4809, 33, 'Будь-ласка, введіть дату Останнього Перегляду'),
(123446, 4810, 33, 'Будь-ласка, введіть дату'),
(123447, 4811, 33, 'Будь-ласка, введіть відповідну дату'),
(123448, 4812, 33, 'Будь-ласка, введіть повідомлення'),
(123449, 4813, 33, 'Будь-ласка, введіть грошову суму використовуючи лише цифри і десятковий дріб'),
(123450, 4814, 33, 'Будь-ласка, введіть новий пароль'),
(123451, 4815, 33, 'Будь-ласка, введіть назву!');
INSERT INTO `lang_definitions` VALUES
(123452, 4819, 33, 'Будь-ласка, введіть правильний код повторної ідентифікації'),
(123453, 4821, 33, 'Будь-ласка, введіть новий критерій пошуку'),
(123454, 4822, 33, 'Будь-ласка, введіть цей правильний код повторної ідентифікації'),
(123455, 4823, 33, 'Будь-ласка, введіть пароль'),
(123456, 4824, 33, 'Будь-ласка, заповніть номер чеку'),
(123457, 4825, 33, 'Будь-ласка, заповніть номер/шифр чеку'),
(123458, 4826, 33, 'Будь-ласка, заповніть дату'),
(123459, 4827, 33, 'Будь-ласка, заповніть суму платежу'),
(123460, 4828, 33, 'Будь-ласка, заповніть категорію платежу'),
(123461, 4829, 33, 'Будь-ласка, заповніть форму платежу'),
(123462, 4830, 33, 'Будь-ласка, заповніть відправку до дати'),
(123463, 4831, 33, 'Будь-ласка, заповніть їх перед продовженням'),
(123464, 4832, 33, 'Вкажіть причину візиту'),
(123465, 4833, 33, 'Будь-ласка, введіть вище критерії пошуку і натисніть Підтвердити щоб розпочати звіт'),
(123466, 4834, 33, 'Будь-ласка, введіть вище критерії пошуку і натисніть Підтвердити щоб переглянути результати'),
(123467, 4835, 33, 'Будь-ласка, введіть вище критерії пошуку і натисніть Підтвердити щоб переглянути результати (результати будуть відображені у спливаючому вікні'),
(123468, 4836, 33, 'Будь-ласка, увійдіть в систему заново'),
(123469, 4837, 33, 'Будь-ласка, зауважте, що це може зайняти багато часу, до кількох хвилин. Ваш браузер може бути неактивним під час цього, але створення рахунку є складним процесом і ваш браузер просто чекає на додаткову інформацію'),
(123470, 4838, 33, 'Будь-ласка, зауважте, константи є чутливими до регістру і будь-які рядки дозволяються'),
(123471, 4839, 33, 'Будь-ласка, використовуйте лише алфавітні символи'),
(123472, 4840, 33, 'Будь-ласка, використовуйте лише алфавітні символи без пробілів'),
(123473, 4841, 33, 'Будь-ласка, оплатіть цю суму'),
(123474, 4842, 33, 'Будь-ласка, розмістіть інсталяційні файли у наступному каталозі'),
(123475, 4843, 33, 'Будь-ласка, зверніться до'),
(123476, 4844, 33, 'Будь-ласка, встановіть пароль знову'),
(123477, 4845, 33, 'Будь-ласка, перезапустіть сервер перед виконанням де-ідентифікації'),
(123478, 4847, 33, 'Будь-ласка, виберіть'),
(123479, 4849, 33, 'Будь-ласка, виберіть мову'),
(123480, 4850, 33, 'Будь-ласка, виберіть пацієнта'),
(123481, 4851, 33, 'Будь-ласка, виберіть основний об''єкт суб''єкта господарювання за допомогою "Tax ID". Якщо ви є приватним лікарем, використайте ваш tax id. Це служить для ідентифікації вас у системі NewCrop.'),
(123482, 4854, 33, 'Будь-ласка, виберіть одержувача'),
(123483, 4855, 33, 'Будь-ласка, виберіть дату початку і дату завершення'),
(123484, 4856, 33, 'Будь-ласка, виберіть дійсного одержувача'),
(123485, 4858, 33, 'Будь-ласка, виберіть причину коректування для кода '),
(123486, 4859, 33, 'Будь-ласка, виберіть подію'),
(123487, 4860, 33, 'Будь-ласка, виберіть будь-яку опцію пошуку'),
(123488, 4863, 33, 'Будь-ласка, виберіть хоча б одне призначення!'),
(123489, 4865, 33, 'Будь-ласка, виберіть необхідні сторінки для копіювання чи далі:'),
(123490, 4866, 33, 'Будь-ласка, виберіть метод оплати'),
(123491, 4867, 33, 'Будь-ласка, виберіть тип оплати.'),
(123492, 4869, 33, 'Будь-ласка, виберіть партнера X12, необхідного для створення пакета 270'),
(123493, 4870, 33, 'Встановіть'),
(123494, 4871, 33, 'Будь-ласка, встановіть змінну de_identification_config назад на нуль'),
(123495, 4873, 33, 'Будь-ласка, запустіть новий процес де-ідентифікації'),
(123496, 4874, 33, 'Будь-ласка, оновіть LibreEHR базу даних щоб включити методики де-ідентифікації, функції, таблиці'),
(123497, 4875, 33, 'Будь-ласка, перегляньте лог-таблицю помилок з де-ідентифікації для отримання деталей'),
(123498, 4876, 33, 'Будь-ласка, перейдіть на екран де-ідентифікації через деякий час'),
(123499, 4877, 33, 'Будь-ласка, перейдіть на екран повторної ідентифікації через деякий час'),
(123500, 4878, 33, 'Будь-ласка, перейдіть на екран через деякий час'),
(123501, 4881, 33, 'Множинний'),
(123502, 4882, 33, 'Після обіду'),
(123503, 4883, 33, 'Післяобідня програма'),
(123504, 4884, 33, 'Pmt метод'),
(123505, 4885, 33, 'Синдром нічного апное'),
(123506, 4886, 33, 'Кон''югований з пневмококом 1'),
(123507, 4887, 33, 'Кон''югований з пневмококом 2'),
(123508, 4888, 33, 'Кон''югований з пневмококом 3'),
(123509, 4889, 33, 'Кон''югований з пневмококом 4'),
(123510, 4890, 33, 'Пневмококова вакцина'),
(123511, 4891, 33, 'Вакцинація від пневмонії'),
(123512, 4892, 33, 'Статус вакцинації від пневмонії для літніх дорослих'),
(123513, 4893, 33, 'Статус вакцинації від пневмонії для літніх дорослих (CQM)'),
(123514, 4894, 33, 'Ортопедичний'),
(123515, 4896, 33, 'Місце надання допомоги (POS)'),
(123516, 4897, 33, 'Поліс'),
(123517, 4898, 33, 'Номер поліса'),
(123518, 4899, 33, 'Номер поліса'),
(123519, 4900, 33, 'Польська'),
(123520, 4901, 33, 'Полідипсія'),
(123521, 4902, 33, 'Поліпи'),
(123522, 4903, 33, 'Поліурія'),
(123523, 4904, 33, 'Поганий апетит'),
(123524, 4905, 33, 'Порушення кровообігу'),
(123525, 4906, 33, 'Поганий слух'),
(123526, 4907, 33, 'Замітки мають бути включені, щоб бути відображеними в цих звітах'),
(123527, 4908, 33, 'Ззаповнити річний огляд подіями?'),
(123528, 4909, 33, 'Спливаючі вікна'),
(123529, 4910, 33, 'Портал'),
(123530, 4911, 33, 'Активність порталу'),
(123531, 4917, 33, 'Португальська'),
(123532, 4918, 33, 'Португальська (бразильська)'),
(123533, 4919, 33, 'Португальська (європейська)'),
(123534, 4920, 33, 'POS код'),
(123535, 4922, 33, 'Позитивний'),
(123536, 4923, 33, 'Точно'),
(123537, 4925, 33, 'Відправити для'),
(123538, 4926, 33, 'Краплі в ніс'),
(123539, 4927, 33, 'Відправити платіж'),
(123540, 4928, 33, 'Післяопераційний'),
(123541, 4929, 33, 'Відправити для фінансової обробки і помітити як оплачене'),
(123542, 4930, 33, 'Оплачено на дату'),
(123543, 4931, 33, 'Дата оплати не може бути пізніше сьогоднішнього дня'),
(123544, 4932, 33, 'Дата оплати має бути пізніше дати фінансового закриття'),
(123545, 4933, 33, 'Лікування після аботру'),
(123546, 4934, 33, 'Контрацепція після аборту'),
(123547, 4935, 33, 'Консультація після аборту'),
(123548, 4936, 33, 'Наслідки аборту'),
(123549, 4937, 33, 'Поштовий'),
(123550, 4938, 33, 'Поштовий індекс'),
(123551, 4939, 33, 'Поштовий індекс'),
(123552, 4941, 33, 'PostCalendar'),
(123553, 4942, 33, 'Адміністрування PostCalendar'),
(123554, 4943, 33, 'Налаштування категорії PostCalendar'),
(123555, 4944, 33, 'Загальні налаштування PostCalendar'),
(123556, 4945, 33, 'Опубліковано в'),
(123557, 4946, 33, 'Дата відправки'),
(123558, 4948, 33, 'Живиться від'),
(123559, 4949, 33, 'PRE + Prev Med/Surg Hx'),
(123560, 4950, 33, 'PQRI'),
(123561, 4951, 33, 'Реєстраційний ID для PQRI'),
(123562, 4952, 33, 'Реєстраційне ім''я для PQRI'),
(123563, 4953, 33, 'Лікарська практика'),
(123564, 4954, 33, 'Налаштування лікарської практики по замовчуванню'),
(123565, 4955, 33, 'Налаштування лікарької практики'),
(123566, 4956, 33, 'Практикуючий лікар'),
(123567, 4958, 33, 'Передоплата'),
(123568, 4959, 33, 'Передоплата'),
(123569, 4960, 33, 'Консультація перед абортом'),
(123570, 4961, 33, 'Консультування перед абортом'),
(123571, 4962, 33, 'Pref Cat'),
(123572, 4964, 33, 'Уподобання'),
(123573, 4965, 33, 'Категорія події, якій надається перевага'),
(123574, 4966, 33, 'Мова, якій надається перевага'),
(123575, 4967, 33, 'Аптека, якій надається перевага'),
(123576, 4968, 33, 'Постачальник медичних послуг, якому надається перевага (PPO)'),
(123577, 4969, 33, 'Тест на визначення вагітності'),
(123578, 4970, 33, 'Попередній'),
(123579, 4971, 33, 'Підготовка до запуску звіту'),
(123580, 4972, 33, 'Передоплата'),
(123581, 4973, 33, 'Призначення'),
(123582, 4974, 33, 'призначення досягло свого ліміту'),
(123583, 4975, 33, 'Історія призначень'),
(123584, 4976, 33, 'Імпорт історії призначень успішно завершено'),
(123585, 4977, 33, 'Мітка призначення'),
(123586, 4978, 33, 'Звіт про призначення'),
(123587, 4979, 33, 'Призначення'),
(123588, 4980, 33, 'Призначення і виконання'),
(123589, 4981, 33, 'Призначення та інші направлення'),
(123590, 4982, 33, 'Призначення і/або направлення спеціалістом'),
(123591, 4983, 33, 'Звіт про призначення'),
(123592, 4984, 33, 'Призначення/направлення'),
(123593, 4985, 33, 'Присутній'),
(123594, 4986, 33, 'Присутні скарги'),
(123595, 4987, 33, 'Присутня проблема(и)'),
(123596, 4988, 33, 'Нажміть Продовжити для обробки'),
(123597, 4989, 33, 'Гаданий діагноз'),
(123598, 4990, 33, 'Гаданий діагноз по спеціалісту'),
(123599, 4991, 33, 'Попер.'),
(123600, 4992, 33, 'Prev Med/Surg Hx'),
(123601, 4993, 33, 'Попередній місяць (утримуйте для меню)'),
(123602, 4994, 33, 'Попередній рік (утримуйте для меню)'),
(123603, 4995, 33, 'Профілактичне лікування'),
(123604, 4998, 33, 'Попередній перегляд події'),
(123605, 5000, 33, 'Попередній перегляд'),
(123606, 5001, 33, 'Попередній'),
(123607, 5002, 33, 'Попередні консультації'),
(123608, 5003, 33, 'Попередній день'),
(123609, 5004, 33, 'Попередня історія/огляд'),
(123610, 5005, 33, 'Попередній місяць'),
(123611, 5006, 33, 'Попередній тиждень'),
(123612, 5007, 33, 'Ціна'),
(123613, 5008, 33, 'Знижка на ціну'),
(123614, 5009, 33, 'Рівень цін'),
(123615, 5010, 33, 'Рівень цін:'),
(123616, 5011, 33, 'Ціни'),
(123617, 5012, 33, 'Основний'),
(123618, 5013, 33, 'Первинний суб''єкт господарювання'),
(123619, 5014, 33, 'tax id первинного суб''єкта господарювання використовується як id фінансового аналізу для NewCrop ePrescription. Зміна медичного закладу вплине на роботу в NewCrop.'),
(123620, 5022, 33, 'Основне страх.'),
(123621, 5023, 33, 'Основне страхування'),
(123622, 5024, 33, 'Дата основного страхування'),
(123623, 5025, 33, 'Основний страхувальник'),
(123624, 5026, 33, 'Основний спеціаліст'),
(123625, 5027, 33, 'Друк'),
(123626, 5028, 33, 'Друк (HTML)'),
(123627, 5029, 33, 'Друк (PDF)'),
(123628, 5031, 33, 'Друкувати будь-яке звернення'),
(123629, 5032, 33, 'Друкувати пусту форму направлення'),
(123630, 5033, 33, 'Команда друку'),
(123631, 5034, 33, 'Дата друку'),
(123632, 5039, 33, 'Формат друку'),
(123633, 5040, 33, 'Друк чотирьох панелей'),
(123634, 5042, 33, 'Друк повідомлення'),
(123635, 5043, 33, 'Багаторазовий друк'),
(123636, 5044, 33, 'Багаторазовий вивід на факс'),
(123637, 5045, 33, 'Друкувати назва, підпис і дата друку'),
(123638, 5046, 33, 'Друк записів'),
(123639, 5047, 33, 'Друк сторінки 1'),
(123640, 5048, 33, 'Друк сторінки 2'),
(123641, 5051, 33, 'Друк рецептів по спеціалісту'),
(123642, 5052, 33, 'Друкувати запис'),
(123643, 5053, 33, 'Друк вибраних заявок'),
(123644, 5054, 33, 'Друк частини запису'),
(123645, 5056, 33, 'Друкувати це звернення'),
(123646, 5057, 33, 'Друкувати цей запис'),
(123647, 5058, 33, 'Друкувати цей запис'),
(123648, 5060, 33, 'Виводити на факс'),
(123649, 5061, 33, 'Вид друку'),
(123650, 5062, 33, 'для друку'),
(123651, 5063, 33, 'Версія для друку'),
(123652, 5064, 33, 'Надрукований'),
(123653, 5066, 33, 'Результати друку:'),
(123654, 5067, 33, 'Друк пропущений; див. тестовий вивід в'),
(123655, 5068, 33, 'Друк пропущений; див. тестовий вивід в '),
(123656, 5069, 33, 'Попередня аутентифікація'),
(123657, 5070, 33, 'Форма попередньої аутентифікації'),
(123658, 5071, 33, 'Попередній візит'),
(123659, 5072, 33, 'Пріоритет'),
(123660, 5073, 33, 'Пріоритет '),
(123661, 5074, 33, 'Конфіденційний'),
(123662, 5075, 33, 'Проблема'),
(123663, 5076, 33, 'Проблема DX'),
(123664, 5077, 33, 'Список проблем'),
(123665, 5079, 33, 'Проблеми/питання'),
(123666, 5080, 33, 'Проц. Бат'),
(123667, 5081, 33, 'Проц. Кат.'),
(123668, 5082, 33, 'Проц. Завантаження'),
(123669, 5083, 33, 'Проц. Очік. Перегл.'),
(123670, 5084, 33, 'Проц. Пост.'),
(123671, 5085, 33, 'Проц. Рез.'),
(123672, 5086, 33, 'Процедура'),
(123673, 5087, 33, 'Ділянки тіла для процедури'),
(123674, 5088, 33, 'Логічні результати процедури'),
(123675, 5089, 33, 'Код процедури'),
(123676, 5090, 33, 'Коди процедур'),
(123677, 5091, 33, 'Латералізація процедури'),
(123678, 5092, 33, 'Назва процедури'),
(123679, 5093, 33, 'Призначення процедури'),
(123680, 5094, 33, 'Призначення процедури'),
(123681, 5095, 33, 'Призначення процедури для'),
(123682, 5097, 33, 'Призначення і звіти по процедурі'),
(123683, 5098, 33, 'Вибір процедури'),
(123684, 5099, 33, 'Спеціаліст по процедурі'),
(123685, 5100, 33, 'Спеціаліст по процедурі'),
(123686, 5101, 33, 'Спеціалісти по процедурі'),
(123687, 5102, 33, 'Звіт по процедурі'),
(123688, 5103, 33, 'Статуси звіту процедури'),
(123689, 5104, 33, 'Відхилення результату процедури від норми'),
(123690, 5105, 33, 'Статуси звіту процедури'),
(123691, 5106, 33, 'Результати процедури'),
(123692, 5107, 33, 'Шляхи процедури'),
(123693, 5108, 33, 'Тип біозразка для процедури'),
(123694, 5109, 33, 'Статистичний звіт по процедурі'),
(123695, 5110, 33, 'Тип процедури'),
(123696, 5111, 33, 'Типи процедури'),
(123697, 5112, 33, 'Частини процедури'),
(123698, 5113, 33, 'Процедура/Послуга'),
(123699, 5114, 33, 'Процедури'),
(123700, 5115, 33, 'Обробити'),
(123701, 5116, 33, 'Обробити і послати нагадування'),
(123702, 5117, 33, 'Обробка файлу ERA'),
(123703, 5118, 33, 'Обробити нові файли з CSV-записами'),
(123704, 5119, 33, 'Обробити нагадування'),
(123705, 5120, 33, 'Обробка займе деякий час'),
(123706, 5121, 33, 'Оброблений'),
(123707, 5122, 33, 'Оброблений з'),
(123708, 5123, 33, 'Оброблена дата'),
(123709, 5124, 33, 'оброблено успішно'),
(123710, 5125, 33, 'Обробка'),
(123711, 5126, 33, 'Обробка і відсилання нагадувань для пацієнтів'),
(123712, 5127, 33, 'Обробка нагадувань для пацієнів'),
(123713, 5128, 33, 'Час обробки'),
(123714, 5129, 33, 'Виготовлення'),
(123715, 5130, 33, 'Виготовлення засобу контрацепції'),
(123716, 5131, 33, 'Виготовлення'),
(123717, 5132, 33, 'Виготовлено'),
(123718, 5133, 33, 'Виготовлено, але не ліків за рецептом і без шаблонів'),
(123719, 5134, 33, 'Проф.'),
(123720, 5135, 33, 'Обробка записів'),
(123721, 5136, 33, 'Рак передміхурової залози'),
(123722, 5137, 33, 'Скринінг раку простати'),
(123723, 5138, 33, 'Огляд простати'),
(123724, 5139, 33, 'Проблеми з простатою'),
(123725, 5140, 33, 'Простата без збільшень, вузлів, чутлива'),
(123726, 5141, 33, 'Протокол'),
(123727, 5142, 33, 'Надайте абсолютний шлях'),
(123728, 5143, 33, 'Надайте абсолютний шлях до файлу'),
(123729, 5145, 33, 'Надання клінічних резюме по пацієнтах, для кожного відвідування кабінету.'),
(123730, 5146, 33, 'Надання пацієнтам за запитом електронної копії їхньої медичної інформації (в тому числі результати діагностики, список питань, списки ліків, засоби від алергій).'),
(123731, 5147, 33, 'Надання пацієнтам своєчасного електронний доступу до їхньої медичної інформації (в тому числі результати лабораторних аналізів, список питань, списки ліків, засоби від алергії) протягом чотирьох робочих днів з інформацією, доступною EP.'),
(123732, 5148, 33, 'Забезпечити запис для пацієнтів на відвідування'),
(123733, 5149, 33, 'Надайте правильну адресу електронної пошти'),
(123734, 5150, 33, 'Надати клінічну інформацію?'),
(123735, 5151, 33, 'Надати освітні(й) ресурс(и)?'),
(123736, 5152, 33, 'Спеціаліст'),
(123737, 5153, 33, 'ID спеціаліста'),
(123738, 5154, 33, 'ID спеціаліста'),
(123739, 5155, 33, 'ID спеціаліста і визначений медзаклад'),
(123740, 5156, 33, 'Помилки відповідності спеціаліста'),
(123741, 5159, 33, 'Номер спеціаліста'),
(123742, 5160, 33, 'Взаємозв"язок спеціалістів'),
(123743, 5162, 33, 'Спеціаліст:'),
(123744, 5163, 33, 'Спеціалісти'),
(123745, 5164, 33, 'Спеціалісти NPI'),
(123746, 5165, 33, 'Спеціалісти бачать вміст календаря'),
(123747, 5166, 33, 'Prv'),
(123748, 5167, 33, 'PSA'),
(123749, 5168, 33, 'Псоріаз'),
(123750, 5169, 33, 'Псих. діагноз'),
(123751, 5170, 33, 'Псих. Лікування'),
(123752, 5171, 33, 'Психіатричний'),
(123753, 5172, 33, 'Короткий психіатричний лист'),
(123754, 5173, 33, 'Психіатричний діагноз'),
(123755, 5174, 33, 'Психіатричний огляд'),
(123756, 5175, 33, 'Психіатричний анамнез'),
(123757, 5176, 33, 'Вживання психотропних препаратів'),
(123758, 5177, 33, 'Психіатричний препарат'),
(123759, 5178, 33, 'Проц. %'),
(123760, 5179, 33, 'Проц. записів'),
(123761, 5180, 33, 'Проц. записів/дозв.'),
(123762, 5181, 33, 'Проц. переплати'),
(123763, 5182, 33, 'Проц. оплати'),
(123764, 5183, 33, 'Проц. запиту реєстр.'),
(123765, 5184, 33, 'Проц. відшкодувань'),
(123766, 5185, 33, 'Проц. релізу'),
(123767, 5186, 33, 'Проц. звіту'),
(123768, 5187, 33, 'PT студента або залиште пустим'),
(123769, 5188, 33, 'PT МІСТО'),
(123770, 5189, 33, 'PT_ДАТАНАРОДЖ'),
(123771, 5191, 33, 'PT ІМ''Я'),
(123772, 5192, 33, 'PT ПРІЗВИЩЕ'),
(123773, 5193, 33, 'PT_ПОБАТЬОВІ'),
(123774, 5196, 33, 'PT ПОШТОВИЙ'),
(123775, 5198, 33, 'PT КРАЇНА'),
(123776, 5199, 33, 'PT ВУЛИЦЯ'),
(123777, 5201, 33, 'Громадський'),
(123778, 5203, 33, 'Служба охорони здоров''я (PHS) чи ішна державна установа'),
(123779, 5204, 33, 'Пуерториканський'),
(123780, 5205, 33, 'Легеневий'),
(123781, 5206, 33, 'Пульс'),
(123782, 5207, 33, 'Панджабський'),
(123783, 5208, 33, 'Покупка'),
(123784, 5209, 33, 'Покупка/повернення'),
(123785, 5210, 33, 'Покупки'),
(123786, 5211, 33, 'P{{Вирівнювання заголовка}}'),
(123787, 5213, 33, 'кожні 3 години'),
(123788, 5214, 33, 'кожні 4 години'),
(123789, 5215, 33, 'кожні 5 годин'),
(123790, 5216, 33, 'кожні 6 годин'),
(123791, 5217, 33, 'кожні 8 годин'),
(123792, 5218, 33, 'кожний день'),
(123793, 5219, 33, 'чотири рази на день'),
(123794, 5220, 33, 'QOH'),
(123795, 5221, 33, 'QOH менше, ніж щомісячне вживання'),
(123796, 5222, 33, 'Qty'),
(123797, 5223, 33, 'QTY'),
(123798, 5224, 33, 'Якість'),
(123799, 5225, 33, 'Оцінка якості (CQM)'),
(123800, 5226, 33, 'Кількість'),
(123801, 5227, 33, 'Кількість для NDC'),
(123802, 5228, 33, 'Наявна кількість'),
(123803, 5229, 33, 'кількість, що є непридатною'),
(123804, 5231, 33, 'Знак запитання'),
(123805, 5232, 33, 'Черга на пакетну обробку HCFA'),
(123806, 5233, 33, 'Черга на пакетну обробку і друк HCFA'),
(123807, 5234, 33, 'Черга на пакетну обробку UB-92'),
(123808, 5235, 33, 'Черга на пакетну обробку і друк UB-92'),
(123809, 5236, 33, 'У черзі'),
(123810, 5237, 33, 'Управління подіями в черзі'),
(123811, 5238, 33, 'У черзі на'),
(123812, 5240, 33, 'Управління матеріалами в черзі'),
(123813, 5241, 33, 'Вихід'),
(123814, 5242, 33, 'Колишній алкоголік'),
(123815, 5243, 33, 'R'),
(123816, 5244, 33, 'RA для пацієнта, звернення чи запису'),
(123817, 5245, 33, 'Раса'),
(123818, 5246, 33, 'Раса та етнос'),
(123819, 5247, 33, 'Раса/етнос'),
(123820, 5248, 33, 'Радіо'),
(123821, 5249, 33, 'Кнопки перемикання'),
(123822, 5251, 33, 'Діапазон'),
(123823, 5252, 33, 'Висип'),
(123824, 5253, 33, 'Швидкість'),
(123825, 5254, 33, 'Співвідношення'),
(123826, 5255, 33, 'Необроблений звіт'),
(123827, 5256, 33, 'Повторна ідентифікація'),
(123828, 5257, 33, 'Процес повторної ідентифікації завершений'),
(123829, 5258, 33, 'Процес повторної ідентифікації триває'),
(123830, 5259, 33, 'Файли повторної ідентифікації будуть збережені у'),
(123831, 5260, 33, 'Повторна травма?'),
(123832, 5261, 33, 'Повторне відкриття'),
(123833, 5262, 33, 'Відкритий повторно'),
(123834, 5263, 33, 'Реакція'),
(123835, 5264, 33, 'Реакції'),
(123836, 5265, 33, 'Читати'),
(123837, 5268, 33, 'Справжнє ім''я'),
(123838, 5269, 33, 'Справді видалити'),
(123839, 5270, 33, 'Причина'),
(123840, 5271, 33, 'Помер з причини'),
(123841, 5272, 33, 'Причина смерті'),
(123842, 5274, 33, 'Причина для направлення'),
(123843, 5275, 33, 'Причина для візиту'),
(123844, 5276, 33, 'Причина/форма'),
(123845, 5277, 33, 'Квитанція'),
(123846, 5278, 33, 'Квитанція для оплати'),
(123847, 5279, 33, 'Квитанція створена'),
(123848, 5280, 33, 'Квитанція по вказуванню методу оплати'),
(123849, 5281, 33, 'Підсумкові надходження'),
(123850, 5282, 33, 'Отриманий'),
(123851, 5283, 33, 'Отриманий через'),
(123852, 5284, 33, 'Отримані факси'),
(123853, 5285, 33, 'Отримано, не переглянуто'),
(123854, 5287, 33, 'Одержувач'),
(123855, 5288, 33, 'ID одержувача'),
(123856, 5289, 33, 'ID одержувача (ISA08)'),
(123857, 5290, 33, 'Визначник ID одержувача (ISA07)'),
(123858, 5291, 33, 'ID-и одержувача'),
(123859, 5292, 33, 'Останні три паролі не дозволені'),
(123860, 5293, 33, 'Отримувач'),
(123861, 5294, 33, 'Список отримувачів порожній'),
(123862, 5295, 33, 'Ім''я отримувача'),
(123863, 5296, 33, 'Адресат опублікованої інформації'),
(123864, 5297, 33, 'Вимагається отримувач аждопоки статус є "Готово"'),
(123865, 5298, 33, 'Рекомендація'),
(123866, 5299, 33, 'Рекомендація по завершенню'),
(123867, 5300, 33, 'Рекомендації'),
(123868, 5301, 33, 'Рекомендації і лікування'),
(123869, 5302, 33, 'Рекомендації по спеціалісту'),
(123870, 5303, 33, 'Запис'),
(123871, 5304, 33, 'Запис вже існує'),
(123872, 5310, 33, 'Зміна запису і карти по життєво-важливих функціях.'),
(123873, 5311, 33, 'Записувати демографічні дані'),
(123874, 5312, 33, 'Публікація запису'),
(123875, 5313, 33, 'Запис про тренованість'),
(123876, 5314, 33, 'Записати оплату'),
(123877, 5315, 33, 'Записати дату запиту'),
(123878, 5316, 33, 'Запис про куріння для пацієнтів 13 років і старше.'),
(123879, 5317, 33, 'Записи'),
(123880, 5318, 33, 'знайдено записи'),
(123881, 5319, 33, 'знайдено записи.'),
(123882, 5320, 33, 'Нерегулярне вживання наркотиків (для розваг)'),
(123883, 5321, 33, 'Нерегулярні (рекреаційні) наркотики'),
(123884, 5322, 33, 'Ректальний'),
(123885, 5323, 33, 'Ректальний огляд'),
(123886, 5324, 33, 'ректально'),
(123887, 5325, 33, 'Перенаправлення'),
(123888, 5326, 33, 'Почервоніння'),
(123889, 5327, 33, 'зменшений:'),
(123890, 5328, 33, 'Посилатись'),
(123891, 5329, 33, 'Посилатись через'),
(123892, 5330, 33, 'Дата посилання'),
(123893, 5331, 33, 'Посилатись на'),
(123894, 5332, 33, 'Класифікація направлень (рівень ризику)'),
(123895, 5333, 33, 'Діапазон результатів направлень'),
(123896, 5334, 33, 'Причина направлення'),
(123897, 5336, 33, 'Ім''я і підпис того, хто направляє'),
(123898, 5337, 33, 'Направлення'),
(123899, 5338, 33, 'Направлення через'),
(123900, 5339, 33, 'Талон направлення'),
(123901, 5340, 33, 'Дата направлення'),
(123902, 5341, 33, 'Форма направлення'),
(123903, 5342, 33, 'ФОРМА НАПРАВЛЕННЯ'),
(123904, 5343, 33, 'ID направлення'),
(123905, 5345, 33, 'Джерело направлення'),
(123906, 5346, 33, 'Джерело направлення для звернень'),
(123907, 5347, 33, 'Направлення до'),
(123908, 5348, 33, 'Направлення'),
(123909, 5349, 33, 'Звіт направлення'),
(123910, 5350, 33, 'Направлений через'),
(123911, 5351, 33, 'Направлений Через'),
(123912, 5352, 33, 'Направлений до'),
(123913, 5353, 33, 'Хто направив'),
(123914, 5355, 33, 'Діагноз при направленні'),
(123915, 5356, 33, 'Діагноз при направленні'),
(123916, 5357, 33, 'Лікар, який направив і лікарська практика'),
(123917, 5358, 33, 'Спеціаліст, який направив'),
(123918, 5359, 33, 'Повторно заповнювати'),
(123919, 5360, 33, 'Повторно заповнені'),
(123920, 5361, 33, 'повторно заповнені'),
(123921, 5362, 33, 'Рефлекси нормальні'),
(123922, 5363, 33, 'Оновити'),
(123923, 5365, 33, 'Оновлені нагадування'),
(123924, 5368, 33, 'Відмовлено встановлювати'),
(123925, 5369, 33, 'reg_re'),
(123926, 5370, 33, 'реєструвати'),
(123927, 5372, 33, 'Зареєстрований'),
(123928, 5373, 33, 'зареєстрований'),
(123929, 5375, 33, 'Дата реєстрації'),
(123930, 5376, 33, 'Форма реєстрації'),
(123931, 5377, 33, 'Реабілітація'),
(123932, 5380, 33, 'Можливість рецидиву'),
(123933, 5381, 33, 'Зв''язати з'),
(123934, 5382, 33, 'Пов''язані'),
(123935, 5383, 33, 'Пов''язані питання'),
(123936, 5384, 33, 'Пов''язані замітки про пацієнта'),
(123937, 5385, 33, 'Родич(і)/діти'),
(123938, 5386, 33, 'Родичі'),
(123939, 5387, 33, 'Взаємовідносини'),
(123940, 5388, 33, 'Відносний порядок цього об''єкта'),
(123941, 5389, 33, 'Родинні'),
(123942, 5399, 33, 'Повноваження Relay Health відсутні в цьому обліковому записі користувача.'),
(123943, 5400, 33, 'Relay Health ID'),
(123944, 5402, 33, 'Дата випуску'),
(123945, 5403, 33, 'Релігія'),
(123946, 5406, 33, 'Повторно увійти в систему'),
(123947, 5407, 33, 'Нагадув.'),
(123948, 5408, 33, 'Запам''ятати вибраний медичний заклад'),
(123949, 5409, 33, 'Нагадування'),
(123950, 5410, 33, 'Інтервали нагадування'),
(123951, 5411, 33, 'Нагадування ще не надіслано'),
(123952, 5412, 33, 'Нагадування надіслано'),
(123953, 5413, 33, 'Нагадування'),
(123954, 5414, 33, 'ПЕРЕВЕСТИ В'),
(123955, 5415, 33, 'Віддалений хост'),
(123956, 5416, 33, 'Видалити'),
(123957, 5419, 33, 'Видалити групу'),
(123958, 5420, 33, 'Видалити форму групи'),
(123959, 5421, 33, 'Відключає підтримку для імунізації'),
(123960, 5422, 33, 'Відключає підтримку для phpMyAdmin'),
(123961, 5423, 33, 'Відключає підтримку для призначень'),
(123962, 5425, 33, 'Видаляє функцію відслідковування карти'),
(123963, 5426, 33, 'Ниркові камені'),
(123964, 5427, 33, 'Переіменовувати'),
(123965, 5428, 33, 'Переіменовувати групу'),
(123966, 5429, 33, 'Відображення'),
(123967, 5430, 33, 'Призначений спеціаліст'),
(123968, 5431, 33, 'Номер призначеного спеціаліста'),
(123969, 5432, 33, 'Переназначити'),
(123970, 5433, 33, 'Переназначити на'),
(123971, 5434, 33, 'Вказівка по переназначенню виконана'),
(123972, 5435, 33, 'Вказівка по переназначенню, 0 якщо не стосується'),
(123973, 5436, 33, 'Повт.'),
(123974, 5437, 33, 'Повторити новий пароль'),
(123975, 5438, 33, 'Повторювана подія'),
(123976, 5439, 33, 'Повторювана інформація'),
(123977, 5440, 33, 'Повторює'),
(123978, 5441, 33, 'ЗАМІНИТИ'),
(123979, 5444, 33, 'Дата відповіді'),
(123980, 5445, 33, 'Форма відповіді'),
(123981, 5446, 33, 'Звіт'),
(123982, 5447, 33, 'Звіт - клінічний'),
(123983, 5449, 33, 'Звіт по'),
(123984, 5453, 33, 'Звіт Історія/Результати'),
(123985, 5454, 33, 'Звіт Результати'),
(123986, 5455, 33, 'Звіт Результати/Історія'),
(123987, 5457, 33, 'Статус звіту'),
(123988, 5458, 33, 'Сумарний звіт'),
(123989, 5459, 33, 'Звіт/Форма'),
(123990, 5460, 33, 'Звітний'),
(123991, 5461, 33, 'Повідомлений'),
(123992, 5462, 33, 'Звітна дата'),
(123993, 5463, 33, 'Звіти'),
(123994, 5467, 33, 'Запрос проігноровано -- обробка вимоги вже виконується'),
(123995, 5474, 33, 'Запит на послугу'),
(123996, 5475, 33, 'Обов''язково надійні паролі'),
(123997, 5476, 33, 'Обов''язково унікальні паролі'),
(123998, 5477, 33, 'Обов''язковий'),
(123999, 5478, 33, 'Обов''язкова доплата'),
(124000, 5479, 33, 'Обов''язкове поле пропущене: Будь-ласка, виберіть EDI-271 файл для завантаження'),
(124001, 5480, 33, 'Обов''язкове поле пропущене: Будь-ласка, введіть ім''я'),
(124002, 5481, 33, 'Обов''язкове поле пропущене: Будь-ласка, введіть прізвище'),
(124003, 5482, 33, 'Обов''язкове поле пропущене: Будь-ласка, введіть ім''я користувача'),
(124004, 5483, 33, 'Обов''язкові поля'),
(124005, 5484, 33, 'Вимоги'),
(124006, 5485, 33, 'ЗАРЕЗЕРВОВАНИЙ'),
(124007, 5486, 33, 'Зарезервований'),
(124008, 5487, 33, 'Зарезевовано для використання в наданні запланованого періоду відпустки'),
(124009, 5488, 33, 'Зарезервовано для обмеження, з якого часу до спеціаліста запис на прийом не доступний'),
(124010, 5489, 33, 'Зарезервовано для визначення, коли подія не трапляється як зазначено'),
(124011, 5490, 33, 'Заерезервовано для визначення, коли спеціаліст може мати час для прийому'),
(124012, 5491, 33, 'Скидання'),
(124013, 5492, 33, 'Скинути загальні параметри для зовнішнього порталу'),
(124014, 5493, 33, 'Скинути місцеві параметри для внутрішнього порталу'),
(124015, 5495, 33, 'Resn'),
(124016, 5496, 33, 'Вирішений'),
(124017, 5497, 33, 'Дихання'),
(124018, 5498, 33, 'Незначна задишка'),
(124019, 5499, 33, 'Дихальний'),
(124020, 5501, 33, 'Обмежити доступ несанкціонованих користувачів до налаштувань розкладів медичних закладів в адмінпанелі користувача.'),
(124021, 5502, 33, 'Обмежити доступ користувачів по медичних закладах'),
(124022, 5503, 33, 'Обмежене навчання'),
(124023, 5504, 33, 'Результат'),
(124024, 5505, 33, 'Ім"я результату'),
(124025, 5506, 33, 'Статус результату'),
(124026, 5507, 33, 'Статус результату чи відхилення від норми відсутнє'),
(124027, 5508, 33, 'Результат, використання % як знак підстановки'),
(124028, 5509, 33, 'Результати'),
(124029, 5510, 33, 'Результати і'),
(124030, 5511, 33, 'Результати знайдені в ході пошуку'),
(124031, 5512, 33, 'Група результатів'),
(124032, 5514, 33, 'Шлях результатів'),
(124033, 5515, 33, 'Результатів на сторінці'),
(124034, 5516, 33, 'Результати/Деталі'),
(124035, 5517, 33, 'Огляд сітківки'),
(124036, 5518, 33, 'Відмовляти у праві:'),
(124037, 5519, 33, 'Повертати'),
(124038, 5520, 33, 'Повертати вказану вище частину з вашою оплатою'),
(124039, 5521, 33, 'Повернутися до календаря'),
(124040, 5522, 33, 'Повернутися до звіту "Результати"'),
(124041, 5523, 33, 'Поверніться до цієї сторінки і Ви зможете завершити процес встанвлення ICD10, клацнувши на заголовку розділу ICD10'),
(124042, 5524, 33, 'Поверніться до цієї сторінки і Ви зможете завершити процес встанвлення ICD9, клацнувши на заголовку розділу ICD9'),
(124043, 5525, 33, 'Поверніться до цієї сторінки і Ви зможете завершити процес встанвлення RxNorm, клацнувши на заголовку розділу RXNORM'),
(124044, 5526, 33, 'Поверніться до цієї сторінки і Ви зможете завершити процес встанвлення Snomed, клацнувши на заголовку розділу SNOMED'),
(124045, 5527, 33, 'Повернути значення'),
(124046, 5528, 33, 'Повернути візит'),
(124047, 5529, 33, 'Знову виконувати'),
(124048, 5530, 33, 'Повторне використання трьох попередніх паролів не дозволено!'),
(124049, 5534, 33, 'Огляд анамнезу перенесених захворювань'),
(124050, 5535, 33, 'Огляд по системах'),
(124051, 5536, 33, 'Огляд вибору систем'),
(124052, 5537, 33, 'Переглянутий'),
(124053, 5538, 33, 'Перегляд'),
(124054, 5539, 33, 'Ревматоїдний артрит'),
(124055, 5540, 33, 'Ревматоїдний артрит'),
(124056, 5541, 33, 'Правий'),
(124057, 5542, 33, 'Праве Вухо'),
(124058, 5543, 33, 'праве вухо'),
(124059, 5545, 33, 'Правий:'),
(124060, 5546, 33, 'Дзвін у вухах'),
(124061, 5547, 33, 'Дзвін у вухах'),
(124062, 5549, 33, 'Фактори ризику'),
(124063, 5550, 33, 'Рівень ризику'),
(124064, 5551, 33, 'RLL:'),
(124065, 5552, 33, 'ROM'),
(124066, 5553, 33, 'Румунська'),
(124067, 5560, 33, 'Реєстр'),
(124068, 5561, 33, 'Шлях'),
(124069, 5562, 33, 'Спосіб застосування, якщо це може бути застосовано'),
(124070, 5563, 33, 'Маршрутизований'),
(124071, 5564, 33, 'Рядки'),
(124072, 5565, 33, 'RRR без MOR'),
(124073, 5566, 33, 'Шум тертя:'),
(124074, 5567, 33, 'Шуми тертя:'),
(124075, 5568, 33, 'Правило'),
(124076, 5569, 33, 'Додати правило'),
(124077, 5570, 33, 'Інформація про правило'),
(124078, 5572, 33, 'Змінити правило'),
(124079, 5575, 33, 'Набір правил'),
(124080, 5578, 33, 'Правила'),
(124081, 5580, 33, 'Налаштування правил'),
(124082, 5581, 33, 'Запуск команди: '),
(124083, 5582, 33, 'Розрив'),
(124084, 5583, 33, 'Російська'),
(124085, 5584, 33, 'Rx'),
(124086, 5585, 33, 'RX'),
(124087, 5586, 33, 'Rx нижнє поле (px)'),
(124088, 5587, 33, 'Rx включити DEA #'),
(124089, 5588, 33, 'Rx включити NPI'),
(124090, 5589, 33, 'Rx включити State Lic. #'),
(124091, 5590, 33, 'Rx ліве поле (px)'),
(124092, 5591, 33, 'Rx розмір сторінки'),
(124093, 5592, 33, 'Rx праве поле'),
(124094, 5593, 33, 'Rx показати'),
(124095, 5594, 33, 'Rx показати'),
(124096, 5595, 33, 'Rx показати стан'),
(124097, 5596, 33, 'Rx верхнє поле (px)'),
(124098, 5598, 33, 'RxNorm'),
(124099, 5599, 33, 'RxNorm база даних'),
(124100, 5600, 33, 'S'),
(124101, 5601, 33, 'Інд. податк. номер'),
(124102, 5602, 33, 'S3:'),
(124103, 5603, 33, 'S4:'),
(124104, 5604, 33, 'SА ** щоб прочитати ліцензію, будь ласка, прочитайте docs/license.txt або відвідайте * http://www.gnu.org/copyleft/gpl.html * */ //========================================================================= // '),
(124105, 5605, 33, 'Продаж'),
(124106, 5606, 33, 'Продажі'),
(124107, 5607, 33, 'Продажі поштучно'),
(124108, 5608, 33, 'Звіт по реалізації продукту'),
(124109, 5609, 33, 'Слина'),
(124110, 5610, 33, 'В той самий день'),
(124111, 5611, 33, 'Самоа'),
(124112, 5612, 33, 'Зразок'),
(124113, 5613, 33, 'Тип санкції'),
(124114, 5617, 33, 'Суб.'),
(124115, 5618, 33, 'Суб. &amp; Нед.'),
(124116, 5619, 33, 'Субота'),
(124117, 5620, 33, 'Зберегти'),
(124118, 5621, 33, 'ЗБЕРЕГТИ'),
(124119, 5622, 33, 'Зберегти і закрити'),
(124120, 5624, 33, 'Зберегти і внести'),
(124121, 5625, 33, 'Зберегти і передати'),
(124122, 5626, 33, 'Зберегти як новий'),
(124123, 5627, 33, 'Зберегти як новий запис'),
(124124, 5628, 33, 'Зберегти параметри сертифікатів'),
(124125, 5629, 33, 'Зберегти зміни'),
(124126, 5630, 33, 'Зберегти форму'),
(124127, 5631, 33, 'Зберегти імунізацію'),
(124128, 5632, 33, 'Зберегти нове поле'),
(124129, 5633, 33, 'Зберегти нову групу'),
(124130, 5634, 33, 'Зберегти новий список'),
(124131, 5635, 33, 'Зберегти новий шаблон'),
(124132, 5636, 33, 'Зберегти пропущені виділення'),
(124133, 5637, 33, 'Зберегти персональні дані пацієнта'),
(124134, 5638, 33, 'Збереження виконано успішно для карти з ID'),
(124135, 5639, 33, 'Зберегти транзакцію'),
(124136, 5641, 33, 'Переглянуто'),
(124137, 5642, 33, 'Переглянутий запис за зверненням'),
(124138, 5643, 33, 'Переглянута директорія'),
(124139, 5644, 33, 'Переглянуто в'),
(124140, 5645, 33, 'Розклад'),
(124141, 5646, 33, 'Розклади медичних закладів:'),
(124142, 5647, 33, 'ШКІЛЬНИЙ ЗАПИС'),
(124143, 5648, 33, 'Сколіоз'),
(124144, 5651, 33, 'SE'),
(124145, 5652, 33, 'Адреса SE'),
(124146, 5653, 33, 'Місто SE'),
(124147, 5654, 33, 'Країна SE'),
(124148, 5655, 33, 'Розташування SE'),
(124149, 5656, 33, 'Поштовий індекс SE'),
(124150, 5657, 33, 'Штат SE'),
(124151, 5658, 33, 'Поштовий індекс SE'),
(124152, 5659, 33, 'Пошук'),
(124153, 5661, 33, 'пошук'),
(124154, 5662, 33, 'повторити пошук'),
(124155, 5663, 33, 'Шукати в усіх стовбцях'),
(124156, 5664, 33, 'Пошук по:'),
(124157, 5665, 33, 'Пошук для'),
(124158, 5666, 33, 'Пошук для:'),
(124159, 5667, 33, 'Пошук в'),
(124160, 5668, 33, 'Пошук в'),
(124161, 5669, 33, 'Шукати або Добавити пацієнта'),
(124162, 5670, 33, 'Пошук оплати'),
(124163, 5671, 33, 'Результати пошуку'),
(124164, 5672, 33, 'Результати пошуку:'),
(124165, 5673, 33, 'Вибраний пошук'),
(124166, 5674, 33, 'Рядок пошуку не збігається зі списком в базі даних'),
(124167, 5675, 33, 'Рядок пошуку повинен мати принаймні три символи'),
(124168, 5676, 33, 'Текстовой пошук'),
(124169, 5677, 33, 'Пошук події'),
(124170, 5678, 33, 'Знайти/Додати'),
(124171, 5679, 33, 'Знайти/Додати страховика'),
(124172, 5680, 33, 'Пошук для записів на прийом'),
(124173, 5681, 33, 'Йде пошук ...'),
(124174, 5682, 33, 'Використання ременя безпеки'),
(124175, 5683, 33, 'Використання ременя безпеки'),
(124176, 5684, 33, 'Другий'),
(124177, 5687, 33, 'Повторний'),
(124178, 5688, 33, 'Повторна страховка'),
(124179, 5689, 33, 'Дата повторної страховки'),
(124180, 5690, 33, 'Постачальник повторної страховки'),
(124181, 5691, 33, 'Тип повторної медичної допомоги'),
(124182, 5698, 33, 'Безпека'),
(124183, 5699, 33, 'Переглянути всі'),
(124184, 5700, 33, 'Показати дозволи'),
(124185, 5701, 33, 'Показати карту фізичного розвитку'),
(124186, 5702, 33, 'Показати повідомлення з останньої групи створених вимог'),
(124187, 5704, 33, 'Показати, починаючи з'),
(124188, 5705, 33, 'Ім"я сегменту'),
(124189, 5706, 33, 'Пакетна вимога сегментів'),
(124190, 5707, 33, 'Пароксизм'),
(124191, 5708, 33, 'Вибр.'),
(124192, 5709, 33, 'Вибрати'),
(124193, 5710, 33, 'вибрати'),
(124194, 5712, 33, 'Вибрати контекст'),
(124195, 5713, 33, 'Виберіть відсоток рядків чи виберіть дати'),
(124196, 5714, 33, 'Вибрати проміжок часу'),
(124197, 5715, 33, 'Вибрати користувача'),
(124198, 5716, 33, 'Вибрати все'),
(124200, 5720, 33, 'Вибрати категорію'),
(124201, 5722, 33, 'Виберіть відповідний перемикач для видалення'),
(124202, 5723, 33, 'Виберіть критерій для видалення'),
(124203, 5724, 33, 'Виберіть CSV таблицю'),
(124204, 5725, 33, 'Виберіть потрібну інформацію для де-ідентифікації'),
(124205, 5726, 33, 'Виберіть інформацію для включення в дані по де-ідентифікації'),
(124206, 5727, 33, 'Виберіть інформцію'),
(124207, 5728, 33, 'Виберіть необхідну групу'),
(124208, 5729, 33, 'Виберіть діагноз'),
(124209, 5730, 33, 'Виберіть діагноз для запиту щодо де-ідентифікації'),
(124210, 5731, 33, 'Виберіть препарат'),
(124211, 5732, 33, 'Виберіть препарати'),
(124212, 5733, 33, 'Виберіть препарати для запиту щодо де-ідентифікації'),
(124213, 5734, 33, 'Виберіть файл EDI-271'),
(124214, 5736, 33, 'Виберіть поле'),
(124215, 5737, 33, 'Виберіть поля'),
(124216, 5738, 33, 'Вибір для друку'),
(124217, 5739, 33, 'Виберіть вакцинацію'),
(124218, 5740, 33, 'Виберіть вакцинацію для запиту щодо де-ідентифікації'),
(124219, 5741, 33, 'Виберіть страховку, друком');
INSERT INTO `lang_definitions` VALUES
(124220, 5742, 33, 'Виберіть проблему'),
(124221, 5744, 33, 'Виберіть мову'),
(124222, 5745, 33, 'Виберіть один'),
(124223, 5746, 33, 'Виберіть один чи більше діагностичних кодів, щоб обгрунтувати послугу'),
(124224, 5747, 33, 'Виберіть один чи більше файлів для вивантаження'),
(124225, 5754, 33, 'Виберіть елементи конфігурації для експорту'),
(124226, 5755, 33, 'Виберіть проблему, яка є головною причиною будь-якої пропущеної події в цей день'),
(124227, 5759, 33, 'Виберіть користувача'),
(124228, 5760, 33, 'Виберіть користувачів зі списку'),
(124229, 5761, 33, 'Виберіть, які мови з доступних можуть бути обрані при вході в систему (застосовується, лише якщо вище відключено вибір з усіх мов)'),
(124230, 5762, 33, 'Виберіть Так для підтвердження видалення групи'),
(124231, 5765, 33, 'Обраний'),
(124232, 5766, 33, 'Обране звернення'),
(124233, 5767, 33, 'Вибір цього пункту створить повідомлення, яке повинне бути опрацьоване кожним одержувачем індивідуально (це не групове завдання)'),
(124234, 5768, 33, 'Самостійно'),
(124235, 5769, 33, 'Сплатити самостійно'),
(124236, 5771, 33, 'Надіслати'),
(124237, 5772, 33, 'Надіслати застаріле нагадування'),
(124238, 5773, 33, 'Надіслати нагадування'),
(124239, 5774, 33, 'Надіслати на обробку'),
(124240, 5775, 33, 'Надіслати повідомлення'),
(124241, 5776, 33, 'Надіслати пакет нагадувань'),
(124242, 5777, 33, 'Надіслати нагадування пацієнтам щодо профілактики або подальшого лікування через вибір пацієнта.'),
(124243, 5778, 33, 'Надіслати підсумки за напрямами'),
(124244, 5779, 33, 'Надіслати цей файл'),
(124245, 5780, 33, 'Надіслати це повідомлення'),
(124246, 5781, 33, 'Надіслати до'),
(124247, 5784, 33, 'Надіслати усім'),
(124248, 5788, 33, 'Відправник'),
(124249, 5789, 33, 'ID відправника'),
(124250, 5790, 33, 'ID відправника (ISA06)'),
(124251, 5791, 33, 'Визначник ID відправника (ISA05)'),
(124252, 5792, 33, 'ID-и відправника'),
(124253, 5793, 33, 'Надсилання до'),
(124254, 5794, 33, 'Конфіденційність'),
(124255, 5795, 33, 'Конфіденційність:'),
(124256, 5796, 33, 'Дослідження чутливості в нормі'),
(124257, 5797, 33, 'Надіслано'),
(124258, 5799, 33, 'Надіслано (ким), залишити порожнім для всіх'),
(124259, 5801, 33, 'Дата відправки'),
(124260, 5802, 33, 'Надіслати елементи'),
(124261, 5803, 33, 'Надіслати медичні записи?'),
(124262, 5804, 33, 'Відправлено успішно'),
(124263, 5807, 33, 'відправлено на друк.'),
(124264, 5808, 33, 'Надіслано (кому), залишити порожнім для всіх'),
(124265, 5810, 33, 'Надіслано, але доставка ще не підтверджена.'),
(124266, 5811, 33, 'Надіслано, але не отримано'),
(124267, 5812, 33, 'Вер.'),
(124268, 5813, 33, 'Окремий'),
(124269, 5814, 33, 'Вересень'),
(124270, 5815, 33, 'Посл.'),
(124271, 5816, 33, 'Послідовність'),
(124272, 5818, 33, 'Звіт про послугу'),
(124273, 5821, 33, 'Послуга'),
(124274, 5822, 33, 'Категорія послуги'),
(124275, 5823, 33, 'Код послуги'),
(124276, 5824, 33, 'Код послуги фінансової звітності'),
(124277, 5825, 33, 'Коди послуги'),
(124278, 5826, 33, 'Дата послуги'),
(124279, 5827, 33, 'Дата послуги:'),
(124280, 5829, 33, 'Місце надання послуги'),
(124281, 5830, 33, 'Ім"я сервісу'),
(124282, 5831, 33, 'Послуги, що надаються спеціалістом'),
(124283, 5832, 33, 'Звітність по послугах'),
(124284, 5833, 33, 'Лише звітність по послугах'),
(124285, 5834, 33, 'Послуги'),
(124286, 5835, 33, 'Послуги по категоріях'),
(124287, 5836, 33, 'Надано допомогу'),
(124288, 5837, 33, 'Надано допомогу'),
(124289, 5838, 33, 'Послуги/Продукція'),
(124290, 5839, 33, 'Тип сесії'),
(124291, 5840, 33, 'Встановити'),
(124292, 5841, 33, 'Задати cookie медичного закладу для запам''ятовування обраного медичного закладу між входами в систему.'),
(124293, 5842, 33, 'Помітити як завершений'),
(124294, 5843, 33, 'Встановити пріоритет обробки звітів, що базуються на CDR-рушії'),
(124295, 5844, 33, 'Встановити пріоритет обробки для створення нагадувань для пацієнтів (у повному клінічному режимі)'),
(124296, 5845, 33, 'Задати повний шлях. Щоб створити клієнтський сертифікат SSL для HTTPS.'),
(124297, 5846, 33, 'Встановити в'),
(124298, 5847, 33, 'Встановити за замовчуванням'),
(124299, 5848, 33, 'Налаштування номера версії в базі даних ...'),
(124300, 5849, 33, 'Налаштування'),
(124301, 5851, 33, 'Сильна мігрень'),
(124302, 5853, 33, 'Ступінь болю'),
(124303, 5854, 33, 'Ступінь болю:'),
(124304, 5855, 33, 'Стать'),
(124305, 5856, 33, 'Захворювання, що передається статевим шляхом'),
(124306, 5857, 33, 'SFTP'),
(124307, 5858, 33, 'Хеш Sha-1'),
(124308, 5859, 33, 'Спільне використання'),
(124309, 5860, 33, 'Команда shell для друку з сервера.'),
(124310, 5863, 33, 'Короткий опис'),
(124311, 5864, 33, 'Утруднене дихання'),
(124312, 5865, 33, 'Утруднене дихання'),
(124313, 5866, 33, 'Утруднене дихання 2'),
(124314, 5867, 33, 'Короткий запис'),
(124315, 5868, 33, 'Короткий запис як:'),
(124316, 5870, 33, 'повинно бути подібно nnnnn-nnnn-nn'),
(124317, 5871, 33, 'Повинно бути у дві букви'),
(124318, 5872, 33, 'повинно містити 10 цифр'),
(124319, 5873, 33, 'повинно містити тільки 10 цифр'),
(124320, 5874, 33, 'Плече'),
(124321, 5875, 33, 'Плече + ключиця'),
(124322, 5876, 33, 'Проблеми плеча'),
(124323, 5877, 33, 'Показати'),
(124324, 5878, 33, 'Показати активні'),
(124325, 5880, 33, 'Показати все'),
(124326, 5881, 33, 'Показати всі процедури'),
(124327, 5883, 33, 'Показати всі транзакції'),
(124328, 5884, 33, 'Показувати як зайнятий'),
(124329, 5885, 33, 'Показати тільки дозволене'),
(124330, 5886, 33, 'Показати доступний час'),
(124331, 5887, 33, 'Показати і US, і метричні (основними є метричні одиниці)'),
(124332, 5888, 33, 'Показати і US, і метричні (основними є US одиниці)'),
(124333, 5889, 33, 'Показати деталі'),
(124334, 5890, 33, 'Показати лише помилки?'),
(124335, 5891, 33, 'Показати графік'),
(124336, 5892, 33, 'При наведенні мишки показувати спливаючий текст за подією?'),
(124337, 5893, 33, 'Показувати скільки подій на адміністративних сторінках?'),
(124338, 5894, 33, 'Показати неактивні'),
(124339, 5896, 33, 'Показати меню'),
(124340, 5897, 33, 'Показати тільки метричні'),
(124341, 5898, 33, 'Показати записи'),
(124342, 5900, 33, 'Показати лише процедури, що не приховані'),
(124343, 5901, 33, 'Показати записи по пацієнту'),
(124344, 5902, 33, 'Показувати фунти і унції'),
(124345, 5903, 33, 'Показувати фунти як десяткові дроби'),
(124346, 5904, 33, 'Показати основне завершення'),
(124347, 5905, 33, 'Показати нагадування'),
(124348, 5906, 33, 'Показати звіт'),
(124349, 5907, 33, 'Показувати в блоці посилання шукати/подати?'),
(124350, 5910, 33, 'Показати індивідуальну форму стану для віджету списку добавлення (буде запит на заголовок і скорочення).'),
(124351, 5911, 33, 'Показувати цю категорію у вікні з сумарною інформацією про пацієнта, навіть, якщо жодної проблеми по цій категорії не введено'),
(124352, 5913, 33, 'Показати тільки оплачені'),
(124353, 5914, 33, 'Показати тільки US'),
(124354, 5915, 33, 'Показ'),
(124355, 5916, 33, 'Показати результат'),
(124356, 5920, 33, 'Рідні брати/сестри'),
(124357, 5921, 33, 'Серповидна клітина'),
(124358, 5922, 33, 'Сиг'),
(124359, 5923, 33, 'Сигмо/колоноскопія'),
(124360, 5925, 33, 'Показати лабораторні результати (на вибір - право записувати/добавляти)'),
(124361, 5926, 33, 'Підписати результати'),
(124362, 5927, 33, 'Підпис'),
(124363, 5929, 33, 'Підпис:'),
(124364, 5930, 33, 'Підписано Rx'),
(124365, 5932, 33, 'Значна пухлина'),
(124366, 5933, 33, 'Спрощено'),
(124367, 5934, 33, 'Проста доплата'),
(124368, 5935, 33, 'Скорочені персональні дані'),
(124369, 5936, 33, 'Скорочені призначення'),
(124370, 5937, 33, 'з'),
(124371, 5938, 33, 'З повагою,'),
(124372, 5940, 33, 'Окремий'),
(124373, 5941, 33, 'Список вибору'),
(124374, 5942, 33, 'Список вибору з можливістю додавання пунктів'),
(124375, 5943, 33, 'Одиничний'),
(124376, 5946, 33, 'Проблеми пазух'),
(124377, 5947, 33, 'Хірургія пазух'),
(124378, 5948, 33, 'ЧУТЛИВІСТЬ ПАЗУХ:'),
(124379, 5949, 33, 'Синусит'),
(124380, 5950, 33, 'Сайт'),
(124381, 5951, 33, 'ID сайту'),
(124382, 5952, 33, 'ID сайту для сервісів Інтеграції медичної інформації, обміну даними лабораторних досліджень (LLC).'),
(124383, 5953, 33, 'ID сайту для підтримки LibreEHR служби обміну даними лабораторних досліджень LLC.'),
(124384, 5956, 33, 'Розмір'),
(124385, 5957, 33, 'Розмір повинен бути числом між 1 і 999'),
(124386, 5958, 33, 'Розмір/Список'),
(124387, 5959, 33, 'Шкіра'),
(124388, 5960, 33, 'Рак шкіри'),
(124389, 5961, 33, 'Шкірне захворювання'),
(124390, 5962, 33, 'Інші шкірні прояви'),
(124391, 5963, 33, 'Пропустити дозвіл для записів по пацієнтові'),
(124392, 5964, 33, 'Пропущений розділ'),
(124393, 5965, 33, 'Пропущений дамп регістра SQL - не застосовується для сервера Windows'),
(124394, 5967, 33, 'Паттерн сну'),
(124395, 5968, 33, 'Паттерн сну'),
(124396, 5969, 33, 'Сон'),
(124397, 5970, 33, 'Словацька'),
(124398, 5972, 33, 'См борг без'),
(124399, 5973, 33, 'Кеш Smarty очищений'),
(124400, 5974, 33, 'Курець, поточний статус невідомий'),
(124401, 5976, 33, 'Статус курця'),
(124402, 5977, 33, 'Дозв. SMS'),
(124403, 5978, 33, 'Шлюз SMS'),
(124404, 5979, 33, 'Ключ API для шлюзу SMS'),
(124405, 5980, 33, 'Ключ API для шлюзу SMS'),
(124406, 5981, 33, 'Пароль для шлюзу SMS'),
(124407, 5982, 33, 'Ім''я користувача для шлюзу SMS'),
(124408, 5983, 33, 'Повідомлення про SMS'),
(124409, 5984, 33, 'Години повідомлення про SMS'),
(124410, 5985, 33, 'Відправляти SMS перед'),
(124411, 5986, 33, 'SMS відправлено'),
(124412, 5987, 33, 'Текст SMS, вживаються теги: ***ІМ''Я***, ***СПЕЦІАЛІСТ***, ***ДАТА***, ***ЧАС ПОЧАТКУ***, ***ЧАС ЗАКІНЧЕННЯ*** <br> напр. Шановний ***ІМ''Я***'),
(124413, 5988, 33, 'Параметри настройки повідомлення SMS / e-mail'),
(124414, 5989, 33, 'Пароль SMTP для аутентифікації'),
(124415, 5992, 33, 'Ім''я вузла сервера SMTP'),
(124416, 5993, 33, 'Номер порту для сервера SMTP'),
(124417, 5994, 33, 'Користувач SMTP для аутентифікації'),
(124418, 5995, 33, 'SNOMED'),
(124419, 5996, 33, 'SNOMED (RF1) клінічний термін'),
(124420, 5997, 33, 'SNOMED (RF1) діагноз'),
(124421, 5998, 33, 'SNOMED (RF1) процедура'),
(124422, 5999, 33, 'SNOMED (RF2) діагноз'),
(124423, 6000, 33, 'SNOMED клінічний термін'),
(124424, 6001, 33, 'База даних SNOMED'),
(124425, 6002, 33, 'SNOMED діагноз'),
(124426, 6003, 33, 'SNOMED процедура'),
(124427, 6004, 33, 'Хропіння'),
(124428, 6005, 33, 'СООП'),
(124429, 6006, 33, 'Труднощі спілкування'),
(124430, 6009, 33, 'Соціальний анамнез:'),
(124431, 6010, 33, 'Ідентифікаційний номер платника податків'),
(124432, 6011, 33, 'розчин'),
(124433, 6013, 33, 'Соматичний стан'),
(124434, 6014, 33, 'Деякі дозволи не відображені. Натисніть тут для перегляду всіх.'),
(124435, 6015, 33, 'Деякі коди не відображаються.'),
(124436, 6016, 33, 'Деякі звернення не були відображені. Натисніть тут для перегляду всіх.'),
(124437, 6017, 33, 'Під час процесу де-ідентіфікаціі трапилася помилка'),
(124438, 6018, 33, 'Деякі записи не відображаються.'),
(124439, 6019, 33, 'Деякі офісні примітк не відображається. Клацніть тут, щоб переглянути всі.'),
(124440, 6020, 33, 'деякі слова'),
(124441, 6023, 33, 'Трапилась помилка. Спробуйте знову.'),
(124442, 6024, 33, 'Найкоротший інтервал очікування (клінічні нагадування)'),
(124443, 6025, 33, 'Найкоротший інтервал очікування (нагадування для пацієнта)'),
(124444, 6026, 33, 'Хворе горло'),
(124445, 6027, 33, 'Вибачне, призначень не зафіксовано'),
(124446, 6028, 33, 'На жаль, виникла проблема при оновленні вашого файлу'),
(124447, 6029, 33, 'Сортувати за'),
(124448, 6030, 33, 'Сортувати за'),
(124449, 6031, 33, 'Сортувати за контрольною сумою'),
(124450, 6032, 33, 'Сортувати за коментарями'),
(124451, 6033, 33, 'Сортувати за користувачами Crt'),
(124452, 6034, 33, 'Сортувати за датою'),
(124453, 6035, 33, 'Сортувати за датою/часом'),
(124454, 6036, 33, 'Сортувати за подією'),
(124455, 6037, 33, 'Сортувати за групою'),
(124456, 6040, 33, 'Сортувати за ID пацієнта'),
(124457, 6041, 33, 'Сортувати за виконанням'),
(124458, 6043, 33, 'Сортувати за користувачем'),
(124459, 6044, 33, 'Сортувати за вакциною'),
(124460, 6045, 33, 'Сортувати у спадному порядку'),
(124461, 6046, 33, 'Сортувати результат за'),
(124462, 6047, 33, 'Сортувати у висхідному порядку'),
(124463, 6048, 33, 'Джерело'),
(124464, 6049, 33, 'Вихідний файл'),
(124465, 6050, 33, 'Шлях вихідного файлу'),
(124466, 6051, 33, 'Відсутній код джерела '),
(124467, 6052, 33, 'Джерело партії'),
(124468, 6054, 33, 'Вихідний пацієнт'),
(124469, 6055, 33, 'Для вихідного пацієнта не вказано дату народження'),
(124470, 6056, 33, 'Вихідного пацієнта не знайдено'),
(124471, 6057, 33, 'Джерело:'),
(124472, 6060, 33, 'Простір'),
(124473, 6061, 33, 'ПРОСТІР'),
(124474, 6062, 33, 'Іспанська'),
(124475, 6063, 33, 'Іспанська (Латинська Америка)'),
(124476, 6064, 33, 'Іспанська (Іспанія)'),
(124477, 6066, 33, 'Спеціальні символи не дозволені'),
(124478, 6067, 33, 'Спеціальне лікування у форму життєво-важливих показників'),
(124479, 6068, 33, 'Спеціаліст'),
(124480, 6069, 33, 'Прізвище та підпис спеціаліста'),
(124481, 6071, 33, 'Спеціальність'),
(124482, 6072, 33, 'Спеціальні системи'),
(124483, 6073, 33, 'Спеціальність:'),
(124484, 6074, 33, 'Спеціальний'),
(124485, 6075, 33, 'Спеціальний додаток'),
(124486, 6076, 33, 'Спеціальна послуга по контрацепції'),
(124487, 6077, 33, 'Спеціальний результат'),
(124488, 6078, 33, 'Спеціальна послуга'),
(124489, 6079, 33, 'Конкретний'),
(124490, 6080, 33, 'Спеціальне форматування для кодів. # =цифра, * = будь-який символ. Якщо не використовується, то пусто.'),
(124491, 6081, 33, 'Спеціальне форматування для кодів. # = цифра, @ = альфа, * = будь-який символ. Якщо не використовується, то пусто.'),
(124492, 6082, 33, 'Спеціальне форматування для номерів рахунків із посилань. # = цифра, * = будь-який символ. Якщо не використовується, то пусто.'),
(124493, 6083, 33, 'Спеціальне форматування для номерів рахунків із посилання. # = цифра, @ = альфа, * = будь-який символ, Якщо не використовується, то пусто.'),
(124494, 6084, 33, 'Спеціальне форматування для полів послуги NDC. # = цифра, * = будь-який символ. Якщо не використовується, то пусто.'),
(124495, 6085, 33, 'Спеціальне форматування для полів послуги NDC. # = цифра, @ = альфа, * = будь-який символ. Якщо не використовується, то пусто.'),
(124496, 6086, 33, 'Спеціальне форматування для зовнішнього ID пацієнта. # = цифра, * = будь-який символ. Якщо не використовується, то пусто.'),
(124497, 6087, 33, 'Спеціальне форматування для зовнішнього ID пацієнта. # = цифра, @ = альфа, * = будь-який символ. Якщо не використовується, то пусто.'),
(124498, 6088, 33, 'Екземпляри'),
(124499, 6089, 33, 'Номер/ідентифікатор екземпляра'),
(124500, 6090, 33, 'Тип зразка'),
(124501, 6092, 33, 'Усне диктування'),
(124502, 6093, 33, 'Сперміциди'),
(124503, 6094, 33, 'Спленектомія'),
(124504, 6095, 33, 'Чоловік, дружина'),
(124505, 6097, 33, 'Мокрота'),
(124506, 6098, 33, 'Мокрота:'),
(124507, 6099, 33, 'SQ'),
(124508, 6102, 33, 'Відділення'),
(124509, 6103, 33, 'Склад відділення'),
(124510, 6104, 33, 'Відділення'),
(124511, 6105, 33, 'SRH'),
(124512, 6106, 33, 'SRH - планування сім''ї'),
(124513, 6107, 33, 'SRH без планування сім''ї'),
(124514, 6108, 33, 'Направлення для SRH'),
(124515, 6109, 33, 'Форма відвідування SRH'),
(124516, 6110, 33, 'Дата послуги'),
(124517, 6111, 33, 'Інд. податк. номер'),
(124518, 6112, 33, 'Управління сертифікатом SSL'),
(124519, 6113, 33, 'Інд. податк. номер'),
(124520, 6114, 33, 'Стійкість'),
(124521, 6115, 33, 'Етапний випуск'),
(124522, 6116, 33, 'Стандартний'),
(124523, 6117, 33, 'Стандартний код'),
(124524, 6118, 33, 'Стандартні одиниці виміру'),
(124525, 6119, 33, 'Стандартні одиниці виміру (активні нагадування)'),
(124526, 6120, 33, 'Стандартні одиниці виміру (пасивні нагадування)'),
(124527, 6121, 33, 'Стандартні одиниці виміру (нагадування про пацієнта)'),
(124528, 6122, 33, 'Стандартне найменування'),
(124529, 6123, 33, 'Стандартний, Спрощений: лише назва, дата початку, коментарі і позначка "Активність", немає діагнозу, прояви, дата закінчення,направлений або спортивні майданчики. ; Футбольна травма'),
(124530, 6124, 33, 'Початок'),
(124531, 6125, 33, 'Початок (рррр-мм-дд): '),
(124532, 6126, 33, 'Розпочати інший звіт'),
(124533, 6128, 33, 'Дата початку'),
(124534, 6129, 33, 'Дата первісного звернення в цю клініку'),
(124535, 6130, 33, 'Дата початку не повинна бути пізніше дати закінчення'),
(124536, 6131, 33, 'Початкова дата:'),
(124537, 6132, 33, 'Початкова дата:'),
(124538, 6133, 33, 'Початковий час'),
(124539, 6134, 33, 'Початкова дата'),
(124540, 6135, 33, 'стат.'),
(124541, 6136, 33, 'Область'),
(124542, 6137, 33, 'Тип даних для області'),
(124543, 6138, 33, 'Державна ліц. #'),
(124544, 6139, 33, 'Державний номер ліцензії'),
(124545, 6140, 33, 'Список областей'),
(124546, 6141, 33, 'Список областей (на вибір - право записувати/добавляти)'),
(124547, 6142, 33, 'Користувацікі поля віджета списку областей'),
(124548, 6143, 33, 'Область або провінція'),
(124549, 6144, 33, 'Область/розташування'),
(124550, 6145, 33, 'Область/район'),
(124551, 6146, 33, 'ПІДСУМКОВА ЗАЯВКА'),
(124552, 6147, 33, 'заявки та оновлені рахунки.'),
(124553, 6148, 33, 'Відправлені заявки:'),
(124554, 6149, 33, 'заявки; рахунки не будуть оновлені.'),
(124555, 6150, 33, 'Статичний текст'),
(124556, 6151, 33, 'Статистичні дані'),
(124557, 6152, 33, 'Стат.'),
(124558, 6153, 33, 'Статус'),
(124559, 6154, 33, 'Статус прийому'),
(124560, 6155, 33, 'Стан вимоги'),
(124561, 6156, 33, 'Статус кво'),
(124562, 6158, 33, 'Конс. ЗПСШ/СНІД'),
(124563, 6159, 33, 'Сила і Фізична форма'),
(124564, 6164, 33, 'Кроки для встановлення DSM IV бази даних'),
(124565, 6165, 33, 'Кроки для встановлення ICD 10 бази даних'),
(124566, 6166, 33, 'Кроки для встановлення ICD 9 бази даних'),
(124567, 6167, 33, 'Кроки для встановлення RxNorm бази даних'),
(124568, 6168, 33, 'Кроки для встановлення Snomed бази даних'),
(124569, 6169, 33, 'Нерухомість суглобів'),
(124570, 6170, 33, 'Нерухомість'),
(124571, 6171, 33, 'Стандартні місяці'),
(124572, 6172, 33, 'Болі у шлунку'),
(124573, 6174, 33, 'Збережений хеш'),
(124574, 6175, 33, 'Розтягування м''язи'),
(124575, 6176, 33, 'Розбризкування'),
(124576, 6177, 33, 'Вулиця'),
(124577, 6178, 33, 'Адреса вулиці'),
(124578, 6179, 33, 'Вулиця і номер'),
(124579, 6180, 33, 'Сила'),
(124580, 6182, 33, 'Гострий фарингіт'),
(124581, 6183, 33, 'Стресовий перелом'),
(124582, 6184, 33, 'Навантажувальна проба'),
(124583, 6185, 33, 'Інсульт'),
(124584, 6186, 33, 'Надійний пароль має принаймні 8 символів і одночасно три з наступних умов: число, буква в нижньому регістрі, буква у верхньому регістрі, спеціальний символ.'),
(124585, 6187, 33, 'Стиль'),
(124586, 6188, 33, 'Для додавання нового пацієнта використовується стиль форми'),
(124587, 6189, 33, 'Підкатегорія'),
(124588, 6190, 33, 'Проміжний підсумок'),
(124589, 6191, 33, 'Підкатегорія'),
(124590, 6192, 33, 'підкатегорія'),
(124591, 6193, 33, 'підшкірно'),
(124592, 6194, 33, 'Суб''єкт'),
(124593, 6195, 33, 'Суб''єктивно'),
(124594, 6196, 33, 'Підязиковий'),
(124595, 6197, 33, 'підязиковий'),
(124596, 6198, 33, 'Підтвердити'),
(124597, 6199, 33, 'підтвердити'),
(124598, 6200, 33, 'Подати весь зміст'),
(124599, 6202, 33, 'Подати подію'),
(124600, 6203, 33, 'податии форму'),
(124601, 6204, 33, 'Подати вибраний зміст'),
(124602, 6205, 33, 'подане'),
(124603, 6206, 33, 'Подане (ким)'),
(124604, 6207, 33, 'Подати номер доступу EDI (PER06)'),
(124605, 6208, 33, 'Підписувач'),
(124606, 6209, 33, 'Адреса підписувача'),
(124607, 6213, 33, 'Місце роботи підписувача'),
(124608, 6214, 33, 'Роботодавець підписувача (SE)'),
(124609, 6215, 33, 'Адреса місця роботи підписувача'),
(124610, 6216, 33, 'Місто роботодавця підписувача'),
(124611, 6217, 33, 'Країна роботодавця підписувача'),
(124612, 6218, 33, 'Область місця роботи підписувача'),
(124613, 6221, 33, 'Поштовий індекс роботодавця підписувача'),
(124614, 6225, 33, 'Телефон підписувача'),
(124615, 6226, 33, 'Звязки підписувача'),
(124616, 6227, 33, 'Родинні звязки підписувача різні, але імя те ж! Це вірно?'),
(124617, 6228, 33, 'Родинні звязки підписувача різні, але номер SS (соц.страх.) той же!'),
(124618, 6229, 33, 'Родинні звязки підписувача одні, але імя інше! Це вірно?'),
(124619, 6230, 33, 'Родинні звязки підписувача одні, але номер SS (соц.страх.) інший!'),
(124620, 6231, 33, 'Стать підписувача'),
(124621, 6237, 33, 'Заміна'),
(124622, 6238, 33, 'заміна дозволена'),
(124623, 6240, 33, 'Успішно'),
(124624, 6241, 33, 'успішно'),
(124625, 6242, 33, 'Підтвердження успішного отримання лабораторного результату'),
(124626, 6243, 33, 'Успішне отримання лабораторних результатів'),
(124627, 6244, 33, 'Успішне отримання лабораторних результатів з Lab Exchange Network'),
(124628, 6246, 33, 'Категорія успішно додана'),
(124629, 6247, 33, 'Категорія успішно додана,'),
(124630, 6248, 33, 'Видалено успішно'),
(124631, 6250, 33, 'База даних успішно встановлена.'),
(124632, 6251, 33, 'Успішно встановлена наступна база даних'),
(124633, 6252, 33, 'Змінено успішно'),
(124634, 6253, 33, 'Збережено успішно. Хочете внести?'),
(124635, 6254, 33, 'Збережено успішно. Хочете надати?'),
(124636, 6256, 33, 'збережено успішно.'),
(124637, 6257, 33, 'База даних успішно оновлена.'),
(124638, 6258, 33, 'іспішно оновлена наступна база даних'),
(124639, 6259, 33, 'успішно.'),
(124640, 6260, 33, 'Суїцид'),
(124641, 6261, 33, 'Підсумок'),
(124642, 6262, 33, 'Підсумок по'),
(124643, 6265, 33, 'Нед.'),
(124644, 6267, 33, 'Неділя'),
(124645, 6268, 33, 'Superbill (суперрахунок)'),
(124646, 6269, 33, 'Коди Superbill'),
(124647, 6270, 33, 'Управління кодами Superbill'),
(124648, 6271, 33, 'Звіт Superbill'),
(124649, 6272, 33, 'Superbill / Бланк оплати'),
(124650, 6273, 33, 'Superbill'),
(124651, 6274, 33, 'Superbills, також відомі як форми звернень або бланки направлень, є невід''ємною частиною більшості випадків лікарської практики.'),
(124652, 6275, 33, 'Суперкористувач'),
(124653, 6276, 33, 'Керівник/відповідальний'),
(124654, 6278, 33, 'Відповідальний лікар DEA'),
(124655, 6279, 33, 'Ім''я відповідального лікаря'),
(124656, 6280, 33, 'Прізвище відповідального лікаря'),
(124657, 6281, 33, 'NPI відповідального лікаря'),
(124658, 6282, 33, 'UPIN відповідального лікаря'),
(124659, 6283, 33, 'Найменування медзакладу-постачальника послуги'),
(124660, 6284, 33, 'Підтримує календарні події, які одночасно призначаються кільком спеціалістам'),
(124661, 6285, 33, 'Підтримує експорт/імпорт конфігураційних даних через сторінку резервного копіювання.'),
(124662, 6286, 33, 'Підтримує події багатьох провайдерів'),
(124663, 6288, 33, 'Підтримує тільки TripleDES шифрування/дешифрування'),
(124664, 6289, 33, 'Тип поверхні'),
(124665, 6290, 33, 'Операції'),
(124666, 6291, 33, 'Операція'),
(124667, 6292, 33, 'Перелік проблем хірургічних втручань'),
(124668, 6293, 33, 'Підтримувані'),
(124669, 6294, 33, 'суспензія'),
(124670, 6295, 33, 'Дата Svc'),
(124671, 6296, 33, 'Дата Svc:'),
(124672, 6299, 33, 'Пітливість:'),
(124673, 6300, 33, 'Шведська'),
(124674, 6301, 33, 'Набряк'),
(124675, 6302, 33, 'Набряк справа'),
(124676, 6303, 33, 'Набряки на суглобах'),
(124677, 6304, 33, 'Збільшені лімфовузли'),
(124678, 6305, 33, 'Символ, що використовується як десяткова кома для валют. Не використовуйте, якщо десяткових знаків 0).'),
(124679, 6306, 33, 'Символ, що використовується для відділення тисяч для валют.'),
(124680, 6307, 33, 'Симптоми'),
(124681, 6308, 33, 'Синхронізувати'),
(124682, 6309, 33, 'Синхронізувати переклади з індивідуальною мовною таблицею.'),
(124683, 6310, 33, 'Нова індивідуальна синхронізована константа:'),
(124684, 6311, 33, 'Нова користувальницька синхронізована мова:'),
(124685, 6312, 33, 'Нове синхронізоване визначення (мова, константа, визначення):'),
(124686, 6313, 33, 'Непритомність'),
(124687, 6314, 33, 'Посиндромне дослідження'),
(124688, 6315, 33, 'Посиндромне дослідження - неповідомлені аспекти'),
(124689, 6316, 33, 'Звіт про посиндромне дослідження'),
(124690, 6317, 33, 'Синовіїт, тендовагініт, бурсит'),
(124691, 6318, 33, 'Система'),
(124692, 6322, 33, 'T'),
(124693, 6323, 33, 'тричі на день'),
(124694, 6324, 33, 'T.V.'),
(124695, 6325, 33, 'Таблиця'),
(124696, 6327, 33, 'Створення таблиці дало збій'),
(124697, 6328, 33, 'Оновлення таблиці дало збій'),
(124698, 6330, 33, 'таблетка'),
(124699, 6332, 33, 'Тагальська'),
(124700, 6335, 33, 'Прийом'),
(124701, 6336, 33, 'Виберіть страховку із спадаючого списку'),
(124702, 6337, 33, 'Виберіть оплату із спадаючого списку'),
(124703, 6338, 33, 'Повернення'),
(124704, 6339, 33, 'Займає час'),
(124705, 6340, 33, 'Максимальна область навігації'),
(124706, 6344, 33, 'Цільова і вихідна дата народження не співпадають'),
(124707, 6345, 33, 'Цільовий і вихідний PID не можуть бути однаковими!'),
(124708, 6346, 33, 'Цільовий і вихідний SSN не співпадають'),
(124709, 6347, 33, 'Цільова дата'),
(124710, 6348, 33, 'Намічений пацієнт'),
(124711, 6349, 33, 'Для наміченого пацієнта не вказано дату народження'),
(124712, 6350, 33, 'Нміченого пацієнта не знайдено'),
(124713, 6351, 33, 'Цільові/Дієві групи'),
(124714, 6354, 33, 'ID податку'),
(124715, 6355, 33, 'Ставка оподаткування'),
(124716, 6356, 33, 'Податки'),
(124717, 6357, 33, 'Систематизація'),
(124718, 6358, 33, 'Td'),
(124719, 6359, 33, 'Огляд травматологічної бригади'),
(124720, 6360, 33, 'Склад бригади'),
(124721, 6361, 33, 'Перегляд складу бригади'),
(124722, 6362, 33, 'Бригада/відділення'),
(124723, 6363, 33, 'Тел.'),
(124724, 6364, 33, 'Телефонний код країни'),
(124725, 6366, 33, 'Темп'),
(124726, 6367, 33, 'Місце вимірювання температури'),
(124727, 6368, 33, 'Метод вимірювання температури'),
(124728, 6369, 33, 'Температура'),
(124729, 6370, 33, 'Шаблон'),
(124730, 6371, 33, 'Ім''я шаблону'),
(124731, 6372, 33, 'Імена шаблонів не повинні починатися з цифр.'),
(124732, 6373, 33, 'Шаблон:'),
(124733, 6374, 33, 'Шаблони'),
(124734, 6375, 33, 'Скронева артерія'),
(124735, 6376, 33, 'Травма сухожилля'),
(124736, 6377, 33, 'Тенденіт / остеомієліт / бурсит'),
(124737, 6378, 33, 'Попередній рахунок для номера'),
(124738, 6379, 33, 'Третя'),
(124739, 6380, 33, 'Спеціалізована страховка'),
(124740, 6381, 33, 'Дата спеціального страхування'),
(124741, 6382, 33, 'Постачальник спеціального страхування'),
(124742, 6383, 33, 'План обстеження'),
(124743, 6384, 33, 'Принципи обстеження'),
(124744, 6385, 33, 'Текст'),
(124745, 6386, 33, 'Описовий діагноз'),
(124746, 6387, 33, 'Поле з текстом'),
(124747, 6393, 33, 'Текст-дата'),
(124748, 6394, 33, 'текст-дата'),
(124749, 6395, 33, 'Текстова область'),
(124750, 6396, 33, 'текстова область'),
(124751, 6397, 33, 'Текстове поле'),
(124752, 6398, 33, 'текстове поле'),
(124753, 6399, 33, 'Список текстових полів'),
(124754, 6400, 33, 'список текстових полів'),
(124755, 6401, 33, 'Тайський'),
(124756, 6402, 33, 'Дякуємо'),
(124757, 6403, 33, 'Дякуємо за Ваш вибір'),
(124758, 6404, 33, 'Кнопка ''Очистити'' видалить всі анотації.'),
(124759, 6405, 33, 'Вказана вище заявка дала збій'),
(124760, 6406, 33, 'Сертифікат SSL сервера Apache і загальнодоступний ключ'),
(124761, 6407, 33, 'Довірений сертифікат Certificate'),
(124762, 6408, 33, 'Необхідний файл: '),
(124763, 6409, 33, 'Сумісний актуальний пакет розширення SNOMED для США вже встановлений.'),
(124764, 6410, 33, 'Відповідний особистий ключ'),
(124765, 6413, 33, 'ось код відмови'),
(124766, 6414, 33, 'ось код групи відмови'),
(124767, 6415, 33, 'Форма місця призначення була закрита'),
(124768, 6416, 33, 'Форма місця призначення була закрита, не вдалося активувати ваш вибір.'),
(124769, 6417, 33, 'Об''єкт, що виконує цю процедуру'),
(124770, 6418, 33, 'Звернення в EP, уповноважену лікарню або CAH, які отримують пацієнта з інших місць лікування або інших фахівців, або повинна виконувати подальше лікування.'),
(124771, 6421, 33, 'Уповноважені фахівці, лікарні або центри здороя, які переводять своїх пацієнтів для медичної допомоги в установи з іншим управлінням або фахівцями, або направляють своїх пацієнтів до іншого медичного фахівця, повинні надати медичну виписку для кожного переведення або направлення.'),
(124772, 6422, 33, 'Ця подія (ї) була прийнята.'),
(124773, 6423, 33, 'Ця подія (ї) приховані.'),
(124774, 6424, 33, 'Дані експорту подані в текстовій області нижче. Можете скопіювати і вставити в email чи будь-яке інше необхідне місце призначення.'),
(124775, 6426, 33, 'Дані експорту подані в текстовій області нижче. Можете скопіювати і вставити в email чи будь-яке інше необхідне місце призначення.'),
(124776, 6427, 33, 'Дані експорту подані в текстовій області нижче. Можете скопіювати і вставити їх в email чи будь-яке інше необхідне місце призначення.'),
(124777, 6428, 33, 'Файл не може бути збережений у CouchDB.'),
(124778, 6429, 33, 'Цей файл не вдалося перейменувати, ця помилка зазвичай пов''язана з проблемами прав доступу в систему зберігання.'),
(124779, 6430, 33, 'Файл не може бути успішно збережений. Ця помилка звачайно стосується проблем з правими доступу до системи сховища (накопичувача)'),
(124780, 6431, 33, 'Першим ("цільовим") записом є той, який вважається найбільш повним та точним. Дані демографічного, історичного та страхового розділів для нього будуть збережені.'),
(124781, 6433, 33, 'перший крок - відкрити обліковий запис на веб-сайті системи Уніфікованої Медичної Мови (UMLS)'),
(124782, 6434, 33, 'Наступні календарні події були додані:'),
(124783, 6435, 33, 'Наступні календарні події були змінені:'),
(124784, 6436, 33, 'Наступні категорії будуть видалені з вашого списку категорій'),
(124785, 6437, 33, 'В даний час встановлена ​​наступна версія бази даних.'),
(124786, 6438, 33, 'Наступні документи були прикріплені до цього Direct-повідомлення:'),
(124787, 6439, 33, 'Наступний файл EDI був оновлений'),
(124788, 6440, 33, 'Активований наступний користувач термінового входу в систему:'),
(124789, 6441, 33, 'Сталася наступна помилка'),
(124790, 6444, 33, 'Наступні поля є обов''язковими'),
(124791, 6446, 33, 'Для відправки запиту повинні бути заповнені такі поля.'),
(124792, 6447, 33, 'Підтримуються наступні міжнародні мовні випуски SNOMED'),
(124793, 6448, 33, 'Наступні проблеми мають ті ж коди діагнозу. Проблеми по звертанню не будуть оновлюватися. Будь ласка, скористайтеся інтерфейсом звертання.'),
(124794, 6449, 33, 'Ім''я вузла на архівному комп''ютері для аудиту ATNA'),
(124795, 6450, 33, 'Початкове вікно є сторінкою пошуку рахунку. Вгорі ви можете ввести джерело (наприклад, номер чека), дату оплати та суму чека. Причина для вводу джерела і дати оплати полягає у тому, що вам не доведеться вводити їх багато разів для кожної вимоги. Кількість, яку ви вводитимете, буде збільшуватися при кожному рахунку, який буде частиною платні, і врешті становитиме нуль, коли оплата буде завершена.'),
(124796, 6451, 33, 'Каталог встановлення повинен бути створений.'),
(124797, 6452, 33, 'Встановлена міжнародна версія SNOMED не сумісна з актуальним пакетом розширення SNOMED для США.'),
(124798, 6453, 33, 'Встановлена міжнародна версія SNOMED є застарілою і не сумісна з актуальним пакетом розширення SNOMED для США.'),
(124799, 6454, 33, 'Встановлена версія і встановлювані файли ідентичні.'),
(124800, 6455, 33, 'Встановлена версія є новішою ніж встановлювані файли.'),
(124801, 6456, 33, 'Мітка, яка з''являється для цього користувача у формі'),
(124802, 6457, 33, 'Довжина не повинна перевищувати наступної кількості символів'),
(124803, 6458, 33, 'Об"єднання не може бути запущено, оскільки SSN та дата народження для двох записів ідентичні. Дана народження не може бути порожньою.'),
(124804, 6459, 33, 'Повідомлення в даний час не може бути надіслане.'),
(124805, 6460, 33, 'Нова категорія буде підкатегорією для '),
(124806, 6461, 33, 'Новий пароль не може бути таким же, як поточний.'),
(124807, 6462, 33, 'Поля нового пароля відрізняються.'),
(124808, 6463, 33, 'Кількість актуальних файлів невірна. Помістіть лише файл, який ви хочете встановити / оновити.'),
(124809, 6464, 33, 'Некоректна кількість оброблюваних файлів. Розмістіть лише файли, які Ви бажаєте встановити/оновити.'),
(124810, 6465, 33, 'Ця сторінка буде перенаправлена на Персональні дані. Ви можете відредагувати поле із країною та повернутися на NewCrop знову.'),
(124811, 6466, 33, 'Пароль повинен бути довжиною не менше вісім символів і повинен'),
(124812, 6468, 33, 'Запит на запис для пацієнта був виконаний.'),
(124813, 6469, 33, 'Нагадування пацієнтові відправлені'),
(124814, 6470, 33, 'Нагадування пацієнтові оновлені'),
(124815, 6472, 33, 'Введені платежі не можуть бути пізніше цієї дати. Це означає, що після здійснення завершального звіту ніхто не введе попередню дату.'),
(124816, 6474, 33, 'Надані необроблені дані можуть бути отримані з'),
(124817, 6475, 33, 'Відомості, наведені нижче, застосовуються, тільки якщо ви вручну публікуєте або виправляєте.'),
(124818, 6477, 33, 'Запитаний документ відсутній в очікуваному місці файлової системи або немає достатніх прав доступу до нього.'),
(124819, 6479, 33, 'Дані демографічного, історичного та страхового розділів другого ("вхідного") запису будуть видалені. Інші дані будуть об"єднані з цільовим записом.'),
(124820, 6480, 33, 'Стовпці Джерело і Дата копіюються з першої сторінки, так що, зазвичай, їх не потрібно чіпати. Можете помістити суму платежу в стовпці Оплата, скориговану суму в стовпці Змінити (або обидві). Можна також натиснути на «W» справа для автоматичного застосування вартості, що списує залишок ціни для цієї позиції.'),
(124821, 6481, 33, 'Не всі дати підставлених файлів від однакового випуску.'),
(124822, 6482, 33, 'Не всі редакції підставлених файлів від однакового випуску.'),
(124823, 6484, 33, 'Тимчасова деталізація календаря і найменший інтервал у хвилинах для вставки запису на прийом.'),
(124824, 6485, 33, 'Перекладена мітка, яка виводиться у формі на поточній мові'),
(124825, 6486, 33, 'Перекладений заголовок, який буде виводиться на поточній мові'),
(124826, 6487, 33, 'Переклад опису на поточну мову'),
(124827, 6488, 33, 'Таблиці перекладів синхронізовані.'),
(124828, 6489, 33, 'Тип цього об''єкта'),
(124829, 6490, 33, 'Код виробника, що ідентифікує цю процедуру або результат'),
(124830, 6491, 33, 'Файли X12, а також отримані звіти виводу HTML, архівуються в підкаталозі "era" основної директорії інсталяції LibreEHR. Слід звертатися час від часу до цих архівів. URL-адреса'),
(124831, 6492, 33, 'Файл zip буде містити наступні пункти'),
(124832, 6493, 33, 'Тема'),
(124833, 6494, 33, 'Тоді надані необроблені дані можуть бути отримані з'),
(124834, 6495, 33, 'Терапевтичні ін''єкції'),
(124835, 6496, 33, 'Є'),
(124836, 6497, 33, 'В даний час немає призначень'),
(124837, 6498, 33, 'Є помилки з вашим поданням. Вони показані нижче.'),
(124838, 6500, 33, 'Виписаних карт немає.'),
(124839, 6501, 33, 'Для цього пацієнта публікацій не зареєстровано.');
INSERT INTO `lang_definitions` VALUES
(124840, 6502, 33, 'Нових заявок немає'),
(124841, 6503, 33, 'Для цього пацієнта немає записів у файл.'),
(124842, 6504, 33, 'Для цього пацієнта немає транзакцій в файл.'),
(124843, 6505, 33, 'Виникла помилка відправки пошти'),
(124844, 6506, 33, 'Категорія вже поіменована'),
(124845, 6507, 33, 'Підкатегорія вже поіменована'),
(124846, 6508, 33, 'Елемент вже поіменований'),
(124847, 6509, 33, 'Запит на запис для пацієнта вже відкритий.'),
(124848, 6510, 33, 'Немає введених COA для аккаунта AR '),
(124849, 6511, 33, 'Немає введених COA для аккаунта кешу '),
(124850, 6512, 33, 'Немає введених COA для вхідного аккаунта '),
(124851, 6513, 33, 'Немає жодного поточного пацієнта'),
(124852, 6515, 33, 'Немає відповідності для рахунку з id'),
(124853, 6516, 33, 'Немає відповідності для рахунку з id = '),
(124854, 6517, 33, 'Немає введення частини для ID послуг '),
(124855, 6519, 33, 'Були проблеми з відправкою повідомлення.'),
(124856, 6520, 33, 'При обробці вашого запиту виникла помилка.'),
(124857, 6521, 33, 'В наступному рядку є помилка LibreEHR SQL'),
(124858, 6522, 33, 'Є 2012 посилань'),
(124859, 6523, 33, 'Ущільнення справа'),
(124860, 6524, 33, 'Стегно'),
(124861, 6525, 33, 'Стегно і підколінна ямка'),
(124862, 6526, 33, 'Об''єкти, які відділ документації (канцелярія) може лише читати'),
(124863, 6527, 33, 'Об''єкти, які відділ документації (канцелярія) може читати і вводити, але не може змінювати'),
(124864, 6528, 33, 'Об''єкти, які відділ документації (канцелярія) може читати і змінювати'),
(124865, 6529, 33, 'Об''єкти, які відділ документації (канцелярія) може читати і частково змінювати'),
(124866, 6530, 33, 'Об''єкти, які клініцисти можуть лише читати'),
(124867, 6531, 33, 'Об''єкти, які клініцисти можуть читати і вводити, але не можуть змінювати'),
(124868, 6532, 33, 'Об''єкти, які клініцисти можуть читати і змінювати'),
(124869, 6533, 33, 'Об''єкти, які клініцисти можуть читати і частково змінювати'),
(124870, 6534, 33, 'Об''єкти, які реєстратура може лише читати'),
(124871, 6535, 33, 'Об''єкти, які реєстратура може читати і вводити, але не може змінювати'),
(124872, 6536, 33, 'Об''єкти, які реєстратура може читати і змінювати'),
(124873, 6537, 33, 'Об''єкти, які реєстратура може читати і частково змінювати'),
(124874, 6538, 33, 'Об''єкти, які лікарі можуть лише читати'),
(124875, 6539, 33, 'Об''єкти, які лікарі можуть читати і вводити, але не можуть змінювати'),
(124876, 6540, 33, 'Об''єкти, які лікарі можуть читати і змінювати'),
(124877, 6541, 33, 'Об''єкти, які лікарі можуть читати і частково змінювати'),
(124878, 6542, 33, 'Третій'),
(124879, 6544, 33, 'Ця дія НЕ МОЖЕ БУТИ скасованою.'),
(124880, 6545, 33, 'Ця дія не може бути скасованою.'),
(124881, 6547, 33, 'Цю дію буде зареєстровано'),
(124882, 6549, 33, 'Цей інтервал прийому вже використовується, вибрати його незважаючи на це?'),
(124883, 6550, 33, 'Вказаний інтервал запису на прийом не існує, виберіть інший.'),
(124884, 6551, 33, 'Цей календарний рік'),
(124885, 6552, 33, 'Цю вимогу було скасовано.'),
(124886, 6553, 33, 'Ця вимога була закрита.'),
(124887, 6554, 33, 'Ця вимога була знехтувана. Причина:-'),
(124888, 6555, 33, 'Цю вимогу було надіслано на наступний рівень.'),
(124889, 6556, 33, 'Цей тип коду не приймає залежності.'),
(124890, 6557, 33, 'Цей контекст містить категорії, які будуть видалені. Все ще потрібно продовжити?'),
(124891, 6558, 33, 'Це визначає, як записи на прийом відображаються в календарі.'),
(124892, 6559, 33, 'Це визначає, яка схема кольорів використовується для запису на прийом'),
(124893, 6561, 33, 'Це звернення'),
(124894, 6562, 33, 'Для цього зверненню було здійснено нарахування. Якщо Ви бажаєте внести змінити, відчиніть його повторно.'),
(124895, 6564, 33, 'Ця опція відсутня'),
(124896, 6565, 33, 'Цей компонент є експериментальним і тестований не повністю. Використовуйте його на свій власний ризик!'),
(124897, 6566, 33, 'Цей номер рахунку було змінено на '),
(124898, 6569, 33, 'Це запис, який буде об''єднано з основним записом, а потім видалено.'),
(124899, 6571, 33, 'Це основний запис, який отримає об''єднані дані.'),
(124900, 6572, 33, 'це розміщення'),
(124901, 6575, 33, 'Цей модуль працює в тестовому режимі. База даних не буде змінена.'),
(124902, 6576, 33, 'Цей модуль підтримує ефективне введення даних EOB.'),
(124903, 6577, 33, 'Це місяць до дати'),
(124904, 6579, 33, 'Ця сторінка дозволяє Вам переглянути кожен з підтримуваних зовнішніх сховищ даних що Ви їх можете встановити чи оновити. Кожну секцію можна розгорнути, клацнувши на її заголовку, щоб переглянути статус відповідної бази даних.'),
(124905, 6580, 33, 'Ця сторінка відключена з міркувань безпеки.'),
(124906, 6581, 33, 'Ця сторінка буде включати вбудований вхід в систему, щоб не робити це кожного разу.'),
(124907, 6582, 33, 'Цей пацієнт не активний.'),
(124908, 6583, 33, 'Цей ID пацієнта вже використовуєтьсяі!'),
(124909, 6584, 33, 'Цей продукт допускає тільки одну партію на складі'),
(124910, 6585, 33, 'Цей протокол не реалізований'),
(124911, 6586, 33, 'Цей звіт зараз працює лише для ICD9 кодів.'),
(124912, 6591, 33, 'На цьому кроці буде створений файл, який потрібно зберегти для подальшого використання. Цей файл не може бути створений повторно.Чи бажаєте продовжити?'),
(124913, 6592, 33, 'Цей користувач не є членом жодної групи'),
(124914, 6593, 33, 'Цей користувач буде отримувати повідомлення про нові вхідні Direct-повідомлення'),
(124915, 6594, 33, 'Ця утиліта є експериментальною. Зробіть резервну копію бази даних і документів перед її використанням!'),
(124916, 6595, 33, 'Це відвідування починає застосування нової контрацепції'),
(124917, 6596, 33, 'Для цього візиту необхідна форма GCAC, надання направлення або процедури.'),
(124918, 6597, 33, 'Це старий варіант виключно метричної форми життєво важливих показників, в даний час застаріла.'),
(124919, 6598, 33, 'Цей тиждень до дати'),
(124920, 6600, 33, 'Це активує повідомлення CCR (безперервність медичного запису) і CCD (безперервність медичного документу).'),
(124921, 6602, 33, 'Це дозволяє вибір налагоджувальної мови (''підставної'').'),
(124922, 6605, 33, 'Це буде "сухий запуск" без фізичного оновлення даних.'),
(124923, 6606, 33, 'Це дозволяє створити резервну копію у форматі tar і потім надіслати на ваш веб-браузер, таким чином що ви зможете її зберегти'),
(124924, 6607, 33, 'Функція шифрування і дешифрування документа буде дезактивована і захована в UI.'),
(124925, 6613, 33, 'Завдяки цьому Віджет Рахунків буде завжди відкритим у вікні "Сумарно по пацієнту".'),
(124926, 6616, 33, 'Це дозволить об''єднати два записи про пацієнта в один. Це корисно, коли запис про пацієнта був помилково продубльований. Якщо це відбувається часто, слід внести зміни в порядок діловодства. Дана функція є не для регулярного використання!'),
(124927, 6617, 33, 'Це не завадить вашому переходу на сайт е-призначень.'),
(124928, 6619, 33, 'Користувацький список вакцинацій, а не стандартний список вакцинацій CVX буде використаний.'),
(124929, 6622, 33, 'Грудний відділ хребта'),
(124930, 6623, 33, 'Тис./куб.мм'),
(124931, 6625, 33, 'Гортань'),
(124932, 6626, 33, 'Рак гортані'),
(124933, 6627, 33, 'Хірургія раку гортані'),
(124934, 6628, 33, 'Тромбоз/інсульт'),
(124935, 6629, 33, 'Чт.'),
(124936, 6630, 33, 'Четвер'),
(124937, 6631, 33, 'Четвер'),
(124938, 6632, 33, 'Щитовидна залоза в нормі'),
(124939, 6633, 33, 'Проблеми щитовидної залози'),
(124940, 6634, 33, 'TIA'),
(124941, 6636, 33, 'TID'),
(124942, 6638, 33, 'Час'),
(124943, 6639, 33, 'Формат відображення часу'),
(124944, 6640, 33, 'Величина часу для додавання (1-60 хвилин)'),
(124945, 6641, 33, 'Вибір часу'),
(124946, 6642, 33, 'Цей інтервал відкритий, зберігайте подію'),
(124947, 6647, 33, 'Одночасна подія'),
(124948, 6648, 33, 'Набір часів (N/A)'),
(124949, 6649, 33, 'Часова мітка і текст'),
(124950, 6650, 33, 'TIN'),
(124951, 6651, 33, 'шум у вухах'),
(124952, 6652, 33, 'Назва'),
(124953, 6653, 33, 'Назва V'),
(124954, 6654, 33, 'Стовпці назви повинні бути чилом між 1 і 999'),
(124955, 6655, 33, 'Назви'),
(124956, 6656, 33, 'TM''S:'),
(124957, 6657, 33, 'Зовнішній ніс, TMs/EAMs/EE'),
(124958, 6658, 33, 'по'),
(124959, 6659, 33, 'ДО'),
(124960, 6660, 33, 'до'),
(124961, 6661, 33, 'в абсолютному шляху файлу'),
(124962, 6662, 33, 'Натисніть для додавання записів '),
(124963, 6663, 33, 'натисніть тут для додавання записів'),
(124964, 6664, 33, 'На уражену область'),
(124965, 6665, 33, 'на уражену область'),
(124966, 6666, 33, 'Для автоматичного відкриття зазначеної форми. Деякі спортивні команди тут використовують football_injury_audit.'),
(124967, 6667, 33, 'В представлення Рахунок'),
(124968, 6668, 33, 'в категорії'),
(124969, 6669, 33, 'В Клінічне представлення'),
(124970, 6670, 33, 'в доплату'),
(124971, 6672, 33, 'To ded''ble'),
(124972, 6673, 33, 'В електронну службу передачі цифрових повідомлень'),
(124973, 6674, 33, 'Для відключення сертифікатів SSL на стороні клієнта закоментуйте вищевказані рядки в конфігураційному файлі Apache і встановіть'),
(124974, 6675, 33, 'Для відключення HTTPS закоментуйте вищевказані рядки в конфігураційному файлі Apache і перезавантажте сервер Apache.'),
(124975, 6676, 33, 'Для включення сертифікатів ssl на стороні клієнта'),
(124976, 6677, 33, 'Для включення перевірки сертифікатів SSL на стороні клієнта повинен бути включений HTTPS'),
(124977, 6678, 33, 'Для включення тільки HTTPS, зробіть зазначені вище зміни і перезавантажте сервер Apache. Якщо хочете також налаштувати сертифікати на стороні клієнта, налаштуйте їх в наступному розділі.'),
(124978, 6679, 33, 'Для зверн.'),
(124979, 6680, 33, 'Фільтрувати по статті'),
(124980, 6681, 33, 'В анамнез'),
(124981, 6682, 33, 'До проблем'),
(124982, 6683, 33, 'Щоб зв''язувати дане звернення/консультацію з наявною проблемою, натисніть тут '),
(124983, 6684, 33, 'Щоб зв''язати дане звернення/консультацію з існуючою проблемою клікніть вище потрібну проблему і натисніть [Зберегти]. Для вибору декількох проблем утримуйте клавішу [Ctrl].'),
(124984, 6685, 33, 'для повторного входу в систему'),
(124985, 6686, 33, 'Клацніть для опублікування запису'),
(124986, 6687, 33, 'для запуску'),
(124987, 6688, 33, 'Для організації доступу https з перевіркою сертифіката клієнта зробіть наступне'),
(124988, 6689, 33, 'Нашкірно'),
(124989, 6690, 33, 'нашкірно'),
(124990, 6691, 33, 'у це відвідування?'),
(124991, 6693, 33, 'До:'),
(124992, 6694, 33, 'До: '),
(124993, 6695, 33, 'ДО_МІСТО'),
(124994, 6696, 33, 'ДО_ФАКС'),
(124995, 6697, 33, 'ДО_ІМ"Я'),
(124996, 6698, 33, 'ДО_ПРІЗВИЩЕ'),
(124997, 6699, 33, 'ДО_ПО-БАТЬКОВІ'),
(124998, 6700, 33, 'ДО_УСТАНОВА'),
(124999, 6703, 33, 'ДО_ПОШТОВА_АДРЕСА'),
(125000, 6704, 33, 'ДО_ОБЛАСТЬ'),
(125001, 6705, 33, 'ДО_ВУЛИЦЯ'),
(125002, 6706, 33, 'ДО_НАЗВА'),
(125003, 6707, 33, 'ДО_ПРОЩАННЯ'),
(125004, 6708, 33, 'Тютюн'),
(125005, 6709, 33, 'Втручання з припинення тютюнопаління'),
(125006, 6710, 33, 'Втручання з припинення тютюнопаління (CQM)'),
(125007, 6712, 33, 'Використання тютюну'),
(125008, 6713, 33, 'Оцінка використання тютюну'),
(125009, 6714, 33, 'Оцінка використання тютюну (CQM)'),
(125010, 6715, 33, 'Сьогодні'),
(125011, 6716, 33, 'СЬОГОДНІ'),
(125012, 6717, 33, 'сьогодні'),
(125013, 6718, 33, 'Сьогоднішній баланс'),
(125014, 6719, 33, 'Сьогоднішні зміни'),
(125015, 6720, 33, 'Сьогоднішня дата'),
(125016, 6721, 33, 'Сьогоднішні події'),
(125017, 6723, 33, 'Token ID для підтримки Інтеграції Медичної Інформації, послуги обміну лабораторними даними LLC'),
(125018, 6724, 33, 'Token ID для підтримки LibreEHR послуги обміну лабораторними даними LLC'),
(125019, 6726, 33, 'Тонзилектомія'),
(125020, 6728, 33, 'Верх'),
(125021, 6730, 33, 'Розділ'),
(125022, 6731, 33, 'Всього'),
(125023, 6732, 33, 'всього'),
(125024, 6733, 33, 'Всього активних дій'),
(125025, 6734, 33, 'Всього активних нагадувань після оновлення'),
(125026, 6735, 33, 'Всього активних нагадувань до оновлення'),
(125027, 6737, 33, 'Підлягає всього'),
(125028, 6738, 33, 'Всього до оплатити'),
(125029, 6739, 33, 'Всього Заборгованість'),
(125030, 6740, 33, 'Загальний платіж'),
(125031, 6741, 33, 'Загальні платежі'),
(125032, 6742, 33, 'Всього клієнтів'),
(125033, 6743, 33, 'Загальна вартість'),
(125034, 6744, 33, 'Підсумкова кількість для подальшої перевірки надано не повністю'),
(125035, 6745, 33, 'всього елементів'),
(125036, 6746, 33, 'Всього невдалих нагадувань, що були відправлені по e-mail'),
(125037, 6747, 33, 'Всього невдалих нагадувань по телефону'),
(125038, 6748, 33, 'Всього для'),
(125039, 6749, 33, 'Всього для '),
(125040, 6750, 33, 'Всього для категорії'),
(125041, 6751, 33, 'Всього неактивованих нагадувань'),
(125042, 6752, 33, 'Всього нових нагадувань'),
(125043, 6753, 33, 'Загальна кількість записів на прийом'),
(125044, 6755, 33, 'Загальна кількість вакцинацій'),
(125045, 6756, 33, 'Загальна кількість результатів'),
(125046, 6758, 33, 'Загальна кількість пацієнтів'),
(125047, 6760, 33, 'Підсумковий баланс по пацієнтам'),
(125048, 6761, 33, 'Всього пацієнтів'),
(125049, 6764, 33, 'Всього знайдених записів'),
(125050, 6765, 33, 'Загальне SRH і планування сім''ї'),
(125051, 6766, 33, 'Всього успішних нагадувань, відправлених через email'),
(125052, 6767, 33, 'Всього успішних нагадувань, відправлених через телефон'),
(125053, 6770, 33, 'Всього незмінених нагадувань'),
(125054, 6771, 33, 'Всього невідправлених нагадувань після запуску процесу відправки'),
(125055, 6772, 33, 'Всього невідправлених нагадувань після оновлення'),
(125056, 6773, 33, 'Всього невідправлених нагадувань до запуску процесу відправки'),
(125057, 6774, 33, 'Всього невідправлених нагадувань до оновлення'),
(125058, 6775, 33, 'Всього оновлених нагадувань'),
(125059, 6776, 33, 'Підсумки'),
(125060, 6777, 33, 'Всього для'),
(125061, 6778, 33, 'Всього для '),
(125062, 6780, 33, 'до{{range}}'),
(125063, 6785, 33, 'Тип навчання'),
(125064, 6786, 33, 'Провести'),
(125065, 6787, 33, 'Транзакція'),
(125066, 6788, 33, 'транзакція'),
(125067, 6789, 33, 'Транзакція дала збій, недостатня кількість в призначуваній партії'),
(125068, 6790, 33, 'Транзакція дала збій, кількість менша нуля'),
(125069, 6791, 33, 'Тип транзакції'),
(125070, 6792, 33, 'транзакції'),
(125071, 6793, 33, 'Транзакції'),
(125072, 6794, 33, 'Транзакції (право запису - на вибір)'),
(125073, 6795, 33, 'Транзакції/направлення'),
(125074, 6797, 33, 'Передати'),
(125075, 6798, 33, 'Дата передачі'),
(125076, 6799, 33, 'Передача дала збій, недостатня кількість у вихідній партії'),
(125077, 6800, 33, 'Сумарна інформація про передачу'),
(125078, 6801, 33, 'Передати до'),
(125079, 6804, 33, 'Передачі'),
(125080, 6806, 33, 'Зміна/передача медичної допомоги?'),
(125081, 6807, 33, 'Групи управління доступом до перекладу'),
(125082, 6808, 33, 'Переводити категорії прийому'),
(125083, 6809, 33, 'Переводити категорії документа'),
(125084, 6810, 33, 'Переводити макети'),
(125085, 6811, 33, 'Переводити списки'),
(125086, 6812, 33, 'Переводити заголовки записів по пацієнтах'),
(125087, 6813, 33, 'перекласти це'),
(125088, 6814, 33, 'Переклад'),
(125089, 6815, 33, 'Переклади'),
(125090, 6816, 33, 'Передати'),
(125091, 6817, 33, 'Збій передачі'),
(125092, 6818, 33, 'Передати вибрані накази'),
(125093, 6819, 33, 'Травма'),
(125094, 6820, 33, 'Лікування'),
(125095, 6822, 33, 'Мета лікування'),
(125096, 6823, 33, 'План лікування'),
(125097, 6824, 33, 'Планування лікування'),
(125098, 6825, 33, 'Лікування отримано'),
(125099, 6826, 33, 'Лікування:'),
(125100, 6827, 33, 'Лікування: '),
(125101, 6828, 33, 'Динаміка'),
(125102, 6829, 33, 'trftime($month_format, mktime(0, 0, 0, $i, 1, 2000)) ); $month_value'),
(125103, 6830, 33, 'Пускова точка / синдром здавлення / DOMS / судома'),
(125104, 6831, 33, 'Трімаляр'),
(125105, 6832, 33, 'Торс і живіт'),
(125106, 6835, 33, 'Спроба створити користувача з ім"ям, що вже використовується!'),
(125107, 6837, 33, 'ч.л.'),
(125108, 6839, 33, 'TTS'),
(125109, 6840, 33, 'Туберкульоз'),
(125110, 6841, 33, 'Вт.'),
(125111, 6842, 33, 'Вт. &amp; Чт.'),
(125112, 6843, 33, 'Вівторок'),
(125113, 6844, 33, 'Новоутворення'),
(125114, 6845, 33, 'Турецька'),
(125115, 6848, 33, 'Двічі на день'),
(125116, 6850, 33, 'Барабанна перетинка'),
(125117, 6851, 33, 'Тип'),
(125118, 6852, 33, 'Введіть id або ім''я. Мінімум 3 символи (включаючи пробіли).'),
(125119, 6853, 33, 'Тип стовпців, які відображаються для результатів пошуку пацієнта'),
(125120, 6854, 33, 'Тип публікації'),
(125121, 6855, 33, 'Тип подій'),
(125122, 6856, 33, 'Тип макета екрану'),
(125123, 6857, 33, 'Введіть або переглядайте ідентифікатор пацієнта тут'),
(125124, 6858, 33, 'Тип Вашого повідомлення тут'),
(125125, 6859, 33, 'Типи призначень і результатів'),
(125126, 6864, 33, 'Коди UCSMC надані через Університет Спортивного Медичного Центру Калгарі'),
(125127, 6865, 33, 'Українська'),
(125128, 6866, 33, 'Виразки'),
(125129, 6867, 33, 'Виразковий коліт'),
(125130, 6868, 33, 'Виразки:'),
(125131, 6871, 33, 'Неможливо створити'),
(125132, 6874, 33, 'Неможливо знайти цю оплату в ar_activity'),
(125133, 6876, 33, 'Не підходить'),
(125134, 6877, 33, 'Не вказано'),
(125135, 6878, 33, 'Несанкціонований'),
(125136, 6879, 33, 'Несанкціонований доступ до ePrescription'),
(125137, 6880, 33, 'Несанкціонований доступ.'),
(125138, 6881, 33, 'Без рахунків'),
(125139, 6882, 33, 'Лише без рахунків'),
(125140, 6884, 33, 'під язик'),
(125141, 6885, 33, 'Схуднення'),
(125142, 6886, 33, 'Недіагностованою'),
(125143, 6887, 33, 'НЕРОЗПОДІЛЕНЕ'),
(125144, 6888, 33, 'Нерозподілене'),
(125145, 6889, 33, 'Невиплачених є'),
(125146, 6890, 33, 'Нерозподілене є'),
(125147, 6892, 33, 'Унікальні клієнти'),
(125148, 6893, 33, 'Унікальний ідентифікатор для цього типу, придатний для читаєтння людиною'),
(125149, 6894, 33, 'Унікальні нові клієнти'),
(125150, 6895, 33, 'Унікальний числовий ідентифікатор для цього типу'),
(125151, 6896, 33, 'Індивідуальний огляд пацієнта'),
(125152, 6897, 33, 'Звіт про індивідуальний огляд пацієнта'),
(125153, 6898, 33, 'Індивідуальна периферична сатурація'),
(125154, 6899, 33, 'Одиниця виміру'),
(125155, 6900, 33, 'Одиниці виміру'),
(125156, 6901, 33, 'од. вим.'),
(125157, 6902, 33, 'Одиниці можна застосувати до значення результату'),
(125158, 6903, 33, 'Одиниці виміру для форм відвідування'),
(125159, 6904, 33, 'Одиниці виміру повинні бути числом'),
(125160, 6905, 33, 'Одиниці виміру не визначені'),
(125161, 6906, 33, 'Одиниця виміру / Л'),
(125162, 6907, 33, 'Невідомий'),
(125163, 6910, 33, 'Невідомо, навіть якщо палить'),
(125164, 6911, 33, 'Невідомо чи N/A'),
(125165, 6912, 33, 'Невідомий id користувача:'),
(125166, 6913, 33, 'від''єднати пацієнта'),
(125167, 6914, 33, 'Неназвана страхова компанія'),
(125168, 6915, 33, 'Незареєстровані'),
(125169, 6918, 33, 'Зняти всі виділення'),
(125170, 6919, 33, 'Не вибраний'),
(125171, 6920, 33, 'Незазначені'),
(125172, 6921, 33, 'неструктуроване'),
(125173, 6922, 33, 'НЕПІДТРИМУВАНИЙ файл завантаження бази даних'),
(125174, 6924, 33, 'до'),
(125175, 6925, 33, 'Невчасний запис'),
(125176, 6926, 33, 'Невикористовуване'),
(125177, 6927, 33, 'Вимога термінового втручання'),
(125178, 6928, 33, 'Включаючи до'),
(125179, 6929, 33, 'Найближчий запис на прийом'),
(125180, 6930, 33, 'Майбутні події'),
(125181, 6931, 33, 'Оновити'),
(125182, 6932, 33, 'оновити'),
(125183, 6933, 33, 'Оновлення активне'),
(125184, 6934, 33, 'Оновити файли'),
(125185, 6935, 33, 'Оновити інф.'),
(125186, 6936, 33, 'Оновити список'),
(125187, 6937, 33, 'Оновити номер спеціаліста'),
(125188, 6938, 33, 'Оновити вибрані об''єкти'),
(125189, 6939, 33, 'Оновлює наступні змінні у файлі'),
(125190, 6940, 33, 'Оновлює інформацію про користувача'),
(125191, 6942, 33, 'Оновлення персональних даних не дозволено.'),
(125192, 6943, 33, 'Оновлення загальних параметрів налаштування по-замовчуванню'),
(125193, 6944, 33, 'Оновлення номеру версії'),
(125194, 6945, 33, 'МОДЕРНІЗАЦІЯ'),
(125195, 6946, 33, 'Модернізація'),
(125196, 6947, 33, 'Модернізація бази даних'),
(125197, 6948, 33, 'Модернізує базу даних LibreEHR для включення методик, функцій і таблиць, необхідних для процесу де-ідентифікації'),
(125198, 6949, 33, 'Модернізація буде продовжена'),
(125199, 6950, 33, 'Унікальний лікарський ідентифікаційний номер (UPIN)'),
(125200, 6951, 33, 'Вивантажити'),
(125201, 6954, 33, 'Вивантажити конфігураційні дані'),
(125202, 6955, 33, 'Вивантажити документ'),
(125203, 6956, 33, 'Збій вивантаження!'),
(125204, 6957, 33, 'Вивантажити зображення у'),
(125205, 6958, 33, 'Вивантажити файл імпорту:'),
(125206, 6960, 33, 'Вивантажено успішно'),
(125207, 6961, 33, 'Вивантажити звіт'),
(125208, 6963, 33, 'Вивантажити цей файл:'),
(125209, 6964, 33, 'Після кліку на номері рахунку з''являється "вікно ручної реєстрації". Тут Ви можете змінити дату оплати та нотатки по рахунку, вибрати учасника, для кого реєструєте і, страховку, для якої повинні бути отримані всі можливі платежі. Особливо важливо те, що для кожного коду рахунку, для якого була змінена сума, можна ввести платіж та інформацію щодо коригування.'),
(125210, 6965, 33, 'При пошуку ви побачите список рахунків. Можете клікнути на одному з номерів рахунків для відкриття другого вікна, яке є сторінкою введення даних для ручної реєстрації. Також можете клікнути на ім''я пацієнта, якщо потрібно ввести запис, який при реєстрації пацієнта побачать співробітники реєстратури, і ви зможете вибрати запрошення появи рахунків для заявок по пацієнту та їх друк.'),
(125211, 6966, 33, 'Верхня кінцівка'),
(125212, 6968, 33, 'Імперативні позиви'),
(125213, 6970, 33, 'Сеча'),
(125214, 6971, 33, 'Підтікання сечі'),
(125215, 6972, 33, 'прискорене сечовипускання'),
(125216, 6973, 33, 'Ослаблений напір струменя сечі'),
(125217, 6974, 33, 'мікроальбумін сечі'),
(125218, 6975, 33, 'Потік сечі'),
(125219, 6976, 33, 'Невідкладність позиву на сечовипускання'),
(125220, 6977, 33, 'URL'),
(125221, 6979, 33, 'URL для підтримки LibreEHR.'),
(125222, 6981, 33, 'URL для телефонного шлюзу. Автоматизована служба VOIP надана через Maviq. Відвідайте http://signup.maviq.com для отримання додаткової інформації.'),
(125223, 6985, 33, 'Використання'),
(125224, 6986, 33, 'Індикатор використання (ISA15)'),
(125225, 6987, 33, 'Використовуйте лише % в полі, щоб сортувати по цьому стовпці'),
(125226, 6988, 33, 'Використовувати 24-годинний формат часу?'),
(125227, 6990, 33, 'Використовуйте сертифіковані технології EHR для виявлення освітніх ресурсів конкретному пацієнту і, якщо це необхідно, надання їх пацієнтові.'),
(125228, 6991, 33, 'Використання панелі платежу'),
(125229, 6992, 33, 'Використовуйте CPOE для лікарських призначень, зроблених безпосередньо будь-яким дипломованим фахівцем, який може робити призначення в медичній карті згідно державних, місцевих та професійних керівних принципів.'),
(125230, 6997, 33, 'Використовувати користувацький список вакцинації'),
(125231, 6999, 33, 'Використовувати діапазон дат'),
(125232, 7000, 33, 'Використовувати за замовчуванням'),
(125233, 7001, 33, 'Використовуйте опцію Видалити для видалення.'),
(125234, 7002, 33, 'Використовувати міжнародний стиль дат?'),
(125235, 7003, 33, 'Використовуйте ім''я вихідного файлу'),
(125236, 7004, 33, 'Використовуйте поля нижче для отримання або передачі.'),
(125237, 7005, 33, 'Використовуйте цю можливість тільки для наново встановлених сайтів, '),
(125238, 7006, 33, 'Використовувати розділи?'),
(125239, 7007, 33, 'Користувач'),
(125240, 7009, 33, 'Користувач / групи'),
(125241, 7010, 33, 'управління користувачем'),
(125242, 7011, 33, 'Управління користувачем і медичним закладом'),
(125243, 7012, 33, 'Управління користувачем і групою'),
(125244, 7014, 33, 'Перевірка сертифіката користувача відключена'),
(125245, 7015, 33, 'Визначено користувачем'),
(125246, 7016, 33, 'Область 11, визначена користувачем'),
(125247, 7017, 33, 'Область 12, визначена користувачем'),
(125248, 7018, 33, 'Поле, визначене користувачем'),
(125249, 7019, 33, 'Список 1, визначений користувачем'),
(125250, 7020, 33, 'Список 2, визначений користувачем'),
(125251, 7021, 33, 'Список 3, визначений користувачем'),
(125252, 7022, 33, 'Список 4, визначений користувачем'),
(125253, 7023, 33, 'Список 5, визначений користувачем'),
(125254, 7024, 33, 'Список 6, визначений користувачем'),
(125255, 7025, 33, 'Список 7, визначений користувачем'),
(125256, 7026, 33, 'Текст 1, визначений користувачем'),
(125257, 7027, 33, 'Текст 2, визначений користувачем'),
(125258, 7028, 33, 'Текст 3, визначений користувачем'),
(125259, 7029, 33, 'Текст 4, визначений користувачем'),
(125260, 7030, 33, 'Текст 5, визначений користувачем'),
(125261, 7031, 33, 'Текст 6, визначений користувачем'),
(125262, 7032, 33, 'Текст 7, визначений користувачем'),
(125263, 7033, 33, 'Текст 8, визначений користувачем'),
(125264, 7034, 33, 'Ім''я користувача'),
(125265, 7037, 33, 'Вхід користувача (якщо 03 вище, інакше залинити пробіл) (ISA02)'),
(125266, 7038, 33, 'Обов''язковий вказівник входу користувача (ISA01~ використовувати 00 чи 03)'),
(125267, 7039, 33, 'Керівництво користувача'),
(125268, 7040, 33, 'Групи користувачів'),
(125269, 7041, 33, 'Ім''я користувача (логін)'),
(125270, 7042, 33, 'Ім''я користувача або хоста не може бути порожнім'),
(125271, 7043, 33, 'Ім''я користувача або хоста'),
(125272, 7044, 33, 'Пароль користувача (ISA04~ якщо 01 вище, інакше залинити пробіл)'),
(125273, 7045, 33, 'Обов''язковий вказівник паролю користувача (ISA03~ використовувати 00 чи 01)'),
(125274, 7046, 33, 'Налаштування користувача'),
(125275, 7047, 33, 'Особливі налаштування користувача'),
(125276, 7048, 33, 'Новий пароль користувачів'),
(125277, 7049, 33, 'Ім''я користувача (логін)'),
(125278, 7051, 33, 'Ім''я користувача (логін) для телефонного шлюзу. Автоматизована служба VOIP надана через Maviq. Відвідайте http://signup.maviq.com для отримання додаткової інформації.'),
(125279, 7052, 33, 'Ім''я користувача для шлюзу SMS'),
(125280, 7053, 33, 'Ім''я користувача для шлюзу SMS.'),
(125281, 7054, 33, 'Ім''я користувача для підключення до CouchDB'),
(125282, 7055, 33, 'Ім''я користувача (логін):'),
(125283, 7056, 33, 'Користувачі'),
(125284, 7057, 33, 'Управління користувачами / групами / реєстрацією'),
(125285, 7058, 33, 'використовуйте формат php <a href="http://php.net/strftime"> strftime </a>'),
(125286, 7059, 33, 'ІМП'),
(125287, 7062, 33, 'ВІДПУСТКА'),
(125288, 7063, 33, 'Відпустка'),
(125289, 7064, 33, 'Вакцина'),
(125290, 7065, 33, 'Контрацептивна вагінальне кільце'),
(125291, 7066, 33, 'Прощальне слово'),
(125292, 7067, 33, 'допустимий'),
(125293, 7068, 33, 'Значення'),
(125294, 7069, 33, 'Значення 1'),
(125295, 7070, 33, 'Значення 2'),
(125296, 7072, 33, 'Значення має бути цифровим'),
(125297, 7073, 33, 'Змінна 1'),
(125298, 7074, 33, 'Змінна 2'),
(125299, 7075, 33, 'єдина змінна для запуску скрипта модернізації деідентіфікаціі'),
(125300, 7076, 33, 'Вітряна віспа 1'),
(125301, 7077, 33, 'Вітряна віспа 2'),
(125302, 7078, 33, 'Варикозно розширені вени'),
(125303, 7079, 33, 'Стан судин'),
(125304, 7080, 33, 'Пошкодження судин'),
(125305, 7081, 33, 'Ангіохірург'),
(125306, 7083, 33, 'Виробник'),
(125307, 7084, 33, 'Версія'),
(125308, 7085, 33, 'Запаморочення'),
(125309, 7086, 33, 'Адміністрація ветеранів'),
(125310, 7087, 33, 'Урядова програма для ветеранів'),
(125311, 7088, 33, 'Дитяча вакцина (VFC)'),
(125312, 7089, 33, 'В''єтнамська'),
(125313, 7090, 33, 'вид'),
(125314, 7091, 33, 'Вид'),
(125315, 7092, 33, 'Перегляд алергії'),
(125316, 7093, 33, 'Перегляд x12-835 ERA файлу'),
(125317, 7094, 33, 'Перегляд тексту пакетної вимоги x12'),
(125318, 7097, 33, 'Перегляд короткого звіту по пацієнту'),
(125319, 7098, 33, 'Перегляд CSV таблиць'),
(125320, 7100, 33, 'Перегляд документа'),
(125321, 7101, 33, 'Перегляд звернення'),
(125322, 7102, 33, 'Перегляд тексту ERA x12'),
(125323, 7103, 33, 'Переглянути події у спливаючому вікні?'),
(125324, 7104, 33, 'Переглянути інформацію користувача специфічну до медзакладу'),
(125325, 7106, 33, 'Перегляд локального x12 файлу'),
(125326, 7107, 33, 'Перегляд журналу'),
(125327, 7108, 33, 'Переглянути сторінку 1'),
(125328, 7109, 33, 'Переглянути сторінку 2'),
(125329, 7110, 33, 'Перегляд минулі і майбутні нагадування'),
(125330, 7111, 33, 'Перегляд пацієнта'),
(125331, 7116, 33, 'Перегляд пов''язаних звернень'),
(125332, 7117, 33, 'Перегляд звіту'),
(125333, 7118, 33, 'Перегляд файлу README'),
(125334, 7121, 33, 'Перегляд/редагування алергій'),
(125335, 7122, 33, 'Перегляд/редагування проблеми'),
(125336, 7123, 33, 'Перегляд/Друк'),
(125337, 7124, 33, 'Переглянути:'),
(125338, 7125, 33, 'VISA'),
(125339, 7126, 33, 'VISA/MC/AMEX/Dis'),
(125340, 7127, 33, 'Пошкодження внутрішніх органів / травма / оперативне втручання'),
(125341, 7133, 33, 'Категорія відвідування:'),
(125342, 7134, 33, 'Дата відвідування'),
(125343, 7135, 33, 'дата відвідування'),
(125344, 7137, 33, 'Форма відвідування'),
(125345, 7138, 33, 'Хронологія відвідувань'),
(125346, 7140, 33, 'Відвідування'),
(125347, 7141, 33, 'Форми відвідувань'),
(125348, 7142, 33, 'Позначення життєво важливих показників'),
(125349, 7143, 33, 'Життєво важливі показники'),
(125350, 7144, 33, 'Життєво важливі показники (метричні)'),
(125351, 7145, 33, 'Налаштування для життєво важливих показників'),
(125352, 7146, 33, 'Голосове'),
(125353, 7147, 33, 'Телефонограма'),
(125354, 7149, 33, 'Блювота'),
(125355, 7151, 33, 'W'),
(125356, 7152, 33, 'Окр. талії'),
(125357, 7153, 33, 'Окружність талії'),
(125358, 7154, 33, 'Очікування'),
(125359, 7155, 33, 'Без попереднього запису'),
(125360, 7157, 33, 'Уолт Пеннінгтон'),
(125361, 7158, 33, 'Склад'),
(125362, 7159, 33, 'Складський максимум, 0, якщо не застосовується'),
(125363, 7160, 33, 'Складський мінімум, 0, якщо не застосовується'),
(125364, 7161, 33, 'Склади'),
(125365, 7162, 33, 'Жар'),
(125366, 7163, 33, 'Попередження'),
(125367, 7164, 33, 'ПОПЕРЕДЖЕННЯ'),
(125368, 7166, 33, 'Попередження, реєстраційний номер вже є в базі даних'),
(125369, 7167, 33, 'Попередження, пацієнт має неоднозначні коди в списку проблем!'),
(125370, 7168, 33, 'Попередження: відвідування для цього пацієнта вже створено!'),
(125371, 7169, 33, 'УВАГА: Якщо ви використовуєте іспанську версію від 2012-10-31, то зверніть увагу - необхідно розпакувати його один раз перед установкою в SNOMED (це тому, що файл в релізі був "двічі заархівований ").'),
(125372, 7170, 33, 'Попередження: ID пацієнта не унікальний!'),
(125373, 7171, 33, 'ПОПЕРЕДЖЕННЯ: конфігураційна інформація буде переписана з дати цього завантаженого файлу!'),
(125374, 7173, 33, 'Попередження'),
(125375, 7175, 33, 'вже завантажений'),
(125376, 7176, 33, 'не було знайдено'),
(125377, 7177, 33, 'Ми високо цінуємо своєчасну виплату заборгованостей'),
(125378, 7178, 33, 'ми подбали про зазначеного пацієнта, провівши амбулаторно обстеження і лікування в нашій клініці психіатрії. Дякуємо за цей направлення.'),
(125379, 7179, 33, 'Слабкість'),
(125380, 7181, 33, 'Пошук в інтернеті'),
(125381, 7182, 33, 'Веб-сайт'),
(125382, 7183, 33, 'Посилання на веб-сайт для внутрішнього порталу пацієнтів.'),
(125383, 7184, 33, 'Сер.'),
(125384, 7185, 33, 'Середа'),
(125385, 7186, 33, 'Тиждень'),
(125386, 7187, 33, 'тиждень'),
(125387, 7188, 33, 'Огляд за тиждень'),
(125388, 7189, 33, 'Тиждень(ні)'),
(125389, 7190, 33, 'Щотижневе подання'),
(125390, 7191, 33, 'тижні'),
(125391, 7192, 33, 'Тижні'),
(125392, 7193, 33, 'Вага'),
(125393, 7194, 33, 'Оцінка ваги та рекомендації для дітей і підлітків'),
(125394, 7195, 33, 'Оцінка ваги та рекомендації для дітей і підлітків (CQM)'),
(125395, 7196, 33, 'Зміна ваги'),
(125396, 7197, 33, 'Втрата ваги'),
(125397, 7198, 33, 'Клініка схуднення'),
(125398, 7199, 33, 'Ласкаво просимо'),
(125399, 7202, 33, 'Що має бути підраховано?'),
(125400, 7203, 33, 'Стридорозне дихання:'),
(125401, 7204, 33, 'Хрипи'),
(125402, 7205, 33, 'Хрипи:'),
(125403, 7208, 33, 'Де можна знайти пов''язані скановані або паперові документи?'),
(125404, 7209, 33, 'Якщо застраховано'),
(125405, 7211, 33, 'Хлистова травма'),
(125406, 7212, 33, 'Білий'),
(125407, 7213, 33, 'Хто'),
(125408, 7214, 33, 'Хто відповідає?'),
(125409, 7215, 33, 'Овдовіла(ий)'),
(125410, 7216, 33, 'Ширина'),
(125411, 7217, 33, 'Ширина в пікселях для меню навігації зліва.'),
(125412, 7221, 33, 'З вибраним:'),
(125413, 7222, 33, 'з старою назвою'),
(125414, 7224, 33, 'З ким можна залишити повідомлення?'),
(125415, 7225, 33, 'Відкласти'),
(125416, 7226, 33, 'протягом годин'),
(125417, 7227, 33, 'протягом годин:'),
(125418, 7228, 33, 'протягом хвилин'),
(125419, 7229, 33, 'протягом хвилин:'),
(125420, 7230, 33, 'Без медичного закладу'),
(125421, 7231, 33, 'Без спеціаліста'),
(125422, 7232, 33, 'Без поновлення'),
(125423, 7233, 33, 'Інспектор'),
(125424, 7234, 33, 'тиж.'),
(125425, 7235, 33, 'У межах норми'),
(125426, 7237, 33, 'Жінка'),
(125427, 7238, 33, 'Тільки жінок'),
(125428, 7240, 33, 'Робота'),
(125429, 7241, 33, 'РОБОЧИЙ ЗАПИС'),
(125430, 7242, 33, 'Робочий телефон'),
(125431, 7243, 33, 'Номер робочого телефону'),
(125432, 7244, 33, 'Пов''язано з роботою?'),
(125433, 7245, 33, 'Робота / освіта / хобі'),
(125434, 7246, 33, 'Робочий / шкільний запис'),
(125435, 7247, 33, 'робочий день'),
(125436, 7248, 33, 'Компенсація працівників'),
(125437, 7249, 33, 'Програма Охорони Здоров''я працівників'),
(125438, 7250, 33, 'Спадкоємці працездатного віку або чоловік чи дружина з планом групи здоров''я роботодавців'),
(125439, 7251, 33, 'Працюю...це може зайняти час.'),
(125440, 7252, 33, 'Найгірший'),
(125441, 7253, 33, 'Хочете використовувати решту суми в загальному рахунку?'),
(125442, 7254, 33, 'Хочете маркувати їх як очищені?'),
(125443, 7255, 33, 'Хочете внести?'),
(125444, 7256, 33, 'Хочете скасувати подання для цього пацієнта?'),
(125445, 7257, 33, 'Хочете видалити надання оплати?'),
(125446, 7258, 33, 'Хочете видалити платежі?'),
(125447, 7259, 33, 'Хочете змінити або завершити платіж?'),
(125448, 7260, 33, 'Хочете змінити платіж?'),
(125449, 7261, 33, 'Хочете відправити і завершити платіж?'),
(125450, 7262, 33, 'Хочете відправити платіж?'),
(125451, 7263, 33, 'Хочете зберегти?'),
(125452, 7264, 33, 'Зап''ястя'),
(125453, 7265, 33, 'Зап''ястя і рука'),
(125454, 7266, 33, 'Проблеми зап''ястя'),
(125455, 7267, 33, 'записувати'),
(125456, 7268, 33, 'без запису'),
(125457, 7270, 33, 'записувати частково'),
(125458, 7271, 33, 'WT'),
(125459, 7273, 33, 'Скасоване x'),
(125460, 7274, 33, 'Скасоване x'),
(125461, 7275, 33, 'Рентген. дослідження'),
(125462, 7276, 33, 'Інтерпретація РЕНГЕНІВСЬКОГО дослідження:'),
(125463, 7277, 33, 'Інтерпретація ренг. дослідження:'),
(125464, 7278, 33, 'Тільки X12: вимога заміни '),
(125465, 7279, 33, 'Партнер X12'),
(125466, 7280, 33, 'Партнери X12'),
(125467, 7281, 33, 'Текст X12'),
(125468, 7284, 33, 'р.'),
(125469, 7285, 33, 'Рік'),
(125470, 7286, 33, 'рік'),
(125471, 7287, 33, 'Огляд за рік'),
(125472, 7288, 33, 'Рік(роки)'),
(125473, 7289, 33, 'Роки'),
(125474, 7290, 33, 'Роки чи місяці'),
(125475, 7291, 33, 'Роки, місяці і дні'),
(125476, 7292, 33, 'ТАК'),
(125477, 7293, 33, 'Так'),
(125478, 7294, 33, 'так'),
(125479, 7295, 33, 'ТАК!'),
(125480, 7296, 33, 'Так, Видалити і зареєструвати');
INSERT INTO `lang_definitions` VALUES
(125481, 7298, 33, 'Так/Ні'),
(125482, 7299, 33, 'Так:'),
(125483, 7300, 33, 'Ідиш'),
(125484, 7303, 33, 'Робиться спроба назавжди замінити існуючий шаблон. Упевнені, що потрібно продовжити?'),
(125485, 7304, 33, 'Дія пароля для входу в систему зберігає. Змініть пароль до'),
(125486, 7305, 33, 'У вас немає права на видалення цієї події'),
(125487, 7306, 33, 'У вас немає права на зміну цієї події'),
(125488, 7307, 33, 'Це вам не дозволено.'),
(125489, 7308, 33, 'Доступ до цієї групи вам не дозволено.'),
(125490, 7309, 33, 'Вам не дозволено додавання/зміна проблем'),
(125491, 7310, 33, 'Вам не дозволено планувати записи на прийом.'),
(125492, 7311, 33, 'Для перегляду цього звернення ви не авторизовані.'),
(125493, 7312, 33, 'Ви вводите знову старий випадок?'),
(125494, 7313, 33, 'У вас немає прямого доступу до цієї функції.'),
(125495, 7314, 33, 'У вас немає прямого доступу до цієї сторінки.'),
(125496, 7315, 33, 'Ви не можете додати пусте значення для категорії!'),
(125497, 7316, 33, 'Ви не можете додати пусте значення для підкатегорії!'),
(125498, 7317, 33, 'Для цього елемента додати порожнє значення неможливо!'),
(125499, 7318, 33, 'Не можна ввести майбутню дату із значенням завершення Так.'),
(125500, 7319, 33, 'Ви не вибрали жодної дії.'),
(125501, 7320, 33, 'Ви не маєте доступу для перегляду / зміни цього запису'),
(125502, 7321, 33, 'Ви намагалися змінити заблокований вміст. Якщо це необхідно зробити, то зніміть блокування. Для розблокування видаліть рядок ''/ *lock::* / '''),
(125503, 7322, 33, 'Ви закінчили сеанс роботи.'),
(125504, 7323, 33, 'Ви можете завантажувати лише файли .txt'),
(125505, 7324, 33, 'Ви можете додатково завантажити HL7 результати з файлу'),
(125506, 7325, 33, 'Можете вставити тут текст, як скаргу за замовчуванням для форми звертання пацієнта.'),
(125507, 7326, 33, 'Ви повинні ввести пароль для шифрування цього документа'),
(125508, 7327, 33, 'Ви повинні ввести свій пароль для зміни паролів користувачів. Залиште порожнім, щоб залишити пароль незмінними.'),
(125509, 7329, 33, 'Спочатку потрібно вибрати або додати пацієнта.'),
(125510, 7330, 33, 'Перш за все, необхідно вибрати або створити звертання.'),
(125511, 7331, 33, 'Потрібно вибрати категорію візиту'),
(125512, 7332, 33, 'Потрібно вибрати категорію візиту'),
(125513, 7333, 33, 'Для продовження ви повинні вибрати деякі поля.'),
(125514, 7334, 33, 'Якщо з''явилася ця вимога, то для успішного створення потрібно запустити цей тест, але сам потрібний файл не містить ніяких даних або тільки незавершені частини суми даних, передбачуваних для включення. Це очевидніше з вимогами HCFA, бо вони зручніші для читання для людиною, тоді як для вимог X12 є більш складним процес визначення, чи підготовлена вимога належним чином.'),
(125515, 7335, 33, 'Потрібно вибрати, принаймні, один контекст'),
(125516, 7336, 33, 'Необхідно вибрати хоча б одного фахівця'),
(125517, 7339, 33, 'Неправильна дата закінчення'),
(125518, 7340, 33, 'Вашу подію видалено.'),
(125519, 7341, 33, 'Вашу подію змінено.'),
(125520, 7342, 33, 'Подія була подана до розгляду.'),
(125521, 7343, 33, 'Ваш файл занадто великий'),
(125522, 7345, 33, 'Ваше ім''я списку було змінено для задоволення вимог стосовно назв'),
(125523, 7346, 33, 'Ваше повідомлення було подано для доставки до'),
(125524, 7347, 33, 'Ваша назва для цієї категорії, методики або результату'),
(125525, 7348, 33, 'Ваш пароль'),
(125526, 7349, 33, 'Термін дії пароля минув. Змініть пароль.'),
(125527, 7350, 33, 'Термін дії пароля минув на'),
(125528, 7351, 33, 'Термін дії пароля минув сьогодні. Змініть пароль.'),
(125529, 7353, 33, 'Ваші налаштування PostCalendar скинуті до налаштувань за-замовчуванням.'),
(125530, 7354, 33, 'Налаштування PostCalendar оновлені.'),
(125531, 7355, 33, 'Частота повторення повинна бути цілим числом.'),
(125532, 7356, 33, 'Частота повторення повинна бути, принаймні, 1.'),
(125533, 7357, 33, 'Ваша початкова дата пізніше кінцевої'),
(125534, 7358, 33, 'Ваша початкова дата недопустима'),
(125535, 7359, 33, 'Ваше представлення дало збій.'),
(125536, 7360, 33, 'рррр-мм-дд'),
(125537, 7361, 33, 'РРРР-ММ-ДД'),
(125538, 7362, 33, 'дата рррр-мм-дд прив''язана до цього документа'),
(125539, 7363, 33, 'дата рррр-мм-дд знищена'),
(125540, 7364, 33, 'дата народження рррр-мм-дд'),
(125541, 7365, 33, 'Дата народження рррр-мм-дд'),
(125542, 7366, 33, 'дата закінчення строку дії рррр-мм-дд'),
(125543, 7367, 33, 'Дата появи або госпіталізації рррр-мм-дд'),
(125544, 7368, 33, 'Дата появи, оперативного втручання або початку лікування рррр-мм-дд'),
(125545, 7369, 33, 'Дата отримання або передачі рррр-мм-дд'),
(125546, 7370, 33, 'Дата одужання або закінчення лікування рррр-мм-дд'),
(125547, 7371, 33, 'Дата повернення до гри рррр-мм-дд'),
(125548, 7372, 33, 'Дата надання допомоги рррр-мм-дд'),
(125549, 7373, 33, 'дата цього листа рррр-мм-дд'),
(125550, 7374, 33, 'дата повернення до гри рррр-мм-дд'),
(125551, 7375, 33, 'дата реєстрації рррр-мм-дд'),
(125552, 7376, 33, 'дата події або початку рррр-мм-дд'),
(125553, 7381, 33, 'рррр-мм-дд гг:хх:сс'),
(125554, 7382, 33, 'yyyy-mm-dd години(24):хвилини'),
(125555, 7383, 33, 'остання дата цієї події рррр-мм-дд'),
(125556, 7387, 33, 'нульовий'),
(125557, 7389, 33, 'Поштовий індекс'),
(125558, 7390, 33, 'Поштовий індекс'),
(125559, 7391, 33, 'Індекс/Країна'),
(125560, 7392, 33, 'Зулуська'),
(125561, 7393, 33, ' але було '),
(125562, 7394, 33, ' отримати доступ не вдалося.'),
(125563, 7395, 33, 'Дійсно потрібно видалити'),
(125564, 7396, 33, 'Препарат'),
(125565, 7397, 33, 'email-повідомлення не відправлені'),
(125566, 7398, 33, 'від'),
(125567, 7399, 33, 'повинна бути створена. '),
(125568, 7400, 33, 'повинна бути повторно відкрита.'),
(125569, 7401, 33, 'Анамнез'),
(125570, 7402, 33, 'це не число'),
(125571, 7403, 33, 'готово для повторного рахунку.'),
(125572, 7404, 33, 'LLL:'),
(125573, 7405, 33, 'партія'),
(125574, 7406, 33, 'Номер офіційного медичного посилання. '),
(125575, 7407, 33, 'мінімум'),
(125576, 7408, 33, 'не знайдено!'),
(125577, 7409, 33, 'Особливості багатьох браузерів можуть припускати вивід нижче краю екрану з раптовими ривками і довгі паузи по кілька секунд, коли здається, що робота завершилася збоєм. Це не так, через деякий час ви побачите вивід результату рядок за рядком. Він може бути послідовністю номерів, що з''являються нижче - це вказує, що навіть якщо нічого відобрати, обробка триває. Ці числа будуть перемежовуватися з вмістом рахунків і це нормально.'),
(125578, 7410, 33, 'термін дії призначення минув'),
(125579, 7411, 33, 'до'),
(125580, 7412, 33, 'оновлення дало збій, не в базі даних?'),
(125581, 7413, 33, 'маркований тільки як рахунок.'),
(125582, 7414, 33, 'було включено в чергу.'),
(125583, 7415, 33, '! Пішов без відвідування'),
(125584, 7416, 33, '" для коду'),
(125585, 7417, 33, '" означає ВІДМІЧЕНІ в параметрах налаштування PostCalendar!'),
(125586, 7418, 33, '# Вст. / Пошук проблеми'),
(125587, 7419, 33, '# З таблеток:'),
(125588, 7420, 33, '$'),
(125589, 7421, 33, '$ Індексовані'),
(125590, 7422, 33, '$ мітка (рррр-мм-дд) '),
(125591, 7423, 33, '%'),
(125592, 7424, 33, '% Скасоване < 24 години'),
(125593, 7425, 33, '% Скасоване < 24 години '),
(125594, 7426, 33, ''' немає, а має бути присутнім.'),
(125595, 7427, 33, '(% відповідає довільному рядку, _ відповідає довільному символу)'),
(125596, 7428, 33, '(утримуйте [ctrl] при кліку щоб вибрати кількох отримувачів)'),
(125597, 7429, 33, '(Назад)'),
(125598, 7430, 33, '(Клікніть для редагування)'),
(125599, 7431, 33, '(Доставка електронної пошти виконується негайно, в той час як автоматизований VOIP відправляється постачальнику послуг для подальшої обробки.)'),
(125600, 7432, 33, '(Детальніше)'),
(125601, 7433, 33, '(Новий Пацієнт)'),
(125602, 7434, 33, '(Записи і повноваження)'),
(125603, 7435, 33, '(Записи про пацієнта)'),
(125604, 7436, 33, '(Виберіть одну з, або введіть свою назву)'),
(125605, 7437, 33, 'Для зміни значення клікніть, утримуючи Shift, або виділіть мишкою'),
(125606, 7438, 33, '* З нагадуванням'),
(125607, 7439, 33, '** Перемістіть хірургію в проблеми!'),
(125608, 7440, 33, '* Обов''язкове'),
(125609, 7441, 33, '+ Карту витягнено'),
(125610, 7442, 33, '- Ні'),
(125611, 7443, 33, '-- Всі --'),
(125612, 7444, 33, '-- Виберіть роль --'),
(125613, 7445, 33, '.'),
(125614, 7446, 33, '0'),
(125615, 7447, 33, '0-10'),
(125616, 7448, 33, '0-24'),
(125617, 7451, 33, '1'),
(125618, 7452, 33, '1 = Північна Америка. Перерахування кодів інших країн див. на http://www.wtng.info/'),
(125619, 7453, 33, '1 день від тепер'),
(125620, 7454, 33, '1 місяць від тепер'),
(125621, 7455, 33, '1 тиждень від тепер'),
(125622, 7456, 33, '1 рік від тепер'),
(125623, 7457, 33, '1. Спокій 2. Холод протягом двох днів 3. Компресія, зберігайте пов''язку на місці, якщо не розвивається оніміння або блідість ноги 4. Підняте положення ноги і фіксація'),
(125624, 7458, 33, '11-14'),
(125625, 7459, 33, '12 hr'),
(125626, 7460, 33, '15-19'),
(125627, 7462, 33, '2'),
(125628, 7463, 33, '2 дні від тепер'),
(125629, 7464, 33, '2 місяці від тепер'),
(125630, 7465, 33, '2 тижні від тепер'),
(125631, 7466, 33, '2 роки від тепер'),
(125632, 7467, 33, '2-20 рокіів'),
(125633, 7468, 33, '20-24'),
(125634, 7477, 33, '2111-13'),
(125635, 7478, 33, '24 год.'),
(125636, 7479, 33, '25+'),
(125637, 7480, 33, '25-29'),
(125638, 7481, 33, 'другий'),
(125639, 7482, 33, '3 дні від тепер'),
(125640, 7483, 33, '3 місяці'),
(125641, 7484, 33, '3 місяці від тепер'),
(125642, 7485, 33, 'тричі на день'),
(125643, 7486, 33, '3 тижні від тепер'),
(125644, 7487, 33, '30-34'),
(125645, 7488, 33, '35-39'),
(125646, 7489, 33, 'третій'),
(125647, 7490, 33, '4 дні від тепер'),
(125648, 7491, 33, '4 місяці'),
(125649, 7492, 33, '4 місяці від тепер'),
(125650, 7493, 33, '4 рази в день'),
(125651, 7494, 33, '4 тижні від тепер'),
(125652, 7495, 33, '40-44'),
(125653, 7496, 33, '45+'),
(125654, 7497, 33, '465.9, URI'),
(125655, 7498, 33, '466.0, бронхіт, органонеспецифічні, гострий'),
(125656, 7499, 33, '486.0, пневмонія, гостра'),
(125657, 7500, 33, '491.21, ХОЗЛ, загострення'),
(125658, 7501, 33, '491.8, бронхіт, хронічний'),
(125659, 7502, 33, '493.92, астма, гострий Exac.'),
(125660, 7503, 33, '496.0, ХОЗЛ'),
(125661, 7504, 33, '4-й'),
(125662, 7505, 33, '5 днів від тепер'),
(125663, 7506, 33, '5 місяців від тепер'),
(125664, 7507, 33, '5 тижнів від тепер'),
(125665, 7508, 33, '519.7, Бронхоспазм'),
(125666, 7509, 33, '5-й'),
(125667, 7510, 33, '6 днів від тепер'),
(125668, 7511, 33, '6 місяців'),
(125669, 7512, 33, '6 місяців від тепер'),
(125670, 7513, 33, '6 тижнів від тепер'),
(125671, 7514, 33, '6-й'),
(125672, 7515, 33, '7 місяців від тепер'),
(125673, 7516, 33, '8 місяців від тепер'),
(125674, 7517, 33, '824.0 Перелом медіальної кісточки, закритий'),
(125675, 7518, 33, '824.2 Перелом латеральної щиколотки, закритий'),
(125676, 7519, 33, '824.6 Трехлодижечний перелом, закритий'),
(125677, 7520, 33, '825.32 Перелом човноподібної кістки (кісточка)'),
(125678, 7521, 33, '825.35 Перелом підстави п''ятої (5-й) метатарзальной кістки'),
(125679, 7522, 33, '845.00 Розтягування щиколотки NOS'),
(125680, 7523, 33, '845.01 Розтягування середньої (дельтоподібного) зв''язки'),
(125681, 7524, 33, '845.02 Розтягування малогомілкової п''яткової'),
(125682, 7525, 33, '9 місяців від тепер'),
(125683, 7526, 33, '99212 встановлений - нескладний'),
(125684, 7527, 33, '99213 встановлений - низької складності'),
(125685, 7528, 33, '< В кабінеті досліджень'),
(125686, 7529, 33, '> Перевірено'),
(125687, 7530, 33, '?'),
(125688, 7531, 33, '? Не показувати'),
(125689, 7532, 33, '@ Прибув'),
(125690, 7533, 33, '[Змінити вид]'),
(125691, 7534, 33, '[Дата останнього звернення]'),
(125692, 7535, 33, '[Днів від останнього звернення]'),
(125693, 7536, 33, '[EOBs]'),
(125694, 7537, 33, '[Експорт OFX]'),
(125695, 7538, 33, '[не рекомендовано]'),
(125696, 7539, 33, '[Кількість звернень]'),
(125697, 7540, 33, '[Звіти]'),
(125698, 7541, 33, '[Вибрати все]'),
(125699, 7542, 33, '[SQL-реєстрований]'),
(125700, 7543, 33, '[Запуск пакетної обробки]'),
(125701, 7544, 33, '[Переглянути журнал]'),
(125702, 7545, 33, '[Перегляд звіту для друку]'),
(125703, 7546, 33, '_PC_DUR_HOURS'),
(125704, 7547, 33, '_PC_DUR_MINUTES'),
(125705, 7548, 33, '_PC_LOCALE'),
(125706, 7549, 33, '~ Пізнє прибуття'),
(125707, 9, 34, 'লট নম্বর দরকার'),
(125708, 10, 34, 'লট নম্বর দরকার !'),
(125709, 11, 34, 'ছোট অক্ষর'),
(125710, 12, 34, 'নম্বর'),
(125711, 14, 34, 'এই ID র পেশেন্ট মজুত আছে'),
(125712, 15, 34, 'এই নামের পেশেন্ট মজুত আছে'),
(125713, 16, 34, 'এই আধার এর পেশেন্ট মজুত আছে'),
(125714, 21, 34, 'একটি স্পেশাল ক্যারেক্টার'),
(125715, 47, 34, 'Assignment গ্রহণ করুন'),
(125716, 48, 34, 'Payment যার জন্য গ্রহণ করা হল'),
(125717, 49, 34, 'Payment যার জন্য গ্রহণ করা হল'),
(125718, 50, 34, 'Assignment গ্রহণ করুন'),
(125719, 54, 34, 'Access বর্জিত'),
(125720, 55, 34, 'আপনি Access করতে পারবেন না'),
(125721, 56, 34, 'পেশেন্ট পোর্টাল এক্সেস করুন'),
(125722, 59, 34, 'Account নাম'),
(125723, 93, 34, 'অ্যাড'),
(125724, 94, 34, 'অ্যাড'),
(125725, 95, 34, 'অ্যাড'),
(125726, 96, 34, 'কম্পানি অ্যাড করুন'),
(125727, 98, 34, 'ফার্মেসী অ্যাড করুন'),
(125728, 101, 34, 'নতুন নোট অ্যাড করুন'),
(125729, 102, 34, 'নতুন অ্যাড করুন'),
(125730, 104, 34, 'বোতাম অ্যাড করুন'),
(125731, 116, 34, 'শাখা অ্যাড করুন'),
(125732, 119, 34, 'গ্রুপ অ্যাড করুন'),
(125733, 120, 34, 'ICD কোড অ্যাড করুন'),
(125734, 122, 34, 'আপনার অ্যাড করার অথরিটি নেই'),
(125735, 123, 34, 'Issue অ্যাড করুন'),
(125736, 125, 34, 'ভাষা অ্যাড করুন'),
(125737, 126, 34, 'নতুন অ্যাড করুন'),
(125738, 127, 34, 'নতুন অ্যাড করুন'),
(125739, 128, 34, 'নতুন ক্যাটাগরি অ্যাড করুন '),
(125740, 758, 34, 'ক্যালেন্ডার'),
(125741, 2498, 34, 'প্রথম নাম'),
(125742, 2499, 34, 'প্রথম নাম'),
(125743, 2500, 34, 'প্রথম নাম:'),
(125744, 2593, 34, 'শুক্র'),
(125745, 2594, 34, 'শুক্রবার'),
(125746, 2694, 34, 'গ্লোবাল'),
(125747, 2696, 34, 'গ্লোবাল ID'),
(125748, 2697, 34, 'গ্লোবাল সেটিং'),
(125749, 2698, 34, 'গ্লোবাল'),
(125750, 3325, 34, 'শেষ'),
(125751, 3328, 34, 'শেষ বিল ডেট:'),
(125752, 3333, 34, 'শেষ ভিসিট'),
(125753, 3343, 34, 'আগের মাস'),
(125754, 3344, 34, 'পদবী'),
(125755, 3345, 34, 'পদবী'),
(125756, 3346, 34, 'পদবী:'),
(125757, 3358, 34, 'শেষ ভিসিট'),
(125758, 3665, 34, 'মেসেজ পাঠানো হল'),
(125759, 3666, 34, 'মেসেজ এর দশা'),
(125760, 3669, 34, 'মেসেজ এর প্রকার'),
(125761, 3670, 34, 'মেসেজ:'),
(125762, 3671, 34, 'মেসেজ'),
(125763, 3672, 34, 'মেসেজ যা আজ পাঠানো হল'),
(125764, 3673, 34, 'পদ্ধতি'),
(125765, 3675, 34, 'outgoing ইমেল পাঠানোর পদ্ধতি'),
(125766, 3676, 34, 'বিনাশ এর পদ্ধতি'),
(125767, 3686, 34, 'মাঝের'),
(125768, 3687, 34, 'মাঝের নাম'),
(125769, 3688, 34, 'মাঝের নাম'),
(125770, 3708, 34, 'মিনিট'),
(125771, 3756, 34, 'সোমবার'),
(125772, 4589, 34, 'পেশেন্ট এর নাম'),
(125773, 4590, 34, 'পেশেন্ট এর নাম ও ঠিকানা'),
(125774, 4593, 34, 'পেশেন্ট এর নাম জরুরি'),
(125775, 4595, 34, 'পেশেন্ট নোট'),
(125776, 4596, 34, 'পেমেন্ট নোট প্রকার'),
(125777, 4597, 34, 'পেশেন্ট নোট'),
(125778, 4603, 34, 'পেশেন্ট পোর্টাল'),
(125779, 4629, 34, 'পেশেন্ট সামারি'),
(125780, 4633, 34, 'পেশেন্ট/ক্লায়েন্ট'),
(125781, 4634, 34, 'পেশেন্ট:'),
(125782, 4647, 34, 'পেমেন্ট'),
(125783, 5617, 34, 'শনি'),
(125784, 5619, 34, 'শনিবার'),
(125785, 5620, 34, 'সেভ'),
(125786, 5621, 34, 'সেভ'),
(125787, 5622, 34, 'সেভ এবং বন্ধ'),
(125788, 5624, 34, 'সেভ এবং দিয়ে দিন'),
(125789, 5625, 34, 'সেভ এবং চালান করুন'),
(125790, 5626, 34, 'নতুন হিসেবে সেভ করুন'),
(125791, 5627, 34, 'নতুন নোট হিসেবে সেভ করুন'),
(125792, 5628, 34, 'সার্টিফিকেট সেটিং সেভ করুন'),
(125793, 5629, 34, 'বদল সেভ করুন'),
(125794, 5630, 34, 'ফর্ম সেভ করুন'),
(125795, 6267, 34, 'রবিবার'),
(125796, 6631, 34, 'গুরুবার'),
(125797, 6843, 34, 'মঙ্গলবার'),
(125798, 7185, 34, 'বুধবার'),
(125799, 7528, 34, '< Exam রুমে আছে'),
(125800, 7529, 34, '> বেরিয়ে গেছে'),
(125801, 7531, 34, '? পেশেন্ট আসে নি'),
(125802, 7532, 34, '@ পৌঁছেগেছে'),
(125803, 7533, 34, '[ভিউ বদলান]'),
(125804, 7534, 34, '[শেষ Encounter এর তারিখ]'),
(125805, 7535, 34, '[শেষ Encounter থেকে দিন]'),
(125806, 7537, 34, '[OFX এক্সপোর্ট করুন]'),
(125807, 7538, 34, '[recommended নয়]'),
(125808, 7539, 34, '[Encounter এর সংখ্যা]'),
(125809, 7540, 34, '[রিপোর্ট]'),
(125810, 7541, 34, '[সব সিলেক্ট করুন]'),
(125811, 7543, 34, '[ব্যাচ প্রসেসিং আরম্ভ করুন]'),
(125812, 7544, 34, '[লগ দেখুন]'),
(125813, 7545, 34, '[Printable রিপোর্ট দেখুন]'),
(125814, 7549, 34, '~ দেরিতে এসেছে'),
(125815, 1, 35, 'A'),
(125816, 2, 35, 'Tšeki või nõude number maksmise tuvastamiseks'),
(125817, 3, 35, 'Admin kasutaja kliendisertifikaat'),
(125818, 7, 35, 'Edasimüüja on vajalik'),
(125819, 8, 35, 'Selle visiidi jaoks peaks lisama GCAC vormi'),
(125820, 9, 35, 'Partiinumber on vajalik'),
(125821, 10, 35, 'Partiinumber on hädavajalik!'),
(125822, 11, 35, 'Väiketäht'),
(125823, 12, 35, 'Number'),
(125824, 14, 35, 'Sellise ID-ga patsient on juba olemas'),
(125825, 15, 35, 'Sellise nimega patsient on juba olemas'),
(125826, 16, 35, 'Sellise SS numbriga patsient juba eksisteerib'),
(125827, 18, 35, 'Positiivne number näitab nii mitu eelnevat visiiti Patsiendi Koondlehe Moodulis'),
(125828, 19, 35, 'Suunava allika võib määratleda iga visiidi jaoks'),
(125829, 20, 35, 'Vajalik on seotud IPPF kood!'),
(125830, 21, 35, 'spetsiaalsümbol'),
(125831, 22, 35, 'Unikaalne väärtus selle välja jaoks, pole kasutajale nähtav'),
(125832, 24, 35, '?enne sööki'),
(125833, 25, 35, 'enne lõunat'),
(125834, 26, 35, 'dummy'),
(125835, 27, 35, 'Aadressiraamat'),
(125836, 28, 35, 'Lühend'),
(125837, 29, 35, 'Abstsess:'),
(125838, 30, 35, 'Abdominaalne'),
(125839, 31, 35, 'On võimeline kandma raskust neli (4) sammu edasi:'),
(125840, 32, 35, 'Ebanormaalne'),
(125841, 33, 35, 'Ebanormaalne 1'),
(125842, 34, 35, 'Ebanormaalne'),
(125843, 35, 35, 'Ebanormaalne vereanalüüs'),
(125844, 36, 35, 'Ebanormaalne juuksekasv'),
(125845, 37, 35, 'Ebanormaalne mammogramm'),
(125846, 39, 35, 'Abort'),
(125847, 40, 35, 'Abordiprobleemid'),
(125848, 41, 35, 'Abordi meetod'),
(125849, 42, 35, 'Abordiga seotud kategooriad'),
(125850, 43, 35, 'Abordid'),
(125851, 44, 35, 'Teave kalendri kohta'),
(125852, 46, 35, '?Puudused Diagnoosi järgi'),
(125853, 47, 35, '?Nõustu Ülesandega'),
(125854, 48, 35, 'Aksepteeri makse'),
(125855, 49, 35, 'Aksepteeri makse'),
(125856, 50, 35, '?Nõustub ülesandega'),
(125857, 51, 35, 'Ligipääsu kontroll'),
(125858, 52, 35, 'Ligipääsu kontrolli loendi administreerimine'),
(125859, 54, 35, 'Ligipääs keelatud'),
(125860, 55, 35, 'Ligipääs Ei ole Lubatud'),
(125861, 56, 35, 'Suundu oma patsiendi portaali'),
(125862, 59, 35, 'Konto nimi'),
(125863, 62, 35, 'Arvepidamine'),
(125864, 64, 35, 'Valud'),
(125865, 65, 35, 'Küsiti kinnitust (ISA14)'),
(125866, 66, 35, 'Kinnitused, Litsensid ja Sertifikaadid'),
(125867, 67, 35, 'ACL(Ligipääsu kontrolli loend)'),
(125868, 68, 35, 'ACL administreerimine'),
(125869, 69, 35, 'ACL administreerimine pole lubatud'),
(125870, 71, 35, 'Akne'),
(125871, 72, 35, 'Leping'),
(125872, 73, 35, 'Lepingu koostamise kuupäev'),
(125873, 74, 35, 'Tegevus'),
(125874, 75, 35, 'Tegevused'),
(125875, 77, 35, 'Aktiveeri CCR/CCD raport'),
(125876, 78, 35, 'Aktiivne'),
(125877, 79, 35, 'Aktiivne hoiatus'),
(125878, 80, 35, 'Aktiivsete hoiatuste reeglid'),
(125879, 81, 35, 'Aktiivsed hoiatused/meeldetuletused'),
(125880, 82, 35, 'Aktiivne Visiit'),
(125881, 84, 35, 'Aktiivsed loendid'),
(125882, 85, 35, 'Aktiivne patsient'),
(125883, 86, 35, 'Aktiivsed ruumid'),
(125884, 87, 35, 'Tegevus'),
(125885, 88, 35, 'Tegevuse tüüp'),
(125886, 90, 35, 'Akuutne mürgistus/Eemaldamine'),
(125887, 92, 35, 'Akuutne või krooniline'),
(125888, 93, 35, 'lisa'),
(125889, 94, 35, 'Lisa'),
(125890, 95, 35, 'LISA'),
(125891, 96, 35, 'Lisa firma'),
(125892, 98, 35, 'Lisa apteek'),
(125893, 100, 35, 'lisa juht '),
(125894, 101, 35, 'Lisa uue märkusena'),
(125895, 102, 35, 'Lisa kui uus'),
(125896, 104, 35, 'Lisa nuppe'),
(125897, 105, 35, 'Lisa nuppe spetssümbolite, -teksti kohta mida näidatakse tekstiredaktori kohal hiirevajutusega teksti sisestamiseks'),
(125898, 106, 35, 'Lisa Kategooria'),
(125899, 107, 35, 'Lisa Konstant'),
(125900, 108, 35, 'Lisa Kontekst'),
(125901, 109, 35, 'Lisa Lisatasud'),
(125902, 110, 35, 'Lisa Kriteeriumid'),
(125903, 111, 35, 'Lisa kohandatud Nupp'),
(125904, 112, 35, 'Lisa Diagnoos'),
(125905, 113, 35, 'Lisa Ravim'),
(125906, 114, 35, 'Lisa Visiit'),
(125907, 115, 35, 'Lisa visiit/märkmed'),
(125908, 116, 35, 'Lisa asutus'),
(125909, 117, 35, 'Lisa Väli'),
(125910, 118, 35, 'Lisa järgmised read Apache serveri konfiguratsioonifaili'),
(125911, 119, 35, 'Lisa Rühm'),
(125912, 120, 35, 'Lisa ICD kood'),
(125913, 121, 35, 'Lisa Immuniseerimine'),
(125914, 122, 35, 'Lisamine pole lubatud!'),
(125915, 123, 35, '?Lisa probleem'),
(125916, 125, 35, 'Lisa keel'),
(125917, 126, 35, 'Lisa uus'),
(125918, 127, 35, 'Lisa uus'),
(125919, 128, 35, 'Lisa uus kategooria '),
(125920, 129, 35, 'Lisa uued sertifikaadid Apache serveri konfiguratsioonifaili'),
(125921, 132, 35, 'Lisa uus rühm'),
(125922, 134, 35, 'Lisa uus seeria ja tegevus'),
(125923, 135, 35, 'Lisa uus märkus'),
(125924, 136, 35, 'Lisa uus märkus'),
(125925, 137, 35, 'Lisa uus partner'),
(125926, 140, 35, 'Lisa märge'),
(125927, 141, 35, 'Lisa Patsiendikirje'),
(125928, 142, 35, 'Lisa retsept'),
(125929, 143, 35, 'Lisa Protseduur'),
(125930, 144, 35, 'Lisa Saatja number'),
(125931, 145, 35, 'Lisa Rehabilitatsioon'),
(125932, 146, 35, 'Lisa Reegel'),
(125933, 147, 35, 'Lisa'),
(125934, 148, 35, 'Lisa Ravimiteloendisse'),
(125935, 149, 35, 'Lisa ülemine tase'),
(125936, 150, 35, 'Lisa tegevus'),
(125937, 151, 35, 'Lisa Kasutaja'),
(125938, 152, 35, 'Lisa kasutaja rühma'),
(125939, 153, 35, 'Lisa/Muuda eRx'),
(125940, 154, 35, 'Lisa/Muuda Patsiendi tegevust'),
(125941, 155, 35, 'lisatud'),
(125942, 156, 35, 'Demograafiliste andmete lisamine keelatud'),
(125943, 158, 35, 'Addisoni Sündroom'),
(125944, 159, 35, 'Addisoni Sündroom'),
(125945, 160, 35, 'Lisaatribuudid'),
(125946, 161, 35, 'Lisadiagnoos:'),
(125947, 162, 35, 'Lisaanamnees'),
(125948, 163, 35, 'Lisaandmed haiguslukku'),
(125949, 164, 35, 'Lisainfo'),
(125950, 165, 35, 'Lisalaborid'),
(125951, 166, 35, 'Lisamärkmed'),
(125952, 167, 35, 'Lisamärkmed selle tulemuse kohta või soovitused'),
(125953, 168, 35, 'Lisamärkmed:'),
(125954, 169, 35, 'Lisamärkmed: '),
(125955, 170, 35, 'Lisamärkmed röntgenpildile:'),
(125956, 172, 35, 'ainult lisamine'),
(125957, 173, 35, 'Aadr.Rmt.'),
(125958, 174, 35, 'Aadr.Raamat'),
(125959, 175, 35, 'Aadress'),
(125960, 178, 35, 'Aadressiraamat'),
(125961, 179, 35, 'Aadressiraamatu sissekanne seda protseduuri teostava ettevõtte kohta'),
(125962, 180, 35, 'Aadressiraamatu sissekanne edasimüüja kohta'),
(125963, 181, 35, 'Aadressiraamatu sissekanne tootja kohta'),
(125964, 182, 35, 'Aadressiraamatu tüübid'),
(125965, 187, 35, 'Aadress1'),
(125966, 188, 35, 'Aadress2'),
(125967, 189, 35, 'AADRESS'),
(125968, 190, 35, 'Muuda'),
(125969, 191, 35, 'Muuda kogust'),
(125970, 192, 35, 'Muuda'),
(125971, 193, 35, 'Muutmine'),
(125972, 194, 35, 'Koguse muutmine'),
(125973, 195, 35, 'Muutmise põhjused'),
(125974, 196, 35, 'Koodi muutmise väärtus '),
(125975, 197, 35, 'Muutmised'),
(125976, 198, 35, 'Admini muutmine'),
(125977, 199, 35, 'Admin'),
(125978, 200, 35, 'Admini E-mail'),
(125979, 201, 35, 'Manustamisviis'),
(125980, 202, 35, 'Manustatud'),
(125981, 203, 35, 'Manustas'),
(125982, 205, 35, 'Manustamiskoht'),
(125983, 206, 35, 'Administreerimine'),
(125984, 207, 35, 'Admini Leht'),
(125985, 208, 35, 'Administraatorid'),
(125986, 209, 35, 'Administraatorid saavad kõike teha'),
(125987, 210, 35, 'Tunnistuse Kuupäev'),
(125988, 212, 35, 'Täiskasvanu kaalujälgimine'),
(125989, 213, 35, 'Täiskasvanu kaalujälgimine (CQM)'),
(125990, 214, 35, 'Eelnev juhtnöör'),
(125991, 215, 35, 'Eelnevad juhtnöörid'),
(125992, 216, 35, 'Eelnevate juhtnööride hoiatus'),
(125993, 218, 35, 'Edasijõudnud'),
(125994, 219, 35, 'Nõuanne'),
(125995, 221, 35, 'Mõjutada normaalset'),
(125996, 223, 35, 'Peale tunde helistamisi'),
(125997, 225, 35, 'Pärast ülaltoodud konfigureerimiste tegemist impordi admini kliendisertifikaat browserisse ja tee Apache serverile restart (parool jäta tühjaks)'),
(125998, 226, 35, 'Pärast PDF salvestamist vajutage vigade kontrollimiseks [Vaata Logi]'),
(125999, 227, 35, 'Pärast TEXT faili(de) salvestamist vajutage vigade kontrollimiseks [Vaata Logi]'),
(126000, 228, 35, 'Pärast enda paketi salvestamist vajutage vigade kontrollimiseks [Vaata Logi]'),
(126001, 230, 35, 'Pärast õiget info sisestust vajuta nuppu Salvesta'),
(126002, 232, 35, 'Hoolitsusjärgne Planeerimine'),
(126003, 233, 35, 'Veelkord'),
(126004, 234, 35, 'Vanus'),
(126005, 235, 35, 'Vanus'),
(126006, 236, 35, 'Vanuse kategooria'),
(126007, 237, 35, 'Vanus asub piiridest väljas'),
(126008, 238, 35, 'Vanuse Näitamise Formaat'),
(126009, 239, 35, 'Vanuse formaat ei sobi ''vanus alates'' jaoks'),
(126010, 240, 35, 'Vanuse formaat ei sobi ''vanus kuni'' jaoks'),
(126011, 241, 35, 'Vanus alates'),
(126012, 242, 35, 'Vanus aastates Näitamise Formaadi Muutmiseks'),
(126013, 243, 35, 'Vanus max'),
(126014, 244, 35, 'Vanus min'),
(126015, 245, 35, 'Vanusepiirid'),
(126016, 247, 35, 'Vananemise tulbad:'),
(126017, 249, 35, 'Albaanlane'),
(126018, 250, 35, 'Alkohol'),
(126019, 251, 35, 'Alkoholi tarbimine'),
(126020, 253, 35, 'Hoiatuste arv'),
(126021, 255, 35, 'Hoiatused'),
(126022, 258, 35, 'ALEUT'),
(126023, 259, 35, 'Kõik'),
(126024, 260, 35, 'KÕIK'),
(126025, 261, 35, 'Kõik (koondatud formaat A)'),
(126026, 262, 35, 'Kõik (koondatud formaat B)'),
(126027, 263, 35, 'Kõik (kumulatiivne)'),
(126028, 266, 35, 'Kõik kategooriad'),
(126029, 268, 35, 'Kõik koodid'),
(126030, 269, 35, 'Terve päev'),
(126031, 270, 35, 'Terve päeva sündmus'),
(126032, 271, 35, 'Kõik demograafilised väljad koos otsingu ja duplikaatide kontrolliga'),
(126033, 272, 35, 'Kõik asutused'),
(126034, 273, 35, 'Kõik kahjustused/probleemid/häired'),
(126035, 274, 35, 'Kõik keeled on lubatud'),
(126036, 276, 35, 'Terve eesnimi või selle osa'),
(126037, 277, 35, 'Terve perekonnanimi või selle osa'),
(126038, 278, 35, 'Terve organisatsioon või selle osa'),
(126039, 280, 35, 'Kõik tooted'),
(126040, 281, 35, 'Kõik suunajad'),
(126041, 282, 35, 'Kõik läbi vaadatud ja negatiivsed:'),
(126042, 283, 35, 'Kõik teemad'),
(126043, 284, 35, 'Kõik kasutajad'),
(126044, 285, 35, 'Allergiline'),
(126045, 286, 35, 'Allergiad'),
(126046, 287, 35, 'Allergiad:'),
(126047, 288, 35, 'Allergia'),
(126048, 289, 35, 'Allergia import lõpetati edukalt'),
(126049, 290, 35, 'Allergia Probleemide Loend'),
(126050, 291, 35, 'Allergiline reaktsioon'),
(126051, 294, 35, 'Tuvasta'),
(126052, 295, 35, 'Luba'),
(126053, 296, 35, 'Luba sisselogimise menüüs kõikide võimalike keelte valik'),
(126054, 297, 35, 'Luba diagnoose sisaldavate nõuete loomist kuid ilma protseduuride või hindadeta. Enamus kliinikuid ei soovi seda.'),
(126055, 298, 35, 'Luba silutav keel'),
(126056, 299, 35, 'Luba e-mail'),
(126057, 300, 35, 'Luba e-maili teated?'),
(126058, 301, 35, 'Luba e-mail?'),
(126059, 302, 35, 'Luba visiidinõuded'),
(126060, 303, 35, 'Luba tervisealane infovahetus'),
(126061, 304, 35, 'Luba immuniseerimiste info jagamine'),
(126062, 305, 35, 'Luba immuniseerimste registri kasutamine'),
(126063, 306, 35, 'Luba teated posti teel'),
(126064, 308, 35, 'Luba patsientide portaal'),
(126065, 309, 35, 'Luba SMS saatmine'),
(126066, 310, 35, 'Luba SMS (tekstisõnumite) saatmine?'),
(126067, 311, 35, 'Luba saadetud juhtumite kohene muutmine aktiivseks?'),
(126068, 312, 35, 'Luba teated telefoni teel?'),
(126069, 313, 35, 'Luba kasutajatel luua globaalseid sündmusi'),
(126070, 314, 35, 'Luba kasutajatel luua personaalseid kalendreid'),
(126071, 315, 35, 'Luba häälsõnumid'),
(126072, 316, 35, 'Lubatud'),
(126073, 317, 35, 'Lubatud keeled'),
(126074, 318, 35, 'Lubatud(c)'),
(126075, 323, 35, 'juba olemas'),
(126076, 324, 35, 'juba olemas.'),
(126077, 325, 35, 'On juba kasutusel, vali teistsugune tähistus'),
(126078, 326, 35, 'On juba kasutusel, vali teistsugune pealkiri'),
(126079, 327, 35, 'Alt aadress'),
(126080, 328, 35, 'muuda'),
(126081, 329, 35, 'Alternatiivis võid kasutada otsingulehte enda maksja või arvelduskoja poolt antud elektroonse ülekande (X12 835) faili üleslaadimiseks. Saad teha seda vajutades Otsi nuppu ja valides üleslaadmiseks faili, seejärel vajutades Otsing toimub üleslaadimine ning vastavate arvete näitamine. Sel juhul teised ülalmainitud parameetrid ei rakendu ja neid ignoreeritaks. Üleslaadimine salvestab küll faili kuid ei töötle selle sisu – seda saab teha eraldi nagu allpool kirjeldatud.'),
(126082, 330, 35, 'enne lõunat'),
(126083, 331, 35, 'AM programm'),
(126084, 332, 35, 'AMC'),
(126085, 333, 35, 'AMC jälgimine'),
(126086, 338, 35, 'Muuda olemasolevat märget'),
(126087, 343, 35, 'Ameerika indiaanlane'),
(126088, 344, 35, 'Ameerika indiaanlane või Alaska pärismaalane'),
(126089, 345, 35, 'AMEX'),
(126090, 346, 35, 'Amhaar'),
(126091, 347, 35, 'Summa'),
(126092, 348, 35, 'Manustatud Kogus'),
(126093, 349, 35, 'Summa suurus'),
(126094, 350, 35, 'Möödunud bilansi summa'),
(126095, 351, 35, 'Hulk selle visiidi jaoks'),
(126096, 352, 35, 'Makstud summa'),
(126097, 353, 35, 'Hulk:'),
(126098, 354, 35, 'Arve summa'),
(126099, 355, 35, 'Korduvate ürituste jaoks peab lõpuaeg olema hiljem kui algusaeg'),
(126100, 357, 35, 'LibreEHR veebikataloogi puu dumpingul tekkis mingi viga'),
(126101, 358, 35, 'phpGACL veebikataloogi puu dumpingul tekkis mingi viga'),
(126102, 359, 35, 'SQL-Ledger veebikataloogi puu dumpingul tekkis mingi viga'),
(126103, 360, 35, 'Loodi ja lingati osaline GCAC probleem. Hiljem peab keegi selle lõpetama.'),
(126104, 362, 35, 'Tekkis mingi ootamatu viga.'),
(126105, 363, 35, 'Suurtäht'),
(126106, 365, 35, 'Ja'),
(126107, 366, 35, 'JA'),
(126108, 367, 35, 'ja'),
(126109, 368, 35, 'ja '),
(126110, 369, 35, 'ja kõik alamandmed? See tegevus logitakse.'),
(126111, 370, 35, 'ja modifikaator'),
(126112, 371, 35, 'ja töödeldi.'),
(126113, 372, 35, 'ja taaskäivita Apache server.'),
(126114, 373, 35, 'ja põhjus on'),
(126115, 374, 35, 'Aneemia'),
(126116, 375, 35, 'Pahkluu'),
(126117, 376, 35, 'Pahkluu + kand'),
(126118, 377, 35, 'Pahkluu uuringu vorm'),
(126119, 378, 35, 'Pahkluu probleemid'),
(126120, 379, 35, 'Ankylosing Spondylitis (selgroo krooniline põletik)'),
(126121, 380, 35, 'Ankylosing Spondylitis'),
(126122, 381, 35, 'Anoreksia'),
(126123, 382, 35, 'Teine asi mida saad kirjutamisaknas teha on sekundaarse arve küsimine. Kui valid enne salvestamist selle valikukasti, siis algne arve taasavatakse ja kutsutakse Maksmise lehele ning kasutatakse järgmises arvekoostamise protsessis'),
(126124, 383, 35, 'eelnevalt'),
(126125, 384, 35, 'Pärak normis, ei esine rektaalset tundlikkust/väljasopistust'),
(126126, 385, 35, 'Ärevus'),
(126127, 386, 35, 'Igasugune'),
(126128, 387, 35, 'Igasugune kategooria'),
(126129, 388, 35, 'Igasugune soovitud kood või selle kirjeldus'),
(126130, 389, 35, 'Igasugune soovitud eriala osa'),
(126131, 390, 35, 'Igasugune ravimi id osa või vaktsineerimise nimetus'),
(126132, 391, 35, 'Igasugune vaktsineerimise id osa või vaktsineerimise nimetus'),
(126133, 392, 35, 'Igasugune patsiendi nime osa või “perenimi,eesnimi“, või “X-Y“'),
(126134, 393, 35, 'Igasugune muu Asjakohane Informatsioon'),
(126135, 394, 35, 'API võti SMS värava jaoks.'),
(126136, 395, 35, 'Apnea'),
(126137, 396, 35, 'Välimus'),
(126138, 397, 35, 'Välimus:'),
(126139, 398, 35, 'Lisa see märkus'),
(126140, 399, 35, 'Lisa olemasolevale märkusele'),
(126141, 400, 35, 'Lisa sellele märkusele'),
(126142, 401, 35, 'Lisa Sellele Märkusele'),
(126143, 402, 35, 'Apendektoomia'),
(126144, 404, 35, 'Sobivad Patsiendid'),
(126145, 405, 35, 'Rakendus'),
(126146, 406, 35, 'Sisselogimisakna rakenduse nimi ja põhiakna pealkiri.'),
(126147, 407, 35, 'Rakenduse vastuvõtja kood (GS03 – kui on tühi kasutatakse ISA08)'),
(126148, 408, 35, 'Rakenduse saatja kood (GS02)'),
(126149, 409, 35, 'Rakenduse pealkiri'),
(126150, 410, 35, 'Kasutatakse Elunäitajate vormi ja Kasvukaardi puhul'),
(126151, 411, 35, 'Lisandub Elunäitajate vormile'),
(126152, 412, 35, 'Lisa muutused ainult sellele toimingele, sellele ja kõigile järgmistele juhtumitele või kõigile juhtumitele?'),
(126153, 413, 35, 'lisa mõjutatud alale'),
(126154, 414, 35, 'lisa nahale'),
(126155, 415, 35, 'Lisamine-panemine'),
(126156, 416, 35, 'Lisa saidile parandus'),
(126157, 417, 35, 'Visiidiaeg'),
(126158, 418, 35, 'Visiidi kuupäev'),
(126159, 419, 35, 'Visiidi näitamisviis'),
(126160, 420, 35, 'Visiidi meeldetuletuse reegel'),
(126161, 421, 35, 'Visiidi seis'),
(126162, 422, 35, 'Visiidi seisud'),
(126163, 423, 35, 'Visiidiaeg perioodil'),
(126164, 424, 35, 'Visiidi/Toimingu värvus'),
(126165, 425, 35, 'Visiidid'),
(126166, 426, 35, 'Visiidid (kirjutamine pole vajalik)'),
(126167, 427, 35, 'Visiidid (kirjutamine, wsome pole vajalik)'),
(126168, 430, 35, 'Visiidid ja Pöördumised'),
(126169, 431, 35, 'Visiitide raport'),
(126170, 432, 35, 'Visiitide-pöördumiste raport'),
(126171, 434, 35, 'Kinnita'),
(126172, 436, 35, 'Kinnitatud'),
(126173, 437, 35, 'Kinnitatud Toimingute administreerimine'),
(126174, 440, 35, 'Vis-Toim'),
(126175, 441, 35, 'Vis.'),
(126176, 442, 35, 'Apr'),
(126177, 443, 35, 'Aprill'),
(126178, 444, 35, 'Araabia'),
(126179, 446, 35, 'Arhiiv'),
(126180, 447, 35, 'Kas ligipääsu kontrollrühma nimesid tõlgitakse?'),
(126181, 448, 35, 'Kas visiitide kategoorianimesid tõlgitakse?'),
(126182, 449, 35, 'Kas dokumentide kategoorianimesid tõlgitakse?'),
(126183, 450, 35, 'Kas selle tüübi jaoks arve koostatakse?'),
(126184, 451, 35, 'Kas patsiendi märkuste pealkirjad tõlgitakse?'),
(126185, 452, 35, 'Kas koodid säilitatakse väliste SQL tabelites (0-Ei,1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2))?'),
(126186, 453, 35, 'Kas oled valmis selle visiidi jaoks koostama täiesti uue GCAC probleemi?'),
(126187, 454, 35, 'Soovid kindlasti tänaseks postitada?'),
(126188, 455, 35, 'Soovid kindlasti need toimingud kinnitada?'),
(126189, 457, 35, 'Soovid kindlasti selle vormi täielikult eemaldada?'),
(126190, 459, 35, 'Soovid kindlasti selle teate kustutada?'),
(126191, 460, 35, 'Soovid kindlasti seda toimingut kustutada?'),
(126192, 461, 35, 'Soovid kindlasti selle asja andmebaasist kustutada?'),
(126193, 462, 35, 'Soovid kindlasti selle märkuse kustutada?'),
(126194, 464, 35, 'Soovid kindlasti neid toiminguid muuta?'),
(126195, 465, 35, 'Soovid kindlasti need toimingud ära peita?'),
(126196, 467, 35, 'Soovid kindlasti neid toiminguid vaadata?'),
(126197, 468, 35, 'Soovid kindlasti kustutada rühma mille nimeks on'),
(126198, 469, 35, 'Soovid kindlasti kogu loendi kustutada?'),
(126199, 470, 35, 'Soovid kindlasti kustutada selle väja'),
(126200, 471, 35, 'Soovid kindlasti valitud väljad kustutada?'),
(126201, 472, 35, 'Oled kindel nende tegevuste jätkamise soovis?'),
(126202, 473, 35, 'Piirkonda pole valitud'),
(126203, 474, 35, 'Käsi'),
(126204, 475, 35, 'Armeenlane'),
(126205, 477, 35, 'Arütmia'),
(126206, 478, 35, 'Artriit'),
(126207, 479, 35, 'Artriit / degeneratiivne liigeste haigus'),
(126208, 480, 35, 'Artriit / degeneratiivne liigeste haigus'),
(126209, 481, 35, 'nagu'),
(126210, 482, 35, 'Nagu'),
(126211, 484, 35, 'Asiaat'),
(126212, 487, 35, 'Hindamine'),
(126213, 488, 35, 'Määratud'),
(126214, 489, 35, 'Assistent'),
(126215, 490, 35, 'Astma'),
(126216, 491, 35, 'juures'),
(126217, 492, 35, 'Vajalik on vähemalt üks otsinguparameeter kui valid Kõik.'),
(126218, 493, 35, 'Randme juures'),
(126219, 494, 35, 'Randme juures:'),
(126220, 495, 35, 'Kergejõustiku meeskond'),
(126221, 496, 35, 'Kergejõustiku Meeskond'),
(126222, 497, 35, 'Sport/Trauma'),
(126223, 498, 35, 'ATNA auditi CA sertifikaat'),
(126224, 499, 35, 'ATNA auditi vastuvõtja'),
(126225, 500, 35, 'ATNA auditi lokaalne sertifikaat'),
(126226, 501, 35, 'ATNA auditi port'),
(126227, 503, 35, 'Tähelepanu'),
(126228, 504, 35, 'NB'),
(126229, 509, 35, 'Kopeerimiste logimise audit'),
(126230, 510, 35, 'Mitmesuguste logimiste audit'),
(126231, 511, 35, 'Logimiskorra audit'),
(126232, 512, 35, 'Patsiendi haigusloo logimise audit'),
(126233, 513, 35, 'Planeerimise logimise audit'),
(126234, 514, 35, 'Turvalisuse haldamise logimise audit'),
(126235, 515, 35, 'SELECT päringu logimise audit'),
(126236, 516, 35, 'Aug'),
(126237, 517, 35, 'August'),
(126238, 519, 35, 'Autoris'),
(126239, 520, 35, 'Autoris/märkmed'),
(126240, 523, 35, 'Autoriseerimise rühm'),
(126241, 524, 35, 'Autoriseerimise seis'),
(126242, 525, 35, 'Autoriseerimised'),
(126243, 526, 35, 'Luba'),
(126244, 527, 35, 'Luba – igasugused kohtumised'),
(126245, 528, 35, 'Luba – minu kohtumised'),
(126246, 529, 35, 'Authorize.net'),
(126247, 530, 35, 'Lubatud'),
(126248, 531, 35, 'Lubatud ainult'),
(126249, 532, 35, 'Saada automaatselt'),
(126250, 535, 35, 'Loo automaatselt uued kohtumised'),
(126251, 536, 35, 'Automaatselt loodud'),
(126252, 537, 35, 'Automaatsed Väärtuste Arvutamised (AMC)'),
(126253, 542, 35, 'Automaatse Väärtuste Arvutamise (AMC) Jälgimine'),
(126254, 543, 35, 'Automaatsed Väärtused (AMC)'),
(126255, 544, 35, 'Automaatne'),
(126256, 546, 35, 'Automaatselt loo uus kohtumine kui visiidi sesi on märgitud „@“ (kohal).'),
(126257, 549, 35, 'Kiirabiauto'),
(126258, 550, 35, 'automaatselt salvestatud'),
(126259, 551, 35, 'Võimalikud kategooriad'),
(126260, 552, 35, 'Võimalikud ajad'),
(126261, 557, 35, 'Kuu keskmine'),
(126262, 558, 35, 'Luumurd / lahtine luumurd'),
(126263, 559, 35, 'Laterale malleoluse luumurd'),
(126264, 560, 35, 'Medial malleoluse luumurd '),
(126265, 561, 35, 'Informeeritusel põhinev'),
(126266, 562, 35, 'Axillaarne'),
(126267, 565, 35, '2x päevas'),
(126268, 566, 35, 'Tagasi'),
(126269, 567, 35, 'tagasi'),
(126270, 568, 35, 'Tagasi kaheksa visiiti'),
(126271, 569, 35, 'Tagasi üksteist visiiti'),
(126272, 570, 35, 'Tagasi viis visiiti'),
(126273, 571, 35, 'Tagasi neli visiiti'),
(126274, 572, 35, 'Tagasi üheksa visiiti'),
(126275, 573, 35, 'Tagasi üks visiit'),
(126276, 574, 35, 'Seljavalu'),
(126277, 575, 35, 'Seljaprobleemid'),
(126278, 576, 35, 'Tagasi seitse visiiti'),
(126279, 577, 35, 'Tagasi kuus visiiti'),
(126280, 578, 35, 'Seljakirurgia'),
(126281, 579, 35, 'Tagasi kümme visiiti'),
(126282, 580, 35, 'Tagasi kolm visiiti'),
(126283, 581, 35, 'Tagasi Admini lehele'),
(126284, 584, 35, 'Tagasi Patsiendi juurde'),
(126285, 585, 35, 'Tagasi Kasutajate juurde'),
(126286, 586, 35, 'Tagasi Vaatesse'),
(126287, 587, 35, 'Tagasi kaksteist visiiti'),
(126288, 588, 35, 'Tagasi kaks visiiti'),
(126289, 589, 35, 'Taustateenused'),
(126290, 590, 35, 'Reservkoopia'),
(126291, 591, 35, 'Reservkoopia fail on loodud. Nüüd saadetakse allalaadimine.'),
(126292, 593, 35, 'Reservkoopia saadeti edukalt'),
(126293, 594, 35, 'Kattetta tshekk'),
(126294, 595, 35, 'Lootusetu võlg'),
(126295, 596, 35, 'Bahasa Indoneesia'),
(126296, 597, 35, 'Bal'),
(126297, 598, 35, 'Saldo (jääk)'),
(126298, 599, 35, 'Saldo (jääk)'),
(126299, 600, 35, 'dummy'),
(126300, 601, 35, 'Laenujääk'),
(126301, 603, 35, 'Pangaveksel'),
(126302, 607, 35, 'Viienda (5.) metarsaali alus'),
(126303, 608, 35, 'Viienda (5.) metarsaali alus:'),
(126304, 611, 35, 'Nõuete Pakett'),
(126305, 612, 35, 'Kommunikeerumisvahendite pakett'),
(126306, 613, 35, 'Maksesissekannete pakett'),
(126307, 614, 35, 'Maksetepakett'),
(126308, 615, 35, 'Alustati paketi töötlemist; see võib kaua kesta'),
(126309, 616, 35, 'Tulemuste pakett'),
(126310, 617, 35, 'BatchCom'),
(126311, 619, 35, 'kuna selline id puudub.'),
(126312, 620, 35, 'Algus'),
(126313, 621, 35, 'Alguskuupäev'),
(126314, 623, 35, 'Teenuse alustamiskuupäev yyyy-mm-dd'),
(126315, 624, 35, 'Kalendri toimingute päeva alustamistund'),
(126316, 626, 35, 'Röhitsused'),
(126317, 628, 35, 'Bengali'),
(126318, 630, 35, 'vahel'),
(126319, 633, 35, 'Bilateraalne'),
(126320, 634, 35, 'Bilateraalne:'),
(126321, 636, 35, 'Arveldamise kuupäev:'),
(126322, 637, 35, 'Arve/arveldamine'),
(126323, 638, 35, 'Arveldatud'),
(126324, 640, 35, 'Arveldamine'),
(126325, 641, 35, 'Arveldamine (kirjutamine vabatahtlik)'),
(126326, 642, 35, 'Arvelduse NB'),
(126327, 644, 35, 'Arvelduskood soovitud teenusele'),
(126328, 645, 35, 'Arveldamise koodid'),
(126329, 646, 35, 'Arveldamise kuupäev:'),
(126330, 647, 35, 'Arveldusosakond'),
(126331, 648, 35, 'Arveldusasutus'),
(126332, 649, 35, 'Arveldusinfo'),
(126333, 650, 35, 'Arveldamiskoht'),
(126334, 655, 35, 'Arveldamise juht'),
(126335, 656, 35, 'Arveldamismärge'),
(126336, 657, 35, 'Arveldamismärge '),
(126337, 658, 35, 'Arveldamismärge:'),
(126338, 659, 35, 'Arvelduspäringu tulemused:'),
(126339, 660, 35, 'Arveldamisraport'),
(126340, 661, 35, 'Arveldamise seis'),
(126341, 662, 35, 'Arveldamise seis = arveldamata'),
(126342, 663, 35, 'arveldus '),
(126343, 665, 35, 'Biopsia'),
(126344, 666, 35, 'Sünnikuupäev'),
(126345, 667, 35, 'Sünd-24 kuud'),
(126346, 669, 35, 'Must (neeger)'),
(126347, 670, 35, 'Tumenenud kops'),
(126348, 671, 35, 'Neeger või Afroameeriklane'),
(126349, 672, 35, 'Kusepõie vähk'),
(126350, 673, 35, 'Kusepõie infektsioonid'),
(126351, 674, 35, 'Tühjad Vormid'),
(126352, 675, 35, 'Veritsemisprobleemid'),
(126353, 676, 35, 'Pimedad punktid'),
(126354, 677, 35, 'Puhitus'),
(126355, 678, 35, 'Blokeeritud'),
(126356, 679, 35, 'Veri'),
(126357, 680, 35, 'Vererõhk'),
(126358, 681, 35, 'Vererõhk'),
(126359, 682, 35, 'Verine nina'),
(126360, 683, 35, 'Meditsiiniline kindlustusfirma Sinine rist'),
(126361, 684, 35, 'Selle raporti sinised read on informatiivsed. Mustad read näitavad juba varem olemasolnud infot. Rohelised read näitavad edukalt rakendatud muudatusi. Punased read näitavad vigu või muutusi mida ei ole veel rakendatud; need tuleb käsitsi töödelda. Hetkel keelatud maksenõudeid ja maksetühistamisi ei toimetata automaatselt ja näidatakse seega punasena.'),
(126362, 685, 35, 'Hägustunud nägemine'),
(126363, 686, 35, 'BMI'),
(126364, 687, 35, 'BMI Olek'),
(126365, 689, 35, 'Keha Piirkond'),
(126366, 690, 35, 'Koht kehal'),
(126367, 691, 35, 'Koht kehal, kui võimalik'),
(126368, 692, 35, 'Luunõrkus:'),
(126369, 693, 35, 'Luunõrkus: Medial Malleolus'),
(126370, 694, 35, 'Boolean (Kahendmuutuja)'),
(126371, 696, 35, 'Robot'),
(126372, 697, 35, 'Mõlemad kõrvad'),
(126373, 698, 35, 'mõlemad kõrvad'),
(126374, 699, 35, 'Põhi'),
(126375, 701, 35, 'BOX 10A. Töötamisega seotud '),
(126376, 702, 35, 'BOX 10B. Autoavarii '),
(126377, 703, 35, 'BOX 10C. Muu õnnetus '),
(126378, 706, 35, 'BOX 15. Sama või sarnase haiguse kuupäev (yyyy-mm-dd):'),
(126379, 708, 35, 'BOX 16. Töövõimetuse kuupäev alates (yyyy-mm-dd):'),
(126380, 709, 35, 'BOX 16. Töövõimetuse kuupäev kuni (yyyy-mm-dd):'),
(126381, 710, 35, 'BOX 18. Hospitaliseerimise kuupäev alates (yyyy-mm-dd): '),
(126382, 711, 35, 'BOX 18. Hospitaliseerimise kuupäev kuni (yyyy-mm-dd): '),
(126383, 712, 35, 'BOX 20. Kas kasutatakse välislaborit?'),
(126384, 713, 35, 'BOX 22. Medicaid taassaatmise kood (ICD-9) '),
(126385, 714, 35, 'BOX 23. Eelmine Autoriseerimise Nr. '),
(126386, 715, 35, 'Vererõhk'),
(126387, 716, 35, 'Diastoolne vererõhk'),
(126388, 717, 35, 'Süstoolne vererõhk'),
(126389, 719, 35, 'Bpd'),
(126390, 721, 35, 'Bps'),
(126391, 722, 35, 'Brasiilia portugallane'),
(126392, 723, 35, 'Rind'),
(126393, 724, 35, 'Rinnabiopsia'),
(126394, 725, 35, 'Rinna eritis'),
(126395, 726, 35, 'Rinna haigus'),
(126396, 727, 35, 'Rinnauuring'),
(126397, 728, 35, 'Rinnamass'),
(126398, 730, 35, 'Rinna helid:'),
(126399, 732, 35, 'Murtud luud'),
(126400, 734, 35, 'Bronhiidi vorm'),
(126401, 735, 35, 'Otsi'),
(126402, 736, 35, 'Otsi haiguslugu'),
(126403, 737, 35, 'Verevalum / hematoom'),
(126404, 739, 35, 'Paistetus Paremal:'),
(126405, 741, 35, 'Põletus urineerimisel'),
(126406, 742, 35, 'Põletus urineerimisel'),
(126407, 744, 35, 'Toimetab'),
(126408, 745, 35, 'kuid pole veel töödeldud.'),
(126409, 746, 35, 'Tuhar'),
(126410, 747, 35, 'Tuhar + SI side'),
(126411, 748, 35, 'juures'),
(126412, 749, 35, 'Juures'),
(126413, 750, 35, 'suu juures'),
(126414, 751, 35, 'Juures/Allikas');
INSERT INTO `lang_definitions` VALUES
(126415, 752, 35, 'Juures:'),
(126416, 753, 35, 'C'),
(126417, 754, 35, 'CA sertifikaat RFC 542 TLS syslog serveri tuvastamiseks'),
(126418, 755, 35, 'Puhvri eluiga (sekundites)'),
(126419, 756, 35, 'Lugeda mallivälimus puhvrisse?'),
(126420, 757, 35, 'Koffeiini tarbimine'),
(126421, 758, 35, 'Kalender'),
(126422, 759, 35, 'Kalendri lõputund'),
(126423, 760, 35, 'Kalendri intervall'),
(126424, 761, 35, 'Kalendri aken'),
(126425, 762, 35, 'Kalendri määrangud'),
(126426, 763, 35, 'Kalendri algustund'),
(126427, 764, 35, 'Kalendri kasutajavaade'),
(126428, 765, 35, 'Kalendrivaade'),
(126429, 766, 35, 'addForm() kutsung läheb siia.<br>'),
(126430, 767, 35, 'Kalorid'),
(126431, 768, 35, 'Gamobdzalane'),
(126433, 774, 35, 'Katkesta'),
(126434, 775, 35, 'Katkesta Muutmine'),
(126435, 776, 35, 'Katkestatud'),
(126436, 777, 35, 'Vähk'),
(126437, 778, 35, 'Vähiuuring: Jämesoolevähi uuring'),
(126438, 779, 35, 'Vähiuuring: Mammogramm'),
(126439, 780, 35, 'Vähiuuring: Pap äie'),
(126440, 781, 35, 'Vähiuuring: Eesnäärmevähi uuring'),
(126441, 782, 35, 'Ei saa seda sisestust lisada kuna see juba eksisteerib!'),
(126442, 783, 35, 'Ei saa seda sisestust lisada/uuendada kuna duplikaat juba eksisteerib!'),
(126443, 784, 35, 'ei saa arhiveerida, ignoreeriti'),
(126444, 785, 35, 'ei saa JPEG formaati muuta. Võimalik et ImageMagick pole installitud?'),
(126445, 786, 35, 'ei saa kustutada, ignoreeriti'),
(126446, 787, 35, 'ei saa reastatult näidata kuna selle tüüp ei ole lehtseja poolt toetatud.'),
(126447, 788, 35, 'ei saa reastatult näidata kuna selle tüüp ei ole lehtseja poolt toetatud'),
(126448, 789, 35, 'ei saa reastatult näidata kuna selle tüüp ei ole lehtseja poolt toetatud.'),
(126449, 790, 35, 'Ei saa luua'),
(126450, 795, 35, 'Ei leia '),
(126451, 796, 35, 'Ei leia faili sihtnime'),
(126452, 799, 35, 'Ei leita sellist patsiendi kliendi id-d SQL-Finantsmoodulis'),
(126453, 800, 35, 'Ei leita viidet postscript dokumendile '),
(126454, 801, 35, 'Ei leita sellist patsiendi kliendi id-d SQL-Finantsmoodulis '),
(126455, 802, 35, 'Ei saa Maksmisi Muuta. Jagatav on Negatiivne.'),
(126456, 803, 35, 'Ei saa avada '),
(126457, 807, 35, 'Ei saa lugeda'),
(126458, 808, 35, 'Ei saa kausta lugeda'),
(126459, 809, 35, 'Ei saa uuendada kuna sa ei töötle olemasolevat sisestust'),
(126460, 810, 35, 'Suurtähtedeks'),
(126461, 812, 35, 'kapsul'),
(126462, 813, 35, 'Kaart'),
(126463, 814, 35, 'Südame katetreerimine'),
(126464, 815, 35, 'Südame Ultraheli'),
(126465, 816, 35, 'Kardiovaskulaarne'),
(126466, 821, 35, 'Kõhre / luu / diski kahjustus'),
(126467, 822, 35, 'Kõhre vigastus'),
(126468, 824, 35, 'sularaha'),
(126469, 825, 35, 'Sularaha'),
(126470, 827, 35, 'Sularahaarve Saatjalt'),
(126471, 829, 35, 'Katarakti Kirurgia'),
(126472, 830, 35, 'Kataraktid'),
(126473, 831, 35, 'Kategooriad'),
(126474, 832, 35, 'Kategooriad'),
(126475, 833, 35, 'Kategooria'),
(126476, 834, 35, 'kategooria'),
(126477, 835, 35, 'Kategooria '),
(126478, 836, 35, 'Kategooria detailid'),
(126479, 837, 35, 'Kategooria Piirid'),
(126480, 838, 35, 'Kategooria nimetus'),
(126481, 839, 35, 'Kategooria nimetus on tühi'),
(126482, 840, 35, 'Kategooria/Pealkiri'),
(126483, 841, 35, 'Kaukaaslane'),
(126484, 850, 35, 'CDR'),
(126485, 852, 35, 'Mobiil'),
(126486, 853, 35, 'Mobiiltelefon'),
(126487, 855, 35, 'Mobiiltelefoni number'),
(126488, 856, 35, 'Keskne Sertifitseerimine'),
(126489, 857, 35, 'Kesk/Lõuna-Ameeriklane'),
(126490, 861, 35, 'Sertifikaadi Kasutaja'),
(126491, 862, 35, 'Sertifikaadid'),
(126492, 866, 35, 'muuda'),
(126493, 867, 35, 'Muuda'),
(126494, 868, 35, 'Muuda Tegevust'),
(126495, 870, 35, 'Nägemismuutus'),
(126496, 871, 35, 'Nägemismuutus'),
(126497, 874, 35, 'Muutunud'),
(126498, 877, 35, 'Omadused'),
(126499, 878, 35, 'Märke jäänud'),
(126500, 883, 35, 'Kaart'),
(126501, 884, 35, 'Kaardi Tegevused'),
(126502, 885, 35, 'Kaardi Tegevuste Raport'),
(126503, 886, 35, 'Kaardi ID'),
(126504, 887, 35, 'Kaardi ID:'),
(126505, 889, 35, 'Kaardi Asukoha Tegevus'),
(126506, 890, 35, 'Kaardi Märge'),
(126507, 891, 35, 'Kaardi Number'),
(126508, 892, 35, 'Kaardi Hoiukohad'),
(126509, 893, 35, 'Kaardi Jälgija'),
(126510, 894, 35, 'Kaardi Jlg'),
(126511, 895, 35, 'Kaardid Väljastatud'),
(126512, 896, 35, 'Kaardid Väljas'),
(126513, 898, 35, 'Kontroll'),
(126514, 899, 35, 'kontrolli'),
(126515, 900, 35, 'Kontrolli kõik'),
(126516, 2, 36, 'شماره چک یا شماره پرونده برای پیگیری پرداخت'),
(126517, 5, 36, 'یک سند بالینی پیوست شده است.'),
(126518, 7, 36, 'توزیع کننده ای مورد نیاز است'),
(126519, 8, 36, 'یک فرم ملاقات GCAC باید به این ملاقات اضافه شده است.'),
(126520, 9, 36, 'شماره سری مورد نیاز است'),
(126521, 10, 36, 'شماره سری مورد نیاز است!'),
(126522, 11, 36, 'یک حرف کوچک'),
(126523, 12, 36, 'یک شماره'),
(126524, 14, 36, 'اکنون بیماری با این شماره شناسایی وجود دارد.'),
(126525, 15, 36, 'اکنون بیماری با این نام وجود دارد.'),
(126526, 16, 36, 'اکنون بیماری با این کد ملی وجود دارد.'),
(126527, 19, 36, 'ممکن است منبع ارجاعی برای هر ویزیت مشخص شده باشد.'),
(126528, 20, 36, 'به یک کد IPPF مرتبط نیاز است!'),
(126529, 21, 36, 'یک حرف ویژه'),
(126530, 22, 36, 'یک مقدار منحصر به فرد برای شناسایی این فیلد، برای کاربر قابل مشاهده نیست'),
(126531, 24, 36, 'پیش از غذا'),
(126532, 25, 36, 'صبح'),
(126533, 28, 36, 'مخفف'),
(126534, 29, 36, 'Abcess:'),
(126535, 30, 36, 'Abdominal'),
(126536, 31, 36, 'قادر به تحمل وزن چهار (4) مرحله:'),
(126537, 34, 36, 'ناهنجار'),
(126538, 35, 36, 'آزمایش خون ناهنجار'),
(126539, 36, 36, 'رشد موی ناهنجار'),
(126540, 37, 36, 'ماموگرام ناهنجار'),
(126541, 39, 36, 'سقط جنین'),
(126542, 40, 36, 'مسائل مربوط به سقط جنین'),
(126543, 41, 36, 'روش سقط جنین'),
(126544, 42, 36, 'دسته بندی های مربوط به سقط جنین'),
(126545, 43, 36, 'سقط جنین ها'),
(126546, 44, 36, 'در باره زمانبندی'),
(126547, 46, 36, 'غیبت ها بر اساس تشخیص'),
(126548, 47, 36, 'پذیرش واگذاری'),
(126549, 48, 36, 'پذیرش پرداخت برای'),
(126550, 49, 36, 'پذیرش پرداخت برای'),
(126551, 50, 36, 'حواله می پذیرد'),
(126552, 51, 36, 'کنترل دسترسی'),
(126553, 52, 36, 'مدیریت لیست کنترل دسترسی'),
(126554, 54, 36, 'دسترسی مجاز نیست'),
(126555, 55, 36, 'دسترسی مجاز نیست'),
(126556, 56, 36, 'دسترسی به پورتال بیمار'),
(126557, 59, 36, 'نام حساب'),
(126558, 62, 36, 'حسابداری'),
(126559, 64, 36, 'دردها'),
(126560, 66, 36, 'قدردانی، صدور مجوز و گواهینامه'),
(126561, 71, 36, 'Acne'),
(126562, 74, 36, 'اقدام'),
(126563, 75, 36, 'اقدامات'),
(126564, 78, 36, 'فعال'),
(126565, 79, 36, 'هشدار فعال'),
(126566, 80, 36, 'قواعد هشدار فعال'),
(126567, 81, 36, 'هشدارها/یادآورهای فعال'),
(126568, 82, 36, 'ویزیت فعال'),
(126569, 84, 36, 'لیست های فعال'),
(126570, 85, 36, 'بیماران فعال'),
(126571, 86, 36, 'طرح های فعال'),
(126572, 87, 36, 'فعالیت'),
(126573, 88, 36, 'نوع فعالیت'),
(126574, 90, 36, 'مسمومیت / محرومیت حاد'),
(126575, 92, 36, 'حاد بر روی مزمن'),
(126576, 93, 36, 'جدید'),
(126577, 94, 36, 'جدید'),
(126578, 95, 36, 'جدید'),
(126579, 96, 36, 'شرکت جدید'),
(126580, 98, 36, 'داروخانه جدید'),
(126581, 100, 36, 'رویداد جدید '),
(126582, 101, 36, 'یادداشت جدید'),
(126583, 102, 36, 'اضافه کردن به عنوان جدید'),
(126584, 104, 36, 'اضافه کردن دکمه'),
(126585, 105, 36, 'برای کاراکتر های خاص دکمه اضافه کنید، متون در بالای ویرایشگر نمایش داده میشوند تا با کلیک کردن دکمه در داخل متن گنجاده شوند'),
(126586, 106, 36, 'رده جدید'),
(126587, 107, 36, 'عدد ثابت جدید'),
(126588, 108, 36, 'مفهوم جدید'),
(126589, 109, 36, 'فرانشیز جدید'),
(126590, 110, 36, 'معیار جدید'),
(126591, 111, 36, 'دکمه دلخواه جدید'),
(126592, 112, 36, 'تشخیص جدید'),
(126593, 113, 36, 'داروی جدید'),
(126594, 114, 36, 'ویزیت جدید'),
(126595, 115, 36, 'ویزیت/یادداشت جدید'),
(126596, 116, 36, 'درمانگاه جدید'),
(126597, 117, 36, 'فیلد جدید'),
(126598, 118, 36, 'خطوط زیر را به فایل تنظیمات آپاچی اضافه کن'),
(126599, 119, 36, 'گروه جدید'),
(126600, 121, 36, 'ایمن سازی جدید'),
(126601, 122, 36, 'اضافه کردن مجاز نیست!'),
(126602, 123, 36, 'مسئله جدید'),
(126603, 125, 36, 'زبان جدید'),
(126604, 126, 36, 'جدید'),
(126605, 127, 36, 'جدید'),
(126606, 128, 36, 'افزودن دسته بندی جدید '),
(126607, 129, 36, 'افزودن گواهینامه های جدید به فایل تنظیمات آپاچی'),
(126608, 132, 36, 'افزودن گروه جدید'),
(126609, 134, 36, 'افزودن شماره سری و معامله'),
(126610, 135, 36, 'افزودن یادداشت جدید'),
(126611, 136, 36, 'افزودن یادداشت جدید'),
(126612, 137, 36, 'افزودن شریک زندگی جدید'),
(126613, 140, 36, 'یادداشت جدید'),
(126614, 141, 36, 'سابقه بیمار جدید'),
(126615, 142, 36, 'نسخه جدید'),
(126616, 143, 36, 'افزودن رویه'),
(126617, 144, 36, 'شماره ارائه دهنده جدید خدمات'),
(126618, 145, 36, 'بازتوانی جدید'),
(126619, 146, 36, 'قاعده جدید'),
(126620, 147, 36, 'افزودن به'),
(126621, 148, 36, 'افزودن به لیست داروها'),
(126622, 149, 36, 'افزودن به سطح بالا'),
(126623, 150, 36, 'تراکنش جدید'),
(126624, 151, 36, 'کاربر جدید'),
(126625, 152, 36, 'افزودن کاربر به گروه'),
(126626, 153, 36, 'افزودن/ویرایش نسخه الکترونیکی‌'),
(126627, 154, 36, 'افزودن/ویرایش تراکنش بیمار'),
(126628, 155, 36, 'اضافه شده'),
(126629, 156, 36, 'اضافه کردن اطلاعات دموگرافیک مجاز نیست.'),
(126630, 158, 36, 'سندروم آدیسون'),
(126631, 159, 36, 'سندروم آدیسون'),
(126632, 160, 36, 'ویژگیهای بیشتر'),
(126633, 161, 36, 'تشخیص های بیشتر:'),
(126634, 162, 36, 'سوابق دیگر'),
(126635, 163, 36, 'یادداشت سوابق بیشتر'),
(126636, 164, 36, 'اطلاعات بیشتر'),
(126637, 165, 36, 'آزمایشات بیشتر'),
(126638, 166, 36, 'یادداشت های بیشتر'),
(126639, 167, 36, 'یادداشت های بیشتر برای این یافته یا توصیه'),
(126640, 168, 36, 'یادداشت های بیشتر:'),
(126641, 169, 36, 'یادداشت های بیشتر: '),
(126642, 170, 36, 'یادداشت های بیشترمربوط با تصاویرX-RAY:'),
(126643, 173, 36, 'کتابچه آدرس ها'),
(126644, 174, 36, 'کتابچه آدرس ها'),
(126645, 175, 36, 'آدرس'),
(126646, 178, 36, 'کتابچه آدرس ها'),
(126647, 182, 36, 'انواع کتابهای آدرس'),
(126648, 187, 36, 'آدرس 1'),
(126649, 188, 36, 'آدرس 2'),
(126650, 190, 36, 'اصلاح'),
(126651, 191, 36, 'اصلاح مبلغ'),
(126652, 192, 36, 'اصلاح'),
(126653, 193, 36, 'اصلاح'),
(126654, 194, 36, 'اصلاح مبلغ'),
(126655, 195, 36, 'دلایل اصلاح'),
(126656, 197, 36, 'اصلاحات'),
(126657, 199, 36, 'مدیر نرم افزار'),
(126658, 200, 36, 'آدرس پست الکترونیکی مدیر نرم افزار'),
(126659, 201, 36, 'مدیریت از طریق'),
(126660, 202, 36, 'مدیریت شده توسط'),
(126661, 203, 36, 'مدیریت شده توسط'),
(126662, 205, 36, 'سایت مدیریت شده'),
(126663, 206, 36, 'مدیریت'),
(126664, 207, 36, 'سایت مدیریت'),
(126665, 208, 36, 'مدیران'),
(126666, 209, 36, 'مدیران قادر به انجام کاری نیستند'),
(126667, 210, 36, 'تاریخ بستری'),
(126668, 212, 36, 'پایش و پیگیری وزن فرد بالغ'),
(126669, 213, 36, 'پایش و پیگیری وزن فرد بالغ (CQM)'),
(126670, 214, 36, 'دستورالعمل پیشرفته'),
(126671, 215, 36, 'دستورالعمل های پیشرفته'),
(126672, 216, 36, 'هشدار دستورالعمل های پیشرفته'),
(126673, 218, 36, 'پیشرفته'),
(126674, 219, 36, 'توصیه'),
(126675, 221, 36, 'Affect normal'),
(126676, 226, 36, 'پس از ذخیره فایل PDF، برای بررسی‌ اشتباهات [مشاهده صورت عملیات] را کلیک کنید.'),
(126677, 227, 36, 'پس از ذخیره "فایل متنی"، برای بررسی‌ اشتباهات [مشاهده صورت عملیات] را کلیک کنید.'),
(126678, 228, 36, 'پس از ذخیره "دستورات دسته ای"، برای بررسی‌ اشتباهات [مشاهده صورت عملیات] را کلیک کنید.'),
(126679, 233, 36, 'مجددا'),
(126680, 234, 36, 'سن'),
(126681, 236, 36, 'طبقه بندی سنی'),
(126682, 237, 36, 'داده مربوط به سن خارج از محدوده سنی مجاز است.'),
(126683, 239, 36, 'فرمت سن برای" سن از" غیرمعتبر است'),
(126684, 240, 36, 'فرمت سن برای" تا سن" غیر معتبراست.'),
(126685, 241, 36, 'سن از'),
(126686, 243, 36, 'حداکثر سن'),
(126687, 244, 36, 'حداقل سن'),
(126688, 245, 36, 'محدوده سنی'),
(126689, 249, 36, 'آلبانیایی'),
(126690, 250, 36, 'الکل'),
(126691, 251, 36, 'مصرف الکل'),
(126692, 253, 36, 'هشدار تعداد'),
(126693, 255, 36, 'هشدارها'),
(126694, 259, 36, 'همه'),
(126695, 260, 36, 'همه'),
(126696, 266, 36, 'همه طبقه بندی ها'),
(126697, 268, 36, 'همه کدها'),
(126698, 269, 36, 'هر روز'),
(126699, 270, 36, 'رویداد برای همه روز'),
(126700, 271, 36, 'همه خصیصه های فردی، و گزینه های جستجو و کپی'),
(126701, 272, 36, 'همه درمانگاه ها'),
(126702, 273, 36, 'همه صدمات/مشکلات/مسائل'),
(126703, 274, 36, 'همه زبان های مجاز'),
(126704, 276, 36, 'همه یا بخشی از نام'),
(126705, 277, 36, 'همه یا بخشی از نام خانوادگی'),
(126706, 278, 36, 'همه یا بخشی از سازمان'),
(126707, 280, 36, 'همه محصولات'),
(126708, 281, 36, 'همه ارائه دهندگان خدمات'),
(126709, 282, 36, 'همه بررسی‌ شده و منفی‌ :'),
(126710, 283, 36, 'همه عناوین'),
(126711, 284, 36, 'همه کاربران'),
(126712, 285, 36, 'حساسیت'),
(126713, 286, 36, 'حساسیت ها'),
(126714, 287, 36, 'حساسیت ها:'),
(126715, 288, 36, 'حساسیت'),
(126716, 289, 36, 'ورود آلرژی با موفقیت به پایان رسید'),
(126717, 291, 36, 'واکنش آلرژی'),
(126718, 294, 36, 'اختصاص'),
(126719, 295, 36, 'اجازه'),
(126720, 298, 36, 'اجازه رفع اشکال زبان'),
(126721, 299, 36, 'اجازه ایمیل'),
(126722, 300, 36, 'اجازه پیام های ایمیل؟'),
(126723, 301, 36, 'اجازه ایمیل؟'),
(126724, 303, 36, 'اجازه تبادل اطلاعات پزشکی'),
(126725, 304, 36, 'اجازه به اشتراک گذاشتن اطلاعات واکسیناسیون'),
(126726, 305, 36, 'اجازه استفاده از رجیستری واکسیناسیون'),
(126727, 306, 36, 'اجازه نامه'),
(126728, 308, 36, 'اجازه پورتال بیمار'),
(126729, 309, 36, 'اجازه SMS'),
(126730, 310, 36, 'اجازه SMS (پیام های متنی)؟'),
(126731, 312, 36, 'اجازه پیام تلفنی؟'),
(126732, 313, 36, 'اجازه کاربران برای انتشار وقایع سراسری'),
(126733, 314, 36, 'اجازه کاربران برای انتشار تقویم های شخصی'),
(126734, 315, 36, 'اجازه پیام صوتی'),
(126735, 316, 36, 'مجاز'),
(126736, 317, 36, 'زبان های مجاز'),
(126737, 323, 36, 'از قبل وجود دارد'),
(126738, 324, 36, 'از قبل وجود دارد.'),
(126739, 325, 36, 'پیش از این استفاده شده است، شناسه دیگری انتخاب کنید.'),
(126740, 326, 36, 'پیش از این استفاده شده است، عنوان دیگری انتخاب کنید.'),
(126741, 330, 36, 'روز'),
(126742, 347, 36, 'مقدار'),
(126743, 348, 36, 'مقدار تهیه شده'),
(126744, 351, 36, 'مبلغ بابت این ملاقات'),
(126745, 352, 36, 'مبلغ پرداخت شده'),
(126746, 353, 36, 'مبلغ:'),
(126747, 365, 36, 'و'),
(126748, 366, 36, 'و'),
(126749, 367, 36, 'و'),
(126750, 368, 36, 'و '),
(126751, 374, 36, 'کم خونی'),
(126752, 375, 36, 'مچ پا'),
(126753, 376, 36, 'مچ پا + پاشنه'),
(126754, 377, 36, 'فرم ارزیابی مچ پا'),
(126755, 378, 36, 'مشکلات مچ پا'),
(126756, 379, 36, 'Ankylosing Sondlilitis'),
(126757, 380, 36, 'Ankylosing Spondlilitis'),
(126758, 381, 36, 'Anorexia'),
(126759, 384, 36, 'معاینه مقعد نرمال، عدم وجود حساسیت در لمس و توده'),
(126760, 385, 36, 'اضطراب'),
(126761, 386, 36, 'هر'),
(126762, 387, 36, 'هر دسته بندی'),
(126763, 395, 36, 'آپنه'),
(126764, 398, 36, 'پیوست این یادداشت'),
(126765, 399, 36, 'پیوست به یادداشت موجود'),
(126766, 400, 36, 'پیوست به این یادداشت'),
(126767, 401, 36, 'پیوست به این یادداشت'),
(126768, 402, 36, 'برداشتن اپاندیس'),
(126769, 417, 36, 'قرار ملاقات'),
(126770, 418, 36, 'تاریخ قرار ملاقات'),
(126771, 419, 36, 'سبک نمایش قرار ملاقات'),
(126772, 420, 36, 'قاعده یادآوری قرار ملاقات'),
(126773, 421, 36, 'وضعیت قرار ملاقات'),
(126774, 422, 36, 'وضعیت های قرار ملاقات'),
(126775, 423, 36, 'قرار ملاقات در ضمن'),
(126776, 424, 36, 'رنگ قرار ملاقات/رویداد'),
(126777, 425, 36, 'قرار ملاقات ها'),
(126778, 434, 36, 'تصویب'),
(126779, 436, 36, 'تصویب شده'),
(126780, 442, 36, 'آوریل'),
(126781, 443, 36, 'آوریل'),
(126782, 447, 36, 'آیا نام گروه های کنترل دسترسی باید ترجمه شوند؟'),
(126783, 453, 36, 'آیا آماده تکمیل یک مسئله GCAC جدید برای این ملاقات هستید؟'),
(126784, 475, 36, 'ارمنی'),
(126785, 477, 36, 'آریتمی'),
(126786, 478, 36, 'آرتروز'),
(126787, 479, 36, 'Arthritis / degen joint diseas'),
(126788, 480, 36, 'Arthritis / degen joint disease'),
(126789, 484, 36, 'آسیایی'),
(126790, 487, 36, 'ارزیابی'),
(126791, 488, 36, 'محول شده به'),
(126792, 489, 36, 'دستیار'),
(126793, 490, 36, 'آسم'),
(126794, 491, 36, 'در'),
(126795, 493, 36, 'At the Navicular'),
(126796, 494, 36, 'At the Navicular:'),
(126797, 497, 36, 'Athletic/Injury'),
(126798, 503, 36, 'توجه'),
(126799, 504, 36, 'توجه'),
(126800, 516, 36, 'اوت'),
(126801, 517, 36, 'اوت'),
(126802, 523, 36, 'گروه مجوز'),
(126803, 524, 36, 'وضعیت مجوز'),
(126804, 525, 36, 'مجوزها'),
(126805, 526, 36, 'اجازه دادن'),
(126806, 530, 36, 'مجاز'),
(126807, 531, 36, 'مجاز تنها'),
(126808, 558, 36, 'Avulsion / avulsion fracture'),
(126809, 560, 36, 'Avulsion medial malleolus '),
(126810, 562, 36, 'Axillary'),
(126811, 565, 36, 'b.i.d.'),
(126812, 568, 36, 'هشت ملاقات قبلی'),
(126813, 569, 36, 'یازده ملاقات قبلی'),
(126814, 570, 36, 'پنج ملاقات قبلی'),
(126815, 571, 36, 'چهار ملاقات قبلی'),
(126816, 572, 36, 'نه‌ ملاقات قبلی'),
(126817, 573, 36, 'یک ملاقات قبلی'),
(126818, 574, 36, 'کمر درد'),
(126819, 575, 36, 'مشکلات کمر'),
(126820, 576, 36, 'هفت ملاقات قبلی'),
(126821, 577, 36, 'شش ملاقات قبلی'),
(126822, 578, 36, 'عمل جراحی پشت'),
(126823, 579, 36, 'ده ملاقات قبلی'),
(126824, 580, 36, 'سه ملاقات قبلی'),
(126825, 581, 36, 'بازگشت به صفحه مدیریت'),
(126826, 584, 36, 'بازگشت به پرونده بیمار'),
(126827, 585, 36, 'بازگشت به صفحه کاربران'),
(126828, 587, 36, 'دوازده ملاقات قبلی'),
(126829, 588, 36, 'دو ملاقات قبلی'),
(126830, 590, 36, 'نسخه پشتیبان'),
(126831, 594, 36, 'چک بی‌ محل'),
(126832, 595, 36, 'بدهی بد'),
(126833, 607, 36, 'Base of fifth (5th) Metarsal'),
(126834, 608, 36, 'Base of fifth (5th) Metarsal:'),
(126835, 614, 36, 'پرداخت های دسته ای'),
(126836, 616, 36, 'نتایج دسته ای'),
(126837, 621, 36, 'از تاریخ'),
(126838, 630, 36, 'بین'),
(126839, 633, 36, 'دو طرفه'),
(126840, 634, 36, 'دو طرفه:'),
(126841, 636, 36, 'تاریخ صورتحساب:'),
(126842, 638, 36, 'صورتحساب صادر شد'),
(126843, 640, 36, 'حسابداری'),
(126844, 641, 36, 'حسابداری (نوشتن اختیاری است)'),
(126845, 642, 36, 'توجه حسابداری'),
(126846, 644, 36, 'کد حسابداری برای سرویس های درخواست شده'),
(126847, 645, 36, 'کدهای حسابداری'),
(126848, 646, 36, 'ارقام حسابداری'),
(126849, 647, 36, 'گروه حسابداری'),
(126850, 648, 36, 'صادرکننده صورت حساب'),
(126851, 649, 36, 'اطلاعات حسابداری'),
(126852, 650, 36, 'محل صدور صورت حساب'),
(126853, 655, 36, 'مدیر حسابداری'),
(126854, 656, 36, 'یادداشت حسابداری'),
(126855, 657, 36, 'یادداشت حسابداری برای '),
(126856, 658, 36, 'یادداشت حسابداری:'),
(126857, 660, 36, 'گزارش حسابداری'),
(126858, 661, 36, 'وضعیت حسابداری'),
(126859, 662, 36, 'وضعیت حسابداری = صورتحساب صادر نشده'),
(126860, 663, 36, 'صدور صورت حساب '),
(126861, 665, 36, 'نمونه برداری'),
(126862, 666, 36, 'تاریخ تولد'),
(126863, 669, 36, 'سیاه'),
(126864, 670, 36, 'ریه سیاه'),
(126865, 671, 36, 'سیاه یا آمریکایی آفریقایی تبار'),
(126866, 672, 36, 'سرطان مثانه'),
(126867, 673, 36, 'عفونت مثانه'),
(126868, 674, 36, 'فرم های خالی'),
(126869, 675, 36, 'مشکلات خونریزی'),
(126870, 676, 36, 'نقاط کور'),
(126871, 677, 36, 'نفخ شکم'),
(126872, 678, 36, 'مسدود شده'),
(126873, 679, 36, 'خون'),
(126874, 680, 36, 'فشار خون'),
(126875, 681, 36, 'فشار خون'),
(126876, 682, 36, 'بینی خونین'),
(126877, 685, 36, 'تاری دید'),
(126878, 686, 36, 'شاخص توده بدن'),
(126879, 687, 36, 'وضعیت شاخص توده بدن'),
(126880, 689, 36, 'ناحیه بدن'),
(126881, 692, 36, 'Bone Tenderness:'),
(126882, 693, 36, 'Bone Tenderness: Medial Malleolus'),
(126883, 696, 36, 'پایین'),
(126884, 697, 36, 'هر دو گوش'),
(126885, 698, 36, 'هر دو گوش'),
(126886, 699, 36, 'پایین'),
(126887, 722, 36, 'پرتغالی برزیل'),
(126888, 723, 36, 'سینه'),
(126889, 724, 36, 'بیوپسی سینه'),
(126890, 725, 36, 'ترشح سینه'),
(126891, 726, 36, 'بیماری سینه'),
(126892, 727, 36, 'معاینه سینه'),
(126893, 730, 36, 'صداهای تنفسی:'),
(126894, 732, 36, 'شکستگی استخوان'),
(126895, 734, 36, 'فرم برونشیت'),
(126896, 737, 36, 'کبودی / هماتوم'),
(126897, 739, 36, 'متورم راست:'),
(126898, 741, 36, 'سوزش ادرار'),
(126899, 742, 36, 'سوزش ادرار'),
(126900, 744, 36, 'مشغول'),
(126901, 745, 36, 'اما هنوز پردازش نشده.'),
(126902, 746, 36, 'باسن'),
(126903, 748, 36, 'توسط'),
(126904, 749, 36, 'توسط'),
(126905, 750, 36, 'توسط دهان'),
(126906, 751, 36, 'توسط/منبع'),
(126907, 752, 36, 'برای:'),
(126908, 758, 36, 'تقویم'),
(126909, 759, 36, 'ساعت پایان تقویم'),
(126910, 761, 36, 'صفحه نمایش تقویم'),
(126911, 762, 36, 'تنظیمات تقویم'),
(126912, 763, 36, 'ساعت شروع تقویم'),
(126913, 765, 36, 'نمایش تقویم'),
(126914, 767, 36, 'کالری'),
(126915, 768, 36, 'کامبوج'),
(126916, 774, 36, 'لغو'),
(126917, 775, 36, 'لغو تغییرات'),
(126918, 776, 36, 'لغو شد'),
(126919, 777, 36, 'سرطان'),
(126920, 790, 36, 'ایجاد نمی توان کرد'),
(126921, 795, 36, 'پیدا نمی توان کرد '),
(126922, 814, 36, 'Cardiac Catheterization'),
(126923, 815, 36, 'Cardiac Echo'),
(126924, 816, 36, 'Cardiovascular'),
(126925, 821, 36, 'Cartilage / chondral / disc damage'),
(126926, 822, 36, 'Cartilage injury'),
(126927, 823, 36, 'Cartoid pulsations nl, pedal pulses nl'),
(126928, 824, 36, 'پول نقد'),
(126929, 825, 36, 'پول نقد'),
(126930, 829, 36, 'جراحی آب مروارید'),
(126931, 830, 36, 'آب مروارید'),
(126932, 831, 36, 'دسته بندی ها'),
(126933, 832, 36, 'دسته بندی ها برای'),
(126934, 833, 36, 'دسته بندی'),
(126935, 834, 36, 'دسته بندی'),
(126936, 835, 36, 'دسته بندی '),
(126937, 836, 36, 'جزئیات دسته بندی'),
(126938, 837, 36, 'محدوده دسته بندی'),
(126939, 838, 36, 'نام دسته بندی'),
(126940, 839, 36, 'نام دسته بندی خالی است'),
(126941, 840, 36, 'دسته بندی/عنوان'),
(126942, 853, 36, 'تلفن همراه'),
(126943, 855, 36, 'شماره تلفن همراه'),
(126944, 862, 36, 'گواهینامه ها'),
(126945, 866, 36, 'تغییر'),
(126946, 867, 36, 'تغییر'),
(126947, 868, 36, 'تغییر فعالیت'),
(126948, 870, 36, 'تغییر در بینایی'),
(126949, 871, 36, 'تغییر در بینایی'),
(126950, 874, 36, 'تغییر'),
(126951, 877, 36, 'مشخصات'),
(126952, 878, 36, 'حروف باقی مانده'),
(126953, 879, 36, 'هزینه'),
(126954, 880, 36, 'تصحیح شارژ'),
(126955, 881, 36, 'شارژ کد شده'),
(126956, 882, 36, 'شارژ ها'),
(126957, 883, 36, 'پرونده'),
(126958, 884, 36, 'تغییرات پرونده'),
(126959, 885, 36, 'تاریخچه تحویل دادن و پس گرفتن پرونده'),
(126960, 886, 36, 'شناسه پرونده'),
(126961, 887, 36, 'شناسه پرونده:'),
(126962, 891, 36, 'شماره پرونده'),
(126963, 892, 36, 'محل ذخیره پرونده'),
(126964, 893, 36, 'ردیاب پرونده'),
(126965, 895, 36, 'پرونده های تحویل داده شده'),
(126966, 898, 36, 'چک'),
(126967, 899, 36, 'چک'),
(126968, 900, 36, 'چک همه'),
(126969, 902, 36, 'مبلغ چک'),
(126970, 903, 36, 'تاریخ چک'),
(126971, 904, 36, 'تفاوت ترجمه را با جدول زبان های مخصوص بررسی کنید.'),
(126972, 906, 36, 'بررسی به'),
(126973, 907, 36, 'بررسی داده های ورودی'),
(126974, 909, 36, 'بررسی نتایج آزمایشگاهی'),
(126975, 912, 36, 'شماره چک'),
(126976, 915, 36, 'پرداخت چک'),
(126977, 916, 36, 'این گزینه را علامت بزنید اگر این یک فایل رمزگذاری شده است'),
(126978, 917, 36, 'این گزینه را علامت بزنید اگر شما می خواهید ارائه دهندگان خدمات پزشکی به طور پیش فرض قرار ملاقات همه بیماران را ببینند و نه فقط مال خود را.'),
(126979, 919, 36, 'تاریخ چک / توضیح مزایا:'),
(126980, 920, 36, 'شماره چک / توضیح مزایا:'),
(126981, 921, 36, 'شماره چک / مرجع'),
(126982, 922, 36, 'شماره چک / مرجع'),
(126983, 923, 36, 'فهرست گزینه ها'),
(126984, 924, 36, 'فهرست گزینه ها'),
(126985, 925, 36, 'گزینه با متن'),
(126986, 926, 36, 'گزینه با متن'),
(126987, 928, 36, 'علامت زده شده'),
(126988, 929, 36, 'گزینه علامت زده شده = بله، خالی = هیچ'),
(126989, 932, 36, 'مرخص شدن'),
(126990, 933, 36, 'شماره کنترل'),
(126991, 934, 36, 'قفسه سینه'),
(126992, 936, 36, 'درد قفسه سینه'),
(126993, 937, 36, 'درد قفسه سینه:'),
(126994, 938, 36, 'دردهای قفسه سینه'),
(126995, 942, 36, 'شکایت اصلی'),
(126996, 943, 36, 'کودک'),
(126997, 946, 36, 'لرز'),
(126998, 947, 36, 'چینی'),
(126999, 948, 36, 'چینی (ساده شده)'),
(127000, 949, 36, 'چینی (سنتی)'),
(127001, 951, 36, 'گزینه ها'),
(127002, 955, 36, 'انتخاب کنید'),
(127003, 957, 36, 'معیار را انتخاب کنید'),
(127004, 962, 36, 'فهرست را انتخاب کنید'),
(127005, 967, 36, 'برونشیت مزمن'),
(127006, 968, 36, 'درد مفاصل مزمن'),
(127007, 969, 36, 'Chronic Kidney Disease (CKD)'),
(127008, 970, 36, 'Chronic synovitis / effusion / joint pain / gout'),
(127009, 971, 36, 'Chronic/Recurrent'),
(127010, 973, 36, 'Cirrhosis of the Liver'),
(127011, 974, 36, 'Cirrhosis Of The Liver'),
(127012, 975, 36, 'شهر'),
(127013, 976, 36, 'نام شهر'),
(127014, 977, 36, 'شهر، استان'),
(127015, 978, 36, 'شهر، استان, کد پستی'),
(127016, 979, 36, 'شهر/استان'),
(127017, 980, 36, 'مطالبه'),
(127018, 981, 36, 'مطالبه '),
(127019, 983, 36, 'آزمون مطالبه به اتمام رسانده'),
(127020, 984, 36, 'نوع مطالبه'),
(127021, 985, 36, 'مطالبه تبدیل به فایل شد'),
(127022, 986, 36, 'مطالبه تبدیل به فایل شد '),
(127023, 987, 36, 'مطالبات'),
(127024, 988, 36, 'طبقه بندی'),
(127025, 989, 36, 'پاک کردن'),
(127026, 991, 36, 'پاک کردن همه'),
(127027, 993, 36, 'پاک کردن توجیه'),
(127028, 994, 36, 'پاک کردن حافظه نهان Smarty'),
(127029, 997, 36, 'کلیک کنید'),
(127030, 1037, 36, 'برای دانلود کلیک کنید'),
(127031, 1038, 36, 'برای ویرایش کلیک کنید'),
(127032, 1043, 36, 'برای چاپ کلیک کنید'),
(127033, 1045, 36, 'برای انتخاب کلیک کنید'),
(127034, 1046, 36, 'برای انتخاب کلیک کنید'),
(127035, 1051, 36, 'برای انتخاب یا تغییر تشخیص کلیک کنید'),
(127036, 1052, 36, 'برای انتخاب یا تغییر کد خدمات کلیک کنید'),
(127037, 1053, 36, 'برای انتخاب بیمار کلیک کنید'),
(127038, 1054, 36, 'برای انتخاب کد مربوطه کلیک کنید'),
(127039, 1055, 36, 'اگر این نتیجه غیر طبیعی است، برای انتخاب و انجام خدمات کلیک کنید'),
(127040, 1056, 36, 'برای انتخاب روش مورد نظر کلیک کنید'),
(127041, 1058, 36, 'برای مشاهده کلیک کنید'),
(127042, 1059, 36, 'برای مشاهده یا ویرایش کلیک کنید'),
(127043, 1060, 36, 'برای مشاهده/ویرایش کلیک کنید'),
(127044, 1061, 36, 'برای ارتقاء انتشار پایگاه داده ها از تاریخ زیر دکمه به روز رسانی را کلیک کنید'),
(127045, 1063, 36, 'کلیک کنید:'),
(127046, 1067, 36, 'نسخه مراجع'),
(127047, 1069, 36, 'خلاصه تاریخچه طبی مراجع'),
(127048, 1070, 36, 'نام مراجع'),
(127049, 1071, 36, 'شماره مراجع'),
(127050, 1074, 36, 'مشتریان'),
(127051, 1075, 36, 'درمانگاه'),
(127052, 1076, 36, 'نسخه کلینیک'),
(127053, 1077, 36, 'رکورد روزانه کلینیک'),
(127054, 1078, 36, 'شناسه کلینیک'),
(127055, 1079, 36, 'درمانی'),
(127056, 1087, 36, 'یادآورهای بالینی'),
(127057, 1088, 36, 'گزارش های بالینی'),
(127058, 1102, 36, 'اهداف درمانی'),
(127059, 1106, 36, 'پزشکان'),
(127060, 1107, 36, 'کپی‌'),
(127061, 1108, 36, 'کپی‌ ملاقات گذشته'),
(127062, 1109, 36, 'بستن'),
(127063, 1111, 36, 'بستن این صفحه'),
(127064, 1112, 36, 'بسته شده'),
(127065, 1131, 36, 'کد'),
(127066, 1132, 36, 'کد'),
(127067, 1138, 36, 'انواع کد'),
(127068, 1141, 36, 'انواع کد'),
(127069, 1143, 36, 'کد شده'),
(127070, 1144, 36, 'کدها'),
(127071, 1145, 36, 'کد نویسی'),
(127072, 1150, 36, 'قهوه'),
(127073, 1154, 36, 'کوچک کردن'),
(127074, 1155, 36, 'کوچک کردن'),
(127075, 1156, 36, 'کوچک کردن همه'),
(127076, 1157, 36, 'کوچک کردن همه'),
(127077, 1158, 36, 'کوچک کردن همه'),
(127078, 1161, 36, 'مجموعه'),
(127079, 1162, 36, 'گزارش مجموعه'),
(127080, 1166, 36, 'Colonoscopy'),
(127081, 1167, 36, 'colonoscopy'),
(127082, 1168, 36, 'رنگ'),
(127083, 1170, 36, 'ستون'),
(127084, 1171, 36, 'ستونها'),
(127085, 1173, 36, 'ویرگول'),
(127086, 1174, 36, 'توضیح'),
(127087, 1175, 36, 'توضیحات'),
(127088, 1178, 36, 'تصدیق تغییرات'),
(127089, 1180, 36, 'ارتباطات'),
(127090, 1182, 36, 'شرکت'),
(127091, 1183, 36, 'نام شرکت'),
(127092, 1184, 36, 'کامل'),
(127093, 1186, 36, 'تکمیل شده'),
(127094, 1188, 36, 'تکمیل شد؟'),
(127095, 1191, 36, 'عوارض سقط جنین'),
(127096, 1194, 36, 'نتایج'),
(127097, 1199, 36, 'تنظیمات'),
(127098, 1208, 36, 'تایید ایجاد بیمار جدید'),
(127099, 1209, 36, 'تایید رمز عبور جدید'),
(127100, 1210, 36, 'تایید پرداخت'),
(127101, 1214, 36, 'مادر زادی'),
(127102, 1217, 36, 'اتصال دهنده ها'),
(127103, 1218, 36, 'عدد ثابت'),
(127104, 1219, 36, 'نام عدد ثابت'),
(127105, 1220, 36, 'نام عدد ثابت خالی است'),
(127106, 1221, 36, 'اعدادثابت'),
(127107, 1222, 36, 'یبوست'),
(127108, 1223, 36, 'در قانون اساسی'),
(127109, 1226, 36, 'شرح مختصر مشاوره'),
(127110, 1227, 36, 'تماس'),
(127111, 1228, 36, 'آدرس پست الکترونیکی'),
(127112, 1229, 36, 'آدرس ایمیل فرد آشنا'),
(127113, 1231, 36, 'اطلاعات فرد آشنا'),
(127114, 1232, 36, 'لنز'),
(127115, 1236, 36, 'نام فرد آشنا'),
(127116, 1237, 36, 'فرد آشنا'),
(127117, 1239, 36, 'شماره تلفن فرد آشنا'),
(127118, 1243, 36, 'محتوا'),
(127119, 1244, 36, 'محتوا'),
(127120, 1245, 36, 'زمینه'),
(127121, 1247, 36, 'ادامه'),
(127122, 1248, 36, 'سند تداوم مراقبت (CCD)'),
(127123, 1249, 36, 'سابقه تداوم مراقبت (CCR)'),
(127124, 1251, 36, 'پیشگیری از بارداری'),
(127125, 1252, 36, 'مسائل مربوط به پیشگیری از بارداری'),
(127126, 1253, 36, 'عوارض پیشگیری از بارداری (مشخص کنید)'),
(127127, 1254, 36, 'روشهای پیشگیری از بارداری'),
(127128, 1255, 36, 'محصولات پیشگیری از بارداری'),
(127129, 1258, 36, 'شناسه کنترل'),
(127130, 1259, 36, 'شماره کنترل'),
(127131, 1261, 36, 'فرانشیز'),
(127132, 1262, 36, 'فرانشیز'),
(127133, 1263, 36, 'فرانشیز'),
(127134, 1266, 36, 'فرانشیز ها'),
(127135, 1267, 36, 'COPD'),
(127136, 1273, 36, 'Coronary Artery Bypass'),
(127137, 1274, 36, 'Coronary Artery Bypass Graft (CABG)'),
(127138, 1289, 36, 'سرفه'),
(127139, 1290, 36, 'سرفه:'),
(127140, 1304, 36, 'مشاوره'),
(127141, 1305, 36, 'فعالیت های مشاوره'),
(127142, 1306, 36, 'فرم پاسخ ارجاع'),
(127143, 1307, 36, 'پاسخ ارجاع'),
(127144, 1308, 36, 'کشور'),
(127145, 1310, 36, 'فهرست کشورها'),
(127146, 1313, 36, 'بخش'),
(127147, 1315, 36, 'کوپن'),
(127148, 1325, 36, 'کرم'),
(127149, 1329, 36, 'ایجاد یک رویداد'),
(127150, 1330, 36, 'ایجاد و دانلود یک نسخه ی پشتیبان کامل'),
(127151, 1332, 36, 'ایجاد پشتیبان گیری'),
(127152, 1336, 36, 'ایجاد کپی'),
(127153, 1338, 36, 'تهیه نسخه پشتیبان از ثبت رویدادها'),
(127154, 1339, 36, 'ایجاد مسئله جدید'),
(127155, 1340, 36, 'ایجاد بیمار جدید'),
(127156, 1346, 36, 'ایجاد یک ملاقات'),
(127157, 1347, 36, 'ایجاد شد'),
(127158, 1351, 36, 'ایجاد کننده'),
(127159, 1352, 36, 'اعتبار'),
(127160, 1353, 36, 'کارت اعتباری'),
(127161, 1354, 36, 'اعتبارات'),
(127162, 1356, 36, 'معیارها'),
(127163, 1358, 36, 'Crohn''s Disease'),
(127164, 1359, 36, 'Crohns Disease'),
(127165, 1369, 36, 'کنونی'),
(127166, 1370, 36, 'الکل کنونی'),
(127167, 1371, 36, 'مشاوره جاری'),
(127168, 1372, 36, 'شرایط جاری'),
(127169, 1377, 36, 'مکان جاری'),
(127170, 1378, 36, 'داروهای جاری'),
(127171, 1379, 36, 'رمز عبور جاری'),
(127172, 1380, 36, 'بیمار جاری'),
(127173, 1382, 36, 'مواد مخدر تفریحی جاری'),
(127174, 1388, 36, 'در حال حاضر درمانگاهی وجود ندارد.'),
(127175, 1389, 36, 'Cushing Syndrom'),
(127176, 1390, 36, 'Cushing Syndrome'),
(127177, 1407, 36, 'تولد'),
(127178, 1408, 36, 'روزانه'),
(127179, 1409, 36, 'رکورد روزانه'),
(127180, 1410, 36, 'دانمارکی'),
(127181, 1413, 36, 'ستون های داده ها'),
(127182, 1416, 36, 'خطا در داده ها'),
(127183, 1420, 36, 'نوع داده'),
(127184, 1421, 36, 'پایگاه داده ها'),
(127185, 1422, 36, 'پایگاه داده ها نصب نشده است.'),
(127186, 1423, 36, 'پچ پایگاه داده'),
(127187, 1424, 36, 'گزارش پایگاه داده ها'),
(127188, 1425, 36, 'ارتقاء پایگاه داده ها به پایان رسید.'),
(127189, 1427, 36, 'تاریخ'),
(127190, 1428, 36, 'تاریخ'),
(127191, 1431, 36, 'تاریخ تجویز'),
(127192, 1432, 36, 'تاریخ و زمان جمع آوری نمونه'),
(127193, 1433, 36, 'تاریخ و زمان این مشاهده'),
(127194, 1435, 36, 'تاریخ و زمانی که نمونه جمع آوری شد'),
(127195, 1438, 36, 'تاریخ ایجاد'),
(127196, 1439, 36, 'تاریخ فوت'),
(127197, 1440, 36, 'تاریخ تخریب'),
(127198, 1451, 36, 'تاریخ صورتحساب'),
(127199, 1452, 36, 'تاریخ تولد'),
(127200, 1453, 36, 'تاریخ تولد'),
(127201, 1454, 36, 'تاریخ تولد'),
(127202, 1455, 36, 'تاریخ ورود'),
(127203, 1456, 36, 'تاریخ آسیب دیدگی'),
(127204, 1459, 36, 'تاریخ ارجاع'),
(127205, 1460, 36, 'تاریخ پاسخ'),
(127206, 1462, 36, 'تاریخ خدمات'),
(127207, 1463, 36, 'تاریخ خدمات'),
(127208, 1464, 36, 'تاریخ خدمات = امروز'),
(127209, 1466, 36, 'تاریخ خدمت:'),
(127210, 1467, 36, 'تاریخ امضاء'),
(127211, 1469, 36, 'تاریخ این دستور'),
(127212, 1470, 36, 'تاریخ این گزارش'),
(127213, 1472, 36, 'تاریخ سفارش'),
(127214, 1475, 36, 'انتخاب تاریخ'),
(127215, 1476, 36, 'تاریخ ارسال'),
(127216, 1477, 36, 'تاریخ ارسال پیام'),
(127217, 1479, 36, 'تاریخ نمی تواند خالی.'),
(127218, 1480, 36, 'تاریخ/قرار ملاقات'),
(127219, 1481, 36, 'تاریخ/یادداشت ها'),
(127220, 1484, 36, 'تاریخ:'),
(127221, 1485, 36, 'فهرست مورخ رویداد پیام ها'),
(127222, 1486, 36, 'روزانه'),
(127223, 1487, 36, 'روز'),
(127224, 1489, 36, 'نمای روزانه'),
(127225, 1490, 36, 'روز(ها)'),
(127226, 1492, 36, 'روز'),
(127227, 1493, 36, 'روزها'),
(127228, 1494, 36, 'روزهای قبل'),
(127229, 1495, 36, 'روزها و بازی های از دست رفته'),
(127230, 1497, 36, 'روزهای از دست رفته'),
(127231, 1498, 36, 'تعداد روز ها در هر ستون:'),
(127232, 1511, 36, 'ناشنوا'),
(127233, 1512, 36, 'اطلاعات برای اشکالزدایی'),
(127234, 1515, 36, 'دسامبر'),
(127235, 1516, 36, 'مرحوم'),
(127236, 1517, 36, 'دسامبر'),
(127237, 1522, 36, 'پیش فرض'),
(127238, 1526, 36, 'درمانگاه پیش فرض'),
(127239, 1538, 36, 'دلیل پیش فرض برای ملاقات'),
(127240, 1540, 36, 'تنظیمات پیش فرض'),
(127241, 1541, 36, 'حالت پیش فرض برای گزینه صفحه جدید در فهرست بیماران.'),
(127242, 1546, 36, 'واحد های پیش فرض'),
(127243, 1547, 36, 'مقدار پیش فرض'),
(127244, 1548, 36, 'انبار پیش فرض'),
(127245, 1551, 36, 'حذف'),
(127246, 1552, 36, 'حذف'),
(127247, 1554, 36, 'حذف'),
(127248, 1555, 36, 'حذف'),
(127249, 1556, 36, 'حذف دسته بندی ها با شناسه (ها): '),
(127250, 1557, 36, 'حذف دسته بندی'),
(127251, 1560, 36, 'حذف گروه'),
(127252, 1561, 36, 'حذف لیست'),
(127253, 1562, 36, 'حذف صفحات'),
(127254, 1565, 36, 'حذف سطر'),
(127255, 1566, 36, 'حذف اقلام انتخاب شده'),
(127256, 1568, 36, 'حذف موفقیت آمیز بود.'),
(127257, 1569, 36, 'این سند را حذف کنید'),
(127258, 1570, 36, 'این فرم را حذف کنید'),
(127259, 1571, 36, 'این یادداشت را حذف کنید'),
(127260, 1573, 36, 'با موفقیت حذف شد.'),
(127261, 1581, 36, 'زوال عقل'),
(127262, 1582, 36, 'آمار دموگرافیک'),
(127263, 1583, 36, 'آمار دموگرافیک (نوشتن، اضافه کردن تنها اختیاری است)'),
(127264, 1585, 36, 'ضوابط فیلتر آمار دموگرافیک'),
(127265, 1586, 36, 'آمار دموگرافیک مجاز نیست'),
(127266, 1587, 36, 'آمار دموگرافیک مجاز نیست.'),
(127267, 1588, 36, 'رد شد'),
(127268, 1589, 36, 'مخرج'),
(127269, 1590, 36, 'دندانپزشکی'),
(127270, 1592, 36, 'مسائل مربوط به دندانپزشکی'),
(127271, 1596, 36, 'تاریخ واریز'),
(127272, 1597, 36, 'تاریخ واریز نمی تواند بزرگتر از امروز باشد'),
(127273, 1598, 36, 'تاریخ واریز:'),
(127274, 1599, 36, 'افسرده'),
(127275, 1600, 36, 'افسردگی'),
(127276, 1602, 36, 'شرح'),
(127277, 1603, 36, 'شرح'),
(127278, 1605, 36, 'شرح افشاء نامه'),
(127279, 1607, 36, 'ترجمه شرح'),
(127280, 1609, 36, 'مقصد'),
(127281, 1610, 36, 'نام فایل مقصد'),
(127282, 1612, 36, 'نابود کردن ...'),
(127283, 1613, 36, 'نابود شده'),
(127284, 1614, 36, 'مواد مخدر نابود شده'),
(127285, 1615, 36, 'گزارش مواد مخدر نابود شده'),
(127286, 1616, 36, 'جزئیات'),
(127287, 1617, 36, 'جزئیات'),
(127288, 1620, 36, 'دیابت'),
(127289, 1623, 36, 'دیابت: معاینه چشم'),
(127290, 1624, 36, 'دیابت: معاینه چشم (CQM)'),
(127291, 1625, 36, 'دیابت: معاینه پا'),
(127292, 1626, 36, 'دیابت: معاینه پا (CQM)'),
(127293, 1627, 36, 'Diabetes: HbA1c Poor Control (CQM)'),
(127294, 1628, 36, 'Diabetes: Hemoglobin A1C'),
(127295, 1629, 36, 'Diabetes: LDL Management & Control (CQM)'),
(127296, 1630, 36, 'Diabetes: Urine Microalbumin'),
(127297, 1631, 36, 'تشخیص'),
(127298, 1632, 36, 'تشخیص ها'),
(127299, 1633, 36, 'تشخیص'),
(127300, 1634, 36, 'کد تشخیص'),
(127301, 1636, 36, 'تاریخ تشخیص'),
(127302, 1638, 36, 'نام تشخیص'),
(127303, 1639, 36, 'گزارش تشخیص'),
(127304, 1640, 36, 'گزارشگری تشخیص'),
(127305, 1641, 36, 'فقط گزارشگری تشخیص'),
(127306, 1642, 36, 'عنوان تشخیص'),
(127307, 1643, 36, 'تشخیص:'),
(127308, 1644, 36, 'تشخیص: '),
(127309, 1645, 36, 'تست های تشخیصی:'),
(127310, 1647, 36, 'Diaphragms/Caps'),
(127311, 1648, 36, 'اسهال'),
(127312, 1650, 36, 'دیکته کردن'),
(127313, 1651, 36, 'دیکته کردن: '),
(127314, 1654, 36, 'امضا دیجیتالی'),
(127315, 1657, 36, 'پست مستقیم'),
(127316, 1663, 36, 'نام مدیر'),
(127317, 1665, 36, 'از کار افتادگی'),
(127318, 1667, 36, 'غیر فعال کردن تقویم'),
(127319, 1668, 36, 'غیر فعال کردن ردیاب پرونده'),
(127320, 1669, 36, 'غیر فعال کردن واکسیناسیون'),
(127321, 1670, 36, 'غیر فعال کردن فرم قدیمی علائم حیاتی به سیستم متری'),
(127322, 1672, 36, 'غیر فعال کردن از phpMyAdmin'),
(127323, 1673, 36, 'غیر فعال کردن نسخه ها'),
(127324, 1674, 36, 'غیر فعال کردن گروه های کاربری'),
(127325, 1675, 36, 'از کار افتاده'),
(127326, 1676, 36, 'از کار افتاده'),
(127327, 1681, 36, 'Discharge'),
(127328, 1682, 36, 'ترشح از مجرای خروجی مثانه'),
(127329, 1689, 36, 'اطلاعات افشاء'),
(127330, 1690, 36, 'نوع افشاء'),
(127331, 1691, 36, 'انواع افشاء'),
(127332, 1692, 36, 'فاش سازی ها'),
(127333, 1694, 36, 'تخفیف'),
(127334, 1695, 36, 'مبلغ تخفیف'),
(127335, 1696, 36, 'سطح تخفیف'),
(127336, 1697, 36, 'درصد تخفیف'),
(127337, 1698, 36, 'تخفیف به صورت مبلغ پولی'),
(127338, 1699, 36, 'میزان تخفیف در زمان مرخص شدن بیمار با درج مبلغ وارد شود، نه به صورت درصد.'),
(127339, 1701, 36, 'بیماری'),
(127340, 1702, 36, 'دررفتگی'),
(127341, 1704, 36, 'اعزام'),
(127342, 1705, 36, 'اعزام سند دریافتی'),
(127343, 1706, 36, 'توزیع'),
(127344, 1707, 36, 'نمایش دستورات پیشاپیش در صفحه اطلاعات دموگرافیک.'),
(127345, 1709, 36, 'نمایش تاریخ رویداد در بلوک؟'),
(127346, 1711, 36, 'نمایش تعداد رویدادها؟'),
(127347, 1713, 36, 'نمایش مکان در بلوک؟'),
(127348, 1714, 36, 'نمایش نام'),
(127349, 1715, 36, 'نمایش تقویم؟'),
(127350, 1718, 36, 'نمایش حوادث امروز در بلوک؟'),
(127351, 1719, 36, 'نمایش موضوع در بلوک؟'),
(127352, 1720, 36, 'نمایش رویدادهای آینده در بلوک؟'),
(127353, 1721, 36, 'ستون نمایش داده شده'),
(127354, 1722, 36, 'نمایش این تعداد از افشاگریهای اخیر:'),
(127355, 1723, 36, 'نمایش این تعداد از یادداشت های اخیر'),
(127356, 1724, 36, 'نمایش این تعداد از یادداشت های اخیر:'),
(127357, 1725, 36, 'توزیع'),
(127358, 1726, 36, 'توزیع ها'),
(127359, 1727, 36, 'توزیع کننده'),
(127360, 1729, 36, 'Diverticulitis'),
(127361, 1730, 36, 'Diverticulitis Surgery'),
(127362, 1731, 36, 'Divirticulitis'),
(127363, 1732, 36, 'Divirticulitis Surgery'),
(127364, 1733, 36, 'طلاق رسمی'),
(127365, 1734, 36, 'سرگیجه:'),
(127366, 1735, 36, 'تغییر ندهید'),
(127367, 1737, 36, 'آلرژی ارسال شده به NewCrop را نمایش ندهید'),
(127368, 1739, 36, 'داروهای ارسال شده NewCrop را نمایش ندهید'),
(127369, 1742, 36, 'تقویم را نشان ندهید.'),
(127370, 1744, 36, 'هیچ محصولی را ذخیره نکرده و نفروشید'),
(127371, 1745, 36, 'ملزوم نکنید که یادداشت های بیمار مجاز شود'),
(127372, 1746, 36, 'رضایت نامه شخصی'),
(127373, 1747, 36, 'ذخیره نکنید'),
(127374, 1748, 36, 'جایگزین نکنید'),
(127375, 1749, 36, 'کاری انجام ندهید'),
(127376, 1751, 36, 'آیا واقعا می خواهید حذف کنید'),
(127377, 1752, 36, 'آیا واقعا می خواهید این گزینش را پاک کنید؟'),
(127378, 1753, 36, 'آیا واقعا می خواهید این گروه را حذف کنید'),
(127379, 1755, 36, 'آیا می خواهید ادامه دهید؟'),
(127380, 1756, 36, 'آیا می خواهید این را حذف کنید؟'),
(127381, 1757, 36, 'آیا می خواهید حذف کنید؟'),
(127382, 1758, 36, 'آیا می خواهید این رکورد را حذف کنید؟'),
(127383, 1759, 36, 'آیا میخواهید به اضافه کردن این بیمار جدید ادامه دهید؟'),
(127384, 1760, 36, 'آیا میخواهید با این نام جدید ادامه دهید؟'),
(127385, 1761, 36, 'آیا می خواهید این سابقه واکسیناسیون را برای همیشه حذف کنید؟'),
(127386, 1762, 36, 'تولد'),
(127387, 1763, 36, 'تاریخ تولد قید نشده، لطفا در صورت امکان وارد نمایید'),
(127388, 1764, 36, 'اسناد'),
(127389, 1765, 36, 'دکتر'),
(127390, 1766, 36, 'دکتر:'),
(127391, 1767, 36, 'نام و امضای دکتر'),
(127392, 1768, 36, 'سند'),
(127393, 1769, 36, 'سند'),
(127394, 1770, 36, 'دسته بندی های اسناد'),
(127395, 1775, 36, 'سند به شناسه بیمار منتقل نمی شود'),
(127396, 1777, 36, 'تاریخ سند'),
(127397, 1778, 36, 'تاریخ و مسئله سند با موفقیت به روز شد'),
(127398, 1779, 36, 'شناسه سند'),
(127399, 1780, 36, 'سند به دسته بندی جدید نقل مکان کرد'),
(127400, 1781, 36, 'سند به شناسه بیمار نقل مکان کرد'),
(127401, 1783, 36, 'درستی‌ فایل تصدیق شد.'),
(127402, 1784, 36, 'روش ذخیره سازی سند'),
(127403, 1785, 36, 'سند با موفقیت تغییر نام داد.'),
(127404, 1790, 36, 'ذخیره سند/تصویربرداری'),
(127405, 1791, 36, 'اسناد'),
(127406, 1792, 36, 'اسناد (نوشتن، اضافه کردن تنها اختیاری)'),
(127407, 1798, 36, 'آیا این نوع اجازه کدهای مربوطه را می دهد؟'),
(127408, 1799, 36, 'شریک زندگی'),
(127409, 1800, 36, 'ذخیره نکنید'),
(127410, 1801, 36, 'ذخیره نکنید'),
(127411, 1802, 36, 'تغییرات را ذخیره نکنید'),
(127412, 1803, 36, 'انجام شد'),
(127413, 1804, 36, 'انجام شده با:'),
(127414, 1805, 36, 'انجام شد. حالا دانلود ارسال خواهد شد.'),
(127415, 1806, 36, 'تاریخ درمان'),
(127416, 1807, 36, 'مقدار مصرف'),
(127417, 1809, 36, 'برای ویرایش دوبار کلیک کنید'),
(127418, 1810, 36, 'دید دوگانه'),
(127419, 1811, 36, 'دانلود'),
(127420, 1814, 36, 'در هر حال دانلود کنید'),
(127421, 1829, 36, 'ملاقات دکتر'),
(127422, 1830, 36, 'دکتر'),
(127423, 1832, 36, 'Dribbling'),
(127424, 1834, 36, 'دارو'),
(127425, 1835, 36, 'جستجوگر دارو'),
(127426, 1836, 36, 'فرم های دارو'),
(127427, 1837, 36, 'شناسه دارو خالی‌ هست!'),
(127428, 1838, 36, 'فواصل استفاده دارو'),
(127429, 1839, 36, 'فهرست موجودی دارو'),
(127430, 1840, 36, 'نام دارو'),
(127431, 1841, 36, 'مسیرهای دارو'),
(127432, 1845, 36, 'واحدهای دارو'),
(127433, 1846, 36, 'داروها'),
(127434, 1847, 36, 'داروها و محصولات'),
(127435, 1848, 36, 'خشکی دهان'),
(127436, 1860, 36, 'ناشی از'),
(127437, 1861, 36, 'تاریخ مقرر'),
(127438, 1863, 36, 'تاریخ مقرر:'),
(127439, 1875, 36, 'چک تکراری'),
(127440, 1880, 36, 'مدت زمان'),
(127441, 1881, 36, 'مدت زمان');
INSERT INTO `lang_definitions` VALUES
(127442, 1882, 36, 'هلندی'),
(127443, 1884, 36, 'Dysphagia'),
(127444, 1885, 36, 'Dyspnea:'),
(127445, 1886, 36, 'Dysuria'),
(127446, 1893, 36, 'هر گیرنده باید خودش پیامش را به عنوان تکمیل شده تنظیم کند.'),
(127447, 1896, 36, 'نوار قلب'),
(127448, 1898, 36, 'ادم'),
(127449, 1904, 36, 'ویرایش'),
(127450, 1905, 36, 'ویرایش'),
(127451, 1906, 36, 'ویرایش آلرژی ها'),
(127452, 1907, 36, 'ویرایش دسته بندی ها'),
(127453, 1908, 36, 'ویرایش تعاریف'),
(127454, 1909, 36, 'ویرایش تعاریف'),
(127455, 1910, 36, 'ویرایش تشخیص ها برای'),
(127456, 1911, 36, 'ویرایش افشاء'),
(127457, 1912, 36, 'ویرایش درمانگاه ها'),
(127458, 1913, 36, 'ویرایش درمانگاه'),
(127459, 1914, 36, 'ویرایش اطلاعات درمانگاه'),
(127460, 1916, 36, 'ویرایش فایل در'),
(127461, 1917, 36, 'ویرایش فرم'),
(127462, 1918, 36, 'ویرایش تنظیمات سراسری'),
(127463, 1919, 36, 'ویرایش مجاز نیست!'),
(127464, 1920, 36, 'ویرایش چیدمان'),
(127465, 1921, 36, 'ویرایش لیست'),
(127466, 1922, 36, 'ویرایش پرداخت'),
(127467, 1923, 36, 'ویرایش ساختار'),
(127468, 1924, 36, 'ویرایش کاربر'),
(127469, 1925, 36, 'ویرایش تنظیمات کاربر'),
(127470, 1928, 36, 'آموزش'),
(127471, 1929, 36, 'تاریخ آموزش'),
(127472, 1932, 36, 'تاریخ اجرا'),
(127473, 1934, 36, 'اثربخشی'),
(127474, 1935, 36, 'کد اقتصادی'),
(127475, 1936, 36, 'Ejaculations'),
(127476, 1937, 36, 'Elbow'),
(127477, 1938, 36, 'Elbow Problems'),
(127478, 1939, 36, 'الکترونیکی'),
(127479, 1944, 36, 'واجد شرایط بودن'),
(127480, 1948, 36, 'واجد شرایط'),
(127481, 1949, 36, 'پست الکترونیک'),
(127482, 1951, 36, 'آدرس ایمیل'),
(127483, 1956, 36, 'اجازه ایمیل'),
(127484, 1958, 36, 'آگاه سازی با ایمیل'),
(127485, 1959, 36, 'ساعت هشدار با ایمیل'),
(127486, 1960, 36, 'گزارش هشدار با ایمیل'),
(127487, 1961, 36, 'ارسال ایمیل قبل از'),
(127488, 1962, 36, 'فرستنده ایمیل'),
(127489, 1963, 36, 'ایمیل ارسال شد'),
(127490, 1964, 36, 'ایمیل ارسال شد به'),
(127491, 1965, 36, 'عنوان ایمیل'),
(127492, 1971, 36, 'تماس اضطراری'),
(127493, 1972, 36, 'شخص برای تماس اضطراری'),
(127494, 1973, 36, 'شماره تلفن برای تماس اضطراری'),
(127495, 1974, 36, 'قرص های ضد بارداری اضطراری'),
(127496, 1975, 36, 'ورود اضطراری به سیستم'),
(127497, 1976, 36, 'ورود اضطراری ACL انتخاب شده است. این کاربر هنوز فعال است. لطفا این کاربر را غیر فعال کنید و آن را در موقعیت اضطراری و مورد نیاز فعال سازید. برای فعال و غیر فعال سازی حساب کاربری به قسمت "مدیریت > کاربری" مراجعه کنید.'),
(127498, 1980, 36, 'تلفن اضطراری'),
(127499, 1982, 36, 'آمفیزم'),
(127500, 1983, 36, 'کارمند'),
(127501, 1984, 36, 'کارفرما'),
(127502, 1985, 36, 'آدرس کارفرما'),
(127503, 1986, 36, 'داده های کارفرما'),
(127504, 1987, 36, 'نام کارفرما'),
(127505, 1988, 36, 'خالی'),
(127506, 1989, 36, 'خالی'),
(127507, 1991, 36, '"ساعت ایمیل" خالیست'),
(127508, 1992, 36, '"فرستنده ایمیل" خالیست'),
(127509, 1993, 36, '"موضوع ایمیل" خالیست'),
(127510, 1994, 36, '"متن ایمیل" خالیست'),
(127511, 1995, 36, '"نام ارائه دهنده" خالیست'),
(127512, 1996, 36, '"رمز عبور" خالیست'),
(127513, 1997, 36, '"ساعت SMS" خالیست'),
(127514, 1998, 36, '"متن SMS" خالیست'),
(127515, 1999, 36, '"نام کاربری" خالیست'),
(127516, 2072, 36, 'ویزیت'),
(127517, 2073, 36, 'ویزیت'),
(127518, 2074, 36, 'ویزیت'),
(127519, 2075, 36, 'ویزیت '),
(127520, 2081, 36, 'تاریخ ویزیت'),
(127521, 2086, 36, 'فرم های ویزیت'),
(127522, 2088, 36, 'سابقه ویزیت'),
(127523, 2089, 36, 'شناسه ویزیت'),
(127524, 2091, 36, 'شماره ویزیت'),
(127525, 2096, 36, 'ویزیت بیمار در مطب'),
(127526, 2097, 36, 'ویزیت بیمار سرپایی'),
(127527, 2100, 36, 'پرداخت ویزیت'),
(127528, 2108, 36, 'آمار ویزیت'),
(127529, 2109, 36, 'خلاصه ویزیت'),
(127530, 2110, 36, 'ویزیت کد بندی شد'),
(127531, 2111, 36, 'ویزیت:'),
(127532, 2113, 36, 'ویزیت ها'),
(127533, 2114, 36, 'فرمها و ویزیت ها'),
(127534, 2115, 36, 'فرمها و ویزیت ها'),
(127535, 2116, 36, 'ویزیت ها مجاز نیستند'),
(127536, 2117, 36, 'گزارش ویزیت'),
(127537, 2118, 36, 'قسمت ویزیت'),
(127538, 2120, 36, 'رمزگذاری'),
(127539, 2121, 36, 'پایان'),
(127540, 2122, 36, 'پایان (yyyy-mm-dd): '),
(127541, 2123, 36, 'تا تاریخ'),
(127542, 2124, 36, 'تا تاریخ'),
(127543, 2127, 36, 'تا تاریخ:'),
(127544, 2131, 36, 'تا زمان'),
(127545, 2136, 36, 'Endo Abnormal Blood'),
(127546, 2137, 36, 'Endocrine'),
(127547, 2138, 36, 'آندوسکوپی'),
(127548, 2141, 36, 'انگلیسی'),
(127549, 2142, 36, 'انگلیسی '),
(127550, 2143, 36, 'انگلیسی (هند)'),
(127551, 2144, 36, 'انگلیسی (استاندارد)'),
(127552, 2147, 36, 'ENT Discharge'),
(127553, 2148, 36, 'ENT Pain'),
(127554, 2154, 36, 'تشخیص بیماری را وارد کنید'),
(127555, 2155, 36, 'داروها ها را وارد کنید'),
(127556, 2158, 36, 'این واکسیناسیون ها را وارد کنید'),
(127557, 2159, 36, 'کلید رمز را وارد کنید'),
(127558, 2161, 36, 'وضعیت جدید را وارد کنید'),
(127559, 2165, 36, 'شرایط جستجوخود را در بالا وارد کنید'),
(127560, 2167, 36, 'رکورد'),
(127561, 2168, 36, 'محیط زیستی'),
(127562, 2176, 36, 'صرع'),
(127563, 2181, 36, 'پاک کن'),
(127564, 2182, 36, 'سیخ شدن'),
(127565, 2183, 36, 'اشتباه'),
(127566, 2225, 36, 'اشتباه: رمزهای عبور با هم مطابقت ندارند. لطفا تایپ حروف را بررسی کنید.'),
(127567, 2226, 36, 'اشتباه: رمزهای عبور با هم مطابقت ندارند. لطفا تایپ حروف را بررسی کنید.'),
(127568, 2235, 36, 'اشتباهات'),
(127569, 2242, 36, 'Erythema:'),
(127570, 2245, 36, 'اسکیمو'),
(127571, 2247, 36, 'بیمار با سابقه مشخص'),
(127572, 2249, 36, 'قومیت'),
(127573, 2250, 36, 'قومیت یا نژاد'),
(127574, 2251, 36, 'فهرست قومیت - نژاد (نوشتن، اضافه کردن تنها اختیاری)'),
(127575, 2253, 36, 'رویداد'),
(127576, 2254, 36, 'رویداد آغاز می شود'),
(127577, 2255, 36, 'دسته بندی رویداد'),
(127578, 2256, 36, 'تاریخ رویداد'),
(127579, 2257, 36, 'توضیحات رویداد'),
(127580, 2258, 36, 'جزئیات رویداد'),
(127581, 2259, 36, 'رویداد تکرار نمی شود'),
(127582, 2260, 36, 'طول مدت رویداد'),
(127583, 2261, 36, 'طول مدت زمان رویداد به دقیقه'),
(127584, 2262, 36, 'هزینه رویداد'),
(127585, 2263, 36, 'محل رویداد'),
(127586, 2264, 36, 'تکرار رویداد هر'),
(127587, 2265, 36, 'تکرار رویداد'),
(127588, 2266, 36, 'زمان شروع رویداد'),
(127589, 2267, 36, 'عنوان رویداد'),
(127590, 2268, 36, 'عنوان رویداد'),
(127591, 2269, 36, 'وب سایت رویداد'),
(127592, 2270, 36, 'رویدادها'),
(127593, 2271, 36, 'رویدادهای'),
(127594, 2272, 36, 'رویدادها را در صفحه جدید باز میشوند'),
(127595, 2273, 36, 'هر'),
(127596, 2274, 36, 'هر'),
(127597, 2275, 36, 'هر ۳ ساعت'),
(127598, 2276, 36, 'هر ۴ ساعت'),
(127599, 2277, 36, 'هر ۵ ساعت'),
(127600, 2278, 36, 'هر ۶ ساعت'),
(127601, 2279, 36, 'هر ۸ ساعت'),
(127602, 2281, 36, 'یکی‌ در میان'),
(127603, 2285, 36, 'معاینه و نتایج آزمون'),
(127604, 2286, 36, 'نتایج معاینه'),
(127605, 2289, 36, 'معاینه'),
(127606, 2290, 36, 'تاریخ معاینه'),
(127607, 2291, 36, 'مثال'),
(127608, 2292, 36, 'مثالها'),
(127609, 2293, 36, 'معاینه/آزمونها'),
(127610, 2294, 36, 'بجز'),
(127611, 2297, 36, 'حذف'),
(127612, 2300, 36, 'ورزش'),
(127613, 2301, 36, 'الگوهای ورزش'),
(127614, 2302, 36, 'الگوهای ورزش'),
(127615, 2303, 36, 'وجود دارد'),
(127616, 2304, 36, 'خروج از مدیریت نرم افزار'),
(127617, 2306, 36, 'گسترش'),
(127618, 2307, 36, 'گسترش'),
(127619, 2308, 36, 'گسترش همه'),
(127620, 2311, 36, 'نمایش گسترده'),
(127621, 2313, 36, 'انقضاء'),
(127622, 2314, 36, 'تاریخ انقضاء'),
(127623, 2315, 36, 'منقضی می شود'),
(127624, 2316, 36, 'منقضی می شود در'),
(127625, 2317, 36, 'صادر کردن'),
(127626, 2318, 36, 'صادر کردن به صورت CSV'),
(127627, 2322, 36, 'صادر کردن جمعیت شناسی بیمار'),
(127628, 2325, 36, 'صادر کردن انتخاب شده به صورت CSV'),
(127629, 2327, 36, 'صادر کردن به CSV'),
(127630, 2328, 36, 'صادر کردن به سیستم حسابداری خارجی'),
(127631, 2329, 36, 'قرار گرفتن در معرض کشورهای خارجی'),
(127632, 2330, 36, 'قرار گرفتن در معرض کشورهای خارجی'),
(127633, 2332, 36, 'بیرونی'),
(127634, 2334, 36, 'بارهای داده های بیرونی'),
(127635, 2335, 36, 'ابزار واردات پایگاه داده های بیرونی'),
(127636, 2336, 36, 'شناسه بیرونی'),
(127637, 2337, 36, 'شناسه بیرونی'),
(127638, 2338, 36, 'شناسه بیرونی'),
(127639, 2339, 36, 'فقط بیرونی'),
(127640, 2342, 36, 'ارجاع بیرونی'),
(127641, 2343, 36, 'پیگیری ارجاع بیرونی'),
(127642, 2344, 36, 'ارجاع بیرونی؟'),
(127643, 2345, 36, 'ارجاعات بیرونی'),
(127644, 2346, 36, 'استخراج فایل ZIP'),
(127645, 2347, 36, 'در حال استخراج فایل. این کار کمی طول می کشد ...'),
(127646, 2349, 36, 'سوزش چشم'),
(127647, 2350, 36, 'درد چشم'),
(127648, 2351, 36, 'قرمزی چشم'),
(127649, 2352, 36, 'چشم ها'),
(127650, 2354, 36, 'F/H Blood Problems'),
(127651, 2355, 36, 'F/H Female Hirsutism/Striae'),
(127652, 2356, 36, 'درمانگاه ها'),
(127653, 2357, 36, 'درمانگاه'),
(127654, 2358, 36, 'درمانگاه'),
(127655, 2359, 36, 'مدیریت درمانگاه'),
(127656, 2360, 36, 'شهر درمانگاه'),
(127657, 2361, 36, 'کد درمانگاه'),
(127658, 2362, 36, 'کد کشوری درمانگاه'),
(127659, 2363, 36, 'نمابر درمانگاه'),
(127660, 2364, 36, 'نام درمانگاه'),
(127661, 2365, 36, 'شماره پروانه بهره برداری'),
(127662, 2366, 36, 'شماره تلفن درمانگاه'),
(127663, 2368, 36, 'وضعیت درمانگاه'),
(127664, 2369, 36, 'خیابان درمانگاه'),
(127665, 2370, 36, 'کد پستی درمانگاه'),
(127666, 2372, 36, 'درمانگاه:'),
(127667, 2383, 36, 'عدم موفقیت'),
(127668, 2390, 36, 'سابقه خانوادگی'),
(127669, 2391, 36, 'سابقه خانوادگی گلوکوم'),
(127670, 2392, 36, 'سابقه خانوادگی:'),
(127671, 2394, 36, 'پرداخت های خانواده'),
(127672, 2395, 36, 'تعداد افراد خانواده'),
(127673, 2398, 36, 'فارسی'),
(127674, 2400, 36, 'پدر'),
(127675, 2402, 36, 'خستگی'),
(127676, 2403, 36, 'خسته'),
(127677, 2404, 36, 'فکس'),
(127678, 2405, 36, 'شمارش فکس'),
(127679, 2406, 36, 'شماره فکس'),
(127680, 2411, 36, 'ویژگی ها'),
(127681, 2412, 36, 'فوریه'),
(127682, 2413, 36, 'فوریه'),
(127683, 2418, 36, 'هزینه'),
(127684, 2419, 36, 'هزینه'),
(127685, 2420, 36, 'هزینه مجاز نمی باشد'),
(127686, 2421, 36, 'جدول هزینه'),
(127687, 2422, 36, 'گزینه های جدول هزینه'),
(127688, 2423, 36, 'هزینه ها'),
(127689, 2424, 36, 'زن'),
(127690, 2434, 36, 'تب'),
(127691, 2435, 36, ':تب:'),
(127692, 2447, 36, 'پرونده'),
(127693, 2456, 36, 'فایلی برای آپلود'),
(127694, 2461, 36, 'پرونده ها'),
(127695, 2468, 36, 'فیلتر'),
(127696, 2472, 36, 'فیلترها'),
(127697, 2473, 36, 'فیلترها'),
(127698, 2474, 36, 'نهایی'),
(127699, 2475, 36, 'تشخیص نهایی'),
(127700, 2476, 36, 'تشخیص نهایی متخصص'),
(127701, 2478, 36, 'مالی'),
(127702, 2482, 36, 'تاریخ بررسی مالی'),
(127703, 2483, 36, 'شرح مختصر مالی بر اساس کد خدمات'),
(127704, 2484, 36, 'جستجو'),
(127705, 2485, 36, 'جستجوی وقت آزاد'),
(127706, 2486, 36, 'جستجوی وقت ملاقات آزاد'),
(127707, 2487, 36, 'جستجوی بیمار'),
(127708, 2488, 36, 'یافتن مطالب آموزشی بیمار'),
(127709, 2489, 36, 'یافته ها'),
(127710, 2490, 36, 'یافته های متخصص'),
(127711, 2492, 36, 'پایان پرداخت'),
(127712, 2493, 36, 'به پایان رسیده'),
(127713, 2497, 36, 'روز اول هفته'),
(127714, 2498, 36, 'نام'),
(127715, 2499, 36, 'نام'),
(127716, 2500, 36, 'نام:'),
(127717, 2503, 36, 'آمادگی جسمی'),
(127718, 2504, 36, 'سطح آمادگی جسمی'),
(127719, 2505, 36, 'سطح آمادگی جسمی این بازیکن در این روز'),
(127720, 2507, 36, 'آمادگی جسمی برای بازی'),
(127721, 2514, 36, 'Flu season'),
(127722, 2515, 36, 'Flu Season'),
(127723, 2516, 36, 'Flu Vaccination'),
(127724, 2517, 36, 'Fluid and electrolyte problem'),
(127725, 2529, 36, 'پیگیری خدمات'),
(127726, 2530, 36, 'پیگیری ها قید شده اند'),
(127727, 2531, 36, 'عدم تحمل غذایی'),
(127728, 2532, 36, 'پا'),
(127729, 2533, 36, 'مشکلات پا'),
(127730, 2534, 36, 'پا:'),
(127731, 2535, 36, 'آسیب دیدگی های فوتبال'),
(127732, 2537, 36, 'گزارش آسیب دیدگی های فوتبال'),
(127733, 2538, 36, 'نوع کفش'),
(127734, 2539, 36, 'برای'),
(127735, 2540, 36, 'برای'),
(127736, 2541, 36, 'برای کد'),
(127737, 2544, 36, 'برای مثال:'),
(127738, 2547, 36, 'برای فاکتور'),
(127739, 2554, 36, 'برای متغیر'),
(127740, 2555, 36, 'برای:'),
(127741, 2559, 36, 'بازو'),
(127742, 2560, 36, 'فرم'),
(127743, 2564, 36, 'قالب'),
(127744, 2565, 36, 'قالب'),
(127745, 2570, 36, 'گزارش فرمت شده'),
(127746, 2571, 36, 'سیگاری سابق'),
(127747, 2572, 36, 'فرم ها'),
(127748, 2573, 36, 'مدیریت فرم ها'),
(127749, 2575, 36, 'فرستادن'),
(127750, 2576, 36, 'فرستادن صفحات از طریق فکس'),
(127751, 2577, 36, 'فرستاده شده'),
(127752, 2579, 36, 'چهارم'),
(127753, 2581, 36, 'شکستگی'),
(127754, 2582, 36, 'شکستگی نویکل'),
(127755, 2583, 36, 'شکستگی قوزک جانبی'),
(127756, 2584, 36, 'شکستگی قوزک داخلی'),
(127757, 2585, 36, 'شکستگی قاعده متاتارس پنجم'),
(127758, 2587, 36, 'فرانسوی'),
(127759, 2588, 36, 'فرانسوی (کانادا)'),
(127760, 2589, 36, 'فرانسوی (استاندارد)'),
(127761, 2590, 36, 'فرکانس'),
(127762, 2591, 36, 'سرماخوردگیهای مکرر'),
(127763, 2592, 36, 'بیماری های مکرر'),
(127764, 2593, 36, 'جمعه'),
(127765, 2594, 36, 'جمعه'),
(127766, 2595, 36, 'از'),
(127767, 2596, 36, 'از'),
(127768, 2597, 36, 'از'),
(127769, 2599, 36, 'از:'),
(127770, 2600, 36, 'از: '),
(127771, 2613, 36, 'دفتر جلو'),
(127772, 2614, 36, 'رسیدهای دفتر جلو'),
(127773, 2615, 36, 'گزارش رسیدهای دفتر جلو'),
(127774, 2617, 36, 'پیشانی راست:'),
(127775, 2619, 36, 'نام کامل'),
(127776, 2620, 36, 'مسیر کامل دایرکتوری حاوی اجرایی های MySQL.'),
(127777, 2621, 36, 'مسیر کامل دایرکتوری حاوی اجرایی های Perl.'),
(127778, 2622, 36, 'مسیر کامل دایرکتوری تهیه پشتیبان رویدادها.'),
(127779, 2623, 36, 'مسیر کامل دایرکتوری برای فایل های موقت.'),
(127780, 2624, 36, 'پخش کامل'),
(127781, 2625, 36, 'آموزشی کامل'),
(127782, 2626, 36, 'کاملا پرداخت شده'),
(127783, 2636, 36, 'Gall Bladder Condition'),
(127784, 2637, 36, 'Gall Stones'),
(127785, 2644, 36, 'ورم معده'),
(127786, 2645, 36, 'درد معده'),
(127787, 2646, 36, 'دستگاه گوارش'),
(127788, 2649, 36, 'فرم ملاقات GCAC از دست رفته است'),
(127789, 2650, 36, 'جنس'),
(127790, 2651, 36, 'جنس '),
(127791, 2652, 36, 'عمومی'),
(127792, 2668, 36, 'ایجاد فاکتور'),
(127793, 2669, 36, 'ایجاد نامه'),
(127794, 2670, 36, 'ایجاد نامه در مورد '),
(127795, 2677, 36, 'ایجاد گزارش'),
(127796, 2684, 36, 'Genitourinary'),
(127797, 2687, 36, 'آلمانی'),
(127798, 2692, 36, 'گلوکوم یا آب سیاه'),
(127799, 2693, 36, 'تاریخچه خانوادگی گلوکوم یا آب سیاه'),
(127800, 2694, 36, 'سراسری'),
(127801, 2696, 36, 'شناسه سراسری'),
(127802, 2697, 36, 'تنظیمات سراسری'),
(127803, 2698, 36, 'تنظیمات سراسری'),
(127804, 2700, 36, 'برو'),
(127805, 2701, 36, 'برو'),
(127806, 2704, 36, 'برو به'),
(127807, 2705, 36, 'برو به هفته'),
(127808, 2706, 36, 'برو به امروز'),
(127809, 2711, 36, 'درجه آسیب دیدگی'),
(127810, 2712, 36, 'درجه:'),
(127811, 2713, 36, 'گرم'),
(127812, 2714, 36, 'جمع کل'),
(127813, 2715, 36, 'جمع کل'),
(127814, 2720, 36, 'بزرگتر از'),
(127815, 2721, 36, 'بزرگتر از یا مساوی با'),
(127816, 2722, 36, 'یونانی'),
(127817, 2724, 36, 'گروه'),
(127818, 2725, 36, 'نام گروه'),
(127819, 2726, 36, 'نام گروه نمی تواند خالی باشد'),
(127820, 2727, 36, 'نام گروه نمی تواند با اعداد یا فاصله شروع می شود.'),
(127821, 2728, 36, 'نام گروه نمی تواند با اعداد شروع می شود.'),
(127822, 2729, 36, 'شماره گروه'),
(127823, 2730, 36, 'پرداخت گروه'),
(127824, 2731, 36, 'گروه:'),
(127825, 2732, 36, 'نام گروه'),
(127826, 2733, 36, 'گروه ها و کنترلهای دسترسی'),
(127827, 2734, 36, 'نمودار رشد'),
(127828, 2735, 36, 'نمودار رشد'),
(127829, 2739, 36, 'نام قیم'),
(127830, 2741, 36, 'Gynecological Exam'),
(127831, 2743, 36, 'h.s.'),
(127832, 2744, 36, 'H/O Hepatitis'),
(127833, 2746, 36, 'Haematoma / bruising'),
(127834, 2750, 36, 'دست + انگشتان'),
(127835, 2751, 36, 'مشکلات دست'),
(127836, 2754, 36, 'به ملاقات مربوط شده است'),
(127837, 2755, 36, 'منقضی شده است'),
(127838, 2760, 36, 'اهل هاوایی'),
(127839, 2761, 36, 'فعالیت های خطرناک'),
(127840, 2762, 36, 'فعالیت های خطرناک'),
(127841, 2768, 36, 'سر'),
(127842, 2769, 36, 'دور سر'),
(127843, 2770, 36, 'دور سر'),
(127844, 2771, 36, 'سردرد'),
(127845, 2772, 36, 'سردرد ها'),
(127846, 2773, 36, 'عملیات بهداشتی و درمانی'),
(127847, 2774, 36, 'عملیات بهداشتی و درمانی'),
(127848, 2775, 36, 'مرکز بهداشتی/درمانگاه'),
(127849, 2778, 36, 'از دست دادن شنوایی'),
(127850, 2779, 36, 'سکته قلبی'),
(127851, 2780, 36, 'بیماری قلبی'),
(127852, 2781, 36, 'نارسایی قلب'),
(127853, 2782, 36, 'مشکل قلبی'),
(127854, 2783, 36, 'مشکلات قلبی'),
(127855, 2784, 36, 'جراحی قلب'),
(127856, 2785, 36, 'پیوند قلب'),
(127857, 2786, 36, 'قلب:'),
(127858, 2787, 36, 'سوزش معده'),
(127859, 2788, 36, 'گرما یا سرما'),
(127860, 2789, 36, 'گرما یا سرما'),
(127861, 2791, 36, 'زبان عبری'),
(127862, 2794, 36, 'ارتفاع'),
(127863, 2796, 36, 'کمک'),
(127864, 2797, 36, 'کمک'),
(127865, 2798, 36, 'هماتمز/خونی'),
(127866, 2799, 36, 'هماتوشزی/ادرار خونی'),
(127867, 2800, 36, 'هماتولوژیک'),
(127868, 2801, 36, 'هماچوری'),
(127869, 2802, 36, 'هموگلوبین'),
(127870, 2803, 36, 'هموگلوبین A1c'),
(127871, 2804, 36, 'هموپتیزی/استفراغ خونی'),
(127872, 2805, 36, 'هپاتیت'),
(127873, 2806, 36, 'هپاتیت A 1'),
(127874, 2807, 36, 'هپاتیت A 2'),
(127875, 2808, 36, 'هپاتیت B 1'),
(127876, 2809, 36, 'هپاتیت B 2'),
(127877, 2810, 36, 'هپاتیت B 3'),
(127878, 2811, 36, 'اینجا'),
(127879, 2813, 36, 'ترمیم فتق'),
(127880, 2814, 36, 'Herniated Disc'),
(127881, 2815, 36, 'تبخال'),
(127882, 2816, 36, 'تردید'),
(127883, 2822, 36, 'پنهانی'),
(127884, 2823, 36, 'مدیریت رویدادهای پنهان'),
(127885, 2824, 36, 'پنهان کردن'),
(127886, 2825, 36, 'پنهان جزئیات'),
(127887, 2828, 36, 'پنهان کردن منو'),
(127888, 2830, 36, 'پنهان یادآوری ها'),
(127889, 2831, 36, 'پنهان/نمایش ستون ها'),
(127890, 2833, 36, 'بالا'),
(127891, 2834, 36, 'فشار خون بالا'),
(127892, 2835, 36, 'هندی'),
(127893, 2836, 36, 'لگن خاصره + کشاله ران'),
(127894, 2837, 36, 'لگن خاصره و کشاله ران'),
(127895, 2838, 36, 'مشکلات لگن خاصره'),
(127896, 2839, 36, 'تعویض لگن خاصره'),
(127897, 2840, 36, 'اطلاعیه HIPAA رسید'),
(127898, 2843, 36, 'هیسپانیک'),
(127899, 2844, 36, 'هیسپانیک - دیگر (متولد در آمریکا)'),
(127900, 2845, 36, 'هیسپانیک - دیگر (متولد خارج از آمریکا)'),
(127901, 2846, 36, 'هیسپانیک یا آمریکای لاتین'),
(127902, 2847, 36, 'تاریخچه پزشکی'),
(127903, 2848, 36, 'اطلاعات سابقه'),
(127904, 2849, 36, 'تاریخ سابقه'),
(127905, 2851, 36, 'سابقه مورمور'),
(127906, 2852, 36, 'سوابق مجاز نیست'),
(127907, 2853, 36, 'سابقه مورمور قلب'),
(127908, 2854, 36, 'تعداد بازدید ها'),
(127909, 2865, 36, 'منزل'),
(127910, 2866, 36, 'تلفن منزل'),
(127911, 2867, 36, 'شماره تلفن منزل'),
(127912, 2868, 36, 'بی خانمان و یا مشابه؟'),
(127913, 2869, 36, 'بی خانمان، و غیره'),
(127914, 2870, 36, 'بی خانمان، و غیره.'),
(127915, 2875, 36, 'ساعت'),
(127916, 2876, 36, 'ساعتها'),
(127917, 2878, 36, 'چگونه آسیب رخ داد؟'),
(127918, 2879, 36, 'چگونه آسیب رخ داد؟:'),
(127919, 2880, 36, 'آنها چگونه با ما آشنا شدند'),
(127920, 2884, 36, 'HTML'),
(127921, 2892, 36, 'Hyperactive'),
(127922, 2893, 36, 'بیماری فشار خون'),
(127923, 2894, 36, 'Hypertension: Blood Pressure Measurement'),
(127924, 2895, 36, 'Hypertension: Blood Pressure Measurement (CQM)'),
(127925, 2896, 36, 'پرکاری تیرویید'),
(127926, 2897, 36, 'کم کاری تیرویید'),
(127927, 2898, 36, 'Hysterectomy'),
(127928, 2900, 36, 'من در این زمان مشغول هستم.'),
(127929, 2901, 36, 'من اجازه خواندن ندارم '),
(127930, 2902, 36, 'ICD'),
(127931, 2909, 36, 'شناسه'),
(127932, 2910, 36, 'شناسه'),
(127933, 2911, 36, 'شناسه نمی تواند خالی باشد'),
(127934, 2912, 36, 'کارت شناسایی'),
(127935, 2927, 36, 'اگر بیکار، قید کنید دانشجو'),
(127936, 2942, 36, 'واکسیناسیون'),
(127937, 2943, 36, 'کد های واکسیناسیون'),
(127938, 2945, 36, 'تاریخ واکسیناسیون'),
(127939, 2948, 36, 'تولید کننده واکسیناسیون'),
(127940, 2949, 36, 'رجیستری واکسیناسیون'),
(127941, 2951, 36, 'خدمات واکسیناسیون'),
(127942, 2952, 36, 'عنوان واکسیناسیون'),
(127943, 2953, 36, 'واکسیناسیون'),
(127944, 2954, 36, 'تزریق واکسن'),
(127945, 2955, 36, 'Immunologic'),
(127946, 2956, 36, 'Implants'),
(127947, 2957, 36, 'وارد کردن'),
(127948, 2962, 36, 'وارد کردن تنظیمات'),
(127949, 2964, 36, 'وارد کردن بیمار'),
(127950, 2965, 36, 'وارد کردن آمار جمعیتی بیمار'),
(127951, 2966, 36, 'کدهای مهم'),
(127952, 2969, 36, 'وارد شده از حسابداری'),
(127953, 2972, 36, 'بهبود یافته'),
(127954, 2973, 36, 'در'),
(127955, 2974, 36, 'در'),
(127956, 2975, 36, 'در هر چشم'),
(127957, 2976, 36, 'در چشم چپ'),
(127958, 2977, 36, 'در سوراخ بینی'),
(127959, 2978, 36, 'در دفتر'),
(127960, 2979, 36, 'در چشم راست'),
(127961, 2981, 36, 'غیر فعال'),
(127962, 2982, 36, 'روز های غیر فعال'),
(127963, 2983, 36, 'صندوق دریافت'),
(127964, 2986, 36, 'شامل شماره کنترل'),
(127965, 2987, 36, 'شامل تکمیل شدگان'),
(127966, 2988, 36, 'شامل کاربران غیر فعال'),
(127967, 2989, 36, 'شامل دسته بندی نشدگان'),
(127968, 2990, 36, 'شامل داده های بدون ساختار'),
(127969, 2991, 36, 'شامل علائم حیاتی'),
(127970, 2992, 36, 'شامل اطلاعات علائم حیاتی؟'),
(127971, 2993, 36, 'شامل بودن'),
(127972, 2994, 36, 'درامد'),
(127973, 2996, 36, 'ناقص'),
(127974, 2997, 36, 'Incomplete Abortion Treatment'),
(127975, 3001, 36, 'افزایش یافته:'),
(127976, 3002, 36, 'بیمه جبران خسارت'),
(127977, 3003, 36, 'نا مشخص'),
(127978, 3004, 36, 'هندی'),
(127979, 3005, 36, 'نشان دهنده اختلال'),
(127980, 3009, 36, 'بیماران مبتلا به تهی دست'),
(127981, 3010, 36, 'گزارش بیماران تهی دست'),
(127982, 3011, 36, 'تهی دستان'),
(127983, 3014, 36, 'سقط جنین عمدی'),
(127984, 3016, 36, 'فاقد شرایط لازم'),
(127985, 3017, 36, 'عفونت/آبسه'),
(127986, 3018, 36, 'عفونت ها'),
(127987, 3020, 36, 'نازایی'),
(127988, 3021, 36, 'آنفلوانزا ۱'),
(127989, 3022, 36, 'آنفلوانزا ۲'),
(127990, 3025, 36, 'واکسن آنفولانزا'),
(127991, 3026, 36, 'اطلاعات'),
(127992, 3027, 36, 'اطلاعات آزمون ۱'),
(127993, 3028, 36, 'اطلاعات آزمون ۲'),
(127994, 3029, 36, 'اطلاعات آزمون ۳'),
(127995, 3030, 36, 'اطلاعات آزمون ۴'),
(127996, 3031, 36, 'اطلاعات آزمون ۵'),
(127997, 3032, 36, 'اطلاعات آزمون ۶'),
(127998, 3034, 36, 'استنشاق'),
(127999, 3037, 36, 'کاربر اولیه'),
(128000, 3039, 36, 'تزریقی'),
(128001, 3040, 36, 'تزریق'),
(128002, 3043, 36, 'آسیب دیدگی'),
(128003, 3044, 36, 'سازوکار آسیب دیدگی'),
(128004, 3045, 36, 'گزارش بررسی اجمالی آسیب دیدگی'),
(128005, 3046, 36, 'مراقبت از آسیب دیدگی'),
(128006, 3047, 36, 'نوع آسیب دیدگی'),
(128007, 3051, 36, 'زمینه های ورودی'),
(128008, 3053, 36, 'بیمه ۱'),
(128009, 3054, 36, 'بیمه ۲ یا ۳'),
(128010, 3056, 36, 'بیمه تنظیم'),
(128011, 3057, 36, 'بسته بندی های بیمه'),
(128012, 3058, 36, 'کد های بیمه'),
(128013, 3061, 36, 'اضافه پرداخت بیمه'),
(128014, 3063, 36, 'بازپرداخت بیمه'),
(128015, 3064, 36, 'شرح مختصر بیمه'),
(128016, 3065, 36, 'بیمه ۱'),
(128017, 3066, 36, 'بیمه ۲'),
(128018, 3067, 36, 'بیمه ۳'),
(128019, 3072, 36, 'بیخوابی'),
(128020, 3074, 36, 'بازرسی'),
(128021, 3076, 36, 'نصب'),
(128022, 3077, 36, 'نصب'),
(128023, 3079, 36, 'نصب پایگاه داده ها'),
(128024, 3081, 36, 'دستور داده شده'),
(128025, 3082, 36, 'دستور العمل'),
(128026, 3084, 36, 'دستورالعمل ها:'),
(128027, 3087, 36, 'بیمه'),
(128028, 3088, 36, 'بیمه'),
(128029, 3091, 36, 'تراز بیمه'),
(128030, 3092, 36, 'مانده معوق بیمه'),
(128031, 3093, 36, 'شرکت بیمه'),
(128032, 3094, 36, 'شرکت های بیمه'),
(128033, 3095, 36, 'شرکت بیمه'),
(128034, 3096, 36, 'جستجو/اضافه کردن شرکت بیمه'),
(128035, 3098, 36, 'داده های بیمه'),
(128036, 3099, 36, 'اطلاعات مربوط به بیمه در پرونده'),
(128037, 3100, 36, 'شماره های بیمه'),
(128038, 3101, 36, 'پرداخت بیمه'),
(128039, 3103, 36, 'ارائه دهنده خدمات بیمه'),
(128040, 3106, 36, 'بیمه شده'),
(128041, 3126, 36, 'معارفه داخلی'),
(128042, 3127, 36, 'زمان داخلی جمع آوری شده'),
(128043, 3128, 36, 'وظیفه بین المللی'),
(128044, 3129, 36, 'مترجم'),
(128045, 3130, 36, 'مترجم نیاز است؟'),
(128046, 3132, 36, 'فاصله'),
(128047, 3135, 36, 'مداخله'),
(128048, 3137, 36, 'عدم تحمل'),
(128049, 3139, 36, 'intramuscularly'),
(128050, 3140, 36, 'intravenously'),
(128051, 3141, 36, 'مقدمه'),
(128052, 3155, 36, 'موجودی'),
(128053, 3156, 36, 'تغییرات موجودی'),
(128054, 3157, 36, 'موجودی و فروش محصولات دارویی و غیر دارویی'),
(128055, 3158, 36, 'موجودی و فروش محصولات دارویی'),
(128056, 3159, 36, 'موجودی برای این سفارش در دسترس نیست.'),
(128057, 3160, 36, 'فهرست موجودی'),
(128058, 3161, 36, 'لیست تراکنش ها'),
(128059, 3216, 36, 'مسئله'),
(128060, 3217, 36, 'مسئله'),
(128061, 3218, 36, 'تاریخ مسئله'),
(128062, 3219, 36, 'شناسه مسئله'),
(128063, 3220, 36, 'عنوان مسئله'),
(128064, 3223, 36, 'مسائل'),
(128065, 3224, 36, 'مسائل (صدمات/پزشکی/آلرژی)'),
(128066, 3225, 36, 'مسائل (صدمات/پزشکی/آلرژی):'),
(128067, 3226, 36, 'مسائل و برخوردها'),
(128068, 3227, 36, 'مسائل و برخوردها'),
(128069, 3228, 36, 'مسائل مجاز نیست'),
(128070, 3229, 36, 'قسمت موضوعات'),
(128071, 3230, 36, 'ایتالیایی'),
(128072, 3231, 36, 'فقره'),
(128073, 3232, 36, 'فقره'),
(128074, 3233, 36, 'اقلام'),
(128075, 3238, 36, 'ژانویه'),
(128076, 3239, 36, 'ژانویه'),
(128077, 3240, 36, 'ژاپنی'),
(128078, 3241, 36, 'یرقان'),
(128079, 3243, 36, 'شرح کار'),
(128080, 3244, 36, 'شناسه کار'),
(128081, 3245, 36, 'دررفتگی مفصل'),
(128082, 3246, 36, 'درد مفصل'),
(128083, 3248, 36, 'ژوئیه'),
(128084, 3249, 36, 'ژوئیه'),
(128085, 3250, 36, 'ژوئن'),
(128086, 3251, 36, 'ژوئن'),
(128087, 3252, 36, 'منطقه آبی رنگ زیر بررسی اطلاعات برای وارد کردن پارامتر های جستجو میباشد. شما می توانید بر اساس نام بیمار، شماره پرونده، و شماره یا تاریخ خدمات پزشکی‌ جستجوکنید، و یا هر ترکیبی از این پارامتر ها. شما همچنین می توانید انتخاب کنید که همه ی فاکتورها، فاکتورها باز، و یا فاکتورهایی را که موعدشان سر رسیده (برای هر بیمار) را انتخاب کنید. جستجو را با کلیک کردن دکمه جستجو شروع کنید.'),
(128088, 3253, 36, 'تنها مال من'),
(128089, 3255, 36, 'توجیه'),
(128090, 3256, 36, 'توجیه/ذخیره'),
(128091, 3264, 36, 'کلید'),
(128092, 3265, 36, 'کلمات کلیدی'),
(128093, 3266, 36, 'kg'),
(128094, 3267, 36, 'kg/m^2'),
(128095, 3269, 36, 'سرطان کلیه'),
(128096, 3270, 36, 'نارسایی کلیه'),
(128097, 3271, 36, 'عفونت های کلیوی'),
(128098, 3272, 36, 'سنگ کلیه'),
(128099, 3273, 36, 'پیوند کلیه'),
(128100, 3277, 36, 'زانو'),
(128101, 3278, 36, 'مشکلات زانو'),
(128102, 3279, 36, 'جایگزینی زانو'),
(128103, 3282, 36, 'کره ای'),
(128104, 3286, 36, 'ازمایشگاه'),
(128105, 3295, 36, 'گزارش آزمایشگاهی'),
(128106, 3296, 36, 'نتیجه آزمایشگاه'),
(128107, 3297, 36, 'نتایج آزمایشگاهی'),
(128108, 3299, 36, 'گزارش نتایج آزمایشگاهی'),
(128109, 3300, 36, 'خدمات آزمایشگاهی'),
(128110, 3301, 36, 'نتایج تست آزمایشگاهی'),
(128111, 3303, 36, 'برچسب'),
(128112, 3304, 36, 'برچسب نمی تواند خالی باشد'),
(128113, 3305, 36, 'ستون های برچسب'),
(128114, 3306, 36, 'برچسب برای این نوع'),
(128115, 3308, 36, 'برچسب ها'),
(128116, 3311, 36, 'آزمایشگاه ها'),
(128117, 3312, 36, 'پارگی/بیماری پوستی'),
(128118, 3313, 36, 'پارگی/سایش'),
(128119, 3316, 36, 'زبان'),
(128120, 3317, 36, 'کد زبان'),
(128121, 3321, 36, 'نام زبان'),
(128122, 3322, 36, 'زبان:'),
(128123, 3324, 36, 'لائوسی'),
(128124, 3325, 36, 'آخرین'),
(128125, 3326, 36, 'تاریخ آخرین فعالیت'),
(128126, 3328, 36, 'تاریخ آخرین صورت حساب:'),
(128127, 3330, 36, 'سال گذشته تقویمی'),
(128128, 3333, 36, 'ویزیت آخر'),
(128129, 3343, 36, 'ماه گذشته'),
(128130, 3344, 36, 'نام خانوادگی'),
(128131, 3345, 36, 'نام خانوادگی'),
(128132, 3346, 36, 'نام خانوادگی:'),
(128133, 3350, 36, 'آخرین نقد و مرور'),
(128134, 3352, 36, 'آخرین ذخیره'),
(128135, 3356, 36, 'آخرین به روز رسانی توسط'),
(128136, 3357, 36, 'آخرین بار تایید شده در'),
(128137, 3358, 36, 'آخرین ملاقات'),
(128138, 3361, 36, 'Lateral Malleolus'),
(128139, 3362, 36, 'Lateral malleolus:'),
(128140, 3378, 36, 'فرم ملاقات براساس چیدمان'),
(128141, 3379, 36, 'طرح بندی/قالب ها'),
(128142, 3380, 36, 'lb'),
(128143, 3381, 36, 'lbs'),
(128144, 3382, 36, 'LDL'),
(128145, 3386, 36, 'ارسال پیغام به'),
(128146, 3390, 36, 'چپ'),
(128147, 3391, 36, 'گوش چپ'),
(128148, 3392, 36, 'گوش چپ'),
(128149, 3394, 36, 'چپ:'),
(128150, 3395, 36, 'چپ: '),
(128151, 3396, 36, 'درد/گرفتگی پا'),
(128152, 3397, 36, 'حقوقی'),
(128153, 3399, 36, 'اندازه مقاله حقوقی'),
(128154, 3400, 36, 'شرح:'),
(128155, 3401, 36, 'طول'),
(128156, 3403, 36, 'کمتر از'),
(128157, 3404, 36, 'کمتر از یا مساوی با'),
(128158, 3406, 36, 'نامه'),
(128159, 3407, 36, 'مولد نامه'),
(128160, 3408, 36, 'اندازه کاغذ نامه'),
(128161, 3409, 36, 'سربرگی که دکتر امضاء می‌کند'),
(128162, 3410, 36, 'سربرگی که بیمار امضاء می‌کند'),
(128163, 3411, 36, 'سطح فوریت'),
(128164, 3412, 36, 'مسئولیت'),
(128165, 3414, 36, 'مجوز/ شناسه'),
(128166, 3423, 36, 'شیوه زندگی'),
(128167, 3424, 36, 'وضعیت شیوه زندگی'),
(128168, 3429, 36, 'محدودیت های'),
(128169, 3431, 36, 'لینک'),
(128170, 3432, 36, 'لینک به بیمار'),
(128171, 3433, 36, 'لینک شده است'),
(128172, 3436, 36, 'لینک شده به سند'),
(128173, 3438, 36, 'فهرست'),
(128174, 3439, 36, 'جعبه لیست'),
(128175, 3440, 36, 'جعبه لیست'),
(128176, 3441, 36, 'جعبه لیست با افزودن'),
(128177, 3442, 36, 'جعبه لیست با افزودن'),
(128178, 3458, 36, 'لیست ها'),
(128179, 3473, 36, 'محلی'),
(128180, 3476, 36, 'محلی'),
(128181, 3477, 36, 'محل'),
(128182, 3478, 36, 'مکان'),
(128183, 3492, 36, 'ورود'),
(128184, 3493, 36, 'ورود'),
(128185, 3494, 36, 'خروج'),
(128186, 3495, 36, 'عضو آنلاین'),
(128187, 3496, 36, 'وارد شده به عنوان'),
(128188, 3497, 36, 'وارد شده به عنوان: '),
(128189, 3498, 36, 'خارج شده اید.'),
(128190, 3499, 36, 'پیگیری رویدادها/عملیات'),
(128191, 3500, 36, 'ورود'),
(128192, 3501, 36, 'ورود'),
(128193, 3505, 36, 'خروج'),
(128194, 3506, 36, 'خروج'),
(128195, 3507, 36, 'فهرست رویدادها/عملیات'),
(128196, 3508, 36, 'بیننده فهرست رویدادها/عملیات'),
(128197, 3514, 36, 'پایین'),
(128198, 3516, 36, 'ساق پا'),
(128199, 3519, 36, 'ستون فقرات کمری'),
(128200, 3520, 36, 'ناهار'),
(128201, 3521, 36, 'ناهار'),
(128202, 3522, 36, 'سرطان ریه'),
(128203, 3523, 36, 'جراحی سرطان ریه'),
(128204, 3524, 36, 'ریه ها:'),
(128205, 3525, 36, 'ریه ها:'),
(128206, 3533, 36, 'پست ارسال شد'),
(128207, 3534, 36, 'اصلی'),
(128208, 3535, 36, 'آدرس اصلی'),
(128209, 3542, 36, 'مطمئن شوید که "'),
(128210, 3545, 36, 'کسالت:'),
(128211, 3548, 36, 'مرد'),
(128212, 3549, 36, 'کاندوم مرد'),
(128213, 3559, 36, 'تنها خصیصه های اجباری یا مشخص شده، بررسی اطللاعات تکراری, و بدون جستجو'),
(128214, 3560, 36, 'تنها خصیصه های اجباری یا مشخص شده، بررسی اطللاعات تکراری, و جستجو'),
(128215, 3561, 36, 'راهنما'),
(128216, 3565, 36, 'مارس'),
(128217, 3568, 36, 'مارس'),
(128218, 3569, 36, 'وضع تأهل'),
(128219, 3571, 36, 'به عنوان صورتحساب صادر شده علامت زده ولی‌ به قسمت صورتحساب نرو'),
(128220, 3572, 36, 'به عنوان پاک شده علامت بزن'),
(128221, 3573, 36, 'به عنوان صورتحساب صادر نشده علامت بزن'),
(128222, 3575, 36, 'به عنوان پاک شده علامت بزن'),
(128223, 3576, 36, 'متاهل'),
(128224, 3578, 36, 'ماسک'),
(128225, 3579, 36, 'ماسک برای شماره های فاکتور'),
(128226, 3580, 36, 'ماسک برای شناسه های بیمار'),
(128227, 3581, 36, 'ماسک برای شناسه های محصول'),
(128228, 3582, 36, 'تطابق'),
(128229, 3591, 36, 'حداکثر'),
(128230, 3594, 36, 'فک بالا سمت راست:'),
(128231, 3595, 36, 'حداکثر سن'),
(128232, 3596, 36, 'حداکثر تعداد حروف'),
(128233, 3601, 36, 'حداکثر اندازه'),
(128234, 3602, 36, 'حداکثر اندازه (وارد کردن صفر اجازه هر اندازه یی را می دهد)'),
(128235, 3603, 36, 'مه'),
(128236, 3605, 36, 'mcg'),
(128237, 3611, 36, 'اندازه گیری'),
(128238, 3616, 36, 'مدیریت خدمات بهداشتی درمانی'),
(128239, 3617, 36, 'سوابق پزشکی'),
(128240, 3618, 36, 'مسئله پزشکی'),
(128241, 3619, 36, 'مسئله پزشکی'),
(128242, 3620, 36, 'مشکل پزشکی'),
(128243, 3623, 36, 'مشکلات پزشکی'),
(128244, 3624, 36, 'پرونده پزشکی'),
(128245, 3625, 36, 'شماره پرونده پزشکی'),
(128246, 3626, 36, 'پرونده های پزشکی'),
(128247, 3627, 36, 'پرونده های پزشکی ارسال شده'),
(128248, 3629, 36, 'خلاصه اطلاعت پزشکی‌ داده شده'),
(128249, 3630, 36, 'سیستم پزشکی'),
(128250, 3631, 36, 'نوع پزشکی'),
(128251, 3635, 36, 'مصرف دارو'),
(128252, 3636, 36, 'فهرست آلرژی دارویی'),
(128253, 3638, 36, 'فهرست داروها'),
(128254, 3639, 36, 'بازنگری داروها انجام شد؟'),
(128255, 3640, 36, 'داروها'),
(128256, 3641, 36, 'داروها:'),
(128257, 3642, 36, 'واحدهای پزشکی'),
(128258, 3643, 36, 'متوسط'),
(128259, 3646, 36, 'مشکلات حافظه'),
(128260, 3647, 36, 'مردان'),
(128261, 3648, 36, 'مردان و زنان'),
(128262, 3649, 36, 'تنها مردان'),
(128263, 3651, 36, 'يائسگي'),
(128264, 3654, 36, 'بیماری های روانی'),
(128265, 3661, 36, 'پیام'),
(128266, 3662, 36, 'مرکز پیام و یادآوری'),
(128267, 3665, 36, 'پیام فرستاده شده'),
(128268, 3666, 36, 'وضعیت پیام'),
(128269, 3670, 36, 'پیام:'),
(128270, 3671, 36, 'پیام ها'),
(128271, 3672, 36, 'پیام هایی که شما امروز فرستاده اید'),
(128272, 3673, 36, 'روش'),
(128273, 3675, 36, 'روش ارسال ایمیل های خروجی.'),
(128274, 3679, 36, 'میلی گرم'),
(128275, 3680, 36, 'mg/1cc'),
(128276, 3681, 36, 'mg/2cc'),
(128277, 3682, 36, 'mg/3cc'),
(128278, 3683, 36, 'mg/4cc'),
(128279, 3684, 36, 'mg/5cc'),
(128280, 3685, 36, 'MG/DL'),
(128281, 3686, 36, 'متوسط'),
(128282, 3687, 36, 'نام میانی'),
(128283, 3688, 36, 'نام میانی'),
(128284, 3696, 36, 'کارگر مهاجر یا فصلی؟'),
(128285, 3697, 36, 'مهاجر/فصلی'),
(128286, 3703, 36, 'حداقل'),
(128287, 3704, 36, 'حداقل'),
(128288, 3705, 36, 'حداقل سن'),
(128289, 3706, 36, 'Minor joint strain +/- synovitis'),
(128290, 3708, 36, 'دقیقه'),
(128291, 3709, 36, 'دقیقه'),
(128292, 3710, 36, 'دقیقه'),
(128293, 3712, 36, 'متفرقه'),
(128294, 3716, 36, 'متفرقه'),
(128295, 3727, 36, 'ml'),
(128296, 3728, 36, 'MM/DD/YYYY'),
(128297, 3729, 36, 'mm/hg'),
(128298, 3730, 36, 'mmHg'),
(128299, 3733, 36, 'موبایل'),
(128300, 3734, 36, 'تلفن همراه'),
(128301, 3753, 36, 'دوشنبه'),
(128302, 3755, 36, 'دوشنبه، چهارشنبه و جمعه'),
(128303, 3756, 36, 'دوشنبه'),
(128304, 3758, 36, 'ماهیانه'),
(128305, 3759, 36, 'ماه'),
(128306, 3761, 36, 'ماه (ها)'),
(128307, 3762, 36, 'درآمد ماهانه'),
(128308, 3763, 36, 'ماه ها'),
(128309, 3771, 36, 'مادر'),
(128310, 3772, 36, 'نام مادر'),
(128311, 3774, 36, 'دهان'),
(128312, 3775, 36, 'انتقال'),
(128313, 3776, 36, 'انتقال سند به دسته بندی ها:'),
(128314, 3777, 36, 'انتقال به پایین'),
(128315, 3779, 36, 'انتقال به بیمار'),
(128316, 3780, 36, 'انتقال به ...'),
(128317, 3781, 36, 'انتقال به بالا'),
(128318, 3783, 36, 'آقای'),
(128319, 3785, 36, 'خانم'),
(128320, 3786, 36, 'دوشیزه'),
(128321, 3796, 36, 'ابزار چند زبانه'),
(128322, 3803, 36, 'Murmur:'),
(128323, 3804, 36, 'Musc Ache'),
(128324, 3805, 36, 'Musc Aches'),
(128325, 3806, 36, 'Musc Redness'),
(128326, 3807, 36, 'Musc Stiffness'),
(128327, 3808, 36, 'Musc Swelling'),
(128328, 3809, 36, 'Musc Warm'),
(128329, 3810, 36, 'Muscle'),
(128330, 3811, 36, 'Muscle injury'),
(128331, 3812, 36, 'Musculoskeletal'),
(128332, 3818, 36, 'خودم'),
(128333, 3823, 36, 'نام'),
(128334, 3825, 36, 'نام (برای اطلاعات بیشتر کلیک کنید)'),
(128335, 3826, 36, 'نام ۱'),
(128336, 3827, 36, 'نام ۲'),
(128337, 3828, 36, 'نام و عنوان مدیر واکسیناسیون'),
(128338, 3831, 36, 'نام حوادث'),
(128339, 3832, 36, 'نام شرکت بیمه'),
(128340, 3833, 36, 'نام ارائه دهنده خدمات پزشکی'),
(128341, 3834, 36, 'نام فرستنده یادآورهای بیمار.'),
(128342, 3835, 36, 'نام ترجمه'),
(128343, 3836, 36, 'نام / مقدار'),
(128344, 3840, 36, 'Nasal mucosa pink, septum midline'),
(128345, 3852, 36, 'Nausea'),
(128346, 3857, 36, 'فرم ملاقات براساس منطقه هدايت'),
(128347, 3881, 36, 'Neural condition / nerve damage'),
(128348, 3882, 36, 'Neuro Numbness'),
(128349, 3883, 36, 'Neuro Weakness'),
(128350, 3884, 36, 'Neurologic'),
(128351, 3888, 36, 'جدید'),
(128352, 3889, 36, 'جدید =>'),
(128353, 3892, 36, 'آلرژی جدید'),
(128354, 3894, 36, 'وقت ملاقات جدید'),
(128355, 3895, 36, 'دسته بندی های جدید'),
(128356, 3896, 36, 'دسته بندی جدید'),
(128357, 3897, 36, 'مشتری جدید'),
(128358, 3898, 36, 'مشاوره جدید'),
(128359, 3900, 36, 'مجموعه تعاریف جدید اضافه شد'),
(128360, 3901, 36, 'سند جدید'),
(128361, 3904, 36, 'ویزیت جدید'),
(128362, 3906, 36, 'فرم ویزیت جدید'),
(128363, 3909, 36, 'اطلاعات درمانگاه جدید'),
(128364, 3912, 36, 'گروه جدید'),
(128365, 3913, 36, 'اطلاعات گروه جدید'),
(128366, 3914, 36, 'مصدومیت/وضعیت جدید'),
(128367, 3917, 36, 'لیست جدید'),
(128368, 3918, 36, 'سفارشات جدید'),
(128369, 3919, 36, 'پاراگراف جدید'),
(128370, 3920, 36, 'رمز عبور جدید'),
(128371, 3921, 36, 'بیمار جدید'),
(128372, 3922, 36, 'بیمار جدید'),
(128373, 3924, 36, 'فرم بیمار جدید'),
(128374, 3925, 36, 'شناسه بیمار جدید'),
(128375, 3926, 36, 'پرداخت جدید'),
(128376, 3928, 36, 'بیمار جدید'),
(128377, 3929, 36, 'نتایج جدید از تبادل الکترونیکی آزمایشگاهی'),
(128378, 3930, 36, 'جستجوی جدید'),
(128379, 3931, 36, 'مطالب ارسالی های جدید'),
(128380, 3932, 36, 'کاربر جدید'),
(128381, 3934, 36, 'ملاقات جدید پزشکی‌'),
(128382, 3935, 36, 'جدید/جستجو'),
(128383, 3937, 36, 'مدیریت NewCrop'),
(128384, 3961, 36, 'روزنامه'),
(128385, 3962, 36, 'بعدی'),
(128386, 3964, 36, 'روز بعد'),
(128387, 3965, 36, 'ماه بعد'),
(128388, 3966, 36, 'ماه بعد (برای منو نگه دارید)'),
(128389, 3968, 36, 'هفته بعد'),
(128390, 3969, 36, 'سال بعد (برای منو نگه دارید)'),
(128391, 3971, 36, 'نام مستعار'),
(128392, 3973, 36, 'تعریق شبانه'),
(128393, 3975, 36, 'خیر'),
(128394, 3976, 36, 'خیر'),
(128395, 3977, 36, 'بدون دسترسی'),
(128396, 3978, 36, 'این بیمار یادآور فعالی ندارد.'),
(128397, 3983, 36, 'قرارهای ملاقات وجود ندارد.'),
(128398, 3985, 36, 'سیستم صدور صورتحسابی در حال حاضر فعال نیست'),
(128399, 4032, 36, 'پرونده ای مطابق جستجو پیدا نشد'),
(128400, 4033, 36, 'نتیجه جدیدی پیدا نشد'),
(128401, 4034, 36, 'یادداشتی وجود ندارد'),
(128402, 4056, 36, 'یاد آوری وجود ندارد'),
(128403, 4058, 36, 'نتیجه ای وجود ندارد'),
(128404, 4060, 36, 'نتیجه ای برای جستجو پیدا نشد'),
(128405, 4061, 36, 'نتیجه ای پیدا نشد، لطفا دوباره سعی کنید.'),
(128406, 4062, 36, 'بی نتیجه، لطفا دوباره سعی کنید.'),
(128407, 4063, 36, 'بی نتیجه، لطفا دوباره سعی کنید.'),
(128408, 4065, 36, 'غیبت'),
(128409, 4069, 36, 'نام چنین چهار چوبی وجود ندارد'),
(128410, 4075, 36, 'بدون ملاقات پزشکی‌'),
(128411, 4076, 36, 'هیچ علائم حیاتی ثبت نشده است.'),
(128412, 4080, 36, 'Nocturia'),
(128413, 4085, 36, 'Non-Insulin Dependent Diabetes'),
(128414, 4089, 36, 'هیچ موردی'),
(128415, 4090, 36, 'هیچ موردی'),
(128416, 4091, 36, 'هیچک موردی تعریف نشده'),
(128417, 4092, 36, 'هیچ مطلبی ثبت نشده است'),
(128418, 4093, 36, 'هیچکدام از موارد فوق'),
(128419, 4097, 36, 'عادی'),
(128420, 4099, 36, 'معاینه قلبی طبیعی:'),
(128421, 4100, 36, 'معاینه قلبی طبیعی: '),
(128422, 4101, 36, 'معاینه ریه طبیعی:'),
(128423, 4102, 36, 'معاینه ریه طبیعی: '),
(128424, 4103, 36, 'ملاقات پزشکی‌ عادی'),
(128425, 4107, 36, 'نمایش عادی'),
(128426, 4108, 36, 'نرمال:'),
(128427, 4109, 36, 'معمولا باید علامت زده شود. به کنترل دسترسی ارتباط ندارد.'),
(128428, 4112, 36, 'نروژی'),
(128429, 4115, 36, 'بینی'),
(128430, 4116, 36, 'خون دماغ'),
(128431, 4120, 36, 'مجاز نیست'),
(128432, 4129, 36, 'مجاز نیست'),
(128433, 4130, 36, 'مجاز نیست'),
(128434, 4135, 36, 'موجود نیست'),
(128435, 4138, 36, 'علامت زده نشده'),
(128436, 4140, 36, 'کد گذاری نشده'),
(128437, 4143, 36, 'معاینه نشد'),
(128438, 4144, 36, 'معاینه نشد:'),
(128439, 4145, 36, 'معاینه نشد: '),
(128440, 4146, 36, 'پیدا نشد'),
(128441, 4148, 36, 'پیدا نشد!'),
(128442, 4150, 36, 'نصب نشده'),
(128443, 4154, 36, 'هنوز ارسال نشده'),
(128444, 4156, 36, 'معین نشده.'),
(128445, 4157, 36, 'یادداشت'),
(128446, 4158, 36, 'کد یادداشت ها'),
(128447, 4162, 36, 'نوع یادداشت'),
(128448, 4172, 36, 'یادداشت ها'),
(128449, 4175, 36, 'یادداشت ها مجاز نیستند'),
(128450, 4177, 36, 'چیزی ضبط نشده'),
(128451, 4179, 36, 'آلرژی برای وارد کردن وجود ندارد'),
(128452, 4180, 36, 'نسخه ای برای وارد کردن وجود ندارد'),
(128453, 4181, 36, 'چیزی برای نشان دادن وجود ندارد'),
(128454, 4182, 36, 'چیزی انتخاب نشده'),
(128455, 4185, 36, 'اطلاعیه'),
(128456, 4186, 36, 'آدرس ایمیل برای ارسال اطلاعیه'),
(128457, 4188, 36, 'اطلاعیه ها'),
(128458, 4190, 36, 'نوامبر'),
(128459, 4191, 36, 'نوامبر'),
(128460, 4192, 36, 'در حال ارسال برای:'),
(128461, 4193, 36, 'در حال چاپ'),
(128462, 4200, 36, 'تعداد'),
(128463, 4204, 36, 'تعداد ستون ها در نمای سالیانه.'),
(128464, 4216, 36, 'از چند ساعت قبل اطلاعیه ایمیلی ارسال شود.'),
(128465, 4217, 36, 'از چند ساعت قبل اطلاعیه تلفنی ارسال شود.'),
(128466, 4218, 36, 'از چند ساعت قبل اطلاعیه SMS ارسال شود.'),
(128467, 4223, 36, 'بی حسی'),
(128468, 4224, 36, 'صورت کسر'),
(128469, 4227, 36, 'تغذیه'),
(128470, 4231, 36, 'چاقی I'),
(128471, 4232, 36, 'چاقی II'),
(128472, 4233, 36, 'چاقی III'),
(128473, 4234, 36, 'عینی'),
(128474, 4237, 36, 'اشتغال'),
(128475, 4239, 36, 'واقعه'),
(128476, 4240, 36, 'اکتبر'),
(128477, 4241, 36, 'اکتبر'),
(128478, 4243, 36, 'از'),
(128479, 4244, 36, 'از تعداد'),
(128480, 4245, 36, 'از قرص های'),
(128481, 4247, 36, 'یادداشت های اداری'),
(128482, 4248, 36, 'خاموش'),
(128483, 4249, 36, 'یادداشت های اداری'),
(128484, 4250, 36, 'ویزیت عادی'),
(128485, 4263, 36, 'اولاد'),
(128486, 4265, 36, 'پماد'),
(128487, 4267, 36, 'تأیید'),
(128488, 4273, 36, 'Old fracture non / malunion'),
(128489, 4275, 36, 'سبک استاتیک قدیمی بدون جستجو و یا بررسی اطللاعات تکراری'),
(128490, 4288, 36, 'در دست'),
(128491, 4289, 36, 'در سفارش'),
(128492, 4290, 36, 'در سایت'),
(128493, 4297, 36, 'پشتیبانی آنلاین'),
(128494, 4298, 36, 'لینک پشتیبانی آنلاین'),
(128495, 4299, 36, 'تنها فعال'),
(128496, 4302, 36, 'فقط در صورتی که محل صدور صورت حساب باشد'),
(128497, 4303, 36, 'فقط غیر فعال'),
(128498, 4304, 36, 'فقط مال من'),
(128499, 4310, 36, 'شروع بیماری:'),
(128500, 4311, 36, 'شروع بیماری: '),
(128501, 4312, 36, 'شروع تورم:'),
(128502, 4316, 36, 'باز'),
(128503, 4318, 36, 'درصفحه جدید باز کنید'),
(128504, 4321, 36, 'ملاقات پزشکی‌ امروز را باز کنید'),
(128505, 4332, 36, 'Opthalmic'),
(128506, 4350, 36, 'تنظیمات اختیاری'),
(128507, 4351, 36, 'یا'),
(128508, 4352, 36, 'یا'),
(128509, 4353, 36, 'یا انتخاب کنید'),
(128510, 4360, 36, 'از راه دهان'),
(128511, 4362, 36, 'سفارش');
INSERT INTO `lang_definitions` VALUES
(128512, 4363, 36, 'سفارش و نوع نتایج'),
(128513, 4364, 36, 'کاتالوگ سفارش'),
(128514, 4365, 36, 'تاریخ سفارش'),
(128515, 4367, 36, 'فرم سفارش'),
(128516, 4369, 36, 'سفارش باید یک عدد بین ۱ و ۹۹۹ باشد'),
(128517, 4370, 36, 'نام روی سفارش'),
(128518, 4371, 36, 'اولویت سفارش'),
(128519, 4372, 36, 'پردازنده سفارش'),
(128520, 4375, 36, 'وضعیت سفارش'),
(128521, 4378, 36, 'نوع سفارش'),
(128522, 4380, 36, 'نوع سفارش/نتیجه'),
(128523, 4381, 36, 'سفارش شده'),
(128524, 4384, 36, 'خدمات بهداشتی سفارش دهنده'),
(128525, 4386, 36, 'آسیب اعضای بدن'),
(128526, 4387, 36, 'سازمان'),
(128527, 4388, 36, 'نام سازمان'),
(128528, 4389, 36, 'نام واحد سازمانی'),
(128529, 4390, 36, 'سازمانها'),
(128530, 4392, 36, 'اصلی'),
(128531, 4396, 36, 'OROPHARYNX: '),
(128532, 4397, 36, 'Orthopnea'),
(128533, 4398, 36, 'OS'),
(128534, 4399, 36, 'Osetoarthritis'),
(128535, 4402, 36, 'دیگر'),
(128536, 4403, 36, 'دیگر'),
(128537, 4404, 36, 'دیگر - مشخص کنید'),
(128538, 4405, 36, 'دیگر - قید شده'),
(128539, 4406, 36, 'برنامه دولتی دیگر'),
(128540, 4408, 36, 'آسیب دیگری که جایی قید نشده'),
(128541, 4409, 36, 'بیمه مسئولیت دیگر اصلی‌ هست'),
(128542, 4410, 36, 'ماه دیگر'),
(128543, 4411, 36, 'برنامه های غیر دولتی دیگر'),
(128544, 4412, 36, 'یادداشت های دیگر'),
(128545, 4413, 36, 'علائم مربوطه دیگر'),
(128546, 4414, 36, 'علائم مربوطه دیگر:'),
(128547, 4415, 36, 'پاسخ دیگر بیمار'),
(128548, 4416, 36, 'آسیب ناشی از استرس/زیاده روی دیگر'),
(128549, 4417, 36, 'جراحی دیگر'),
(128550, 4418, 36, 'Other/Generic Abortion-Related'),
(128551, 4420, 36, 'دیگران'),
(128552, 4424, 36, 'بیرون'),
(128553, 4425, 36, 'خارج از دفتر'),
(128554, 4427, 36, 'نتیجه'),
(128555, 4428, 36, 'چشم انداز'),
(128556, 4431, 36, 'عقب افتاده'),
(128557, 4432, 36, 'استفاده بیش از حد'),
(128558, 4433, 36, 'بررسی اجمالی'),
(128559, 4434, 36, 'اضافه وزن'),
(128560, 4437, 36, 'اشباع اکسیژن'),
(128561, 4443, 36, 'اهالی جزایر اقیانوس آرام'),
(128562, 4445, 36, 'صفحه'),
(128563, 4446, 36, 'صفحات'),
(128564, 4447, 36, 'پرداخت شده'),
(128565, 4448, 36, 'مبلغ پرداختی که اختصاص داده شده'),
(128566, 4449, 36, 'مبلغ پرداخت شده'),
(128567, 4450, 36, 'پرداخت شده از طریق'),
(128568, 4451, 36, 'درد'),
(128569, 4453, 36, 'Palpitation'),
(128570, 4455, 36, 'پاپ اسمیر'),
(128571, 4456, 36, 'کاغذ'),
(128572, 4457, 36, 'اندازه کاغذ'),
(128573, 4458, 36, 'فلج'),
(128574, 4463, 36, 'همکار'),
(128575, 4464, 36, 'نام همکار'),
(128576, 4467, 36, 'رمز عبور'),
(128577, 4468, 36, 'رمز عبور برای رمزگشایی سند'),
(128578, 4469, 36, 'بیماران تصویب شده'),
(128579, 4470, 36, 'هشدار منفعل'),
(128580, 4471, 36, 'قوانین هشدار منفعل'),
(128581, 4472, 36, 'رمز عبور'),
(128582, 4473, 36, 'تغییر رمز عبور'),
(128583, 4475, 36, 'موفقیت تغییر رمز ورود'),
(128584, 4477, 36, 'رمز عبور مهلت انقضاء'),
(128585, 4479, 36, 'رمز عبور برای وب سایت دروازه تلفن. خدمات خودکار VOIP توسط Maviq ارائه شده است. لطفا برای کسب اطلاعات بیشتر به این سایت مراجعه کنید. http://signup.maviq.com'),
(128586, 4483, 36, 'امنیت رمز عبور به تازگی ارتقا یافته.'),
(128587, 4486, 36, 'رمز عبور:'),
(128588, 4490, 36, 'موعد انجام'),
(128589, 4491, 36, 'موعد انجام'),
(128590, 4494, 36, 'لیست ویزیت های پیشین'),
(128591, 4514, 36, 'بیمار'),
(128592, 4515, 36, 'بیمار'),
(128593, 4516, 36, 'بیمار'),
(128594, 4517, 36, 'آدرس بیمار'),
(128595, 4518, 36, 'آدرس بیمار در دست نیست'),
(128596, 4521, 36, 'آلرژی های بیمار'),
(128597, 4522, 36, 'آلرژی های بیمار'),
(128598, 4523, 36, 'قرار ملاقات بیمار'),
(128599, 4524, 36, 'موازنه بیمار'),
(128600, 4525, 36, 'مانده معوق بیمار'),
(128601, 4528, 36, 'شناسه پرونده بیمار'),
(128602, 4529, 36, 'مرخص شدن بیمار'),
(128603, 4530, 36, 'مرخص شدن بیمار برای '),
(128604, 4531, 36, 'شهر بیمار'),
(128605, 4533, 36, 'ارتباطات بیمار ارسال شد'),
(128606, 4534, 36, 'ارتباطات بیمار ارسال شد'),
(128607, 4535, 36, 'کشور بیمار'),
(128608, 4539, 36, 'داده های بیمار'),
(128609, 4541, 36, 'تاریخ تولد بیمار در دست نیست'),
(128610, 4542, 36, 'جزئیات بیمار'),
(128611, 4543, 36, 'تاریخ تولد بیمار'),
(128612, 4544, 36, 'سند بیمار'),
(128613, 4545, 36, 'آموزش بیمار'),
(128614, 4546, 36, 'امکانات آموزشی بیمار'),
(128615, 4550, 36, 'بیمار یاب'),
(128616, 4551, 36, 'نام بیمار'),
(128617, 4553, 36, 'نام بیمار در دست نیست'),
(128618, 4558, 36, 'جنس بیمار'),
(128619, 4559, 36, 'جنس بیمار در دست نیست'),
(128620, 4561, 36, 'سابقه بیمار'),
(128621, 4562, 36, 'سابقه/سبک زندگی بیمار'),
(128622, 4563, 36, 'تلفن خانه بیمار'),
(128623, 4564, 36, 'شناسه بیمار'),
(128624, 4565, 36, 'شناسه بیمار'),
(128625, 4566, 36, 'کارت شناسایی بیمار'),
(128626, 4568, 36, 'واکسیناسیون بیمار'),
(128627, 4569, 36, 'اطلاعات بیمار'),
(128628, 4570, 36, 'دستورالعمل های بیمار'),
(128629, 4573, 36, 'مسائل بیمار'),
(128630, 4575, 36, 'نام خانوادگی بیمار'),
(128631, 4577, 36, 'نام خانوادگی بیمار در دست نیست'),
(128632, 4581, 36, 'فهرست بیماران'),
(128633, 4582, 36, 'ستونهای فهرست بیماران'),
(128634, 4584, 36, 'صفحه جدید فهرست بیماران'),
(128635, 4587, 36, 'مشکلات پزشکی بیمار'),
(128636, 4588, 36, 'داروهای بیمار'),
(128637, 4589, 36, 'نام بیمار'),
(128638, 4590, 36, 'نام و آدرس بیمار'),
(128639, 4593, 36, 'نام بیمار ضروریست'),
(128640, 4595, 36, 'یادداشت بیمار'),
(128641, 4596, 36, 'نوع یادداشت بیمار'),
(128642, 4597, 36, 'یادداشت های بیمار'),
(128643, 4598, 36, 'یادداشت های بیمار (نوشتن، اضافه کردن تنها اختیاریست)'),
(128644, 4599, 36, 'شماره بیمار'),
(128645, 4600, 36, 'پرداخت بیمار'),
(128646, 4608, 36, 'گزارش چاپ شده بیمار'),
(128647, 4609, 36, 'گزارش سابقه بیمار'),
(128648, 4610, 36, 'درخواست سابقه بیمار'),
(128649, 4611, 36, 'درخواست سوابق بیمار'),
(128650, 4613, 36, 'یادآوری بیمار'),
(128651, 4616, 36, 'قواعد یادآوری بیمار'),
(128652, 4617, 36, 'ایمیل فرستنده یادآوری بیمار'),
(128653, 4618, 36, 'نام فرستنده یادآوری بیمار'),
(128654, 4619, 36, 'یادآورهای بیمار'),
(128655, 4620, 36, 'گزارش بیمار'),
(128656, 4621, 36, 'درخواست بیمار'),
(128657, 4622, 36, 'بیمار درخواست سوابق پزشکی کرد'),
(128658, 4623, 36, 'نتایج بیمار'),
(128659, 4624, 36, 'سبک نتیجه های جست و جو بیمار'),
(128660, 4625, 36, 'صفحه جستجو/افزودن بیمار'),
(128661, 4626, 36, 'تنظیمات بیمار'),
(128662, 4627, 36, 'استان بیمار'),
(128663, 4629, 36, 'خلاصه مشخصات بیمار'),
(128664, 4630, 36, 'تراکنش های بیمار'),
(128665, 4631, 36, 'کد پستی بیمار'),
(128666, 4633, 36, 'بیمار/ارباب رجوع'),
(128667, 4634, 36, 'بیمار'),
(128668, 4635, 36, 'شناسه بیمار'),
(128669, 4636, 36, 'بیماران'),
(128670, 4638, 36, 'پرداخت'),
(128671, 4639, 36, 'به گزینه های "انجام شده با" توجه کنید. پس از دریافت و علامت زدن همه پرداختهای بیمه‌ از بیمار درخواست پرداخت مبلغ باقی مانده خواهد شد. در غیر این صورت مبلغ باقی مانده جمع آوری نمی شود! همچنین اگر مبلغ باقی مانده یی وجود دارد که بیمار باید پرداخت کند، مهلت مناسبی برای پرداخت باید قید شود که روی لحن و انشأ صورت حساب بیمار تاثیر گذار میباشد.'),
(128672, 4640, 36, 'تاریخ پرداخت:'),
(128673, 4641, 36, 'وضعیت پرداخت'),
(128674, 4642, 36, 'نام گیرنده'),
(128675, 4643, 36, 'پرداخت کننده'),
(128676, 4644, 36, 'نوع پرداخت کننده'),
(128677, 4645, 36, 'پرداخت کننده'),
(128678, 4646, 36, 'نهاد پرداخت کننده'),
(128679, 4647, 36, 'پرداخت'),
(128680, 4648, 36, 'پرداخت'),
(128681, 4649, 36, 'کد اصلاح پرداخت'),
(128682, 4650, 36, 'پرداخت در مقابل'),
(128683, 4651, 36, 'مبلغ پرداخت'),
(128684, 4652, 36, 'مبلغ پرداخت باید عدد باشد'),
(128685, 4653, 36, 'دسته بندی پرداخت'),
(128686, 4654, 36, 'تاریخ پرداخت'),
(128687, 4655, 36, 'پرداخت وارد شده در'),
(128688, 4656, 36, 'پرداخت از'),
(128689, 4659, 36, 'فهرست پرداخت'),
(128690, 4660, 36, 'روش پرداخت'),
(128691, 4661, 36, 'مرتب سازی پرداخت بر اساس'),
(128692, 4662, 36, 'وضعیت پرداخت'),
(128693, 4663, 36, 'نوع پرداخت'),
(128694, 4664, 36, 'ارزش پرداخت برای کد '),
(128695, 4665, 36, 'پرداخت ها'),
(128696, 4672, 36, 'Pelvis and buttock'),
(128697, 4673, 36, 'Pemphigus'),
(128698, 4674, 36, 'در انتظار'),
(128699, 4677, 36, 'در انتظار پیگیری'),
(128700, 4679, 36, 'در انتظار دستورات'),
(128701, 4681, 36, 'در انتظار بررسی'),
(128702, 4685, 36, 'Peptic Ulcer Disease'),
(128703, 4688, 36, 'Per Nostril'),
(128704, 4689, 36, 'per nostril'),
(128705, 4690, 36, 'Per Oris'),
(128706, 4691, 36, 'per oris'),
(128707, 4692, 36, 'Per Rectum'),
(128708, 4693, 36, 'per rectum'),
(128709, 4694, 36, 'در صد'),
(128710, 4697, 36, 'در صد'),
(128711, 4699, 36, 'انجام جستجو'),
(128712, 4700, 36, 'انجام این عمل'),
(128713, 4701, 36, 'درصد عملکرد'),
(128714, 4705, 36, 'مدت زمان'),
(128715, 4707, 36, 'Perioperative Care'),
(128716, 4708, 36, 'Peripheral'),
(128717, 4712, 36, 'شخص'),
(128718, 4713, 36, 'شخصی کردن'),
(128719, 4717, 36, 'داروخانه'),
(128720, 4718, 36, 'داروخانه'),
(128721, 4720, 36, 'Pheumothorax'),
(128722, 4729, 36, 'تلفن'),
(128723, 4730, 36, 'فهرست تماس های تلفن'),
(128724, 4731, 36, 'گزارش فهرست تماس های تلفن'),
(128725, 4737, 36, 'ساعت هشدار تلفن'),
(128726, 4738, 36, 'شماره تلفن'),
(128727, 4740, 36, 'Photophobia'),
(128728, 4741, 36, 'عکس ها'),
(128729, 4747, 36, 'معاینه پزشکی'),
(128730, 4749, 36, 'درخواست پزشک'),
(128731, 4750, 36, 'امضاء پزشک'),
(128732, 4752, 36, 'پزشکان'),
(128733, 4753, 36, 'انتخاب'),
(128734, 4754, 36, 'انتخاب'),
(128735, 4756, 36, 'PID'),
(128736, 4757, 36, 'PID (Pelvic Inflammatory Disease)'),
(128737, 4758, 36, 'اندازه قرص'),
(128738, 4759, 36, 'قرص'),
(128739, 4765, 36, 'نگهدارنده جای'),
(128740, 4767, 36, 'متن ساده'),
(128741, 4768, 36, 'طرح'),
(128742, 4771, 36, 'نام طرح'),
(128743, 4775, 36, 'مجموعه طرح ها'),
(128744, 4779, 36, 'طرح:'),
(128745, 4782, 36, 'طرح ها'),
(128746, 4784, 36, 'بازیکن'),
(128747, 4824, 36, 'لطفا شماره چک را وارد کنید'),
(128748, 4825, 36, 'لطفا شماره چک / مرجع را وارد کنید'),
(128749, 4826, 36, 'لطفا تاریخ را قید کنید'),
(128750, 4827, 36, 'لطفا مبلغ پرداخت را قید کنید'),
(128751, 4828, 36, 'لطفا دسته بندی پرداخت را قید کنید'),
(128752, 4829, 36, 'لطفا فرم پرداخت را پر کنید'),
(128753, 4831, 36, 'لطفا قبل از ادامه آنها را پر کنید.'),
(128754, 4832, 36, 'لطفا دلیل ملاقات را شرح دهید'),
(128755, 4834, 36, 'برای دیدن نتایج لطفا معیار جستجو را در بالا وارد کرده، و روی ارسال کلیک کنید.'),
(128756, 4835, 36, 'برای دیدن نتایج لطفا معیار جستجو را در بالا وارد کرده، و روی ارسال کلیک کنید. (نتایج در یک صفحه جدید نمایش داده خواهد شد)'),
(128757, 4836, 36, 'لطفا دوباره وارد سیستم شوید.'),
(128758, 4876, 36, 'لطفا پس از مدتی از صفحه "فسخ شناسایی" دیدار کنید'),
(128759, 4877, 36, 'لطفا پس از مدتی از صفحه "شناسایی مجدد" دیدار کنید'),
(128760, 4878, 36, 'لطفا پس از مدتی از این صفحه دیدار کنید'),
(128761, 4881, 36, 'Plural'),
(128762, 4882, 36, 'عصر'),
(128763, 4885, 36, 'PND'),
(128764, 4886, 36, 'Pneumococcal Conjugate 1'),
(128765, 4887, 36, 'Pneumococcal Conjugate 2'),
(128766, 4888, 36, 'Pneumococcal Conjugate 3'),
(128767, 4889, 36, 'Pneumococcal Conjugate 4'),
(128768, 4890, 36, 'Pneumococcal Vaccine'),
(128769, 4894, 36, 'Podiatric'),
(128770, 4897, 36, 'پوشش بیمه'),
(128771, 4898, 36, 'شماره انحصاری پوشش بیمه'),
(128772, 4899, 36, 'شماره انحصاری پوشش بیمه'),
(128773, 4900, 36, 'لهستانی'),
(128774, 4901, 36, 'Polydypsia'),
(128775, 4902, 36, 'پولیپ'),
(128776, 4903, 36, 'Polyuria'),
(128777, 4904, 36, 'کم اشتهایی'),
(128778, 4905, 36, 'گردش خون ضعیف'),
(128779, 4906, 36, 'شنوایی ضعیف'),
(128780, 4910, 36, 'پورتال'),
(128781, 4911, 36, 'فعالیت درسایت پورتال'),
(128782, 4917, 36, 'پرتغالی'),
(128783, 4918, 36, 'پرتغالی (برزیلی)'),
(128784, 4919, 36, 'پرتغالی (اروپایی)'),
(128785, 4922, 36, 'مثبت'),
(128786, 4923, 36, 'مثبت ها'),
(128787, 4925, 36, 'ارسال برای'),
(128788, 4926, 36, 'Post Nasal Drip'),
(128789, 4927, 36, 'درج پرداخت'),
(128790, 4928, 36, 'Post surgical'),
(128791, 4937, 36, 'پستی'),
(128792, 4938, 36, 'کد پستی'),
(128793, 4939, 36, 'کد پستی'),
(128794, 4953, 36, 'دفتر پزشکی‌'),
(128795, 4954, 36, 'تنظیم پیش فرض دفتر'),
(128796, 4955, 36, 'تنظیمات دفتر پزشکی‌'),
(128797, 4956, 36, 'پزشک'),
(128798, 4958, 36, 'پیش پرداخت'),
(128799, 4959, 36, 'پیش پرداخت'),
(128800, 4964, 36, 'تنظیمات'),
(128801, 4965, 36, 'دسته بندی رویداد انتخابی'),
(128802, 4966, 36, 'زبان انتخابی'),
(128803, 4967, 36, 'داروخانه انتخابی'),
(128804, 4970, 36, 'مقدماتی'),
(128805, 4972, 36, 'پیش پرداخت'),
(128806, 4973, 36, 'نسخه'),
(128807, 4975, 36, 'تاریخچه نسخه'),
(128808, 4977, 36, 'برچسب نسخه'),
(128809, 4978, 36, 'گزارش نسخه'),
(128810, 4979, 36, 'نسخه ها'),
(128811, 4980, 36, 'نسخه ها و مقدرات'),
(128812, 4981, 36, 'نسخه ها و معارفه های دیگر'),
(128813, 4983, 36, 'گزارش نسخه ها'),
(128814, 4984, 36, 'تجویزها / ارجاعات'),
(128815, 4989, 36, 'تشخیص محتمل'),
(128816, 4991, 36, 'قبلی'),
(128817, 4993, 36, 'ماه گذشته (برای منو نگه دارید)'),
(128818, 4994, 36, 'سال گذشته (برای منو نگه دارید)'),
(128819, 4995, 36, 'مراقبت پیشگیرانه'),
(128820, 4998, 36, 'پیش نمایش رویداد'),
(128821, 5000, 36, 'پیش نمایش'),
(128822, 5001, 36, 'قبلی'),
(128823, 5002, 36, 'مشورت قبلی'),
(128824, 5003, 36, 'روز گذشته'),
(128825, 5005, 36, 'ماه گذشته'),
(128826, 5006, 36, 'هفته گذشته'),
(128827, 5007, 36, 'قیمت'),
(128828, 5008, 36, 'تنزیل قیمت'),
(128829, 5009, 36, 'سطح قیمت'),
(128830, 5010, 36, 'سطح قیمت:'),
(128831, 5011, 36, 'قیمت ها'),
(128832, 5012, 36, 'اصلی'),
(128833, 5013, 36, 'واحد تجاری اصلی'),
(128834, 5022, 36, 'بیمه اصلی'),
(128835, 5023, 36, 'بیمه اصلی'),
(128836, 5024, 36, 'اطلاعات بیمه اصلی'),
(128837, 5025, 36, 'ارائه دهنده خدمات بیمه اصلی'),
(128838, 5026, 36, 'ارائه دهنده خدمات اصلی'),
(128839, 5027, 36, 'چاپ'),
(128840, 5028, 36, 'چاپ (HTML)'),
(128841, 5029, 36, 'چاپ (PDF)'),
(128842, 5032, 36, 'چاپ فرم ارجاع خالی'),
(128843, 5033, 36, 'دستور چاپ'),
(128844, 5042, 36, 'پیام چاپ'),
(128845, 5043, 36, 'چاپ های متعدد'),
(128846, 5044, 36, 'چاپ های متعدد به فکس'),
(128847, 5046, 36, 'چاپ یادداشت ها'),
(128848, 5047, 36, 'چاپ صفحه 1'),
(128849, 5048, 36, 'چاپ صفحه 2'),
(128850, 5053, 36, 'چاپ عبارت انتخاب شده'),
(128851, 5056, 36, 'چاپ این ویزیت'),
(128852, 5057, 36, 'چاپ این یادداشت'),
(128853, 5058, 36, 'چاپ این یادداشت'),
(128854, 5062, 36, 'قابل چاپ'),
(128855, 5063, 36, 'نسخه قابل چاپ'),
(128856, 5064, 36, 'چاپ شده'),
(128857, 5066, 36, 'در حال چاپ نتایج:'),
(128858, 5071, 36, 'ملاقات قبلی'),
(128859, 5072, 36, 'اولویت'),
(128860, 5073, 36, 'اولویت '),
(128861, 5074, 36, 'خصوصی'),
(128862, 5075, 36, 'مشکل'),
(128863, 5077, 36, 'لیست مشکلات'),
(128864, 5079, 36, 'مشکلات/مسائل'),
(128865, 5086, 36, 'رویه'),
(128866, 5089, 36, 'کد رویه'),
(128867, 5090, 36, 'کدهای رویه'),
(128868, 5092, 36, 'نام رویه'),
(128869, 5093, 36, 'دستور رویه'),
(128870, 5094, 36, 'دستور رویه'),
(128871, 5095, 36, 'دستور رویه برای'),
(128872, 5097, 36, 'گزارشات و دستورات رویه'),
(128873, 5099, 36, 'فراهم کننده رویه'),
(128874, 5100, 36, 'فراهم کننده رویه'),
(128875, 5101, 36, 'فراهم کنندگان رویه'),
(128876, 5102, 36, 'گزارش رویه'),
(128877, 5103, 36, 'وضعیتهای گزارش رویه'),
(128878, 5104, 36, 'نتیجه رویه غیر طبیعی'),
(128879, 5105, 36, 'وضعیت های نتایج رویه'),
(128880, 5106, 36, 'نتایج رویه'),
(128881, 5108, 36, 'انواع نمونه مورد استفاده در رویه'),
(128882, 5109, 36, 'گزارش آماری رویه'),
(128883, 5110, 36, 'نوع اقدام پزشکی‌'),
(128884, 5111, 36, 'انواع اقدامات پزشکی‌'),
(128885, 5112, 36, 'واحد رویه'),
(128886, 5113, 36, 'رویه / خدمات'),
(128887, 5114, 36, 'اقدامات پزشکی‌'),
(128888, 5115, 36, 'پروسه'),
(128889, 5116, 36, 'پردازش و ارسال یادآورها'),
(128890, 5117, 36, 'پردازش فایل ERA'),
(128891, 5119, 36, 'پردازش یادآورها'),
(128892, 5120, 36, 'پردازش به مقداری زمان نیاز دارد'),
(128893, 5121, 36, 'پردازش'),
(128894, 5122, 36, 'پردازش شده'),
(128895, 5123, 36, 'تاریخ پردازش'),
(128896, 5124, 36, 'با موفقیت مورد پردازش قرار گرفت'),
(128897, 5125, 36, 'پردازش'),
(128898, 5126, 36, 'در حال پردازش و ارسال یادآورهای بیمار'),
(128899, 5127, 36, 'در حال پردازش یادآورهای بیمار'),
(128900, 5128, 36, 'زمان پردازش'),
(128901, 5129, 36, 'محصول'),
(128902, 5135, 36, 'پیشرفت معالجات'),
(128903, 5136, 36, 'سرطان پروستات'),
(128904, 5137, 36, 'آزمون سرطان پروستات'),
(128905, 5138, 36, 'معاینه پروستات'),
(128906, 5140, 36, 'Prostate w/o enlrgmt, nodules, tender'),
(128907, 5145, 36, 'خلاصه های بالینی بیماران را برای هر یک از ملاقاتهایشان ارائه کنید.'),
(128908, 5148, 36, 'ارائه سوابق به بیمار برای ملاقات'),
(128909, 5152, 36, 'ارائه دهنده خدمات'),
(128910, 5154, 36, 'شناسه ارائه دهنده خدمات'),
(128911, 5159, 36, 'شماره ارائه دهنده خدمات'),
(128912, 5162, 36, 'ارائه دهنده خدمات:'),
(128913, 5163, 36, 'ارائه دهندگان خدمات'),
(128914, 5167, 36, 'PSA'),
(128915, 5168, 36, 'Psoriasis'),
(128916, 5169, 36, 'تشخیص روانپزشکی'),
(128917, 5170, 36, 'داروی روانپزشکی'),
(128918, 5171, 36, 'روانپزشکی'),
(128919, 5172, 36, 'نامه مختصر روانپزشکی'),
(128920, 5173, 36, 'تشخیص روانپزشکی'),
(128921, 5174, 36, 'معاینه روانی'),
(128922, 5175, 36, 'تاریخچه روانپزشکی'),
(128923, 5177, 36, 'داروی روانپزشکی'),
(128924, 5179, 36, 'یادداشت های بیمار'),
(128925, 5180, 36, 'یادداشت ها/ تاییدهای بیمار'),
(128926, 5181, 36, 'اضافه پرداختی بیمار'),
(128927, 5182, 36, 'پرداختی بیمار'),
(128928, 5183, 36, 'درخواست سابقه بیمار'),
(128929, 5184, 36, 'بازپرداخت بیمار'),
(128930, 5185, 36, 'مرخص شدن بیمار'),
(128931, 5186, 36, 'گزارش بیمار'),
(128932, 5187, 36, 'دانشجوی بیمار، یا خالی بگذارید'),
(128933, 5201, 36, 'عمومی'),
(128934, 5204, 36, 'پورتوریکویی'),
(128935, 5205, 36, 'ریوی'),
(128936, 5206, 36, 'نبض'),
(128937, 5207, 36, 'پنجابی'),
(128938, 5208, 36, 'خرید'),
(128939, 5209, 36, 'خرید/پس دادن'),
(128940, 5210, 36, 'خریدها'),
(128941, 5213, 36, 'q.3h'),
(128942, 5214, 36, 'q.4h'),
(128943, 5215, 36, 'q.5h'),
(128944, 5216, 36, 'q.6h'),
(128945, 5217, 36, 'q.8h'),
(128946, 5218, 36, 'q.d.'),
(128947, 5219, 36, 'q.i.d.'),
(128948, 5220, 36, 'QOH'),
(128949, 5245, 36, 'نژاد'),
(128950, 5246, 36, 'نژاد و قومیت'),
(128951, 5247, 36, 'نژاد/قومیت'),
(128952, 5248, 36, 'رادیو'),
(128953, 5251, 36, 'محدوده'),
(128954, 5252, 36, 'Rashes'),
(128955, 5253, 36, 'نرخ'),
(128956, 5254, 36, 'نسبت'),
(128957, 5255, 36, 'گزارش اولیه'),
(128958, 5263, 36, 'واکنش'),
(128959, 5264, 36, 'واکنش ها'),
(128960, 5265, 36, 'خواندن'),
(128961, 5268, 36, 'نام واقعی'),
(128962, 5269, 36, 'واقعا حذف کنید'),
(128963, 5270, 36, 'دلیل'),
(128964, 5271, 36, 'دلیل مرگ'),
(128965, 5272, 36, 'دلیل مرگ'),
(128966, 5274, 36, 'دلیل مراجعه'),
(128967, 5275, 36, 'دلیل ملاقات'),
(128968, 5276, 36, 'دلیل/فرم'),
(128969, 5296, 36, 'گیرنده افشاء نامه'),
(128970, 5300, 36, 'توصیه ها'),
(128971, 5301, 36, 'توصیه ها و درمان'),
(128972, 5302, 36, 'توصیه های متخصص'),
(128973, 5303, 36, 'سابقه'),
(128974, 5312, 36, 'ثبت افشاء نامه'),
(128975, 5317, 36, 'سوابق'),
(128976, 5318, 36, 'سوابق یافت شد'),
(128977, 5319, 36, 'سوابق یافت شد.'),
(128978, 5320, 36, 'استفاده از مواد مخدر تفریحی'),
(128979, 5321, 36, 'مواد مخدر تفریحی'),
(128980, 5322, 36, 'مقعدی'),
(128981, 5323, 36, 'معاینه مقعد'),
(128982, 5324, 36, 'از راه مقعد'),
(128983, 5326, 36, 'سرخی'),
(128984, 5327, 36, 'کاهش یافته:'),
(128985, 5328, 36, 'ارجاع'),
(128986, 5329, 36, 'ارجاع توسط'),
(128987, 5330, 36, 'تاریخ ارجاع'),
(128988, 5331, 36, 'ارجاع به'),
(128989, 5332, 36, 'تقسیم بندی ارجاع (سطح خطر)'),
(128990, 5333, 36, 'محدوده نتایج ارجاع'),
(128991, 5334, 36, 'دلیل ارجاع'),
(128992, 5336, 36, 'نام و امضاء ارجاع دهنده'),
(128993, 5337, 36, 'ارجاع'),
(128994, 5338, 36, 'ارجاع بر اساس'),
(128995, 5339, 36, 'کارت ارجاع'),
(128996, 5340, 36, 'تاریخ ارجاع'),
(128997, 5341, 36, 'فرم ارچاع'),
(128998, 5342, 36, 'فرم ارجاع'),
(128999, 5343, 36, 'شناسه ارچاع'),
(129000, 5345, 36, 'منبع ارجاع'),
(129001, 5347, 36, 'ارچاع به'),
(129002, 5348, 36, 'معارفه ها'),
(129003, 5349, 36, 'گزارش معارفه ها'),
(129004, 5350, 36, 'معرفی شده توسط'),
(129005, 5351, 36, 'معرفی شده توسط'),
(129006, 5352, 36, 'معرفی شده به'),
(129007, 5353, 36, 'معرفی کننده'),
(129008, 5355, 36, 'تشخیص ارجاع دهنده'),
(129009, 5356, 36, 'تشخیص ارجاع دهنده'),
(129010, 5357, 36, 'دکتر و کلینیک ارجاع دهنده'),
(129011, 5358, 36, 'دکتر ارجاع دهنده'),
(129012, 5359, 36, 'پر کردن مجدد'),
(129013, 5360, 36, 'پر کردن مجدد'),
(129014, 5361, 36, 'پر کردن مجدد'),
(129015, 5362, 36, 'Reflexes normal'),
(129016, 5363, 36, 'تازه کردن'),
(129017, 5365, 36, 'تازه کردن یادآورها'),
(129018, 5368, 36, 'خودداری از بیان'),
(129019, 5370, 36, 'ثبت نام'),
(129020, 5372, 36, 'ثبت نام کرده'),
(129021, 5373, 36, 'ثبت نام کرده'),
(129022, 5375, 36, 'تاریخ ثبت نام'),
(129023, 5376, 36, 'فرم ثبت نام'),
(129024, 5381, 36, 'مرتبط به'),
(129025, 5382, 36, 'مرتبط'),
(129026, 5383, 36, 'مسائل مربوط'),
(129027, 5385, 36, 'رابطه (ها) / کودکان'),
(129028, 5386, 36, 'روابط'),
(129029, 5387, 36, 'رابطه'),
(129030, 5389, 36, 'بستگان'),
(129031, 5402, 36, 'تاریخ مرخص شدن'),
(129032, 5403, 36, 'مذهب'),
(129033, 5406, 36, 'ورود دوباره به سیستم'),
(129034, 5409, 36, 'یادآوری'),
(129035, 5410, 36, 'فواصل یادآوری ها'),
(129036, 5412, 36, 'یادآوری فرستاده شد'),
(129037, 5413, 36, 'یادآوری ها'),
(129038, 5426, 36, 'Renal Stones'),
(129039, 5438, 36, 'تکرار رویداد'),
(129040, 5439, 36, 'تکرار اطلاعات:'),
(129041, 5440, 36, 'تکرارها'),
(129042, 5444, 36, 'تاریخ پاسخ'),
(129043, 5445, 36, 'پاسخ از'),
(129044, 5446, 36, 'گزارش'),
(129045, 5447, 36, 'گزارش - بالینی'),
(129046, 5449, 36, 'گزارش توسط'),
(129047, 5457, 36, 'وضعیت گزارش'),
(129048, 5458, 36, 'گزارش مجموع'),
(129049, 5459, 36, 'گزارش از'),
(129050, 5460, 36, 'قابل گزارش'),
(129051, 5461, 36, 'گزارش شده'),
(129052, 5462, 36, 'تاریخ گزارش'),
(129053, 5463, 36, 'گزارش ها'),
(129054, 5474, 36, 'سرویس درخواست شده'),
(129055, 5475, 36, 'ملزم به کلمات عبور قوی'),
(129056, 5476, 36, 'ملزم به کلمه عبور منحصر به فرد'),
(129057, 5477, 36, 'ضروری'),
(129058, 5483, 36, 'فیلدهای لازم'),
(129059, 5484, 36, 'الزامات'),
(129060, 5485, 36, 'رزرو شده'),
(129061, 5486, 36, 'رزرو شده'),
(129062, 5491, 36, 'تنظیم مجدد'),
(129063, 5492, 36, 'تنظیم مجدد اعتبارنامه پورتال برای خارج از سایت'),
(129064, 5493, 36, 'تنظیم مجدد اعتبارنامه پورتال برای داخل سایت'),
(129065, 5496, 36, 'حل و فصل شد'),
(129066, 5497, 36, 'تنفس'),
(129067, 5499, 36, 'تنفسی'),
(129068, 5504, 36, 'نتیجه'),
(129069, 5506, 36, 'نتیجه وضعیت'),
(129070, 5507, 36, 'وضعیت نتیجه یا اختلالات خالی‌ هست'),
(129071, 5510, 36, 'نتایج و'),
(129072, 5511, 36, 'نتایج جستجو یافت شد'),
(129073, 5512, 36, 'نتایج گروه'),
(129074, 5515, 36, 'تعداد نتایج در هر صفحه'),
(129075, 5516, 36, 'نتایج/جزئیات'),
(129076, 5517, 36, 'معاینه شبکیه'),
(129077, 5519, 36, 'بازگشت'),
(129078, 5521, 36, 'بازگشت به تقویم'),
(129079, 5528, 36, 'ملاقات مجدد'),
(129080, 5535, 36, 'بررسی سیستم ها'),
(129081, 5536, 36, 'چک لیست بررسی سیستم ها'),
(129082, 5537, 36, 'بررسی شد'),
(129083, 5539, 36, 'Rheumatoid Arthritis'),
(129084, 5540, 36, 'Rheumotoid Arthritis'),
(129085, 5541, 36, 'راست'),
(129086, 5542, 36, 'گوش راست'),
(129087, 5543, 36, 'گوش راست'),
(129088, 5545, 36, 'راست:'),
(129089, 5546, 36, 'زنگ زدن در گوش'),
(129090, 5547, 36, 'زنگ زدن در گوش'),
(129091, 5549, 36, 'عوامل خطر'),
(129092, 5550, 36, 'سطح خطر'),
(129093, 5553, 36, 'رومانیایی'),
(129094, 5564, 36, 'ردیف'),
(129095, 5568, 36, 'قاعده'),
(129096, 5569, 36, 'قاعده جدید'),
(129097, 5570, 36, 'جزئیات قاعده'),
(129098, 5572, 36, 'قاعده ویرایش'),
(129099, 5575, 36, 'مجموعه قواعد'),
(129100, 5578, 36, 'قواعد'),
(129101, 5580, 36, 'تنظیمات قواعد'),
(129102, 5581, 36, 'دستور در حال اجرا: '),
(129103, 5582, 36, 'پارگی'),
(129104, 5583, 36, 'روسی'),
(129105, 5584, 36, 'Rx'),
(129106, 5585, 36, 'RX'),
(129107, 5601, 36, 'کد ملی‌'),
(129108, 5602, 36, 'S3:'),
(129109, 5603, 36, 'S4:'),
(129110, 5604, 36, 'SA ** برای خواندن مجوز لطفا به این اسناد مراجعه کنید docs/license.txt یا http://www.gnu.org/copyleft/gpl.html ** //========================================================================= // '),
(129111, 5605, 36, 'فروش'),
(129112, 5606, 36, 'فروش'),
(129113, 5607, 36, 'فروش بر اساس آیتم ها'),
(129114, 5608, 36, 'فروش بر اساس گزارش محصول'),
(129115, 5609, 36, 'بزاق'),
(129116, 5610, 36, 'همان روز'),
(129117, 5611, 36, 'اهل جزیره ساموا'),
(129118, 5612, 36, 'نمونه'),
(129119, 5613, 36, 'نوع تحریم'),
(129120, 5617, 36, 'شنبه'),
(129121, 5618, 36, 'شنبه و یکشنبه'),
(129122, 5619, 36, 'شنبه'),
(129123, 5620, 36, 'ذخیره'),
(129124, 5621, 36, 'ذخیره'),
(129125, 5622, 36, 'ذخیره و بستن'),
(129126, 5624, 36, 'ذخیره و توزیع'),
(129127, 5626, 36, 'ذخیره به عنوان جدید'),
(129128, 5628, 36, 'ذخیره تنظیمات گواهینامه'),
(129129, 5629, 36, 'ذخیره تغییرات'),
(129130, 5630, 36, 'ذخیره فرم'),
(129131, 5631, 36, 'ذخیره واکسیناسیون'),
(129132, 5633, 36, 'ذخیره گروه جدید'),
(129133, 5634, 36, 'ذخیره لیست جدید'),
(129134, 5639, 36, 'ذخیره تراکنش'),
(129135, 5652, 36, 'آدرس SE'),
(129136, 5653, 36, 'شهر SE'),
(129137, 5654, 36, 'کشور SE'),
(129138, 5655, 36, 'محله SE'),
(129139, 5656, 36, 'کد پستی SE'),
(129140, 5657, 36, 'استان SE'),
(129141, 5658, 36, 'کد پستی SE'),
(129142, 5659, 36, 'جستجو'),
(129143, 5661, 36, 'جستجو'),
(129144, 5662, 36, 'جستجوی مجدد'),
(129145, 5663, 36, 'جستجو تمام ستون ها'),
(129146, 5664, 36, 'جستجو بر اساس:'),
(129147, 5665, 36, 'جستجو برای'),
(129148, 5666, 36, 'جستجو برای:'),
(129149, 5668, 36, 'جستجو در'),
(129150, 5669, 36, 'جستجو یا بیمار جدید'),
(129151, 5670, 36, 'جستجوی پرداخت ها'),
(129152, 5671, 36, 'نتیجه های جستجو'),
(129153, 5672, 36, 'نتیجه های جستجو:'),
(129154, 5673, 36, 'انتخاب جستجو'),
(129155, 5676, 36, 'متن جستجو'),
(129156, 5677, 36, 'جستجوی رویدادها'),
(129157, 5678, 36, 'جستجو/افزودن'),
(129158, 5679, 36, 'جستجو/افزودن بیمه'),
(129159, 5680, 36, 'جستجوی قرار ملاقات ها'),
(129160, 5681, 36, 'جستجو ...'),
(129161, 5682, 36, 'استفاده از کمربند ایمنی'),
(129162, 5683, 36, 'استفاده از کمربند ایمنی'),
(129163, 5684, 36, 'دوم'),
(129164, 5687, 36, 'ثانوی'),
(129165, 5688, 36, 'بیمه ثانوی'),
(129166, 5689, 36, 'اطلاعات بیمه ثانوی'),
(129167, 5690, 36, 'ارائه دهنده بیمه ثانوی'),
(129168, 5691, 36, 'نوع Medicare ثانوی'),
(129169, 5698, 36, 'امنیت'),
(129170, 5699, 36, 'دیدن همه'),
(129171, 5700, 36, 'دیدن مجوز'),
(129172, 5707, 36, 'Seizures'),
(129173, 5708, 36, 'گزیدن'),
(129174, 5709, 36, 'گزیدن'),
(129175, 5710, 36, 'گزیدن'),
(129176, 5712, 36, 'انتخاب یک زمینه'),
(129177, 5714, 36, 'انتخاب مدت زمان'),
(129178, 5715, 36, 'انتخاب یک کاربر'),
(129179, 5716, 36, 'انتخاب همه'),
(129180, 5722, 36, 'گزینه های مربوطه را انتخاب کنید تا حذف شوند'),
(129181, 5727, 36, 'انتخاب تاریخ'),
(129182, 5728, 36, 'گزیدن اکیپ'),
(129183, 5729, 36, 'گزیدن تشخیص بیماری'),
(129184, 5731, 36, 'انتخاب دارو'),
(129185, 5732, 36, 'انتخاب داروها'),
(129186, 5736, 36, 'انتخاب پارامتر'),
(129187, 5737, 36, 'انتخاب پارامترها'),
(129188, 5738, 36, 'برای چاپ انتخاب کنید'),
(129189, 5739, 36, 'انتخاب واکسیناسیون'),
(129190, 5742, 36, 'انتخاب مسئله'),
(129191, 5744, 36, 'انتخاب زبان'),
(129192, 5746, 36, 'انتخاب یک یا چند کد تشخیص برای توجیه خدمات'),
(129193, 5759, 36, 'انتخاب کاربر'),
(129194, 5760, 36, 'کاربران را از فهرست کرکره ای انتخاب کنید'),
(129195, 5762, 36, 'برای تایید حذف گروه بله را انتخاب کنید'),
(129196, 5765, 36, 'منتخب'),
(129197, 5766, 36, 'ویزیت انتخاب شده'),
(129198, 5768, 36, 'شخصی‌'),
(129199, 5769, 36, 'پرداخت شخصی‌'),
(129200, 5771, 36, 'ارسال'),
(129201, 5772, 36, 'ارسال یادآوری مورخ'),
(129202, 5773, 36, 'ارسال یادآوری'),
(129203, 5774, 36, 'ارسال در حال انجام'),
(129204, 5775, 36, 'ارسال پیام'),
(129205, 5776, 36, 'ارسال دسته یادآوری ها'),
(129206, 5777, 36, 'ارسال یادآوری به بیماران طبق اولویت بیمار برای پیشگیری/پیگیری مراقبت.'),
(129207, 5778, 36, 'ارسال خلاصه ها با معارفه ها'),
(129208, 5779, 36, 'ارسال این پرونده'),
(129209, 5780, 36, 'ارسال این پیام'),
(129210, 5781, 36, 'ارسال به'),
(129211, 5784, 36, 'ارسال به همه'),
(129212, 5788, 36, 'فرستنده'),
(129213, 5789, 36, 'فرستنده شناسه'),
(129214, 5794, 36, 'حساسیت'),
(129215, 5795, 36, 'حساسیت:'),
(129216, 5796, 36, 'معاینه حسی نرمال'),
(129217, 5799, 36, 'ارسال شده توسط; اگر برای همه, خالی بگذارید'),
(129218, 5801, 36, 'تاریخ ارسال'),
(129219, 5802, 36, 'ارسال شده'),
(129220, 5803, 36, 'ارسال مدارک پزشکی؟'),
(129221, 5804, 36, 'با موفقیت ارسال شد'),
(129222, 5807, 36, 'به چاپگر فرستاده شد.'),
(129223, 5808, 36, 'ارسال شده به; اگر برای همه, خالی بگذارید'),
(129224, 5812, 36, 'سپتامبر'),
(129225, 5813, 36, 'جدا از هم'),
(129226, 5814, 36, 'سپتامبر'),
(129227, 5816, 36, 'ترتیب'),
(129228, 5821, 36, 'خدمت'),
(129229, 5822, 36, 'دسته بندی خدمت'),
(129230, 5823, 36, 'کد خدمت'),
(129231, 5824, 36, 'گزارش مالی کد خدمت'),
(129232, 5825, 36, 'کد های خدمت'),
(129233, 5826, 36, 'تاریخ خدمت'),
(129234, 5827, 36, 'تاریخ خدمت:'),
(129235, 5829, 36, 'محل ارائه خدمات'),
(129236, 5831, 36, 'خدمت ارائه شده توسط متخصص'),
(129237, 5832, 36, 'گزارش خدمت'),
(129238, 5833, 36, 'گزارش خدمات تنها'),
(129239, 5834, 36, 'خدمات'),
(129240, 5835, 36, 'خدمات بر اساس دسته بندی'),
(129241, 5836, 36, 'خدمات ارائه شده'),
(129242, 5837, 36, 'خدمات ارائه شده'),
(129243, 5838, 36, 'خدمات / محصولات'),
(129244, 5851, 36, 'میگرن شدید'),
(129245, 5853, 36, 'شدت درد'),
(129246, 5854, 36, 'شدت درد:'),
(129247, 5855, 36, 'جنس'),
(129248, 5856, 36, 'بیماری آمیزشی'),
(129249, 5859, 36, 'اشتراک'),
(129250, 5864, 36, 'تنگی نفس'),
(129251, 5865, 36, 'تنگی نفس'),
(129252, 5866, 36, 'تنگی نفس 2'),
(129253, 5874, 36, 'شانه'),
(129254, 5875, 36, 'شانه + ترقوه'),
(129255, 5876, 36, 'مشکلات شانه'),
(129256, 5877, 36, 'نمایش'),
(129257, 5878, 36, 'نمایش یادداشت های فعال'),
(129258, 5880, 36, 'نمایش همه'),
(129259, 5883, 36, 'نمایش همه تراکنش ها'),
(129260, 5884, 36, 'مشغول نشان بده'),
(129261, 5885, 36, 'تنها نمایش دارای مجوز'),
(129262, 5886, 36, 'زمان قابل استفاده را نشان بده'),
(129263, 5894, 36, 'نمایش یادداشت های غیر فعال'),
(129264, 5896, 36, 'نمایش منو'),
(129265, 5897, 36, 'نمایش به متریک'),
(129266, 5898, 36, 'نمایش یادداشت ها'),
(129267, 5901, 36, 'نمایش یادداشت های بیمار'),
(129268, 5904, 36, 'نمایش اولیه کامل'),
(129269, 5905, 36, 'نمایش یادآوری ها'),
(129270, 5913, 36, 'تنها صورتحساب صادر نشده را نشان بده'),
(129271, 5914, 36, 'تنها ایالات متحده را نشان بده'),
(129272, 5915, 36, 'نمایش'),
(129273, 5920, 36, 'خواهر و برادر'),
(129274, 5921, 36, 'Sickle Cell'),
(129275, 5923, 36, 'Sigmoid/Colonoscopy'),
(129276, 5926, 36, 'نتایج را امضا کنید'),
(129277, 5927, 36, 'امضا'),
(129278, 5929, 36, 'امضا:'),
(129279, 5937, 36, 'پس از'),
(129280, 5938, 36, 'با احترام،'),
(129281, 5940, 36, 'مجرد'),
(129282, 5946, 36, 'مشکلات سینوسی'),
(129283, 5947, 36, 'جراحی سینوس'),
(129284, 5949, 36, 'سینوزیت'),
(129285, 5951, 36, 'شناسه سایت'),
(129286, 5956, 36, 'اندازه'),
(129287, 5959, 36, 'پوست'),
(129288, 5960, 36, 'سرطان پوست'),
(129289, 5961, 36, 'بیماری های پوستی'),
(129290, 5967, 36, 'الگوهای خواب'),
(129291, 5968, 36, 'الگوهای خواب'),
(129292, 5969, 36, 'خوابیدن'),
(129293, 5970, 36, 'اسلواکی'),
(129294, 5973, 36, 'حافظه نهان Smarty پاک شد'),
(129295, 5976, 36, 'وضعیت سیگار کشیدن'),
(129296, 5977, 36, 'اجازه SMS'),
(129297, 5983, 36, 'هشدار از طریق SMS'),
(129298, 5984, 36, 'ساعت هشدار از طریق SMS'),
(129299, 5985, 36, 'ارسال SMS قبل از'),
(129300, 5986, 36, 'SMS ارسال شد'),
(129301, 6004, 36, 'خرناس'),
(129302, 6005, 36, 'فرم پیشرفت معالجات SOAP'),
(129303, 6029, 36, 'مرتب سازی بر اساس'),
(129304, 6030, 36, 'مرتب سازی بر اساس'),
(129305, 6031, 36, 'چیدمان بر اساس شماره کنترل'),
(129306, 6034, 36, 'مرتب سازی بر اساس تاریخ'),
(129307, 6035, 36, 'مرتب سازی بر اساس تاریخ/زمان'),
(129308, 6036, 36, 'مرتب سازی بر اساس رویداد'),
(129309, 6037, 36, 'مرتب سازی بر اساس گروه'),
(129310, 6040, 36, 'مرتب سازی بر اساس شناسه بیمار'),
(129311, 6041, 36, 'مرتب سازی بر اساس موفقیت'),
(129312, 6043, 36, 'مرتب سازی بر اساس کاربر'),
(129313, 6044, 36, 'مرتب سازی بر اساس واکسن'),
(129314, 6045, 36, 'مرتب سازی به پایین'),
(129315, 6046, 36, 'مرتب سازی نتایج بر اساس'),
(129316, 6047, 36, 'مرتب کردن به بالا'),
(129317, 6048, 36, 'منبع'),
(129318, 6049, 36, 'پرونده منبع'),
(129319, 6050, 36, 'مسیر فایل پرونده منبع'),
(129320, 6057, 36, 'منبع:'),
(129321, 6060, 36, 'فاصله'),
(129322, 6061, 36, 'فاصله'),
(129323, 6062, 36, 'اسپانیایی'),
(129324, 6063, 36, 'اسپانیایی (آمریکای لاتین)'),
(129325, 6064, 36, 'اسپانیایی (اسپانیا)'),
(129326, 6068, 36, 'متخصص'),
(129327, 6069, 36, 'نام و امضاء متخصص'),
(129328, 6071, 36, 'تخصص'),
(129329, 6072, 36, 'سیستم های تخصصی'),
(129330, 6073, 36, 'تخصص:'),
(129331, 6074, 36, 'ویژه'),
(129332, 6075, 36, 'کاربرد ویژه'),
(129333, 6076, 36, 'خدمات ویژه پیشگیری از بارداری'),
(129334, 6077, 36, 'نتایج ویژه'),
(129335, 6078, 36, 'خدمات ویژه'),
(129336, 6079, 36, 'مشخص شده'),
(129337, 6088, 36, 'نمونه'),
(129338, 6089, 36, 'تعداد/شناسه نمونه'),
(129339, 6090, 36, 'نوع نمونه'),
(129340, 6092, 36, 'دیکته کردن گفتار'),
(129341, 6095, 36, 'همسر'),
(129342, 6097, 36, 'Sputum'),
(129343, 6098, 36, 'Sputum:'),
(129344, 6099, 36, 'SQ'),
(129345, 6102, 36, 'اکیپ'),
(129346, 6103, 36, 'عضویت در اکیپ'),
(129347, 6104, 36, 'اکیپ های'),
(129348, 6109, 36, 'فرم ملاقات SRH'),
(129349, 6113, 36, 'کد ملی‌'),
(129350, 6114, 36, 'ثبات'),
(129351, 6115, 36, 'انتشار در چند مرحله'),
(129352, 6116, 36, 'استاندارد'),
(129353, 6117, 36, 'کد استاندارد'),
(129354, 6118, 36, 'اقدامات استاندارد'),
(129355, 6122, 36, 'نام استاندارد'),
(129356, 6124, 36, 'شروع'),
(129357, 6125, 36, 'شروع (YYYY-MM-DD): '),
(129358, 6128, 36, 'تاریخ شروع'),
(129359, 6129, 36, 'تاریخ شروع در این کلینیک'),
(129360, 6131, 36, 'از تاریخ:'),
(129361, 6132, 36, 'از تاریخ:'),
(129362, 6133, 36, 'az زمان'),
(129363, 6134, 36, 'از تاریخ'),
(129364, 6136, 36, 'استان'),
(129365, 6151, 36, 'آمار و ارقام'),
(129366, 6152, 36, 'آمار'),
(129367, 6153, 36, 'وضعیت'),
(129368, 6156, 36, 'وضع موجود'),
(129369, 6169, 36, 'مفاصل سفت'),
(129370, 6170, 36, 'سفتی'),
(129371, 6172, 36, 'دردهای معده'),
(129372, 6175, 36, 'فشار عضلانی'),
(129373, 6177, 36, 'خیابان'),
(129374, 6178, 36, 'آدرس خیابان'),
(129375, 6179, 36, 'خیابان و پلاک'),
(129376, 6180, 36, 'قدرت'),
(129377, 6182, 36, 'گلودرد استرپتوکوکی'),
(129378, 6183, 36, 'شکستگی ناشی از فشار'),
(129379, 6184, 36, 'تست استرس'),
(129380, 6185, 36, 'سکته مغزی'),
(129381, 6194, 36, 'موضوع'),
(129382, 6195, 36, 'ذهنی'),
(129383, 6196, 36, 'زیر زبانی'),
(129384, 6197, 36, 'زیر زبانی'),
(129385, 6198, 36, 'ارسال'),
(129386, 6199, 36, 'ارسال'),
(129387, 6200, 36, 'ارسال تمام مطالب'),
(129388, 6202, 36, 'ارسال رویداد'),
(129389, 6203, 36, 'ارسال فرم'),
(129390, 6204, 36, 'ارسال محتوای انتخاب شده'),
(129391, 6205, 36, 'ارسال شده'),
(129392, 6206, 36, 'ارسال شده توسط'),
(129393, 6208, 36, 'بیمه گر'),
(129394, 6209, 36, 'نشانی بیمه گر'),
(129395, 6213, 36, 'کارفرمای بیمه گر'),
(129396, 6214, 36, 'کارفرمای بیمه گر(SE)'),
(129397, 6215, 36, 'آدرس کارفرمای بیمه گر'),
(129398, 6216, 36, 'شهر کارفرمای بیمه گر'),
(129399, 6217, 36, 'کشور کارفرمای بیمه گر'),
(129400, 6218, 36, 'استان کارفرمای بیمه گر'),
(129401, 6221, 36, 'کد پستی کارفرمای بیمه گر'),
(129402, 6225, 36, 'تلفن بیمه گر'),
(129403, 6226, 36, 'نسبت بیمه گر'),
(129404, 6231, 36, 'جنسیت مشترک'),
(129405, 6237, 36, 'جایگزینی'),
(129406, 6238, 36, 'جایگزینی مجاز است'),
(129407, 6240, 36, 'موفقیت'),
(129408, 6241, 36, 'موفقیت'),
(129409, 6246, 36, 'دسته بندی با موفقیت اضافه شد'),
(129410, 6247, 36, 'با موفقیت به دسته بندی اضافه شد'),
(129411, 6248, 36, 'با موفقیت حذف شد'),
(129412, 6250, 36, 'پایگاه داده ها با موفقیت نصب شد.'),
(129413, 6251, 36, 'پایگاه داده های زیر با موفقیت نصب شد'),
(129414, 6259, 36, 'با موفقیت.'),
(129415, 6260, 36, 'خود کشی'),
(129416, 6261, 36, 'خلاصه'),
(129417, 6262, 36, 'خلاصه ای از'),
(129418, 6265, 36, 'یکشنبه'),
(129419, 6267, 36, 'یکشنبه'),
(129420, 6289, 36, 'نوع سطح'),
(129421, 6290, 36, 'اعمال جراحی'),
(129422, 6291, 36, 'عمل جراحی'),
(129423, 6293, 36, 'معلق'),
(129424, 6294, 36, 'تعلیق'),
(129425, 6295, 36, 'تاریخ خدمات'),
(129426, 6296, 36, 'تاریخ خدمات:'),
(129427, 6299, 36, 'عرق کردن:'),
(129428, 6300, 36, 'سوئدی'),
(129429, 6301, 36, 'ورم'),
(129430, 6302, 36, 'سمت راست تورم'),
(129431, 6303, 36, 'تورم مفاصل'),
(129432, 6304, 36, 'تورم غدد لنفاوی'),
(129433, 6318, 36, 'سیستم'),
(129434, 6323, 36, 't.i.d.'),
(129435, 6324, 36, 'تلویزیون'),
(129436, 6325, 36, 'جدول'),
(129437, 6327, 36, 'ایجاد جدول ناموفق بود'),
(129438, 6328, 36, 'جدول به روز رسانی ناموفق بود'),
(129439, 6332, 36, 'تاگالوگ'),
(129440, 6354, 36, 'شناسه مالیات'),
(129441, 6355, 36, 'نرخ مالیات'),
(129442, 6356, 36, 'عوارض'),
(129443, 6357, 36, 'طبقه بندی'),
(129444, 6373, 36, 'الگو:'),
(129445, 6374, 36, 'قالب ها'),
(129446, 6375, 36, 'شریان تمپورال'),
(129447, 6376, 36, 'آسیب دیدگی تاندون'),
(129448, 6379, 36, 'سوم'),
(129449, 6380, 36, 'بیمه سوم'),
(129450, 6381, 36, 'اطلاعات بیمه سوم'),
(129451, 6382, 36, 'ارائه دهنده بیمه سوم'),
(129452, 6383, 36, 'برنامه ریزی آزمون'),
(129453, 6384, 36, 'آزمون سیستم'),
(129454, 6385, 36, 'متن'),
(129455, 6386, 36, 'متن تشخیص بیماری'),
(129456, 6387, 36, 'زمینه متن'),
(129457, 6393, 36, 'تاریخ متن'),
(129458, 6394, 36, 'تاریخ متن'),
(129459, 6402, 36, 'با تشکر از شما'),
(129460, 6403, 36, 'با تشکر از شما برای انتخاب'),
(129461, 6444, 36, 'موارد ذیل مورد نیاز است'),
(129462, 6446, 36, 'موارد ذیل باید پر شوئد تا درخواست ارسال شود.'),
(129463, 6450, 36, 'صفحه اول برای جستجوی فاکتور است. در بالای صفحه، میتوانید یک مرجع اطلاعات (مثلا شماره چک)، تاریخ پرداخت و مبلغ چک را وارد کنید. دلیل قید مرجع اطلاعات و تاریخ پرداخت آن است که مجبور نباشید آنها را مجددا برای هر مطالبه وارد کنید. مبلغ وارد شده برای هر فاکتور بر اساس هر صورت حساب پرداختی مربوطه کاهش میابد، و انشاءالله سرانجام به صفر می‌رسد.'),
(129464, 6500, 36, 'هیچ پرونده‌ پزشکی‌ به متقاضی داده نشده'),
(129465, 6501, 36, 'هیچ افشاء نامه ای برای این بیمار وجود ندارد.'),
(129466, 6503, 36, 'یادداشتی برای این بیمار در فایل وجود ندارد.'),
(129467, 6524, 36, 'ران'),
(129468, 6525, 36, 'ران + عضلات عقب ران'),
(129469, 6542, 36, 'سومین'),
(129470, 6572, 36, 'این مکان'),
(129471, 6595, 36, 'این ملاقات آغاز استفاده از پیشگیری بارداری جدید میباشد'),
(129472, 6596, 36, 'این ملاقات نیازمند فرم GCAC، و مراجعه یا خدمات پزشکی دارد.'),
(129473, 6622, 36, 'ستون فقرات'),
(129474, 6625, 36, 'گلو'),
(129475, 6626, 36, 'سرطان گلو'),
(129476, 6627, 36, 'جراحی سرطان گلو'),
(129477, 6628, 36, 'ترومبوز/سکته مغزی'),
(129478, 6629, 36, 'پنجشنبه'),
(129479, 6630, 36, 'پنجشنبه'),
(129480, 6631, 36, 'پنجشنبه'),
(129481, 6632, 36, 'تیروئید طبیعی'),
(129482, 6633, 36, 'مشکلات تیروئید'),
(129483, 6638, 36, 'زمان'),
(129484, 6639, 36, 'سبک نمایش زمان'),
(129485, 6641, 36, 'انتخاب زمان'),
(129486, 6651, 36, 'زنگ زدن گوش'),
(129487, 6652, 36, 'عنوان'),
(129488, 6655, 36, 'عناوین'),
(129489, 6658, 36, 'به'),
(129490, 6659, 36, 'تا'),
(129491, 6660, 36, 'تا'),
(129492, 6663, 36, 'برای اضافه کردن یادداشت، لطفا اینجا را کلیک کنید'),
(129493, 6667, 36, 'به نمایش صدور صورت حساب'),
(129494, 6668, 36, 'به دسته'),
(129495, 6669, 36, 'به نمایش بالینی'),
(129496, 6681, 36, 'به تاریخچه'),
(129497, 6682, 36, 'به مسائل'),
(129498, 6685, 36, 'برای ورود دوباره'),
(129499, 6686, 36, 'برای ضبط افشاء، لطفا کلیک کنید'),
(129500, 6689, 36, 'به پوست'),
(129501, 6690, 36, 'به پوست'),
(129502, 6691, 36, 'به این ملاقات؟'),
(129503, 6693, 36, 'به:'),
(129504, 6694, 36, 'به: '),
(129505, 6708, 36, 'تنباکو'),
(129506, 6712, 36, 'مصرف دخانیات'),
(129507, 6713, 36, 'ارزیابی مصرف دخانیات'),
(129508, 6715, 36, 'امروز'),
(129509, 6716, 36, 'امروز'),
(129510, 6717, 36, 'امروز'),
(129511, 6728, 36, 'بالا'),
(129512, 6730, 36, 'مبحث'),
(129513, 6731, 36, 'مجموعا'),
(129514, 6732, 36, 'مجموعا'),
(129515, 6739, 36, 'مانده معوق کل'),
(129516, 6744, 36, 'گزینه توزیع کامل برای این شماره چک پر نشده'),
(129517, 6787, 36, 'تراکنش'),
(129518, 6788, 36, 'تراکنش'),
(129519, 6790, 36, 'تراکنش ناموفق، مقدار کمتر از صفر است'),
(129520, 6791, 36, 'نوع تراکنش'),
(129521, 6792, 36, 'تراکنش ها'),
(129522, 6793, 36, 'تراکنش ها'),
(129523, 6794, 36, 'تراکنش ها (نوشتن اختیاری)'),
(129524, 6795, 36, 'تراکنش ها/ارجاعات'),
(129525, 6807, 36, 'گروههای کنترل دسترسی ترجمه شود'),
(129526, 6819, 36, 'اسیب'),
(129527, 6820, 36, 'درمان'),
(129528, 6822, 36, 'اهداف درمان'),
(129529, 6823, 36, 'طرح درمانی'),
(129530, 6826, 36, 'درمان:'),
(129531, 6827, 36, 'درمان: '),
(129532, 6828, 36, 'روند'),
(129533, 6840, 36, 'سل'),
(129534, 6841, 36, 'سه‌شنبه'),
(129535, 6842, 36, 'سه شنبه و پنجشنبه'),
(129536, 6843, 36, 'سه‌شنبه'),
(129537, 6844, 36, 'غده'),
(129538, 6845, 36, 'ترکی'),
(129539, 6848, 36, 'دو بار در روز'),
(129540, 6851, 36, 'نوع'),
(129541, 6854, 36, 'نوع افشاء'),
(129542, 6855, 36, 'نوع رویدادها'),
(129543, 6856, 36, 'نوع چیدمان بندی صفحه نمایش'),
(129544, 6857, 36, 'شناسه بیمار را اینجا تایپ یا اسکن کنید'),
(129545, 6858, 36, 'پیام خود را اینجا تایپ کنید'),
(129546, 6859, 36, 'انواع سفارشات و نتایج'),
(129547, 6865, 36, 'اوکراینی'),
(129548, 6866, 36, 'زخمها'),
(129549, 6868, 36, 'زخمها:'),
(129550, 6877, 36, 'معین نشده'),
(129551, 6878, 36, 'غیر مجاز'),
(129552, 6880, 36, 'دسترسی غیر مجاز.'),
(129553, 6884, 36, 'زیر زبان'),
(129554, 6885, 36, 'کم وزنی');
INSERT INTO `lang_definitions` VALUES
(129555, 6890, 36, 'لغو "مرخص شدن"'),
(129556, 6899, 36, 'واحد'),
(129557, 6900, 36, 'واحدها'),
(129558, 6901, 36, 'واحدها'),
(129559, 6903, 36, 'واحدهای فرم های ملاقات'),
(129560, 6907, 36, 'مجهول'),
(129561, 6924, 36, 'تا'),
(129562, 6925, 36, 'بایگانی نابهنگام'),
(129563, 6928, 36, 'تاحدود'),
(129564, 6933, 36, 'به روز رسانی یادداشت های فعال'),
(129565, 6934, 36, 'به روز رسانی فایل'),
(129566, 6935, 36, 'به روز رسانی اطلاعات'),
(129567, 6936, 36, 'به روز رسانی لیست'),
(129568, 6937, 36, 'روز رسانی شماره ارائه دهنده خدمات'),
(129569, 6938, 36, 'بروز رسانی اقلام انتخاب شده'),
(129570, 6939, 36, 'بروز رسانی متغیرهای زیر در فایل'),
(129571, 6940, 36, 'به بروز رسانی اطلاعات کاربری'),
(129572, 6965, 36, 'پس از جستجو لیست فاکتورها به شما ارائه میشود. شما میتوانید روی یکی از شماره فاکتورها کلیک کنید تا صفحه دومی‌ برای وارد کردن اطلاعات و ارسال دستی باز شود. همچنین برای وارد کردن یاد داشت می توانید روی نام یک بیمار کلیک کنید تا کارکنان دفتر جلو در زمان پذیرش بیمار آن را ببینند. همچنین می توانید فاکتورهایی‌ را انتخاب کنید تا در صورت حسابهای بیماران قید شده و آن صورت حسابها را چاپ کنید.'),
(129573, 6966, 36, 'بازو'),
(129574, 6968, 36, 'ضرورت'),
(129575, 6970, 36, 'ادرار'),
(129576, 6972, 36, 'فرکانس ادرار'),
(129577, 6981, 36, 'آدرس وب سایت برای دروازه تلفن. خدمات خودکار VOIP توسط Maviq ارائه شده است. لطفا برای کسب اطلاعات بیشتر به این سایت مراجعه کنید. http://signup.maviq.com'),
(129578, 6999, 36, 'حدود تاریخ استفاده'),
(129579, 7007, 36, 'کاربر'),
(129580, 7009, 36, 'کاربر/گروه ها'),
(129581, 7010, 36, 'مدیریت کاربر'),
(129582, 7015, 36, 'تعریف شده توسط کاربر'),
(129583, 7016, 36, 'منطقه ۱۱ تعریف شده توسط کاربر'),
(129584, 7017, 36, 'منطقه ۱۲ تعریف شده توسط کاربر'),
(129585, 7018, 36, 'زمینه تعریف شده توسط کاربر'),
(129586, 7019, 36, 'لیست ۱ تعریف شده توسط کاربر'),
(129587, 7020, 36, 'لیست ۲ تعریف شده توسط کاربر'),
(129588, 7021, 36, 'لیست ۳ تعریف شده توسط کاربر'),
(129589, 7022, 36, 'لیست ۴ تعریف شده توسط کاربر'),
(129590, 7023, 36, 'لیست ۵ تعریف شده توسط کاربر'),
(129591, 7024, 36, 'لیست ۶ تعریف شده توسط کاربر'),
(129592, 7025, 36, 'لیست ۷ تعریف شده توسط کاربر'),
(129593, 7026, 36, 'متن ۱ تعریف شده توسط کاربر'),
(129594, 7027, 36, 'متن ۲ تعریف شده توسط کاربر'),
(129595, 7028, 36, 'متن ۳ تعریف شده توسط کاربر'),
(129596, 7029, 36, 'متن ۴ تعریف شده توسط کاربر'),
(129597, 7030, 36, 'متن ۵ تعریف شده توسط کاربر'),
(129598, 7031, 36, 'متن ۶ تعریف شده توسط کاربر'),
(129599, 7032, 36, 'متن ۷ تعریف شده توسط کاربر'),
(129600, 7033, 36, 'متن ۸ تعریف شده توسط کاربر'),
(129601, 7034, 36, 'نام کاربر'),
(129602, 7039, 36, 'کتابچه راهنمای کاربر'),
(129603, 7040, 36, 'تاریخ عضویت کاربر'),
(129604, 7041, 36, 'نام کاربر'),
(129605, 7043, 36, 'نام کاربر یا میزبان'),
(129606, 7046, 36, 'تنظیمات کاربر'),
(129607, 7047, 36, 'تنظیمات خاص کاربر'),
(129608, 7049, 36, 'نام کاربری برای وب سایت دروازه تلفن. خدمات خودکار VOIP توسط Maviq ارائه شده است. لطفا برای کسب اطلاعات بیشتر به این سایت مراجعه کنید. http://signup.maviq.com'),
(129609, 7055, 36, 'نام کاربری:'),
(129610, 7056, 36, 'کاربران'),
(129611, 7057, 36, 'کاربران/گروه ها/اداره گزارشا‌ت'),
(129612, 7062, 36, 'مرخصی'),
(129613, 7063, 36, 'مرخصی'),
(129614, 7064, 36, 'واکسن'),
(129615, 7067, 36, 'تایید اعتبار'),
(129616, 7068, 36, 'ارزش'),
(129617, 7083, 36, 'فروشنده'),
(129618, 7089, 36, 'ویتنامی'),
(129619, 7090, 36, 'مشاهده'),
(129620, 7091, 36, 'مشاهده'),
(129621, 7092, 36, 'مشاهده آلرژی'),
(129622, 7097, 36, 'مشاهده گزارش جامع بیمار'),
(129623, 7100, 36, 'مشاهده سند'),
(129624, 7107, 36, 'مشاهده رویدادها/عملیات'),
(129625, 7108, 36, 'مشاهده صفحه ۱'),
(129626, 7109, 36, 'نمایش صفحه ۲'),
(129627, 7110, 36, 'نمایش یادآورهای گذشته و آینده'),
(129628, 7111, 36, 'مشاهده بیمار'),
(129629, 7116, 36, 'برخوردهای مرتبط'),
(129630, 7121, 36, 'مشاهده/ویرایش آلرژی'),
(129631, 7122, 36, 'مشاهده/ویرایش مسئله'),
(129632, 7123, 36, 'مشاهده/چاپ'),
(129633, 7124, 36, 'مشاهده:'),
(129634, 7133, 36, 'دسته بندی ملاقات:'),
(129635, 7134, 36, 'تاریخ ملاقات'),
(129636, 7135, 36, 'تاریخ ملاقات'),
(129637, 7137, 36, 'فرم های ملاقات'),
(129638, 7138, 36, 'تاریخچه ملاقات'),
(129639, 7140, 36, 'ملاقات ها'),
(129640, 7142, 36, 'علایم حیاتی'),
(129641, 7143, 36, 'علایم حیاتی'),
(129642, 7146, 36, 'صدا'),
(129643, 7147, 36, 'صدا ارسال شد'),
(129644, 7149, 36, 'استفراغ'),
(129645, 7153, 36, 'دور کمر'),
(129646, 7154, 36, 'انتظار'),
(129647, 7155, 36, 'بدون وقت قبلی'),
(129648, 7158, 36, 'انبار کالا'),
(129649, 7161, 36, 'انبارهای کالا'),
(129650, 7162, 36, 'گرم'),
(129651, 7163, 36, 'هشدار'),
(129652, 7164, 36, 'هشدار'),
(129653, 7166, 36, 'هشدار، این شماره چک از قبل در پایگاه داده وجود داشته'),
(129654, 7168, 36, 'هشدار: امروز قبلا یک ملاقات برای این بیمار ساخته شد!'),
(129655, 7170, 36, 'هشدار: شناسه بیمار منحصر به فرد نیست!'),
(129656, 7173, 36, 'هشدارها'),
(129657, 7179, 36, 'ضعف'),
(129658, 7181, 36, 'جستجو در اینترنت'),
(129659, 7182, 36, 'سایت اینترنتی'),
(129660, 7184, 36, 'چهارشنبه'),
(129661, 7185, 36, 'چهارشنبه'),
(129662, 7186, 36, 'هفتگی'),
(129663, 7187, 36, 'هفته'),
(129664, 7188, 36, 'نمایش هفته ای'),
(129665, 7189, 36, 'هفته (ها)'),
(129666, 7190, 36, 'مواجهه شده هفتگی'),
(129667, 7192, 36, 'هفته ها'),
(129668, 7193, 36, 'وزن'),
(129669, 7194, 36, 'ارزیابی وزن و مشاوره برای کودکان و جوانان'),
(129670, 7196, 36, 'تغییر وزن'),
(129671, 7198, 36, 'کلینیک کاهش وزن'),
(129672, 7199, 36, 'خوش آمدید'),
(129673, 7203, 36, 'خس خس:'),
(129674, 7204, 36, 'خس خس سینه'),
(129675, 7205, 36, 'خس خس سینه:'),
(129676, 7212, 36, 'سفید'),
(129677, 7213, 36, 'هویت'),
(129678, 7214, 36, 'چه کسی پاسخ داد؟'),
(129679, 7215, 36, 'بیوه'),
(129680, 7216, 36, 'عرض'),
(129681, 7226, 36, 'در عرض چند ساعت'),
(129682, 7227, 36, 'در عرض چند ساعت:'),
(129683, 7228, 36, 'در عرض چند دقیقه'),
(129684, 7229, 36, 'در عرض چند دقیقه:'),
(129685, 7233, 36, 'شاهد'),
(129686, 7237, 36, 'زنان'),
(129687, 7238, 36, 'فقط برای خانمها'),
(129688, 7240, 36, 'کار'),
(129689, 7241, 36, 'یادداشت کار'),
(129690, 7242, 36, 'تلفن محل کار'),
(129691, 7243, 36, 'شماره تلفن محل کار'),
(129692, 7244, 36, 'مرتبط به کار؟'),
(129693, 7245, 36, 'کار/آموزش/سرگرمی'),
(129694, 7246, 36, 'یادداشت کار/مدرسه'),
(129695, 7247, 36, 'روز کاری'),
(129696, 7252, 36, 'بدتر'),
(129697, 7264, 36, 'مچ دست'),
(129698, 7265, 36, 'دست و مچ دست'),
(129699, 7266, 36, 'مشکلات مچ دست'),
(129700, 7267, 36, 'نوشتن'),
(129701, 7268, 36, 'کسر کردن'),
(129702, 7273, 36, 'x لغو شد'),
(129703, 7274, 36, 'x لغو شد'),
(129704, 7275, 36, 'آزمون اشعه ایکس'),
(129705, 7276, 36, 'تفسیر آزمون اشعه ایکس:'),
(129706, 7277, 36, 'تفسیر آزمون اشعه ایکس:'),
(129707, 7285, 36, 'سال'),
(129708, 7286, 36, 'سال'),
(129709, 7287, 36, 'نمایش سالیانه'),
(129710, 7288, 36, 'سال (ها)'),
(129711, 7289, 36, 'سال'),
(129712, 7292, 36, 'آری'),
(129713, 7293, 36, 'آری'),
(129714, 7294, 36, 'آری'),
(129715, 7295, 36, 'آری!'),
(129716, 7296, 36, 'آری، حذف و Log'),
(129717, 7298, 36, 'آری/خیر'),
(129718, 7299, 36, 'آری:'),
(129719, 7300, 36, 'ییدیش'),
(129720, 7329, 36, 'شما اول باید یک بیمار را انتخاب و یا اضافه کنید.'),
(129721, 7330, 36, 'شما اول باید یک ویزیت را انتخاب و یا اضافه کنید.'),
(129722, 7331, 36, 'شما باید یک دسته بندی ملاقات انتخاب کنید'),
(129723, 7332, 36, 'شما باید یک دسته بندی ملاقات انتخاب کنید.'),
(129724, 7387, 36, 'صفر'),
(129725, 7389, 36, 'کد پستی'),
(129726, 7390, 36, 'کد پستی'),
(129727, 7391, 36, 'کد پستی/کشور:'),
(129728, 7392, 36, 'زولویی'),
(129729, 7394, 36, ' قابل دسترسی نیست.'),
(129730, 7395, 36, 'آیا واقعا می خواهید را حذف کنید'),
(129731, 7396, 36, 'دارو'),
(129732, 7397, 36, 'ایمیل ها فرستاده نشدند'),
(129733, 7398, 36, 'از'),
(129734, 7399, 36, 'ایجاد شده است. '),
(129735, 7400, 36, 'دوباره باز شده است.'),
(129736, 7401, 36, 'تاریخچه'),
(129737, 7402, 36, 'یک عدد نیست'),
(129738, 7403, 36, 'آماده برای صدور صورت حساب مجدد است.'),
(129739, 7408, 36, 'یافت نشد!'),
(129740, 7411, 36, 'تا'),
(129741, 7412, 36, 'به روز رسانی نا موفق بود، در پایگاه داده ها نیست؟'),
(129742, 7415, 36, '! انصراف از ویزیت'),
(129743, 7417, 36, '" در تنظیمات ارسال تقویم علامت زده شده!'),
(129744, 7418, 36, '# مسائل بیمه/مالی'),
(129745, 7419, 36, 'تعداد قرص ها:'),
(129746, 7421, 36, '$ کدگذاری انجام شد'),
(129747, 7424, 36, '٪ لغو >۲۴ ساعت قبل از ملاقات'),
(129748, 7425, 36, '٪ لغو >۲۴ ساعت قبل از ملاقات '),
(129749, 7428, 36, '(برای انتخاب چندین گیرنده [CTRL] + کلیک کنید)'),
(129750, 7429, 36, '(بازگشت)'),
(129751, 7430, 36, '(برای ویرایش کلیک کنید.)'),
(129752, 7432, 36, '(بیشتر)'),
(129753, 7433, 36, '(بیمار جدید)'),
(129754, 7434, 36, '(یادداشت ها و مجوزها)'),
(129755, 7435, 36, '(یادداشت های بیمار)'),
(129756, 7436, 36, '(یکی از اینها را انتخاب، یا عنوان خودتان را تایپ کنید)'),
(129757, 7438, 36, '* یادآوری شد'),
(129758, 7439, 36, '** لطفا جراحی ها را به مسائل تبدیل کنید!'),
(129759, 7440, 36, '* ضروری'),
(129760, 7441, 36, '+ پرونده آورده شد'),
(129761, 7442, 36, '- هیچ'),
(129762, 7445, 36, '.'),
(129763, 7446, 36, '0'),
(129764, 7447, 36, '۰-۱۰'),
(129765, 7448, 36, '۰-۲۴'),
(129766, 7451, 36, '1'),
(129767, 7453, 36, '۱ روز دیگر'),
(129768, 7454, 36, '۱ ماه دیگر'),
(129769, 7455, 36, '۱ هفته دیگر'),
(129770, 7456, 36, '۱ سال دیگر'),
(129771, 7458, 36, '۱۱-۱۴'),
(129772, 7459, 36, '۱۲ ساعت'),
(129773, 7460, 36, '۱۵-۱۹'),
(129774, 7462, 36, '2'),
(129775, 7463, 36, '۲ روز دیگر'),
(129776, 7464, 36, '۲ ماه دیگر'),
(129777, 7465, 36, '۲ هفته دیگر'),
(129778, 7466, 36, '۲ سال دیگر'),
(129779, 7468, 36, '۲۰-۲۴'),
(129780, 7477, 36, '۲۱۱۱-۱۳'),
(129781, 7479, 36, '۲۵+'),
(129782, 7480, 36, '۲۵-۲۹'),
(129783, 7482, 36, '۳ روز دیگر'),
(129784, 7483, 36, '۳ ماه'),
(129785, 7484, 36, '۳ ماه دیگر'),
(129786, 7485, 36, '۳ بار در روز'),
(129787, 7486, 36, '۳ هفته دیگر'),
(129788, 7487, 36, '۳۰-۳۴'),
(129789, 7488, 36, '۳۵-۳۹'),
(129790, 7490, 36, '۴ روز دیگر'),
(129791, 7491, 36, '۴ ماه'),
(129792, 7492, 36, '۴ ماه دیگر'),
(129793, 7493, 36, '۴ بار در روز'),
(129794, 7494, 36, '۴ هفته دیگر'),
(129795, 7495, 36, '۴۰-۴۴'),
(129796, 7496, 36, '۴۵+'),
(129797, 7505, 36, '۵ روز دیگر'),
(129798, 7506, 36, '۵ ماه دیگر'),
(129799, 7507, 36, '۵ هفته دیگر'),
(129800, 7510, 36, '۶ روز دیگر'),
(129801, 7511, 36, '۶ ماه'),
(129802, 7512, 36, '۶ ماه دیگر'),
(129803, 7513, 36, '۶ هفته دیگر'),
(129804, 7515, 36, '۷ ماه دیگر'),
(129805, 7516, 36, '۸ ماه دیگر'),
(129806, 7525, 36, '۹ ماه دیگر'),
(129807, 7528, 36, '< در اتاق معاینه'),
(129808, 7529, 36, '> مرخص شد'),
(129809, 7531, 36, '? غیبت'),
(129810, 7532, 36, '@ مراجعه کرد'),
(129811, 7533, 36, '[تغییر نمایش]'),
(129812, 7538, 36, '[توصیه نمی شود]'),
(129813, 7540, 36, '[گزارش ها]'),
(129814, 7541, 36, '[انتخاب همه]'),
(129815, 7544, 36, '[نمایش صورت عملیات]'),
(129816, 7545, 36, '[نمایش گزارش چاپی]'),
(129817, 7549, 36, '~ تأخیر'),
(129818, 1, 37, 'A'),
(129819, 2, 37, 'Reikalingas sąskaitos ar paraiškos numeris identifikuojant apmokėjimą'),
(129820, 3, 37, 'Kliento sertifikatas skirtas sistemos administratoriui'),
(129821, 4, 37, 'Klinikinis dokumentas pridėtas.'),
(129822, 5, 37, 'Klinikinis dokumentas pridėtas.'),
(129823, 7, 37, 'Platintojas privalomas'),
(129824, 8, 37, 'Prie šio vizito reikalinga pridėti GCAC formą'),
(129825, 9, 37, 'Reikalingas partijos numeris'),
(129826, 10, 37, 'Reikalingas partijos numeris!'),
(129827, 11, 37, 'Apatinio registro raidė'),
(129828, 12, 37, 'Skaičius'),
(129829, 14, 37, 'Pacientas su tokiu asmens kodu jau yra'),
(129830, 15, 37, 'Pacientas su tokiu vardu jau yra'),
(129831, 16, 37, 'Pacientas su tokiu socialinio draudimo numeriu jau yra'),
(129832, 21, 37, 'Specialus simbolis'),
(129833, 23, 37, 'Toks vizitas jau yra sukurtas šiam pacientui. Paspauskite "Atšaukti", kad tęsti, arba "Gerai", kad sukurti naują vizitą'),
(129834, 29, 37, 'Abscesas:'),
(129835, 34, 37, 'Nukrypimas nuo normos'),
(129836, 35, 37, 'Patologiniai kraujo tyrimų rezultatai'),
(129837, 36, 37, 'Patologinis plaukų augimas'),
(129838, 37, 37, 'Patologinė mamograma'),
(129839, 39, 37, 'Abortas'),
(129840, 40, 37, 'Aborto problemos'),
(129841, 41, 37, 'Nėštumo nutraukimo metodas'),
(129842, 42, 37, 'Abortas - susijusios kategorijos'),
(129843, 43, 37, 'Abortai'),
(129844, 44, 37, 'Apie kalendorių'),
(129845, 46, 37, 'Neatvykimai, suskirstyti pagal diagnozę'),
(129846, 47, 37, 'Priimti paskyrimą'),
(129847, 48, 37, 'Priimti mokėjimą už'),
(129848, 49, 37, 'Priimti mokėjimą už'),
(129849, 50, 37, 'Priimti paskyrimą'),
(129850, 52, 37, 'Prieigos kontrolės sąrašo administravimas'),
(129851, 53, 37, 'Prieigos data'),
(129852, 54, 37, 'Prieiga neleidžiama'),
(129853, 55, 37, 'Prieiga nepatvirtinta'),
(129854, 56, 37, 'Prisijungti prie savo pacientų portalo'),
(129855, 59, 37, 'Paskyros pavadinimas'),
(129856, 91, 37, 'Lėtinės ligos ūminė apraiška'),
(129857, 128, 37, 'Nauja kategorija: '),
(129858, 130, 37, 'Naujas komponentas'),
(129859, 131, 37, 'NAuji komponentai'),
(129860, 132, 37, 'Nauja grupė'),
(129861, 138, 37, 'Naujas pacientas'),
(129862, 140, 37, 'Naujas paciento įrašas'),
(129863, 146, 37, 'Nauja taisyklė'),
(129864, 151, 37, 'Naujas vartotojas'),
(129865, 159, 37, 'Adisono sindromas'),
(129866, 164, 37, 'Papildoma informacija'),
(129867, 175, 37, 'Adresas'),
(129868, 199, 37, 'Administratorius'),
(129869, 200, 37, 'Administratoriaus elektroninis paštas'),
(129870, 208, 37, 'Administratoriai'),
(129871, 234, 37, 'Amžius'),
(129872, 250, 37, 'Alkoholis'),
(129873, 251, 37, 'Alkoholio suvartojimas'),
(129874, 252, 37, 'Alkoholio vartojimas'),
(129875, 1, 39, '一つの'),
(129876, 2, 39, '支払を識別するための小切手番号もしくは請求番号'),
(129877, 3, 39, '管理者のためのクライアント証明'),
(129878, 4, 39, '医療文書が添付されます。'),
(129879, 5, 39, '医療文書が添付されます。'),
(129880, 7, 39, 'ディストリビューターが必要です。'),
(129881, 8, 39, 'GCAC訪問フォームは今回の訪問で追加されました'),
(129882, 9, 39, 'ロット番号が必要です'),
(129883, 10, 39, 'ロット番号が必要です！'),
(129884, 11, 39, '小文字で入力'),
(129885, 12, 39, '数量'),
(129886, 14, 39, 'このＩＤの患者は既に存在します。'),
(129887, 15, 39, 'この名前の患者は既に存在します。'),
(129888, 16, 39, 'このSSの患者は既に存在します。'),
(129889, 17, 39, '正の数は、（負の数が降順に過去の予定が表示されます）患者概要]画面にウィジェット上でその多くの過去の予定が表示されます'),
(129890, 18, 39, '正の数は、患者の概要]画面にウィジェット上でその多くの過去の予定が表示されます。'),
(129891, 19, 39, '照会元は、各訪問のために指定されてもよい。'),
(129892, 20, 39, '関連するIPPFコードが必要です'),
(129893, 21, 39, '特殊文字'),
(129894, 22, 39, 'ユニークな値は、ユーザーには見えないこのフィールドを識別するために'),
(129895, 23, 39, '訪問は、すでに今日この患者のために存在しています。新しいものを作成することを続行するためにそれを開くために、キャンセル、または[OK]をクリックします。'),
(129896, 24, 39, 'a.c.'),
(129897, 25, 39, '午前'),
(129898, 26, 39, 'A/F Level Right:'),
(129899, 27, 39, 'AB'),
(129900, 28, 39, '略語'),
(129901, 29, 39, '膿瘍：'),
(129902, 30, 39, '腹部'),
(129903, 31, 39, '：重量を4（4）の手順に耐え'),
(129904, 32, 39, 'ABN'),
(129905, 33, 39, 'ABN1'),
(129906, 34, 39, '異常な'),
(129907, 35, 39, '異常な血液検査'),
(129908, 36, 39, '異常な髪の成長'),
(129909, 37, 39, '異常マンモグラム'),
(129910, 39, 39, '中絶'),
(129911, 40, 39, '妊娠中絶の問題'),
(129912, 41, 39, '妊娠中絶の方法'),
(129913, 42, 39, '妊娠中絶-関連カテゴリ'),
(129914, 43, 39, '中絶'),
(129915, 44, 39, 'カレンダーについて'),
(129916, 46, 39, '診断で欠席'),
(129917, 47, 39, '割り当てを受け入れる'),
(129918, 48, 39, 'のための支払いを受け入れる'),
(129919, 49, 39, 'のための支払いを受け入れる'),
(129920, 50, 39, '割り当てを受け入れ'),
(129921, 51, 39, 'アクセス制御'),
(129922, 52, 39, 'アクセス制御リストの管理'),
(129923, 53, 39, 'アクセス日'),
(129924, 54, 39, 'アクセスは許可されていません'),
(129925, 55, 39, 'アクセスは認証されていません'),
(129926, 56, 39, '患者ポータルへアクセス'),
(129927, 57, 39, '事故'),
(129928, 59, 39, 'アカウント名'),
(129929, 62, 39, 'アカウント管理'),
(129930, 64, 39, '痛み'),
(129931, 65, 39, '謝辞要求（ISA14）'),
(129932, 66, 39, '謝辞、ライセンスと認証'),
(129933, 67, 39, 'アクセス制限（ACL）'),
(129934, 68, 39, 'アクセス管理（ACL）'),
(129935, 69, 39, 'アクセス管理（ACL）は認証されていません'),
(129936, 70, 39, 'ACLが更新されました'),
(129937, 71, 39, 'にきび'),
(129938, 72, 39, '行為'),
(129939, 73, 39, '法律日'),
(129940, 74, 39, 'アクション'),
(129941, 75, 39, 'アクション'),
(129942, 77, 39, 'CCR / CCDレポートをアクティブに'),
(129943, 78, 39, '有効'),
(129944, 79, 39, '有効なアラート'),
(129945, 80, 39, '有効なアラートルール'),
(129946, 81, 39, '有効なアラート/予告'),
(129947, 82, 39, '有効な来院者'),
(129948, 84, 39, '有効なリスト'),
(129949, 85, 39, '有効な患者'),
(129950, 86, 39, '有効なプラン'),
(129951, 87, 39, 'アクティビティ'),
(129952, 88, 39, 'アクティビティタイプ'),
(129953, 90, 39, '急性中毒/退会'),
(129954, 91, 39, '慢性疾患の急性顕現'),
(129955, 92, 39, '慢性に急性'),
(129956, 93, 39, '追加'),
(129957, 94, 39, '追加'),
(129958, 95, 39, '追加'),
(129959, 96, 39, '会社を追加'),
(129960, 98, 39, '薬局を追加'),
(129961, 100, 39, 'イベントを追加 '),
(129962, 101, 39, '新規ノートの追加'),
(129963, 102, 39, '新規追加'),
(129964, 104, 39, 'ボタン追加'),
(129965, 105, 39, '特殊文字用のボタンを追加し、テキストはをクリックして上のテキストに含めるためのエディタの上部に表示する'),
(129966, 106, 39, 'カテゴリ追加'),
(129967, 107, 39, '定数追加'),
(129968, 108, 39, 'コンテキスト追加'),
(129969, 109, 39, 'Copayを追加'),
(129970, 110, 39, '抽出の追加'),
(129971, 111, 39, 'カスタムボタン追加'),
(129972, 112, 39, '診断を追加'),
(129973, 113, 39, '薬の追加'),
(129974, 114, 39, '来院者の追加'),
(129975, 115, 39, '来院者・ノートの追加'),
(129976, 116, 39, '施術院の追加'),
(129977, 117, 39, 'フィールドの追加'),
(129978, 118, 39, 'Apache 設定への要点を追加'),
(129979, 119, 39, 'グループの追加'),
(129980, 120, 39, 'ICDコードの追加'),
(129981, 121, 39, '免疫を追加'),
(129982, 122, 39, '追加は許可されていません！'),
(129983, 123, 39, '問題の追加'),
(129984, 124, 39, '追跡するためにアイテムを追加します。'),
(129985, 125, 39, '言語の追加'),
(129986, 126, 39, '新規追加'),
(129987, 127, 39, '新規追加'),
(129988, 128, 39, '新規カテゴリの追加 '),
(129989, 129, 39, 'Apache 設定へ新規認証局を追加'),
(129990, 130, 39, '新規コンポーネント追加'),
(129991, 131, 39, '新規コンポーネント追加'),
(129992, 132, 39, '新規グループ追加'),
(129993, 133, 39, '新規問題を追加'),
(129994, 134, 39, '新規ロット及び課金の追加'),
(129995, 135, 39, '新規ノート追加'),
(129996, 136, 39, '新規ノート追加'),
(129997, 137, 39, '新規パートナーの追加'),
(129998, 138, 39, '新規患者の追加'),
(129999, 140, 39, 'ノート追加'),
(130000, 141, 39, '患者レコードの追加'),
(130001, 142, 39, '処方箋を追加'),
(130002, 143, 39, '手順を追加'),
(130003, 144, 39, '提供者番号を追加します。'),
(130004, 145, 39, 'リハビリを追加'),
(130005, 146, 39, 'ルール追加'),
(130006, 147, 39, '追加'),
(130007, 148, 39, '薬リストの追加'),
(130008, 149, 39, 'トップレベル追加'),
(130009, 150, 39, '課金決裁追加'),
(130010, 151, 39, 'ユーザー追加'),
(130011, 152, 39, 'グループへユーザー追加'),
(130012, 153, 39, '追加/編集ERX'),
(130013, 154, 39, '決済の追加/編集'),
(130014, 155, 39, '追加済み'),
(130015, 156, 39, '基本データの追加は認証されていません'),
(130016, 157, 39, 'アイテムのトラック追加に失敗'),
(130017, 158, 39, 'アディソン症候群'),
(130018, 159, 39, 'アディソン症候群'),
(130019, 160, 39, '追加属性'),
(130020, 161, 39, '追加の診断：'),
(130021, 162, 39, '履歴の追加'),
(130022, 163, 39, '履歴ノートの追加'),
(130023, 164, 39, '情報の追加'),
(130024, 165, 39, 'ラボの追加'),
(130025, 166, 39, 'ノートの追加'),
(130026, 167, 39, '該当結果または該当についての追加'),
(130027, 168, 39, 'ノートの追加'),
(130028, 169, 39, 'ノートの追加 '),
(130029, 170, 39, 'レントゲンノートの追加'),
(130030, 171, 39, 'さらに、対応する米国SNOMED拡張パッケージにはインターナショナル（英語版）をインストールした後、別々にインポートすることができますSNOMEDリリース'),
(130031, 172, 39, 'addonly'),
(130032, 173, 39, '住所録'),
(130033, 174, 39, '住所録'),
(130034, 175, 39, '住所録'),
(130035, 178, 39, '住所録'),
(130036, 179, 39, 'この手順を実行する会社のアドレス帳のエントリ'),
(130037, 180, 39, 'ディストリビューターのためのアドレス帳のエントリ'),
(130038, 181, 39, 'ベンダーのためのアドレス帳のエントリ'),
(130039, 182, 39, '住所録タイプ'),
(130040, 183, 39, '住所ラベル'),
(130041, 187, 39, '住所１'),
(130042, 188, 39, '住所２'),
(130043, 189, 39, '宛先'),
(130044, 190, 39, '調整'),
(130045, 191, 39, '金額調整'),
(130046, 192, 39, '調整'),
(130047, 193, 39, '調整'),
(130048, 194, 39, '調整AMTの'),
(130049, 195, 39, '調整理由'),
(130050, 196, 39, 'コー​​ドの調整値 '),
(130051, 197, 39, '調整'),
(130052, 198, 39, 'アドリアマイシン調整'),
(130053, 199, 39, '管理者'),
(130054, 200, 39, '管理者のメールアドレス'),
(130055, 201, 39, '管理者宛'),
(130056, 202, 39, '管理者'),
(130057, 203, 39, '管理者'),
(130058, 204, 39, '管理日'),
(130059, 205, 39, '管理者のウェブサイト'),
(130060, 206, 39, '管理者'),
(130061, 207, 39, '管理者のウェブサイト'),
(130062, 208, 39, '管理者'),
(130063, 209, 39, '管理可能な事由'),
(130064, 210, 39, '管理日'),
(130065, 212, 39, '大人の体重のスクリーニングおよびフォローアップ'),
(130066, 213, 39, '大人の体重は、スクリーニングおよびフォローアップ（CQM）'),
(130067, 214, 39, '事前指示'),
(130068, 215, 39, '事前指示'),
(130069, 216, 39, 'アドバンスディレクティブの警告'),
(130070, 218, 39, '高度な'),
(130071, 219, 39, 'アドバイス'),
(130072, 220, 39, '遠く'),
(130073, 221, 39, '正常な影響を与える'),
(130074, 222, 39, 'アフリカーンス語'),
(130075, 223, 39, '時間の通話の後'),
(130076, 224, 39, 'パスワードは、塩なしにusersテーブルに格納されている古いパスワードメカニズムからの移行が完了した後に新たな方式による認証のみが可能なように、このフラグをfalseに設定する必要があります'),
(130077, 225, 39, '上記の設定を行った後、ブラウザに管理クライアント証明書をインポートし、Apacheサーバ（空のパスワード）を再起動します。'),
(130078, 226, 39, 'PDFファイルを保存した後、エラーをチェックし、[ログの表示]をクリックします。'),
(130079, 227, 39, 'テキストフ​​ァイル（複数可）を保存した後、エラーをチェックするために、[ログの表示]をクリックします。'),
(130080, 228, 39, 'あなたのバッチを保存した後、エラーをチェックするために、[ログの表示]をクリックします。'),
(130081, 229, 39, 'その後一致列を作成するために選択された患者ID、または0が表示されます。'),
(130082, 230, 39, '情報が正しく入力された後、[保存]ボタンをクリックします。'),
(130083, 231, 39, 'ボタンをクリックしてアップロードした後「インポート」'),
(130084, 232, 39, 'アフターケアプランニング'),
(130085, 233, 39, '再び'),
(130086, 234, 39, '年齢'),
(130087, 235, 39, '年齢'),
(130088, 236, 39, '年齢層'),
(130089, 237, 39, '年齢データが範囲外です'),
(130090, 238, 39, '年齢表示形式'),
(130091, 239, 39, '年齢表示型が異常です'),
(130092, 240, 39, '年齢上限が異常です'),
(130093, 241, 39, '下限の年齢'),
(130094, 242, 39, '年齢表示形式の変更'),
(130095, 243, 39, '年齢最大値'),
(130096, 244, 39, '年齢最小値'),
(130097, 245, 39, '年齢範囲'),
(130098, 247, 39, 'エージング列：'),
(130099, 248, 39, 'アカン語'),
(130100, 249, 39, 'アルバニア語'),
(130101, 250, 39, 'アルコール'),
(130102, 251, 39, 'アルコールの消費'),
(130103, 252, 39, '飲酒歴'),
(130104, 253, 39, 'アラート回数'),
(130105, 255, 39, 'アラート'),
(130106, 258, 39, 'アレウト族'),
(130107, 259, 39, '全て'),
(130108, 260, 39, '全て'),
(130109, 261, 39, 'すべて（丁合いのフォーマットA）'),
(130110, 262, 39, 'すべて（丁合いフォーマットB）'),
(130111, 263, 39, 'すべて（累計）'),
(130112, 265, 39, 'すべての自動メジャー計算（AMC）'),
(130113, 266, 39, 'すべてのカテゴリ'),
(130114, 267, 39, 'すべての臨床品質尺度（CQM）'),
(130115, 268, 39, 'すべてのコード'),
(130116, 269, 39, '終日'),
(130117, 270, 39, '終日イベント'),
(130118, 271, 39, '検索と重複チェックを持つすべての人口統計フィールド、'),
(130119, 272, 39, '全ての施設'),
(130120, 273, 39, 'すべての負傷/問題/課題'),
(130121, 274, 39, '全ての言語を許可'),
(130122, 275, 39, 'すべての公式臨床品質尺度（CQM）メジャーグループ'),
(130123, 276, 39, '最初の名前のすべてまたは一部'),
(130124, 277, 39, '姓の全部または一部'),
(130125, 278, 39, '組織のすべてまたは一部'),
(130126, 279, 39, '全ての患者'),
(130127, 280, 39, '全てのプロダクト'),
(130128, 281, 39, '全てのプロバイダー'),
(130129, 282, 39, '全ての参照者及び陰性'),
(130130, 283, 39, '全てのトピック'),
(130131, 284, 39, '全てのユーザー'),
(130132, 285, 39, 'アレルギー疾患'),
(130133, 286, 39, 'アレルギー'),
(130134, 287, 39, 'アレルギー'),
(130135, 288, 39, 'アレルギー'),
(130136, 289, 39, 'アレルギーのインポートは正常に行われました'),
(130137, 290, 39, 'アレルギー問題リスト'),
(130138, 291, 39, 'アレルギー反応'),
(130139, 294, 39, '割り当て'),
(130140, 295, 39, '許可'),
(130141, 296, 39, 'メニューの選択肢として使用可能なすべての言語は、ログイン時に許可します。'),
(130142, 297, 39, 'の診断ではなく、手順や料金を含む特許請求の範囲の作成を許可します。ほとんどのクリニックはこれをしたくない。'),
(130143, 298, 39, '許可するデバッグ言語'),
(130144, 299, 39, '許可されたメールアドレス'),
(130145, 300, 39, 'メール送信を許可しますか？'),
(130146, 301, 39, 'メールを許可しますか？'),
(130147, 302, 39, '出会い請求を許可'),
(130148, 303, 39, '医療情報交換を可能にする'),
(130149, 304, 39, '許可免疫情報の共有'),
(130150, 305, 39, '免疫レジストリ使用を許可'),
(130151, 306, 39, 'メールメッセージを許可する'),
(130152, 308, 39, '患者のポータルを許可する'),
(130153, 309, 39, 'SMS許可'),
(130154, 310, 39, 'SMS（テキスト送信）の許可？'),
(130155, 311, 39, '追加したイベントを直ちに有効にしますか？'),
(130156, 312, 39, '留守電を許可しますか？'),
(130157, 313, 39, 'ユーザーがグローバルイベントを公開できるように'),
(130158, 314, 39, 'ユーザーが個人的なカレンダーを公開できるように'),
(130159, 315, 39, '留守電を許可'),
(130160, 316, 39, '許可済み'),
(130161, 317, 39, '許可された言語'),
(130162, 318, 39, '許可'),
(130163, 319, 39, '通院者に電子サインを許可'),
(130164, 320, 39, 'E-署名個々のフォームを許可します'),
(130165, 321, 39, 'メールの許可'),
(130166, 322, 39, '留守電の許可'),
(130167, 323, 39, '既に存在しています'),
(130168, 324, 39, '既に存在しています'),
(130169, 325, 39, '利用済みです。別の識別子を選択してください'),
(130170, 326, 39, '利用済みです。別のタイトルを選択してください'),
(130171, 327, 39, '別の住所'),
(130172, 328, 39, '変更する'),
(130173, 329, 39, '別の方法として、あなたはあなたの支払またはクリアリングハウスから入手した電子送金（X12 835）ファイルをアップロードする検索ページを使用することができます。 [参照]ボタンをクリックし、アップロードするファイルを選択してから、アップロードを実行すると、対応する請求書を表示するには検索をクリックすることでこれを行うことができます。この場合は、上記の他のパラメータが適用されず、無視されます。アップロードは、ファイルが保存されますが、まだその内容は処理されません - 下記のように別々に行われている。'),
(130174, 330, 39, 'AM'),
(130175, 331, 39, 'AMプログラム'),
(130176, 332, 39, 'AMC'),
(130177, 333, 39, 'AMCの追跡'),
(130178, 334, 39, 'AMC-2011'),
(130179, 335, 39, 'AMC-2014'),
(130180, 338, 39, '既存のノートを改正'),
(130181, 339, 39, 'から改正'),
(130182, 340, 39, '改正ステータス'),
(130183, 341, 39, '改正'),
(130184, 342, 39, 'のための改正'),
(130185, 343, 39, 'アメリカ先住民'),
(130186, 344, 39, 'アメリカインディアンまたはアラスカ先住民'),
(130187, 345, 39, 'AMEX'),
(130188, 346, 39, 'アムハラ語'),
(130189, 347, 39, '小計'),
(130190, 348, 39, 'の投与量'),
(130191, 349, 39, '請求額'),
(130192, 350, 39, '過去の残高の金額'),
(130193, 351, 39, '今回の小計'),
(130194, 352, 39, '支払額'),
(130195, 353, 39, '小計'),
(130196, 354, 39, 'AMT請求された'),
(130197, 355, 39, '開始日よりも後の終了日は、繰り返しイベントのために必要です！'),
(130198, 356, 39, 'エラーがフォームに署名が発生しました'),
(130199, 357, 39, 'LibreEHRウェブディレクトリツリーをダンプ中にエラーが発生しました'),
(130200, 358, 39, 'phpGACLウェブディレクトリツリーをダンプ中にエラーが発生しました'),
(130201, 359, 39, 'SQL-元帳のWebディレクトリツリーをダンプ中にエラーが発生しました'),
(130202, 360, 39, '不完全GCAC問題が作成され、リンクされている。誰かが後でそれを完了する必要があります。'),
(130203, 362, 39, '予期しないエラーが発生しました。'),
(130204, 363, 39, '大文字'),
(130205, 367, 39, 'と'),
(130206, 368, 39, 'と '),
(130207, 369, 39, 'とすべての下位データ？このアクションは記録されます'),
(130208, 370, 39, 'と修飾子'),
(130209, 371, 39, 'および処理さ。'),
(130210, 372, 39, '及び Apache サーバーの再起動'),
(130211, 373, 39, 'そしてその理由は、'),
(130212, 374, 39, '貧血'),
(130213, 375, 39, '足首'),
(130214, 376, 39, '足首+ヒール'),
(130215, 377, 39, '足首評価書式'),
(130216, 378, 39, '足首の問題'),
(130217, 379, 39, '強直性Sondlilitis'),
(130218, 380, 39, '強直性Spondlilitis'),
(130219, 381, 39, '食欲不振'),
(130220, 382, 39, '転記]ウィンドウで行うことができますもう一つは、二次の課金を要求している。あなたが保存する前にこのチェックボックスを選択した場合は、元の主張は再オープンし、課金ページにキューイングされ、そして次の請求の実行中に処理されますされます。'),
(130221, 383, 39, 'アンティ'),
(130222, 384, 39, '肛門のNL、無直腸優しさ/質量'),
(130223, 385, 39, '不安'),
(130224, 387, 39, 'カテゴリー'),
(130225, 388, 39, '目的のコードまたはその説明のいずれかの部分'),
(130226, 389, 39, '希望する専門のいずれかの部分'),
(130227, 390, 39, '薬物idまたは薬剤名のいずれかの部分'),
(130228, 391, 39, '免疫IDまたは免疫名のいずれかの部分'),
(130229, 392, 39, '患者名の任意の部分、または「最後、最初の "、または「XY "'),
(130230, 393, 39, 'Anyother関連情報'),
(130231, 394, 39, 'SMSゲートウェイのAPI鍵'),
(130232, 395, 39, '無呼吸'),
(130233, 396, 39, '外観'),
(130234, 397, 39, '外観'),
(130235, 398, 39, 'このノートの追加'),
(130236, 399, 39, '既存ノートへの追加'),
(130237, 400, 39, 'このノートの追加'),
(130238, 401, 39, 'このノートの追加'),
(130239, 402, 39, '虫垂切除術'),
(130240, 403, 39, '虫垂切除術'),
(130241, 404, 39, '該当患者'),
(130242, 405, 39, 'アプリケーション'),
(130243, 406, 39, 'ログインページとメインウィンドウタイトルのアプリケーション名。'),
(130244, 407, 39, 'アプリケーションレシーバーコード（GS03 - 空白ISA08を使用する場合）'),
(130245, 408, 39, 'アプリケーション送信者コード（GS02）'),
(130246, 409, 39, 'アプリケーション名'),
(130247, 410, 39, 'バイタルフォームと成長チャートに適用されます'),
(130248, 411, 39, 'バイタルフォームに適用されます'),
(130249, 412, 39, '唯一、これとすべての将来の発生に、またはすべての出現に現在のイベントへの変更を適用しますか？'),
(130250, 413, 39, '患部に適用されます'),
(130251, 414, 39, '皮膚に適用されます'),
(130252, 415, 39, '適用'),
(130253, 416, 39, 'サイトへのパッチの適用'),
(130254, 417, 39, '任命'),
(130255, 418, 39, '予約日'),
(130256, 419, 39, 'アポイントの表示スタイル'),
(130257, 420, 39, '予定のリマインダールール'),
(130258, 421, 39, '予定の状況'),
(130259, 422, 39, '予定のステータス'),
(130260, 423, 39, '内の選任'),
(130261, 424, 39, '選任/イベントの色'),
(130262, 425, 39, '予定'),
(130263, 426, 39, '予定（オプション書き込み）'),
(130264, 427, 39, '予定（書き込み、オプショナルwsome）'),
(130265, 430, 39, '予定との出会い'),
(130266, 431, 39, '予定レポート'),
(130267, 432, 39, '予定-出会いレポート'),
(130268, 434, 39, '承認する'),
(130269, 435, 39, '患者/クライアント - >インポート - >承認待ちから患者を承認'),
(130270, 436, 39, '到着'),
(130271, 438, 39, '正常に到着しました'),
(130272, 443, 39, '４月'),
(130273, 444, 39, 'アラビア人'),
(130274, 445, 39, 'アルゴン人'),
(130275, 446, 39, 'アーカイブ'),
(130276, 447, 39, 'アクセスコントロールグループ名は翻訳されましたか？'),
(130277, 448, 39, '予約カテゴリー名は翻訳されましたか？'),
(130278, 450, 39, 'このタイプの課金は済みましたか？'),
(130279, 451, 39, '患者のノートタイトルは翻訳されましたか？'),
(130280, 454, 39, '本日の投函でよろしいですか？'),
(130281, 455, 39, 'これらのイベントは完了しましたか？'),
(130282, 457, 39, 'このフォームから完全に削除しても良いですか？'),
(130283, 458, 39, '本当に削除しますか？'),
(130284, 460, 39, 'このイベントを本当に削除しますか？'),
(130285, 461, 39, 'このアイテムをデータベースから本当に削除しますか？'),
(130286, 462, 39, 'このノートを本当に削除しますか？'),
(130287, 464, 39, 'これらのイベントを編集してもよろしいですか？'),
(130288, 465, 39, 'これらのイベントを非表示設定しますか？'),
(130289, 466, 39, '再度送信しますか？'),
(130290, 467, 39, 'イベントを再度閲覧しますか？'),
(130291, 474, 39, '腕'),
(130292, 475, 39, 'アルメニア人'),
(130293, 477, 39, '不整脈'),
(130294, 478, 39, '関節炎'),
(130295, 484, 39, 'アジア人'),
(130296, 485, 39, 'アッサム語'),
(130297, 487, 39, '評価'),
(130298, 488, 39, '指定先'),
(130299, 489, 39, '介助'),
(130300, 490, 39, '喘息'),
(130301, 495, 39, 'アスレチックチーム'),
(130302, 496, 39, 'アスレチックチーム'),
(130303, 497, 39, 'アスレチック/傷害'),
(130304, 503, 39, '注意'),
(130305, 516, 39, '８月'),
(130306, 517, 39, '８月'),
(130307, 519, 39, '認証'),
(130308, 520, 39, '認証/ノート'),
(130309, 523, 39, '権限グループ'),
(130310, 524, 39, '認証ステータス'),
(130311, 525, 39, '権限'),
(130312, 526, 39, '認証'),
(130313, 527, 39, '認証ー来院者'),
(130314, 528, 39, '認証ー来院者'),
(130315, 529, 39, 'Authorize.net'),
(130316, 530, 39, '認証済み'),
(130317, 531, 39, '認証済みのみ'),
(130318, 532, 39, '自動送信'),
(130319, 535, 39, '来院者自動作成'),
(130320, 536, 39, '自動生成されました'),
(130321, 544, 39, '自動的'),
(130322, 550, 39, '自動保存'),
(130323, 551, 39, '利用可能なカテゴリ'),
(130324, 552, 39, '利用可能な時間帯'),
(130325, 553, 39, '利用可能なトラック'),
(130326, 554, 39, 'アヴァル語'),
(130327, 556, 39, 'アヴェスター語'),
(130328, 557, 39, '月平均'),
(130329, 562, 39, '腋窩'),
(130330, 563, 39, 'アイマラ語'),
(130331, 564, 39, 'アゼルバイジャン人'),
(130332, 566, 39, '戻る'),
(130333, 567, 39, '戻る'),
(130334, 568, 39, '８度前に戻る'),
(130335, 569, 39, '11度前に戻る'),
(130336, 570, 39, '5度前に戻る'),
(130337, 571, 39, '4度前に戻る'),
(130338, 572, 39, '9度前に戻る'),
(130339, 573, 39, '初回に戻る'),
(130340, 574, 39, '病状'),
(130341, 575, 39, '問題'),
(130342, 576, 39, '7度前に戻る'),
(130343, 577, 39, '6度前に戻る'),
(130344, 578, 39, '外科に戻る'),
(130345, 579, 39, '10度前に戻る'),
(130346, 580, 39, '3度前に戻る'),
(130347, 581, 39, '管理画面へ戻る'),
(130348, 582, 39, '来院者画面へ戻る'),
(130349, 583, 39, '患者画面へ戻る'),
(130350, 584, 39, '患者画面へ戻る'),
(130351, 585, 39, 'ユーザーへ戻る'),
(130352, 586, 39, 'ビューへ戻る'),
(130353, 587, 39, '12度前に戻る'),
(130354, 588, 39, '２度前に戻る'),
(130355, 589, 39, 'バックグラウンドサービス'),
(130356, 590, 39, 'バックアップ'),
(130357, 591, 39, 'バックアップが作成されました。引き続きダウンロードします'),
(130358, 592, 39, 'バックアップリスト'),
(130359, 597, 39, '対価'),
(130360, 598, 39, '対価'),
(130361, 599, 39, '対価'),
(130362, 600, 39, '対価'),
(130363, 601, 39, '対価期限'),
(130364, 604, 39, 'バーコードラベル'),
(130365, 605, 39, 'バーコードラベルタイプ'),
(130366, 609, 39, 'バシキール語'),
(130367, 611, 39, 'バッチ請求'),
(130368, 612, 39, 'バッチコミュニケーションツール'),
(130369, 613, 39, 'バッチ支払エントリ'),
(130370, 615, 39, 'バッチ処理を開始しました。しばらく時間がかかる場合があります。'),
(130371, 616, 39, 'バッチ結果'),
(130372, 619, 39, '従ってこのIDはありません'),
(130373, 620, 39, '開始日'),
(130374, 621, 39, '開始日'),
(130375, 623, 39, 'サービス開始日 yyyy-mm-dd'),
(130376, 625, 39, 'ベラルーシ人'),
(130377, 628, 39, 'ベンガル人'),
(130378, 630, 39, '間'),
(130379, 632, 39, 'ビハール語'),
(130380, 636, 39, '支払日'),
(130381, 640, 39, '支払'),
(130382, 661, 39, '支払状況'),
(130383, 666, 39, '誕生日'),
(130384, 669, 39, '黒'),
(130385, 671, 39, '黒人またはアフリカ系アメリカ人'),
(130386, 674, 39, 'ブランクフォーム'),
(130387, 675, 39, '出血に関する異常'),
(130388, 676, 39, '不可視箇所'),
(130389, 678, 39, '制限済み'),
(130390, 679, 39, '血液'),
(130391, 680, 39, '血圧'),
(130392, 681, 39, '血圧'),
(130393, 682, 39, '鼻血'),
(130394, 686, 39, 'BMI'),
(130395, 687, 39, 'BMIステータス'),
(130396, 689, 39, '体部'),
(130397, 690, 39, '体側'),
(130398, 692, 39, '骨の圧痛：'),
(130399, 695, 39, 'ボスニア人'),
(130400, 697, 39, '両耳'),
(130401, 698, 39, '両耳'),
(130402, 700, 39, '下マージン（PX）'),
(130403, 719, 39, '血圧拡張期'),
(130404, 722, 39, 'ブラジル系ポルトガル人'),
(130405, 723, 39, '胸'),
(130406, 724, 39, '乳房生検'),
(130407, 730, 39, '呼吸音'),
(130408, 731, 39, 'ブルトン語'),
(130409, 732, 39, '骨折'),
(130410, 735, 39, '閲覧'),
(130411, 736, 39, '記録閲覧'),
(130412, 738, 39, 'ブルガリア人'),
(130413, 743, 39, '職場の電話番号'),
(130414, 748, 39, 'で'),
(130415, 749, 39, 'で'),
(130416, 750, 39, '口で'),
(130417, 752, 39, 'による:'),
(130418, 754, 39, 'RFC5425 TLS syslog サーバーの許諾済みCA認証局'),
(130419, 755, 39, 'キャッシュ有効時間 (秒指定)'),
(130420, 758, 39, 'カレンダー'),
(130421, 759, 39, 'カレンダー：閉店時間'),
(130422, 760, 39, 'カレンダー：定期'),
(130423, 761, 39, 'カレンダー画面'),
(130424, 762, 39, 'カレンダー設定'),
(130425, 763, 39, 'カレンダー：開業時間'),
(130426, 764, 39, 'カレンダーUI'),
(130427, 765, 39, 'カレンダー表示'),
(130428, 767, 39, 'カテゴリー'),
(130429, 768, 39, 'カンボジア人'),
(130431, 774, 39, '取り消し'),
(130432, 775, 39, '取り消し変更'),
(130433, 776, 39, 'キャンセル済み'),
(130434, 777, 39, '癌'),
(130435, 778, 39, 'がん検診：大腸がん検診'),
(130436, 779, 39, 'がん検診：マンモグラフィー'),
(130437, 780, 39, 'がん検診：子宮がん検診'),
(130438, 790, 39, '作成できません'),
(130439, 791, 39, 'ファイルを作成できません'),
(130440, 793, 39, 'ファイルを削除できません'),
(130441, 795, 39, '見つかりません '),
(130442, 796, 39, '指定ファイル名が見つかりません'),
(130443, 803, 39, '開けません '),
(130444, 807, 39, '読み出しできません'),
(130445, 808, 39, 'ディレクトリーが読めません'),
(130446, 810, 39, '大文字化'),
(130447, 811, 39, 'すべて大文字化'),
(130448, 812, 39, 'カプセル'),
(130449, 813, 39, 'カード'),
(130450, 814, 39, '心臓カテーテル'),
(130451, 815, 39, '心エコー'),
(130452, 816, 39, '心血管'),
(130453, 821, 39, '軟骨/軟骨/ディスク損傷'),
(130454, 822, 39, '軟骨損傷'),
(130455, 824, 39, '現金'),
(130456, 825, 39, '現金'),
(130457, 827, 39, '提供者によって現金受取'),
(130458, 828, 39, 'カタロニア語 - バレンシア'),
(130459, 829, 39, '白内障の手術'),
(130460, 830, 39, '白内障'),
(130461, 831, 39, 'カテゴリー'),
(130462, 832, 39, 'カテゴリー'),
(130463, 833, 39, 'カテゴリー'),
(130464, 834, 39, 'カテゴリー'),
(130465, 835, 39, 'カテゴリー '),
(130466, 836, 39, 'カテゴリー詳細'),
(130467, 837, 39, 'カテゴリー制限'),
(130468, 838, 39, 'カテゴリー名'),
(130469, 839, 39, 'カテゴリー名が空欄です'),
(130470, 840, 39, 'カテゴリー/タイトル'),
(130471, 841, 39, '白人'),
(130472, 842, 39, '出会い/一次提供情報を印刷するために領収書を引き起こす'),
(130473, 846, 39, 'CCRは承認'),
(130474, 847, 39, 'CCR患者レビュー'),
(130475, 848, 39, 'CCRレビューと承認'),
(130476, 850, 39, 'CDR'),
(130477, 851, 39, 'CDRは、処理優先を報告'),
(130478, 852, 39, '携帯電話'),
(130479, 853, 39, '携帯電話'),
(130480, 854, 39, '携帯電話番号'),
(130481, 855, 39, '携帯電話番号'),
(130482, 856, 39, '中央認証局'),
(130483, 857, 39, '中央南アメリカ人'),
(130484, 858, 39, 'CA認証 .crt ファイルの指定先が空欄ではありません'),
(130485, 859, 39, 'CA認証 .key ファイルの指定先が空欄ではありません'),
(130486, 860, 39, 'RFC 5425 TLS syslog サーバーへ認証許諾中'),
(130487, 861, 39, '認証されたユーザー'),
(130488, 862, 39, '認証局'),
(130489, 863, 39, 'チャモロ'),
(130490, 864, 39, 'ChampUS'),
(130491, 865, 39, 'ChampUSVA'),
(130492, 866, 39, '変更'),
(130493, 867, 39, '変更'),
(130494, 868, 39, 'アクティビティの変更'),
(130495, 869, 39, '変更に失敗しました！ CouchDBは、エラーを接続する？'),
(130496, 870, 39, 'ビジョンの変更'),
(130497, 871, 39, 'ビジョンの変化'),
(130498, 872, 39, 'パスワード変更'),
(130499, 874, 39, '変更済み'),
(130500, 875, 39, '変更された腸'),
(130501, 876, 39, 'ドキュメントの為の患者IDの変更'),
(130502, 877, 39, '特徴'),
(130503, 878, 39, '残りの文字'),
(130504, 879, 39, '変更'),
(130505, 880, 39, '調整'),
(130506, 881, 39, '充電コード化'),
(130507, 882, 39, '課金'),
(130508, 883, 39, 'チャート'),
(130509, 884, 39, 'チャート活動'),
(130510, 885, 39, 'チャートチェックイン/アウト活動報告'),
(130511, 886, 39, 'チャートID'),
(130512, 887, 39, 'チャートID:'),
(130513, 888, 39, 'チャートラベル'),
(130514, 889, 39, 'チャートの場所アクティビティ'),
(130515, 890, 39, 'チャートノート'),
(130516, 891, 39, 'チャート番号'),
(130517, 892, 39, 'チャート保存場所'),
(130518, 893, 39, 'チャートトラッカー'),
(130519, 894, 39, 'チャートトラック'),
(130520, 895, 39, 'チャートがチェックアウト'),
(130521, 896, 39, 'アウトチャート'),
(130522, 897, 39, 'チェチェン人'),
(130523, 898, 39, '確認'),
(130524, 899, 39, '確認'),
(130525, 900, 39, 'すべて確認'),
(130526, 902, 39, '小計額の確認'),
(130527, 903, 39, '日付確認'),
(130528, 904, 39, 'カスタム言語テーブルと翻訳の違いを確認してください。'),
(130529, 906, 39, 'にチェックイン'),
(130530, 907, 39, '入力日確認'),
(130531, 908, 39, 'グラフに項目を確認してください'),
(130532, 909, 39, '検査結果を確認してください'),
(130533, 910, 39, 'チェックマークが見直しを示している'),
(130534, 911, 39, '確認番号'),
(130535, 912, 39, '確認場の具'),
(130536, 915, 39, '支払額確認'),
(130537, 916, 39, 'これは暗号化されたファイルの場合はチェックボックスをオンにします'),
(130538, 917, 39, 'あなたはプロバイダがデフォルトとちょうど彼らの自身のないことで、すべての予定を表示したい場合は、これを確認してください。'),
(130539, 918, 39, 'この診断から問題を作成することを確認'),
(130540, 919, 39, '/ EOB日付を確認してください：'),
(130541, 920, 39, 'チェック/ EOB番号：'),
(130542, 921, 39, '/参照番号を確認してください'),
(130543, 922, 39, '/参照番号を確認してください'),
(130544, 923, 39, 'チェックボックスリスト'),
(130545, 924, 39, 'チェックボックスリスト'),
(130546, 925, 39, 'テキスト/ Wチェックボックス'),
(130547, 926, 39, 'テキスト/ Wチェックボックス'),
(130548, 927, 39, 'あなたが拒否し、HL7ファイルを削除する場合はチェックボックスは上記を示す。'),
(130549, 928, 39, 'チェック'),
(130550, 929, 39, 'チェックボックス=はい、空=なし'),
(130551, 931, 39, 'ロックチェックボックスをチェックすると、この出会いの任意のフォーム上の任意のfuther編集を防ぐことができます。'),
(130552, 932, 39, 'チェックアウト'),
(130553, 933, 39, 'チェックサム'),
(130554, 934, 39, '胸'),
(130555, 935, 39, 'チェストCTAB'),
(130556, 936, 39, '胸の痛み'),
(130557, 937, 39, '胸の痛み：'),
(130558, 938, 39, '胸の痛み'),
(130559, 940, 39, 'CHG');
INSERT INTO `lang_definitions` VALUES
(130560, 941, 39, 'Chichewa- Chewa-ニャンジャ語'),
(130561, 942, 39, '主訴'),
(130562, 943, 39, '子供'),
(130563, 945, 39, '小児期の予防接種ステータス（CQM）'),
(130564, 946, 39, '寒気'),
(130565, 947, 39, '中国人'),
(130566, 948, 39, '簡体字'),
(130567, 949, 39, '繁体字'),
(130568, 950, 39, 'カイロプラクティック'),
(130569, 951, 39, '選択肢'),
(130570, 952, 39, '胆嚢摘出術'),
(130571, 953, 39, '胆嚢摘出術'),
(130572, 954, 39, 'Cholecystestomy'),
(130573, 955, 39, '選択'),
(130574, 956, 39, 'セクションを選択して、その中の項目をクリックします。その後、他のセクションでは、関連する項目がハイライト表示さ​​れ、あなたが関係を追加および削除するために、そのセクションでクリックすることができます。'),
(130575, 957, 39, '抽出字句選択'),
(130576, 958, 39, 'ダウンロードを選択するか、インラインで表示'),
(130577, 959, 39, 'ファイル選択'),
(130578, 960, 39, 'リストから選択'),
(130579, 961, 39, 'レイアウト方向を選択してください'),
(130580, 962, 39, 'リスト選択'),
(130581, 963, 39, '用紙サイズ'),
(130582, 964, 39, 'PDF言語設定選択'),
(130583, 965, 39, 'この出会いレポートの印刷形式を選択してください。'),
(130584, 967, 39, '慢性気管支炎'),
(130585, 968, 39, '慢性関節痛'),
(130586, 969, 39, '慢性腎臓病（CKD）'),
(130587, 970, 39, '慢性滑膜炎/胸水/関節痛/痛風'),
(130588, 971, 39, '慢性/再発'),
(130589, 972, 39, 'チュバシュ'),
(130590, 973, 39, '肝硬変'),
(130591, 974, 39, '肝硬変'),
(130592, 975, 39, '市町村'),
(130593, 976, 39, '市町村名'),
(130594, 977, 39, '市県'),
(130595, 978, 39, '市県郵便番号'),
(130596, 979, 39, '市/県'),
(130597, 980, 39, 'クレーム'),
(130598, 981, 39, 'クレーム '),
(130599, 982, 39, 'クレーム状況'),
(130600, 983, 39, 'クレームテストが実行を完了しました'),
(130601, 984, 39, 'クレームタイプ'),
(130602, 985, 39, 'クレームはファイルに生成されました'),
(130603, 986, 39, 'クレームはファイルに生成されました '),
(130604, 987, 39, 'クレーム'),
(130605, 988, 39, 'クラス分け'),
(130606, 989, 39, 'クリア'),
(130607, 990, 39, 'アクティブな患者をクリア'),
(130608, 991, 39, 'すべてクリア'),
(130609, 992, 39, 'クリアHL7データ'),
(130610, 993, 39, '明確な正当化'),
(130611, 994, 39, 'Smartyキャッシュクリア'),
(130612, 995, 39, 'EDI 270バッチ作成に必要な社内情報をクリア。'),
(130613, 996, 39, 'CLIA 番号'),
(130614, 997, 39, 'クリック'),
(130615, 998, 39, 'テキストフ​​ァイルにカテゴリ、サブカテゴリ、アイテム、コンテンツデータをエクスポートする「輸出」をクリックしてください。 XMLファイルには、このファイルの任意の類似点とは一切関係ありません。開始タグと終了タグが同じライン上にある必要があり、彼らはスペースなしで小文字する必要があります。インポートするには、ファイルを参照し、「インポート」をクリックします。データは完全に異なっている場合、それはあなたの既存のデータとマージします。類似の項目名がある場合は、古いものが保持され、新しいものが最後に追加で保存。'),
(130616, 999, 39, '新しい注釈を追加するには、グラフィック上のスポットをクリックして、それを削除するには、もう一度それをクリック'),
(130617, 1000, 39, 'ファイルssl.zip内の証明書をダウンロードする証明書のダウンロード]をクリックします'),
(130618, 1001, 39, 'クリックして次へ'),
(130619, 1002, 39, 'クリックして詳細へ'),
(130620, 1003, 39, 'クリックして注文サマリーへ'),
(130621, 1004, 39, 'クリックして結果へ'),
(130622, 1005, 39, 'ここをクリック'),
(130623, 1006, 39, '新しい患者の追加'),
(130624, 1007, 39, 'クリックして新しい傷害ステータス変更を追加、日々の活動を編集します'),
(130625, 1008, 39, '日付の選択'),
(130626, 1009, 39, '日付と時間の選択'),
(130627, 1010, 39, '開始日の選択'),
(130628, 1011, 39, '日付時間の選択'),
(130629, 1012, 39, '開始日時時間の選択'),
(130630, 1013, 39, '終了日時時間の選択'),
(130631, 1014, 39, 'このモジュールを構成するには、ここをクリックします'),
(130632, 1016, 39, 'このモジュールを無効にするには、ここをクリックします'),
(130633, 1018, 39, 'このモジュールを有効にするには、ここをクリックします'),
(130634, 1019, 39, 'このモジュールをインストールするには、ここをクリック'),
(130635, 1020, 39, '検索'),
(130636, 1021, 39, '優先順位、カテゴリとニックネームの設定を更新するためにはこちらをクリック'),
(130637, 1022, 39, '全表示'),
(130638, 1023, 39, '全グラフの表示'),
(130639, 1024, 39, '全ラボデータの表示'),
(130640, 1025, 39, '全バイタルの表示'),
(130641, 1026, 39, '患者の詳細表示'),
(130642, 1027, 39, 'それらすべてを見るにはここをクリックしてください。'),
(130643, 1028, 39, 'より多くの詳細を編集/表示するにはここをクリック'),
(130644, 1029, 39, '次の日からデータベース·リリースをインストールするには、[インストール]ボタンをクリックして'),
(130645, 1030, 39, 'それを高めるために、時間の部分のいずれかをクリック'),
(130646, 1031, 39, '患者のファイルを開くには患者名をクリックして'),
(130647, 1032, 39, 'すべての結果を表示する、または特定の結果を表示するには、上記の入力検索条件を喜ばせるために、[更新]をクリックします。'),
(130648, 1033, 39, '診断を追加します'),
(130649, 1034, 39, '新しいコンポーネントを追加します'),
(130650, 1035, 39, '新しい相談を追加します'),
(130651, 1036, 39, '正当化するために診断を選択する場合にクリックします。'),
(130652, 1037, 39, 'クリックしてダウンロード'),
(130653, 1038, 39, '編集'),
(130654, 1039, 39, '詳細の編集'),
(130655, 1040, 39, 'このイベントの編集'),
(130656, 1041, 39, 'レポートの生成'),
(130657, 1042, 39, '該当患者表示'),
(130658, 1043, 39, '印刷'),
(130659, 1044, 39, '受信（追加）をクリックして新しいロット'),
(130660, 1045, 39, '選択'),
(130661, 1046, 39, '選択'),
(130662, 1047, 39, 'この手順のための業界標準のコードをクリックして選択します'),
(130663, 1048, 39, 'オプションの手順のコードをクリックして選択します'),
(130664, 1049, 39, '選択またはコーディング変更するにはクリック'),
(130665, 1050, 39, 'CVXコードを選択または変更するにはクリック'),
(130666, 1051, 39, '診断を選択または変更するにはクリック'),
(130667, 1052, 39, 'サービスコードを選択したり、変更するにはクリック'),
(130668, 1053, 39, '選択する患者をクリック'),
(130669, 1054, 39, '選択する関連コードをクリック'),
(130670, 1055, 39, 'この結果が異常である場合に実行するサービスをクリックして選択します'),
(130671, 1056, 39, '希望の手順をクリックして選択します'),
(130672, 1057, 39, 'ソート'),
(130673, 1058, 39, '閲覧'),
(130674, 1059, 39, '閲覧または編集'),
(130675, 1060, 39, '閲覧/編集'),
(130676, 1062, 39, '患者に合わせて上に示した場所をクリックします。'),
(130677, 1063, 39, 'クリック'),
(130678, 1064, 39, 'クライアント証明書の有効期限日数'),
(130679, 1065, 39, 'クライアント証明書の有効期間'),
(130680, 1066, 39, 'クライアント証明書の有効性は有効な数値でなければなりません。'),
(130681, 1067, 39, 'クライアントコピー'),
(130682, 1069, 39, 'クライアント病歴サマリー'),
(130683, 1070, 39, 'クライアント名'),
(130684, 1071, 39, 'クライアント番号'),
(130685, 1072, 39, 'クライアントプロファイル - 新規クライアント'),
(130686, 1073, 39, 'クライアントプロファイル - ユニークなクライアント'),
(130687, 1074, 39, 'クライアント'),
(130688, 1075, 39, 'クリニック'),
(130689, 1076, 39, 'クリニックのコピー'),
(130690, 1077, 39, 'クリニックデイリー·レコード'),
(130691, 1078, 39, 'クリニックID'),
(130692, 1079, 39, '臨床の'),
(130693, 1080, 39, '臨床決定ルールアラートマネージャ'),
(130694, 1081, 39, '病歴'),
(130695, 1083, 39, '臨床計画'),
(130696, 1084, 39, '臨床品質尺度（CQM）'),
(130697, 1085, 39, '臨床品質尺度（CQM） - 2011'),
(130698, 1086, 39, '臨床品質尺度（CQM） - 2014'),
(130699, 1087, 39, '通院予定'),
(130700, 1088, 39, '通院レポート'),
(130701, 1089, 39, '臨床ルールの動作カテゴリ'),
(130702, 1090, 39, '臨床ルールのアクションアイテム'),
(130703, 1091, 39, '臨床ルールのフィルタメソッド'),
(130704, 1092, 39, '臨床ルールのターゲットメソッド'),
(130705, 1093, 39, '臨床ルール'),
(130706, 1094, 39, '臨床ルール年齢間隔'),
(130707, 1095, 39, '臨床ルールの比較'),
(130708, 1096, 39, '臨床ルールタイプの出会い'),
(130709, 1097, 39, '臨床ルールリマインダーためのオプション'),
(130710, 1098, 39, '臨床ルールリマインダー不活性化のオプション'),
(130711, 1099, 39, '臨床ルールリマインダー間隔'),
(130712, 1100, 39, '臨床ルールリマインダー方法'),
(130713, 1101, 39, '臨床ルールターゲット間隔'),
(130714, 1102, 39, '臨床目標'),
(130715, 1103, 39, '臨床用語'),
(130716, 1104, 39, '臨床用語コード（単数または複数）'),
(130717, 1106, 39, '臨床医'),
(130718, 1107, 39, '複製'),
(130719, 1108, 39, '過去の訪問の複製'),
(130720, 1109, 39, '閉じる'),
(130721, 1110, 39, 'ウインドウを閉じる'),
(130722, 1111, 39, 'ウインドウを閉じる'),
(130723, 1112, 39, '閉じる'),
(130724, 1113, 39, 'cm'),
(130725, 1114, 39, 'CMS 1500マージン'),
(130726, 1115, 39, 'CMS 1500紙フォーム·フォーマット'),
(130727, 1116, 39, 'CMS 1500：ボックス31フォーマット'),
(130728, 1117, 39, 'CMS 1500：ボックス31日付（シグネチャ）'),
(130729, 1118, 39, 'CMS ID'),
(130730, 1119, 39, 'CMSポータル'),
(130731, 1120, 39, 'CMSポータルログイン'),
(130732, 1121, 39, 'CMSポータルログインID'),
(130733, 1122, 39, 'CMSポータルが有効になっていません！'),
(130734, 1123, 39, 'CMSポータルのパスワード'),
(130735, 1124, 39, 'CMSポータルリクエスト'),
(130736, 1125, 39, 'CMSポータルサイトアドレス'),
(130737, 1126, 39, 'CMSポータルユーザー名'),
(130738, 1127, 39, 'そのままCN2-12'),
(130739, 1128, 39, '共同ペイ'),
(130740, 1129, 39, '共同ペイ·有料'),
(130741, 1130, 39, 'CO-PAY'),
(130742, 1131, 39, 'コー​​ド'),
(130743, 1132, 39, 'コー​​ド'),
(130744, 1133, 39, 'コー​​ドファインダー'),
(130745, 1134, 39, 'コー​​ドは、2つの文字の小文字にする必要があります'),
(130746, 1135, 39, 'コー​​ドまたは通貨を示す記号'),
(130747, 1136, 39, 'コー​​ドテキスト'),
(130748, 1137, 39, 'コー​​ドタイプ'),
(130749, 1138, 39, 'コー​​ドタイプ'),
(130750, 1139, 39, 'コー​​ドタイプが認識されない'),
(130751, 1140, 39, 'コー​​ドタイプはまだ定義されていない'),
(130752, 1141, 39, 'コー​​ドタイプ'),
(130753, 1142, 39, 'コー​​ド（単数または複数）'),
(130754, 1143, 39, 'コー​​ド化'),
(130755, 1144, 39, 'コー​​ド'),
(130756, 1145, 39, 'コー​​ディング'),
(130757, 1146, 39, 'コー​​ディング（教育内容はこちら）'),
(130758, 1147, 39, 'コー​​ディング - どんな出会いが（書き込み、オプショナルwsome）'),
(130759, 1148, 39, 'コー​​ディング - 私の出会い（書き込みを、オプショナルwsome）'),
(130760, 1149, 39, '許可されていないコーディング'),
(130761, 1150, 39, 'コー​​ヒー'),
(130762, 1151, 39, 'コー​​ヒーを使用'),
(130763, 1152, 39, '共同保険'),
(130764, 1153, 39, 'コルW / O'),
(130765, 1154, 39, '伸縮'),
(130766, 1155, 39, '伸縮'),
(130767, 1156, 39, '全伸縮'),
(130768, 1157, 39, '全伸縮'),
(130769, 1158, 39, '全伸縮'),
(130770, 1160, 39, '収集日'),
(130771, 1161, 39, 'コレクション'),
(130772, 1162, 39, 'コレクションレポート'),
(130773, 1163, 39, '大腸癌'),
(130774, 1164, 39, '結腸癌スクリーニング'),
(130775, 1165, 39, '大腸癌手術'),
(130776, 1166, 39, '大腸内視鏡検査'),
(130777, 1167, 39, '大腸内視鏡検査'),
(130778, 1168, 39, 'カラー'),
(130779, 1169, 39, 'カラー：略称'),
(130780, 1170, 39, 'カラム'),
(130781, 1171, 39, 'カラム'),
(130782, 1172, 39, 'ロットを組み合わせる'),
(130783, 1173, 39, 'カンマ'),
(130784, 1174, 39, 'コメント'),
(130785, 1175, 39, 'コメント'),
(130786, 1176, 39, 'この結果や勧告のコメント'),
(130787, 1177, 39, '企業向け損害保険株式会社'),
(130788, 1178, 39, '変更のコミット'),
(130789, 1179, 39, '通信'),
(130790, 1180, 39, 'コミュニケーション'),
(130791, 1182, 39, '会社'),
(130792, 1183, 39, '会社名'),
(130793, 1184, 39, '完了'),
(130794, 1186, 39, '完了'),
(130795, 1188, 39, '完了？'),
(130796, 1190, 39, 'サービスプロバイダによって合併症'),
(130797, 1191, 39, '中絶の合併症'),
(130798, 1192, 39, 'コンポーネント'),
(130800, 1194, 39, '結論'),
(130801, 1198, 39, '設定'),
(130802, 1199, 39, '設定'),
(130803, 1200, 39, '設定 エキスポート/インポート'),
(130804, 1201, 39, '設定は正しく保存されました'),
(130805, 1202, 39, 'クライアント側のSSL証明書を使用するようにApacheとLibreEHRを設定します。'),
(130806, 1203, 39, 'apache を 端末側SSL認証で設定'),
(130807, 1204, 39, 'apache を HTTPS 利用で設定'),
(130808, 1205, 39, 'LIBREEHR を 端末側SSL認証で設定'),
(130809, 1206, 39, 'トラックの設定'),
(130810, 1207, 39, 'トラックの設定'),
(130811, 1208, 39, '新規患者作成の完了'),
(130812, 1209, 39, '新規パスワードの完了'),
(130813, 1210, 39, '支払完了'),
(130814, 1214, 39, '先天性の'),
(130815, 1215, 39, 'Conjuntiva、生徒'),
(130816, 1216, 39, '接続エラー'),
(130817, 1217, 39, '接続'),
(130818, 1218, 39, 'コンスタント'),
(130819, 1219, 39, 'コンスタント名'),
(130820, 1220, 39, 'コンスタント名が空白です'),
(130821, 1221, 39, '定数'),
(130822, 1222, 39, '便秘'),
(130823, 1223, 39, '憲法上の'),
(130824, 1226, 39, 'コンサルテーション簡単な説明'),
(130825, 1227, 39, '連絡先'),
(130826, 1228, 39, '連絡先電子メール'),
(130827, 1229, 39, '連絡先電子メールアドレス'),
(130828, 1230, 39, 'お問い合わせEMRダイレクトphiMailダイレクトメッセージサービスに加入する'),
(130829, 1231, 39, '連絡先情報'),
(130830, 1232, 39, 'コンタクトレンズ'),
(130831, 1233, 39, 'ラボエクスチェンジサービスのためのhttp://mi-squared.comでのお問い合わせ医療情報の統合、LLC。'),
(130832, 1234, 39, 'ERXサービスを購読するhttp://zhservices.comでhttp://mi-squared.comまたはZHヘルスケアで医療情報の統合、LLCにお問い合わせください'),
(130833, 1236, 39, '連絡先名前'),
(130834, 1237, 39, '連絡者'),
(130835, 1238, 39, '連絡先電話番号'),
(130836, 1239, 39, '連絡先電話番号'),
(130837, 1240, 39, 'ERXサービスを購読に関するお問い合わせZMG、LLC（zmghealth@gmail.com）'),
(130838, 1241, 39, '4以下の項目のうち少なくとも3が含まれています。'),
(130839, 1242, 39, 'コンテナグループ名'),
(130840, 1243, 39, 'コンテント'),
(130841, 1244, 39, 'コンテキスト'),
(130842, 1245, 39, 'コンテキスト'),
(130843, 1246, 39, 'コンテキスト名は空白にはできません'),
(130844, 1247, 39, '続く'),
(130845, 1248, 39, 'ケア文書の連続性（CCD）'),
(130846, 1249, 39, 'ケア記録（CCR）の継続性'),
(130847, 1250, 39, 'コントラクライアント'),
(130848, 1251, 39, '避妊'),
(130849, 1252, 39, '避妊の問題'),
(130850, 1253, 39, '避妊合併症（指定）'),
(130851, 1254, 39, '避妊方法'),
(130852, 1255, 39, '避妊製品'),
(130853, 1256, 39, '避妊サービスは、以前に開始した'),
(130854, 1257, 39, '避妊スタート'),
(130855, 1258, 39, 'コントロールID'),
(130856, 1259, 39, 'コントロール番号'),
(130857, 1261, 39, 'COPAY'),
(130858, 1262, 39, 'Copay'),
(130859, 1263, 39, 'CoPay'),
(130860, 1264, 39, '正でないCopay'),
(130861, 1265, 39, 'Copay有料'),
(130862, 1266, 39, 'Copays'),
(130863, 1267, 39, 'COPD'),
(130864, 1268, 39, '患者チャートにコピーページ'),
(130865, 1269, 39, 'コピー値'),
(130866, 1270, 39, 'データベースファイルをコピーする。これにはしばらく時間がかかります...'),
(130867, 1271, 39, '著作権表示'),
(130868, 1272, 39, 'コー​​ニッシュ'),
(130869, 1273, 39, '冠動脈バイパス'),
(130870, 1274, 39, '冠動脈バイパス移植（CABG）'),
(130871, 1275, 39, '修正された'),
(130872, 1276, 39, 'コルシカの'),
(130873, 1277, 39, 'CouchDBの'),
(130874, 1278, 39, 'CouchDBの接続が失敗しました。'),
(130875, 1279, 39, 'CouchDBのデータベース'),
(130876, 1280, 39, 'CouchDBのデータベース名'),
(130877, 1281, 39, 'CouchDBのホスト'),
(130878, 1282, 39, 'CouchDBのホスト名'),
(130879, 1283, 39, 'CouchDBのログの有効化'),
(130880, 1284, 39, 'CouchDBのパスワード'),
(130881, 1285, 39, 'CouchDBのポート'),
(130882, 1286, 39, 'CouchDBのポート'),
(130883, 1287, 39, 'CouchDBは失敗したセーブ'),
(130884, 1288, 39, 'のCouchDBのUserName'),
(130885, 1289, 39, '咳'),
(130886, 1290, 39, '咳：'),
(130887, 1291, 39, 'サーバーへ接続できません'),
(130888, 1293, 39, 'テーブルを開けません'),
(130889, 1294, 39, 'ファイルを読めません'),
(130890, 1295, 39, 'このファイルを読めません'),
(130891, 1296, 39, 'サーバー障害によりメールを送信できません '),
(130892, 1297, 39, 'サーバー障害によりメールを送信できません '),
(130893, 1298, 39, 'バックアップ先のディレクトリを作成できません'),
(130894, 1299, 39, 'ディレクトリを削除できません'),
(130895, 1300, 39, '過去のバックアップファイルを削除できません'),
(130896, 1301, 39, '過去のエクスポートファイルを削除できません'),
(130897, 1302, 39, 'ワーファリン管理 - INRのモニタリング'),
(130898, 1303, 39, '法によるCouns'),
(130899, 1304, 39, 'カウンセリング'),
(130900, 1305, 39, 'カウンセリング活動'),
(130901, 1306, 39, 'COUNTERの紹介FORM'),
(130902, 1307, 39, 'カウンター紹介'),
(130903, 1308, 39, '国'),
(130904, 1309, 39, '国別日時表示形式'),
(130905, 1310, 39, '国リスト'),
(130906, 1311, 39, '国リスト（追記可能）'),
(130907, 1313, 39, '国'),
(130908, 1315, 39, 'クーポン'),
(130909, 1318, 39, 'CPT'),
(130910, 1319, 39, 'CPTコード'),
(130911, 1320, 39, 'CPTコード'),
(130912, 1324, 39, '湿性ラ音'),
(130913, 1325, 39, 'クリーム'),
(130914, 1327, 39, 'ユーザーまたはクライアントホスト名のどちらかのクライアント側のSSL証明書を作成します。'),
(130915, 1328, 39, '新規トラック作成'),
(130916, 1329, 39, 'イベント作成'),
(130917, 1330, 39, '完全バックアップの作成及びダウンロード'),
(130918, 1331, 39, 'トラックの作成及び改変'),
(130919, 1332, 39, 'バクアップ作成'),
(130920, 1333, 39, 'バッチ作成'),
(130921, 1334, 39, 'クライアント認証作成'),
(130922, 1335, 39, 'クライアント側SSL認証作成'),
(130923, 1336, 39, 'デュプリケイト作成'),
(130924, 1337, 39, '来院者作成'),
(130925, 1338, 39, 'イベントログバックアップ作成'),
(130926, 1339, 39, '新規問題作成'),
(130927, 1340, 39, '新規患者作成の完了'),
(130928, 1341, 39, '新規トラック作成'),
(130929, 1344, 39, '患者ノート作成'),
(130930, 1345, 39, 'SSL認証及びサーバー認証作成'),
(130931, 1346, 39, '訪問先作成'),
(130932, 1347, 39, '作成された'),
(130933, 1348, 39, 'エキスポートファイル作成'),
(130934, 1349, 39, '新規トラック作成異常'),
(130935, 1350, 39, 'リモートホストでのファイル作成に失敗'),
(130936, 1351, 39, '作成者'),
(130937, 1352, 39, 'クレジット'),
(130938, 1353, 39, 'クレジットカード'),
(130939, 1354, 39, 'クレジット'),
(130940, 1356, 39, '抽出文字'),
(130941, 1357, 39, 'クロアチア人'),
(130942, 1358, 39, 'クローン病'),
(130943, 1359, 39, 'クローン病'),
(130944, 1360, 39, 'CSVエキスポート'),
(130945, 1361, 39, 'CSVファイル'),
(130946, 1362, 39, 'CSVテーブル'),
(130947, 1364, 39, 'キューバ人'),
(130948, 1365, 39, '通貨小数点以下の桁数'),
(130949, 1366, 39, '通貨小数点記号'),
(130950, 1367, 39, '通貨指定子'),
(130951, 1368, 39, '通貨桁区切り'),
(130952, 1369, 39, 'カレント'),
(130953, 1370, 39, '現在の飲酒量'),
(130954, 1371, 39, '現在の相談'),
(130955, 1372, 39, '現在の抽出字句'),
(130956, 1374, 39, '現在の日常喫煙者'),
(130957, 1375, 39, '現在のファイル名の変更先'),
(130958, 1376, 39, '現在のハッシュ'),
(130959, 1377, 39, '現住所'),
(130960, 1379, 39, '現在のパスワード'),
(130961, 1380, 39, '現在の患者'),
(130962, 1383, 39, '現在の時々喫煙者'),
(130963, 1385, 39, '現在の値'),
(130964, 1386, 39, '現在のアクティブ'),
(130965, 1387, 39, '日常的走行量'),
(130966, 1388, 39, '現在の通院はありません'),
(130967, 1389, 39, 'クッシング症候群'),
(130968, 1390, 39, 'クッシング症候群'),
(130969, 1392, 39, 'カスタム'),
(130970, 1393, 39, 'カスタムインプット'),
(130971, 1394, 39, 'カスタムテーブル'),
(130972, 1403, 39, 'チェコ人'),
(130973, 1404, 39, 'D'),
(130974, 1405, 39, '拡張＆掻爬術'),
(130975, 1406, 39, '拡張＆切除'),
(130976, 1407, 39, '誕生日'),
(130977, 1408, 39, '毎日'),
(130978, 1409, 39, '日誌'),
(130979, 1410, 39, 'デンマーク語.'),
(130980, 1416, 39, 'データエラー'),
(130981, 1420, 39, 'データ種別'),
(130982, 1421, 39, 'データベースアップグレード'),
(130983, 1422, 39, 'データベースがインストールされていません'),
(130984, 1423, 39, 'データベースパッチ'),
(130985, 1424, 39, 'データベースレポート出力'),
(130986, 1425, 39, 'データベース更新完了'),
(130987, 1426, 39, 'データカラムは１から999までです'),
(130988, 1427, 39, '日付'),
(130989, 1428, 39, '日付'),
(130990, 1429, 39, '日付と時間　管理向け'),
(130991, 1431, 39, '日付　管理向け'),
(130992, 1438, 39, '日付作成'),
(130993, 1441, 39, '日付表示フォーマット'),
(130994, 1451, 39, '課金日'),
(130995, 1452, 39, '誕生日'),
(130996, 1453, 39, '誕生日'),
(130997, 1454, 39, '誕生日'),
(130998, 1455, 39, '入力日'),
(130999, 1458, 39, '支払日 yyyy-mm-dd'),
(131000, 1460, 39, '返信日'),
(131001, 1461, 39, 'レポート日'),
(131002, 1462, 39, 'サービス日'),
(131003, 1463, 39, 'サービス日'),
(131004, 1464, 39, 'サービス日 = 今日'),
(131005, 1465, 39, 'サービス日 mm/dd/yyyy'),
(131006, 1466, 39, 'サービス日:'),
(131007, 1467, 39, 'サイン日'),
(131008, 1468, 39, 'ステータス変更日'),
(131009, 1469, 39, '該当オーダー日'),
(131010, 1470, 39, '該当レポート日'),
(131011, 1472, 39, '日時指定済み'),
(131012, 1474, 39, '日時選択'),
(131013, 1475, 39, '日時選択'),
(131014, 1476, 39, '日付送信'),
(131015, 1478, 39, '日付時間'),
(131016, 1479, 39, '日付は空白にできません'),
(131017, 1481, 39, '日付/ノート'),
(131018, 1482, 39, '日付/ノート終端'),
(131019, 1483, 39, '日付/時間'),
(131020, 1484, 39, '日付:'),
(131021, 1486, 39, '日'),
(131022, 1487, 39, '日'),
(131023, 1490, 39, '日'),
(131024, 1492, 39, '日'),
(131025, 1493, 39, '日'),
(131026, 1494, 39, '日前'),
(131027, 1501, 39, 'DBインストール済み'),
(131028, 1502, 39, 'DD/MM/YYYY'),
(131029, 1512, 39, 'デバッグ情報'),
(131030, 1514, 39, 'デバッグ中'),
(131031, 1515, 39, '12月'),
(131032, 1517, 39, '12月'),
(131033, 1522, 39, '通常'),
(131034, 1523, 39, '通常カレンダー表示'),
(131035, 1524, 39, '通常来院者表示ID'),
(131036, 1526, 39, '通常施術院'),
(131037, 1527, 39, '通常言語'),
(131038, 1530, 39, '通常メソッド'),
(131039, 1531, 39, '通常パスワード失効期限日'),
(131040, 1533, 39, '通常患者所在国'),
(131041, 1547, 39, 'デフォルト値'),
(131042, 1551, 39, '削除'),
(131043, 1552, 39, '削除'),
(131044, 1554, 39, '削除'),
(131045, 1555, 39, '削除'),
(131046, 1556, 39, '削除:ID及びカテゴリー '),
(131047, 1557, 39, '削除;カテゴリー'),
(131048, 1559, 39, '削除できません!'),
(131049, 1560, 39, 'グループ削除'),
(131050, 1561, 39, 'リスト削除'),
(131051, 1562, 39, 'ページ削除'),
(131052, 1565, 39, '列削除'),
(131053, 1566, 39, '選択アイテム削除'),
(131054, 1567, 39, '選択リクエスト削除'),
(131055, 1568, 39, '削除できました'),
(131056, 1569, 39, 'このドキュメントを削除'),
(131057, 1570, 39, 'このフォームを削除'),
(131058, 1571, 39, 'このノートを削除'),
(131059, 1572, 39, '正常に削除できました'),
(131060, 1573, 39, '正常に削除できました'),
(131061, 1582, 39, '一般表示項目'),
(131062, 1583, 39, '一般表示項目（追記オプション）'),
(131063, 1585, 39, '一般表示項目:抽出済み'),
(131064, 1586, 39, '一般表示項目は認証されていません'),
(131065, 1587, 39, '一般表示項目は認証されていません'),
(131066, 1588, 39, '禁止'),
(131067, 1590, 39, '歯科'),
(131068, 1591, 39, '歯科問題リスト'),
(131069, 1592, 39, '歯科問題リスト'),
(131070, 1596, 39, '預託日'),
(131071, 1597, 39, '入金日を今日より大きくすることはできません'),
(131072, 1598, 39, 'デポジット日：'),
(131073, 1599, 39, 'うつ病の'),
(131074, 1600, 39, 'うつ病'),
(131075, 1602, 39, '説明'),
(131076, 1603, 39, '説明'),
(131077, 1604, 39, '説明は、デフォルトのテキストです'),
(131078, 1605, 39, '情報開示の説明'),
(131079, 1606, 39, 'この手順または結果コードの説明'),
(131080, 1607, 39, '説明の翻訳'),
(131081, 1608, 39, '希望のファイル名'),
(131082, 1609, 39, '宛先'),
(131083, 1610, 39, 'コピー先のファイル名'),
(131084, 1611, 39, 'ロットを破壊'),
(131085, 1612, 39, '破壊します...'),
(131086, 1613, 39, '破壊されました'),
(131087, 1614, 39, '破壊された薬剤'),
(131088, 1615, 39, '破壊された医薬品レポート'),
(131089, 1616, 39, '詳細'),
(131090, 1620, 39, '糖尿病'),
(131091, 1633, 39, '診断'),
(131092, 1634, 39, '診断コード'),
(131093, 1635, 39, '診断コード'),
(131094, 1636, 39, '診断日'),
(131095, 1638, 39, '診断名'),
(131096, 1639, 39, '診断レポート'),
(131097, 1640, 39, '診断レポート'),
(131098, 1641, 39, '診断レポートのみ'),
(131099, 1642, 39, '診断タイトル'),
(131100, 1643, 39, '診断：'),
(131101, 1644, 39, '診断： '),
(131102, 1645, 39, '診断テスト：'),
(131103, 1646, 39, 'ダイヤル'),
(131104, 1647, 39, 'ダイヤフラム/キャップ'),
(131105, 1648, 39, '下痢'),
(131106, 1650, 39, '口述筆記'),
(131107, 1653, 39, 'びまん：'),
(131108, 1654, 39, 'デジタル署名'),
(131109, 1657, 39, 'ダイレクトメール'),
(131110, 1658, 39, 'ダイレクトメッセージログ'),
(131111, 1659, 39, 'ダイレクトメッセージを受信しました。'),
(131112, 1660, 39, 'ダイレクトメッセージは現在使用できません。'),
(131113, 1661, 39, 'ダイレクトメッセージは失敗を送信します。'),
(131114, 1663, 39, 'ディレクター名'),
(131115, 1664, 39, 'ディレクトリが削除できませんでした。継続しています。'),
(131116, 1665, 39, '廃疾'),
(131117, 1667, 39, 'カレンダー無効'),
(131118, 1668, 39, 'チャートトラッカー無効'),
(131119, 1672, 39, 'phpMyAdmin無効'),
(131120, 1674, 39, 'ユーザーグループ無効'),
(131121, 1675, 39, '使用禁止'),
(131122, 1676, 39, '無効'),
(131123, 1681, 39, '放出'),
(131124, 1682, 39, '尿道からの排出'),
(131125, 1684, 39, '右放電'),
(131126, 1685, 39, '右放電：'),
(131127, 1714, 39, '表示名'),
(131128, 1729, 39, '憩室炎'),
(131129, 1730, 39, '憩室炎の手術'),
(131130, 1731, 39, '憩室炎'),
(131131, 1732, 39, '憩室炎の手術'),
(131132, 1733, 39, '離婚'),
(131133, 1734, 39, 'めまい：'),
(131134, 1751, 39, '本当に削除しますか'),
(131135, 1752, 39, '本当にこの選択を削除しますか？'),
(131136, 1753, 39, '本当にこのグループを削除しますか？'),
(131137, 1754, 39, '本当に削除しますか？'),
(131138, 1755, 39, '本当に継続しますか？'),
(131139, 1756, 39, '本当にこれを削除しますか？'),
(131140, 1757, 39, '削除しますか？'),
(131141, 1758, 39, 'このレコードを削除しますか？'),
(131142, 1759, 39, '新規患者を継続して追加しますか？'),
(131143, 1760, 39, '新規名前を継続して追加しますか？'),
(131144, 1762, 39, '誕生日'),
(131145, 1763, 39, '誕生日がありません。入力してください。'),
(131146, 1764, 39, '医者'),
(131147, 1765, 39, '医者'),
(131148, 1766, 39, '医者'),
(131149, 1767, 39, '医者の指名および署名'),
(131150, 1768, 39, '文書'),
(131151, 1769, 39, '文書'),
(131152, 1770, 39, '文書カテゴリー'),
(131153, 1771, 39, 'ラボレザルトの文書カテゴリーが存在しません'),
(131154, 1772, 39, 'ラボレザルトを受信しました。'),
(131155, 1777, 39, '文書日時'),
(131156, 1779, 39, '文書ID'),
(131157, 1780, 39, '文書を新規カテゴリへ移動しました'),
(131158, 1781, 39, '文書を患者IDへ移動しました'),
(131159, 1784, 39, '文書保管メソッド'),
(131160, 1785, 39, '文書名を変更しました'),
(131161, 1786, 39, '文書を来院者に付与しました'),
(131162, 1787, 39, '文書定型管理'),
(131163, 1788, 39, '文書定型'),
(131164, 1789, 39, '文書'),
(131165, 1790, 39, '文書/イメージ 保存'),
(131166, 1791, 39, '文書'),
(131167, 1792, 39, '文書(追記オプション)'),
(131168, 1799, 39, '婚姻者'),
(131169, 1803, 39, '完了。ダウンロードを続けて送信'),
(131170, 1804, 39, '完了:'),
(131171, 1805, 39, '完了。ダウンロードを続けて送信'),
(131172, 1806, 39, '診察日'),
(131173, 1809, 39, 'ダブルクリックで編集'),
(131174, 1811, 39, 'ダウンロード'),
(131175, 1828, 39, '医師確認'),
(131176, 1829, 39, '医師来診'),
(131177, 1830, 39, '医者'),
(131178, 1831, 39, 'ドラッグして移動'),
(131179, 1834, 39, '薬'),
(131180, 1835, 39, '薬検索'),
(131181, 1836, 39, '薬フォーム'),
(131182, 1837, 39, '薬品IDがありません'),
(131183, 1840, 39, '薬品名'),
(131184, 1846, 39, '薬品'),
(131185, 1847, 39, '薬品および薬剤'),
(131186, 1848, 39, 'ドライマウス'),
(131187, 1849, 39, 'DSM-IV Diagnosis'),
(131188, 1850, 39, 'DT 1'),
(131189, 1851, 39, 'DT 2'),
(131190, 1852, 39, 'DT 3'),
(131191, 1853, 39, 'DT 4'),
(131192, 1854, 39, 'DT 5'),
(131193, 1855, 39, 'DTaP 1'),
(131194, 1856, 39, 'DTaP 2'),
(131195, 1857, 39, 'DTaP 3'),
(131196, 1858, 39, 'DTaP 4'),
(131197, 1859, 39, 'DTaP 5'),
(131198, 1860, 39, '経過'),
(131199, 1861, 39, '経過日'),
(131200, 1862, 39, '経過日 mm/dd/yyyy または yyyy-mm-dd'),
(131201, 1863, 39, '経過日:'),
(131202, 1880, 39, '間隔'),
(131203, 1881, 39, '間隔'),
(131204, 1896, 39, '心電図'),
(131205, 1904, 39, '編集'),
(131206, 1905, 39, '編集'),
(131207, 1906, 39, 'アレルギー編集'),
(131208, 1907, 39, 'カテゴリー編集'),
(131209, 1912, 39, '来院所編集'),
(131210, 1913, 39, '来院所編集'),
(131211, 1914, 39, '来院所情報編集'),
(131212, 1915, 39, '院所指定者情報編集'),
(131213, 1918, 39, 'グローバル設定編集'),
(131214, 1919, 39, '編集権限がありません!'),
(131215, 1920, 39, 'レイアウト編集'),
(131216, 1921, 39, 'リスト編集'),
(131217, 1922, 39, '支払編集'),
(131218, 1923, 39, '構造編集'),
(131219, 1924, 39, 'ユーザー編集'),
(131220, 1925, 39, 'ユーザー設定編集'),
(131221, 1949, 39, '電子メール'),
(131222, 1950, 39, '電子メール'),
(131223, 1951, 39, '電子メールアドレス'),
(131224, 1952, 39, '電子メールアドレスがありません'),
(131225, 1956, 39, '電子メール認証'),
(131226, 1958, 39, '電子メール通知'),
(131227, 1959, 39, '電子メール通知時間'),
(131228, 1960, 39, '電子メール通知レポート'),
(131229, 1962, 39, '電子メール送信者'),
(131230, 1963, 39, '電子メール送信'),
(131231, 1964, 39, '電子メール宛先'),
(131232, 1965, 39, '電子メール件名'),
(131233, 1971, 39, '緊急連絡先'),
(131234, 1972, 39, '緊急連絡者'),
(131235, 1973, 39, '研究連絡電話番号'),
(131236, 1975, 39, '緊急ログイン'),
(131237, 1978, 39, '緊急ログインメールアドレス'),
(131238, 1979, 39, '緊急ログインユーザーは全て操作できます'),
(131239, 1980, 39, '緊急電話番号'),
(131240, 1982, 39, '肺気腫'),
(131241, 1983, 39, '雇用者'),
(131242, 1984, 39, '雇用主'),
(131243, 1985, 39, '雇用主住所'),
(131244, 1986, 39, '雇用日'),
(131245, 1987, 39, '雇用主名前'),
(131246, 1988, 39, '空'),
(131247, 1989, 39, '空'),
(131248, 1990, 39, 'パスワード空白は無効です'),
(131249, 1991, 39, '電子メール送信時間が空白です'),
(131250, 1992, 39, '電子メール宛先が空白です'),
(131251, 1993, 39, '電子メール件名が空白です'),
(131252, 1994, 39, '電子メール本文が空白です'),
(131253, 1995, 39, '電子メール送信主が空白です'),
(131254, 1996, 39, 'パスワードの値が空白です'),
(131255, 1997, 39, 'SMS送信時間が空白です'),
(131256, 1998, 39, 'SMS本文が空白です'),
(131257, 1999, 39, 'ユーザーネームが空白です'),
(131258, 2001, 39, '有効'),
(131259, 2008, 39, 'AMCレポートを有効にします'),
(131260, 2009, 39, 'AMCトラッキングを有効にします'),
(131261, 2016, 39, 'SSL端末接続が可能です'),
(131262, 2017, 39, 'SSL端末の認証接続が可能です'),
(131263, 2025, 39, 'CMSポータルが可能です'),
(131264, 2027, 39, 'CQMレポートを有効にします'),
(131265, 2031, 39, 'Hylafax サポート可能'),
(131266, 2033, 39, 'NewCrop erxのインポートステータスメッセージを有効にします'),
(131267, 2034, 39, 'AMCレポートの内訳を有効にします'),
(131268, 2035, 39, 'CQMレポートの内訳を有効にします'),
(131269, 2036, 39, '標準的な臨床規則レポートの内訳を有効にします'),
(131270, 2038, 39, 'ロックトグルを有効にします'),
(131271, 2039, 39, 'CouchDBのにドキュメントのアップロード/ダウンロードのログを有効にします'),
(131272, 2040, 39, 'すべてのSQLのSELECTクエリのログを有効にします。'),
(131273, 2041, 39, 'バックアップ関連の活動のログを有効にします。'),
(131274, 2061, 39, 'スキャナーサポート可能'),
(131275, 2130, 39, '終了日：'),
(131276, 2131, 39, '終了時刻'),
(131277, 2141, 39, '英語'),
(131278, 2142, 39, '英語 '),
(131279, 2143, 39, '英語（インド）'),
(131280, 2144, 39, '英語（一般）'),
(131281, 2155, 39, '薬剤を入力してください'),
(131282, 2158, 39, '予防接種を入力してください'),
(131283, 2159, 39, 'キーを入力してください'),
(131284, 2160, 39, '新しいデータを入力してください'),
(131285, 2161, 39, '新しい状態を入力してください'),
(131286, 2163, 39, 'この手順についてLOINCコードを入力してください'),
(131287, 2164, 39, '再識別コードを入力してください'),
(131288, 2167, 39, 'エントリー'),
(131289, 2168, 39, '環境の'),
(131290, 2181, 39, '消去'),
(131291, 2183, 39, 'エラー'),
(131292, 2184, 39, 'エラー'),
(131293, 2190, 39, '「プロセス」の選択でエラーが発生しました'),
(131294, 2194, 39, 'YESまたはNOオプションでエラーが発生しました'),
(131295, 2196, 39, 'エラー処理ファイル'),
(131296, 2198, 39, 'エラーメッセージの削除'),
(131297, 2200, 39, '値を取得中にエラーが発生しました。'),
(131298, 2235, 39, 'エラー'),
(131299, 2245, 39, 'エスキモー人'),
(131300, 2246, 39, 'スペイン人'),
(131301, 2247, 39, '発行済み患者'),
(131302, 2248, 39, 'エストニア人'),
(131303, 2249, 39, 'エスニック人'),
(131304, 2250, 39, 'エスニック及び人種'),
(131305, 2251, 39, 'エスニック及び人種(追記オプション)'),
(131306, 2253, 39, 'イベント'),
(131307, 2254, 39, 'イベント開始'),
(131308, 2255, 39, 'イベントカテゴリー'),
(131309, 2256, 39, 'イベント日付'),
(131310, 2257, 39, 'イベント概要'),
(131311, 2258, 39, 'イベント詳細'),
(131312, 2259, 39, 'イベントは繰り返しません'),
(131313, 2260, 39, 'イベント間隔'),
(131314, 2261, 39, 'イベント間隔(分)'),
(131315, 2262, 39, 'イベント料'),
(131316, 2263, 39, 'イベント場所'),
(131317, 2264, 39, 'イベントリピート毎'),
(131318, 2265, 39, 'イベントリピート'),
(131319, 2266, 39, 'イベント開始時間'),
(131320, 2267, 39, 'イベントタイトル'),
(131321, 2268, 39, 'イベントタイトル'),
(131322, 2269, 39, 'イベントウェブサイト'),
(131323, 2270, 39, 'イベント'),
(131324, 2272, 39, 'イベントを新規ウインドウで開く'),
(131325, 2273, 39, '毎'),
(131326, 2274, 39, '毎'),
(131327, 2275, 39, '3時間毎'),
(131328, 2276, 39, '4時間毎'),
(131329, 2277, 39, '5時間毎'),
(131330, 2278, 39, '6時間毎'),
(131331, 2279, 39, '8時間毎'),
(131332, 2280, 39, '4回毎'),
(131333, 2281, 39, 'その都度'),
(131334, 2282, 39, '3回毎'),
(131335, 2285, 39, '練習及び試験レザルト'),
(131336, 2286, 39, '練習レザルト'),
(131337, 2289, 39, '練習レザルト'),
(131338, 2290, 39, '練習日'),
(131339, 2291, 39, 'サンプル'),
(131340, 2292, 39, 'サンプル'),
(131341, 2293, 39, '試験/テスト'),
(131342, 2300, 39, '運動'),
(131343, 2301, 39, '運動パターン'),
(131344, 2302, 39, '運動パターン'),
(131345, 2305, 39, '経験'),
(131346, 2306, 39, '展開'),
(131347, 2307, 39, '展開'),
(131348, 2308, 39, '全て展開'),
(131349, 2313, 39, '有効期限'),
(131350, 2314, 39, '有効期限'),
(131351, 2315, 39, '有効期限'),
(131352, 2317, 39, 'エクスポート'),
(131353, 2318, 39, 'CSVでエクスポート'),
(131354, 2319, 39, '設定のエクスポート'),
(131355, 2322, 39, '患者一般表示項目のエクスポート'),
(131356, 2325, 39, '選択済みをCSVでエクスポート'),
(131357, 2327, 39, 'CSVへエクスポート'),
(131358, 2328, 39, '外部課金システムへエクスポート'),
(131359, 2332, 39, '外部'),
(131360, 2334, 39, '外部データ読み込み'),
(131361, 2335, 39, '外部データベースインポートユーティリティー'),
(131362, 2336, 39, '外部ID'),
(131363, 2337, 39, '外部ID'),
(131364, 2338, 39, '外部識別子'),
(131365, 2339, 39, '外部のみ'),
(131366, 2346, 39, 'ZIPファイル展開'),
(131367, 2347, 39, 'ファイル展開中…しばらくお待ちください'),
(131368, 2349, 39, '眼刺激性'),
(131369, 2350, 39, '目疾患'),
(131370, 2352, 39, '目'),
(131371, 2356, 39, '病院'),
(131372, 2379, 39, '作成失敗'),
(131373, 2382, 39, '失敗しました。'),
(131374, 2383, 39, '失敗'),
(131375, 2384, 39, '失敗'),
(131376, 2400, 39, '父親'),
(131377, 2402, 39, '倦怠感'),
(131378, 2403, 39, '疲労'),
(131379, 2404, 39, 'ファックス'),
(131380, 2405, 39, 'ファックス枚数'),
(131381, 2406, 39, 'ファックス番号'),
(131382, 2408, 39, 'ファックス/スキャン'),
(131383, 2409, 39, 'FAX受信'),
(131384, 2410, 39, 'FAX送信'),
(131385, 2411, 39, '特徴'),
(131386, 2412, 39, '2月'),
(131387, 2413, 39, '2月'),
(131388, 2423, 39, '報酬'),
(131389, 2424, 39, '女性'),
(131390, 2426, 39, '女性用コンドーム'),
(131391, 2435, 39, '発熱'),
(131392, 2438, 39, 'フィールド'),
(131393, 2446, 39, 'フィジー人'),
(131394, 2447, 39, 'ファイル更新'),
(131395, 2449, 39, 'ファイル位置'),
(131396, 2450, 39, 'ファイル管理'),
(131397, 2456, 39, '送信ファイル'),
(131398, 2457, 39, '送信ファイル'),
(131399, 2459, 39, 'ファイル名'),
(131400, 2460, 39, 'ファイル名の末尾は”.pdf”が必要です'),
(131401, 2461, 39, 'ファイル位置'),
(131402, 2462, 39, 'フィリピン人'),
(131403, 2468, 39, 'フィルター'),
(131404, 2472, 39, 'フィルター'),
(131405, 2473, 39, 'フィルター'),
(131406, 2493, 39, '完了'),
(131407, 2494, 39, 'フィンランド語'),
(131408, 2495, 39, '最初'),
(131409, 2497, 39, '週の最初の日'),
(131410, 2498, 39, 'ファーストネーム'),
(131411, 2499, 39, 'ファーストネーム'),
(131412, 2500, 39, 'ファーストネーム：'),
(131413, 2501, 39, '初来院または相談'),
(131414, 2502, 39, '名前苗字'),
(131415, 2503, 39, 'フィットネス'),
(131416, 2504, 39, 'フィットネスレベル'),
(131417, 2512, 39, 'フロー'),
(131418, 2532, 39, '足'),
(131419, 2564, 39, '書式'),
(131420, 2571, 39, '喫煙経験者'),
(131421, 2581, 39, '骨折'),
(131422, 2583, 39, '外果骨折'),
(131423, 2584, 39, '内果骨折'),
(131424, 2588, 39, 'フランス人(カナダ系)'),
(131425, 2589, 39, 'フランス人(一般)'),
(131426, 2590, 39, '周期'),
(131427, 2593, 39, '金'),
(131428, 2594, 39, '金曜日'),
(131429, 2595, 39, 'From'),
(131430, 2596, 39, '送信元'),
(131431, 2597, 39, 'から'),
(131432, 2598, 39, 'から'),
(131433, 2599, 39, '送信元:'),
(131434, 2600, 39, '送信元: '),
(131435, 2635, 39, 'ガリシア語'),
(131436, 2637, 39, '胆石'),
(131437, 2641, 39, 'ゲーム/イベント'),
(131438, 2643, 39, 'ガンダ語'),
(131439, 2644, 39, '胃炎'),
(131440, 2645, 39, '胃の痛み'),
(131441, 2646, 39, '胃腸'),
(131442, 2647, 39, 'GCAC統計レポート'),
(131443, 2648, 39, 'GCAC統計'),
(131444, 2649, 39, 'GCAC訪問フォームが欠落しています'),
(131445, 2650, 39, '性別'),
(131446, 2651, 39, '性別 '),
(131447, 2652, 39, '総合'),
(131448, 2653, 39, '総合問題リスト'),
(131449, 2656, 39, '生成'),
(131450, 2668, 39, 'インボイス作成'),
(131451, 2669, 39, 'レター作成'),
(131452, 2670, 39, 'レター挨拶作成 '),
(131453, 2683, 39, '生成'),
(131454, 2684, 39, '泌尿生殖器'),
(131455, 2687, 39, 'ドイツ語'),
(131456, 2698, 39, '全般'),
(131457, 2713, 39, 'グラム'),
(131458, 2714, 39, '総合計'),
(131459, 2715, 39, '総合計'),
(131460, 2722, 39, 'ギリシャ人'),
(131461, 2724, 39, 'グループ'),
(131462, 2725, 39, 'グループ名'),
(131463, 2731, 39, 'グループ'),
(131464, 2732, 39, 'グループ名'),
(131465, 2752, 39, 'ハードディスク'),
(131466, 2760, 39, 'ハワイ人'),
(131467, 2768, 39, '頭'),
(131468, 2771, 39, '頭痛'),
(131469, 2772, 39, '頭痛'),
(131470, 2780, 39, '心臓病'),
(131471, 2781, 39, '心不全'),
(131472, 2784, 39, '心臓外科'),
(131473, 2791, 39, 'ヘブライ人'),
(131474, 2794, 39, '身長'),
(131475, 2795, 39, '身長/長さ'),
(131476, 2796, 39, 'ヘルプ'),
(131477, 2797, 39, 'ヘルプ'),
(131478, 2798, 39, '吐血'),
(131479, 2799, 39, '血便排泄'),
(131480, 2800, 39, '血液学'),
(131481, 2801, 39, '血尿'),
(131482, 2802, 39, 'ヘモグロビン'),
(131483, 2803, 39, 'ヘモグロビン A1C'),
(131484, 2804, 39, '喀血'),
(131485, 2805, 39, '肝炎'),
(131486, 2806, 39, 'A型肝炎1'),
(131487, 2807, 39, 'A型肝炎2'),
(131488, 2808, 39, 'B型肝炎1'),
(131489, 2809, 39, 'B型肝炎2'),
(131490, 2810, 39, 'B型肝炎3'),
(131491, 2812, 39, 'ヘレロ語'),
(131492, 2814, 39, '椎間板ヘルニア'),
(131493, 2815, 39, 'ヘルペス'),
(131494, 2816, 39, 'ためらい'),
(131495, 2818, 39, 'Hib 1'),
(131496, 2819, 39, 'Hib 2'),
(131497, 2820, 39, 'Hib 3'),
(131498, 2821, 39, 'Hib 4'),
(131499, 2824, 39, '隠す'),
(131500, 2825, 39, '詳細を隠す'),
(131501, 2828, 39, 'メニューを隠す'),
(131502, 2830, 39, 'リマインダーを隠す'),
(131503, 2833, 39, '高い'),
(131504, 2834, 39, '高血圧'),
(131505, 2843, 39, 'ヒスパニック'),
(131506, 2846, 39, 'ヒスパニックまたはラテン'),
(131507, 2847, 39, '履歴'),
(131508, 2848, 39, '履歴データ'),
(131509, 2849, 39, '履歴日時'),
(131510, 2851, 39, '履歴番号'),
(131511, 2855, 39, 'HIV'),
(131512, 2858, 39, 'HL7ビュアー'),
(131513, 2861, 39, 'フモン語'),
(131514, 2863, 39, '複数の項目を選択するにはCtrlキーを押しながら'),
(131515, 2865, 39, 'ホーム'),
(131516, 2866, 39, '自宅'),
(131517, 2867, 39, '自宅電話番号'),
(131518, 2868, 39, 'ホームレス(同様に)'),
(131519, 2869, 39, 'ホームレス等'),
(131520, 2870, 39, 'ホームレス等'),
(131521, 2872, 39, 'ホスト名'),
(131522, 2873, 39, 'ホスト名は空にできません'),
(131523, 2875, 39, '時間'),
(131524, 2876, 39, '時間'),
(131525, 2887, 39, 'ハンガリー語'),
(131526, 2888, 39, 'Hylafax 電話帳'),
(131527, 2890, 39, 'Hylafax サーバー'),
(131528, 2891, 39, 'Hylafax サーバー ホスト名'),
(131529, 2893, 39, '高血圧'),
(131530, 2897, 39, '甲状腺機能低下症'),
(131531, 2900, 39, 'この時間は多忙です'),
(131532, 2901, 39, '読み込み権限がありません '),
(131533, 2902, 39, 'ICD'),
(131534, 2909, 39, 'ID'),
(131535, 2911, 39, 'IDは空白にできません'),
(131536, 2912, 39, 'IDカード'),
(131537, 2915, 39, '識別子（一句）'),
(131538, 2925, 39, 'SMTPで利用するサーバーホスト名またはIPアドレス'),
(131539, 2926, 39, 'SMTPで利用するTCPポート番号(通常 25)'),
(131540, 2927, 39, '非雇用の場合は学生'),
(131541, 2936, 39, '否定'),
(131542, 2937, 39, '持病'),
(131543, 2938, 39, 'IM'),
(131544, 2941, 39, 'イメージサービス'),
(131545, 2942, 39, '免疫'),
(131546, 2943, 39, '免疫コード'),
(131547, 2953, 39, '免疫化'),
(131548, 2956, 39, 'インプラント'),
(131549, 2957, 39, 'インポート'),
(131550, 2962, 39, '設定のインポート'),
(131551, 2964, 39, '患者のインポート'),
(131552, 2967, 39, '重要：このアップロードツールは、システムに入力されていない患者ドキュメントのみアップロードするためのものです。システム入力済の患者のファイルをアップロードするには、患者のサマリー画面内のリンクよりアップロードツールを使用してください。'),
(131553, 2972, 39, '加速する'),
(131554, 2978, 39, 'オフィス内'),
(131555, 2983, 39, '受信箱'),
(131556, 2986, 39, 'チェックサム含む'),
(131557, 2991, 39, 'バイタル含む'),
(131558, 2996, 39, '非完全'),
(131559, 3004, 39, 'インド人'),
(131560, 3005, 39, '異常を示します'),
(131561, 3006, 39, 'この問題は、現在アクティブであるかどうかを示します'),
(131562, 3008, 39, '専門的な使用のためのインジケータ'),
(131563, 3009, 39, '貧しい患者'),
(131564, 3010, 39, '貧しい患者レポート'),
(131565, 3013, 39, 'インドネシア語'),
(131566, 3014, 39, '人工流産'),
(131567, 3016, 39, '不適格'),
(131568, 3017, 39, '感染/膿瘍'),
(131569, 3018, 39, '感染症'),
(131570, 3020, 39, '不妊'),
(131571, 3027, 39, 'Info test 1'),
(131572, 3028, 39, 'Info test 2'),
(131573, 3029, 39, 'Info test 3'),
(131574, 3030, 39, 'Info test 4'),
(131575, 3031, 39, 'Info test 5'),
(131576, 3032, 39, 'Info test 6'),
(131577, 3040, 39, '注射'),
(131578, 3043, 39, '傷害'),
(131579, 3065, 39, 'Ins1'),
(131580, 3066, 39, 'Ins2'),
(131581, 3067, 39, 'Ins3'),
(131582, 3068, 39, '挿入'),
(131583, 3070, 39, 'テーブルに古いイベントを挿入します'),
(131584, 3072, 39, '不眠症'),
(131585, 3073, 39, 'ログ検査'),
(131586, 3074, 39, '検査'),
(131587, 3076, 39, 'インストール'),
(131588, 3077, 39, 'インストール'),
(131589, 3078, 39, 'コードセットのインストール'),
(131590, 3079, 39, 'DBのインストール'),
(131591, 3087, 39, '保険'),
(131592, 3088, 39, '保険'),
(131593, 3093, 39, '保険会社'),
(131594, 3094, 39, '保険会社'),
(131595, 3095, 39, '保険会社'),
(131596, 3104, 39, '保険形式'),
(131597, 3105, 39, '保険'),
(131598, 3116, 39, '内部エラー'),
(131599, 3118, 39, '内部エラー：MSH-10が見つかりません'),
(131600, 3129, 39, '通訳'),
(131601, 3130, 39, '通訳が必要？'),
(131602, 3132, 39, '間隔'),
(131603, 3133, 39, '間隔(分)'),
(131604, 3135, 39, '介入'),
(131605, 3142, 39, 'イヌクティトゥト語'),
(131606, 3143, 39, 'イヌピアック語'),
(131607, 3144, 39, '不明文字がある'),
(131608, 3147, 39, '長さ違い'),
(131609, 3151, 39, 'サービスコード異常'),
(131610, 3153, 39, 'ユーザー名あるいはパスワードに誤りがあります'),
(131611, 3155, 39, '持ち物'),
(131612, 3160, 39, '持ち物リスト'),
(131613, 3162, 39, '見積もり'),
(131614, 3163, 39, '見積もり'),
(131615, 3173, 39, '見積もり:'),
(131616, 3174, 39, '国際家族計画連盟'),
(131617, 3180, 39, 'IPV 1'),
(131618, 3181, 39, 'IPV 2'),
(131619, 3182, 39, 'IPV 3'),
(131620, 3183, 39, 'IPV 4'),
(131621, 3184, 39, 'アイリッシュ'),
(131622, 3198, 39, 'PHPがセーフモードで実行されていますか？'),
(131623, 3202, 39, 'ファイルは暗号化されていますか？'),
(131624, 3205, 39, '医学的問題のコードタイプですか？'),
(131625, 3208, 39, '有効ですか？'),
(131626, 3211, 39, 'これでよろしいですか？'),
(131627, 3214, 39, 'では長すぎます'),
(131628, 3215, 39, 'ISO 639-2 Code'),
(131629, 3216, 39, '問題'),
(131630, 3217, 39, '問題'),
(131631, 3218, 39, '問題日'),
(131632, 3219, 39, '問題ID'),
(131633, 3220, 39, '課題'),
(131634, 3221, 39, '課題タイプ'),
(131635, 3222, 39, '課題タイプ'),
(131636, 3223, 39, '問題内容'),
(131637, 3230, 39, 'イタリア人'),
(131638, 3231, 39, 'アイテム'),
(131639, 3232, 39, 'アイテム'),
(131640, 3233, 39, 'アイテム'),
(131641, 3237, 39, '点滴静脈注射'),
(131642, 3238, 39, '一月'),
(131643, 3239, 39, '一月'),
(131644, 3240, 39, '日本語'),
(131645, 3242, 39, 'ジャワ人'),
(131646, 3243, 39, '仕事概略'),
(131647, 3244, 39, '仕事ID'),
(131648, 3248, 39, '6月'),
(131649, 3249, 39, '6月'),
(131650, 3250, 39, '7月'),
(131651, 3251, 39, '7月');
INSERT INTO `lang_definitions` VALUES
(131652, 3255, 39, '適正値'),
(131653, 3256, 39, '適正値/保存'),
(131654, 3264, 39, 'キー'),
(131655, 3265, 39, 'キーワード'),
(131656, 3266, 39, 'キログラム'),
(131657, 3267, 39, '平方キログラム'),
(131658, 3269, 39, '小児がん'),
(131659, 3270, 39, '小児不全'),
(131660, 3272, 39, '腎臓結石'),
(131661, 3273, 39, '腎臓移植'),
(131662, 3275, 39, 'キニヤルワンダ語'),
(131663, 3276, 39, 'キルンディ語'),
(131664, 3277, 39, '肘'),
(131665, 3278, 39, 'ひじ故障'),
(131666, 3279, 39, 'ひじ置換'),
(131667, 3280, 39, 'コミ語'),
(131668, 3281, 39, 'コンゴ人'),
(131669, 3282, 39, '韓国人'),
(131670, 3286, 39, 'ラボ'),
(131671, 3287, 39, 'ラボ書類'),
(131672, 3303, 39, 'ラベル'),
(131673, 3304, 39, 'ラベルは空白にできません'),
(131674, 3305, 39, 'ラベルカラム数'),
(131675, 3308, 39, 'ラベル'),
(131676, 3311, 39, 'ラボ'),
(131677, 3315, 39, 'ランドスケープ'),
(131678, 3316, 39, '言語'),
(131679, 3317, 39, '言語コード'),
(131680, 3318, 39, '言語定義を追加しました'),
(131681, 3319, 39, '言語インターフェースツール'),
(131682, 3321, 39, '言語名'),
(131683, 3322, 39, '言語:'),
(131684, 3325, 39, '最後'),
(131685, 3326, 39, '最終活動日'),
(131686, 3327, 39, '最終虫垂'),
(131687, 3328, 39, '前回の請求日：'),
(131688, 3329, 39, '最終乳房検査'),
(131689, 3331, 39, '最後の白内障手術'),
(131690, 3332, 39, '最終胆嚢摘出術'),
(131691, 3343, 39, '最終月'),
(131692, 3344, 39, '名'),
(131693, 3345, 39, '名'),
(131694, 3346, 39, '名'),
(131695, 3352, 39, '最終保存'),
(131696, 3356, 39, '最終更新日'),
(131697, 3358, 39, '最終訪問日'),
(131698, 3359, 39, '最後のレントゲン'),
(131699, 3368, 39, 'ラテン人'),
(131700, 3369, 39, 'ラトビア人'),
(131701, 3372, 39, 'レイアウト'),
(131702, 3374, 39, 'レイアウト編集'),
(131703, 3376, 39, 'レイアウトスタイル'),
(131704, 3379, 39, 'レイアウト'),
(131705, 3380, 39, 'lb'),
(131706, 3381, 39, 'lbs'),
(131707, 3390, 39, '左'),
(131708, 3391, 39, '左耳'),
(131709, 3393, 39, '左マージン(mm)'),
(131710, 3394, 39, '左:'),
(131711, 3395, 39, '左: '),
(131712, 3397, 39, 'リーガル'),
(131713, 3399, 39, 'リーガル紙サイズ'),
(131714, 3401, 39, '長さ'),
(131715, 3406, 39, 'レター'),
(131716, 3407, 39, 'レター生成'),
(131717, 3408, 39, 'レター用紙サイズ'),
(131718, 3414, 39, 'ライセンス/ID'),
(131719, 3423, 39, 'ライフスタイル'),
(131720, 3431, 39, 'リンク'),
(131721, 3438, 39, 'リスト'),
(131722, 3439, 39, 'リストボックス'),
(131723, 3440, 39, 'リストボックス'),
(131724, 3443, 39, '一覧編集'),
(131725, 3445, 39, 'グループ一覧'),
(131726, 3459, 39, 'リトアニア人'),
(131727, 3470, 39, '読み込み中'),
(131728, 3476, 39, '場所'),
(131729, 3492, 39, 'ログイン'),
(131730, 3493, 39, 'ログイン'),
(131731, 3494, 39, 'ログアウト'),
(131732, 3495, 39, 'ログイン中'),
(131733, 3496, 39, 'ログイン名'),
(131734, 3497, 39, 'ログイン名 '),
(131735, 3498, 39, 'ログアウト'),
(131736, 3499, 39, 'ログイン中'),
(131737, 3500, 39, 'ログイン'),
(131738, 3501, 39, 'ログイン'),
(131739, 3505, 39, 'ログアウト'),
(131740, 3506, 39, 'ログアウト'),
(131741, 3522, 39, '肺がん'),
(131742, 3523, 39, '肺がん外科手術'),
(131743, 3524, 39, '肺'),
(131744, 3525, 39, '肺'),
(131745, 3533, 39, 'メール送信済み'),
(131746, 3534, 39, 'メイン'),
(131747, 3535, 39, '主住所'),
(131748, 3548, 39, '男性'),
(131749, 3549, 39, '男性用コンドーム'),
(131750, 3552, 39, '乳房'),
(131751, 3561, 39, 'マニュアル'),
(131752, 3568, 39, '3月'),
(131753, 3576, 39, '結婚'),
(131754, 3582, 39, '該当'),
(131755, 3591, 39, '最大'),
(131756, 3603, 39, '5月'),
(131757, 3614, 39, '医療'),
(131758, 3617, 39, '医療受診'),
(131759, 3624, 39, '診察歴'),
(131760, 3625, 39, '診察歴'),
(131761, 3626, 39, '診察歴'),
(131762, 3627, 39, '診察歴'),
(131763, 3647, 39, '男性'),
(131764, 3648, 39, '男女'),
(131765, 3649, 39, '男性のみ'),
(131766, 3650, 39, '初潮'),
(131767, 3651, 39, '閉経'),
(131768, 3652, 39, '月経出血'),
(131769, 3653, 39, '月経頻度'),
(131770, 3654, 39, '精神障害'),
(131771, 3655, 39, 'メニューテキスト'),
(131772, 3656, 39, 'メニュー'),
(131773, 3657, 39, 'マージ'),
(131774, 3661, 39, 'メッセージ'),
(131775, 3665, 39, 'メッセージ送信'),
(131776, 3666, 39, 'メッセージ状況'),
(131777, 3667, 39, 'メッセージタイトル'),
(131778, 3668, 39, '患者へのメッセージ'),
(131779, 3670, 39, 'メッセージ:'),
(131780, 3671, 39, 'メッセージ'),
(131781, 3672, 39, '本日送信したメッセージ'),
(131782, 3677, 39, 'メキシコ人'),
(131783, 3679, 39, 'mg'),
(131784, 3680, 39, 'mg/1cc'),
(131785, 3681, 39, 'mg/2cc'),
(131786, 3682, 39, 'mg/3cc'),
(131787, 3683, 39, 'mg/4cc'),
(131788, 3684, 39, 'mg/5cc'),
(131789, 3685, 39, 'MG/DL'),
(131790, 3686, 39, '中間'),
(131791, 3687, 39, 'ミドルネーム'),
(131792, 3688, 39, 'ミドルネーム'),
(131793, 3701, 39, 'MIME Type'),
(131794, 3702, 39, 'MimeType'),
(131795, 3703, 39, '最小'),
(131796, 3704, 39, '最小'),
(131797, 3705, 39, '最低年齢'),
(131798, 3708, 39, '分'),
(131799, 3709, 39, '分'),
(131800, 3710, 39, '分'),
(131801, 3712, 39, 'その他'),
(131802, 3716, 39, 'その他'),
(131803, 3726, 39, '混合'),
(131804, 3727, 39, 'ml'),
(131805, 3728, 39, 'MM/DD/YYYY'),
(131806, 3729, 39, 'mm/hg'),
(131807, 3730, 39, 'mmHg'),
(131808, 3731, 39, 'MMR 1'),
(131809, 3732, 39, 'MMR 2'),
(131810, 3733, 39, '携帯'),
(131811, 3734, 39, '携帯電話番号'),
(131812, 3747, 39, 'モジュール'),
(131813, 3748, 39, 'モジュールディレクトリがありません'),
(131814, 3749, 39, 'モジュールインストーラー'),
(131815, 3750, 39, 'モジュール名'),
(131816, 3751, 39, 'モジュール名は既に使われています'),
(131817, 3752, 39, 'モジュール'),
(131818, 3753, 39, '月'),
(131819, 3754, 39, '月から金'),
(131820, 3755, 39, '月水金'),
(131821, 3756, 39, '月曜日'),
(131822, 3757, 39, 'モンゴル人'),
(131823, 3758, 39, '月'),
(131824, 3759, 39, '月'),
(131825, 3760, 39, '月表'),
(131826, 3761, 39, '月'),
(131827, 3762, 39, '月収'),
(131828, 3763, 39, '月'),
(131829, 3771, 39, '母親'),
(131830, 3772, 39, '母親の名前'),
(131831, 3774, 39, '口'),
(131832, 3775, 39, '移動'),
(131833, 3776, 39, '書類をカテゴリへ移動'),
(131834, 3777, 39, '下へ'),
(131835, 3778, 39, '移動不可'),
(131836, 3779, 39, '患者へ移動'),
(131837, 3780, 39, '移動中...'),
(131838, 3781, 39, '上へ'),
(131839, 3782, 39, '移動中...'),
(131840, 3783, 39, 'Mr.'),
(131841, 3785, 39, 'Mrs.'),
(131842, 3786, 39, 'Ms.'),
(131843, 3796, 39, '多言語ツール'),
(131844, 3810, 39, '筋肉'),
(131845, 3821, 39, '該当なし'),
(131846, 3822, 39, '該当なし'),
(131847, 3823, 39, '名前'),
(131848, 3826, 39, '名前１'),
(131849, 3827, 39, '名前２'),
(131850, 3831, 39, 'イベント名'),
(131851, 3833, 39, 'プロバイダ名'),
(131852, 3837, 39, '名前:'),
(131853, 3858, 39, 'ナビゲーションエリアの幅'),
(131854, 3866, 39, '首'),
(131855, 3867, 39, '首故障'),
(131856, 3873, 39, '要認証'),
(131857, 3874, 39, '要適合'),
(131858, 3875, 39, '要補助課金'),
(131859, 3876, 39, '否定'),
(131860, 3877, 39, '否定'),
(131861, 3879, 39, 'ネパール人'),
(131862, 3883, 39, '精神的虚脱'),
(131863, 3886, 39, '非アルコール'),
(131864, 3887, 39, '非喫煙'),
(131865, 3888, 39, '新規'),
(131866, 3901, 39, '新規書類'),
(131867, 3902, 39, '新規書類'),
(131868, 3904, 39, '新規来院者'),
(131869, 3905, 39, '新規来院者(ID付与済み)'),
(131870, 3906, 39, '新規来院者フォーム'),
(131871, 3907, 39, '新規来院者非認定'),
(131872, 3909, 39, '新施術院情報'),
(131873, 3910, 39, '新規ファイル'),
(131874, 3911, 39, '新規ファイル'),
(131875, 3912, 39, '新規グループ'),
(131876, 3913, 39, '新規グループ情報'),
(131877, 3917, 39, '新規リスト'),
(131878, 3918, 39, '新規注文'),
(131879, 3919, 39, '新規パラグラフ'),
(131880, 3920, 39, '新規パスワード'),
(131881, 3921, 39, '新規患者'),
(131882, 3922, 39, '新規患者'),
(131883, 3923, 39, '新規患者来院者'),
(131884, 3924, 39, '新規患者フォーム'),
(131885, 3925, 39, '新規患者ID'),
(131886, 3926, 39, '新規支払'),
(131887, 3930, 39, '新規検索'),
(131888, 3932, 39, '新規ユーザー'),
(131889, 3933, 39, '新規値'),
(131890, 3934, 39, '新規訪問'),
(131891, 3935, 39, '新規/検索'),
(131892, 3962, 39, '次'),
(131893, 3964, 39, '翌月'),
(131894, 3965, 39, '来月'),
(131895, 3968, 39, '翌週'),
(131896, 3970, 39, 'ニックネーム'),
(131897, 3971, 39, 'ニックネーム'),
(131898, 3973, 39, '夜汗'),
(131899, 3975, 39, 'いいえ'),
(131900, 3976, 39, 'いいえ'),
(131901, 3977, 39, 'ノーアクセス'),
(131902, 3978, 39, '有効な患者の予定はありません'),
(131903, 3983, 39, '予約はありません'),
(131904, 3997, 39, 'エラーはありません'),
(131905, 3998, 39, 'イベントはありません'),
(131906, 4001, 39, 'グループが選択されていません'),
(131907, 4002, 39, 'ヘルニア無し'),
(131908, 4006, 39, '保険会社がありません'),
(131909, 4007, 39, '問題ありません'),
(131910, 4008, 39, 'この来院では問題ありません'),
(131911, 4009, 39, '選択されたカテゴリにはアイテムがありません'),
(131912, 4010, 39, 'アイテムが選択されていません'),
(131913, 4024, 39, 'ラボデータ書類がありません'),
(131914, 4025, 39, '選択日にはログファイルがありません'),
(131915, 4029, 39, '該当がありません。もう一度'),
(131916, 4030, 39, '該当がありませんでした。'),
(131917, 4031, 39, '該当がありません。新規患者を作成しますか？'),
(131918, 4032, 39, '一致するレコードがありません'),
(131919, 4033, 39, '新規レザルトがありません'),
(131920, 4034, 39, 'ノートがありません'),
(131921, 4038, 39, 'パラメーターが選択されていません'),
(131922, 4039, 39, 'パートナーがみつかりません'),
(131923, 4040, 39, '選択された抽出設定では患者記録がありません'),
(131924, 4041, 39, '設定された識別コードでは患者記録がありません'),
(131925, 4043, 39, '調剤薬局がありません'),
(131926, 4046, 39, '前のエントリーがありません'),
(131927, 4053, 39, 'レコードがありません'),
(131928, 4055, 39, 'レコードがありません。抽出範囲を拡大してください'),
(131929, 4056, 39, 'リマインダーがありません'),
(131930, 4057, 39, '指定された抽出条件ではリザルトがありません'),
(131931, 4058, 39, 'リザルトがありません'),
(131932, 4059, 39, 'リザルトがありませんでした'),
(131933, 4060, 39, '検索からはリザルトがありません'),
(131934, 4061, 39, 'リザルトがありません。もう一度'),
(131935, 4062, 39, 'リザルトがありません。もう一度'),
(131936, 4063, 39, 'リザルトがありません。もう一度'),
(131937, 4064, 39, 'このモジュールには設定がありません'),
(131938, 4066, 39, 'ファイルに署名がありません'),
(131939, 4069, 39, 'コンテキスト名がありません'),
(131940, 4070, 39, 'テーブルが選択されていません。テーブルを選択してください'),
(131941, 4073, 39, 'トラックがしていされていません'),
(131942, 4074, 39, 'トラックは書面化されていません'),
(131943, 4075, 39, '訪問無し'),
(131944, 4076, 39, 'バイタルは書面化されていません'),
(131945, 4077, 39, 'キャンセル'),
(131946, 4079, 39, 'いいえ'),
(131947, 4081, 39, '未払い'),
(131948, 4089, 39, '無し'),
(131949, 4090, 39, '無し'),
(131950, 4091, 39, '指定なし'),
(131951, 4092, 39, '書面化されていません'),
(131952, 4093, 39, '以降はありません'),
(131953, 4097, 39, '普通'),
(131954, 4108, 39, '普通:'),
(131955, 4112, 39, 'ノルウェー人'),
(131956, 4115, 39, '鼻'),
(131957, 4120, 39, '未許可'),
(131958, 4121, 39, '管理者グループへは削除は許可されていません'),
(131959, 4122, 39, '編集は許可されていません'),
(131960, 4129, 39, '許可されていません'),
(131961, 4130, 39, '許可されていません'),
(131962, 4133, 39, 'ユーザー管理を許可されていません'),
(131963, 4135, 39, 'ありません'),
(131964, 4137, 39, '支払われていません'),
(131965, 4146, 39, '見つかりません'),
(131966, 4148, 39, '見つかりません!'),
(131967, 4149, 39, 'ヒスパニックまたはラテン系ではありません'),
(131968, 4150, 39, 'インストールされていません'),
(131969, 4151, 39, 'インストールされていません'),
(131970, 4153, 39, '送信されていません'),
(131971, 4155, 39, '指定されていません'),
(131972, 4156, 39, '指定されていません'),
(131973, 4181, 39, '表示するものがありません'),
(131974, 4185, 39, '通知'),
(131975, 4186, 39, '通知先電子メールアドレス'),
(131976, 4188, 39, '通知'),
(131977, 4190, 39, '11月'),
(131978, 4191, 39, '11月'),
(131979, 4193, 39, '印刷中'),
(131980, 4200, 39, '番号'),
(131981, 4240, 39, '10月'),
(131982, 4241, 39, '10月'),
(131983, 4267, 39, 'OK'),
(131984, 4268, 39, 'ポップアップウインドウを閉じますか？'),
(131985, 4270, 39, '古い'),
(131986, 4276, 39, 'オーダー'),
(131987, 4277, 39, '省略'),
(131988, 4297, 39, 'オンラインサポート'),
(131989, 4298, 39, 'オンラインサポートリンク'),
(131990, 4304, 39, '自分のみ'),
(131991, 4315, 39, 'なんてことだ！'),
(131992, 4316, 39, '開く'),
(131993, 4318, 39, '新規ウインドウで開く'),
(131994, 4319, 39, '新規患者'),
(131995, 4321, 39, '今日の訪問先を開く'),
(131996, 4324, 39, 'LibreEHRデータベースアップグレード'),
(131997, 4329, 39, 'LibreEHRユーザー'),
(131998, 4333, 39, 'オプション'),
(131999, 4347, 39, 'オプション: 患者ID番号'),
(132000, 4350, 39, 'オプション'),
(132001, 4352, 39, 'OR'),
(132002, 4353, 39, 'または選択'),
(132003, 4362, 39, '注文'),
(132004, 4364, 39, '注文カタログ'),
(132005, 4365, 39, '注文日'),
(132006, 4366, 39, '注文概要'),
(132007, 4367, 39, '注文フォーム'),
(132008, 4368, 39, '注文ID'),
(132009, 4370, 39, '注文名'),
(132010, 4371, 39, '注文優先度'),
(132011, 4373, 39, '注文結果'),
(132012, 4374, 39, '注文状況'),
(132013, 4376, 39, '注文歴'),
(132014, 4377, 39, '注文トラック'),
(132015, 4378, 39, '注文タイプ'),
(132016, 4380, 39, '注文/結果タイプ'),
(132017, 4381, 39, '注文済み'),
(132018, 4382, 39, '注文者'),
(132019, 4387, 39, '組織'),
(132020, 4388, 39, '組織名'),
(132021, 4389, 39, '組織団体名'),
(132022, 4390, 39, '書式'),
(132023, 4392, 39, 'オリジナル'),
(132024, 4393, 39, 'オリジナルチェックサム'),
(132025, 4403, 39, 'その他'),
(132026, 4425, 39, 'オフィス外(外回り)'),
(132027, 4427, 39, '転帰'),
(132028, 4428, 39, 'Outlook'),
(132029, 4445, 39, 'ページ'),
(132030, 4447, 39, '支払済み'),
(132031, 4450, 39, '支払手段'),
(132032, 4451, 39, '病状'),
(132033, 4453, 39, '動悸'),
(132034, 4456, 39, '用紙'),
(132035, 4457, 39, '用紙サイズ'),
(132036, 4459, 39, '両親'),
(132037, 4463, 39, 'パートナー'),
(132038, 4464, 39, 'パートナー名'),
(132039, 4467, 39, '暗号文字列'),
(132040, 4468, 39, '書類暗号解除用暗号文字列'),
(132041, 4469, 39, '許諾済み患者'),
(132042, 4472, 39, 'パスワード'),
(132043, 4473, 39, 'パスワード変更'),
(132044, 4474, 39, 'パスワードは変更されました'),
(132045, 4475, 39, 'パスワードは変更されました'),
(132046, 4480, 39, 'SMS Gateway の為のパスワード'),
(132047, 4481, 39, 'SMS Gateway の為のパスワード'),
(132048, 4483, 39, 'パスワード保護は正常にアップグレードされました'),
(132049, 4485, 39, 'パスワードは8文字以上で設定してください'),
(132050, 4486, 39, 'パスワード:'),
(132051, 4487, 39, 'パスワードが一致していません'),
(132052, 4490, 39, '期日経過'),
(132053, 4491, 39, '期日経過'),
(132054, 4508, 39, 'Path for Event Log Backup'),
(132055, 4509, 39, 'Path to CA Certificate File'),
(132056, 4510, 39, 'Path to CA Key File'),
(132057, 4511, 39, 'Path to MySQL Binaries'),
(132058, 4512, 39, 'Path to Perl Binaries'),
(132059, 4513, 39, 'Path to Temporary Files'),
(132060, 4514, 39, '患者'),
(132061, 4515, 39, '患者'),
(132062, 4516, 39, '患者'),
(132063, 4517, 39, '患者の住所'),
(132064, 4518, 39, '患者の住所が未指定です'),
(132065, 4521, 39, '患者のアレルギー'),
(132066, 4522, 39, '患者のアレルギー'),
(132067, 4523, 39, '患者の予約'),
(132068, 4531, 39, '患者の所在市'),
(132069, 4532, 39, '患者の所在市がありません'),
(132070, 4534, 39, '患者の所在国'),
(132071, 4539, 39, '患者の来院日'),
(132072, 4541, 39, '患者の誕生日がありません'),
(132073, 4542, 39, '患者詳細'),
(132074, 4543, 39, '患者の誕生日'),
(132075, 4544, 39, '患者の書類'),
(132076, 4545, 39, '患者の学歴'),
(132077, 4550, 39, '患者検索'),
(132078, 4551, 39, '患者の名'),
(132079, 4553, 39, '患者名がありません'),
(132080, 4558, 39, '患者の性別'),
(132081, 4559, 39, '患者の性別がありません'),
(132082, 4561, 39, '患者の往診履歴'),
(132083, 4562, 39, '患者の履歴/ライフスタイル'),
(132084, 4563, 39, '患者の自宅電話番号'),
(132085, 4564, 39, '患者ID'),
(132086, 4565, 39, '患者ID'),
(132087, 4566, 39, '患者IDカード'),
(132088, 4567, 39, '患者IDカードカテゴリ名'),
(132089, 4569, 39, '患者情報'),
(132090, 4573, 39, '患者病状'),
(132091, 4575, 39, '患者姓'),
(132092, 4577, 39, '患者の姓がありません'),
(132093, 4581, 39, '患者リスト'),
(132094, 4589, 39, '患者姓名'),
(132095, 4590, 39, '患者姓名と住所'),
(132096, 4593, 39, '患者の姓名が必要です'),
(132097, 4595, 39, '患者ノート'),
(132098, 4596, 39, '患者ノートタイプ'),
(132099, 4597, 39, '患者ノート'),
(132100, 4598, 39, '患者ノート(追記のみ)'),
(132101, 4599, 39, '患者番号'),
(132102, 4624, 39, '患者検索結果スタイル'),
(132103, 4634, 39, '患者:'),
(132104, 4635, 39, '患者ID'),
(132105, 4636, 39, '患者一覧'),
(132106, 4648, 39, '支払'),
(132107, 4671, 39, 'PDFの言語'),
(132108, 4674, 39, '保留中'),
(132109, 4710, 39, 'ペルシャ人'),
(132110, 4711, 39, 'ペルシャ人'),
(132111, 4712, 39, '個人'),
(132112, 4713, 39, '個人化'),
(132113, 4715, 39, '薬学'),
(132114, 4717, 39, '調剤薬局'),
(132115, 4718, 39, '調剤薬局'),
(132116, 4729, 39, '電話'),
(132117, 4730, 39, '通話履歴リスト'),
(132118, 4731, 39, '通話履歴リスト'),
(132119, 4732, 39, '電話番号'),
(132120, 4733, 39, '電話ゲートウェイパスワード'),
(132121, 4734, 39, '電話ゲートウェイURL'),
(132122, 4735, 39, '電話ゲートウェイユーザー名'),
(132123, 4736, 39, '自宅番号'),
(132124, 4738, 39, '電話番号'),
(132125, 4739, 39, '電話番号'),
(132126, 4740, 39, '写真恐怖症'),
(132127, 4741, 39, '写真'),
(132128, 4742, 39, 'PHP圧縮済'),
(132129, 4743, 39, 'PHP CURL モジュールを有効にしてください'),
(132130, 4744, 39, 'PHP 展開済み'),
(132131, 4746, 39, 'PHP-gaclはインストールされていません'),
(132132, 4752, 39, '医師'),
(132133, 4759, 39, '錠剤'),
(132134, 4767, 39, 'プレーンテキスト'),
(132135, 4768, 39, 'プラン'),
(132136, 4771, 39, 'プラン名'),
(132137, 4779, 39, 'プラン:'),
(132138, 4782, 39, 'プラン'),
(132139, 4787, 39, 'パスワードを変更してください'),
(132140, 4788, 39, 'ファイルを選択してください'),
(132141, 4789, 39, '患者を選択してください'),
(132142, 4790, 39, 'リストから正しい選択をしてください'),
(132143, 4791, 39, '正しい選択をしてください'),
(132144, 4792, 39, '正しい値を選んでください'),
(132145, 4797, 39, 'ウインドウを閉じてください'),
(132146, 4798, 39, '新規名称を比較してください'),
(132147, 4800, 39, '処理前に値を直してください'),
(132148, 4801, 39, '処理前にディレクトリを作成してください'),
(132149, 4805, 39, 'CURL拡張を有効にしてください'),
(132150, 4806, 39, 'OPENSSL拡張を有効にしてください'),
(132151, 4807, 39, 'SOAP拡張を有効にしてください'),
(132152, 4808, 39, 'XML拡張を有効にしてください'),
(132153, 4810, 39, '日付を入力してください'),
(132154, 4812, 39, 'メッセージを入力してください'),
(132155, 4814, 39, '新規パスワードを入力してください'),
(132156, 4815, 39, 'タイトルを入力してください'),
(132157, 4816, 39, '正確な住所を入力してください'),
(132158, 4817, 39, 'アイテム名をもう少し入力してください'),
(132159, 4818, 39, 'トラック名をもう少し入力してください'),
(132160, 4820, 39, '終了日は開始日以後に設定してください'),
(132161, 4821, 39, '新規検索文字列を入力してください'),
(132162, 4823, 39, '新規パスワードを入力してください'),
(132163, 4824, 39, 'チェック番号を入力してください'),
(132164, 4826, 39, '日付を入力してください'),
(132165, 4827, 39, '支払合計を入力してください'),
(132166, 4828, 39, '支払カテゴリを入力してください'),
(132167, 4829, 39, '支払元を入力してください'),
(132168, 4836, 39, '再ログインしてください'),
(132169, 4839, 39, 'アルファベットのみです'),
(132170, 4840, 39, '空白無しのアルファベットのみです'),
(132171, 4841, 39, 'この合計額を支払ってください'),
(132172, 4842, 39, 'インストールファイルを指定のディレクトリに設置してください'),
(132173, 4844, 39, 'パスワードをリセットしてください'),
(132174, 4847, 39, '選択してください'),
(132175, 4849, 39, '言語を選択してください'),
(132176, 4850, 39, '患者を選択してください'),
(132177, 4854, 39, '受領者を選択してください'),
(132178, 4855, 39, '開始日と終了日を選択してください'),
(132179, 4857, 39, 'アクティブグループを選択'),
(132180, 4859, 39, 'イベントを選択してください'),
(132181, 4881, 39, '複数'),
(132182, 4882, 39, '午後'),
(132183, 4886, 39, 'Pneumococcal Conjugate 1'),
(132184, 4887, 39, 'Pneumococcal Conjugate 2'),
(132185, 4888, 39, 'Pneumococcal Conjugate 3'),
(132186, 4889, 39, 'Pneumococcal Conjugate 4'),
(132187, 4897, 39, 'ポリシー'),
(132188, 4898, 39, 'ポリシー番号'),
(132189, 4899, 39, 'ポリシー番号'),
(132190, 4900, 39, 'ポーランド人'),
(132191, 4909, 39, 'ポップアップ'),
(132192, 4910, 39, 'ポータル'),
(132193, 4912, 39, 'ポータルID'),
(132194, 4913, 39, 'ポータルIDは要求されたポータルと一致しません'),
(132195, 4914, 39, 'ポータルパスワードがありません'),
(132196, 4915, 39, 'ポータルリクエスト'),
(132197, 4916, 39, '縦向き'),
(132198, 4917, 39, 'ポルトガル人'),
(132199, 4918, 39, 'ブラジル人'),
(132200, 4919, 39, 'ポルトガル人(ヨーロッパ系)'),
(132201, 4920, 39, 'POS Code'),
(132202, 4921, 39, '位置'),
(132203, 4922, 39, 'ポジティブ'),
(132204, 4923, 39, 'ポジティブ'),
(132205, 4925, 39, '投函先'),
(132206, 4937, 39, '郵便'),
(132207, 4938, 39, '郵便番号'),
(132208, 4939, 39, '郵便番号'),
(132209, 4946, 39, '投函日'),
(132210, 4948, 39, 'Powered by'),
(132211, 4953, 39, '教練'),
(132212, 4954, 39, '教練基本設定'),
(132213, 4955, 39, '教練設定'),
(132214, 4956, 39, '教練者'),
(132215, 4958, 39, '先払い'),
(132216, 4963, 39, '設定'),
(132217, 4964, 39, '設定'),
(132218, 4965, 39, '優先するイベントカテゴリー'),
(132219, 4966, 39, '優先する言語'),
(132220, 4967, 39, '優先する薬局'),
(132221, 4972, 39, '前納'),
(132222, 4973, 39, '処方'),
(132223, 4974, 39, '処方箋は、その上限に達しています'),
(132224, 4975, 39, '処方履歴'),
(132225, 4976, 39, '処方履歴のインポートが正常に完了しました'),
(132226, 4977, 39, '調剤ラベル'),
(132227, 4978, 39, '処方レポート'),
(132228, 4979, 39, '処方箋'),
(132229, 4983, 39, '処方箋レポート'),
(132230, 4984, 39, '処方箋/紹介'),
(132231, 4985, 39, 'プレゼント'),
(132232, 5001, 39, '前'),
(132233, 5061, 39, '印刷表示'),
(132234, 5062, 39, '印刷可能'),
(132235, 5063, 39, '印刷可能表示'),
(132236, 5114, 39, '処置'),
(132237, 5205, 39, '肺'),
(132238, 5206, 39, '脈拍'),
(132239, 5207, 39, 'パンジャブ語'),
(132240, 5208, 39, '購入'),
(132241, 5209, 39, '購入/戻ります'),
(132242, 5210, 39, '購入'),
(132243, 5245, 39, '人種'),
(132244, 5246, 39, '人種と民族'),
(132245, 5247, 39, '人種/民族'),
(132246, 5248, 39, 'ラジオ'),
(132247, 5249, 39, 'ラジオボタン'),
(132248, 5251, 39, '宗教'),
(132249, 5363, 39, '更新'),
(132250, 5369, 39, '登録'),
(132251, 5370, 39, '登録'),
(132252, 5371, 39, '登録されました'),
(132253, 5372, 39, '登録されました'),
(132254, 5373, 39, '登録されているモジュール'),
(132255, 5374, 39, '登録日'),
(132256, 5375, 39, '登録フォーム'),
(132257, 5376, 39, 'リハビリテーション'),
(132258, 5377, 39, '拒否'),
(132259, 5379, 39, '再発の可能性'),
(132260, 5381, 39, '関連'),
(132261, 5382, 39, '関連問題'),
(132262, 5383, 39, '関連患者の注意事項'),
(132263, 5409, 39, 'リマインダー'),
(132264, 5413, 39, 'リマインダー'),
(132265, 5426, 39, '腎臓結石'),
(132266, 5427, 39, '名前変更'),
(132267, 5428, 39, 'グループ名変更'),
(132268, 5429, 39, 'レンダリング'),
(132269, 5430, 39, 'レンダリングプロバイダ'),
(132270, 5431, 39, 'レンダリングプロバイダー数'),
(132271, 5432, 39, '並べ替え'),
(132272, 5446, 39, 'レポート'),
(132273, 5457, 39, 'レポートステータス'),
(132274, 5475, 39, '強いパスワードが必須です'),
(132275, 5476, 39, 'ユニークなパスワードが必須です'),
(132276, 5477, 39, '必須'),
(132277, 5491, 39, 'リセット'),
(132278, 5584, 39, '医療用医薬品'),
(132279, 5585, 39, '医療用医薬品'),
(132280, 5605, 39, '販売'),
(132281, 5606, 39, '販売'),
(132282, 5607, 39, 'アイテム別売上高'),
(132283, 5608, 39, '製品別売上高レポート'),
(132284, 5609, 39, '唾液'),
(132285, 5610, 39, '同日'),
(132286, 5611, 39, 'サモア語'),
(132287, 5612, 39, 'サンプル'),
(132288, 5616, 39, 'サルデーニャ語'),
(132289, 5619, 39, '土曜日'),
(132290, 5620, 39, '保存'),
(132291, 5621, 39, '保存'),
(132292, 5622, 39, '保存して閉じる'),
(132293, 5627, 39, '新規ノートとして保存'),
(132294, 5633, 39, '新規グループを保存'),
(132295, 5634, 39, '新規名称リストを保存'),
(132296, 5635, 39, '新規テンプレート保存'),
(132297, 5640, 39, '保存成功しました'),
(132298, 5641, 39, 'スキャン'),
(132299, 5643, 39, 'スキャナのディレクトリ'),
(132300, 5645, 39, 'スケジュール'),
(132301, 5659, 39, '検索'),
(132302, 5669, 39, '患者検索・追加'),
(132303, 5671, 39, '検索結果'),
(132304, 5672, 39, '検索結果：'),
(132305, 5676, 39, '検索テキスト'),
(132306, 5678, 39, '検索/追加'),
(132307, 5680, 39, '予定検索'),
(132308, 5681, 39, '検索中...'),
(132309, 5698, 39, 'セキュリティ'),
(132310, 5699, 39, '全て見る'),
(132311, 5709, 39, '選択'),
(132312, 5710, 39, '選択'),
(132313, 5716, 39, 'すべて選択'),
(132314, 5720, 39, 'カテゴリ選択'),
(132315, 5724, 39, 'CSVテーブル選択'),
(132316, 5731, 39, '薬剤選択'),
(132317, 5732, 39, '薬剤選択'),
(132318, 5736, 39, 'フィールド選択'),
(132319, 5737, 39, 'フィールド選択'),
(132320, 5744, 39, '言語選択'),
(132321, 5748, 39, '出力選択'),
(132322, 5752, 39, 'ソース選択'),
(132323, 5753, 39, 'テンプレート選択'),
(132324, 5771, 39, '送信'),
(132325, 5775, 39, '送信メッセージ'),
(132326, 5784, 39, '全てに送信'),
(132327, 5788, 39, '送信者'),
(132328, 5789, 39, '送信者ＩＤ'),
(132329, 5801, 39, '送信日'),
(132330, 5814, 39, '9月'),
(132331, 5821, 39, 'サービス'),
(132332, 5822, 39, 'サービスカテゴリ'),
(132333, 5823, 39, 'サービスコード'),
(132334, 5825, 39, 'サービスコード'),
(132335, 5830, 39, 'サービス名'),
(132336, 5832, 39, 'サービスレポート'),
(132337, 5833, 39, 'サービスレポートのみ'),
(132338, 5834, 39, 'サービス'),
(132339, 5839, 39, 'セッションタイプ'),
(132340, 5849, 39, '設定'),
(132341, 5855, 39, '性別'),
(132342, 5877, 39, '表示'),
(132343, 5880, 39, '全て表示'),
(132344, 5889, 39, '詳細表示'),
(132345, 5891, 39, 'グラフを表示'),
(132346, 5896, 39, 'メニューを表示'),
(132347, 5898, 39, 'ノートを表示'),
(132348, 5901, 39, '患者ノートを表示'),
(132349, 5905, 39, 'リマインダーを表示'),
(132350, 5906, 39, 'レポートを表示'),
(132351, 5912, 39, 'タスク履歴表示'),
(132352, 5914, 39, 'USのみ表示'),
(132353, 5956, 39, 'サイズ'),
(132354, 5976, 39, '喫煙状態'),
(132355, 5977, 39, 'SMS認証'),
(132356, 5978, 39, 'SMSゲートウェイ'),
(132357, 5981, 39, 'SMSゲートウェイパスワード'),
(132358, 5982, 39, 'SMSゲートウェイユーザ名'),
(132359, 5983, 39, 'SMS通知'),
(132360, 5989, 39, 'SMTP認証パスワード'),
(132361, 5992, 39, 'SMTPサーバーホスト名'),
(132362, 5993, 39, 'SMTPサーバーポート番号'),
(132363, 5994, 39, 'SMTP認証ユーザー'),
(132364, 6034, 39, '日付順でソート'),
(132365, 6036, 39, 'イベント順でソート'),
(132366, 6037, 39, 'グループ順でソート'),
(132367, 6040, 39, '患者番号順でソート'),
(132368, 6043, 39, 'ユーザー順でソート'),
(132369, 6048, 39, 'ソース'),
(132370, 6049, 39, 'ソースファイル'),
(132371, 6050, 39, 'ソースファイルパス'),
(132372, 6054, 39, '感染患者'),
(132373, 6060, 39, 'スペース'),
(132374, 6088, 39, '検体'),
(132375, 6089, 39, '検体番号/識別子'),
(132376, 6090, 39, '検体の種類'),
(132377, 6092, 39, '音声ディクテーション'),
(132378, 6093, 39, '殺精子剤'),
(132379, 6094, 39, '脾臓摘出術'),
(132380, 6095, 39, '配偶者'),
(132381, 6096, 39, '配偶者の歴史'),
(132382, 6097, 39, '喀痰'),
(132383, 6098, 39, '喀痰:'),
(132384, 6100, 39, 'sql'),
(132385, 6102, 39, '分隊'),
(132386, 6103, 39, '分隊会員'),
(132387, 6104, 39, '分隊'),
(132388, 6124, 39, '開始'),
(132389, 6125, 39, '開始(yyyy-mm-dd): '),
(132390, 6128, 39, '開始日'),
(132391, 6131, 39, '開始日:'),
(132392, 6132, 39, '開始日:'),
(132393, 6133, 39, '開始時刻:'),
(132394, 6153, 39, 'ステータス'),
(132395, 6173, 39, '停止'),
(132396, 6177, 39, '通り'),
(132397, 6187, 39, 'スタイル'),
(132398, 6240, 39, '成功'),
(132399, 6241, 39, '成功'),
(132400, 6248, 39, '削除成功'),
(132401, 6252, 39, '更新成功'),
(132402, 6256, 39, '格納成功。'),
(132403, 6257, 39, 'データベースのアップグレード成功しました。'),
(132404, 6261, 39, '概要'),
(132405, 6267, 39, '日曜日'),
(132406, 6275, 39, 'スーパーユーザー'),
(132407, 6297, 39, 'スワヒリ語'),
(132408, 6298, 39, 'スワティ'),
(132409, 6299, 39, '発汗：'),
(132410, 6300, 39, 'スウェーデン語'),
(132411, 6301, 39, 'むくみ'),
(132412, 6302, 39, '右の膨潤'),
(132413, 6303, 39, '腫脹関節'),
(132414, 6304, 39, '腫れたリンパ節'),
(132415, 6305, 39, '通貨の小数点として使用する記号。小数点以下の桁数が0の場合は使用されません。'),
(132416, 6318, 39, 'システム'),
(132417, 6325, 39, 'テーブル'),
(132418, 6363, 39, '電話'),
(132419, 6364, 39, '電話国コード'),
(132420, 6370, 39, 'テンプレート'),
(132421, 6371, 39, 'テンプレート名'),
(132422, 6373, 39, 'テンプレート：'),
(132423, 6374, 39, 'テンプレート'),
(132424, 6383, 39, 'テストスケジューリング'),
(132425, 6384, 39, 'テストシステム'),
(132426, 6385, 39, 'テキスト'),
(132427, 6387, 39, 'テキストフィールド'),
(132428, 6401, 39, 'タイ'),
(132429, 6402, 39, 'ありがとう'),
(132430, 6493, 39, 'テーマ'),
(132431, 6629, 39, '木'),
(132432, 6631, 39, '木曜日'),
(132433, 6632, 39, '正常甲状腺'),
(132434, 6633, 39, '甲状腺の問題'),
(132435, 6652, 39, 'タイトル'),
(132436, 6659, 39, '宛先'),
(132437, 6661, 39, '強制 ファイルパス'),
(132438, 6662, 39, 'ノート追記 '),
(132439, 6663, 39, 'ここでノートを追記'),
(132440, 6667, 39, '領収書表示へ'),
(132441, 6668, 39, 'カテゴリーへ'),
(132442, 6680, 39, '性別でフィルター'),
(132443, 6681, 39, '履歴へ'),
(132444, 6682, 39, '問題へ'),
(132445, 6708, 39, 'タバコ'),
(132446, 6711, 39, '喫煙'),
(132447, 6712, 39, '喫煙'),
(132448, 6715, 39, '今日'),
(132449, 6716, 39, '本日'),
(132450, 6717, 39, '本日'),
(132451, 6729, 39, '上マージン (mm)'),
(132452, 6731, 39, '合計'),
(132453, 6732, 39, '合計'),
(132454, 6741, 39, '合計料金'),
(132455, 6742, 39, '合計クライアント'),
(132456, 6743, 39, '総費用'),
(132457, 6807, 39, 'アクセス制御グループを翻訳'),
(132458, 6808, 39, '予定カテゴリを翻訳'),
(132459, 6809, 39, 'ドキュメントカテゴリを翻訳'),
(132460, 6810, 39, 'レイアウトを翻訳'),
(132461, 6811, 39, 'リストを翻訳'),
(132462, 6812, 39, '患者のノートタイトルを翻訳'),
(132463, 6813, 39, 'これを翻訳します'),
(132464, 6814, 39, '翻訳'),
(132465, 6815, 39, '翻訳'),
(132466, 6816, 39, '送信します'),
(132467, 6817, 39, '送信に失敗しました'),
(132468, 6818, 39, '選択した注文を送信'),
(132469, 6819, 39, '外傷'),
(132470, 6820, 39, '目標'),
(132471, 6822, 39, '目標ゴール'),
(132472, 6823, 39, '目標プラン'),
(132473, 6824, 39, '目標プランニング'),
(132474, 6825, 39, '目標を受理'),
(132475, 6826, 39, '目標'),
(132476, 6827, 39, '目標 '),
(132477, 6828, 39, '傾向'),
(132478, 6843, 39, '火曜日'),
(132479, 6844, 39, '腫瘍'),
(132480, 6845, 39, 'トルコ語'),
(132481, 6846, 39, 'トルクメン語'),
(132482, 6847, 39, '監督者訓練'),
(132483, 6848, 39, '1日2回'),
(132484, 6850, 39, '鼓膜'),
(132485, 6851, 39, 'タイプ'),
(132486, 6869, 39, 'ディレクトリにアクセスすることができません'),
(132487, 6870, 39, 'URLにアクセスすることができません'),
(132488, 6871, 39, '作成することができません'),
(132489, 6872, 39, '患者文書サブディレクトリを作成することができません'),
(132490, 6873, 39, 'このファイル内のデータを見つけることができません。'),
(132491, 6876, 39, '未申請'),
(132492, 6877, 39, '未割当'),
(132493, 6878, 39, '不認定'),
(132494, 6880, 39, '認証されていないアクセス'),
(132495, 6881, 39, '未払い'),
(132496, 6882, 39, '未払いのみ'),
(132497, 6884, 39, '舌下'),
(132498, 6885, 39, '低体重'),
(132499, 6886, 39, '未診断'),
(132500, 6887, 39, '未分配'),
(132501, 6888, 39, '分配されていません'),
(132502, 6889, 39, '未分配は、'),
(132503, 6890, 39, 'チェックアウトを元に戻します'),
(132504, 6892, 39, 'ユニーククライアント'),
(132505, 6894, 39, 'ユニークな新しいクライアント'),
(132506, 6895, 39, 'このタイプのユニークなの数値識別子'),
(132507, 6896, 39, 'ユニーク見た患者'),
(132508, 6897, 39, 'ユニーク見患者報告'),
(132509, 6898, 39, 'ユニークSP'),
(132510, 6899, 39, 'ユニット'),
(132511, 6900, 39, '単位'),
(132512, 6907, 39, '不明'),
(132513, 6911, 39, '不明　または無し'),
(132514, 6912, 39, '不明なユーザーID：'),
(132515, 6913, 39, '患者のリンクを解除'),
(132516, 6915, 39, '未登録'),
(132517, 6916, 39, '未登録のモジュール'),
(132518, 6918, 39, 'すべて選択解除'),
(132519, 6919, 39, '選択されていません'),
(132520, 6920, 39, '特定されていません'),
(132521, 6921, 39, '体系化されていません'),
(132522, 6922, 39, 'サポートされていないデータベース・ロード・ファイル'),
(132523, 6926, 39, '未使用'),
(132524, 6931, 39, 'アップデート'),
(132525, 6932, 39, 'アップデート'),
(132526, 6934, 39, 'ファイル更新'),
(132527, 6935, 39, 'インフォ更新'),
(132528, 6936, 39, 'リスト更新'),
(132529, 6937, 39, 'プロバイダー番号更新'),
(132530, 6938, 39, '選択アイテム更新'),
(132531, 6940, 39, 'ユーザー情報更新'),
(132532, 6942, 39, '更新したデモ画像は認証されていません'),
(132533, 6943, 39, 'グローバル設定を更新しました'),
(132534, 6944, 39, 'バージョン判別を更新しました'),
(132535, 6945, 39, 'アップグレード'),
(132536, 6946, 39, 'アップグレード'),
(132537, 6947, 39, 'データベースアップグレード'),
(132538, 6951, 39, 'アップロード'),
(132539, 6953, 39, 'アップロードしてインストール'),
(132540, 6955, 39, 'ドキュメントアップロード'),
(132541, 6956, 39, 'アップロード失敗！'),
(132542, 6961, 39, 'アップロードレポート'),
(132543, 6966, 39, '上腕'),
(132544, 6967, 39, 'ウルドゥー語'),
(132545, 6968, 39, '緊急'),
(132546, 6970, 39, '尿'),
(132547, 6972, 39, '尿頻度'),
(132548, 6977, 39, 'URL'),
(132549, 7007, 39, 'ユーザーネーム'),
(132550, 7009, 39, 'ユーザー／グループ'),
(132551, 7010, 39, 'ユーザー管理'),
(132552, 7013, 39, 'ユーザーを削除できません'),
(132553, 7014, 39, 'ユーザー認証を禁止します'),
(132554, 7015, 39, 'ユーザー任意'),
(132555, 7016, 39, 'ユーザー任意エリア 11'),
(132556, 7017, 39, 'ユーザー任意エリア 12'),
(132557, 7018, 39, 'ユーザー任意フィールド'),
(132558, 7019, 39, 'ユーザー任意リスト 1'),
(132559, 7020, 39, 'ユーザー任意リスト 2'),
(132560, 7021, 39, 'ユーザー任意リスト 3'),
(132561, 7022, 39, 'ユーザー任意リスト 4'),
(132562, 7023, 39, 'ユーザー任意リスト 5'),
(132563, 7024, 39, 'ユーザー任意リスト 6'),
(132564, 7025, 39, 'ユーザー任意リスト 7'),
(132565, 7026, 39, 'ユーザー任意テキスト 1'),
(132566, 7027, 39, 'ユーザー任意テキスト 2'),
(132567, 7028, 39, 'ユーザー任意テキスト 3'),
(132568, 7029, 39, 'ユーザー任意テキスト 4'),
(132569, 7030, 39, 'ユーザー任意テキスト 5'),
(132570, 7031, 39, 'ユーザー任意テキスト 6'),
(132571, 7032, 39, 'ユーザー任意テキスト 7'),
(132572, 7033, 39, 'ユーザー任意テキスト 8'),
(132573, 7034, 39, '名'),
(132574, 7039, 39, 'ユーザーマニュアル'),
(132575, 7040, 39, 'ユーザー会員規約'),
(132576, 7041, 39, 'ユーザーネーム'),
(132577, 7042, 39, 'ユーザーまたはホスト名は空白にできません'),
(132578, 7043, 39, 'ユーザーまたはホスト名'),
(132579, 7046, 39, 'ユーザー設定'),
(132580, 7048, 39, 'ユーザーの新しいパスワード'),
(132581, 7049, 39, 'ユーザーネーム'),
(132582, 7052, 39, 'SMS Gateway の為のユーザー名'),
(132583, 7053, 39, 'SMS Gateway の為のユーザー名'),
(132584, 7055, 39, 'ユーザーネーム'),
(132585, 7056, 39, 'ユーザー名'),
(132586, 7057, 39, 'ユーザー名/グループ/ログ 管理者'),
(132587, 7061, 39, 'ウズベク語'),
(132588, 7062, 39, '休暇'),
(132589, 7063, 39, '休暇'),
(132590, 7064, 39, 'ワクチン'),
(132591, 7065, 39, '膣リング'),
(132592, 7066, 39, '告別'),
(132593, 7067, 39, '検証'),
(132594, 7068, 39, '値'),
(132595, 7069, 39, '値 1'),
(132596, 7070, 39, '値 2'),
(132597, 7073, 39, '値 1'),
(132598, 7074, 39, '値 2'),
(132599, 7076, 39, '水痘１'),
(132600, 7077, 39, '水痘２'),
(132601, 7078, 39, '静脈瘤'),
(132602, 7079, 39, '血管の病気'),
(132603, 7080, 39, '血管損傷'),
(132604, 7081, 39, '血管外科'),
(132605, 7082, 39, 'ベンダ語'),
(132606, 7083, 39, 'ベンダー'),
(132607, 7084, 39, 'バージョン'),
(132608, 7089, 39, 'ベトナム人'),
(132609, 7090, 39, '表示'),
(132610, 7091, 39, '表示'),
(132611, 7092, 39, 'アレルギーについて表示'),
(132612, 7098, 39, 'CSVテーブルで表示'),
(132613, 7100, 39, '文書を表示'),
(132614, 7101, 39, '通院歴を表示'),
(132615, 7103, 39, 'ポップアップでイベントを表示しますか？'),
(132616, 7107, 39, 'ログ表示'),
(132617, 7108, 39, 'Page 1 表示'),
(132618, 7109, 39, 'Page 2 表示'),
(132619, 7110, 39, '過去と先の予約を表示'),
(132620, 7111, 39, '患者の表示'),
(132621, 7116, 39, '関連する通院の表示'),
(132622, 7117, 39, 'レポートの表示'),
(132623, 7118, 39, 'README ファイルの表示'),
(132624, 7121, 39, '閲覧/編集 アレルギー'),
(132625, 7122, 39, '閲覧/編集 問題'),
(132626, 7123, 39, '閲覧/印刷'),
(132627, 7125, 39, 'VISA'),
(132628, 7126, 39, 'VISA/MC/AMEX/Dis'),
(132629, 7143, 39, 'バイタル'),
(132630, 7146, 39, '音声'),
(132631, 7158, 39, '発注'),
(132632, 7159, 39, '発注の最大値は0以上'),
(132633, 7160, 39, '発注の最少値は0以上'),
(132634, 7161, 39, '問屋'),
(132635, 7162, 39, '暖気'),
(132636, 7163, 39, '注意'),
(132637, 7164, 39, '注意'),
(132638, 7181, 39, 'ウェブ検索'),
(132639, 7182, 39, 'ウェブサイト'),
(132640, 7184, 39, '水'),
(132641, 7185, 39, '水曜日'),
(132642, 7186, 39, '週'),
(132643, 7187, 39, '週'),
(132644, 7188, 39, '週表示'),
(132645, 7193, 39, '体重'),
(132646, 7199, 39, 'ようこそ'),
(132647, 7200, 39, 'ウェールズ語'),
(132648, 7201, 39, 'フリジア語'),
(132649, 7202, 39, '喘鳴：'),
(132650, 7203, 39, '喘鳴'),
(132651, 7236, 39, 'ウォロフ語'),
(132652, 7237, 39, '女性のみ'),
(132653, 7238, 39, '女性のみ'),
(132654, 7239, 39, 'WordPress Portal'),
(132655, 7240, 39, '仕事'),
(132656, 7241, 39, '仕事について'),
(132657, 7242, 39, '職場の電話番号'),
(132658, 7243, 39, '職場の電話番号'),
(132659, 7244, 39, '仕事がらみ？'),
(132660, 7247, 39, '業務日'),
(132661, 7255, 39, '場所を変更しますか？'),
(132662, 7256, 39, 'この患者への領収をキャンセルしますか？'),
(132663, 7257, 39, '領収書を削除しますか？'),
(132664, 7258, 39, '支払いを削除しますか？'),
(132665, 7259, 39, '支払いを変更の上、完了しますか？'),
(132666, 7260, 39, '支払を変更しますか？'),
(132667, 7261, 39, '先払いまたは支払を完了しますか？'),
(132668, 7262, 39, '先払いしますか？'),
(132669, 7263, 39, '保存しますか？'),
(132670, 7264, 39, '腕'),
(132671, 7265, 39, '手と腕'),
(132672, 7266, 39, '腕に問題'),
(132673, 7267, 39, '書く'),
(132674, 7268, 39, '書き出す'),
(132675, 7269, 39, '一度だけ書く'),
(132676, 7273, 39, 'x キャンセル'),
(132677, 7274, 39, 'x キャンセル'),
(132678, 7275, 39, 'レントゲン'),
(132679, 7285, 39, '年または日'),
(132680, 7286, 39, '年または日'),
(132681, 7287, 39, '毎年'),
(132682, 7288, 39, '年または日'),
(132683, 7289, 39, '年数'),
(132684, 7290, 39, '年または日'),
(132685, 7291, 39, '年月日'),
(132686, 7292, 39, 'はい'),
(132687, 7293, 39, 'はい'),
(132688, 7294, 39, 'はい'),
(132689, 7295, 39, 'はい'),
(132690, 7296, 39, 'ログを削除'),
(132691, 7298, 39, 'はい・いいえ'),
(132692, 7299, 39, 'はい'),
(132693, 7300, 39, 'イディッシュ語'),
(132694, 7301, 39, 'ヨルバ語'),
(132695, 7303, 39, '既存のテンプレートを置き換えようとしています。続けますか？'),
(132696, 7304, 39, 'ログイン猶予期間です。ログイン前にパスワードを変更します'),
(132697, 7305, 39, 'このイベントを削除は許可されていません'),
(132698, 7306, 39, 'イベントを編集は許可されていません'),
(132699, 7307, 39, 'この権限はありません'),
(132700, 7309, 39, '問題を追加/編集する権限がありません。'),
(132701, 7310, 39, '予定をスケジュールする権限がありません。'),
(132702, 7313, 39, '直接このページにアクセスすることはできません。'),
(132703, 7314, 39, 'あなたは直接このページにアクセスすることはできません。'),
(132704, 7320, 39, 'このノートを閲覧・編集する権限がありません'),
(132705, 7323, 39, '.txtファイルのみアップロードできます'),
(132706, 7326, 39, '文書を暗号化する為のパスワードを入力してください'),
(132707, 7329, 39, '患者を選択または追加してください'),
(132708, 7330, 39, 'エンカウンターを選択または作成してください'),
(132709, 7331, 39, '訪問先カテゴリを指定してください'),
(132710, 7332, 39, '訪問先カテゴリを指定してください'),
(132711, 7333, 39, '幾つかのフィールドを指定する必要があります'),
(132712, 7335, 39, '最低一つのコンテキストを指定してください'),
(132713, 7336, 39, '最低一つのプロバイダーを指定してください'),
(132714, 7338, 39, '病院のレポート'),
(132715, 7339, 39, '終了日が異常です'),
(132716, 7340, 39, 'イベントが削除されました'),
(132717, 7341, 39, 'イベントが変更されました'),
(132718, 7342, 39, 'イベントが更新されました'),
(132719, 7343, 39, 'ファイルが大きすぎます'),
(132720, 7344, 39, 'ラボのレザルト'),
(132721, 7348, 39, 'パスワード利用期限'),
(132722, 7349, 39, 'パスワード期限が切れました。パスワードを更新してください'),
(132723, 7350, 39, 'パスワード利用期限'),
(132724, 7351, 39, '今日はパスワード利用期限日です。パスワードを更新してください'),
(132725, 7354, 39, 'ポストカレンダー設定は更新されました'),
(132726, 7355, 39, '周回度数は整数で指定してください'),
(132727, 7356, 39, '周回度数を1回以上指定してください'),
(132728, 7357, 39, '開始日時が終了日時を超えています'),
(132729, 7358, 39, '開始日時が異常です'),
(132730, 7359, 39, 'サブミッション　指定エラー'),
(132731, 7360, 39, 'yyyy-mm-dd'),
(132732, 7361, 39, 'YYYY-MM-DD'),
(132733, 7362, 39, 'yyyy-mm-dd date associated with this document'),
(132734, 7363, 39, 'yyyy-mm-dd date destroyed'),
(132735, 7364, 39, 'yyyy-mm-dd date of birth'),
(132736, 7365, 39, 'yyyy-mm-dd Date of Birth'),
(132737, 7366, 39, 'yyyy-mm-dd date of expiration'),
(132738, 7367, 39, 'yyyy-mm-dd Date of onset or hospitalization'),
(132739, 7368, 39, 'yyyy-mm-dd date of onset, surgery or start of medication'),
(132740, 7369, 39, 'yyyy-mm-dd date of purchase or transfer'),
(132741, 7370, 39, 'yyyy-mm-dd date of recovery or end of medication'),
(132742, 7371, 39, 'yyyy-mm-dd Date of return to play'),
(132743, 7372, 39, 'yyyy-mm-dd Date of service'),
(132744, 7373, 39, 'yyyy-mm-dd date of this letter'),
(132745, 7374, 39, 'yyyy-mm-dd date returned to play'),
(132746, 7375, 39, 'yyyy-mm-dd document date'),
(132747, 7376, 39, 'yyyy-mm-dd event date or starting date'),
(132748, 7377, 39, 'yyyy-mm-dd H:m End Date'),
(132749, 7378, 39, 'yyyy-mm-dd H:m End date'),
(132750, 7379, 39, 'yyyy-mm-dd H:m Start Date'),
(132751, 7380, 39, 'yyyy-mm-dd H:m Start date'),
(132752, 7381, 39, 'yyyy-mm-dd hh:mm:ss'),
(132753, 7382, 39, 'yyyy-mm-dd Hours(24):minutes'),
(132754, 7383, 39, 'yyyy-mm-dd last date of this event'),
(132755, 7385, 39, 'ZEF segment 内部エラー'),
(132756, 7386, 39, 'Zend Module'),
(132757, 7387, 39, 'ゼロ'),
(132758, 7388, 39, 'Zhuang, Chuang'),
(132759, 7389, 39, '郵便'),
(132760, 7390, 39, '郵便番号'),
(132761, 7391, 39, '郵便番号/国'),
(132762, 7392, 39, 'Zulu'),
(132763, 7395, 39, '本当に削除しますか'),
(132764, 7396, 39, '薬'),
(132765, 7399, 39, 'は、作成されました。 '),
(132766, 7400, 39, 'は、再度オープンされました。'),
(132767, 7401, 39, '履歴'),
(132768, 7402, 39, 'は、番号ではありません。'),
(132769, 7403, 39, 'は、再度課金できるようになりました。'),
(132770, 7405, 39, '個数'),
(132771, 7407, 39, '分'),
(132772, 7408, 39, '見つかりません。'),
(132773, 7414, 39, 'は、キュー実行されます。'),
(132774, 7430, 39, '(クリックして編集)'),
(132775, 7433, 39, '(新しい患者)'),
(132776, 7440, 39, '* 必須'),
(132777, 7443, 39, '--全て--'),
(132778, 7459, 39, '12時間'),
(132779, 7462, 39, '2'),
(132780, 7464, 39, '今から2か月'),
(132781, 7478, 39, '24時間'),
(132782, 7483, 39, '3か月'),
(132783, 7484, 39, '今から3か月'),
(132784, 7485, 39, '日に3回'),
(132785, 7491, 39, '4か月'),
(132786, 7492, 39, '今から4か月'),
(132787, 7493, 39, '日に4回'),
(132788, 7499, 39, '486.0, 肺炎, 急性'),
(132789, 7511, 39, '6か月'),
(132790, 7512, 39, '今から6か月'),
(132791, 7528, 39, '< 診察室'),
(132792, 7529, 39, '> 退出'),
(132793, 7530, 39, '?'),
(132794, 7531, 39, '? 非表示'),
(132795, 7532, 39, '@ 到着'),
(132796, 7533, 39, '[View切り替え]'),
(132797, 7537, 39, '[OFXエクスポート]'),
(132798, 7539, 39, '[総通院者数]'),
(132799, 7540, 39, '[レポート]'),
(132800, 7541, 39, '[全選択]'),
(132801, 7542, 39, '[SQL-Ledger]'),
(132802, 7543, 39, '[バッチ処理開始]'),
(132803, 7544, 39, '[ログ表示]'),
(132804, 7545, 39, '[印刷可能なレポートの表示]'),
(132805, 7546, 39, '_PC_DUR_HOURS'),
(132806, 7547, 39, '_PC_DUR_MINUTES'),
(132807, 7548, 39, '_PC_LOCALE'),
(132808, 7549, 39, '~ 遅刻（遅延到着）'),
(132809, 1, 40, 'Yksi'),
(132810, 2, 40, 'Viitenumero'),
(132811, 3, 40, 'Pääkäyttäjän käyttöoikeusvarmenne'),
(132812, 4, 40, 'Kliininen asiakirja on liitteenä'),
(132813, 5, 40, 'Kliininen asiakirja on liitteenä.'),
(132814, 7, 40, 'Jakelija tarvitaan'),
(132815, 8, 40, 'GCAC vierailu lomake lisätään tämän vierailun.'),
(132816, 9, 40, 'Eränumero tarvitaan'),
(132817, 10, 40, 'Eränumero tarvitaan'),
(132818, 11, 40, 'Pieni kirjain'),
(132819, 12, 40, 'Numero'),
(132820, 14, 40, 'Potilas tällä ID:llä on jo olemassa.'),
(132821, 15, 40, 'Potilas tällä nimellä on jo olemassa.'),
(132822, 16, 40, 'Potilas tällä sotulla on jo olemassa.'),
(132823, 18, 40, 'Positiivinen luku näyttää useilla aiemmilla lähetetyt laatikkoon Potilaan yhteenveto.'),
(132824, 19, 40, 'Lähetteen antaja voidaan määrittää jokaisesta käynnistä.'),
(132825, 20, 40, 'Vastaava IPPF koodi vaaditaan!'),
(132826, 21, 40, 'Erikoismerkki'),
(132827, 22, 40, 'Yksilöllinen arvo tähän kenttään. Ei näy käyttäjälle.'),
(132828, 23, 40, 'Tälle potilaalle on jo merkitty käynti tälle päivälle. Klikkaa "Peruuta" avataksesi sen tai "OK", jos haluat jatkaa uuden käynnin luomista.'),
(132829, 24, 40, 'Ennen ateriaa'),
(132830, 25, 40, 'Aamupäivä'),
(132831, 26, 40, 'Ilma / neste tasolla oikein'),
(132832, 27, 40, 'AB'),
(132833, 28, 40, 'Lyhenne'),
(132834, 29, 40, 'Paise:'),
(132835, 30, 40, 'Vatsa'),
(132836, 31, 40, 'Pystyy kantamaan painoa neljä (4) askelta:'),
(132837, 32, 40, 'Poikkeava'),
(132838, 33, 40, 'ABN1');
INSERT INTO `lang_definitions` VALUES
(132839, 34, 40, 'Poikkeava'),
(132840, 35, 40, 'Poikkeava verikoe'),
(132841, 36, 40, 'Poikkeava hiusten kasvu'),
(132842, 37, 40, 'Poikkeava mammografia'),
(132843, 39, 40, 'Raskaudenkeskeytys'),
(132844, 40, 40, 'Aborttiin liittyvät ongelmat'),
(132845, 41, 40, 'Raskaudenkeskeytyksen menetelmä'),
(132846, 42, 40, 'Raskaudenkeskeytykseen liittyvät luokat'),
(132847, 43, 40, 'Raskaudenkeskeytykset'),
(132848, 44, 40, 'Tietoja kalenterista'),
(132849, 46, 40, 'Poissaoloja Diagnoosi'),
(132850, 47, 40, 'Hyväksy tehtävät'),
(132851, 48, 40, 'Hyväksy maksu'),
(132852, 49, 40, 'Hyväksy maksu'),
(132853, 50, 40, 'Hyväksyy tehtävän'),
(132854, 51, 40, 'Pääsyvalvonta'),
(132855, 52, 40, 'Käytön hallinta'),
(132856, 54, 40, 'Pääsy kielletty'),
(132857, 55, 40, 'Ei lupaa pääsyyn'),
(132858, 56, 40, 'Avaa potilaan yhteenveto'),
(132859, 57, 40, 'Onnettomuus'),
(132860, 59, 40, 'Tilin nimi'),
(132861, 62, 40, 'Tilinhallinta'),
(132862, 64, 40, 'Kivut'),
(132863, 65, 40, 'Hyväksyminen pyydetty (ISA14)'),
(132864, 66, 40, 'Hyväksynnät, lisenssit ja todistukset'),
(132865, 67, 40, 'Käyttäjät (ACL)'),
(132866, 68, 40, 'Käyttäjien hallinta (ACL)'),
(132867, 69, 40, 'Ei lupaa hallinnoida käyttäjiä (ACL)'),
(132868, 70, 40, 'Käyttäjät päivitetty onnistuneesti (ACL)'),
(132869, 71, 40, 'Akne'),
(132870, 72, 40, 'Ajankohtaista'),
(132871, 73, 40, 'Tapahtuman päivämäärä'),
(132872, 74, 40, 'Toimenpide'),
(132873, 75, 40, 'Toimenpiteet'),
(132874, 77, 40, 'Aktivoi CCR / CCD raportointi'),
(132875, 78, 40, 'Päällä'),
(132876, 79, 40, 'Aktiivinen muistutus'),
(132877, 80, 40, 'Aktiivisen muistutuksen säännöt'),
(132878, 81, 40, 'Aktiivisia muistutuksia'),
(132879, 82, 40, 'Aktiivinen käynti'),
(132880, 84, 40, 'Aktiiviset listat'),
(132881, 85, 40, 'Aktiivinen potilas'),
(132882, 86, 40, 'Ajankohtaiset suunnitelmat'),
(132883, 87, 40, 'Aktiviteetit'),
(132884, 88, 40, 'toiminnan tyyppi'),
(132885, 90, 40, 'Akuutti myrkytys / peruuttaminen'),
(132886, 91, 40, 'Kroonisen sairauden akuutti ilmeneminen'),
(132887, 92, 40, 'Akuutti krooninen'),
(132888, 93, 40, 'Lisää'),
(132889, 94, 40, 'Lisää'),
(132890, 95, 40, 'Lisää'),
(132891, 96, 40, 'Lisää yritys'),
(132892, 98, 40, 'Lisää apteekki'),
(132893, 100, 40, 'Lisää tapahtuma '),
(132894, 101, 40, 'Lisää uutena muistiinpanona'),
(132895, 102, 40, 'Lisää uutena'),
(132896, 104, 40, 'Lisää painikkeita'),
(132897, 105, 40, 'Lisää painikkeita erikoismerkeille ja teksteille näytettäväksi editorin yläosassa sisällytettäessä tekstiä yhdellä klikkauksella'),
(132898, 106, 40, 'Lisää luokka'),
(132899, 107, 40, 'Lisää vakio'),
(132900, 108, 40, 'Lisää konteksti'),
(132901, 109, 40, 'Lisää maksuerä'),
(132902, 110, 40, 'Lisää peruste'),
(132903, 111, 40, 'Lisää mukautettu painike'),
(132904, 112, 40, 'Lisää diagnoosi'),
(132905, 113, 40, 'Lisää lääke'),
(132906, 114, 40, 'Lisää käynti'),
(132907, 115, 40, 'Lisää käynti / merkintä'),
(132908, 116, 40, 'Lisää tila'),
(132909, 117, 40, 'Lisää kenttä'),
(132910, 118, 40, 'Lisää seuraavat lauseet Apachen asetustiedostoon'),
(132911, 119, 40, 'Lisää ryhmä'),
(132912, 120, 40, 'Lisää diagnoosi koodi (ICD)'),
(132913, 121, 40, 'Lisää rokote'),
(132914, 122, 40, 'Ei oikeutta lisäämiseen!'),
(132915, 123, 40, 'Lisää tapahtuma'),
(132916, 124, 40, 'Lisää seurattava tuote'),
(132917, 125, 40, 'Lisää kieli'),
(132918, 126, 40, 'Lisää uusi'),
(132919, 127, 40, 'Lisää uusi'),
(132920, 128, 40, 'Lisää uusi luokka: '),
(132921, 129, 40, 'Lisää uusi sertifikaatti Apachen asetustiedostoon'),
(132922, 130, 40, 'Lisää uusi komponentti'),
(132923, 131, 40, 'Lisää uusia komponentteja'),
(132924, 132, 40, 'Lisää uusi ryhmä'),
(132925, 133, 40, 'Lisää uusi aihe'),
(132926, 134, 40, 'Lisää uusi erä ja transaktio'),
(132927, 135, 40, 'Lisää uusi muistiinpano'),
(132928, 136, 40, 'Lisää uusi muistiinpano'),
(132929, 137, 40, 'Lisää uusi kumppani'),
(132930, 138, 40, 'Lisää uusi potilas'),
(132931, 140, 40, 'Lisää muistiinpano'),
(132932, 141, 40, 'Lisää potilaskertomus'),
(132933, 142, 40, 'Lisää lääkemääräys'),
(132934, 143, 40, 'Lisää toiminto'),
(132935, 144, 40, 'Lisää hoitajan numero'),
(132936, 145, 40, 'Lisää kuntoutus'),
(132937, 146, 40, 'Lisää sääntö'),
(132938, 147, 40, 'Lisää'),
(132939, 148, 40, 'Lisää lääkelistaan'),
(132940, 149, 40, 'Lisää huipputaso'),
(132941, 150, 40, 'Lisää transaktio'),
(132942, 151, 40, 'Lisää käyttäjä'),
(132943, 152, 40, 'Lisää käyttäjä ryhmään'),
(132944, 153, 40, 'Lisää / Muokkaa sähköinen lääkemääräys'),
(132945, 154, 40, 'Lisää / Muokkaa potilastapahtumaa'),
(132946, 155, 40, 'lisätty'),
(132947, 156, 40, 'Ei saa lisätä henkilökohtaisia ​​tietoja.'),
(132948, 157, 40, 'Seurattavan tuotteen lisääminen ei onnistunut'),
(132949, 158, 40, 'Addison oireyhtymä'),
(132950, 159, 40, 'Addison oireyhtymä'),
(132951, 160, 40, 'lisämääreitä'),
(132952, 161, 40, 'Täydentävä diagnoosi:'),
(132953, 162, 40, 'Täydentävä sairaushistoria'),
(132954, 163, 40, 'Täydentävät historiatiedot'),
(132955, 164, 40, 'Lisätiedot'),
(132956, 165, 40, 'Täydentävä laboratoriotulos'),
(132957, 166, 40, 'Lisätiedot'),
(132958, 167, 40, 'Lisätiedot tähän tulokseen tai suositukseen'),
(132959, 168, 40, 'Lisätiedot:'),
(132960, 169, 40, 'Lisätiedot: '),
(132961, 170, 40, 'Röntgenin lisätiedot:'),
(132962, 171, 40, 'Lisäksi Yhdysvaltain vastaavaa snomed Extension Package voidaan tuoda erikseen asennuksen jälkeen International (Englanti versio) snomed Julkaisu'),
(132963, 172, 40, 'Vain lisäys'),
(132964, 173, 40, 'Osoitekirja'),
(132965, 174, 40, 'Osoitekirja'),
(132966, 175, 40, 'Osoite'),
(132967, 178, 40, 'Osoitekirja'),
(132968, 179, 40, 'Osoitekirjamerkintä yhtiöstä, joka suorittaa toimenpidettä'),
(132969, 180, 40, 'Osoitekirjamerkintä jakelijasta'),
(132970, 181, 40, 'Osoitekirjamerkintä myyjästä'),
(132971, 182, 40, 'Osoitteistolajit'),
(132972, 183, 40, 'Osoitetarra'),
(132973, 187, 40, 'Osoite1'),
(132974, 188, 40, 'Osoite2'),
(132975, 189, 40, 'Vastaanottaja'),
(132976, 190, 40, 'Pyöristä'),
(132977, 191, 40, 'Pyöristyksen määrä'),
(132978, 192, 40, 'Pyöristä'),
(132979, 193, 40, 'Pyöristys'),
(132980, 194, 40, 'Pyöristyksen määrä'),
(132981, 195, 40, 'Pyöristyksen syy'),
(132982, 196, 40, 'Pyöristyksen säätöarvo '),
(132983, 197, 40, 'Pyöristykset'),
(132984, 198, 40, 'Hallinnoi pyöristyksiä'),
(132985, 199, 40, 'Pääkäyttäjä'),
(132986, 200, 40, 'Pääkäyttäjän sähköpostiosoite'),
(132987, 202, 40, 'Hallinnoima'),
(132988, 203, 40, 'Hallinnoima'),
(132989, 204, 40, 'Hallinnointi pvm'),
(132990, 205, 40, 'Hallinnoitu sivusto'),
(132991, 206, 40, 'Hallinto'),
(132992, 207, 40, 'Hallinnoitava sivusto'),
(132993, 208, 40, 'Ylläpitäjät'),
(132994, 209, 40, 'Ylläpitäjät voivat tehdä kaikkea'),
(132995, 210, 40, 'Hyväksy päivämäärä'),
(132996, 212, 40, 'Painonhallinta ja seuranta aikuisille'),
(132997, 213, 40, 'Painonhallinta ja seuranta aikuisille'),
(132998, 214, 40, 'Tarkennettu neuvonta'),
(132999, 215, 40, 'Tarkennettu neuvonta'),
(133000, 216, 40, 'Tarkennettu neuvonta varoitus'),
(133001, 218, 40, 'Tarkennettu'),
(133002, 219, 40, 'Neuvo'),
(133003, 221, 40, 'Vaikuttaa normaaliin'),
(133004, 222, 40, 'Afrikaans'),
(133005, 223, 40, 'Päivystyspuhelu'),
(133006, 224, 40, 'Jälkeen Siirto vanhasta salasanoin jossa salasanat tallennetaan käyttäjien taulukossa ilman suolaa on valmis, tämän merkinnän pitäisi olla väärä, jotta vain todennus uusi menetelmä on mahdollista'),
(133007, 225, 40, 'Suorittamisen jälkeen edellä kokoonpanoissa, tuoda admin asiakassertifikaatin selain ja käynnistä uudelleen Apache-palvelin (tyhjä salasana).'),
(133008, 226, 40, 'PDF-tiedoston tallennuksen jälkeen, valitse [View Log] tarkistaaksesi virheet.'),
(133009, 227, 40, 'Tekstitiedoston tallennuksen jälkeen, valitse [View Log] tarkistaaksesi virheet'),
(133010, 228, 40, 'Erän tallennuksen jälkeen, valitse [View Log] tarkistaaksesi virheet.'),
(133011, 230, 40, 'Kun tiedot on syötetty oikein, klikkaa Tallenna-painiketta.'),
(133012, 231, 40, 'Tiedoston lähettämisen jälkeen klikkaa painiketta "Tuo"'),
(133013, 232, 40, 'Jälkihoidon suunnitelma'),
(133014, 233, 40, 'Jälleen'),
(133015, 234, 40, 'Ikä'),
(133016, 235, 40, 'vuotiaana'),
(133017, 236, 40, 'Ikäryhmä'),
(133018, 237, 40, 'Ikätieto on alueen ulkopuolella.'),
(133019, 238, 40, 'Iän esitysmuoto'),
(133020, 239, 40, 'Ikä muodossa "ikä alkaen" ei kelpaa'),
(133021, 240, 40, 'Ikä muodossa "ikään asti" ei kelpaa'),
(133022, 241, 40, 'Ikä alkaen'),
(133023, 242, 40, 'Vaihda iän näyttömuotoa'),
(133024, 243, 40, 'Ikä korkeintaan'),
(133025, 244, 40, 'Ikä vähintään'),
(133026, 245, 40, 'Ikäryhmä'),
(133027, 247, 40, 'Ikäsarakkeet:'),
(133028, 248, 40, 'Akan'),
(133029, 249, 40, 'Albania'),
(133030, 250, 40, 'Alkoholi'),
(133031, 251, 40, 'Alkoholin kulutus'),
(133032, 252, 40, 'Alkoholin käyttö'),
(133033, 253, 40, 'Varoitus Lukumäärä'),
(133034, 255, 40, 'Varoitukset'),
(133035, 258, 40, 'Aleut väestöstä'),
(133036, 259, 40, 'Kaikki'),
(133037, 260, 40, 'Kaikki'),
(133038, 261, 40, 'Kaikki (lajiteltuina A)'),
(133039, 262, 40, 'Kaikki (lajiteltuina B)'),
(133040, 263, 40, 'Kaikki (kumulatiivinen)'),
(133041, 265, 40, 'Kaikki automaattiset mittauslaskelmat (AMC)'),
(133042, 266, 40, 'Kaikki luokat'),
(133043, 267, 40, 'Kaikki kliinisen laadun mittaukset (CMQ)'),
(133044, 268, 40, 'Kaikki koodit'),
(133045, 269, 40, 'Koko päivä'),
(133046, 270, 40, 'Koko päivän tapahtuma'),
(133047, 271, 40, 'Kaikki väestötiedot kentät, mukana haku- ja päällekkäisyyksien tarkistus'),
(133048, 272, 40, 'Kaikki toimipaikat'),
(133049, 273, 40, 'Kaikki henkilövahingot / ongelmat / kysymykset'),
(133050, 274, 40, 'Kaikki kielet ovat sallittuja'),
(133051, 275, 40, 'Kaikki viralliset kliinisen laadun mittaukset (CQM) mittaryhmät'),
(133052, 276, 40, 'Koko etunimi tai sen osa'),
(133053, 277, 40, 'Koko sukunimi tai osa siitä'),
(133054, 278, 40, 'Koko organisaation nimi tai sen osa siitä'),
(133055, 279, 40, 'Kaikki potilaat'),
(133056, 280, 40, 'Kaikki tuotteet'),
(133057, 281, 40, 'Kaikki tarjoajat'),
(133058, 282, 40, 'Kaikki tutkitut ja negatiiviset:'),
(133059, 283, 40, 'Kaikki aiheet'),
(133060, 284, 40, 'Kaikki käyttäjät'),
(133061, 285, 40, 'Allerginen'),
(133062, 286, 40, 'Allergiat'),
(133063, 287, 40, 'Allergiat:'),
(133064, 288, 40, 'Allergia'),
(133065, 289, 40, 'Allergioiden tuonti onnistui'),
(133066, 290, 40, 'Allergialuettelo'),
(133067, 291, 40, 'Allerginen reaktio'),
(133068, 294, 40, 'Jaa'),
(133069, 295, 40, 'Salli'),
(133070, 296, 40, 'Salli koko saatavilla kielivalintavalikko sisäänkirjautuessa.'),
(133071, 297, 40, 'Salli diagnosien luominen, mutta ei menettelyjä tai maksuja. Useimmat klinikat eivät halua tätä.'),
(133072, 298, 40, 'Salli kielen virheenkorjaus'),
(133073, 299, 40, 'E-mail sallittu'),
(133074, 300, 40, 'Ovatko sähköpostit sallittua?'),
(133075, 301, 40, 'Onko sähköposti sallittu?'),
(133076, 302, 40, 'Luvanvaraisuudesta potilailla kokous'),
(133077, 303, 40, 'Salli terveystietojen jakaminen'),
(133078, 304, 40, 'Salli rokotustietojen jakaminen'),
(133079, 305, 40, 'Salli rokotusrekisterin käyttö'),
(133080, 306, 40, 'Salli postiviestit'),
(133081, 308, 40, 'Salli kirjautuminen potilasportaaliin'),
(133082, 309, 40, 'Salli SMS'),
(133083, 310, 40, 'Salli SMS (tekstiviestit)?'),
(133084, 311, 40, 'Sallitaanko tapahtumien välitön aktivoituminen?'),
(133085, 312, 40, 'Sallitaanko puhelinviestit?'),
(133086, 313, 40, 'Salli käyttäjien julkaista Yhteisiä tapahtumia'),
(133087, 314, 40, 'Salli käyttäjien julkaista henkilökohtaisen ​​kalenterinsa'),
(133088, 315, 40, 'Salli puheviestit'),
(133089, 316, 40, 'Sallittu'),
(133090, 317, 40, 'Sallittu kielet'),
(133091, 318, 40, 'Hyväksytty ©'),
(133092, 319, 40, 'Sallitaan sähköinen allekirjoitus koko tapahtumaan'),
(133093, 320, 40, 'Sallitaan sähköinen allekirjoitus yksittäisiin lomakkeisiin'),
(133094, 321, 40, 'Sallitaan kirjeet'),
(133095, 322, 40, 'Sallitaan puheviestit'),
(133096, 323, 40, 'on jo olemassa'),
(133097, 324, 40, 'on jo olemassa.'),
(133098, 325, 40, 'Jo käytössä, valitse toinen tunniste'),
(133099, 326, 40, 'Jo käytössä, valitse toinen nimike'),
(133100, 327, 40, 'Vaihtoehtoinen osoite'),
(133101, 328, 40, 'Vaihda'),
(133102, 329, 40, 'Vaihtoehtoisesti voit käyttää hakutoimintoa ladata sähköisen hyväksynnän (X12 83L) tiedosto, joka olet saanut maksajan tai selvityskeskusjärjestelmän. Voit tehdä tämän napsauttamalla Selaa-painiketta ja valitse tiedosto, jonka haluat ladata ja napsauta Haku-painiketta ladata ja näyttää vastaavat laskut. Tässä tapauksessa ei muut parametrit edellä mainittiin, ja niitä ei huomioida. Siirto tallentaa tiedoston, mutta prosessit eivät ole vielä sisältöä - tämä tapahtuu erikseen alla.'),
(133103, 330, 40, 'aamupäivä'),
(133104, 331, 40, 'Aamupäivän ohjelma'),
(133105, 332, 40, 'Automaattinen laskeminen toimenpiteet (AMC)'),
(133106, 333, 40, 'Automaattinen laskeminen toimenpiteet (AMC) seuranta'),
(133107, 334, 40, 'AMC-2011'),
(133108, 335, 40, 'AMC-2014'),
(133109, 338, 40, 'Muokkaa muistiinpanoa'),
(133110, 339, 40, 'Tarkistus alk'),
(133111, 340, 40, 'Tarkistuksen tila'),
(133112, 341, 40, 'Tarkistukset'),
(133113, 342, 40, 'Tarkistukset kohteelle'),
(133114, 343, 40, 'Amerikan intiaani'),
(133115, 344, 40, 'Amerikan intiaani tai syntynyt Alaskassa'),
(133116, 345, 40, 'AMEX'),
(133117, 346, 40, 'Amhara'),
(133118, 347, 40, 'Määrä'),
(133119, 348, 40, 'Annosteltu määrä'),
(133120, 349, 40, 'Veloitettava summa'),
(133121, 350, 40, 'Edellinen saldo'),
(133122, 351, 40, 'Tämän käynnin summa'),
(133123, 352, 40, 'Maksettu summa'),
(133124, 353, 40, 'Summa:'),
(133125, 354, 40, 'Laskutettu summa'),
(133126, 355, 40, 'Toistuvaan tapahtumaan vaaditaan aloituspäivää myöhäisempi lopetuspäivämäärä!'),
(133127, 356, 40, 'Lomaketta allekirjoitettaessa tapahtui virhe'),
(133128, 357, 40, 'Tapahtui virhe poistettaessa LibreEHR www-tiedostopuuta.'),
(133129, 358, 40, 'Tapahtui virhe poistettaessa phpGACL www-tiedostopuuta.'),
(133130, 359, 40, 'Tapahtui virhe poistettaessa SQL-Ledger www-tiedostopuuta.'),
(133131, 360, 40, 'Epätäydellinen GCAC on luotu ja linkitetty. Joku tulee täydentämään sitä myöhemmin.'),
(133132, 362, 40, 'Tapahtunut odottamaton virhe'),
(133133, 363, 40, 'Iso kirjain'),
(133134, 365, 40, 'Ja'),
(133135, 366, 40, 'JA'),
(133136, 367, 40, 'ja'),
(133137, 368, 40, 'ja '),
(133138, 369, 40, 'ja kaikki tiedot alisteisia? Tämä toimenpide kirjataan'),
(133139, 370, 40, 'ja muokkaaja'),
(133140, 371, 40, 'ja onnistui.'),
(133141, 372, 40, 'ja käynnistä Apache serveri uudestaan.'),
(133142, 373, 40, 'ja syy on'),
(133143, 374, 40, 'Anemia'),
(133144, 375, 40, 'Nilkka'),
(133145, 376, 40, 'Nilkka + kantapää'),
(133146, 377, 40, 'Nilkka arviointilomake'),
(133147, 378, 40, 'Nilkka ongelmia'),
(133148, 379, 40, 'Selkärankareuman Spondlilitis'),
(133149, 380, 40, 'Selkärankareuman Spondlilitis'),
(133150, 381, 40, 'Anoreksia'),
(133151, 382, 40, 'Toinen asia mitä voi tehdä lähetysikkunassa on pyytää toissijainen laskutus. Jos valitset tämän vaihtoehdon ennen tallentamista, niin alkuperäinen lasku avataan uudelleen ja laitetaan jonoon Laskutus-sivulle, ja se käsitellään seuraavan laskutuksen yhteydessä.'),
(133152, 383, 40, 'ennakko'),
(133153, 384, 40, 'Anus, ei peräsuolen arkuutta'),
(133154, 385, 40, 'Ahdistus'),
(133155, 386, 40, 'Kaikki'),
(133156, 387, 40, 'Kaikki luokat'),
(133157, 388, 40, 'Mikä tahansa osa koodista tai sen kuvauksesta'),
(133158, 389, 40, 'Mikä tahansa osa halutusta erikoisuudesta'),
(133159, 390, 40, 'Mikä tahansa osa lääkkeen numerosta tai nimestä'),
(133160, 391, 40, 'Mikä tahansa osa rokotteen tunnisteesta tai nimestä'),
(133161, 392, 40, 'Mikä tahansa osa potilaan nimestä, joko "sukunimi, etunimi" tai "X-Y"'),
(133162, 393, 40, 'Muut asiaa koskevat tiedot'),
(133163, 394, 40, 'API avain SMS portaaliin'),
(133164, 395, 40, 'Uniapnea'),
(133165, 396, 40, 'Ulkoasu'),
(133166, 397, 40, 'Ulkoasu:'),
(133167, 398, 40, 'Liitä tämä huomautus'),
(133168, 399, 40, 'Liitä nykyiseen muistiinpanoon'),
(133169, 400, 40, 'Liitä tähän ilmoitukseen'),
(133170, 401, 40, 'Liitä tähän ilmoitukseen'),
(133171, 402, 40, 'Umpilisäkkeen poisto'),
(133172, 403, 40, 'umpilisäkkeen poisto'),
(133173, 404, 40, 'Sovellettava Potilaat'),
(133174, 405, 40, 'Sovellus'),
(133175, 406, 40, 'Sovelluksen nimi sisäänkirjautumissivulle ja pääikkunan otsikko.'),
(133176, 407, 40, 'Sovellus vastaanotin Code (GS03 - Jos tyhjä ISA08 käytetään)'),
(133177, 408, 40, 'Sovelluksen lähettäjäkoodi (GS02)'),
(133178, 409, 40, 'Sovelluksen otsake'),
(133179, 410, 40, 'Käytettävä lomake elintoiminnoille ja kasvukäyrälle'),
(133180, 411, 40, 'Käytettävä lomake elintoiminnoille'),
(133181, 412, 40, 'Tehdäänkö muutos nykyiseen tapahtumaan, nykyiseen ja mahdollisesti tuleviin tapahtumiin tai joka tapauksessa?'),
(133182, 413, 40, 'sovelletaan hoidettavalle alueelle'),
(133183, 414, 40, 'iholle'),
(133184, 415, 40, 'lisää'),
(133185, 416, 40, 'Lisätään korjaustiedosto sivustolle'),
(133186, 417, 40, 'Ajanvaraus'),
(133187, 418, 40, 'Ajanvaraus päivämäärä'),
(133188, 419, 40, 'Ajanvarauksen esitystapa'),
(133189, 420, 40, 'Ajanvarauksen muistuttaja'),
(133190, 421, 40, 'Ajanvarauksen tila'),
(133191, 422, 40, 'Ajanvarausten tilat'),
(133192, 423, 40, 'Ajanvaraukset aikajaksolla'),
(133193, 424, 40, 'Ajanvarauksen / tapahtuman väri'),
(133194, 425, 40, 'Ajanvaraukset'),
(133195, 426, 40, 'Ajanvaraukset (valinnainen)'),
(133196, 427, 40, 'Ajanvaraukset (Kirjoita, osa valinnaisia)'),
(133197, 430, 40, 'Ajanvaraukset ja potilastapaamiset'),
(133198, 431, 40, 'Ajanvarausraportti'),
(133199, 432, 40, 'Ajanvaraus- ja vierailuraportti'),
(133200, 434, 40, 'Hyväksy'),
(133201, 435, 40, 'Hyväksy potilas hakemistosta Potilas/Asiakas->Tuo->Odottaa hyväksyntää'),
(133202, 436, 40, 'Hyväksytty'),
(133203, 437, 40, 'Tapahtumien hallinnointi hyväksytty'),
(133204, 438, 40, 'Hyväksyminen onnistui'),
(133205, 440, 40, 'Ajanvaraukset ja vierailut'),
(133206, 441, 40, 'Ajanvaraukset'),
(133207, 442, 40, 'Huhtikuu'),
(133208, 443, 40, 'Huhtikuu'),
(133209, 444, 40, 'Arabia'),
(133210, 445, 40, 'Aragonia'),
(133211, 446, 40, 'Arkistoi'),
(133212, 447, 40, 'Käännetäänkö ryhmien nimet?'),
(133213, 448, 40, 'Käännetäänkö ajanvarausluokkien nimet?'),
(133214, 449, 40, 'Käännetäänkö tiedostoluokkien nimet?'),
(133215, 450, 40, 'Peritään tämän tyyppisistä maksu?'),
(133216, 451, 40, 'Käännetäänkö potilasmerkintöjen otsikot?'),
(133217, 452, 40, 'Onko koodit tallennettu erilliseen sql-tauluun (0-No, 1-ICD10, 2-SNOMED(RF1), 3-SNOMED(RF2)) ?'),
(133218, 453, 40, 'Oletko valmis viimeistelemään uuden GCAC aiheen tälle käynnille?'),
(133219, 454, 40, 'Haluatko varmasti lähettää tämän tänään?'),
(133220, 455, 40, 'Haluatko varmasti hyväksyä nämä tapahtumat?'),
(133221, 457, 40, 'Haluatko varmasti poistaa tämän kaavakkeen lopullisesti?'),
(133222, 458, 40, 'Haluatko varmasti poistaa tämän'),
(133223, 459, 40, 'Haluatko varmasti poistaa tämän liitteen?'),
(133224, 460, 40, 'Haluatko varmasti poistaa tämän tapahtuman?'),
(133225, 461, 40, 'Haluatko varmasti poistaa tämän tietokannasta?'),
(133226, 462, 40, 'Haluatko varmasti poistaa tämän muistiinpanon?'),
(133227, 464, 40, 'Haluatko varmasti muokata näitä tapahtumia?'),
(133228, 465, 40, 'Haluatko varmasti piilottaa nämä tapahtumat?'),
(133229, 466, 40, 'Haluatko varmasti lähettää sen uudestaan?'),
(133230, 467, 40, 'Haluatko varmasti nähdä nämä tapahtumat?'),
(133231, 468, 40, 'Haluatko varmasti poistaa koko ryhmän nimeltään'),
(133232, 469, 40, 'Haluatko varmasti poistaa koko listan'),
(133233, 470, 40, 'Oletko varma, että haluat poistaa kentän'),
(133234, 471, 40, 'Haluatko varmasti poistaa valitut kentät?'),
(133235, 472, 40, 'Haluatko varmasti jatkaa toimintoa?'),
(133236, 473, 40, 'Aluetta ei ole määritelty'),
(133237, 474, 40, 'Käsivarsi'),
(133238, 475, 40, 'Armenia'),
(133239, 477, 40, 'Rytmihäiriö'),
(133240, 478, 40, 'Nivelrikko'),
(133241, 479, 40, 'Nivelrikko / Perinnöllinen niveltulehdus'),
(133242, 480, 40, 'Nivelrikko / Perinnöllinen niveltulehdus'),
(133243, 481, 40, 'kuten'),
(133244, 482, 40, 'Alkaen'),
(133245, 483, 40, 'Nouseva'),
(133246, 484, 40, 'Aasialainen'),
(133247, 485, 40, 'Assami'),
(133248, 487, 40, 'Arviointi'),
(133249, 488, 40, 'Määritetty'),
(133250, 489, 40, 'Avustaja'),
(133251, 490, 40, 'Astma'),
(133252, 491, 40, 'kohteessa'),
(133253, 492, 40, 'Vaaditaan vähintään yksi parametri jos valitset Kaikki.'),
(133254, 493, 40, 'Veneluussa'),
(133255, 494, 40, 'Veneluussa:'),
(133256, 495, 40, 'Urheilujoukkue'),
(133257, 496, 40, 'Urheilujoukkue'),
(133258, 497, 40, 'Urheiluvamma'),
(133259, 498, 40, 'ATNA (Audit Trail and Node Authentication) tarkastuksen CA sertifikaatti'),
(133260, 499, 40, 'ATNA (Audit Trail and Node Authentication) tarkastuksen isäntä'),
(133261, 500, 40, 'ATNA (Audit Trail and Node Authentication) tarkastuksen paikallinen sertifikaatti'),
(133262, 501, 40, 'ATNA (Audit Trail and Node Authentication) tarkastuksen portti'),
(133263, 503, 40, 'Huomio'),
(133264, 504, 40, 'Huom.'),
(133265, 506, 40, 'Tarkasta CDR moottorin kyselyt'),
(133266, 507, 40, 'Tietosuoja lokin tarkastus'),
(133267, 508, 40, 'Tietosuoja lokin tarkastusraportti'),
(133268, 509, 40, 'Tarkasta varmuuskopioiden kirjaaminen'),
(133269, 510, 40, 'Tarkasta sekalaisten tietojen kirjaaminen'),
(133270, 511, 40, 'Tarkasta kirjaamisjärjestys'),
(133271, 512, 40, 'Tarkasta potilastietojen kirjaaminen'),
(133272, 513, 40, 'Tarkasta aikataulujen kirjaaminen'),
(133273, 514, 40, 'Tarkasta tietoturvahallinnon kirjaaminen'),
(133274, 515, 40, 'Tarkasta VALITSE kyselyn kirjaaminen'),
(133275, 516, 40, 'Elokuu'),
(133276, 517, 40, 'Elokuu'),
(133277, 519, 40, 'Oikeudet'),
(133278, 520, 40, 'Oikeudet/Muistiinpanot'),
(133279, 523, 40, 'Ryhmäoikeudet'),
(133280, 524, 40, 'Valtuutuksen tila'),
(133281, 525, 40, 'Valtuutukset'),
(133282, 526, 40, 'Valtuuta'),
(133283, 527, 40, 'Valtuuta - kaikki tapahtumat'),
(133284, 528, 40, 'Valtuuta - minun tapahtumat'),
(133285, 529, 40, 'Authorize.net'),
(133286, 530, 40, 'Valtuutettu'),
(133287, 531, 40, 'Vain valtuutetuille'),
(133288, 532, 40, 'Lähetä automaattisesti'),
(133289, 535, 40, 'Luo uusi käynti automaattisesti'),
(133290, 536, 40, 'Luotu automaattisesti'),
(133291, 537, 40, 'Automatisoidut laskelmat (AMC)'),
(133292, 538, 40, 'Automatisoidut laskelmat (AMC) - 2011'),
(133293, 539, 40, 'Automatisoidut laskelmat (AMC) - 2014'),
(133294, 542, 40, 'Automatisoitujen laskelmien (AMC) seuranta'),
(133295, 543, 40, 'Automatisoidut mittaukset (AMC)'),
(133296, 544, 40, 'Automaattinen'),
(133297, 546, 40, 'Uusi käynti luodaan automaattisesti, kun varaustila on asetettu @ (Saapunut)'),
(133298, 549, 40, 'Liikennelääketiede'),
(133299, 550, 40, 'tallennettu automaattisesti'),
(133300, 551, 40, 'Käytettävissä olevat luokat'),
(133301, 552, 40, 'Käytettävissä olevat ajat'),
(133302, 553, 40, 'Käytettävissä olevat "Tracks"'),
(133303, 554, 40, 'Avaari'),
(133304, 555, 40, 'Avery tarran tyypin valinta potilastarran tulostamiseksi tapahtuu navigaation vasemmasta reunasta'),
(133305, 556, 40, 'Avesta'),
(133306, 557, 40, 'Keskimäärin kuukaudessa'),
(133307, 558, 40, 'Avulsion / avulsion murtuma'),
(133308, 559, 40, 'Ulkokehräksen murtuma'),
(133309, 560, 40, 'Sisäkehräksen murtuma '),
(133310, 561, 40, 'Tietoisuuteen perustuva'),
(133311, 562, 40, 'Kainalo'),
(133312, 563, 40, 'Aimara'),
(133313, 564, 40, 'Azeri'),
(133314, 565, 40, '2 krt/pvä'),
(133315, 566, 40, 'Takaisin'),
(133316, 567, 40, 'takaisin'),
(133317, 568, 40, 'Palaa 8 käyntiä'),
(133318, 569, 40, 'Palaa 11 käyntiä'),
(133319, 570, 40, 'Palaa 5 käyntiä'),
(133320, 571, 40, 'Palaa 4 käyntiä'),
(133321, 572, 40, 'Palaa 9 käyntiä'),
(133322, 573, 40, 'Palaa 1 käynti'),
(133323, 574, 40, 'Selkäkipu'),
(133324, 575, 40, 'Selkävaivat'),
(133325, 576, 40, 'Palaa 7 käyntiä'),
(133326, 577, 40, 'Palaa 6 käyntiä'),
(133327, 578, 40, 'Selkäleikkaus'),
(133328, 579, 40, 'Palaa 10 käyntiä'),
(133329, 580, 40, 'Palaa 3 käyntiä'),
(133330, 581, 40, 'Takaisin Admin sivulle'),
(133331, 582, 40, 'Takaisin potilaskäyntiin'),
(133332, 583, 40, 'Takaisin potilaaseen'),
(133333, 584, 40, 'Takaisin potilaaseen'),
(133334, 585, 40, 'Takaisin käyttäjiin'),
(133335, 586, 40, 'Takaisin näkymään'),
(133336, 587, 40, 'Palaa 12 käyntiä'),
(133337, 588, 40, 'Palaa 2 käyntiä'),
(133338, 589, 40, 'Palvelut taustalla'),
(133339, 590, 40, 'Varmuuskopio'),
(133340, 591, 40, 'Varmuuskopio luotu. Lähetetään ladattavaksi.'),
(133341, 592, 40, 'Lista varmuuskopioista'),
(133342, 593, 40, 'Varmuuskopio vastaanotettu onnistuneesti'),
(133343, 594, 40, 'Katteeton shekki'),
(133344, 595, 40, 'Luottotappio'),
(133345, 596, 40, 'Bahasa Indonesia'),
(133346, 597, 40, 'Saldo'),
(133347, 598, 40, 'Saldo'),
(133348, 599, 40, 'Saldo'),
(133349, 600, 40, 'Saldo'),
(133350, 601, 40, 'Kertynyt saldo'),
(133351, 602, 40, 'Bambara'),
(133352, 603, 40, 'Pankkivekseli'),
(133353, 604, 40, 'Viivakooditarra'),
(133354, 605, 40, 'Viivakooditarran tyyppi'),
(133355, 606, 40, 'Viivakooditarran tyyppi viivakoodin tulostamista varten valitaan navigaation vasemmasta reunasta.'),
(133356, 607, 40, 'Base of fifth (5th) Metarsal'),
(133357, 608, 40, 'Base of fifth (5th) Metarsal:'),
(133358, 609, 40, 'Baškiiri'),
(133359, 610, 40, 'Baski'),
(133360, 611, 40, 'Koontilasku'),
(133361, 612, 40, 'Erälähetyksen viestintämoduuli'),
(133362, 613, 40, 'Kirjaus koontimaksuun'),
(133363, 614, 40, 'Koontimaksut'),
(133364, 615, 40, 'Ryhmäprosessi tunnistettu; tämä saattaa kestää hetken.'),
(133365, 616, 40, 'Eräajon tulokset'),
(133366, 617, 40, 'BatchCom'),
(133367, 618, 40, 'Ole kärsivällinen, joidenkin asiakirjojen käsittely saattaa vaatia useita minuutteja!'),
(133368, 619, 40, 'koska kyseistä tunnusta ei ole.'),
(133369, 620, 40, 'Aloitus'),
(133370, 621, 40, 'Aloituspäivämäärä'),
(133371, 623, 40, 'Hoidon alkamispäivä vvvv-kk-pp'),
(133372, 624, 40, 'Alkamistunti kalenterimerkinnöille.'),
(133373, 625, 40, 'Valkovenäläinen'),
(133374, 626, 40, 'Röyhtäily'),
(133375, 628, 40, 'Bengali'),
(133376, 629, 40, 'Bengali / Bangla'),
(133377, 630, 40, 'välillä'),
(133378, 631, 40, 'Kaksisuuntainen'),
(133379, 632, 40, 'Bihar'),
(133380, 633, 40, 'Bilateraali'),
(133381, 634, 40, 'Bilateraali:'),
(133382, 636, 40, 'Laskutuspäivä:'),
(133383, 637, 40, 'Lasku'),
(133384, 638, 40, 'Laskutettu'),
(133385, 640, 40, 'Laskutus'),
(133386, 641, 40, 'Laskutus (Vaihtoehtoinen)'),
(133387, 642, 40, 'Laskun yksilöintitieto'),
(133388, 644, 40, 'Laskutuskoodi pyydettyyn palveluun'),
(133389, 645, 40, 'Laskutuskoodit'),
(133390, 646, 40, 'Laskutustiedot'),
(133391, 647, 40, 'Laskutusosasto'),
(133392, 648, 40, 'Laskutuspaikka'),
(133393, 649, 40, 'Laskutustiedot'),
(133394, 650, 40, 'Laskutusosoite'),
(133395, 655, 40, 'Laskutusjärjestelmä'),
(133396, 656, 40, 'Huomautuslasku'),
(133397, 657, 40, 'Huomautuslasku '),
(133398, 658, 40, 'Huomautuslasku:'),
(133399, 659, 40, 'Lakutusjonon tulos:'),
(133400, 660, 40, 'Laskutusraportti'),
(133401, 661, 40, 'Laskutuksen tila'),
(133402, 662, 40, 'Laskutuksen tila = Laskuttamaton'),
(133403, 663, 40, 'laskutus '),
(133404, 665, 40, 'Koepala'),
(133405, 666, 40, 'Syntymäpäivä'),
(133406, 667, 40, 'Syntymä - 24 kuukautta'),
(133407, 668, 40, 'Bislama'),
(133408, 669, 40, 'Musta'),
(133409, 670, 40, 'Pölykeuhko'),
(133410, 671, 40, 'Mustaihoinen'),
(133411, 672, 40, 'Virtsarakon syöpä'),
(133412, 673, 40, 'Virtsarakkoinfektiot'),
(133413, 674, 40, 'Tyhjät lomakkeet'),
(133414, 675, 40, 'Verenvuoto-ongelmia'),
(133415, 676, 40, 'Sokea piste'),
(133416, 677, 40, 'Turvotus'),
(133417, 678, 40, 'Estetyt'),
(133418, 679, 40, 'Veri'),
(133419, 680, 40, 'Verenpaine'),
(133420, 681, 40, 'Verenpaine'),
(133421, 682, 40, 'Nenäverenvuoto'),
(133422, 683, 40, 'Blue Cross Blue Shield (Vakuutusyhtiö)'),
(133423, 684, 40, 'Siniset viivat tässä raportissa ovat tiedottavia. Mustat viivat osoittavat aiemmin olemassa olevaa tietoa. Green linjat osoittavat muutoksia, jotka onnistuneesti sovellettu. Punaiset viivat kuvaavat virheitä, tai muutokset, jotka ei ole sovellettu; ne voidaan käsitellä manuaalisesti. Tällä hetkellä kiistettyjä vaateita ja peruutettuja maksuja ei käsitellä automaattisesti ja siten ovat punaisia.'),
(133424, 685, 40, 'Näön hämärtyminen'),
(133425, 686, 40, 'BMI (Pituus-massa indeksi)'),
(133426, 687, 40, 'BMI tila'),
(133427, 689, 40, 'Kehon osa'),
(133428, 692, 40, 'Luiden arkuus:'),
(133429, 693, 40, 'Luiden arkuus: Ulkokehräs'),
(133430, 694, 40, 'Totuusarvo'),
(133431, 695, 40, 'Bosnia'),
(133432, 696, 40, 'Ala'),
(133433, 697, 40, 'Molemmat korvat'),
(133434, 698, 40, 'molemmat korvat'),
(133435, 699, 40, 'Pohja'),
(133436, 700, 40, 'Alamarginaali (px)'),
(133437, 701, 40, 'RUUTU 10 A. Työllisyyteen liittyvä '),
(133438, 702, 40, 'RUUTU 10 B. Auto-onnettomuus '),
(133439, 703, 40, 'RUUTU 10 C. Muu onnettomuus '),
(133440, 704, 40, 'RUUTU 14 Päiväyksen karsinta'),
(133441, 705, 40, 'RUUTU 15 Toinen päiväyksen karsinta'),
(133442, 706, 40, 'RUUTU 15. Saman tai vastaavan sairauden esiintymispäivä (vvvv-kk-pp):'),
(133443, 707, 40, 'RUUTU 15. Saman tai vastaavan sairauden esiintymispäivä / Toinen päivämäärä (vvvv-kk-pp):'),
(133444, 708, 40, 'RUUTU 16. Työkyvyttömyys alkaa (vvvv-kk-pp):'),
(133445, 709, 40, 'RUUTU 16. Työkyvyttömyys päättyy (vvvv-kk-pp):'),
(133446, 710, 40, 'RUUTU 18. Sairaalahoidossa alkaen (vvvv-kk-pp): '),
(133447, 711, 40, 'RUUTU 18. Sairaalahoito päättyy (vvvv-kk-pp): '),
(133448, 712, 40, 'RUUTU 20. Onko käytetty ulkopuolista laboratoriota?'),
(133449, 713, 40, 'RUUTU 22. Medicaid uudelleenlähetys koodi (ICD-9) '),
(133450, 714, 40, 'RUUTU 23. Aiempi valtuutusnumero '),
(133451, 715, 40, 'Verenpaine'),
(133452, 716, 40, 'Verenpaine diastolinen'),
(133453, 717, 40, 'Verenpainen systolinen'),
(133454, 719, 40, 'Verenpaine diastolinen'),
(133455, 721, 40, 'Verenpainen systolinen'),
(133456, 722, 40, 'Brasilian portugeesi'),
(133457, 723, 40, 'Rinta'),
(133458, 724, 40, 'Rintojen koepala'),
(133459, 725, 40, 'Rintojen eritteet'),
(133460, 726, 40, 'Rintojen sairaudet'),
(133461, 727, 40, 'Rintatutkimus'),
(133462, 728, 40, 'Kyhmyt rinnoissa'),
(133463, 730, 40, 'Hengitysäänet'),
(133464, 731, 40, 'Bretoni'),
(133465, 732, 40, 'Luunmurtumat'),
(133466, 733, 40, 'vioittunut lomake'),
(133467, 734, 40, 'Keuhkoputkentulehduksen muoto'),
(133468, 735, 40, 'Selaa'),
(133469, 736, 40, 'Selaa tietuetta'),
(133470, 737, 40, 'Verenpurkauma / hematooma'),
(133471, 738, 40, 'Bulgaria'),
(133472, 739, 40, 'Pullistuma Oikea:'),
(133473, 740, 40, 'Burma'),
(133474, 741, 40, 'Kirvelyä virtsatessa'),
(133475, 742, 40, 'Kirvelyä virtsatessa'),
(133476, 743, 40, 'Työpuhelin'),
(133477, 744, 40, 'Varattu'),
(133478, 745, 40, 'mutta ei vielä käsitelty.'),
(133479, 746, 40, 'Pakara'),
(133480, 747, 40, 'Pakara + SI-nivel'),
(133481, 748, 40, 'alue'),
(133482, 749, 40, 'Kautta'),
(133483, 750, 40, 'oraalisti'),
(133484, 751, 40, 'Kautta / Lähde'),
(133485, 752, 40, 'Alue:'),
(133486, 753, 40, 'C'),
(133487, 754, 40, 'CA sertifikaatti varmentamaan RFC 5425 TLS syslog palvelin.'),
(133488, 755, 40, 'Välimuistin elinaika (sekunteja)'),
(133489, 756, 40, 'Jätetäänkö asiakirjamallin tuloste välimuistiin?'),
(133490, 757, 40, 'Kahvin kulutus'),
(133491, 758, 40, 'Kalenteri'),
(133492, 759, 40, 'Kalenterin lopetusaika'),
(133493, 760, 40, 'Kalenterin aikaväli'),
(133494, 761, 40, 'Kalenterinäkymä'),
(133495, 762, 40, 'Kalenterin asetukset'),
(133496, 763, 40, 'Kalenterin aloitusaika'),
(133497, 764, 40, 'Kalenterin käyttöliittymä'),
(133498, 765, 40, 'Kalenterinäkymä'),
(133499, 766, 40, 'addForm() kutsu tulee tähän.<br>'),
(133500, 767, 40, 'Kalorit'),
(133501, 768, 40, 'Kamputsealainen'),
(133502, 774, 40, 'Peru'),
(133503, 775, 40, 'Peru muutokset'),
(133504, 776, 40, 'Peruttu'),
(133505, 777, 40, 'Syöpä'),
(133506, 778, 40, 'Syöpäseulonta: Paksusuolen syövän seulonta'),
(133507, 779, 40, 'Syöpäseulonta: Mammografia'),
(133508, 780, 40, 'Syöpäseulonta: Papakoe'),
(133509, 781, 40, 'Syöpäseulonta: Eturauhasen syövän seulonta'),
(133510, 782, 40, 'Tätä lisäystä ei voi tehdä, koska se on jo olemassa!'),
(133511, 783, 40, 'Tätä lisäystä/päivitystä ei voi tehdä, koska siitä on jo olemassa duplikaatti!'),
(133512, 784, 40, 'ei voi arkistoida, sivuutettu'),
(133513, 785, 40, 'ei voi muuntaa muotoon JPEG. Kenties ImageMagick on asentamatta?'),
(133514, 786, 40, 'ei voi poistaa, sivuutettu'),
(133515, 787, 40, 'ei voida näyttää inline, koska selain ei tue sen tyyppiä.'),
(133516, 788, 40, 'ei voida näyttää inline, koska selain ei tue sen tyyppiä.'),
(133517, 789, 40, 'ei voida näyttää inline, koska selain ei tue sen tyyppiä.'),
(133518, 790, 40, 'Ei voi luoda'),
(133519, 791, 40, 'Asiakirjaa ei voi luoda'),
(133520, 792, 40, 'Asiakirjaa ei voi poistaa (SFTP palvelimelta)'),
(133521, 793, 40, 'Asiakirjaa ei voi poistaa'),
(133522, 794, 40, 'Kohde tiedostonimeä ei voi määrittää'),
(133523, 795, 40, 'Ei löydetä '),
(133524, 796, 40, 'Kohteen tiedostonimeä ei löydy'),
(133525, 799, 40, 'Potilaan asiakastunnusta ei löydy SQL-Ledger tietokannasta'),
(133526, 800, 40, 'PostScript asiakirjan viitettä ei löydy '),
(133527, 802, 40, 'Maksun muokkaus ei onnistu. Jakamaton on negatiivinen.'),
(133528, 803, 40, 'Ei voida avata '),
(133529, 804, 40, 'Ei voida lähettää vakuuttajalle. Maksajaksi on merkitty potilas.'),
(133530, 805, 40, 'Ei voida lähettää potilaalle. Maksajaksi on merkitty vakuuttaja.'),
(133531, 806, 40, 'Maksua ei voi lähettää. Jakamaton on negatiivinen.'),
(133532, 807, 40, 'Ei voida lukea'),
(133533, 808, 40, 'Hakemistoa ei voi lukea'),
(133534, 809, 40, 'Päivitys ei onnistu, koska et ole muokkaamassa tallennettua tietoa.'),
(133535, 810, 40, 'Isot kirjaimet'),
(133536, 811, 40, 'Isot Aloituskirjaimet Kaikkialle'),
(133537, 812, 40, 'kapseli'),
(133538, 813, 40, 'Kortti'),
(133539, 814, 40, 'Sydämen katetrointi'),
(133540, 815, 40, 'Ekokardiografia'),
(133541, 816, 40, 'Sydän- ja verisuonitaudit'),
(133542, 822, 40, 'Rustovaurio'),
(133543, 824, 40, 'käteinen'),
(133544, 825, 40, 'Käteinen'),
(133545, 826, 40, 'Käteiskuitit'),
(133546, 827, 40, 'Käteiskuitit tuottajittain'),
(133547, 829, 40, 'Kaihileikkaus'),
(133548, 830, 40, 'Kaihi'),
(133549, 831, 40, 'Luokat'),
(133550, 832, 40, 'Luokat kohteelle'),
(133551, 833, 40, 'Luokka'),
(133552, 834, 40, 'luokka'),
(133553, 835, 40, 'Luokka '),
(133554, 836, 40, 'Luokan yksityiskohdat'),
(133555, 837, 40, 'Luokan rajoitukset'),
(133556, 838, 40, 'Luokan nimi'),
(133557, 839, 40, 'Luokan nimi puuttuu'),
(133558, 840, 40, 'Luokka / Otsikko'),
(133559, 841, 40, 'Kaukaasiaalainen'),
(133560, 852, 40, 'Matkapuhelin'),
(133561, 853, 40, 'Matkapuhelin'),
(133562, 854, 40, 'Matkapuhelimen numero'),
(133563, 855, 40, 'Matkapuhelimen numero'),
(133564, 856, 40, 'Keskussertifiointi'),
(133565, 857, 40, 'Keski-/Eteläamerikkalainen'),
(133566, 860, 40, 'Sertifioi lähettämään RFC 5425 TLS syslog palvelimelle.'),
(133567, 861, 40, 'Sertifioi käyttäjä'),
(133568, 862, 40, 'Sertifikaatit'),
(133569, 863, 40, 'Tšamorro'),
(133570, 866, 40, 'vaihda'),
(133571, 867, 40, 'Vaihda'),
(133572, 868, 40, 'Vaihda aktiivisuus'),
(133573, 869, 40, 'Vaihto epäonnistui! CouchDB yhteysongelma?'),
(133574, 870, 40, 'Muutoksia näössä'),
(133575, 871, 40, 'Muutoksia näössä'),
(133576, 872, 40, 'Vaihda salasana'),
(133577, 874, 40, 'Vaihdettu'),
(133578, 875, 40, 'Muutokset suolen toiminnassa'),
(133579, 876, 40, 'Vaihdetaan potilaan tunniste asiakirjaan'),
(133580, 877, 40, 'Ominaisuudet'),
(133581, 878, 40, 'Merkkiä jäljellä'),
(133582, 879, 40, 'Veloitus'),
(133583, 880, 40, 'Veloituksen pyöristys'),
(133584, 881, 40, 'Veloitus koodattu'),
(133585, 882, 40, 'Veloitukset'),
(133586, 883, 40, 'Kaavio'),
(133587, 884, 40, 'Kaavio Toiminta'),
(133588, 885, 40, 'Aktiivisuusraportin kaavio sisään- ja uloskirjautumista'),
(133589, 886, 40, 'Kaavio tunniste'),
(133590, 887, 40, 'Kaavio tunniste:'),
(133591, 888, 40, 'Kaavion nimiö'),
(133592, 889, 40, 'Kaavio Sijainti Toiminta'),
(133593, 890, 40, 'Kaavio muistiinpano'),
(133594, 891, 40, 'Kaavio numero'),
(133595, 892, 40, 'Kaavio tallennuksen sijainti'),
(133596, 893, 40, 'Kaavio seuranta'),
(133597, 894, 40, 'Potilaskorttien seuranta'),
(133598, 895, 40, 'Kaaviot Kirjattu ulos'),
(133599, 896, 40, 'Kaaviot ulkona'),
(133600, 897, 40, 'Tšetšeeni'),
(133601, 898, 40, 'Tarkista'),
(133602, 899, 40, 'tarkista'),
(133603, 900, 40, 'Valitse kaikki'),
(133604, 902, 40, 'Tarkista summa'),
(133605, 903, 40, 'Tarkista päiväys'),
(133606, 904, 40, 'Tarkista erilaiset käännökset kielitaulukon avulla.'),
(133607, 906, 40, 'Kirjaudu sisään'),
(133608, 907, 40, 'Tarkista syötettävä tieto'),
(133609, 908, 40, 'Tarkista kuvaajan kohteet'),
(133610, 909, 40, 'Tarkista laboratoriotulokset'),
(133611, 910, 40, 'Valintamerkki osoittaa tarkistetaan'),
(133612, 911, 40, 'Shekin numero'),
(133613, 912, 40, 'Shekin numero'),
(133614, 915, 40, 'Maksu shekillä'),
(133615, 916, 40, 'Valitse valintaruutu, jos tämä on salattu tiedosto'),
(133616, 917, 40, 'Ruksaa tämä jos haluat palvelun tuottajien näkevän oletusarvoisesti kaikki tapaamiset eikä vain heidän omiaan.'),
(133617, 919, 40, 'Shekki/Etuuksien selitys päiväys:'),
(133618, 920, 40, 'Shekki/Etuuksien selitys numero:'),
(133619, 921, 40, 'Shekki-/Viitenumero'),
(133620, 922, 40, 'Shekki-/Viitenumero'),
(133621, 923, 40, 'Lista valintaruuduista'),
(133622, 924, 40, 'lista valintaruuduista'),
(133623, 925, 40, 'valintaruutu tekstillä'),
(133624, 926, 40, 'Valintaruutu tekstillä'),
(133625, 927, 40, 'Yllä olevat valintaruudut ilmaisevat, haluatko hylätä ja poistaa HL7 asiakirjan'),
(133626, 928, 40, 'Rastitettu'),
(133627, 929, 40, 'Rastitettu = Kyllä, Tyhjä = Ei'),
(133628, 931, 40, 'Rastittamalla valintaruutu estää kaikki muutokset tämän käynnin aikana tehtyihin lomakkeisiin.'),
(133629, 932, 40, 'Kassa'),
(133630, 933, 40, 'Tarkistussumma'),
(133631, 934, 40, 'Rintakehä'),
(133632, 935, 40, 'Rintakehä / Hengitysteiden tutkimus'),
(133633, 936, 40, 'Rintakipu'),
(133634, 937, 40, 'Rintakipu:'),
(133635, 938, 40, 'Rintakipuja'),
(133636, 942, 40, 'Perimmäinen tulosyy'),
(133637, 943, 40, 'Lapsi'),
(133638, 945, 40, 'Lapsuusajan rokotusten tila (CQM)'),
(133639, 946, 40, 'Vilunväristyksiä'),
(133640, 947, 40, 'Kiinalainen'),
(133641, 948, 40, 'Kiina (Yksinkertaistettu)'),
(133642, 949, 40, 'Kiina (Perinteinen)'),
(133643, 950, 40, 'Kiropraktikko'),
(133644, 951, 40, 'Valinnat'),
(133645, 952, 40, 'Sappirakon poisto'),
(133646, 953, 40, 'sappirakon poisto'),
(133647, 954, 40, 'Sappirakon poisto'),
(133648, 955, 40, 'Valitse'),
(133649, 957, 40, 'Valintakriteeri'),
(133650, 958, 40, 'Valitse lataus tai näyttö'),
(133651, 959, 40, 'Valitse tiedosto'),
(133652, 960, 40, 'Valitse listasta'),
(133653, 961, 40, 'Valitse ulkoasun suunta'),
(133654, 962, 40, 'Valitse lista'),
(133655, 963, 40, 'Valitse paperikoko'),
(133656, 964, 40, 'Valitse PDF:n kieliasetus'),
(133657, 965, 40, 'Valitse tulostusmuoto tälle tapaamisraportille'),
(133658, 967, 40, 'Krooninen keuhkoputkentulehdus'),
(133659, 968, 40, 'Krooninen nivelkipu'),
(133660, 969, 40, 'Krooninen munuaistauti (CKD)'),
(133661, 970, 40, 'Krooninen nivelkalvontulehdus / nestekertymä / nivelkipu / kihti'),
(133662, 971, 40, 'Krooninen / Toistuva'),
(133663, 972, 40, 'Tšuvassi'),
(133664, 973, 40, 'Maksakirroosi'),
(133665, 974, 40, 'Maksakirroosi'),
(133666, 975, 40, 'Kaupunki'),
(133667, 976, 40, 'Kaupungin nimi'),
(133668, 977, 40, 'Kaupunki, lääni'),
(133669, 978, 40, 'Kaupunki, läänin postinumero'),
(133670, 979, 40, 'Kaupunki/Lääni'),
(133671, 980, 40, 'Vaatimus'),
(133672, 981, 40, 'Vaatimus '),
(133673, 982, 40, 'Vaatimuksen tila'),
(133674, 983, 40, 'Tarkastuksen analyysi päättynyt'),
(133675, 987, 40, 'Pyynnöt'),
(133676, 988, 40, 'Luokittelut'),
(133677, 989, 40, 'Tyhjennä'),
(133678, 990, 40, 'TYHJENNÄ AKTIIVINEN POTILAS'),
(133679, 991, 40, 'Tyhjennä kaikki'),
(133680, 992, 40, 'Tyhjennä HL7 tieto'),
(133681, 993, 40, 'Tyhjennä perustelut'),
(133682, 994, 40, 'Tyhjennä Smarty välimuisti'),
(133683, 997, 40, 'Klikkaa'),
(133684, 1001, 40, 'klikkaa lisätietoja varten'),
(133685, 1002, 40, 'Klikkaa ja näytä lisätiedot'),
(133686, 1003, 40, 'Tilaa yhteenveto klikkaamalla'),
(133687, 1004, 40, 'Klikkaa tuloksia varten'),
(133688, 1005, 40, 'Klikkaa tätä'),
(133689, 1006, 40, 'Luo uusi potilas klikkaamalla tätä.'),
(133690, 1007, 40, 'Klikkaa tätä ja päivitä vamman tilamuutokset sekä päivittäiset aktiviteetit'),
(133691, 1008, 40, 'Valitse päivä klikkaamalla tätä'),
(133692, 1009, 40, 'Valitse päivä ja aika klikkaamalla tätä'),
(133693, 1010, 40, 'Valitse aloituspäivä klikkaamalla tätä'),
(133694, 1011, 40, 'Valitse päivä ja aika klikkaamalla tätä'),
(133695, 1012, 40, 'Valitse alkamisaika ja päivä klikkaamalla tätä'),
(133696, 1013, 40, 'Valitse päättyisaika ja päivä klikkaamalla tätä'),
(133697, 1014, 40, 'Anna modulille määrittelyt klikkaamalla tätä'),
(133698, 1016, 40, 'Poista moduuli käytöstä klikkaamalla tätä'),
(133699, 1018, 40, 'Ota moduuli käyttöön klikkaamalla tätä'),
(133700, 1019, 40, 'Asenna moduli klikkaamalla tätä.'),
(133701, 1020, 40, 'hae klikkaamalla tätä'),
(133702, 1021, 40, 'päivitä oikeuksien, luokan ja kutsumanimen asetukset klikkaamalla tätä'),
(133703, 1022, 40, 'Näytä kaikki klikkaamalla tätä.'),
(133704, 1023, 40, 'Näytä ja tee kaavio klikkaamalla tätä'),
(133705, 1024, 40, 'Näytä ja tee kaavio kaikista laboratoriotuloksista.'),
(133706, 1025, 40, 'Näytä ja tee kaavio elintoiminnoista klikkaamalla tätä.'),
(133707, 1026, 40, 'Näytä potilaan tiedot klikkaamalla tätä'),
(133708, 1027, 40, 'Näytä ne kaikki klikkaamalla tätä.'),
(133709, 1028, 40, 'Näytä/muokkaa lisää yksityiskohtia klikkaamalla tätä'),
(133710, 1029, 40, 'Klikkaa Asenna-painiketta asentaaksesi tietokanta version seuraavalta päiväykseltä'),
(133711, 1030, 40, 'Klikkaa aikajaksoa lisätäksesi sitä'),
(133712, 1031, 40, 'Avaa potilastiedot klikkaamalla potilaan nimeä'),
(133713, 1032, 40, 'Klikkaa Päivitä nähdäksesi kaikki tulokset tai anna hakukriteeri tarkennetut tulokset.'),
(133714, 1033, 40, 'Klikkaa ja lisää diagnoosi'),
(133715, 1034, 40, 'Klikkaa ja lisää uusia komponentteja'),
(133716, 1035, 40, 'Lisää uusi käynti klikkaamalla'),
(133717, 1036, 40, 'Klikkaa ja valitse diagnoosi täsmennettäväksi.'),
(133718, 1037, 40, 'Lataa klikkaamalla'),
(133719, 1038, 40, 'Klikkaa ja muokkaa'),
(133720, 1039, 40, 'Klikkaa ja muokkaa kuvausta'),
(133721, 1040, 40, 'Klikkaa ja muokkaa tapahtumaa'),
(133722, 1041, 40, 'Klikkaa ja luo raportti'),
(133723, 1042, 40, 'Klikkaa ja sovita potilas'),
(133724, 1043, 40, 'Klikkaa ja tulosta'),
(133725, 1044, 40, 'Klikkaa ja vastaanota (lisää) uusi erä'),
(133726, 1045, 40, 'Klikkaa ja valitse'),
(133727, 1046, 40, 'Klikkaa ja valitse'),
(133728, 1047, 40, 'Klikkaa ja valitse standardin mukainen koodi tälle toiminnolle'),
(133729, 1048, 40, 'Klikkaa ja valitse vihtoehtoinen koodi toiminnolle'),
(133730, 1049, 40, 'Klikkaa ja valitse koodi tai muuta sitä'),
(133731, 1050, 40, 'Klikkaa ja valitse tai muuta CVX koodia'),
(133732, 1051, 40, 'Klikkaa ja valitse tai muokkaa diagnoosi'),
(133733, 1052, 40, 'Klikkaa ja valitse tai muuta palvelukoodia'),
(133734, 1053, 40, 'Klikkaa ja valitse potilas'),
(133735, 1054, 40, 'Klikkaa ja valitse rinnakkaiskoodi'),
(133736, 1055, 40, 'Klikkaa ja valitse suoritettavat toimenpiteet, mikäli tulos on poikkeava'),
(133737, 1056, 40, 'Klikkaa ja valitse halutut toimenpiteet'),
(133738, 1057, 40, 'Klikkaa ja järjestä'),
(133739, 1058, 40, 'Klikkaa ja näytä'),
(133740, 1059, 40, 'Klikkaa ja näytä tai muokkaa'),
(133741, 1060, 40, 'Klikkaa ja näytä/muokkaa'),
(133742, 1061, 40, 'Klikkaa Päivitä-painiketta jos haluat päivittää tietokannan seuraavalta päiväykseltä'),
(133743, 1062, 40, 'Osoita klikkaamalla missä edellä todettiin vastaavuus potilaaseen.'),
(133744, 1063, 40, 'Klikkaa:'),
(133745, 1064, 40, 'Asiakasohjelman sertifikaatin vanheneminen päivissä'),
(133746, 1065, 40, 'Asiakasohjelman sertifikaatin kelpoisuusaika'),
(133747, 1066, 40, 'Asiakasohjelman kelpoisuus tulee ilmoittaa numerona.'),
(133748, 1067, 40, 'Asiakas kopio'),
(133749, 1069, 40, 'Asiakkaan potilashistorian kooste'),
(133750, 1070, 40, 'Asiakkaan nimi'),
(133751, 1071, 40, 'Asiakasnumero'),
(133752, 1072, 40, 'Asiakasprofiili - Uudet asiakkaat'),
(133753, 1073, 40, 'Asiakasprofiili - Yksilöidyt asiakkaat'),
(133754, 1074, 40, 'Asiakkaat'),
(133755, 1075, 40, 'Klinikka'),
(133756, 1076, 40, 'Klinikan kopio'),
(133757, 1078, 40, 'Klinikan tunniste'),
(133758, 1079, 40, 'Lääketieteelliset'),
(133759, 1081, 40, 'Kliininen historia'),
(133760, 1083, 40, 'Kliiniset suunnitelmat'),
(133761, 1084, 40, 'Kliiniset laatutoimenpiteet (CQM)'),
(133762, 1085, 40, 'Kliiniset laatutoimenpiteet (CQM) - 2011'),
(133763, 1086, 40, 'Kliiniset laatutoimenpiteet (CQM) - 2014'),
(133764, 1087, 40, 'Kliiniset muistutukset'),
(133765, 1088, 40, 'Kliiniset raportit'),
(133766, 1089, 40, 'Kliinisen toimintasäännön luokka'),
(133767, 1090, 40, 'Kliinisen toimintasäännön nimike'),
(133768, 1091, 40, 'Kliinisen säännön suodatusmetodit'),
(133769, 1092, 40, 'Kliinisen säännön kohdistusmetodit'),
(133770, 1093, 40, 'Kliiniset säännöt'),
(133771, 1094, 40, 'Kliinisten sääntöjen ikäluokat'),
(133772, 1095, 40, 'Kliinisten sääntöjen vertailut'),
(133773, 1096, 40, 'Kliinisten sääntöjen vastaanottotyypit'),
(133774, 1097, 40, 'Kliinisten sääntöjen muistutusten säännönmukaiset vaihtoehdot'),
(133775, 1098, 40, 'Kliinisten sääntöjen muistuttajien inaktivoinnin optiot'),
(133776, 1099, 40, 'Kliinisten sääntöjen muistuttajien aikavälit'),
(133777, 1100, 40, 'Kliinisten sääntöjen muistuttajien metodit'),
(133778, 1101, 40, 'Kliinisten sääntöjen kohdistuksen aikavälit'),
(133779, 1102, 40, 'Lääketieteelliset päämäärät'),
(133780, 1103, 40, 'Lääketieteelliset termit'),
(133781, 1104, 40, 'Lääketieteellisten termien koodi(t)'),
(133782, 1106, 40, 'Hoitavat lääkärit'),
(133783, 1107, 40, 'Klooni'),
(133784, 1108, 40, 'Kloonaa edellinen käynti'),
(133785, 1109, 40, 'Sulje'),
(133786, 1110, 40, 'Sulje ikkuna'),
(133787, 1111, 40, 'sulje ikkuna'),
(133788, 1112, 40, 'Suljettu'),
(133789, 1113, 40, 'cm'),
(133790, 1114, 40, 'CMS 1500 lomakkeen marginaalit'),
(133791, 1115, 40, 'CMS 1500 lomakkeen paperikoko'),
(133792, 1118, 40, 'CMS tunniste'),
(133793, 1119, 40, 'CMS portaali'),
(133794, 1120, 40, 'CMS portaalin sisäänkirjautuminen'),
(133795, 1121, 40, 'CMS portaalin sisäänkirjautumisen tunniste'),
(133796, 1122, 40, 'CMS portaali ei käytössä!'),
(133797, 1123, 40, 'CMS portaalin salasana'),
(133798, 1125, 40, 'CMS portaalin sivuston osoite'),
(133799, 1126, 40, 'CMS portaalin käyttäjätunnus'),
(133800, 1128, 40, 'Omavastuu'),
(133801, 1129, 40, 'Omavastuu maksettu'),
(133802, 1130, 40, 'Omavastuu'),
(133803, 1131, 40, 'Koodi'),
(133804, 1132, 40, 'koodi'),
(133805, 1133, 40, 'Koodin haku'),
(133806, 1134, 40, 'Koodi annettava kahdella pienellä kirjaimella'),
(133807, 1135, 40, 'Koodin tai symbolin on kuvattava valuuttaa'),
(133808, 1136, 40, 'Koodi teksti'),
(133809, 1137, 40, 'Koodityyppi'),
(133810, 1138, 40, 'koodityyppi'),
(133811, 1139, 40, 'Koodityyppiä ei tunnistettu'),
(133812, 1140, 40, 'Koodityyppiä ei vielä määritelty'),
(133813, 1141, 40, 'Koodityypit'),
(133814, 1142, 40, 'Koodi(t)'),
(133815, 1143, 40, 'Koodattu'),
(133816, 1144, 40, 'Koodit'),
(133817, 1145, 40, 'Koodaus'),
(133818, 1146, 40, 'Koodaus (klikkaa opastukseen)'),
(133819, 1147, 40, 'Koodaus - kaikki käynnit (kirjoitus, rajoitettu kirjoitus)'),
(133820, 1148, 40, 'Koodaus - omat käynnit (kirjoitus, rajoitettu kirjoitus)'),
(133821, 1149, 40, 'Ei oikeutta koodaukseen'),
(133822, 1150, 40, 'Kahvi'),
(133823, 1151, 40, 'Kahvin kulutus'),
(133824, 1154, 40, 'Sulje'),
(133825, 1155, 40, 'sulje'),
(133826, 1156, 40, 'Sulje kaikki'),
(133827, 1157, 40, 'Sulje kaikki'),
(133828, 1158, 40, 'sulje kaikki'),
(133829, 1160, 40, 'Koontipäivä'),
(133830, 1161, 40, 'Koosteet'),
(133831, 1162, 40, 'Raportti koosteista'),
(133832, 1163, 40, 'Paksusuolen syöpä'),
(133833, 1164, 40, 'Paksusuolen syöpä seulonta'),
(133834, 1165, 40, 'Paksusuolen syöpä leikkaus'),
(133835, 1166, 40, 'Kolonoskopia'),
(133836, 1167, 40, 'kolonoskopia'),
(133837, 1168, 40, 'Väri'),
(133838, 1169, 40, 'Väri: lyhenne'),
(133839, 1170, 40, 'Sarake'),
(133840, 1171, 40, 'Sarakkeet'),
(133841, 1172, 40, 'Eriä koostetaan'),
(133842, 1173, 40, 'Pilkku'),
(133843, 1174, 40, 'Kommentti'),
(133844, 1175, 40, 'Kommentit'),
(133845, 1176, 40, 'Kommentit tähän tulokseen tai suositukseen'),
(133846, 1177, 40, 'Kaupallinen vakuutus Oy'),
(133847, 1178, 40, 'Suorita muutokset'),
(133848, 1179, 40, 'Viestintä'),
(133849, 1180, 40, 'Viestintä'),
(133850, 1182, 40, 'Yritys'),
(133851, 1183, 40, 'Yrityksen nimi'),
(133852, 1184, 40, 'Valmis'),
(133853, 1186, 40, 'Valmis'),
(133854, 1188, 40, 'Valmis?'),
(133855, 1190, 40, 'Palvelun tarjoajalla ongelmia'),
(133856, 1191, 40, 'Komplikaatiot raskaudenkeskeytyksessä'),
(133857, 1192, 40, 'Komponentit'),
(133858, 1193, 40, 'Tietokoneavusteinen lääketieteellinen tilausjärjestelmä'),
(133859, 1194, 40, 'Päätelmät'),
(133860, 1198, 40, 'Rakenne'),
(133861, 1199, 40, 'Rakenne'),
(133862, 1200, 40, 'Rakenne Vienti/Tuonti'),
(133863, 1201, 40, 'Rakenteen tallentaminen onnistui'),
(133864, 1202, 40, 'Määrittele Apache ja LibreEHR käyttämään asiakkaan SSL-sertifikaattia'),
(133865, 1203, 40, 'Määrittele Apache käyttämään asiakkaan SSL-sertifikaattia'),
(133866, 1204, 40, 'Määrittele Apache käyttämään HTTPS-protokollaa.'),
(133867, 1205, 40, 'Määrittele LibreEHR käyttämään asiakkaan SSL-sertifikaattia'),
(133868, 1208, 40, 'Vahvista uusi potilas'),
(133869, 1209, 40, 'Vahvista uusi salasana'),
(133870, 1210, 40, 'Vahvista maksu'),
(133871, 1214, 40, 'Synnynnäinen'),
(133872, 1216, 40, 'Yhteysvirhe'),
(133873, 1217, 40, 'Yhteydet'),
(133874, 1218, 40, 'Vakio'),
(133875, 1219, 40, 'vakion nimi'),
(133876, 1220, 40, 'Vakion nimi puuttuu'),
(133877, 1221, 40, 'vakiot'),
(133878, 1222, 40, 'Ummetus'),
(133879, 1223, 40, 'Perustiedot'),
(133880, 1226, 40, 'Käynnin lyhyt kuvaus'),
(133881, 1227, 40, 'Yhteystiedot'),
(133882, 1228, 40, 'Sähköposti'),
(133883, 1229, 40, 'Sähköpostiosoite'),
(133884, 1230, 40, 'Ota yhteys EMR Directiin phiMail Direct viestipalvelun tilaamista varten'),
(133885, 1231, 40, 'Yhteystiedot'),
(133886, 1232, 40, 'Piilolinssit'),
(133887, 1233, 40, 'Ota yhteys Medical Information Integration, LLC http://mi-squared.com Lab Exchange Service varten.'),
(133888, 1234, 40, 'Ota yhteys Medical Information Integration, LLC http://mi-squared.com tai ZH Healthcare http://zhservices.com eRx palvelun tilaamista varten'),
(133889, 1236, 40, 'Yhteyshenkilön nimi'),
(133890, 1237, 40, 'Yhteyshenkilö'),
(133891, 1238, 40, 'Yhteyshenkilön puhelinnumero'),
(133892, 1239, 40, 'Yhteyshenkilön puhelinnumero'),
(133893, 1240, 40, 'Ota yhteys ZMG:een (zmghealth@gmail.com) eRx palvelun tilaamista varten'),
(133894, 1241, 40, 'sisältää ainakin kolme neljästä seuraavasta:'),
(133895, 1242, 40, 'Säiliö-ryhmän nimi'),
(133896, 1243, 40, 'Sisältö'),
(133897, 1244, 40, 'sisältö');
INSERT INTO `lang_definitions` VALUES
(133898, 1245, 40, 'Asiayhteys'),
(133899, 1246, 40, 'Kontekstin nimi ei voi olla tyhjä'),
(133900, 1247, 40, 'Jatka'),
(133901, 1248, 40, 'Hoitosuunnitelma'),
(133902, 1249, 40, 'Potilaskertomus'),
(133903, 1251, 40, 'Ehkäisy'),
(133904, 1252, 40, 'Ehkäisyyn liittyvät asiat'),
(133905, 1253, 40, 'Ehkäisyyn liittyvät ongelmat (tarkenna)'),
(133906, 1254, 40, 'Ehkäisymenetelmä'),
(133907, 1255, 40, 'Ehkäisyssä käytetyt tuotteet'),
(133908, 1256, 40, 'Aiemmin aloitetut ehkäisyyn liittyvät palvelut'),
(133909, 1257, 40, 'Ehkäisy aloitettu'),
(133910, 1258, 40, 'Kontrollitunniste'),
(133911, 1259, 40, 'Kontrollinumero'),
(133912, 1261, 40, 'OMAVASTUU'),
(133913, 1262, 40, 'Omavastuu'),
(133914, 1263, 40, 'Omavastuu'),
(133915, 1264, 40, 'Osamaksu negatiivinen'),
(133916, 1265, 40, 'Omavastuu maksettu'),
(133917, 1266, 40, 'Omavastuut'),
(133918, 1267, 40, 'Keuhkoahtaumatauti'),
(133919, 1268, 40, 'Kopioi sivuja potilaan kuvaajaan'),
(133920, 1269, 40, 'Kopioi arvot'),
(133921, 1270, 40, 'Kopioidaan tietokannan tiedostoa. Tässä saattaa mennä tuokio…'),
(133922, 1271, 40, 'Tekijänoikeus tiedote'),
(133923, 1272, 40, 'Korni'),
(133924, 1273, 40, 'Sepelvaltimoiden ohitusleikkaus'),
(133925, 1274, 40, 'Sepelvaltimoiden ohitusleikkaus'),
(133926, 1275, 40, 'Korjattu'),
(133927, 1276, 40, 'Korsika'),
(133928, 1277, 40, 'CouchDB'),
(133929, 1278, 40, 'CouchDB yhteys epäonnistui.'),
(133930, 1279, 40, 'CouchDB tietokanta'),
(133931, 1280, 40, 'CouchDB tietokannan nimi'),
(133932, 1281, 40, 'CouchDB palvelin'),
(133933, 1282, 40, 'CouchDB palvelimen nimi'),
(133934, 1283, 40, 'CouchDB loki sallittu'),
(133935, 1284, 40, 'CouchDB salasana'),
(133936, 1285, 40, 'CouchDB portti'),
(133937, 1286, 40, 'CouchDB portti'),
(133938, 1287, 40, 'CouchDB tallennus ei onnistunut'),
(133939, 1288, 40, 'CouchDB käyttäjätunnus'),
(133940, 1289, 40, 'Yskä'),
(133941, 1290, 40, 'Köhä:'),
(133942, 1291, 40, 'yhdistäminen palvelimelle ei onnistunut'),
(133943, 1293, 40, 'taulukon avaaminen ei onnistunut'),
(133944, 1294, 40, 'Tiedoston lukeminen ei onnistunut'),
(133945, 1295, 40, 'Tiedoston lukeminen ei onnistunut'),
(133946, 1296, 40, 'Palvelinongelmien vuoksi sähköpostin lähettäminen ei onnistunut, '),
(133947, 1297, 40, 'Palvelinongelmien vuoksi sähköpostin lähettäminen ei onnistunut. '),
(133948, 1298, 40, 'Varmuuskopiohakemiston luonti ei onnistunut:'),
(133949, 1299, 40, 'Hakemiston poistaminen ei onnistunut:'),
(133950, 1300, 40, 'Vanhan varmuuskopiotiedoston poistaminen ei onnistunut:'),
(133951, 1301, 40, 'Vanhan viedyn tiedoston poistaminen ei onnistunut:'),
(133952, 1302, 40, 'INR seuranta'),
(133953, 1303, 40, 'Neuvonta menetelmä'),
(133954, 1304, 40, 'Terapia'),
(133955, 1305, 40, 'Terapiatoiminnot'),
(133956, 1306, 40, 'LAUSUNTOPYYNTÖ LOMAKE'),
(133957, 1307, 40, 'Lausyntopyyntö'),
(133958, 1308, 40, 'Maa'),
(133959, 1309, 40, 'Maa tietotyyppi'),
(133960, 1310, 40, 'Maa lista'),
(133961, 1311, 40, 'Maa lista (kirjoita, lisääminen mahdollista)'),
(133962, 1312, 40, 'Maan nimi esitettynä kahdella kirjaimella. (Esimerkiksi Suomi on FI, USA on US)'),
(133963, 1313, 40, 'lääni'),
(133964, 1315, 40, 'Lipuke'),
(133965, 1318, 40, 'CPT'),
(133966, 1319, 40, 'CPT koodi'),
(133967, 1320, 40, 'CPT koodit'),
(133968, 1324, 40, 'Murtumat:'),
(133969, 1325, 40, 'kerma'),
(133970, 1326, 40, 'Luo asiakasohjelman SSL sertifikaatti jokaiselle käyttäjälle tai koneelle.'),
(133971, 1327, 40, 'Luo asiakasohjelman SSL sertifikaatti jokaiselle käyttäjälle tai koneelle.'),
(133972, 1329, 40, 'Luo tapahtuma'),
(133973, 1330, 40, 'Luo ja lataa täysi varmuuskopio'),
(133974, 1332, 40, 'Luo varmuuskopio'),
(133975, 1333, 40, 'Luo ryhmäajo'),
(133976, 1334, 40, 'Luo asiakasohjelman sertifikaatti'),
(133977, 1335, 40, 'Luo asiakasohjelman SSL-sertifikaatti'),
(133978, 1336, 40, 'Luo duplikaatti'),
(133979, 1337, 40, 'Luo tapaaminen'),
(133980, 1338, 40, 'Luo tapahtumalokin varmuuskopio'),
(133981, 1339, 40, 'Luo uusi aihe'),
(133982, 1340, 40, 'Luo uusi potilas'),
(133983, 1344, 40, 'Luo potilasmerkintä'),
(133984, 1345, 40, 'Luo SSL sertifikaattivaltuutus ja palvelinsertifikaatti'),
(133985, 1346, 40, 'Luo käynti'),
(133986, 1347, 40, 'Luotu'),
(133987, 1348, 40, 'Luodaan vietävää tiedostoa'),
(133988, 1350, 40, 'Tämän tiedoston luominen etäpalvelimella ei onnistunut'),
(133989, 1351, 40, 'Luonut'),
(133990, 1352, 40, 'luotto'),
(133991, 1353, 40, 'Luottokortti'),
(133992, 1354, 40, 'Luotot'),
(133993, 1355, 40, 'Cree'),
(133994, 1356, 40, 'Kriteerit'),
(133995, 1357, 40, 'Kroatian'),
(133996, 1358, 40, 'Crohnin tauti'),
(133997, 1359, 40, 'Crohnin tauti'),
(133998, 1360, 40, 'CSV vienti'),
(133999, 1361, 40, 'CSV tiedosto'),
(134000, 1362, 40, 'CSV taulut'),
(134001, 1363, 40, 'Kuutio millimetriä'),
(134002, 1364, 40, 'Kuubalainen'),
(134003, 1365, 40, 'Valuutan desimaalimerkin paikka'),
(134004, 1366, 40, 'Valuutan desimaalimerkki'),
(134005, 1367, 40, 'Valuuttakoodi'),
(134006, 1368, 40, 'Valuutan tuhaterotin'),
(134007, 1369, 40, 'Nykyinen'),
(134008, 1370, 40, 'Alkoholin käyttö nyt'),
(134009, 1371, 40, 'Nykyinen konsultaatio'),
(134010, 1372, 40, 'Nykyiset kriteerit'),
(134011, 1373, 40, 'Tämän päivän korostusväri'),
(134012, 1374, 40, 'Tupakoi päivittäin'),
(134013, 1375, 40, 'Asiakirjan nimi muutettiin muotoon'),
(134014, 1377, 40, 'Nykyinen sijainti'),
(134015, 1378, 40, 'Nykyinen lääkitys'),
(134016, 1379, 40, 'Nykyinen salasana'),
(134017, 1380, 40, 'Nykyinen potilas'),
(134018, 1382, 40, 'Käyttää vapaa-ajan huumeita'),
(134019, 1383, 40, 'Satunnainen tupakoija'),
(134020, 1385, 40, 'Tämän hetkinen arvo'),
(134021, 1386, 40, 'Tällä hetkellä aktiivinen'),
(134022, 1387, 40, 'Tällä hetkellä käynnissä'),
(134023, 1388, 40, 'Nyt ei ole toimitiloja.'),
(134024, 1389, 40, 'Cushingin oireyhtymä'),
(134025, 1390, 40, 'Cushingin oireyhtymä'),
(134026, 1392, 40, 'Muokattu'),
(134027, 1393, 40, 'Muokattu syöte?'),
(134028, 1394, 40, 'Muokattu taulu'),
(134029, 1396, 40, 'Rokotuskoodi'),
(134030, 1397, 40, 'Rokotuskoodien kartoitus'),
(134031, 1398, 40, 'Rokotteet'),
(134032, 1399, 40, 'Sykli'),
(134033, 1400, 40, 'Ehkäisyn suoja-aika'),
(134034, 1401, 40, 'Ehkäisyn suoja-ajan faktori'),
(134035, 1402, 40, 'Ehkäisyn suoja-ajan raportti'),
(134036, 1403, 40, 'Tšekki'),
(134037, 1407, 40, 'Syntymäaika'),
(134038, 1408, 40, 'päivittäin'),
(134039, 1410, 40, 'Tanska'),
(134040, 1411, 40, 'Vastaava tieto on jo tietokannassa. Ole hyvä ja vaihda koodi ja/tai kuvaus'),
(134041, 1412, 40, 'Vastaava tieto on jo tietokannassa. Ole hyvä ja vaihda vakion nimi'),
(134042, 1413, 40, 'Tietosarakkeet'),
(134043, 1416, 40, 'Tietovirhe'),
(134044, 1417, 40, 'Tieto kohteesta'),
(134045, 1419, 40, 'tiedot kaikista tapaamisista tähän mennessä'),
(134046, 1420, 40, 'Tietotyyppi'),
(134047, 1421, 40, 'Tietokanta'),
(134048, 1422, 40, 'Tietokantaa ei ole asennettu.'),
(134049, 1423, 40, 'Tietokannan paikkaus'),
(134050, 1424, 40, 'Tietokannan raportti'),
(134051, 1425, 40, 'Tietokannan päivitys suoritettu.'),
(134052, 1426, 40, 'Tietosarakkeiden lukumäärän tulee olla 1 ja 999 väliltä'),
(134053, 1427, 40, 'Päivämäärä'),
(134054, 1428, 40, 'Päivämäärä'),
(134055, 1429, 40, 'Päiväys ja aika hallinnoitu'),
(134056, 1431, 40, 'Päiväys hallinnoitu'),
(134057, 1432, 40, 'Näytteiden keräämisen päiväys ja aika'),
(134058, 1433, 40, 'Havainnon päiväys ja aika'),
(134059, 1435, 40, 'Päiväys ja aika, jolloin näyte on otettu'),
(134060, 1436, 40, 'Päiväys ei voi olla myöhemmin kuin tänään'),
(134061, 1437, 40, 'Päivä jolloin ehkäisypalvelu on alkujaan toimitettu'),
(134062, 1438, 40, 'Luontipäivä'),
(134063, 1439, 40, 'Kuolinpäivä'),
(134064, 1440, 40, 'Tuhoamispäivä'),
(134065, 1441, 40, 'Päivän esitysmuoto'),
(134066, 1442, 40, 'Päiväyksen esitysmuoto kohdassa "tapaaminen päättyy" on epäkelpo'),
(134067, 1443, 40, 'Päiväyksen esitysmuoto kohdassa "tapaaminen alkaa" on epäkelpo'),
(134068, 1444, 40, 'Päiväyksen esitysmuoto kohdassa "Seuraava tapaaminen" on epäkelpo'),
(134069, 1445, 40, 'Päiväyksen esitysmuoto kohdassa "ei tavattu sitten" on epäkelpo'),
(134070, 1446, 40, 'Päiväyksen esitysmuoto kohdassa "nähty viimeksi" on epäkelpo'),
(134071, 1448, 40, 'Koodista puuttuu päiväys '),
(134072, 1450, 40, 'Pankkitalletuksen päiväys vvvv-kk-pp'),
(134073, 1451, 40, 'Laskutuspvm'),
(134074, 1452, 40, 'Syntymäaika'),
(134075, 1453, 40, 'Syntymäaika'),
(134076, 1454, 40, 'Syntymäaika'),
(134077, 1455, 40, 'Sisäänkirjautumisen päiväys'),
(134078, 1456, 40, 'Loukkaantumispäivämäärä'),
(134079, 1458, 40, 'Maksupäivä vvvv-kk-pp'),
(134080, 1459, 40, 'Lähetteen päiväys'),
(134081, 1460, 40, 'Vastauksen päiväys'),
(134082, 1461, 40, 'Raportin päiväys'),
(134083, 1462, 40, 'Käynnin pvm'),
(134084, 1463, 40, 'Käyntipäivä'),
(134085, 1464, 40, 'Käyntipäivä = Tänään'),
(134086, 1465, 40, 'Käyntipäivämäärä pp/kk/vvvv'),
(134087, 1466, 40, 'Käynnin pvm:'),
(134088, 1467, 40, 'Allekirjoituksen päiväys'),
(134089, 1468, 40, 'Muutoksen päiväys'),
(134090, 1469, 40, 'Tämän määräyksen päiväys'),
(134091, 1470, 40, 'Tämän raportin päiväys'),
(134092, 1472, 40, 'Tilauspäivä'),
(134093, 1474, 40, 'Päivämäärän valitsin'),
(134094, 1475, 40, 'Päivämäärän valitsin'),
(134095, 1476, 40, 'Lähetyspäivämäärä'),
(134096, 1477, 40, 'Viestin lähetyspäivä'),
(134097, 1478, 40, 'Päiväys ja aika'),
(134098, 1479, 40, 'Päiväys ei voi olla tyhjä'),
(134099, 1480, 40, 'Pvm/Tapaaminen'),
(134100, 1481, 40, 'Pvm/Muistio'),
(134101, 1482, 40, 'Pvm/Muistio viimeisestä'),
(134102, 1483, 40, 'Pvm/Aika'),
(134103, 1484, 40, 'Päivämäärä:'),
(134104, 1485, 40, 'Päivättyjen viestien loki'),
(134105, 1486, 40, 'Päivä'),
(134106, 1487, 40, 'päivä'),
(134107, 1489, 40, 'Päivänäkymä'),
(134108, 1490, 40, 'Päivä(t)'),
(134109, 1491, 40, 'viikonpäivä(t) Ma - Pe'),
(134110, 1492, 40, 'päivää'),
(134111, 1493, 40, 'Päivää'),
(134112, 1494, 40, 'päivää sitten'),
(134113, 1495, 40, 'Menetetyt pelit ja päivät'),
(134114, 1496, 40, 'päivää viime käynnistä'),
(134115, 1497, 40, 'Menetetyt päivät'),
(134116, 1498, 40, 'Päivät saraketta kohden:'),
(134117, 1500, 40, 'Päivät/Sarakkeet'),
(134118, 1501, 40, 'Tietokanta asennettu'),
(134119, 1502, 40, 'PP/KK/VVVV'),
(134120, 1503, 40, 'De-identifiointi'),
(134121, 1504, 40, 'De-identifiointiprosessi on valmis'),
(134122, 1505, 40, 'De-identifiointiprosessi on käynnissä'),
(134123, 1506, 40, 'De-identifiointiprosessi on käynnistetty ja toimii taustalla'),
(134124, 1507, 40, 'De-identifioitava tieto ei välttämättä ole täydellinen'),
(134125, 1508, 40, 'De-identifioitavat asiakirjat on tallennettu kohteeseen'),
(134126, 1509, 40, 'Huumevirasto'),
(134127, 1511, 40, 'Kuuro'),
(134128, 1512, 40, 'Virheenkorjaus informaatio'),
(134129, 1514, 40, 'Virheenkorjaus'),
(134130, 1515, 40, 'Joulukuu'),
(134131, 1516, 40, 'KUOLLUT'),
(134132, 1517, 40, 'Joulukuu'),
(134133, 1518, 40, 'Paunat desimaaleilla vai paunat ja unssit eroteltuna # (esim. 5#4)'),
(134134, 1520, 40, 'Vähennyskelpoinen'),
(134135, 1521, 40, 'Omavastuun täyttyminen'),
(134136, 1522, 40, 'Oletus'),
(134137, 1523, 40, 'Kalenterin oletusnäkymä'),
(134138, 1524, 40, 'Vakiokäyntilomakkeen tunniste'),
(134139, 1526, 40, 'Oletustoimipiste'),
(134140, 1527, 40, 'Oletuskieli'),
(134141, 1528, 40, 'Oletuskieli, jos muita ei sallittu tai valittu.'),
(134142, 1529, 40, 'Oletuslista (kirjoita, vain lisäys vaihtoehtoinen)'),
(134143, 1530, 40, 'Oletusmetodi'),
(134144, 1531, 40, 'Salasanan vanhenemisen oletusarvo päivissä'),
(134145, 1532, 40, 'Salasanan vanhenemisen oletusarvo päivissä. Jos arvo on 0, ominaisuus on poissa käytöstä.'),
(134146, 1533, 40, 'Potilaan kotimaan oletusarvo'),
(134147, 1535, 40, 'Oletuspainoarvo'),
(134148, 1536, 40, 'Oletuspalveluntarjoaja'),
(134149, 1538, 40, 'Käynnin syyn oletusarvo'),
(134150, 1540, 40, 'Oletusasetus'),
(134151, 1542, 40, 'Oletusmalli'),
(134152, 1546, 40, 'Oletusyksiköt'),
(134153, 1547, 40, 'Oletusarvo'),
(134154, 1548, 40, 'Oletusvarasto'),
(134155, 1549, 40, 'Oletus X12 kumppani'),
(134156, 1550, 40, 'Oletus/Yleiset'),
(134157, 1551, 40, 'Poista'),
(134158, 1552, 40, 'poista'),
(134159, 1553, 40, 'Toistuminen viiveellä (> 12 kk)'),
(134160, 1554, 40, 'Poista'),
(134161, 1555, 40, 'poista'),
(134162, 1556, 40, 'Poista luokat joiden tunniste(et) on: '),
(134163, 1557, 40, 'Poista luokka'),
(134164, 1559, 40, 'Poistaminen epäonnistui!'),
(134165, 1560, 40, 'Poista ryhmä'),
(134166, 1561, 40, 'Poista lista'),
(134167, 1562, 40, 'Poista sivut'),
(134168, 1563, 40, 'Poista potilas, käynti, lomake, aihe, dokumentti, maksu, laskutus tai maksusuoritus'),
(134169, 1565, 40, 'Poista rivi'),
(134170, 1566, 40, 'Poista valitut kohteet'),
(134171, 1567, 40, 'Poista valitut pyynnöt'),
(134172, 1568, 40, 'Poistettu onnistuneesti.'),
(134173, 1569, 40, 'Poista tämä dokumentti'),
(134174, 1570, 40, 'Poista tämä lomake'),
(134175, 1571, 40, 'Poista tämä muistiinpano'),
(134176, 1572, 40, 'Poisto onnistui'),
(134177, 1573, 40, 'Poisto onnistui.'),
(134178, 1574, 40, 'Poistaa'),
(134179, 1575, 40, 'Tämän tapahtuman poistoa ei voi perua. Tapahtumaa ei voida palauttaa kun se on kerran poistettu. Haluatko varmasti poistaa tapahtuman?'),
(134180, 1576, 40, 'Toimitus on varmistettu'),
(134181, 1577, 40, 'Toimitus ei sallittu määriteltyyn osoitteeseen.'),
(134182, 1578, 40, 'Toimitusta ei voi suorittaa määriteltyyn osoitteeseen.'),
(134183, 1579, 40, 'Liitteenä olevat potilasasiakirjat on toimitettu potilaan pyynnöstä'),
(134184, 1580, 40, 'Liitteenä olevat potilasasiakirjat on toimitettu potilaan pyynnöstä.'),
(134185, 1581, 40, 'Dementia'),
(134186, 1582, 40, 'Väestörakenne'),
(134187, 1583, 40, 'Väestörakenne (kirjoita, vain lisäys vaihtoehtoinen)'),
(134188, 1585, 40, 'Väestörakenteen suodatuskriteerit'),
(134189, 1586, 40, 'Väestörakenteelle ei valtuutusta'),
(134190, 1587, 40, 'Väestörakenteelle ei valtuutusta.'),
(134191, 1588, 40, 'Evätty'),
(134192, 1589, 40, 'Nimittäjä'),
(134193, 1590, 40, 'Hampaat'),
(134194, 1591, 40, 'Lista hammasongelmista'),
(134195, 1592, 40, 'Hammasongelmat'),
(134196, 1593, 40, 'Riippuvaiset modulit'),
(134197, 1594, 40, 'Riippuvuusongelma'),
(134198, 1596, 40, 'Talletus pvm'),
(134199, 1597, 40, 'Talletuksen päiväys ei voi olla tämän päivän jälkeen'),
(134200, 1598, 40, 'Talletus pvm:'),
(134201, 1599, 40, 'Masentunut'),
(134202, 1600, 40, 'Masennus'),
(134203, 1601, 40, 'Laskeva'),
(134204, 1602, 40, 'Kuvaus'),
(134205, 1603, 40, 'kuvaus'),
(134206, 1604, 40, 'Kuvaus on oletusteksti'),
(134207, 1605, 40, 'Tiedoksiannon kuvaus'),
(134208, 1606, 40, 'Tämän menettelyn kuvaus tai tuloksen koodi'),
(134209, 1607, 40, 'Kuvauksen käännös'),
(134210, 1608, 40, 'Haluttu tiedostonimi'),
(134211, 1609, 40, 'Tavoite'),
(134212, 1610, 40, 'Kohdetiedostonimi'),
(134213, 1611, 40, 'Tuhoa erä'),
(134214, 1612, 40, 'Tuhoa…'),
(134215, 1613, 40, 'Tuhottu'),
(134216, 1614, 40, 'Tuhotut lääkkeet'),
(134217, 1615, 40, 'Raportti tuhotuista lääkkeistä'),
(134218, 1616, 40, 'Lisätieto'),
(134219, 1617, 40, 'Lisätietoja'),
(134220, 1619, 40, 'Poikkeava kehitys'),
(134221, 1620, 40, 'Diabetes'),
(134222, 1621, 40, 'Diabetes'),
(134223, 1622, 40, 'Diabetes: Verenpaineen hoito (CQM)'),
(134224, 1623, 40, 'Diabetes: Silmätutkimus'),
(134225, 1624, 40, 'Diabetes: Silmätutkimus (CQM)'),
(134226, 1625, 40, 'Diabetes: Jalkojen tutkimus'),
(134227, 1626, 40, 'Diabetes: Jalkojen tutkimus (CQM)'),
(134228, 1628, 40, 'Diabetes: Hemoglobiini A1C'),
(134229, 1629, 40, 'Diabetes: LDL hoito ja seuranta (CQM)'),
(134230, 1630, 40, 'Diabetes: Virtsan microalbumiini'),
(134231, 1631, 40, 'Diagnoosi'),
(134232, 1632, 40, 'Diagnoosit'),
(134233, 1633, 40, 'Diagnoosi tai pääasiallinen oire'),
(134234, 1634, 40, 'Diagnoosikoodi'),
(134235, 1635, 40, 'Diagnoosikoodit'),
(134236, 1636, 40, 'Diagnoosin pvm'),
(134237, 1637, 40, 'Diagnoosi on koodattava linkitettyyn käyntiin'),
(134238, 1638, 40, 'Diagnoosin nimi'),
(134239, 1639, 40, 'Diagnoosiraportti'),
(134240, 1640, 40, 'Diagnoosiraportointi'),
(134241, 1641, 40, 'Vain diagnoosiraportointi'),
(134242, 1642, 40, 'Dignoosin otsikko'),
(134243, 1643, 40, 'Diagnoosi:'),
(134244, 1644, 40, 'Diagnoosi: '),
(134245, 1645, 40, 'Diagnostiset testit:'),
(134246, 1646, 40, 'Valitsee'),
(134247, 1648, 40, 'Ripuli'),
(134248, 1650, 40, 'Sanelu'),
(134249, 1651, 40, 'Sanelu: '),
(134250, 1652, 40, 'Vastaanotitko ilmoituksen HIPAA ilmoituksesta?'),
(134251, 1654, 40, 'Digitaalisesti allekirjoitettu'),
(134252, 1657, 40, 'Suoraposti'),
(134253, 1658, 40, 'Suoraviestien loki'),
(134254, 1659, 40, 'Suoraviesti vastaanotettu.'),
(134255, 1660, 40, 'Suoraviestintä ei ole juuri nyt käytettävissä.'),
(134256, 1661, 40, 'Suoraviestinnässä lähetysvirhe.'),
(134257, 1664, 40, 'Hakemiston poistaminen epäonnistui; jatkaa.'),
(134258, 1665, 40, 'Vammaisuus'),
(134259, 1666, 40, 'Poista käytöstä'),
(134260, 1667, 40, 'Poista kalenteri käytöstä'),
(134261, 1669, 40, 'Poista rokotukset käytöstä'),
(134262, 1672, 40, 'Poista phpMyAdmin käytöstä'),
(134263, 1673, 40, 'Poista reseptit käytöstä'),
(134264, 1674, 40, 'Poista käyttäjäryhmät käytöstä'),
(134265, 1675, 40, 'ei käytössä'),
(134266, 1676, 40, 'Työkyvytön'),
(134267, 1677, 40, 'Alle 65 vuotiaat työkyvyttömyyseläkkeellä olevat, joilla ryhmäsairausvakuutus (LGHP)'),
(134268, 1678, 40, 'DISC'),
(134269, 1679, 40, 'Hylkää'),
(134270, 1680, 40, 'Hylätty'),
(134271, 1681, 40, 'Vuoto'),
(134272, 1682, 40, 'Vuotoa virtsaputkesta'),
(134273, 1684, 40, 'Vuoto oikea'),
(134274, 1685, 40, 'Vuoto oikea:'),
(134275, 1688, 40, 'Purkautunut'),
(134276, 1689, 40, 'Tiedoksiannon info'),
(134277, 1690, 40, 'Tiedoksiannon tyyppi'),
(134278, 1691, 40, 'Tiedoksiannon tyypit'),
(134279, 1692, 40, 'Tiedoksiannot'),
(134280, 1694, 40, 'Alennus'),
(134281, 1695, 40, 'Alennuksen määrä'),
(134282, 1696, 40, 'Alennukset'),
(134283, 1697, 40, 'Alennusprosentti'),
(134284, 1698, 40, 'Alennukset määräsummina'),
(134285, 1699, 40, 'Alennukset uloskirjautuessa annetaan rahamäärinä, ei prosenttiperusteisina.'),
(134286, 1700, 40, 'Diskreetti tulos'),
(134287, 1701, 40, 'Sairaus'),
(134288, 1702, 40, 'Sijoiltaanmeno'),
(134289, 1703, 40, 'Lähetys #'),
(134290, 1704, 40, 'Lähetys'),
(134291, 1705, 40, 'Vastaanotetun dokumentin lähetys'),
(134292, 1706, 40, 'Annosteltu'),
(134293, 1708, 40, 'Näytä dokumentit'),
(134294, 1709, 40, 'Näytetäänkö tapahtumien päiväykset blokkina?'),
(134295, 1710, 40, 'Brittiläisen mittajärjestelmän esitystapa'),
(134296, 1711, 40, 'Kuinka monta tapahtumaa näytetään?'),
(134297, 1713, 40, 'Näytetäänkö sijainti blokkina?'),
(134298, 1714, 40, 'Näyttönimi'),
(134299, 1715, 40, 'Näytetäänkö kalenteri?'),
(134300, 1718, 40, 'Näytetäänkö tämänpäiväiset tapahtumat blokkina?'),
(134301, 1719, 40, 'Näytetäänkö aiheet blokkina?'),
(134302, 1720, 40, 'Näytetäänkö tulevat tapahtumat blokkina?'),
(134303, 1721, 40, 'Näytettävät sarakkeet'),
(134304, 1722, 40, 'Näytetään seuraava lukumäärä viimeisimmistä esitettävistä tiedoista:'),
(134305, 1723, 40, 'Näytetään seuraava lukumäärä viimeisimmistä muistiinpanoista'),
(134306, 1724, 40, 'Näytetään seuraava lukumäärä viimeisimmistä muistiinpanoista:'),
(134307, 1725, 40, 'Jakelu'),
(134308, 1726, 40, 'Jakelut'),
(134309, 1727, 40, 'Jakelija'),
(134310, 1729, 40, 'Divertikuliitti'),
(134311, 1730, 40, 'Divertikuliitti leikkaus'),
(134312, 1731, 40, 'Divertikuliitti'),
(134313, 1732, 40, 'Divertikuliitti leikkaus'),
(134314, 1733, 40, 'Eronnut'),
(134315, 1734, 40, 'Huimaus:'),
(134316, 1735, 40, 'Älä vaihda'),
(134317, 1742, 40, 'Älä näytä kalenteria.'),
(134318, 1744, 40, 'Ei inventoitavia ja myytäviä tuotteita'),
(134319, 1745, 40, 'Älä vaadi valtuutusta potilasmuistioihin'),
(134320, 1747, 40, 'älä tallenna'),
(134321, 1748, 40, 'älä korvaa'),
(134322, 1749, 40, 'älä tee mitään'),
(134323, 1751, 40, 'Haluatko todella poistaa'),
(134324, 1752, 40, 'Haluatko todella poistaa valitun?'),
(134325, 1753, 40, 'Haluatko todella poistaa tämän ryhmän?'),
(134326, 1754, 40, 'Haluatko todellakin poistaa?'),
(134327, 1755, 40, 'Haluatko jatkaa?'),
(134328, 1756, 40, 'Haluatko poistaa tämän?'),
(134329, 1757, 40, 'Haluatko poistaa?'),
(134330, 1758, 40, 'Haluatko poistaa tämän tietueen?'),
(134331, 1759, 40, 'Haluatko jatkaa lisäämällä tämän uuden potilaan?'),
(134332, 1760, 40, 'Haluatko jatkaa uudella nimellä?'),
(134333, 1761, 40, 'Haluatko poistaa LOPULLISESTI tämän rokotustiedon?'),
(134334, 1762, 40, 'Syntymäaika'),
(134335, 1763, 40, 'Syntymäaika puuttuu, anna se mikäli mahdollista'),
(134336, 1765, 40, 'Lääkäri'),
(134337, 1766, 40, 'Lääkäri:'),
(134338, 1767, 40, 'Lääkärin nimi ja allekirjoitus'),
(134339, 1768, 40, 'Asiakirja'),
(134340, 1769, 40, 'asiakirja'),
(134341, 1770, 40, 'Asiakirjaluokat'),
(134342, 1771, 40, 'Asiakirjaluokkaa laboratoriotuloksille ei ole'),
(134343, 1772, 40, 'Asiakirjaluokan nimi sähköisesti vastaanotettujen laboratoriotulosten tallentamiseen.'),
(134344, 1774, 40, 'Asiakirjaluokka tai Hylkää'),
(134345, 1775, 40, 'Asiakirjaa ei voitu liittää potilastunnisteeseen'),
(134346, 1777, 40, 'Asiakirjan päiväys'),
(134347, 1778, 40, 'Asiakirjan päiväyksen ja aiheen päivitys onnistui'),
(134348, 1779, 40, 'Asiakirjan tunniste'),
(134349, 1780, 40, 'Asiakirja siirretty uuteen luokkaan'),
(134350, 1781, 40, 'Asiakirja liitetty potilastunnisteeseen'),
(134351, 1783, 40, 'Asiakirjan tietojen eheys on tarkistettu'),
(134352, 1784, 40, 'Asiakirjojen tallennus tapa'),
(134353, 1785, 40, 'Asiakirja nimetty uudelleen.'),
(134354, 1786, 40, 'Asiakirjan yhdistäminen tapaamiseen onnistui'),
(134355, 1787, 40, 'Asiakirjamallien hallinta'),
(134356, 1788, 40, 'Asiakirjamallit'),
(134357, 1789, 40, 'Asiakirja(t)'),
(134358, 1790, 40, 'Asiakirjat/Kuvat tallennus'),
(134359, 1791, 40, 'Asiakirjat'),
(134360, 1792, 40, 'Asiakirjat (kirjoita, "vain lisäys" vaihtoehtoinen)'),
(134361, 1794, 40, 'Arvioinnin päiväys'),
(134362, 1797, 40, 'ei näytä olevan voimassa'),
(134363, 1798, 40, 'Salliiko tämä tyyppi samankaltaiset koodit?'),
(134364, 1799, 40, 'Avoliitossa'),
(134365, 1800, 40, 'Älä tallenna'),
(134366, 1801, 40, 'Älä tallenna'),
(134367, 1802, 40, 'Älä tallenna muutoksia'),
(134368, 1803, 40, 'Tehty'),
(134369, 1805, 40, 'Tehty. Lähetetään ladattavaksi.'),
(134370, 1806, 40, 'Käynti PVM'),
(134371, 1807, 40, 'Annostus'),
(134372, 1809, 40, 'muokkaukseen tuplaklikkauksella'),
(134373, 1810, 40, 'Diplopia'),
(134374, 1811, 40, 'Lataa'),
(134375, 1814, 40, 'Lataa kuitenkin'),
(134376, 1815, 40, 'Lataa laskutusasiakirja, lähetä kirjanpitoon ja merkitse laskutetuksi'),
(134377, 1817, 40, 'Lataa sertifikaatit'),
(134378, 1818, 40, 'Lataa konfiguraation tiedot'),
(134379, 1819, 40, 'Lataa asiakirjamalli tälle potilaalle ja käynnille'),
(134380, 1820, 40, 'lataa salattu asiakirja'),
(134381, 1824, 40, 'Lataa tai poista asiakirjamalli'),
(134382, 1825, 40, 'Lataa PDF'),
(134383, 1827, 40, 'Lataa valitut lausunnot'),
(134384, 1831, 40, 'Siirretään vetämällä'),
(134385, 1832, 40, 'Kuolaaminen'),
(134386, 1833, 40, 'Ajokortti tai henkilöllisyystodistus'),
(134387, 1834, 40, 'Lääke'),
(134388, 1835, 40, 'Lääkehaku'),
(134389, 1836, 40, 'Lääkelomakkeet'),
(134390, 1837, 40, 'Lääkkeen tunniste puuttuu!'),
(134391, 1838, 40, 'Lääkkeen annosteluvälit'),
(134392, 1839, 40, 'Lääkkeiden inventaari'),
(134393, 1840, 40, 'Lääkkeen nimi'),
(134394, 1841, 40, 'Lääkkeen antotapa'),
(134395, 1845, 40, 'Lääkeyksiköt'),
(134396, 1846, 40, 'Lääkkeet'),
(134397, 1847, 40, 'Lääkkeet ja tuotteet'),
(134398, 1848, 40, 'Kserostomia – Suun kuivuminen'),
(134399, 1849, 40, 'DSM-IV diagnoosit'),
(134400, 1850, 40, 'DT 1'),
(134401, 1851, 40, 'DT 2'),
(134402, 1852, 40, 'DT 3'),
(134403, 1853, 40, 'DT 4'),
(134404, 1854, 40, 'DT 5'),
(134405, 1855, 40, 'DTaP 1'),
(134406, 1856, 40, 'DTaP 2'),
(134407, 1857, 40, 'DTaP 3'),
(134408, 1858, 40, 'DTaP 4'),
(134409, 1859, 40, 'DTaP 5'),
(134410, 1860, 40, 'Maksettava'),
(134411, 1861, 40, 'Eräpäivä'),
(134412, 1862, 40, 'Eräpäivä kk/pp/vvvv tai yyyy-kk-pp'),
(134413, 1863, 40, 'Eräpäivä:'),
(134414, 1869, 40, 'Pudotetaan LibreEHR tietokanta'),
(134415, 1870, 40, 'Pudotetaan LibreEHR web hakemistopuu'),
(134416, 1871, 40, 'Pudotetaan phpGACL tietokanta'),
(134417, 1872, 40, 'Pudotetaan phpGACL web hakemistopuu'),
(134418, 1873, 40, 'Pudotetaan SQL-Ledger tietokanta'),
(134419, 1874, 40, 'Pudotetaan SQL-Ledger web hakemistopuu'),
(134420, 1875, 40, 'Kaksoiskappaleiden haku'),
(134421, 1876, 40, 'Kaksinkertainen tunniste rivillä'),
(134422, 1877, 40, 'Kaksinkertainen nimi rivillä'),
(134423, 1878, 40, 'VAROITUS KAKSOISKAPPALEESTA'),
(134424, 1880, 40, 'kesto'),
(134425, 1881, 40, 'Kesto'),
(134426, 1882, 40, 'Hollanti'),
(134427, 1884, 40, 'Dysfagia'),
(134428, 1885, 40, 'Hengenahdistus:'),
(134429, 1886, 40, 'Dysuria'),
(134430, 1887, 40, 'Dzongkha'),
(134431, 1888, 40, 'E-Resepti?'),
(134432, 1889, 40, 'E-Raportit'),
(134433, 1893, 40, 'Jokaisen vastaanottajan täytyy kuitata viesti vastaanotetuksi'),
(134434, 1894, 40, 'Varhainen uusiutuminen (< 2 kk)'),
(134435, 1895, 40, 'Korvat'),
(134436, 1896, 40, 'Sydänsähkökäyrä'),
(134437, 1898, 40, 'Turvotus'),
(134438, 1899, 40, 'edi historia'),
(134439, 1900, 40, 'EDI historia'),
(134440, 1902, 40, 'EDI-271 tiedosto ladattu'),
(134441, 1904, 40, 'Muokkaa'),
(134442, 1905, 40, 'muokkaa'),
(134443, 1906, 40, 'Muokkaa allergioita'),
(134444, 1907, 40, 'Muokkaa luokkia'),
(134445, 1908, 40, 'Muokkaa määritelmiä'),
(134446, 1909, 40, 'Muokkaa määritelmiä'),
(134447, 1910, 40, 'Muokkaa diagnooseja kohteelle'),
(134448, 1912, 40, 'Muokkaa toimipaikkoja'),
(134449, 1913, 40, 'Muokkaa toimipaikkaa'),
(134450, 1914, 40, 'Muokkaa toimipaikan tietoja'),
(134451, 1916, 40, 'Muokkaa tiedostoa kohteessa'),
(134452, 1917, 40, 'Muokkaa lomaketta'),
(134453, 1918, 40, 'Muokkaa yleisasetuksia'),
(134454, 1919, 40, 'Ei oikeuksia muokkaamiseen!'),
(134455, 1920, 40, 'Muokkaa ulkoasua'),
(134456, 1921, 40, 'Muokka listaa'),
(134457, 1922, 40, 'Muokkaa maksua'),
(134458, 1923, 40, 'Muokkaa rakennetta'),
(134459, 1924, 40, 'Muokkaa käyttäjätietoja'),
(134460, 1925, 40, 'Muokkaa käyttäjän asetuksia'),
(134461, 1926, 40, 'Muokkaa antamiasi tietoja'),
(134462, 1927, 40, 'Muokkaus epäonnistui'),
(134463, 1928, 40, 'Koulutus'),
(134464, 1929, 40, 'Koulutuksen päiväys'),
(134465, 1930, 40, 'Koulutus materiaalia kohteelle'),
(134466, 1932, 40, 'Voimaantulopäivä'),
(134467, 1934, 40, 'Vaikuttavuus'),
(134468, 1936, 40, 'Siemensyöksyt'),
(134469, 1937, 40, 'Kyynärpää'),
(134470, 1938, 40, 'Kyynärpään vaivat'),
(134471, 1939, 40, 'Sähköinen'),
(134472, 1942, 40, 'Sähköiset toimeksiannot'),
(134473, 1943, 40, 'Sähköiset raportit'),
(134474, 1944, 40, 'Kelpoisuus'),
(134475, 1946, 40, 'Kelpoisuusvaste'),
(134476, 1948, 40, 'Hyväksyttävä'),
(134477, 1949, 40, 'Sähköposti'),
(134478, 1950, 40, 'sähköposti'),
(134479, 1951, 40, 'Sähköpostiosoite'),
(134480, 1952, 40, 'Sähköpostiosoite puuttuu'),
(134481, 1958, 40, 'Ilmoitus sähköpostista'),
(134482, 1959, 40, 'Tunnit jolloin sähköpostista ilmoitetaan'),
(134483, 1960, 40, 'Raportti ilmoitetuista sähköposteista'),
(134484, 1961, 40, 'Lähetä sähköposti ennen'),
(134485, 1962, 40, 'Sähköpostin lähettäjä'),
(134486, 1963, 40, 'Sähköposti lähetetty'),
(134487, 1964, 40, 'Sähköpostin vastaanottaja'),
(134488, 1965, 40, 'Sähköposti aihe'),
(134489, 1966, 40, 'Sähköpostiviesti, Käytettävä tagi: ***NAME , esim. Hyvä ***NAME***'),
(134490, 1967, 40, 'Sähköpostiviesti, Käytettävä tagi: ***NAME , esim. Hyvä ***NAME*** {{Älä käännä vakiota ***NAME*** tässä elementissä.}}'),
(134491, 1968, 40, 'Sähköpostin välitystapa'),
(134492, 1969, 40, 'Sähköposti lähetetty osoitteeseen'),
(134493, 1971, 40, 'Hätäyhteystiedot'),
(134494, 1972, 40, 'Hätäyhteyshenkilö'),
(134495, 1973, 40, 'Hätäyhteyshenkilön puhelinnumero'),
(134496, 1974, 40, 'Jälkiehkäisy'),
(134497, 1980, 40, 'Hätäpuhelin'),
(134498, 1982, 40, 'Keuhkolaajentuma'),
(134499, 1983, 40, 'Työntekijä'),
(134500, 1984, 40, 'Työnantaja'),
(134501, 1985, 40, 'Työnantajan osoite'),
(134502, 1986, 40, 'Työnantajan tiedot'),
(134503, 1987, 40, 'Työnantajan nimi'),
(134504, 1988, 40, 'TYHJÄ'),
(134505, 1989, 40, 'Tyhjä'),
(134506, 1990, 40, 'Salasanan jättäminen tyhjäksi ei ole sallittua'),
(134507, 1992, 40, 'Tyhjä arvo kohdassa "Sähköpostin lähettäjä"'),
(134508, 1993, 40, 'Tyhjä arvo kohdassa "Sähköpostin aihe"'),
(134509, 1994, 40, 'Tyhjä arvo kohdassa "Sähköpostin sisältö"'),
(134510, 1996, 40, 'Tyhjä arvo kohdassa "Salasana"'),
(134511, 1999, 40, 'Tyhjä arvo kohdassa "Käyttäjätunnus"'),
(134512, 2001, 40, 'Salli'),
(134513, 2016, 40, 'Salli asiakasohjelman SSL'),
(134514, 2017, 40, 'Salli valtuutus asiakasohjelman SSL sertifikaatilla.'),
(134515, 2030, 40, 'Salli palkkiot vasemmassa navigaatiossa'),
(134516, 2051, 40, 'Salli ulkoisen potilasportaalin käyttö'),
(134517, 2052, 40, 'Salli ulkoisen potilasportaalin käyttö.'),
(134518, 2053, 40, 'Salli paikallisen potilasportaalin käyttö'),
(134519, 2055, 40, 'Salli paikallisen potilasportaalin käyttö.'),
(134520, 2061, 40, 'Salli tuki skannerille'),
(134521, 2068, 40, 'sallittu'),
(134522, 2071, 40, 'Käynti'),
(134523, 2072, 40, 'Käynti'),
(134524, 2073, 40, 'Käynti'),
(134525, 2074, 40, 'käynti'),
(134526, 2075, 40, 'Käynti '),
(134527, 2080, 40, 'käynnin tiedot'),
(134528, 2081, 40, 'Käynnin päiväys'),
(134529, 2086, 40, 'Käyntilomakkeet'),
(134530, 2087, 40, 'käynnin terveydentilan ja käyttäytymisen arviointi'),
(134531, 2088, 40, 'Käyntihistoria'),
(134532, 2089, 40, 'Käynnin tunniste'),
(134533, 2091, 40, 'Käynnin numero'),
(134534, 2099, 40, 'Käyntilomakkeen paperikoko'),
(134535, 2100, 40, 'Käynnin maksu'),
(134536, 2107, 40, 'käynti psykiatrilla / psykologilla'),
(134537, 2108, 40, 'Käynnin tilastot'),
(134538, 2109, 40, 'Käynnin yhteenveto'),
(134539, 2110, 40, 'Käynti on koodattu'),
(134540, 2111, 40, 'Käynti:'),
(134541, 2113, 40, 'Käynnit'),
(134542, 2114, 40, 'Käynnit ja lomakkeet'),
(134543, 2115, 40, 'Käynnit ja lomakkeet'),
(134544, 2116, 40, 'Ei valtuutusta vastaanotoille'),
(134545, 2117, 40, 'Raportti vastaanotoista'),
(134546, 2120, 40, 'Salaus'),
(134547, 2121, 40, 'Päättynyt'),
(134548, 2122, 40, 'Päättynyt (vvvv-kk-pp) '),
(134549, 2123, 40, 'Päättymispäivä'),
(134550, 2124, 40, 'Päättymispäivä'),
(134551, 2126, 40, 'Päättymispäivän tulee olla aloituspäivän jälkeen'),
(134552, 2127, 40, 'Päättymispäivä:'),
(134553, 2130, 40, 'Raportin loppu'),
(134554, 2131, 40, 'Lopetusaika'),
(134555, 2133, 40, 'Hoidon päättymispäivä vvvv-kk-pp'),
(134556, 2135, 40, 'Päättymisaika kalenteritapahtumille.'),
(134557, 2137, 40, 'Endokrinologia'),
(134558, 2138, 40, 'Endoskopia'),
(134559, 2141, 40, 'Englanti'),
(134560, 2142, 40, 'Englanti '),
(134561, 2143, 40, 'Englanti (Intian)'),
(134562, 2144, 40, 'Englanti (Standardi)'),
(134563, 2146, 40, 'Varmista että LibreEHR:llä on oikeus kirjoittaa hakemistoon'),
(134564, 2149, 40, 'Antamalla diagnoosikoodin poissuljetaan kaikki lähetteet ilman sitä'),
(134565, 2150, 40, 'Syötä muutos ...'),
(134566, 2151, 40, 'Kirjoita viesti tähän'),
(134567, 2152, 40, 'Anna tietokannan root salasana'),
(134568, 2153, 40, 'Anna tietokannan root käyttäjätunnus'),
(134569, 2154, 40, 'Anna diagnoosi'),
(134570, 2155, 40, 'Anna lääkkeet'),
(134571, 2156, 40, 'Anna käynti'),
(134572, 2157, 40, 'Anna käynnin numero'),
(134573, 2158, 40, 'Anna rokotukset'),
(134574, 2159, 40, 'Anna avain'),
(134575, 2160, 40, 'Anna uusi tieto'),
(134576, 2161, 40, 'Anna uusi lääni'),
(134577, 2162, 40, 'Anna vastaanottajan suora osoite'),
(134578, 2164, 40, 'Anna uudelleentunnistautumiskoodi'),
(134579, 2165, 40, 'Anna hakukriteeri yläpuolelle'),
(134580, 2167, 40, 'merkintää'),
(134581, 2176, 40, 'Epilepsia'),
(134582, 2181, 40, 'Pyyhi'),
(134583, 2182, 40, 'Erektiot'),
(134584, 2183, 40, 'Virhe'),
(134585, 2184, 40, 'VIRHE'),
(134586, 2185, 40, 'Virhe laboratoriotulosten kuittauksen varmistamisessa'),
(134587, 2188, 40, 'Virhe sukupuolen valinnassa'),
(134588, 2193, 40, 'Virhe tiedoston gzip-pakkaamisessa: '),
(134589, 2194, 40, 'Virhe KYLLÄ tai EI valinnassa'),
(134590, 2195, 40, 'Virhe ladatun tiedoston esikatselussa'),
(134591, 2196, 40, 'Virhe tiedoston käsittelyssä'),
(134592, 2197, 40, 'Virhe tiedoston lataamisessa'),
(134593, 2198, 40, 'Virhe viestin poistamisessa'),
(134594, 2200, 40, 'Virhe arvojen noutamisessa.'),
(134595, 2201, 40, 'Virhe asiakirjan tallennuksessa'),
(134596, 2202, 40, 'Virhe annettaessa LibreEHR:n käyttäjälle lupaa tiedostoon.'),
(134597, 2205, 40, 'virhe lomakkeen rekisteröinnissä!'),
(134598, 2206, 40, 'Virhe tiedoston tallennuksen aikana'),
(134599, 2208, 40, 'Virhe tiedoston kirjoittamisen aikana'),
(134600, 2209, 40, 'virhe(et) uusien tulosten vuoksi'),
(134601, 2210, 40, 'Virhe, kyseistä tiedostoa ei ole'),
(134602, 2211, 40, 'VIRHE, tiedon kerääminen palvelimelta ei onnistu'),
(134603, 2212, 40, 'Virhe, asiakassertifikaatin luominen ei onnistu.'),
(134604, 2215, 40, 'Virhe, palvelinsertifikaatin luominen ei onnistu.'),
(134605, 2216, 40, 'Virhe, tiedoston avaaminen ei onnistu'),
(134606, 2220, 40, 'Virhe: tunnisteen kaksoiskappale rivillä'),
(134607, 2221, 40, 'Virhe: nimen kaksoiskappale rivillä'),
(134608, 2222, 40, 'VIRHE: Kenttä'),
(134609, 2223, 40, 'VIRHE: ZipArchive PHP Moduuli puuttuu'),
(134610, 2225, 40, 'Virhe: väärä salasana. Tarkista oikeinkirjoitus.'),
(134611, 2226, 40, 'Virhe: väärä salasana. Tarkista oikeinkirjoitus.'),
(134612, 2227, 40, 'Virhe: asiakirjaa ei ole'),
(134613, 2229, 40, 'VIRHE: asiakirjan kopiointi ei onnistu.'),
(134614, 2230, 40, 'Virhe: Ladattavan arkiston luominen ei onnistu'),
(134615, 2231, 40, 'VIRHE: Zip Arkiston luominen ei onnistu'),
(134616, 2232, 40, 'VIRHE: Tiedoston purkaminen ei onnistu'),
(134617, 2233, 40, 'VIRHE: Tiedoston lataaminen tietokantaan ei onnistu.'),
(134618, 2234, 40, 'VIRHE: Versionumeron asettaminen ei onnistu'),
(134619, 2235, 40, 'Virheet'),
(134620, 2236, 40, 'eRX tilin tila'),
(134621, 2237, 40, 'eRX loki'),
(134622, 2238, 40, 'ERX Nimi'),
(134623, 2239, 40, 'ERX Salasana'),
(134624, 2240, 40, 'ERX Rooli'),
(134625, 2241, 40, 'ERX Käyttäjä'),
(134626, 2242, 40, 'Monimuotoinen punavihoittuma:'),
(134627, 2245, 40, 'Eskimo'),
(134628, 2246, 40, 'Esperanto'),
(134629, 2247, 40, 'Vanha potilas'),
(134630, 2248, 40, 'Viro'),
(134631, 2249, 40, 'Etnisyys'),
(134632, 2250, 40, 'Etnisyys tai rotu'),
(134633, 2251, 40, 'Etnisyys-rotulistaus (kirjoita, vain lisäys vaihtoehtoinen)'),
(134634, 2253, 40, 'Tapahtuma'),
(134635, 2254, 40, 'Tapahtuma alkaa'),
(134636, 2255, 40, 'Tapahtuman luokka'),
(134637, 2256, 40, 'Tapahtuman päiväys'),
(134638, 2257, 40, 'Tapahtuman kuvaus'),
(134639, 2258, 40, 'Tapahtuman lisätiedot'),
(134640, 2259, 40, 'Tapahtuma ei toistu'),
(134641, 2260, 40, 'Tapahtuman kesto'),
(134642, 2261, 40, 'Tapahtuman kesto minuuteissa'),
(134643, 2262, 40, 'Tapahtuman hinta'),
(134644, 2263, 40, 'Tapahtuman sijainti'),
(134645, 2264, 40, 'Tapahtuma toistuu joka'),
(134646, 2266, 40, 'Tapahtuman aloitusaika'),
(134647, 2267, 40, 'Tapahtuman otsikko'),
(134648, 2268, 40, 'Tapahtuman otsikko'),
(134649, 2269, 40, 'Tapahtuman www-sivu'),
(134650, 2270, 40, 'Tapahtumat'),
(134651, 2271, 40, 'Tapahtumat kohteelle'),
(134652, 2272, 40, 'Avaa tapahtumat uuteen ikkunaan'),
(134653, 2273, 40, 'joka'),
(134654, 2274, 40, 'Joka'),
(134655, 2275, 40, 'joka 3 tunti'),
(134656, 2276, 40, 'joka 4 tunti'),
(134657, 2277, 40, 'joka 5 tunti'),
(134658, 2278, 40, 'joka 6 tunti'),
(134659, 2279, 40, 'joka 8 tunti'),
(134660, 2280, 40, 'Joka neljäs'),
(134661, 2281, 40, 'Joka toinen'),
(134662, 2282, 40, 'Joka kolmas'),
(134663, 2283, 40, 'Joka, joka toinen, joka kolmas, jne.'),
(134664, 2285, 40, 'Koe- ja testitulokset'),
(134665, 2286, 40, 'Koetulokset'),
(134666, 2289, 40, 'Tutkimus'),
(134667, 2290, 40, 'Tutkimuksen päiväys'),
(134668, 2291, 40, 'Esimerkki'),
(134669, 2292, 40, 'Esimerkit'),
(134670, 2293, 40, 'Kokeet/testit'),
(134671, 2294, 40, 'Paitsi'),
(134672, 2296, 40, 'Poissuljettu potilaat'),
(134673, 2297, 40, 'Syrjäytyminen'),
(134674, 2304, 40, 'Poistu hallintapaneelista'),
(134675, 2306, 40, 'Laajenna'),
(134676, 2307, 40, 'laajenna'),
(134677, 2308, 40, 'Laajenna kaikki'),
(134678, 2311, 40, 'Laajennettu näkymä'),
(134679, 2313, 40, 'Umpeutuminen'),
(134680, 2314, 40, 'Umpeutumispäivämäärä'),
(134681, 2315, 40, 'Umpeutuu'),
(134682, 2316, 40, 'umpeutuu'),
(134683, 2317, 40, 'Vie'),
(134684, 2318, 40, 'Vie CSV:nä'),
(134685, 2319, 40, 'Vie asetukset'),
(134686, 2325, 40, 'Vie valitut kohteet CSV:nä'),
(134687, 2327, 40, 'Vie CSV:ksi'),
(134688, 2328, 40, 'Vie ulkoiseen laskutusjärjestelmään'),
(134689, 2332, 40, 'Ulkoinen'),
(134690, 2334, 40, 'Ulkoisten tietojen lataus'),
(134691, 2335, 40, 'Ulkoisen tietokannan tuontityökalu'),
(134692, 2336, 40, 'Ulkoinen tunniste'),
(134693, 2337, 40, 'Ulkoinen tunniste'),
(134694, 2338, 40, 'Ulkoinen tunniste'),
(134695, 2339, 40, 'Vain ulkoinen'),
(134696, 2342, 40, 'Ulkoinen lähete'),
(134697, 2343, 40, 'Ulkoisten lähetteiden seuranta'),
(134698, 2344, 40, 'Ulkoinen lähete?'),
(134699, 2345, 40, 'Ulkoiset lähetteet'),
(134700, 2346, 40, 'Pura zip-tiedosto'),
(134701, 2347, 40, 'Puretaan tiedostoa. Tämä saattaa kestää hetken…'),
(134702, 2352, 40, 'Silmät'),
(134703, 2356, 40, 'Toimipaikat'),
(134704, 2357, 40, 'Toimipaikka'),
(134705, 2358, 40, 'toimipaikka'),
(134706, 2359, 40, 'Toimipaikan hallinta'),
(134707, 2360, 40, 'Toimipaikan kaupunki'),
(134708, 2361, 40, 'Toimipaikan koodi'),
(134709, 2362, 40, 'Toimipaikan maakoodi'),
(134710, 2363, 40, 'Toimipaikan fax'),
(134711, 2364, 40, 'Toimipaikan nimi'),
(134712, 2366, 40, 'Toimipaikan puhelin'),
(134713, 2367, 40, 'Toimipaikkasidonnainen käyttäjätieto'),
(134714, 2368, 40, 'Toimipaikan lääni'),
(134715, 2369, 40, 'Toimipaikan katuosoite'),
(134716, 2370, 40, 'Toimipaikan postinumero'),
(134717, 2372, 40, 'Toimipaikka:'),
(134718, 2373, 40, 'EPÄONNISTUMINEN'),
(134719, 2374, 40, 'epäonnistuminen'),
(134720, 2375, 40, 'Epäonnistuminen'),
(134721, 2376, 40, 'Hylätyt potilaat'),
(134722, 2377, 40, 'Potilaan lisääminen portaaliin epäonnistui'),
(134723, 2378, 40, 'Yksilöllisen tiedostonimen luominen epäonnistui'),
(134724, 2379, 40, 'Luonti epäonnistui'),
(134725, 2380, 40, 'Väliaikaisen hakemiston luominen epäonnistui. CouchDB ei toimi.'),
(134726, 2382, 40, 'Epäonnistui.'),
(134727, 2383, 40, 'epäonnistuminen'),
(134728, 2384, 40, 'Epäonnistuminen'),
(134729, 2385, 40, 'ILMOITUS EPÄONNISTUMISESTA: Suoraviestin lähetys epäonnistui.'),
(134730, 2390, 40, 'Perintötekijät'),
(134731, 2391, 40, 'Perinnölliset alttiudet glaukoomalle'),
(134732, 2392, 40, 'Perintötekijät:'),
(134733, 2397, 40, 'Fääri'),
(134734, 2398, 40, 'Farsi'),
(134735, 2400, 40, 'Isä'),
(134736, 2401, 40, 'Isän taustatietot'),
(134737, 2402, 40, 'Uupumus'),
(134738, 2403, 40, 'Uupunut'),
(134739, 2404, 40, 'Faxi'),
(134740, 2406, 40, 'Faxin numero'),
(134741, 2408, 40, 'Faxi/Skanneri'),
(134742, 2409, 40, 'Tulleet faxit'),
(134743, 2410, 40, 'Lähteneet faxit'),
(134744, 2411, 40, 'Ominaisuudet'),
(134745, 2412, 40, 'Helmikuu'),
(134746, 2413, 40, 'Helmikuu'),
(134747, 2418, 40, 'Palkkio'),
(134748, 2419, 40, 'palkkio'),
(134749, 2420, 40, 'Palkkio ei sallittu'),
(134750, 2421, 40, 'Palkkiolomake'),
(134751, 2422, 40, 'Palkkiolomakkeen vaihtoehdot'),
(134752, 2423, 40, 'Palkkiot'),
(134753, 2424, 40, 'Nainen'),
(134754, 2434, 40, 'Kuume'),
(134755, 2435, 40, 'Kuume:'),
(134756, 2438, 40, 'Kenttä'),
(134757, 2439, 40, 'Kenttä ''nimi'' ei voi olla NULL'),
(134758, 2443, 40, 'Kentt(i)ä puuttuu!'),
(134759, 2446, 40, 'Fidži'),
(134760, 2447, 40, 'Tiedosto'),
(134761, 2449, 40, 'tiedoston sijainti'),
(134762, 2450, 40, 'Tiedoston hallinta'),
(134763, 2453, 40, 'Tiedoston käyttöoikeus myönnetty LibreEHR käyttäjälle.'),
(134764, 2454, 40, 'Tiedoston nouto CouchDB:ta epäonnistui'),
(134765, 2455, 40, 'Arkistohuone'),
(134766, 2458, 40, 'Saman niminen tiedosto on jo olemassa kohteessa:'),
(134767, 2459, 40, 'Tiedostonimi'),
(134768, 2460, 40, 'Tiedostonimen päätteen tulee olla ".pdf"'),
(134769, 2461, 40, 'Tiedostot'),
(134770, 2462, 40, 'Filipino'),
(134771, 2463, 40, 'Täytä mikä tahansa alla olevista riveistä.'),
(134772, 2465, 40, 'Anna alla olevat arvot'),
(134773, 2467, 40, 'Täytä rivi.'),
(134774, 2468, 40, 'Suodatin'),
(134775, 2469, 40, 'Suodata vakioista'),
(134776, 2470, 40, 'Suodata määritelmistä'),
(134777, 2471, 40, 'suodatettu kohteesta'),
(134778, 2472, 40, 'suodattimet'),
(134779, 2473, 40, 'Suodattimet'),
(134780, 2474, 40, 'Lopullinen'),
(134781, 2475, 40, 'Lopullinen diagnoosi'),
(134782, 2476, 40, 'Lopullinen diagnoosi erikoislääkärin tekemänä'),
(134783, 2478, 40, 'Taloudellinen'),
(134784, 2484, 40, 'Haku'),
(134785, 2485, 40, 'Hae vapaa'),
(134786, 2486, 40, 'Hae vapaat tapaamiset'),
(134787, 2487, 40, 'Hae potilas'),
(134788, 2489, 40, 'Löydökset'),
(134789, 2490, 40, 'Erikoislääkärin löydökset'),
(134790, 2493, 40, 'päättynyt'),
(134791, 2494, 40, 'Suomi'),
(134792, 2495, 40, 'Ensimmäinen'),
(134793, 2497, 40, 'Viikon ensimmäinen päivä'),
(134794, 2498, 40, 'Etunimi'),
(134795, 2499, 40, 'Etunimi'),
(134796, 2500, 40, 'Etunimi:'),
(134797, 2501, 40, 'Ensimmäinen käynti tai konsultaatio'),
(134798, 2502, 40, 'Etunimi Sukunimi'),
(134799, 2509, 40, 'Korjaa tämä'),
(134800, 2511, 40, 'Ilmavaivoja'),
(134801, 2512, 40, 'Virta'),
(134802, 2514, 40, 'Flunssa kausi'),
(134803, 2515, 40, 'Flunssa kausi'),
(134804, 2516, 40, 'Flunssarokote'),
(134805, 2531, 40, 'Ruokayliherkkyys'),
(134806, 2532, 40, 'Jalka'),
(134807, 2533, 40, 'Jalkaongelmat'),
(134808, 2534, 40, 'Jalka:'),
(134809, 2535, 40, 'Jalkapallovammat'),
(134810, 2536, 40, 'Jalkapallovamma'),
(134811, 2537, 40, 'Raportti jalkapallovammasta'),
(134812, 2538, 40, 'Jalkineen tyyppi'),
(134813, 2539, 40, 'käyttäjä'),
(134814, 2544, 40, 'Esimerkki:'),
(134815, 2560, 40, 'Lomake'),
(134816, 2561, 40, 'lomake'),
(134817, 2562, 40, 'Lomakkeen elementtiä ei löydy'),
(134818, 2563, 40, 'Lomakkeen allekirjoitus onnistui'),
(134819, 2564, 40, 'Muoto'),
(134820, 2565, 40, 'muoto'),
(134821, 2566, 40, 'Iän esitystapa'),
(134822, 2568, 40, 'Useimmin käytetty esitystapa päiväyksille.'),
(134823, 2569, 40, 'Useimmin käytetty esitystapa ajalle.'),
(134824, 2570, 40, 'Muotoiltu raportti'),
(134825, 2571, 40, 'Tupakoinut aiemmin'),
(134826, 2572, 40, 'Lomakkeet'),
(134827, 2573, 40, 'Lomakkeiden hallinta'),
(134828, 2575, 40, 'Lähetä edelleen'),
(134829, 2576, 40, 'Lähetä edelleen faxilla'),
(134830, 2577, 40, 'Lähetetty edelleen'),
(134831, 2579, 40, 'Neljäs'),
(134832, 2587, 40, 'Ranska'),
(134833, 2588, 40, 'Ranska (Kanada)'),
(134834, 2589, 40, 'Ranska (Vakio)'),
(134835, 2590, 40, 'Frekvenssi'),
(134836, 2591, 40, 'Toistuva vilustuminen'),
(134837, 2592, 40, 'Toistuva sairastuminen'),
(134838, 2593, 40, 'Pe'),
(134839, 2594, 40, 'Perjantai'),
(134840, 2595, 40, 'Alkaen'),
(134841, 2596, 40, 'LÄHETTÄJÄ'),
(134842, 2597, 40, 'lähettäjä'),
(134843, 2598, 40, 'Aloituksen päivämäärä ei voi olla myöhäisempi kuin lopetuksen päivämäärä.'),
(134844, 2599, 40, 'Alkaen:'),
(134845, 2600, 40, 'Lähettäjä: '),
(134846, 2619, 40, 'Koko nimi'),
(134847, 2620, 40, 'Koko polku MYSQL ohjelmatiedostoja sisältävään hakemistoon.'),
(134848, 2621, 40, 'Koko polku Perl ohjelmatiedostoja sisältävään hakemistoon.'),
(134849, 2622, 40, 'Koko polku tapahtumalokien varmuuskopioiden hakemistoon.'),
(134850, 2626, 40, 'Maksettu kokonaan'),
(134851, 2631, 40, 'Tulevaisuus'),
(134852, 2635, 40, 'Galego'),
(134853, 2636, 40, 'Sappirakon kunto'),
(134854, 2637, 40, 'Sappikivet'),
(134855, 2650, 40, 'Sukupuoli'),
(134856, 2651, 40, 'Sukupuoli '),
(134857, 2656, 40, 'Luo'),
(134858, 2664, 40, 'Luo CMS 1500'),
(134859, 2665, 40, 'Luo CMS 1500 PDF'),
(134860, 2666, 40, 'Luo CMS 1500 TEXT'),
(134861, 2667, 40, 'Luo HCFA'),
(134862, 2668, 40, 'Luo lasku'),
(134863, 2669, 40, 'Luo kirje'),
(134864, 2670, 40, 'Luo kirje koskien '),
(134865, 2677, 40, 'Luo raportti'),
(134866, 2678, 40, 'Luo käyttäjätunnus ja salasana'),
(134867, 2679, 40, 'Luo X12'),
(134868, 2683, 40, 'Luodaan'),
(134869, 2686, 40, 'Georgia'),
(134870, 2687, 40, 'Saksa'),
(134871, 2694, 40, 'Yleinen'),
(134872, 2696, 40, 'Yleistunniste'),
(134873, 2697, 40, 'Yleisasetukset'),
(134874, 2698, 40, 'Yleiset'),
(134875, 2700, 40, 'siirry'),
(134876, 2701, 40, 'Siirry'),
(134877, 2704, 40, 'Siirry kohteeseen'),
(134878, 2706, 40, 'Tänään'),
(134879, 2707, 40, 'Tavoite A'),
(134880, 2708, 40, 'Tavoite ja menetelmät'),
(134881, 2709, 40, 'Tavoite B'),
(134882, 2710, 40, 'Tavoite C'),
(134883, 2712, 40, 'Taso:'),
(134884, 2713, 40, 'grammaa'),
(134885, 2714, 40, 'Loppusumma'),
(134886, 2715, 40, 'Loppusummat'),
(134887, 2720, 40, 'Suurempi kuin'),
(134888, 2721, 40, 'Suurempi tai yhtä suuri kuin'),
(134889, 2722, 40, 'Kreikka'),
(134890, 2723, 40, 'Kreikka, moderni'),
(134891, 2724, 40, 'Ryhmä'),
(134892, 2725, 40, 'Ryhmän nimi'),
(134893, 2726, 40, 'Ryhmän nimi ei voi olla tyhjä'),
(134894, 2727, 40, 'Ryhmän nimi ei voi alkaa numerolla tai välilyönnillä.'),
(134895, 2728, 40, 'Ryhmän nimi ei voi alkaa numerolla.'),
(134896, 2729, 40, 'Ryhmän numero'),
(134897, 2731, 40, 'Ryhmä:'),
(134898, 2732, 40, 'Ryhmän nimi'),
(134899, 2733, 40, 'Ryhmät ja käyttöoikeudet'),
(134900, 2734, 40, 'Kasvukäyrä'),
(134901, 2735, 40, 'Kasvukäyrä'),
(134902, 2739, 40, 'Holhoojan nimi'),
(134903, 2741, 40, 'Gynekologinen tutkimus'),
(134904, 2752, 40, 'Kovalevy'),
(134905, 2755, 40, 'on vanhentunut'),
(134906, 2761, 40, 'Vaaralliset harrastukset'),
(134907, 2762, 40, 'Vaaralliset harrastukset'),
(134908, 2768, 40, 'Pää'),
(134909, 2769, 40, 'Päänympärys'),
(134910, 2770, 40, 'Päänympärys'),
(134911, 2771, 40, 'Päänsärky'),
(134912, 2772, 40, 'Päänsärkyjä'),
(134913, 2775, 40, 'Vastaanottavan sairaalan tai poliklinikan nimi ja osoite'),
(134914, 2790, 40, 'Tupakoi runsaasti'),
(134915, 2791, 40, 'Heprea'),
(134916, 2792, 40, 'Heprea (moderni)'),
(134917, 2794, 40, 'Pituus'),
(134918, 2795, 40, 'Pituus'),
(134919, 2805, 40, 'Hepatitis'),
(134920, 2822, 40, 'Piilotettu'),
(134921, 2824, 40, 'Piilota'),
(134922, 2825, 40, 'Piilota yksityiskohdat'),
(134923, 2828, 40, 'Piilota valikko'),
(134924, 2830, 40, 'Piilota muistutukset'),
(134925, 2831, 40, 'Piilota/Näytä sarakkeet'),
(134926, 2833, 40, 'Korkea'),
(134927, 2834, 40, 'Korkea verenpaine'),
(134928, 2865, 40, 'Etusivu'),
(134929, 2866, 40, 'Kotipuhelin'),
(134930, 2867, 40, 'Kotipuhelimen numero'),
(134931, 2868, 40, 'Koditon tai vastaava?'),
(134932, 2869, 40, 'Koditon jne'),
(134933, 2870, 40, 'Koditon jne.'),
(134934, 2875, 40, 'Tunti'),
(134935, 2876, 40, 'Tunnit'),
(134936, 2887, 40, 'Unkari'),
(134937, 2917, 40, 'Käyttämättömän istunnon aikakatkaisu sekunneissa'),
(134938, 2974, 40, 'LUOKASSA'),
(134939, 2981, 40, 'Poissa'),
(134940, 2983, 40, 'Saapuneet'),
(134941, 3087, 40, 'Vakuutus'),
(134942, 3088, 40, 'vakuutus'),
(134943, 3093, 40, 'Vakuutusyhtiö'),
(134944, 3094, 40, 'Vakuutusyhtiöt'),
(134945, 3095, 40, 'Vakuutusyhtiö'),
(134946, 3100, 40, 'Vakuutusnumerot'),
(134947, 3101, 40, 'Vakuutusmaksu'),
(134948, 3104, 40, 'Vakuutustyypit'),
(134949, 3105, 40, 'Vakuutukset'),
(134950, 3123, 40, 'Sisäinen tunniste'),
(134951, 3129, 40, 'Tulkki'),
(134952, 3130, 40, 'Tarvitaanko tulkki?'),
(134953, 3162, 40, 'Lasku'),
(134954, 3163, 40, 'lasku'),
(134955, 3166, 40, 'Laskun päiväys'),
(134956, 3167, 40, 'Laskulla ei ole päiväystä!'),
(134957, 3168, 40, 'Laskun numero'),
(134958, 3169, 40, 'Laskun viitenumero'),
(134959, 3173, 40, 'Lasku:'),
(134960, 3185, 40, 'Epäsäännöllinen sydämen syke'),
(134961, 3191, 40, 'on vaadittu kenttä.'),
(134962, 3238, 40, 'Tammikuu'),
(134963, 3239, 40, 'Tammikuu'),
(134964, 3248, 40, 'Heinäkuu'),
(134965, 3249, 40, 'Heinäkuu'),
(134966, 3250, 40, 'Kesäkuu'),
(134967, 3251, 40, 'Kesäkuu'),
(134968, 3253, 40, 'Vain omat'),
(134969, 3265, 40, 'Hakusanat'),
(134970, 3287, 40, 'Laboratorio asiakirjat'),
(134971, 3303, 40, 'Nimiö'),
(134972, 3304, 40, 'Nimiö ei voi olla tyhjä'),
(134973, 3305, 40, 'Nimiön sarakkeet'),
(134974, 3306, 40, 'Nimiö tälle tyypille'),
(134975, 3307, 40, 'Nimiön sarakkeiden arvo tulee olla numero väliltä 1 ja 999'),
(134976, 3308, 40, 'Nimiöt'),
(134977, 3315, 40, 'Vaaka'),
(134978, 3316, 40, 'Kieli'),
(134979, 3317, 40, 'Kielikoodi'),
(134980, 3321, 40, 'Kielen nimi'),
(134981, 3322, 40, 'Kieli:'),
(134982, 3325, 40, 'Viimeinen'),
(134983, 3342, 40, 'Edelliset kuukautiset'),
(134984, 3343, 40, 'Viime kuu'),
(134985, 3344, 40, 'Sukunimi'),
(134986, 3345, 40, 'Sukunimi'),
(134987, 3346, 40, 'Sukunimi:'),
(134988, 3352, 40, 'Viimeksi tallennettu'),
(134989, 3358, 40, 'Viimeisin käynti'),
(134990, 3372, 40, 'Ulkoasu'),
(134991, 3373, 40, 'Ulkoasuun perustuvat'),
(134992, 3374, 40, 'Ulkoasun muokkain'),
(134993, 3375, 40, 'Ulkoasuryhmät'),
(134994, 3376, 40, 'Ulkoasujen tyylit'),
(134995, 3378, 40, 'LBV lomakkeet'),
(134996, 3379, 40, 'Ulkoasut'),
(134997, 3380, 40, 'pauna'),
(134998, 3381, 40, 'paunaa'),
(134999, 3383, 40, 'jätä tyhjäksi jos vielä aktiivinen'),
(135000, 3384, 40, 'Jättämällä tyhjäksi säilytät vanhan tiedostonimen'),
(135001, 3385, 40, 'Jättämällä tyhjäksi säilytät vanhan salasanan.'),
(135002, 3386, 40, 'Millä jätät viestin'),
(135003, 3387, 40, 'Poistu lomakkeesta'),
(135004, 3390, 40, 'Vasen'),
(135005, 3391, 40, 'Vasen korva'),
(135006, 3392, 40, 'vasen korva'),
(135007, 3393, 40, 'Vasen marginaali (mm)'),
(135008, 3394, 40, 'Vasen:'),
(135009, 3395, 40, 'Vasen: '),
(135010, 3403, 40, 'Pienempi kuin'),
(135011, 3404, 40, 'Pienempi tai yhtä suuri kuin'),
(135012, 3423, 40, 'Elämäntapa'),
(135013, 3438, 40, 'Lista'),
(135014, 3458, 40, 'Listat'),
(135015, 3459, 40, 'Liettua'),
(135016, 3464, 40, 'Tallenna määritykset'),
(135017, 3476, 40, 'Paikalliset'),
(135018, 3492, 40, 'Kirjaudu'),
(135019, 3493, 40, 'Kirjaudu'),
(135020, 3494, 40, 'Uloskirjautuminen'),
(135021, 3495, 40, 'Kirjauduttu'),
(135022, 3496, 40, 'Kirjauduttu käyttäjänä'),
(135023, 3497, 40, 'Kirjauduttu käyttäjänä: '),
(135024, 3498, 40, 'Uloskirjauduttu.'),
(135025, 3499, 40, 'Kirjautuu'),
(135026, 3500, 40, 'Kirjaudu'),
(135027, 3501, 40, 'kirjaudu'),
(135028, 3503, 40, 'Kirjautuminen etäpalvelimelle'),
(135029, 3504, 40, 'Kirjautuminen etäpalvelimelle epäonnistui'),
(135030, 3505, 40, 'Uloskirjautuminen'),
(135031, 3506, 40, 'uloskirjautuminen'),
(135032, 3507, 40, 'Lokit'),
(135033, 3520, 40, 'LOUNAS'),
(135034, 3521, 40, 'Lounas'),
(135035, 3536, 40, 'Päänäkymän yläosa'),
(135036, 3553, 40, 'Hallinnoi'),
(135037, 3555, 40, 'Hallinnoi moduuleja'),
(135038, 3556, 40, 'Hallinnoi käännöksiä'),
(135039, 3557, 40, 'Hallinto'),
(135040, 3558, 40, 'Pakolliset ja määritellyt kentät'),
(135041, 3559, 40, 'Vain pakolliset ja määritellyt kentät, tuplien tarkistus, ei hakua'),
(135042, 3560, 40, 'Vain pakolliset ja määritellyt kentät, tuplien tarkistus, ei hakua'),
(135043, 3561, 40, 'Käyttöohjeet'),
(135044, 3563, 40, 'Valmistaja'),
(135045, 3565, 40, 'Maaliskuu'),
(135046, 3568, 40, 'Maaliskuu'),
(135047, 3569, 40, 'Siviilisääty'),
(135048, 3570, 40, 'Merkitse laskutetuksi'),
(135049, 3572, 40, 'Merkitse laskutetuksi, mutta ohita laskutus'),
(135050, 3574, 40, 'Merkitse ei-laskutetuksi'),
(135051, 3576, 40, 'Aviossa'),
(135052, 3603, 40, 'Toukokuu'),
(135053, 3611, 40, 'Mittaus'),
(135054, 3617, 40, 'Esitiedot'),
(135055, 3624, 40, 'Sairaskertomus'),
(135056, 3625, 40, 'Sairaskertomus #'),
(135057, 3626, 40, 'Sairaskertomukset'),
(135058, 3627, 40, 'Lähetetyt sairaskertomukset'),
(135059, 3635, 40, 'Lääkitys');
INSERT INTO `lang_definitions` VALUES
(135060, 3640, 40, 'Lääkitykset'),
(135061, 3641, 40, 'Lääkitykset:'),
(135062, 3646, 40, 'Muistiongelmat'),
(135063, 3647, 40, 'Miehet'),
(135064, 3648, 40, 'Miehet ja naiset'),
(135065, 3649, 40, 'Vain miehet'),
(135066, 3651, 40, 'Menopaussi'),
(135067, 3652, 40, 'Kuukautisvuoto'),
(135068, 3653, 40, 'Kuukautiskierto'),
(135069, 3654, 40, 'Mielenterveysongelmat'),
(135070, 3655, 40, 'Valikkoteksti'),
(135071, 3656, 40, 'Valikot'),
(135072, 3661, 40, 'Viesti'),
(135073, 3662, 40, 'Viesti- ja muistutuskeskus'),
(135074, 3663, 40, 'Viestin sisältö ei ole vain tekstiä, joten se on tallennettu dokumenttina.'),
(135075, 3664, 40, 'Viesti potilaalta'),
(135076, 3665, 40, 'Viesti lähetetty'),
(135077, 3666, 40, 'Viestin tila'),
(135078, 3667, 40, 'Viestin otsikko'),
(135079, 3668, 40, 'Viesti potilaalle'),
(135080, 3669, 40, 'Viestin tyyppi'),
(135081, 3670, 40, 'VIESTI:'),
(135082, 3671, 40, 'Viestit'),
(135083, 3672, 40, 'Tänään lähettämäsi viestit'),
(135084, 3679, 40, 'mg'),
(135085, 3680, 40, 'mg/1cc'),
(135086, 3681, 40, 'mg/2cc'),
(135087, 3682, 40, 'mg/3cc'),
(135088, 3683, 40, 'mg/4cc'),
(135089, 3684, 40, 'mg/5cc'),
(135090, 3685, 40, 'MG/DL'),
(135091, 3687, 40, 'Toinen etunimi'),
(135092, 3688, 40, 'Toinen etunimi'),
(135093, 3701, 40, 'MIME-tyyppi'),
(135094, 3702, 40, 'MIME-tyyppi'),
(135095, 3708, 40, 'Minuutti'),
(135096, 3709, 40, 'minuuttia'),
(135097, 3710, 40, 'Minuuttia'),
(135098, 3716, 40, 'Sekalaiset'),
(135099, 3718, 40, 'puuttuu'),
(135100, 3719, 40, 'Vaadittu kenttä puuttuu'),
(135101, 3720, 40, 'Palkkio puuttuu'),
(135102, 3722, 40, 'Puuttuva tai virheellinen'),
(135103, 3724, 40, 'Raportin päiväys puuttuu'),
(135104, 3726, 40, 'Sekoitettu'),
(135105, 3727, 40, 'ml'),
(135106, 3728, 40, 'KK/PP/VVVV'),
(135107, 3729, 40, 'mm/hg'),
(135108, 3730, 40, 'mmHg'),
(135109, 3733, 40, 'Matkapuhelin'),
(135110, 3734, 40, 'Matkapuhelin'),
(135111, 3743, 40, 'Muokkaa'),
(135112, 3745, 40, 'Muokkaa maksuja'),
(135113, 3747, 40, 'Moduuli'),
(135114, 3748, 40, 'Moduulihakemistoa ei löydy'),
(135115, 3749, 40, 'Moduulin asentaja'),
(135116, 3750, 40, 'Moduulin nimi'),
(135117, 3751, 40, 'Moduulin nimi on jo olemassa'),
(135118, 3752, 40, 'Moduulit'),
(135119, 3753, 40, 'Ma'),
(135120, 3754, 40, 'Ma – Pe'),
(135121, 3755, 40, 'Ma, Ke & Pe'),
(135122, 3756, 40, 'Maanantai'),
(135123, 3758, 40, 'Kuukausi'),
(135124, 3759, 40, 'kuukausi'),
(135125, 3760, 40, 'Kuukausinäkymä'),
(135126, 3761, 40, 'Kuukaudet'),
(135127, 3762, 40, 'Kuukausitulot'),
(135128, 3763, 40, 'Kuukaudet'),
(135129, 3765, 40, 'Yli 100 asiakirjaa. Tarkenna hakukriteeriäsi.'),
(135130, 3766, 40, 'Yli 50 tulosta, täsmennä hakuasi.'),
(135131, 3767, 40, 'Useimpien sarakkeiden järjestystä voiodaan muuttaa klikkaamalla sarakkeen otsikkoa'),
(135132, 3771, 40, 'Äiti'),
(135133, 3772, 40, 'Äidin nimi'),
(135134, 3774, 40, 'Suu'),
(135135, 3775, 40, 'Siirry'),
(135136, 3776, 40, 'Siirrä asiakirja luokkaan:'),
(135137, 3777, 40, 'Siirry alas'),
(135138, 3778, 40, 'Siirto epäonnistui!'),
(135139, 3779, 40, 'Siirry potilaaseen'),
(135140, 3780, 40, 'Siirry kohteeseen'),
(135141, 3781, 40, 'Siirry ylös'),
(135142, 3782, 40, 'Siirtää'),
(135143, 3783, 40, 'Hra.'),
(135144, 3785, 40, 'Rva.'),
(135145, 3786, 40, 'Nti.'),
(135146, 3823, 40, 'Nimi'),
(135147, 3825, 40, 'Nimi (klikkaa lisää)'),
(135148, 3826, 40, 'Nimi 1'),
(135149, 3827, 40, 'Nimi 2'),
(135150, 3832, 40, 'Vakuutusyhtiön nimi'),
(135151, 3836, 40, 'Nimi/Arvo'),
(135152, 3837, 40, 'Nimi:'),
(135153, 3854, 40, 'Navigaatio'),
(135154, 3855, 40, 'Navigaatiopalkki sisältää käyntilomakkeet'),
(135155, 3856, 40, 'Navigaatiopalkki näkyy koko kehyksen korkeudelta'),
(135156, 3857, 40, 'Navigaatiopalkin käyntilomakkeet'),
(135157, 3858, 40, 'Navigaatiopalkin leveys'),
(135158, 3859, 40, 'Navigointivalikko koostuu valintanapeista'),
(135159, 3860, 40, 'Navigaatio esitetään puunäkymänä'),
(135160, 3861, 40, 'Navigaatiossa käytetään liukuvalikkoa'),
(135161, 3885, 40, 'Ei koskaan'),
(135162, 3886, 40, 'Ei milloinkaan alkoholia'),
(135163, 3887, 40, 'Ei milloinkaan tupakoinut'),
(135164, 3888, 40, 'Uusi'),
(135165, 3889, 40, 'Uusi =>'),
(135166, 3892, 40, 'Uusi allergia'),
(135167, 3894, 40, 'Uusi ajanvaraus'),
(135168, 3895, 40, 'Uudet luokat'),
(135169, 3896, 40, 'Uusi luokka'),
(135170, 3897, 40, 'Uudet asiakkaat'),
(135171, 3900, 40, 'Uusi(a) määrittely(jä) lisätty'),
(135172, 3901, 40, 'Uusi asiakirja'),
(135173, 3902, 40, 'Uudet asiakirjat'),
(135174, 3904, 40, 'Uusi käynti'),
(135175, 3910, 40, 'Uusi tiedosto'),
(135176, 3911, 40, 'Uusia tiedostoja'),
(135177, 3912, 40, 'Uusi ryhmä'),
(135178, 3917, 40, 'Uusi lista'),
(135179, 3919, 40, 'Uusi kappale'),
(135180, 3920, 40, 'Uusi salasana'),
(135181, 3921, 40, 'Uusi potilas'),
(135182, 3922, 40, 'UUSI POTILAS'),
(135183, 3923, 40, 'Uusi potilaskäynti'),
(135184, 3924, 40, 'Uusi potilaslomake'),
(135185, 3925, 40, 'Uusi potilastunniste'),
(135186, 3926, 40, 'Uusi maksu'),
(135187, 3930, 40, 'Uusi haku'),
(135188, 3932, 40, 'Uusi käyttäjä'),
(135189, 3933, 40, 'Uusi arvo'),
(135190, 3934, 40, 'Uusi käynti'),
(135191, 3935, 40, 'Uusi/Hae'),
(135192, 3960, 40, 'Uudempi'),
(135193, 3961, 40, 'Sanomalehti'),
(135194, 3962, 40, 'Seuraava'),
(135195, 3964, 40, 'Seuraava päivä'),
(135196, 3965, 40, 'Seuraava kuukausi'),
(135197, 3966, 40, 'Seuraava kuukausi (pidä valikkoa varten)'),
(135198, 3967, 40, 'Seuraava aikataulutettu ajo'),
(135199, 3968, 40, 'Seuraava viikko'),
(135200, 3969, 40, 'Seuraava vuosi (pidä valikkoa varten)'),
(135201, 3975, 40, 'Ei'),
(135202, 3976, 40, 'EI'),
(135203, 3977, 40, 'Ei pääsyä'),
(135204, 3978, 40, 'Potilaalle ei ole aktiivisia muistutuksia.'),
(135205, 3983, 40, 'Ei ajanvarauksia'),
(135206, 3985, 40, 'Laskutusjärjestelmä ei ole käytössä'),
(135207, 3992, 40, 'Ei diagnoosia'),
(135208, 3993, 40, 'Ei löydettyjä asiakirjoja'),
(135209, 3997, 40, 'Virheitä ei löytynyt'),
(135210, 3998, 40, 'Ei tapahtumia'),
(135211, 4000, 40, 'Ei tiedostoja asennettavaksi'),
(135212, 4001, 40, 'Ryhmää ei ole valittu'),
(135213, 4029, 40, 'Ei osumia. Yritä hakea uudestaan.'),
(135214, 4030, 40, 'Ei osumia.'),
(135215, 4031, 40, 'Ei osumia. Luodaanko uusi potilas?'),
(135216, 4037, 40, 'Muita puhelinnumeroita ei ole listattu'),
(135217, 4048, 40, 'Ei aiempia käyntejä.'),
(135218, 4049, 40, 'Ei toimenpiteitä tällä käynnillä.'),
(135219, 4053, 40, 'Ei kirjauksia'),
(135220, 4055, 40, 'Ei kirjauksia. Laajenna hakukriteerejä.'),
(135221, 4056, 40, 'Ei muistutuksia'),
(135222, 4057, 40, 'Ei hakutuloksia näillä hakukriteereillä.'),
(135223, 4058, 40, 'Ei tuloksia'),
(135224, 4059, 40, 'Tuloksia ei löytynyt'),
(135225, 4060, 40, 'Ei hakutuloksia tähän hakuun'),
(135226, 4061, 40, 'Ei tuloksia, yritä uudestaan.'),
(135227, 4062, 40, 'Ei tuloksia, yritä uudestaan.'),
(135228, 4063, 40, 'Ei tuloksia, yritä uudestaan.'),
(135229, 4064, 40, 'Tälle moduulille ei ole asetuksia saatavilla'),
(135230, 4070, 40, 'Taulua ei ole valittu! Valitse taulu.'),
(135231, 4077, 40, 'Ei, peruuta'),
(135232, 4089, 40, 'Ei mitään'),
(135233, 4090, 40, 'ei mitään'),
(135234, 4091, 40, 'Ei mitään määriteltynä'),
(135235, 4092, 40, 'Ei mitään dokumentoituna'),
(135236, 4093, 40, 'Ei mikään ylläolevista'),
(135237, 4097, 40, 'Normaali'),
(135238, 4108, 40, 'normaali:'),
(135239, 4111, 40, 'Pohjoissaame'),
(135240, 4112, 40, 'Norja'),
(135241, 4113, 40, 'Kirjanorja'),
(135242, 4114, 40, 'Uusnorja'),
(135243, 4115, 40, 'Nenä'),
(135244, 4116, 40, 'Nenäverenvuoto'),
(135245, 4117, 40, 'ei kirjain tai numero'),
(135246, 4120, 40, 'Ei sallittu'),
(135247, 4121, 40, 'Administrators-ryhmän poistaminen ei ole sallittua'),
(135248, 4122, 40, 'Muokkaaminen ei ole sallittua'),
(135249, 4125, 40, 'Pääkäyttäjän poistaminen Administrators-ryhmästä ei ole sallittua'),
(135250, 4126, 40, 'Tämän käyttäjän poistaminen Administrators-ryhmästä ei ole sallittua'),
(135251, 4129, 40, 'Ei sallittu'),
(135252, 4130, 40, 'Ei sallittu'),
(135253, 4135, 40, 'Ei saatavilla'),
(135254, 4137, 40, 'Ei laskutettu'),
(135255, 4140, 40, 'Ei koodattu'),
(135256, 4143, 40, 'Ei tutkittu'),
(135257, 4144, 40, 'Ei tutkittu:'),
(135258, 4145, 40, 'Ei tutkittu: '),
(135259, 4146, 40, 'ei löytynyt'),
(135260, 4148, 40, 'ei löytynyt!'),
(135261, 4150, 40, 'Ei asennettu'),
(135262, 4151, 40, 'Ei asennettu'),
(135263, 4153, 40, 'Ei lähetetty'),
(135264, 4154, 40, 'Ei vielä lähetetty'),
(135265, 4155, 40, 'Ei määritetty'),
(135266, 4156, 40, 'Ei määritetty.'),
(135267, 4176, 40, 'Ei hyväksymistä odottavia'),
(135268, 4177, 40, 'Ei kirjauksia'),
(135269, 4190, 40, 'Marraskuu'),
(135270, 4191, 40, 'Marraskuu'),
(135271, 4237, 40, 'Ammatti'),
(135272, 4240, 40, 'Lokakuu'),
(135273, 4241, 40, 'Lokakuu'),
(135274, 4252, 40, 'Https-linkki ulkoiseen potilasportaaliin.'),
(135275, 4253, 40, 'Https-linkki ulkoiseen potilasportaaliin. (Potilaan linkki)'),
(135276, 4254, 40, 'Salasana ulkoiseen potilasportaaliin'),
(135277, 4255, 40, 'Salasana ulkoiseen potilasportaaliin (Jätä tyhjäksi jos ei rekisteröity).'),
(135278, 4258, 40, 'Ulkoisen potilasportaalin osoite'),
(135279, 4259, 40, 'Ulkoisen potilasportaalin osoite (Potilaan linkki)'),
(135280, 4260, 40, 'Ulkoisen potilasportaalin käyttäjätunnus'),
(135281, 4261, 40, 'Ulkoisen potilasportaalin käyttäjätunnus (Jätä tyhjäksi jos ei rekisteröity).'),
(135282, 4263, 40, 'Jälkikasvu'),
(135283, 4267, 40, 'OK'),
(135284, 4268, 40, 'Voidaanko tämä toinen ponnahdusikkuna sulkea?'),
(135285, 4270, 40, 'Vanha'),
(135286, 4272, 40, 'Vanhat asiakkaat'),
(135287, 4274, 40, 'Perinteinen ulkoasu ilman valikkoa vasemmalla'),
(135288, 4275, 40, 'Perinteinen staattinen lomake, ilman hakutoimintoa tai kaksoiskappaleen tarkistusta'),
(135289, 4276, 40, 'Vanhempi'),
(135290, 4277, 40, 'Ohita'),
(135291, 4280, 40, 'Ohita työnantajat'),
(135292, 4283, 40, 'Ohitetaanko sisäiset käyttäjät?'),
(135293, 4297, 40, 'Online-tuki'),
(135294, 4298, 40, 'Online-tuen linkki'),
(135295, 4299, 40, 'Vain aktiiviset'),
(135296, 4303, 40, 'Vain passiiviset'),
(135297, 4304, 40, 'Vain omat'),
(135298, 4315, 40, 'Hupsis!'),
(135299, 4316, 40, 'Avaa'),
(135300, 4318, 40, 'Avaa uudessa ikkunassa'),
(135301, 4319, 40, 'Avaa potilas'),
(135302, 4321, 40, 'Avaa tämän päivän käynnit'),
(135303, 4327, 40, 'LibreEHR on määritettävä käyttämään varmenteita ennen kuin se voi luoda asiakkaalle varmenteita.'),
(135304, 4328, 40, 'LibreEHR vaatii Javascriptiä käyttäjän tunnistautumiseen.'),
(135305, 4329, 40, 'LibreEHR käyttäjät'),
(135306, 4351, 40, 'Tai'),
(135307, 4352, 40, 'TAI'),
(135308, 4353, 40, 'tai valitse'),
(135309, 4354, 40, 'tai klikkaa ja vedä nopeampaa valintaa varten.'),
(135310, 4362, 40, 'Järjestys'),
(135311, 4402, 40, 'Muut'),
(135312, 4434, 40, 'Ylipaino'),
(135313, 4437, 40, 'Happisaturaatio'),
(135314, 4438, 40, 'unssi'),
(135315, 4445, 40, 'Sivu'),
(135316, 4446, 40, 'Sivua'),
(135317, 4447, 40, 'Maksettu'),
(135318, 4449, 40, 'Maksettu summa'),
(135319, 4450, 40, 'Maksukanava'),
(135320, 4451, 40, 'Kipu'),
(135321, 4456, 40, 'Paperi'),
(135322, 4457, 40, 'Paperikoko'),
(135323, 4472, 40, 'Salasana'),
(135324, 4473, 40, 'Salasanan vaihto'),
(135325, 4474, 40, 'Salasanan vaihto onnistui'),
(135326, 4475, 40, 'Salasanan vaihto onnistui.'),
(135327, 4476, 40, 'Salasana ei täytä sille asetettuja vähimmäisvaatimuksia. Salasanassa on oltava ainakin kolme seuraavista: numero, pieni kirjain, iso kirjain tai erikoismerkki (Ei numero eikä kirjain).'),
(135328, 4485, 40, 'Salasana on liian lyhyt. Siinä on oltava ainakin kahdeksan merkkiä.'),
(135329, 4486, 40, 'Salasana:'),
(135330, 4487, 40, 'Salasana ei täsmää!'),
(135331, 4488, 40, 'Aiemmat ajanvaraukset'),
(135332, 4489, 40, 'Aiempien ajanvarausten näyttövimpain'),
(135333, 4494, 40, 'Lista aiemmista käynneistä'),
(135334, 4495, 40, 'Aiemmat käynnit'),
(135335, 4496, 40, 'Aiemmat käynnit ja dokumentit'),
(135336, 4497, 40, 'Aiemmat käynnit potilaalle'),
(135337, 4499, 40, 'Liitä tuotava tieto alla olevaan tekstilaatikkoon:'),
(135338, 4508, 40, 'Polku tapahtumalokin varmuuskopioon'),
(135339, 4514, 40, 'Potilas'),
(135340, 4515, 40, 'potilas'),
(135341, 4516, 40, 'POTILAS'),
(135342, 4517, 40, 'Potilaan osoite'),
(135343, 4518, 40, 'Potilaan osoite puuttuu'),
(135344, 4521, 40, 'Potilaan allergiat'),
(135345, 4522, 40, 'Potilaan allergiat'),
(135346, 4531, 40, 'Potilaan kaupunki'),
(135347, 4532, 40, 'Potilaan kaupunki puuttuu'),
(135348, 4535, 40, 'Potilaan maa'),
(135349, 4536, 40, 'Potilaan maa puuttuu. Et ole myöskään asettanut oletusarvoa potilaan maalle yleisissä asetuksissa'),
(135350, 4541, 40, 'Potilaan syntymäaika puuttuu'),
(135351, 4543, 40, 'Potilaan syntymäaika'),
(135352, 4551, 40, 'Potilaan etunimi'),
(135353, 4553, 40, 'Potilaan etunimi puuttuu'),
(135354, 4558, 40, 'Potilaan sukupuoli'),
(135355, 4559, 40, 'Potilaan sukupuoli puuttuu'),
(135356, 4563, 40, 'Potilaan kotipuhelin'),
(135357, 4564, 40, 'Potilaan tunniste'),
(135358, 4565, 40, 'Potilaan tunniste'),
(135359, 4566, 40, 'Potilaan henkilökortti'),
(135360, 4575, 40, 'Potilaan sukunimi'),
(135361, 4577, 40, 'Potilaan sukunimi puuttuu'),
(135362, 4581, 40, 'Potilaslista'),
(135363, 4584, 40, 'Potilaslistaukset uuteen ikkunaan'),
(135364, 4585, 40, 'Potilaslistaussivun mitta'),
(135365, 4589, 40, 'Potilaan nimi'),
(135366, 4590, 40, 'Potilaan nimi ja osoite'),
(135367, 4593, 40, 'Potilaan nimi vaaditaan'),
(135368, 4599, 40, 'Potilasnumero'),
(135369, 4603, 40, 'Potilasportaali'),
(135370, 4605, 40, 'Potilasportaali on suljettu'),
(135371, 4606, 40, 'Potilasportaalin kirjautuminen'),
(135372, 4607, 40, 'Potilasportaalin www-osoite'),
(135373, 4610, 40, 'Potilastietojen pyyntö'),
(135374, 4611, 40, 'Potilastietojen pyyntö'),
(135375, 4613, 40, 'Muistutus potilaalle'),
(135376, 4619, 40, 'Muistutukset potilaille'),
(135377, 4624, 40, 'Potilashakutulosten tyyli'),
(135378, 4625, 40, 'Potilaiden haku / lisäys näkymä'),
(135379, 4633, 40, 'Potilas/asiakas'),
(135380, 4634, 40, 'Potilas:'),
(135381, 4635, 40, 'Potilastunniste'),
(135382, 4636, 40, 'Potilaat'),
(135383, 4638, 40, 'Maksu'),
(135384, 4640, 40, 'Maksupäivä:'),
(135385, 4641, 40, 'Maksun tila'),
(135386, 4642, 40, 'Maksun saajan nimi'),
(135387, 4643, 40, 'Maksaja'),
(135388, 4647, 40, 'Maksusuoritus'),
(135389, 4648, 40, 'maksusuoritus'),
(135390, 4651, 40, 'Maksettava summa'),
(135391, 4652, 40, 'Maksettavan summan tulee olla numeerinen'),
(135392, 4654, 40, 'Maksupäivä'),
(135393, 4656, 40, 'Maksaja'),
(135394, 4675, 40, 'Hyväksymistä odottavat'),
(135395, 4705, 40, 'Piste'),
(135396, 4711, 40, 'Farsi'),
(135397, 4725, 40, 'phiMail salasana'),
(135398, 4726, 40, 'phiMail palvelimen osoite'),
(135399, 4727, 40, 'phiMail käyttäjätunnus'),
(135400, 4729, 40, 'Puhelin'),
(135401, 4732, 40, 'Matkapuhelin'),
(135402, 4736, 40, 'Kotipuhelin'),
(135403, 4737, 40, 'Puhelinaika'),
(135404, 4738, 40, 'Puhelinnumero'),
(135405, 4739, 40, 'Puhelinnumero'),
(135406, 4742, 40, 'PHP pakattu'),
(135407, 4743, 40, 'PHP CURL moduulin pitäisi olla päällä palvelimellasi.'),
(135408, 4744, 40, 'PHP purettu'),
(135409, 4745, 40, 'PHP-gacl pääsynvalvonta ei ole päällä'),
(135410, 4746, 40, 'PHP-gacl ei asennettu'),
(135411, 4747, 40, 'Terveystarkastus'),
(135412, 4750, 40, 'Lääkärin allekirjoitus'),
(135413, 4752, 40, 'Lääkärit'),
(135414, 4753, 40, 'valitse'),
(135415, 4754, 40, 'Valitse'),
(135416, 4755, 40, 'Valitse CSS teema.'),
(135417, 4767, 40, 'Muotoilematon teksti'),
(135418, 4786, 40, 'Ota yhteyttä jos joku yllä olevista tiedoista on väärä'),
(135419, 4787, 40, 'Ole hyvä ja vaihda salasanasi.'),
(135420, 4788, 40, 'Ole hyvä ja valitse tiedosto'),
(135421, 4789, 40, 'Ole hyvä ja valitse potilas'),
(135422, 4792, 40, 'Ole hyvä ja valitse arvo kohteelle'),
(135423, 4793, 40, 'Ole hyvä ja valitse ensin aikajakso, klikkaa sitten Virkistä nähdäksesi tulokset.'),
(135424, 4797, 40, 'Ole hyvä ja sulje tämä ikkuna.'),
(135425, 4800, 40, 'Ole hyvä ja korjaa arvo(t) ennen jatkamista!'),
(135426, 4801, 40, 'Ole hyvä ja luo seuraava hakemisto ennen jatkamista'),
(135427, 4802, 40, 'Lääkemääräystä ei saa hyväksyä, mikäli sitä ei ole lähetetty faksilla.'),
(135428, 4803, 40, 'Lääkemääräystä ei saa hyväksyä, mikäli sitä ei ole lähetetty faksilla.'),
(135429, 4805, 40, 'OLE HYVÄ JA KÄYNNISTÄ CURL LAAJENNUS'),
(135430, 4806, 40, 'OLE HYVÄ JA KÄYNNISTÄ OPENSSL LAAJENNUS'),
(135431, 4807, 40, 'OLE HYVÄ JA KÄYNNISTÄ SOAP LAAJENNUS'),
(135432, 4808, 40, 'OLE HYVÄ JA KÄYNNISTÄ XML LAAJENNUS'),
(135433, 4810, 40, 'Ole hyvä ja anna päiväys.'),
(135434, 4812, 40, 'Ole hyvä ja kirjoita viesti'),
(135435, 4813, 40, 'Ole hyvä ja anna rahasumma käyttäen vain numeroita ja desimaalipistettä.'),
(135436, 4814, 40, 'Ole hyvä ja anna uusi salasana'),
(135437, 4820, 40, 'Ole hyvä ja anna päättymispäiväksi päivä, joka on aloituspäivän jälkeen!'),
(135438, 4821, 40, 'Ole hyvä ja anna uusi hakutermi'),
(135439, 4822, 40, 'Ole hyvä ja anna oikea uudelleentunnistautumiskoodi'),
(135440, 4823, 40, 'Ole hyvä ja anna salasana'),
(135441, 4824, 40, 'Ole hyvä ja anna shekin numero'),
(135442, 4825, 40, 'Ole hyvä ja anna viite-/shekinnumero'),
(135443, 4826, 40, 'Ole hyvä ja anna päiväys'),
(135444, 4827, 40, 'Ole hyvä ja anna maksettava summa'),
(135445, 4828, 40, 'Ole hyvä ja anna maksun luokka'),
(135446, 4829, 40, 'Ole hyvä ja anna maksajan tiedot'),
(135447, 4846, 40, 'Ole hyvä ja katso liitteenä oleva PDF.'),
(135448, 4847, 40, 'Ole hyvä ja valitse'),
(135449, 4849, 40, 'Ole hyvä ja valitse kieli'),
(135450, 4850, 40, 'Ole hyvä ja valitse potilas.'),
(135451, 4854, 40, 'Ole hyvä ja valitse vastaanottaja'),
(135452, 4855, 40, 'Ole hyvä ja valitse aloitus- ja lopetuspäivä'),
(135453, 4857, 40, 'Ole hyvä ja valitse aktiivinen ryhmä'),
(135454, 4859, 40, 'Ole hyvä ja valitse tapahtuma'),
(135455, 4863, 40, 'Ole hyvä ja valitse ainakin yksi lääkemääräys!'),
(135456, 4865, 40, 'Ole hyvä ja valitse haluamasi sivut kopioitavaksi tai edelleen lähetettäviksi:'),
(135457, 4866, 40, 'Ole hyvä ja valitse maksutapa'),
(135458, 4868, 40, 'Ole hyvä ja valitse käyntiluokka'),
(135459, 4870, 40, 'Ole hyvä ja aseta'),
(135460, 4900, 40, 'Puola'),
(135461, 4916, 40, 'Pysty'),
(135462, 4917, 40, 'Portugali'),
(135463, 4918, 40, 'Portugali (Brasilialainen)'),
(135464, 4919, 40, 'Portugali (Eurooppalainen)'),
(135465, 4938, 40, 'Postinumero'),
(135466, 4939, 40, 'Postinumero'),
(135467, 4948, 40, 'Voimanlähteenä'),
(135468, 4958, 40, 'Ennakkomaksu'),
(135469, 4959, 40, 'Ennakkomaksu'),
(135470, 4971, 40, 'Valmistaudutaan ajamaan raportti'),
(135471, 4972, 40, 'Ennakkomaksu'),
(135472, 4973, 40, 'Lääkemääräys'),
(135473, 4998, 40, 'Esikatsele tapahtumaa'),
(135474, 5007, 40, 'Hinta'),
(135475, 5011, 40, 'Hinnat'),
(135476, 5032, 40, 'Tulosta tyhjä lähetelomake'),
(135477, 5086, 40, 'Toimenpide'),
(135478, 5114, 40, 'Toimenpiteet'),
(135479, 5115, 40, 'Käsittele'),
(135480, 5116, 40, 'Käsittele ja lähetä muistutukset'),
(135481, 5119, 40, 'Käsittele muistutukset'),
(135482, 5120, 40, 'Käsittely vie hetken'),
(135483, 5121, 40, 'Käsitelty'),
(135484, 5122, 40, 'Käsittelijä'),
(135485, 5124, 40, 'käsitelty onnistuneesti'),
(135486, 5125, 40, 'Käsittelee'),
(135487, 5126, 40, 'Käsittelee ja lähettää muistutuksia potilaille'),
(135488, 5127, 40, 'Käsittelee potilaiden muistutuksia'),
(135489, 5128, 40, 'Käsittelyaika'),
(135490, 5152, 40, 'Hoitava lääkäri'),
(135491, 5153, 40, 'SV numero'),
(135492, 5154, 40, 'SV numero'),
(135493, 5159, 40, 'SV numero'),
(135494, 5162, 40, 'Lääkäri'),
(135495, 5163, 40, 'Lääkärit'),
(135496, 5165, 40, 'Lääkärit näkevät koko kalenterin'),
(135497, 5188, 40, 'PT_CITY'),
(135498, 5189, 40, 'PT_DOB'),
(135499, 5190, 40, 'PT_EMAIL'),
(135500, 5191, 40, 'PT_FNAME'),
(135501, 5192, 40, 'PT_LNAME'),
(135502, 5193, 40, 'PT_MNAME'),
(135503, 5194, 40, 'PT_PHONE_CELL'),
(135504, 5195, 40, 'PT_PHONE_HOME'),
(135505, 5196, 40, 'PT_POSTAL'),
(135506, 5197, 40, 'PT_SSN'),
(135507, 5198, 40, 'PT_STATE'),
(135508, 5199, 40, 'PT_STREET'),
(135509, 5201, 40, 'Julkinen'),
(135510, 5203, 40, 'Julkinen terveydenhuolto tai muu julkispalvelu'),
(135511, 5206, 40, 'Pulssi'),
(135512, 5224, 40, 'Laatu'),
(135513, 5225, 40, 'Laatumittarit'),
(135514, 5226, 40, 'Määrä'),
(135515, 5241, 40, 'Lopettanut'),
(135516, 5243, 40, 'R'),
(135517, 5245, 40, 'Rotu'),
(135518, 5246, 40, 'Rotu ja etnisyys'),
(135519, 5247, 40, 'Rotu/Etnisyys'),
(135520, 5248, 40, 'Radio'),
(135521, 5249, 40, 'Radiopainikkeet'),
(135522, 5252, 40, 'Ihottumat'),
(135523, 5256, 40, 'Uudelleen tunnistautuminen'),
(135524, 5257, 40, 'Uudelleentunnistautumisprosessi on valmis'),
(135525, 5258, 40, 'Uudelleentunnistautumisprosessi on käynnissä'),
(135526, 5265, 40, 'Lue'),
(135527, 5268, 40, 'Oikea nimi'),
(135528, 5270, 40, 'Syy'),
(135529, 5271, 40, 'Kuolinsyy'),
(135530, 5272, 40, 'Kuolinsyy'),
(135531, 5275, 40, 'Käynnin syy'),
(135532, 5277, 40, 'Kuitti'),
(135533, 5278, 40, 'Kuitti maksusta'),
(135534, 5279, 40, 'Kuitti luotu'),
(135535, 5282, 40, 'Vastaanotettu'),
(135536, 5283, 40, 'Vastaanottaja'),
(135537, 5284, 40, 'Vastaanotetut faxit'),
(135538, 5293, 40, 'Vastaanottaja'),
(135539, 5294, 40, 'Vastaanottajien lista on tyhjä'),
(135540, 5295, 40, 'Vastaanottajan nimi'),
(135541, 5298, 40, 'Suositus'),
(135542, 5300, 40, 'Suositukset'),
(135543, 5301, 40, 'Suositukset ja hoidot'),
(135544, 5302, 40, 'Erikoislääkärin suositukset'),
(135545, 5332, 40, 'Lähettävän lääkärin kiireellisyysluokitus'),
(135546, 5334, 40, 'Lähettämisen syy'),
(135547, 5337, 40, 'Lähete'),
(135548, 5338, 40, 'Lähetteen antaja'),
(135549, 5340, 40, 'Lähetteen päiväys'),
(135550, 5341, 40, 'Lähete'),
(135551, 5342, 40, 'LÄHETE'),
(135552, 5343, 40, 'Lähetteen tunniste'),
(135553, 5348, 40, 'Lähetteet'),
(135554, 5358, 40, 'Lähettävä lääkäri'),
(135555, 5363, 40, 'Virkistä'),
(135556, 5365, 40, 'Virkistää muistutuksia'),
(135557, 5370, 40, 'rekisteröidy'),
(135558, 5371, 40, 'Rekisteröidy'),
(135559, 5372, 40, 'Rekisteröidyt'),
(135560, 5373, 40, 'rekisteröidyt'),
(135561, 5374, 40, 'Rekisteröidyt moduulit'),
(135562, 5377, 40, 'Kuntoutus'),
(135563, 5379, 40, 'Hylätty'),
(135564, 5389, 40, 'Sukulaiset'),
(135565, 5409, 40, 'Muistutus'),
(135566, 5410, 40, 'Muistutuksen aikavälit'),
(135567, 5411, 40, 'Muistututusta ei vielä lähetetty'),
(135568, 5412, 40, 'Muistutus lähetetty'),
(135569, 5413, 40, 'Muistutukset'),
(135570, 5416, 40, 'Poista'),
(135571, 5419, 40, 'Poista ryhmä'),
(135572, 5421, 40, 'Poistaa tuen rokotuksille'),
(135573, 5422, 40, 'Poistaa phpMyAdmin-tuen'),
(135574, 5423, 40, 'Poistaa tuen lääkemääräyksille'),
(135575, 5427, 40, 'Nimeä uudelleen'),
(135576, 5428, 40, 'Nimeä ryhmä uudelleen'),
(135577, 5437, 40, 'Toista uusi salasana'),
(135578, 5438, 40, 'Toistaa tapahtuman'),
(135579, 5439, 40, 'Toistaa tiedon:'),
(135580, 5440, 40, 'Toistot:'),
(135581, 5441, 40, 'KORVAA'),
(135582, 5443, 40, 'korvattu'),
(135583, 5444, 40, 'Vastauksen päiväys'),
(135584, 5445, 40, 'Vastauksen lähettäjä'),
(135585, 5446, 40, 'Raportti'),
(135586, 5447, 40, 'Raportti – Kliininen'),
(135587, 5449, 40, 'Raportin tekijä'),
(135588, 5452, 40, 'Raportti on lähetetty potilaalle.'),
(135589, 5457, 40, 'Raportin tila'),
(135590, 5461, 40, 'Raportoitu'),
(135591, 5463, 40, 'Raportit'),
(135592, 5475, 40, 'Vaaditaan vahva salasana'),
(135593, 5476, 40, 'Vaaditaan uniikki salasana'),
(135594, 5477, 40, 'Vaadittu'),
(135595, 5478, 40, 'Vaaditaan omavastuu'),
(135596, 5480, 40, 'Vaadittu kenttä puuttuu: Anna etunimi'),
(135597, 5481, 40, 'Vaadittu kenttä puuttuu: Anna sukunimi'),
(135598, 5482, 40, 'Vaadittu kenttä puuttuu: Anna käyttäjätunnus'),
(135599, 5483, 40, 'Vaaditut kentät'),
(135600, 5484, 40, 'Vaatimukset'),
(135601, 5491, 40, 'Palauta'),
(135602, 5515, 40, 'Tuloksia sivulla'),
(135603, 5521, 40, 'Palaa kalenteriin'),
(135604, 5541, 40, 'Oikea'),
(135605, 5542, 40, 'Oikea korva'),
(135606, 5543, 40, 'oikea korva'),
(135607, 5544, 40, 'Oikea marginaali (mm)'),
(135608, 5545, 40, 'Oikea:'),
(135609, 5549, 40, 'Riskitekijät'),
(135610, 5564, 40, 'Rivit'),
(135611, 5583, 40, 'Venäjä'),
(135612, 5601, 40, 'Sotu'),
(135613, 5605, 40, 'Myynti'),
(135614, 5606, 40, 'Myynnit'),
(135615, 5607, 40, 'Myynnit tuotteittain'),
(135616, 5612, 40, 'Näyte'),
(135617, 5617, 40, 'La'),
(135618, 5618, 40, 'La & Su'),
(135619, 5619, 40, 'Lauantai'),
(135620, 5620, 40, 'Tallenna'),
(135621, 5621, 40, 'TALLENNA'),
(135622, 5622, 40, 'Tallenna ja sulje'),
(135623, 5623, 40, 'Tallenna ja poista pyyntö'),
(135624, 5626, 40, 'Tallenna uutena'),
(135625, 5629, 40, 'Tallenna muutokset'),
(135626, 5630, 40, 'Tallenna lomake'),
(135627, 5632, 40, 'Tallenna uusi kenttä'),
(135628, 5633, 40, 'Tallenna uusi ryhmä'),
(135629, 5634, 40, 'Tallenna uusi lista'),
(135630, 5635, 40, 'Tallenna uusi malli'),
(135631, 5640, 40, 'Tallennus onnistui'),
(135632, 5659, 40, 'Hae'),
(135633, 5661, 40, 'hae'),
(135634, 5662, 40, 'hae uudestaan'),
(135635, 5663, 40, 'Hae kaikista sarakkeista'),
(135636, 5664, 40, 'Hae termillä:'),
(135637, 5667, 40, 'Hae kohteesta'),
(135638, 5668, 40, 'Hae kohteesta'),
(135639, 5669, 40, 'Hae tai lisää potilas'),
(135640, 5670, 40, 'Hae maksu'),
(135641, 5671, 40, 'Hae tulokset'),
(135642, 5672, 40, 'Hae tulokset:'),
(135643, 5677, 40, 'Hae tapahtumia'),
(135644, 5678, 40, 'Hae/Lisää'),
(135645, 5679, 40, 'Hae/Lisää vakuuttaja'),
(135646, 5680, 40, 'Tapaamisten haku'),
(135647, 5681, 40, 'Hakee…'),
(135648, 5682, 40, 'Turvavyön käyttö'),
(135649, 5683, 40, 'Turvavyön käyttö'),
(135650, 5684, 40, 'Toinen'),
(135651, 5687, 40, 'Toissijainen'),
(135652, 5688, 40, 'Toissijainen vakuutus'),
(135653, 5690, 40, 'Toissijainen vakuutusyhtiö'),
(135654, 5699, 40, 'Näytä kaikki'),
(135655, 5709, 40, 'Valitse'),
(135656, 5710, 40, 'valitse'),
(135657, 5715, 40, 'Valitse käyttäjä'),
(135658, 5716, 40, 'Valitse kaikki'),
(135659, 5720, 40, 'Valitse luokka'),
(135660, 5724, 40, 'Valitse CSV taulu'),
(135661, 5727, 40, 'Valitse päivä'),
(135662, 5731, 40, 'Valitse lääke'),
(135663, 5732, 40, 'Valitse lääkkeet'),
(135664, 5736, 40, 'Valitse kenttä'),
(135665, 5737, 40, 'Valitse kentät'),
(135666, 5738, 40, 'Valitse tulostettavaksi'),
(135667, 5744, 40, 'Valitse kieli'),
(135668, 5747, 40, 'Valitse yksi tai useampi tiedosto ladattavaksi'),
(135669, 5752, 40, 'Valitse lähde'),
(135670, 5753, 40, 'Valitse malli'),
(135671, 5759, 40, 'Valitse käyttäjä'),
(135672, 5760, 40, 'Valitse käyttäjät pudotusvalikosta'),
(135673, 5761, 40, 'Valitse kielet, jos mitkään, valittavaksi kirjautumisessa. Tarpeellinen vain jos "Kaikki kielet sallittu" ei ole päällä.'),
(135674, 5765, 40, 'Valitut'),
(135675, 5766, 40, 'Valittu käynti'),
(135676, 5771, 40, 'Lähetä'),
(135677, 5772, 40, 'Lähetä päivätty muistutus'),
(135678, 5773, 40, 'Lähetä muistutus'),
(135679, 5774, 40, 'Lähetys käynnissä'),
(135680, 5775, 40, 'Lähetä viesti'),
(135681, 5779, 40, 'Lähetä tämä tiedosto'),
(135682, 5780, 40, 'Lähetä tämä viesti'),
(135683, 5781, 40, 'Lähetä kohteelle'),
(135684, 5784, 40, 'Lähetä kaikille'),
(135685, 5786, 40, 'Lähetä portaaliin'),
(135686, 5787, 40, 'Lähetä portaaliin'),
(135687, 5788, 40, 'Lähettäjä'),
(135688, 5789, 40, 'Lähettäjän tunniste'),
(135689, 5790, 40, 'Lähettäjän tunniste (ISA06)'),
(135690, 5792, 40, 'Lähettäjän tunnisteet'),
(135691, 5797, 40, 'Lähetetty'),
(135692, 5798, 40, 'Lähetetty - Varmistettu'),
(135693, 5800, 40, 'Lähettäjä:'),
(135694, 5801, 40, 'Lähetyspäivä'),
(135695, 5802, 40, 'Lähetetyt'),
(135696, 5804, 40, 'Lähetys onnistui'),
(135697, 5807, 40, 'lähetetty tulostimelle.'),
(135698, 5809, 40, 'Vastaanottaja:'),
(135699, 5810, 40, 'Lähetetty, mutta toimitusta ei vielä varmistettu.'),
(135700, 5811, 40, 'Lähetetty, ei vastaanotettu'),
(135701, 5812, 40, 'Syyskuu'),
(135702, 5813, 40, 'Eronnut'),
(135703, 5814, 40, 'Syyskuu'),
(135704, 5855, 40, 'Sukupuoli'),
(135705, 5856, 40, 'Sukupuolitauti'),
(135706, 5863, 40, 'Lyhyt kuvaus'),
(135707, 5877, 40, 'Näytä'),
(135708, 5878, 40, 'Näytä aktiiviset'),
(135709, 5880, 40, 'Näytä kaikki'),
(135710, 5884, 40, 'Näytä varatut'),
(135711, 5886, 40, 'Näytä vapaat ajat'),
(135712, 5887, 40, 'Näytä sekä imperial- että metrijärjestelmä (oletus metri)'),
(135713, 5888, 40, 'Näytä sekä imperial- että metrijärjestelmä (oletus Imperial)'),
(135714, 5889, 40, 'Näytä yksityiskohdat'),
(135715, 5890, 40, 'Näytä vain virheet'),
(135716, 5894, 40, 'Näytä passiiviset'),
(135717, 5896, 40, 'Näytä valikko'),
(135718, 5897, 40, 'Näytä vain metrijärjestelmä'),
(135719, 5898, 40, 'Näytä merkinnät'),
(135720, 5901, 40, 'Näytä potilasmerkinnät'),
(135721, 5902, 40, 'Näytä paunat ja unssit'),
(135722, 5903, 40, 'Näytä paunat desimaaleina'),
(135723, 5905, 40, 'Näytä muistutukset'),
(135724, 5906, 40, 'Näytä raportti'),
(135725, 5913, 40, 'Näytä vain laskuttamattomat'),
(135726, 5915, 40, 'Näytetään'),
(135727, 5916, 40, 'Näytetään tulokset'),
(135728, 5920, 40, 'Sisarukset'),
(135729, 5933, 40, 'Yksinkertaistettu'),
(135730, 5934, 40, 'Yksinkertaistettu omavastuu'),
(135731, 5935, 40, 'Yksinkertaistettu demografia'),
(135732, 5936, 40, 'Yksinkertaistetut lääkemääräykset'),
(135733, 5938, 40, 'Terveisin,'),
(135734, 5940, 40, 'Naimaton'),
(135735, 5959, 40, 'Iho'),
(135736, 5960, 40, 'Ihosyöpä'),
(135737, 5961, 40, 'Ihotauti'),
(135738, 5977, 40, 'SMS Luoja'),
(135739, 5986, 40, 'SMS lähetetty'),
(135740, 6012, 40, 'Somali'),
(135741, 6048, 40, 'Lähde'),
(135742, 6057, 40, 'Lähde'),
(135743, 6060, 40, 'Välilyönti'),
(135744, 6062, 40, 'Espanja'),
(135745, 6063, 40, 'Espanja (Latinalais-amerikkalainen)'),
(135746, 6064, 40, 'Espanja (Espanja)'),
(135747, 6095, 40, 'Puoliso'),
(135748, 6096, 40, 'Puolison historia'),
(135749, 6111, 40, 'Sotu'),
(135750, 6113, 40, 'Sotu'),
(135751, 6153, 40, 'Tila'),
(135752, 6156, 40, 'Vallitseva tila'),
(135753, 6189, 40, 'Alikategoria'),
(135754, 6190, 40, 'Välisumma'),
(135755, 6191, 40, 'Alikategoria'),
(135756, 6192, 40, 'alikategoria'),
(135757, 6194, 40, 'Aihe'),
(135758, 6195, 40, 'Tulosyy'),
(135759, 6198, 40, 'Lähetä'),
(135760, 6199, 40, 'lähetä'),
(135761, 6200, 40, 'Lähetä koko sisältö'),
(135762, 6201, 40, 'Lähetä ja poista pyyntö'),
(135763, 6202, 40, 'Lähetä tapahtuma'),
(135764, 6203, 40, 'lähetä lomake'),
(135765, 6205, 40, 'lähetetty'),
(135766, 6206, 40, 'Lähettäjä'),
(135767, 6208, 40, 'Tilaaja'),
(135768, 6209, 40, 'Tilaajan osoite'),
(135769, 6261, 40, 'Yhteenveto'),
(135770, 6265, 40, 'Su'),
(135771, 6266, 40, 'Sunda'),
(135772, 6267, 40, 'Sunnuntai'),
(135773, 6300, 40, 'Ruotsi'),
(135774, 6308, 40, 'Synkronoi'),
(135775, 6325, 40, 'Taulu'),
(135776, 6327, 40, 'Taulun luominen epäonnistui'),
(135777, 6328, 40, 'Taulun päivitys epäonnistui'),
(135778, 6329, 40, 'Taulut'),
(135779, 6340, 40, 'Korkea navigaatiopalkki'),
(135780, 6352, 40, 'Tataari'),
(135781, 6364, 40, 'Puhelimen maakoodi'),
(135782, 6366, 40, 'Lämpö'),
(135783, 6367, 40, 'Mittauspaikka'),
(135784, 6368, 40, 'Mittaustapa'),
(135785, 6369, 40, 'Lämpö'),
(135786, 6370, 40, 'Malline'),
(135787, 6371, 40, 'Mallinteen nimi'),
(135788, 6372, 40, 'Mallinteiden nimet eivät voi alkaa numeroilla.'),
(135789, 6373, 40, 'Malline:'),
(135790, 6374, 40, 'Mallinteet'),
(135791, 6385, 40, 'Teksti'),
(135792, 6386, 40, 'Diagnoositeksi'),
(135793, 6387, 40, 'Tekstikenttä'),
(135794, 6395, 40, 'Tekstialue'),
(135795, 6396, 40, 'tekstialue'),
(135796, 6397, 40, 'Tekstilaatikko'),
(135797, 6398, 40, 'tekstilaatikko'),
(135798, 6399, 40, 'Tekstilaatikko listalla'),
(135799, 6400, 40, 'tekstilaatikko listalla'),
(135800, 6493, 40, 'Malli'),
(135801, 6629, 40, 'To'),
(135802, 6630, 40, 'Torstai'),
(135803, 6631, 40, 'Torstai'),
(135804, 6638, 40, 'Aika'),
(135805, 6639, 40, 'Ajan esitysmuoto'),
(135806, 6658, 40, 'Päättyen'),
(135807, 6667, 40, 'Laskutusnäkymään'),
(135808, 6668, 40, 'luokkaan'),
(135809, 6669, 40, 'Kliiniseen näkymään'),
(135810, 6670, 40, 'Omavastuuseen'),
(135811, 6693, 40, 'Vastaanottaja:'),
(135812, 6694, 40, 'Vastaanottaja: '),
(135813, 6708, 40, 'Tupakointi'),
(135814, 6715, 40, 'Tänään'),
(135815, 6716, 40, 'TÄNÄÄN'),
(135816, 6717, 40, 'tänään'),
(135817, 6728, 40, 'Ylä'),
(135818, 6729, 40, 'Ylämarginaali (mm)'),
(135819, 6730, 40, 'Aihe'),
(135820, 6731, 40, 'Yhteensä'),
(135821, 6732, 40, 'yhteensä'),
(135822, 6734, 40, 'Aktiiviset muistutukset yhteensä päivityksen jälkeen'),
(135823, 6735, 40, 'Aktiiviset muistutukset yhteensä ennen päivitystä'),
(135824, 6737, 40, 'Maksettava kokonaissumma'),
(135825, 6738, 40, 'Maksettu kokonaissumma'),
(135826, 6739, 40, 'Maksettava kokonaissaldo'),
(135827, 6740, 40, 'Kokonaisveloitus'),
(135828, 6741, 40, 'Veloitukset yhteensä'),
(135829, 6742, 40, 'Asiakkaat yhteensä'),
(135830, 6743, 40, 'Kokonaiskustannus'),
(135831, 6752, 40, 'Uudet muistutukset yhteensä'),
(135832, 6753, 40, 'Ajanvarausten määrä yhteensä'),
(135833, 6758, 40, 'Potilaiden määrä yhteensä'),
(135834, 6761, 40, 'Potilaat yhteensä'),
(135835, 6780, 40, 'päättyen{{range}}'),
(135836, 6808, 40, 'Käännä tapaamisten luokat'),
(135837, 6809, 40, 'Käännä asiakirjojen luokat'),
(135838, 6810, 40, 'Käännä ulkoasut'),
(135839, 6811, 40, 'Käännä listat'),
(135840, 6813, 40, 'käännä tämä'),
(135841, 6814, 40, 'Käännös'),
(135842, 6815, 40, 'Käännökset'),
(135843, 6820, 40, 'Hoito'),
(135844, 6822, 40, 'Hoidon tavoitteet'),
(135845, 6823, 40, 'Hoitosuunnitelma'),
(135846, 6824, 40, 'Hoidon suunnittelu'),
(135847, 6826, 40, 'Hoito:'),
(135848, 6827, 40, 'Hoito: '),
(135849, 6841, 40, 'Ti'),
(135850, 6842, 40, 'Ti & To'),
(135851, 6843, 40, 'Tiistai'),
(135852, 6851, 40, 'Tyyppi'),
(135853, 6869, 40, 'Ei pääsyä hakemistoon'),
(135854, 6870, 40, 'Ei pääsyä URL:iin'),
(135855, 6871, 40, 'Luominen ei onnistu'),
(135856, 6877, 40, 'Määrittämätön'),
(135857, 6878, 40, 'Ei valtuutusta'),
(135858, 6879, 40, 'Ei valtuutusta pääsyyn eResepteihin'),
(135859, 6880, 40, 'Ei valtuutusta pääsyyn.'),
(135860, 6899, 40, 'Yksikkö'),
(135861, 6904, 40, 'Yksikön on oltava numeerinen'),
(135862, 6915, 40, 'Rekisteröimättömät'),
(135863, 6916, 40, 'Rekisteröimättömät moduulit'),
(135864, 6926, 40, 'Käyttämätön'),
(135865, 6929, 40, 'Tulevat ajanvaraukset'),
(135866, 6930, 40, 'Tulevat tapahtumat'),
(135867, 6931, 40, 'Päivitä'),
(135868, 6932, 40, 'päivitä'),
(135869, 6933, 40, 'Päivitys käynnissä'),
(135870, 6934, 40, 'Päivitä tiedostot'),
(135871, 6935, 40, 'Päivitä tiedot'),
(135872, 6936, 40, 'Päivitä lista'),
(135873, 6938, 40, 'Päivitä valitut kohteet'),
(135874, 6939, 40, 'Päivitä seuraavat muuttujat tiedostossa'),
(135875, 6940, 40, 'Päivitä käyttäjän tiedot'),
(135876, 6943, 40, 'Päivitetään yleisiä asetuksia oletuksiin'),
(135877, 6967, 40, 'Urdu'),
(135878, 6977, 40, 'URL'),
(135879, 6979, 40, 'LibreEHR tukisivujen URL'),
(135880, 6982, 40, 'URL WordPress-sivustolle joka tukee portaalia'),
(135881, 6988, 40, 'Käytä 24 tunnin aikamääritystä?'),
(135882, 6991, 40, 'Käytä Veloitukset-paneelia'),
(135883, 6999, 40, 'Käytä aikaväliä'),
(135884, 7002, 40, 'Käytä kansainvälistä päiväystapaa?'),
(135885, 7007, 40, 'Käyttäjä'),
(135886, 7009, 40, 'Käyttäjä / Ryhmät'),
(135887, 7010, 40, 'Käyttäjien hallinta'),
(135888, 7011, 40, 'Käyttäjien ja tilojen hallinta'),
(135889, 7012, 40, 'Käyttäjien ja ryhmien hallinta'),
(135890, 7013, 40, 'Käyttäjää ei voi poistaa'),
(135891, 7015, 40, 'Käyttäjän määrittelemä'),
(135892, 7016, 40, 'Käyttäjän määrittelemä alue 11'),
(135893, 7017, 40, 'Käyttäjän määrittelemä alue 12'),
(135894, 7018, 40, 'Käyttäjän määrittelemä kenttä'),
(135895, 7019, 40, 'Käyttäjän määrittelemä lista 1'),
(135896, 7020, 40, 'Käyttäjän määrittelemä lista 2'),
(135897, 7021, 40, 'Käyttäjän määrittelemä lista 3'),
(135898, 7022, 40, 'Käyttäjän määrittelemä lista 4'),
(135899, 7023, 40, 'Käyttäjän määrittelemä lista 5'),
(135900, 7024, 40, 'Käyttäjän määrittelemä lista 6'),
(135901, 7025, 40, 'Käyttäjän määrittelemä lista 7'),
(135902, 7026, 40, 'Käyttäjän määrittelemä teksti 1'),
(135903, 7027, 40, 'Käyttäjän määrittelemä teksti 2'),
(135904, 7028, 40, 'Käyttäjän määrittelemä teksti 3'),
(135905, 7029, 40, 'Käyttäjän määrittelemä teksti 4'),
(135906, 7030, 40, 'Käyttäjän määrittelemä teksti 5'),
(135907, 7031, 40, 'Käyttäjän määrittelemä teksti 6'),
(135908, 7032, 40, 'Käyttäjän määrittelemä teksti 7'),
(135909, 7033, 40, 'Käyttäjän määrittelemä teksti 8'),
(135910, 7034, 40, 'Käyttäjän etunimi'),
(135911, 7040, 40, 'Käyttäjän jäsenyydet'),
(135912, 7041, 40, 'Käyttäjän nimi'),
(135913, 7046, 40, 'Käyttäjän asetukset'),
(135914, 7047, 40, 'Käyttäjäkohtaiset asetukset'),
(135915, 7048, 40, 'Käyttäjän uusi salasana'),
(135916, 7049, 40, 'Käyttäjätunnus'),
(135917, 7055, 40, 'Käyttäjätunnus:'),
(135918, 7056, 40, 'Käyttäjät'),
(135919, 7062, 40, 'LOMA'),
(135920, 7063, 40, 'Loma'),
(135921, 7068, 40, 'Arvo'),
(135922, 7069, 40, 'Arvo 1'),
(135923, 7070, 40, 'Arvo 2'),
(135924, 7072, 40, 'Arvon tulee olla numeerinen'),
(135925, 7090, 40, 'katso'),
(135926, 7091, 40, 'Katso'),
(135927, 7092, 40, 'Katso allergiat'),
(135928, 7098, 40, 'Katso CSV taulut'),
(135929, 7100, 40, 'Katso dokumenttia'),
(135930, 7103, 40, 'Näytetäänkö tapahtumat ponnahdusikkunassa?'),
(135931, 7108, 40, 'Katso sivu 1'),
(135932, 7109, 40, 'Katso sivu 2'),
(135933, 7110, 40, 'Katso menneitä ja tulevia muistutuksia'),
(135934, 7111, 40, 'Näytä potilas'),
(135935, 7117, 40, 'Näytä raportti'),
(135936, 7118, 40, 'Näytä LUE MINUT tiedosto'),
(135937, 7123, 40, 'Näytä/Tulosta'),
(135938, 7124, 40, 'Näytä:'),
(135939, 7125, 40, 'VISA'),
(135940, 7126, 40, 'VISA/MC/AMEX/Dis'),
(135941, 7132, 40, 'Käyntiluokka'),
(135942, 7133, 40, 'Käyntiluokka:'),
(135943, 7134, 40, 'Käyntipäivä'),
(135944, 7135, 40, 'Käyntipäivä'),
(135945, 7137, 40, 'Käyntilomake'),
(135946, 7138, 40, 'Käyntihistoria'),
(135947, 7140, 40, 'Käynnit'),
(135948, 7141, 40, 'Käynnit alkaen'),
(135949, 7143, 40, 'Elintoiminnot'),
(135950, 7144, 40, 'Elintoiminnot (metrinen)'),
(135951, 7145, 40, 'Elintoimintolomakkeen asetukset'),
(135952, 7147, 40, 'Puheviesti lähetetty'),
(135953, 7149, 40, 'Oksentaminen'),
(135954, 7152, 40, 'Vyötärön ympärys'),
(135955, 7153, 40, 'Vyötärön ympärys'),
(135956, 7154, 40, 'Odottava'),
(135957, 7158, 40, 'Varasto'),
(135958, 7161, 40, 'Varastot'),
(135959, 7162, 40, 'Lämmin'),
(135960, 7163, 40, 'Varoitus'),
(135961, 7164, 40, 'VAROITUS'),
(135962, 7166, 40, 'Varoitus, shekin numero on jo tietokannassa'),
(135963, 7168, 40, 'Varoitus: Potilaalle on varattu jo aika tälle päivälle!'),
(135964, 7170, 40, 'Varoitus: Potilaan tunniste ei ole uniikki!'),
(135965, 7173, 40, 'Varoitukset'),
(135966, 7181, 40, 'Nettihaku'),
(135967, 7182, 40, 'Nettisivut'),
(135968, 7184, 40, 'Ke'),
(135969, 7185, 40, 'Keskiviikko'),
(135970, 7186, 40, 'Viikko'),
(135971, 7187, 40, 'viikko'),
(135972, 7188, 40, 'Viikkonäkymä'),
(135973, 7189, 40, 'Viikko/Viikot'),
(135974, 7191, 40, 'viikot'),
(135975, 7192, 40, 'Viikot'),
(135976, 7193, 40, 'Paino'),
(135977, 7196, 40, 'Painonvaihtelu'),
(135978, 7197, 40, 'Painon menetys'),
(135979, 7198, 40, 'Laihdutusklinikka'),
(135980, 7199, 40, 'Tervetuloa'),
(135981, 7200, 40, 'Kymri'),
(135982, 7215, 40, 'Leski'),
(135983, 7230, 40, 'Ilman toimipaikkaa'),
(135984, 7231, 40, 'Ilman palvelun tuottajaa'),
(135985, 7232, 40, 'Ilman päivitystä'),
(135986, 7233, 40, 'Todistaja'),
(135987, 7237, 40, 'Naiset'),
(135988, 7238, 40, 'Vain naiset'),
(135989, 7239, 40, 'WordPress portaali'),
(135990, 7240, 40, 'Työ'),
(135991, 7242, 40, 'Puhelin (Työ)'),
(135992, 7243, 40, 'Työpuhelimen numero'),
(135993, 7244, 40, 'Työperäinen?'),
(135994, 7245, 40, 'Työ / Koulutus / Harrastukset'),
(135995, 7246, 40, 'Sairauslomatodistus'),
(135996, 7247, 40, 'työpäivä'),
(135997, 7251, 40, 'Työstää… tässä saattaa kulua hetki.'),
(135998, 7252, 40, 'Huonontunut'),
(135999, 7270, 40, 'rajoitettu kirjoitus'),
(136000, 7285, 40, 'Vuosi'),
(136001, 7286, 40, 'vuosi'),
(136002, 7287, 40, 'Vuosinäkymä'),
(136003, 7288, 40, 'Vuodet'),
(136004, 7289, 40, 'Vuotta'),
(136005, 7290, 40, 'Vuodet tai kuukaudet'),
(136006, 7291, 40, 'Vuodet, kuukaudet ja päivät'),
(136007, 7292, 40, 'KYLLÄ'),
(136008, 7293, 40, 'Kyllä'),
(136009, 7294, 40, 'kyllä'),
(136010, 7295, 40, 'KYLLÄ!'),
(136011, 7298, 40, 'Kyllä/Ei'),
(136012, 7299, 40, 'Kyllä:'),
(136013, 7333, 40, 'Voit jatkaa valittuasi joitakin kenttiä.'),
(136014, 7339, 40, 'Antamasi lopetuspäivä on puutteellinen'),
(136015, 7340, 40, 'Tapahtumasi on poistettu.'),
(136016, 7341, 40, 'Tapahtumaasi on muokattu.'),
(136017, 7342, 40, 'Tapahtumasi on lähetetty.'),
(136018, 7343, 40, 'Tiedostosi on liian suuri'),
(136019, 7348, 40, 'Salasanasi'),
(136020, 7349, 40, 'Salasanasi on vanhentunut. Vaihda salasanasi.'),
(136021, 7350, 40, 'Salasanasi vanhenee'),
(136022, 7351, 40, 'Salasanasi vanhenee tänään. Vaihda salasanasi.'),
(136023, 7358, 40, 'Aloituspäivä on virheellinen'),
(136024, 7359, 40, 'Lähetyksesi epäonnistui.'),
(136025, 7360, 40, 'vvvv-kk-pp'),
(136026, 7361, 40, 'VVVV-KK-PP'),
(136027, 7364, 40, 'vvvv-kk-pp syntymäaika'),
(136028, 7365, 40, 'vvvv-kk-pp syntymäaika'),
(136029, 7366, 40, 'vvvv-kk-pp päättymispäivä'),
(136030, 7376, 40, 'vvvv-kk-pp tapahtuman päivä tai aloituspäivä'),
(136031, 7377, 40, 'vvvv-kk-pp T:m lopetuspäivä'),
(136032, 7378, 40, 'vvvv-kk-pp T:m lopetuspäivä'),
(136033, 7379, 40, 'vvvv-kk-pp T:m aloituspäivä'),
(136034, 7380, 40, 'vvvv-kk-pp T:m aloituspäivä'),
(136035, 7381, 40, 'vvvv-kk-pp tt:mm:ss'),
(136036, 7382, 40, 'vvvv-kk-pp Tunnit(24):minuutit'),
(136037, 7383, 40, 'vvvv-kk-pp tapahtuman viimeinen päivä'),
(136038, 7386, 40, 'Zend moduuli'),
(136039, 7387, 40, 'Nolla'),
(136040, 7388, 40, 'Zhuang'),
(136041, 7389, 40, 'Postinumero'),
(136042, 7390, 40, 'Postinumero'),
(136043, 7391, 40, 'Postinumero/Maa:'),
(136044, 7392, 40, 'Zulu'),
(136045, 7393, 40, ' mutta oli '),
(136046, 7395, 40, 'Haluatko todellakin poistaa'),
(136047, 7396, 40, 'Lääke'),
(136048, 7397, 40, 'sähköpostia lähettämättä'),
(136049, 7399, 40, 'on luotu. '),
(136050, 7400, 40, 'on avattu uudelleen.'),
(136051, 7401, 40, 'Historia'),
(136052, 7402, 40, 'ei ole numero'),
(136053, 7408, 40, 'ei löytynyt!'),
(136054, 7411, 40, 'kunnes'),
(136055, 7427, 40, '(% korvaa kaikkiin merkkijonot, _ korvaa kaikki kirjaimet)'),
(136056, 7429, 40, '(Takaisin)'),
(136057, 7432, 40, '(Lisää)'),
(136058, 7433, 40, '(Uusi potilas)'),
(136059, 7438, 40, '* Muistutus tehty'),
(136060, 7440, 40, '* Vaadittu'),
(136061, 7442, 40, '- Ei mikään'),
(136062, 7443, 40, '-- Kaikki --'),
(136063, 7444, 40, '-- Valitse rooli --'),
(136064, 7445, 40, '.'),
(136065, 7446, 40, '0'),
(136066, 7447, 40, '0-10'),
(136067, 7448, 40, '0-24'),
(136068, 7451, 40, '1'),
(136069, 7452, 40, '1=Pohjois-Amerikka. Katso osoitteesta http://www.wtng.info/ muiden maiden koodit.'),
(136070, 7458, 40, '11-14'),
(136071, 7459, 40, '12 t'),
(136072, 7460, 40, '15-19'),
(136073, 7461, 40, '1'),
(136074, 7462, 40, '2'),
(136075, 7467, 40, '2 - 20 vuotta'),
(136076, 7468, 40, '20-24'),
(136077, 7477, 40, '2111-13'),
(136078, 7478, 40, '24 t'),
(136079, 7479, 40, '25+'),
(136080, 7480, 40, '25-29'),
(136081, 7481, 40, '2'),
(136082, 7483, 40, '3 kuukautta'),
(136083, 7485, 40, 'Kolmasti päivässä'),
(136084, 7487, 40, '30-34'),
(136085, 7488, 40, '35-39'),
(136086, 7489, 40, '3'),
(136087, 7491, 40, '4 kuukautta'),
(136088, 7493, 40, 'Neljästi päivässä'),
(136089, 7495, 40, '40-44'),
(136090, 7496, 40, '45+'),
(136091, 7504, 40, '4'),
(136092, 7509, 40, '5'),
(136093, 7510, 40, '6 kuukautta'),
(136094, 7514, 40, '6'),
(136095, 7528, 40, '< Tutkimushuoneessa'),
(136096, 7530, 40, '?'),
(136097, 7531, 40, '? Ei saapunut'),
(136098, 7532, 40, '@ Saapunut'),
(136099, 7533, 40, '[Vaihda näkymää]'),
(136100, 7538, 40, '[ei suositella]'),
(136101, 7539, 40, '[Käyntien määrä]'),
(136102, 7540, 40, '[Raportit]'),
(136103, 7541, 40, '[Valitse kaikki]'),
(136104, 7542, 40, '[SQL-Ledger]'),
(136105, 7543, 40, '[Aloita ryhmäajon työstäminen]'),
(136106, 7544, 40, '[Näytä loki]'),
(136107, 7545, 40, '[Näytä tulostettava raportti]'),
(136108, 7546, 40, '_PC_DUR_HOURS'),
(136109, 7547, 40, '_PC_DUR_MINUTES'),
(136110, 7548, 40, '_PC_LOCALE'),
(136111, 7549, 40, '~ Saapunut myöhässä'),
(136112, 25, 41, 'a.m'),
(136113, 27, 41, 'AB'),
(136114, 29, 41, '농양'),
(136115, 30, 41, '복부'),
(136116, 32, 41, '비정상'),
(136117, 34, 41, '비정상'),
(136118, 35, 41, '혈액검사 비정상'),
(136119, 36, 41, '모발자람 비정상'),
(136120, 37, 41, '유방쵤영 비정상'),
(136121, 39, 41, '유산'),
(136122, 41, 41, '유산 방법'),
(136123, 42, 41, '유산 관련 범주'),
(136124, 43, 41, '유산'),
(136125, 44, 41, '달력에 대하여'),
(136126, 64, 41, '통증'),
(136127, 67, 41, 'ACL'),
(136128, 71, 41, '여드름'),
(136129, 74, 41, '행위'),
(136130, 75, 41, '행위들'),
(136131, 87, 41, '활력'),
(136132, 88, 41, '활력 형태'),
(136133, 90, 41, '급성 중독/금단'),
(136134, 92, 41, '만성에 급성'),
(136135, 95, 41, 'ADD'),
(136136, 104, 41, '버튼추가'),
(136137, 126, 41, '새로 추가'),
(136138, 127, 41, '새로 추가'),
(136139, 128, 41, '새 범주 추가'),
(136140, 132, 41, '새 그룹 추가'),
(136141, 135, 41, '새 기록 추가'),
(136142, 136, 41, '새 노트 추가'),
(136143, 137, 41, '새 파트너 추가'),
(136144, 140, 41, '노트 추가'),
(136145, 141, 41, '환자 기록 추가'),
(136146, 142, 41, '처방 추가'),
(136147, 143, 41, '시술 추가'),
(136148, 146, 41, '규칙 추가'),
(136149, 147, 41, '여기에 추가'),
(136150, 148, 41, '투약리스트에 추가'),
(136151, 149, 41, '레벨에 추가'),
(136152, 151, 41, '사용자 추가'),
(136153, 152, 41, '그룹에 사용자 추가'),
(136154, 153, 41, '추가/편집 eRX'),
(136155, 155, 41, '추가됨'),
(136156, 161, 41, '추가 진단'),
(136157, 162, 41, '추가 병력'),
(136158, 163, 41, '추가 병력 노트'),
(136159, 164, 41, '추가 정보'),
(136160, 165, 41, '추가 검사'),
(136161, 166, 41, '추가 노트'),
(136162, 167, 41, '이 결과에 따른 추가 노트 혹은 권고'),
(136163, 168, 41, '추가 노트 :'),
(136164, 169, 41, '추가 노트 : '),
(136165, 170, 41, '추가 엑스선 노트 :'),
(136166, 174, 41, '주소록'),
(136167, 175, 41, '주소'),
(136168, 178, 41, '주소록'),
(136169, 187, 41, '주소1'),
(136170, 188, 41, '주소2'),
(136171, 189, 41, '주소'),
(136172, 192, 41, '조정'),
(136173, 199, 41, '관리자'),
(136174, 200, 41, '관리자 이메일 주소'),
(136175, 210, 41, '입원일'),
(136176, 212, 41, '성인 체중 screening 과 추적'),
(136177, 213, 41, '성인 체중 screening 과 추적(CQM)'),
(136178, 233, 41, '다시'),
(136179, 234, 41, '나이'),
(136180, 235, 41, '나이로'),
(136181, 236, 41, '나이 범주'),
(136182, 237, 41, '나이가 범위를 벗어남'),
(136183, 238, 41, '나이표시 형태'),
(136184, 243, 41, '최고 연령'),
(136185, 244, 41, '최저 연령'),
(136186, 245, 41, '연령대'),
(136187, 249, 41, '알바니아인'),
(136188, 250, 41, '알콜'),
(136189, 251, 41, '알콜 소비'),
(136190, 259, 41, '전체'),
(136191, 260, 41, '전체'),
(136192, 268, 41, '전체 코드'),
(136193, 274, 41, '모든 언어 허가됨'),
(136194, 276, 41, '첫이름의 전체 혹은 부분'),
(136195, 277, 41, '마지막 이름의 전체 혹은 부분'),
(136196, 283, 41, '전체 주제'),
(136197, 284, 41, '전체 사용자'),
(136198, 295, 41, '허가됨'),
(136199, 296, 41, '로그인시 선택에 의해 모든 언어가 허가됨'),
(136200, 299, 41, '메일 허가됨'),
(136201, 300, 41, '메일 내용 허가되었나요?'),
(136202, 301, 41, '메일 허가되었나요?'),
(136203, 303, 41, '건강정보 교환 허가됨'),
(136204, 304, 41, '예방주사 정보 교환'),
(136205, 306, 41, '메일 메시지 허가'),
(136206, 309, 41, 'SMS 허가'),
(136207, 310, 41, 'SMS 허가(텍스트) ?'),
(136208, 316, 41, '허가됨'),
(136209, 317, 41, '언어들 허가됨'),
(136210, 323, 41, '이미 존재함'),
(136211, 324, 41, '이미 존재함'),
(136212, 374, 41, '빈혈'),
(136213, 375, 41, '발목'),
(136214, 378, 41, '발목 문제'),
(136215, 385, 41, '불안'),
(136216, 395, 41, '무호흡'),
(136217, 396, 41, '외양'),
(136218, 397, 41, '외양:'),
(136219, 402, 41, '충수절제술'),
(136220, 414, 41, '피부에 도포'),
(136221, 415, 41, '적용'),
(136222, 416, 41, '부위에 적용'),
(136223, 478, 41, '관절염'),
(136224, 484, 41, '아시아인'),
(136225, 490, 41, '천식'),
(136226, 574, 41, '요통'),
(136227, 590, 41, '백업'),
(136228, 591, 41, '백업파일이 만들어짐, 다운로드 중'),
(136229, 598, 41, '균형'),
(136230, 599, 41, '균헝'),
(136231, 620, 41, '양성'),
(136232, 621, 41, '시작일'),
(136233, 679, 41, '혈액'),
(136234, 680, 41, '혈압'),
(136235, 681, 41, '혈압'),
(136236, 697, 41, '양측 귀'),
(136237, 698, 41, '양측 귀'),
(136238, 699, 41, '바닥'),
(136239, 715, 41, 'BP'),
(136240, 716, 41, '확장기혈압'),
(136241, 717, 41, '수축기혈압'),
(136242, 724, 41, '유방 생검'),
(136243, 725, 41, '유방 분비물'),
(136244, 726, 41, '유방 질환'),
(136245, 727, 41, '유방 exam'),
(136246, 728, 41, '유방 종괴'),
(136247, 730, 41, '호흡 소리'),
(136248, 732, 41, '골절'),
(136249, 757, 41, '카페인 섭취'),
(136250, 2806, 41, 'A1 간염'),
(136251, 2807, 41, 'A2 간염'),
(136252, 2808, 41, 'B1 간염'),
(136253, 2809, 41, 'B2 간염'),
(136254, 2810, 41, 'B3 간염'),
(136255, 2811, 41, '여기'),
(136256, 2813, 41, '탈장 수술'),
(136257, 2814, 41, '탈출된 디스크'),
(136258, 2815, 41, '헤르페스'),
(136259, 3919, 41, '새 문장'),
(136260, 3920, 41, '새 암호'),
(136261, 3921, 41, '신환'),
(136262, 3922, 41, '신환'),
(136263, 3924, 41, '신환 폼'),
(136264, 3925, 41, '신환 번호'),
(136265, 3928, 41, '신환'),
(136266, 3930, 41, '새로찾기'),
(136267, 3932, 41, '새 사용자'),
(136268, 3934, 41, '새 방문'),
(136269, 3935, 41, '새로 검색'),
(136270, 1, 46, 'एक'),
(136271, 2, 46, 'एक चेक नंबर किंवा दावा संख्या पैसे ओळखण्यासाठी'),
(136272, 3, 46, 'प्रशासक वापरकर्ता एक क्लायंट प्रमाणपत्र'),
(136273, 4, 46, 'एक क्लिनिकल दस्तऐवज संलग्न आहे'),
(136274, 5, 46, 'एक क्लिनिकल दस्तऐवज संलग्न आहे.'),
(136275, 7, 46, 'एक वितरक आवश्यक आहे'),
(136276, 8, 46, 'एक GCAC भेट फॉर्म भेट जोडले पाहिजे.'),
(136277, 9, 46, 'lot नंबर आवश्यक आहे'),
(136278, 10, 46, 'lot नंबर आवश्यक आहे!'),
(136279, 11, 46, 'एक लोअरकेस पत्र'),
(136280, 12, 46, 'अनेक'),
(136281, 14, 46, 'या आयडी एक रुग्ण आधीपासून विद्यमान आहे.'),
(136282, 15, 46, 'या नावाची एक रुग्ण आधीपासून विद्यमान आहे.'),
(136283, 16, 46, 'या एस रुग्णाच्या आधीपासून विद्यमान आहे.'),
(136284, 17, 46, 'एक सकारात्मक क्रमांक (ऋण संख्या उतरत्या क्रमाने गेल्या भेटी दर्शवेल) रुग्णांच्या सारांश स्क्रीन मध्ये एक विजेट अनेक गेल्या भेटी दर्शवेल');
INSERT INTO `lang_definitions` VALUES
(136285, 18, 46, 'एक सकारात्मक संख्या रुग्णांच्या सारांश स्क्रीन मध्ये एक विजेट अनेक गेल्या भेटी दर्शवेल.'),
(136286, 19, 46, 'एक रेफरल स्रोत प्रत्येक भेट निर्देशीत केले जाऊ शकते.'),
(136287, 20, 46, 'संबंधित IPPF कोड आवश्यक आहे!'),
(136288, 21, 46, 'विशेष वर्ण'),
(136289, 22, 46, 'एक अद्वितीय मूल्य, वापरकर्ता दिसत नाही या क्षेत्रात ओळखण्यासाठी'),
(136290, 23, 46, 'भेट आधीच या रुग्णाला आज अस्तित्वात आहे. नवीन तयार पुढे ते उघडण्याचा रद्द करा किंवा OK वर क्लिक करा.'),
(136291, 24, 46, 'a.c.'),
(136292, 25, 46, 'दुपारी'),
(136293, 26, 46, 'एक / महिला स्तर उजवे:'),
(136294, 27, 46, 'अब्राहम'),
(136295, 28, 46, 'संक्षेप'),
(136296, 29, 46, 'Abcess:'),
(136297, 30, 46, 'ओटीपोटात'),
(136298, 31, 46, 'वजन चार (4) पावले सहन करणे शक्य:'),
(136299, 32, 46, 'एबीएन'),
(136300, 33, 46, 'ABN1'),
(136301, 34, 46, 'असामान्य'),
(136302, 35, 46, 'असामान्य रक्त चाचणी'),
(136303, 36, 46, 'असामान्य केस वाढ'),
(136304, 37, 46, 'असामान्य मध्यमवयानंतरचा'),
(136305, 39, 46, 'गर्भपात'),
(136306, 40, 46, 'गर्भपात मुद्दे'),
(136307, 41, 46, 'गर्भपात पद्धत'),
(136308, 42, 46, 'गर्भपात-संबंधित श्रेणी'),
(136309, 43, 46, 'गर्भपात'),
(136310, 44, 46, 'कॅलेंडर बद्दल'),
(136311, 46, 46, 'निदान करून सु'),
(136312, 47, 46, 'असाइनमेंट स्वीकारा'),
(136313, 48, 46, 'भरणा स्वीकारा'),
(136314, 49, 46, 'भरणा स्वीकारा'),
(136315, 50, 46, 'असाइनमेंट स्वीकारते'),
(136316, 51, 46, 'एक्सेस कंट्रोल'),
(136317, 52, 46, 'एक्सेस कंट्रोल यादी प्रशासन'),
(136318, 53, 46, 'प्रवेश तारीख'),
(136319, 54, 46, 'प्रवेश परवानगी नाही'),
(136320, 55, 46, 'प्रवेश अधिकृत नाही'),
(136321, 56, 46, 'आपले रुग्णांच्या पोर्टल प्रवेश'),
(136322, 57, 46, 'अपघात'),
(136323, 59, 46, 'खात्याचे नाव'),
(136324, 62, 46, 'लेखा'),
(136325, 64, 46, 'वेदना'),
(136326, 65, 46, 'पोचपावती मागणी (ISA14)'),
(136327, 66, 46, 'घोरतात, परवाना व सर्टिफिकेशन'),
(136328, 67, 46, 'ACL यांना आधार देतो'),
(136329, 68, 46, 'ACL यांना आधार देतो प्रशासन'),
(136330, 69, 46, 'ACL यांना आधार देतो प्रशासन अधिकृत नाही'),
(136331, 70, 46, 'ACL यांना यशस्वीपणे अद्यतनित'),
(136332, 71, 46, 'पुरळ'),
(136333, 72, 46, 'कायदा'),
(136334, 73, 46, 'कायदा तारीख'),
(136335, 74, 46, 'क्रिया'),
(136336, 75, 46, 'क्रिया'),
(136337, 77, 46, 'CCR / सीसीडीची अहवाल सक्रिय'),
(136338, 78, 46, 'सक्रिय'),
(136339, 79, 46, 'सक्रिय अॅलर्ट'),
(136340, 80, 46, 'सक्रिय अॅलर्ट नियम'),
(136341, 81, 46, 'सक्रिय सतर्कता / स्मरणपत्रे'),
(136342, 82, 46, 'सक्रिय आढळतात'),
(136343, 84, 46, 'सक्रिय याद्या'),
(136344, 85, 46, 'सक्रिय रुग्णांच्या'),
(136345, 86, 46, 'सक्रिय योजना'),
(136346, 87, 46, 'क्रियाकलाप'),
(136347, 88, 46, 'क्रियाकलाप प्रकार'),
(136348, 90, 46, 'तीव्र उन्माद / काढणे'),
(136349, 91, 46, 'एक गंभीर अट तीव्र प्रकटीकरण'),
(136350, 92, 46, 'तीव्र वर तीव्र'),
(136351, 93, 46, 'जोडा'),
(136352, 94, 46, 'जोडा'),
(136353, 95, 46, 'ADD'),
(136354, 96, 46, 'एक कंपनी जोडा'),
(136355, 98, 46, 'एक फार्मसी जोडा'),
(136356, 100, 46, 'एक कार्यक्रम जोडा '),
(136357, 101, 46, 'नवीन टीप म्हणून जोडा'),
(136358, 102, 46, 'नवीन म्हणून जोडा'),
(136359, 104, 46, 'बटणे जोडा'),
(136360, 105, 46, 'विशेष वर्ण साठी बटणे जोडा, ग्रंथ एक क्लिक करा मजकूर समावेश संपादक वर प्रदर्शित करण्यासाठी'),
(136361, 106, 46, 'श्रेणी जोडा'),
(136362, 107, 46, 'सतत जोडा'),
(136363, 108, 46, 'संदर्भ जोडा'),
(136364, 109, 46, 'Copay जोडा'),
(136365, 110, 46, 'निकष जोडा'),
(136366, 111, 46, 'सानुकूल बटण जोडा'),
(136367, 112, 46, 'निदान जोडा'),
(136368, 113, 46, 'औषध जोडा'),
(136369, 114, 46, 'चकमकीत जोडा'),
(136370, 115, 46, 'चकमकीत / नोट्स जोडा'),
(136371, 116, 46, 'सुविधा जोडा'),
(136372, 117, 46, 'फील्ड जोडा'),
(136373, 118, 46, 'अपॅची संरचना फाइलमध्ये खालील ओळी जोडा'),
(136374, 119, 46, 'गट जोडा'),
(136375, 120, 46, 'ICD कोड जोडा'),
(136376, 121, 46, 'लसीकरण जोडा'),
(136377, 122, 46, 'जोडा अधिकृत नाही!'),
(136378, 123, 46, 'अंक जोडा'),
(136379, 124, 46, 'ट्रॅक आयटम जोडा'),
(136380, 125, 46, 'भाषा जोडा'),
(136381, 126, 46, 'नवीन जोडा'),
(136382, 127, 46, 'नवीन जोडा'),
(136383, 128, 46, 'नवीन श्रेणी जोडा: '),
(136384, 129, 46, 'अपॅची संरचना फाइल नवीन प्रमाणपत्रे जोडा'),
(136385, 130, 46, 'नवीन घटक जोडा'),
(136386, 131, 46, 'नवीन घटक जोडा'),
(136387, 132, 46, 'नवीन गट जोडा'),
(136388, 133, 46, 'नवीन समस्या जोडा'),
(136389, 134, 46, 'नवीन भरपूर आणि व्यवहार जोडा'),
(136390, 135, 46, 'नवीन टीप जोडण्यासाठी'),
(136391, 136, 46, 'नवीन टीप जोडण्यासाठी'),
(136392, 137, 46, 'नवीन भागीदार जोडा'),
(136393, 138, 46, 'नवीन रुग्णांच्या जोडा'),
(136394, 140, 46, 'टीप जोडा'),
(136395, 141, 46, 'रुग्णांच्या नोंद जोडा'),
(136396, 142, 46, 'नियम जोडा'),
(136397, 143, 46, 'प्रक्रिया जोडा'),
(136398, 144, 46, 'प्रदाता क्रमांक जोडा'),
(136399, 145, 46, 'Rehab जोडा'),
(136400, 146, 46, 'नियम जोडा'),
(136401, 147, 46, 'जोडू'),
(136402, 148, 46, 'औषधोपचार यादी जोडा'),
(136403, 149, 46, 'टॉप लेव्हल जोडा'),
(136404, 150, 46, 'व्यवहार जोडा'),
(136405, 151, 46, 'वापरकर्ता जोडा'),
(136406, 152, 46, 'गट करणे वापरकर्ता जोडा'),
(136407, 153, 46, 'जोडा / संपादित करा eRx'),
(136408, 154, 46, '/ संपादित रुग्णांच्या व्यवहार जोडा'),
(136409, 155, 46, 'जोडले'),
(136410, 156, 46, 'लोकसंख्याशास्त्र जमा करणे अधिकृत नाही.'),
(136411, 157, 46, 'आयटम जोडताना अयशस्वी ट्रॅक'),
(136412, 158, 46, 'एडिसन Syndrom'),
(136413, 159, 46, 'एडिसन सिंड्रोम'),
(136414, 160, 46, 'अतिरिक्त विशेषता'),
(136415, 161, 46, 'अतिरिक्त निदान:'),
(136416, 162, 46, 'अतिरिक्त इतिहास'),
(136417, 163, 46, 'अतिरिक्त इतिहास टिपा'),
(136418, 164, 46, 'अतिरिक्त माहिती'),
(136419, 165, 46, 'अतिरिक्त लॅब'),
(136420, 166, 46, 'अतिरिक्त टिपा'),
(136421, 167, 46, 'हा परिणाम किंवा शिफारस अतिरिक्त टिपा'),
(136422, 168, 46, 'अतिरिक्त टिपा:'),
(136423, 169, 46, 'अतिरिक्त टिपा: '),
(136424, 170, 46, 'अतिरिक्त एक्स-रे टिपा:'),
(136425, 171, 46, 'याव्यतिरिक्त, संबंधित अमेरिकन Snomed विस्तार संकुल Snomed प्रकाशन आंतरराष्ट्रीय (इंग्रजी आवृत्ती) स्थापित केल्यानंतर स्वतंत्रपणे आयात करू शकता'),
(136426, 172, 46, 'addonly'),
(136427, 173, 46, 'प बु'),
(136428, 174, 46, 'प पुस्तक'),
(136429, 175, 46, 'पत्ता'),
(136430, 178, 46, 'अॅड्रेस बुक'),
(136431, 179, 46, 'ही प्रक्रिया करत कंपनी अॅड्रेस बुक प्रवेश'),
(136432, 180, 46, 'वितरक साठी अॅड्रेस बुक प्रवेश'),
(136433, 181, 46, 'विक्रेता साठी अॅड्रेस बुक प्रवेश'),
(136434, 182, 46, 'पुस्तक प्रकार पत्ता'),
(136435, 183, 46, 'पत्ता लेबल'),
(136436, 187, 46, 'पत्ता 1'),
(136437, 188, 46, 'Address2'),
(136438, 189, 46, 'पत्ता'),
(136439, 190, 46, 'Adj'),
(136440, 191, 46, 'Adj रक्कम'),
(136441, 192, 46, 'समायोजित'),
(136442, 193, 46, 'समायोजन'),
(136443, 194, 46, 'समायोजन रक्कम'),
(136444, 195, 46, 'समायोजन कारणे'),
(136445, 196, 46, 'कोड समायोजन मूल्य '),
(136446, 197, 46, 'ऍडजस्ट'),
(136447, 198, 46, 'ADM समायोजित'),
(136448, 199, 46, 'प्रशासन'),
(136449, 200, 46, 'प्रशासन ई-मेल पत्ता'),
(136450, 201, 46, 'मार्गे चालवणे'),
(136451, 202, 46, 'प्रशासित'),
(136452, 203, 46, 'प्रशासित'),
(136453, 204, 46, 'प्रशासित तारीख'),
(136454, 205, 46, 'प्रशासित साइट'),
(136455, 206, 46, 'प्रशासन'),
(136456, 207, 46, 'प्रशासन साइट'),
(136457, 208, 46, 'प्रशासक'),
(136458, 209, 46, 'प्रशासक काहीही करू शकतात'),
(136459, 210, 46, 'तारीख देणे'),
(136460, 212, 46, 'प्रौढ वजन स्क्रीनिंग आणि पाठपुरावा'),
(136461, 213, 46, 'प्रौढ वजन स्क्रिनिंग पाठपुरावा (CQM)'),
(136462, 214, 46, 'आगाऊ निर्देशक'),
(136463, 215, 46, 'आगाऊ निर्देश'),
(136464, 216, 46, 'आगाऊ निर्देश चेतावणी'),
(136465, 218, 46, 'प्रगत'),
(136466, 219, 46, 'सल्ला'),
(136467, 220, 46, 'खूप लांबून'),
(136468, 221, 46, 'सामान्य प्रभाव'),
(136469, 222, 46, 'आफ्रिकान्स'),
(136470, 223, 46, 'तास कॉल केल्यानंतर'),
(136471, 224, 46, 'संकेतशब्द मीठ पूर्ण झाले आहे न वापरकर्ते टेबल मध्ये साठवले जातात जेथे जुना पासवर्ड माध्यमांतून स्थलांतर केल्यानंतर, या ध्वज नवीन पद्धतीने केवळ प्रमाणीकरण शक्य आहे जेणेकरून खोटे वर सेट केले पाहिजे'),
(136472, 225, 46, 'वरील संरचना करत केल्यानंतर, ब्राउझरला प्रशासन क्लायंट प्रमाणपत्र आयात आणि Apache सर्व्हर (रिक्त पासवर्ड) पुन्हा सुरू करा.'),
(136473, 226, 46, 'पीडीएफ जतन केल्यावर, चुका तपासण्यासाठी [पहा लॉग] क्लिक करा.'),
(136474, 227, 46, 'मजकूर फाइल (चे) जतन केल्यावर, चुका तपासण्यासाठी [पहा लॉग] क्लिक करा.'),
(136475, 228, 46, 'आपल्या बॅच जतन केल्यावर, चुका तपासण्यासाठी [पहा लॉग] क्लिक करा.'),
(136476, 229, 46, 'त्यानंतर मॅच स्तंभ तयार करण्यासाठी निवडलेली रुग्ण आयडी दाखवा, किंवा 0 आहे.'),
(136477, 230, 46, 'माहिती योग्यरितीने प्रविष्ट आहे, सेव्ह बटणावर क्लिक करा.'),
(136478, 231, 46, 'बटण क्लिक करा अपलोड केल्यानंतर "आयात"'),
(136479, 232, 46, 'उपचार संपल्यावर घेतली जाणारी दक्षता नियोजन'),
(136480, 233, 46, 'पुन्हा'),
(136481, 234, 46, 'वय'),
(136482, 235, 46, 'वय करून'),
(136483, 236, 46, 'वय वर्ग'),
(136484, 237, 46, 'वय डेटा श्रेणी बाहेर आहे.'),
(136485, 238, 46, 'वय प्रदर्शन स्वरूप'),
(136486, 239, 46, 'पासून वय वय स्वरूप वैध नाही'),
(136487, 240, 46, 'पर्यंत वय वय स्वरूप वैध नाही'),
(136488, 241, 46, 'पासून वय'),
(136489, 242, 46, 'प्रदर्शन स्वरूप बदल वर्ष वय'),
(136490, 243, 46, 'वय कमाल'),
(136491, 244, 46, 'वय मि'),
(136492, 245, 46, 'वय श्रेणी'),
(136493, 247, 46, 'स्तंभ वृद्धत्व:'),
(136494, 248, 46, 'अकान'),
(136495, 249, 46, 'अल्बेनियन'),
(136496, 250, 46, 'मद्यार्क'),
(136497, 251, 46, 'मद्य सेवन'),
(136498, 252, 46, 'अल्कोहोल वापर'),
(136499, 253, 46, 'अॅलर्ट संख्या'),
(136500, 255, 46, 'अॅलर्ट'),
(136501, 258, 46, 'अलेउत'),
(136502, 259, 46, 'सर्व'),
(136503, 260, 46, 'सर्व'),
(136504, 261, 46, 'सर्व (Collated स्वरूप अ)'),
(136505, 262, 46, 'सर्व (Collated स्वरूप ब)'),
(136506, 263, 46, 'सर्व (एकूण)'),
(136507, 265, 46, 'सर्व स्वयंचलित माप गणना (एएमसी)'),
(136508, 266, 46, 'सर्व कॅटेगरीज'),
(136509, 267, 46, 'सर्व क्लिनिकल गुणवत्ता उपाय (CQM)'),
(136510, 268, 46, 'सर्व कोड'),
(136511, 269, 46, 'संपूर्ण दिवस'),
(136512, 270, 46, 'सर्व दिवस कार्यक्रम'),
(136513, 271, 46, 'शोध आणि दुप्पट चेक सर्व लोकसंख्याशास्त्र फील्ड,'),
(136514, 272, 46, 'सर्व सुविधा'),
(136515, 273, 46, 'सर्व दुखापती / समस्या / समस्या'),
(136516, 274, 46, 'सर्व भाषा परवानगी'),
(136517, 275, 46, 'सर्व अधिकृत क्लिनिकल गुणवत्ता उपाय (CQM) माप गट'),
(136518, 276, 46, 'पहिले नाव सर्व किंवा काही भाग'),
(136519, 277, 46, 'आडनाव सर्व किंवा काही भाग'),
(136520, 278, 46, 'संस्था सर्व किंवा काही भाग'),
(136521, 279, 46, 'सर्व रुग्णांना'),
(136522, 280, 46, 'सर्व उत्पादने'),
(136523, 281, 46, 'सर्व प्रदाते'),
(136524, 282, 46, 'सर्व पुनरावलोकन आणि नकारात्मक:'),
(136525, 283, 46, 'सर्व विषय'),
(136526, 284, 46, 'सर्व वापरकर्ते'),
(136527, 285, 46, 'असोशी'),
(136528, 286, 46, 'ऍलर्जी'),
(136529, 287, 46, 'ऍलर्जी:'),
(136530, 288, 46, 'ऍलर्जी'),
(136531, 289, 46, 'ऍलर्जी आयात यशस्वीरित्या पूर्ण'),
(136532, 290, 46, 'ऍलर्जी समस्या सूची'),
(136533, 291, 46, 'ऍलर्जी प्रतिक्रिया'),
(136534, 294, 46, 'वाटप'),
(136535, 295, 46, 'परवानगी द्या'),
(136536, 296, 46, 'लॉगिन मेनू वर पर्याय म्हणून सर्व उपलब्ध भाषा परवानगी द्या.'),
(136537, 297, 46, 'निदान पण नाही कार्यपद्धती किंवा आकार असलेली दावे निर्मितीस अनुमती द्या. सर्वाधिक दवाखाने हे करायचे नाही.'),
(136538, 298, 46, 'परवानगी द्या डिबगिंग भाषा'),
(136539, 299, 46, 'ईमेल परवानगी द्या'),
(136540, 300, 46, 'ईमेल संदेश अनुमती द्यायची?'),
(136541, 301, 46, 'ईमेल अनुमती द्यायची?'),
(136542, 302, 46, 'चकमकीत दावे परवानगी द्या'),
(136543, 303, 46, 'आरोग्य माहिती एक्सचेंज परवानगी द्या'),
(136544, 304, 46, 'परवानगी द्या लसीकरण माहिती शेअरिंग'),
(136545, 305, 46, 'परवानगी द्या लसीकरण नोंदणी वापरा'),
(136546, 306, 46, 'मेल संदेश परवानगी द्या'),
(136547, 308, 46, 'रुग्णांच्या पोर्टल परवानगी द्या'),
(136548, 309, 46, 'एसएमएस परवानगी द्या'),
(136549, 310, 46, 'SMS (मजकूर संदेश) अनुमती द्यायची?'),
(136550, 311, 46, 'सादर घटना त्वरित सक्रिय केले करण्याची परवानगी द्यायची?'),
(136551, 312, 46, 'टेलिफोन संदेश अनुमती द्यायची?'),
(136552, 313, 46, 'वापरकर्ते जागतिक घडामोडी प्रकाशित करण्याची परवानगी द्या'),
(136553, 314, 46, 'वापरकर्ते वैयक्तिक कॅलेंडर प्रकाशित करण्याची परवानगी द्या'),
(136554, 315, 46, 'परवानगी द्या आवाज संदेश'),
(136555, 316, 46, 'परवानगी'),
(136556, 317, 46, 'परवानगी भाषा'),
(136557, 318, 46, 'परवानगी (क)'),
(136558, 319, 46, 'संपूर्ण चकमकीत ई-साइन इन करा परवानगी देते'),
(136559, 320, 46, 'अनुमती देते वैयक्तिक अर्ज ई-साइन इन'),
(136560, 321, 46, 'मेल अनुमती देते'),
(136561, 322, 46, 'आवाज संदेश अनुमती देते'),
(136562, 323, 46, 'आधिपासूनच अस्तित्वात आहे'),
(136563, 324, 46, 'आधिपासूनच अस्तित्वात आहे.'),
(136564, 325, 46, 'आधीच दुसर्या अभिज्ञापक निवडा, वापरले'),
(136565, 326, 46, 'आधीच दुसर्या शीर्षक निवडा, वापरले'),
(136566, 327, 46, 'Alt पत्ता'),
(136567, 328, 46, 'बदल'),
(136568, 329, 46, 'वैकल्पिकरित्या, तुम्ही इलेक्ट्रॉनिक पाठवण्याच्या (X12 835) आपण आपल्या देणारा किंवा त्याचे श्रेय क्लिअरींग पासून प्राप्त केली आहे फाइल अपलोड करण्यासाठी शोध पृष्ठ वापरू शकतो. आपण ब्राउझ करा बटण क्लिक करा आणि अपलोड करण्यासाठी फाइल निवडून, आणि नंतर अपलोड सुरू आणि संबंधित पावत्या प्रदर्शित शोध क्लिक करून हे करू शकता. या प्रकरणात इतर घटक लागू होत नाही हे वर नमूद केलेल्या आणि दुर्लक्ष केले जाईल. फाइल अपलोड वाचते पण अद्याप त्यातील सामग्री प्रक्रिया नाही - खालील माणे स्वतंत्रपणे केले आहे.'),
(136569, 330, 46, 'सकाळी'),
(136570, 331, 46, 'सकाळी कार्यक्रम'),
(136571, 332, 46, 'एएमसी'),
(136572, 333, 46, 'एएमसी ट्रॅकिंग'),
(136573, 334, 46, 'एएमसी-2011'),
(136574, 335, 46, 'एएमसी-2014'),
(136575, 338, 46, 'विद्यमान टीप बदल'),
(136576, 339, 46, 'पासून दुरुस्ती'),
(136577, 340, 46, 'दुरुस्ती स्थिती'),
(136578, 341, 46, 'संशोधन'),
(136579, 342, 46, 'साठी संशोधन'),
(136580, 343, 46, 'अमेरिकन भारतीय'),
(136581, 344, 46, 'अमेरिकन भारतीय किंवा अलास्का नेटिव्ह'),
(136582, 345, 46, 'एमेक्स'),
(136583, 346, 46, 'अम्हारिक'),
(136584, 347, 46, 'रक्कम'),
(136585, 348, 46, 'रक्कम प्रशासित'),
(136586, 349, 46, 'रक्कम शुल्क'),
(136587, 350, 46, 'मागील शिल्लक रक्कम'),
(136588, 351, 46, 'या भेटीची रक्कम'),
(136589, 352, 46, 'अदा केलेली रक्कम'),
(136590, 353, 46, 'रक्कम:'),
(136591, 354, 46, 'रक्कम बिल'),
(136592, 355, 46, 'प्रारंभ तारीख पेक्षा नंतर समाप्ती तारीख पुनरावृत्ती घटना आवश्यक आहे!'),
(136593, 356, 46, 'एक त्रुटी फॉर्म साइन इन आली'),
(136594, 357, 46, 'LibreEHR वेब निर्देशिका झाड डम्पिंग करताना एक त्रुटी आली'),
(136595, 358, 46, 'PhpGACL वेब निर्देशिका झाड डम्पिंग करताना एक त्रुटी आली'),
(136596, 359, 46, 'एस क्यू एल-लेजर वेब निर्देशिका झाड डम्पिंग करताना एक त्रुटी आली'),
(136597, 360, 46, 'अपूर्ण GCAC समस्या तयार केले आणि दुवा साधला गेला आहे. कोणीतरी नंतर पूर्ण करणे आवश्यक आहे.'),
(136598, 362, 46, 'एक अनपेक्षित त्रुटी आली आहे.'),
(136599, 363, 46, 'एक लोअरकेस पत्र'),
(136600, 365, 46, 'आणि'),
(136601, 366, 46, 'आणि'),
(136602, 367, 46, 'आणि'),
(136603, 368, 46, 'आणि '),
(136604, 369, 46, 'आणि सर्व गौण डेटा? ही क्रिया लॉग इन केले जाईल'),
(136605, 370, 46, 'आणि सुधारक'),
(136606, 371, 46, 'आणि प्रक्रिया.'),
(136607, 372, 46, 'आणि Apache सर्व्हर पुन्हा सुरू करा.'),
(136608, 373, 46, 'आणि कारण आहे'),
(136609, 374, 46, 'अशक्तपणा'),
(136610, 375, 46, 'पायाचा घोटा'),
(136611, 376, 46, 'पायाचा घोटा + टाच'),
(136612, 377, 46, 'पायाचा घोटा मूल्यांकन फॉर्म'),
(136613, 378, 46, 'पायाचा घोटा समस्या'),
(136614, 379, 46, 'Ankylosing Sondlilitis'),
(136615, 380, 46, 'Ankylosing Spondlilitis'),
(136616, 381, 46, 'भूक मंदावणे'),
(136617, 382, 46, 'तुम्ही पोस्टिंग विंडो मध्ये करू शकता आणखी एक गोष्ट दुय्यम बिलिंग विनंती आहे. आपण जतन करण्यापूर्वी हा चेकबॉक्स निवडा असेल, तर मूळ हक्क पुन्हा उघडले आणि बिलिंग पृष्ठावरील रांगेत, आणि पुढील बिलिंग रन प्रक्रिया केली जाईल जाईल.'),
(136618, 383, 46, 'आधीचा'),
(136619, 384, 46, 'गुद्द्वार नॅथन, नाही मलमार्गविषयक प्रेमळपणा / वस्तुमान'),
(136620, 385, 46, 'काळजी'),
(136621, 386, 46, 'कोणतीही'),
(136622, 387, 46, 'कोणतीही वर्ग'),
(136623, 388, 46, 'इच्छित कोड किंवा त्याचे वर्णन काही भाग'),
(136624, 389, 46, 'इच्छित विशेष काही भाग'),
(136625, 390, 46, 'औषध आयडी किंवा औषध नाव काही भाग'),
(136626, 391, 46, 'लसीकरण आयडी किंवा लसीकरण नाव काही भाग'),
(136627, 392, 46, 'रुग्ण नाव काही भाग, किंवा  "गेल्या, प्रथम ", किंवा  "XY "'),
(136628, 393, 46, 'Anyother संबंधित माहिती'),
(136629, 394, 46, 'एसएमएस गेटवे API की.'),
(136630, 395, 46, 'श्वसनक्रिया बंद होणे'),
(136631, 396, 46, 'स्वरूप'),
(136632, 397, 46, 'स्वरूप:'),
(136633, 398, 46, 'ही टीप जोडा'),
(136634, 399, 46, 'विद्यमान नोंद करण्यासाठी जोडा'),
(136635, 400, 46, 'या टिपेवर जोडा'),
(136636, 401, 46, 'या टीप जोडा'),
(136637, 402, 46, 'आंत्रपुच्छ काढून टाकणे'),
(136638, 403, 46, 'आंत्रपुच्छ काढून टाकणे'),
(136639, 404, 46, 'लागू रुग्णांना'),
(136640, 405, 46, 'अर्ज'),
(136641, 406, 46, 'लॉग इन पृष्ठ मुख्य विंडो शीर्षक अर्ज नाव.'),
(136642, 407, 46, 'अर्ज स्वीकारणारा कोड (GS03 - रिक्त ISA08 वापरले जाईल असेल तर)'),
(136643, 408, 46, 'अर्ज प्रेषक कोड (GS02)'),
(136644, 409, 46, 'अर्ज शीर्षक'),
(136645, 410, 46, 'मर्मस्थाने फॉर्म आणि वाढ चार्ट लागू'),
(136646, 411, 46, 'मर्मस्थाने फॉर्म लागू'),
(136647, 412, 46, 'या फक्त वर्तमान कार्यक्रमात बदल, आणि सर्व भविष्यातील घटना, किंवा सर्व घटना लागू करा?'),
(136648, 413, 46, 'प्रभावित क्षेत्र लागू'),
(136649, 414, 46, 'त्वचा लागू'),
(136650, 415, 46, 'अर्ज'),
(136651, 416, 46, 'साइटवर ठिगळ अर्ज'),
(136652, 417, 46, 'नियुक्ती'),
(136653, 418, 46, 'नियुक्ती तारीख'),
(136654, 419, 46, 'नियुक्ती प्रदर्शन शैली'),
(136655, 420, 46, 'नियुक्ती स्मरणपत्र नियम'),
(136656, 421, 46, 'नियुक्ती स्थिती'),
(136657, 422, 46, 'नियुक्ती पुतळे'),
(136658, 423, 46, 'आत नियुक्ती'),
(136659, 424, 46, 'नियुक्ती / इव्हेंट रंग'),
(136660, 425, 46, 'भेटी'),
(136661, 426, 46, 'भेटी (पर्यायी लिहा)'),
(136662, 427, 46, 'नियुक्ती (राइट, पर्यायी wsome)'),
(136663, 430, 46, 'भेटी आणि Encounters'),
(136664, 431, 46, 'भेटी अहवाल'),
(136665, 432, 46, 'भेटी-Encounters अहवाल'),
(136666, 434, 46, 'मंजूर'),
(136667, 435, 46, 'रुग्णांच्या / Client-> Import-> प्रलंबित मंजूरी पासून रुग्णाला मंजूर'),
(136668, 436, 46, 'मंजूर'),
(136669, 437, 46, 'मंजूर आगामी कार्यक्रम प्रशासन'),
(136670, 438, 46, 'यशस्वीरित्या मंजूर'),
(136671, 440, 46, 'Appt-Enc'),
(136672, 441, 46, 'Appts'),
(136673, 442, 46, 'एप्रिल'),
(136674, 443, 46, 'एप्रिल'),
(136675, 444, 46, 'अरबी'),
(136676, 445, 46, 'अर्गोनीज'),
(136677, 446, 46, 'संग्रहण'),
(136678, 447, 46, 'अनुवादित केले प्रवेश नियंत्रण गट नावे आहेत?'),
(136679, 448, 46, 'नियुक्ती श्रेणी नावे अनुवादित केले आहेत का?'),
(136680, 449, 46, 'दस्तऐवज श्रेणी नावे अनुवादित केले आहेत का?'),
(136681, 450, 46, 'शुल्क हा प्रकार आकारले जातात?'),
(136682, 451, 46, 'अनुवादित केले रुग्णाला नोंद शीर्षके आहेत?'),
(136683, 452, 46, 'कोड बाह्य एस क्यू एल सपाट दगडी पाट्या (0-नाही, 1-ICD10, 2-SNOMED (RF1), 3-SNOMED (RF2)) मध्ये संग्रहित आहेत?'),
(136684, 453, 46, 'आपण या भेट एक नवीन GCAC समस्या पूर्ण करण्यासाठी तयार आहेत?'),
(136685, 454, 46, 'आपण आज पोस्ट खात्री आहे?'),
(136686, 455, 46, 'आपण या घटना मंजूर करू इच्छिता आपल्याला खात्री आहे?'),
(136687, 457, 46, 'आपण पूर्णपणे हा फॉर्म काढू इच्छिता आपल्याला खात्री आहे?'),
(136688, 458, 46, 'आपण हटवू इच्छिता खात्री आहे की'),
(136689, 459, 46, 'आपण हे उघड हटवू इच्छिता आपल्याला खात्री आहे?'),
(136690, 460, 46, 'आपण हा कार्यक्रम हटवू इच्छिता आपल्याला खात्री आहे?'),
(136691, 461, 46, 'आपण डेटाबेस हा आयटम हटवू इच्छिता आपल्याला खात्री आहे?'),
(136692, 462, 46, 'आपण ही नोट हटवू इच्छिता आपल्याला खात्री आहे?'),
(136693, 464, 46, 'आपण या घटना संपादित करू इच्छित आपल्याला खात्री आहे?'),
(136694, 465, 46, 'आपण या घटना लपवू इच्छित आपल्याला खात्री आहे?'),
(136695, 466, 46, 'आपण पुन्हा ते प्रसारित करू इच्छित आपल्याला खात्री आहे?'),
(136696, 467, 46, 'आपण या घटना पाहू इच्छित आपल्याला खात्री आहे?'),
(136697, 468, 46, 'आपण नाव संपूर्ण गट हटवू इच्छित आपली खात्री आहे की'),
(136698, 469, 46, 'आपण संपूर्ण यादी हटवू इच्छित आपली खात्री आहे की'),
(136699, 470, 46, 'आपण क्षेत्रात हटवू इच्छित आपली खात्री आहे की'),
(136700, 471, 46, 'आपण निवडलेल्या शेतात हटवू इच्छित आपल्याला खात्री आहे?'),
(136701, 472, 46, 'आपण आपली खात्री आहे की  ''या क्रिया सुरू करू इच्छितो?'),
(136702, 473, 46, 'क्षेत्र निर्दिष्ट नाही'),
(136703, 474, 46, 'हाताचा'),
(136704, 475, 46, 'आर्मेनियन'),
(136705, 477, 46, 'Arrythmia'),
(136706, 478, 46, 'संधिवात'),
(136707, 479, 46, 'संधिवात / degen संयुक्त diseas'),
(136708, 480, 46, 'संधिवात / degen संयुक्त रोग'),
(136709, 481, 46, 'म्हणून'),
(136710, 482, 46, 'आतापर्यंत'),
(136711, 483, 46, 'ASC'),
(136712, 484, 46, 'आशियाई'),
(136713, 485, 46, 'आसामी'),
(136714, 487, 46, 'मूल्यांकन'),
(136715, 488, 46, 'नियुक्त'),
(136716, 489, 46, 'सहाय्यक'),
(136717, 490, 46, 'दमा'),
(136718, 491, 46, 'येथे'),
(136719, 492, 46, 'तुम्ही सर्व निवडा तर कमीत कमी एक शोध घटक आवश्यक आहे.'),
(136720, 493, 46, 'होडीच्या आकाराचे वेळी'),
(136721, 494, 46, 'होडीच्या आकाराचे वेळी:'),
(136722, 495, 46, 'मैदानी खेळ किंवा खेळाडूविषयक संघ'),
(136723, 496, 46, 'मैदानी खेळ किंवा खेळाडूविषयक टीम'),
(136724, 497, 46, 'मैदानी खेळ किंवा खेळाडूविषयक / इजा'),
(136725, 498, 46, 'ATNA ऑडिट CA प्रमाणपत्र'),
(136726, 499, 46, 'ATNA ऑडिट यजमान'),
(136727, 500, 46, 'ATNA ऑडिट स्थानिक प्रमाणपत्र'),
(136728, 501, 46, 'ATNA ऑडिट पोर्ट'),
(136729, 503, 46, 'लक्ष'),
(136730, 504, 46, 'लक्ष द्या'),
(136731, 506, 46, 'CDR इंजिन क्वेरी ऑडिट'),
(136732, 507, 46, 'ऑडिट लॉग लुडबुड'),
(136733, 508, 46, 'लॉग लुडबुड अहवाल ऑडिट'),
(136734, 509, 46, 'ऑडिट लॉग साठवत'),
(136735, 510, 46, 'ऑडिट लॉग विविध'),
(136736, 511, 46, 'ऑडिट लॉग ऑर्डर'),
(136737, 512, 46, 'ऑडिट लॉग रुग्णांच्या नोंद'),
(136738, 513, 46, 'ऑडिट लॉग शेड्युलिंग'),
(136739, 514, 46, 'ऑडिट लॉग सुरक्षा प्रशासन'),
(136740, 515, 46, 'निवडा क्वेरी लॉग इन ऑडिट'),
(136741, 516, 46, 'ऑगस्ट'),
(136742, 517, 46, 'ऑगस्ट'),
(136743, 519, 46, 'प्रमाणिकरण'),
(136744, 520, 46, 'प्रमाणिकरण / नोट्स'),
(136745, 523, 46, 'प्राधिकृत गट'),
(136746, 524, 46, 'प्राधिकृत स्थिती'),
(136747, 525, 46, 'अधिकृत'),
(136748, 526, 46, 'अधिकृत'),
(136749, 527, 46, 'अधिकृत - कोणत्याही चकमकी'),
(136750, 528, 46, 'अधिकृत - माझ्या चकमकी'),
(136751, 529, 46, 'Authorize.net'),
(136752, 530, 46, 'अधिकृत'),
(136753, 531, 46, 'फक्त अधिकृत'),
(136754, 532, 46, 'ऑटो पाठवा'),
(136755, 535, 46, 'नवी Encounters ऑटो-तयार करा'),
(136756, 536, 46, 'स्वयं-व्युत्पन्न'),
(136757, 537, 46, 'स्वयंचलित माप गणना (एएमसी)'),
(136758, 538, 46, 'स्वयंचलित माप गणना (एएमसी) - 2011'),
(136759, 539, 46, 'स्वयंचलित माप गणना (एएमसी) - 2014'),
(136760, 542, 46, 'स्वयंचलित माप गणना (एएमसी) ट्रॅकिंग'),
(136761, 543, 46, 'स्वयंचलित उपाय (एएमसी)'),
(136762, 544, 46, 'स्वयंचलित'),
(136763, 546, 46, 'नियुक्ती स्थिती सेट केल्यावर स्वयंचलितपणे एक नवीन चकमकीत तयार "@" (आगमन).'),
(136764, 549, 46, 'ऑटोमोबाइल वैद्यकीय'),
(136765, 550, 46, 'स्वयंजतन'),
(136766, 551, 46, 'उपलब्ध श्रेणी'),
(136767, 552, 46, 'उपलब्ध टाइम्स'),
(136768, 553, 46, 'उपलब्ध ट्रॅक'),
(136769, 554, 46, 'अॅव्हेरिक'),
(136770, 555, 46, 'डाव्या nav स्क्रीन मध्ये पॉपअप पासून रुग्ण लेबले छपाई साठी Avery Label प्रकार'),
(136771, 556, 46, 'अवेस्तन'),
(136772, 557, 46, 'सरासरी मासिक'),
(136773, 558, 46, 'एका भागापासून दुसरा भाग फाटुन निघणे / एका भागापासून दुसरा भाग फाटुन निघणे फ्रॅक्चर'),
(136774, 559, 46, 'एका भागापासून दुसरा भाग फाटुन निघणे बाजूकडील घोटा'),
(136775, 560, 46, 'एका भागापासून दुसरा भाग फाटुन निघणे सरासरीचा घोटा '),
(136776, 561, 46, 'जागृती आधारित'),
(136777, 562, 46, 'Axillary'),
(136778, 563, 46, 'आयमरा'),
(136779, 564, 46, 'अझरबैजानी'),
(136780, 565, 46, 'b.i.d.'),
(136781, 566, 46, 'मागे'),
(136782, 567, 46, 'परत'),
(136783, 568, 46, 'मागे आठ भेटी'),
(136784, 569, 46, 'मागे अकरा भेटी'),
(136785, 570, 46, 'मागे पाच भेटी'),
(136786, 571, 46, 'मागे चार भेटी'),
(136787, 572, 46, 'मागे नऊ भेटी'),
(136788, 573, 46, 'परत एक भेट'),
(136789, 574, 46, 'पाठदुखी'),
(136790, 575, 46, 'मागे समस्या'),
(136791, 576, 46, 'मागे सात भेटी'),
(136792, 577, 46, 'सहा भेटी'),
(136793, 578, 46, 'मागे शस्त्रक्रिया'),
(136794, 579, 46, 'मागे दहा भेटी'),
(136795, 580, 46, 'तीन भेटी'),
(136796, 581, 46, 'परत प्रशासन पृष्ठ'),
(136797, 582, 46, 'परत सामना करण्यासाठी'),
(136798, 583, 46, 'परत रुग्णाला'),
(136799, 584, 46, 'मागे रुग्णांच्या करण्यासाठी'),
(136800, 585, 46, 'परत वापरकर्ते'),
(136801, 586, 46, 'मागे पहा करण्यासाठी'),
(136802, 587, 46, 'मागे बारा भेटी'),
(136803, 588, 46, 'परत दोन भेटी'),
(136804, 589, 46, 'पार्श्वभूमी सेवा'),
(136805, 590, 46, 'बॅकअप'),
(136806, 591, 46, 'बॅकअप फाइल तयार करण्यात आली आहे. आता डाउनलोड पाठवेल.'),
(136807, 592, 46, 'बॅकअप यादी'),
(136808, 593, 46, 'बॅकअप यशस्वीरित्या घेतले'),
(136809, 594, 46, 'खराब तपासणी'),
(136810, 595, 46, 'खराब कर्ज'),
(136811, 596, 46, 'बहासा इंडोनेशिया'),
(136812, 597, 46, 'बाळ'),
(136813, 598, 46, 'शिल्लक'),
(136814, 599, 46, 'शिल्लक'),
(136815, 600, 46, 'शिल्लक रक्कम'),
(136816, 601, 46, 'शिल्लक मुळे'),
(136817, 602, 46, 'बाम्बारा'),
(136818, 603, 46, 'बँक ड्राफ्ट'),
(136819, 604, 46, 'बारकोड लेबल'),
(136820, 605, 46, 'बारकोड लेबल प्रकार'),
(136821, 606, 46, 'डाव्या एनएव्ही स्क्रीन मध्ये पॉपअप पासून बारकोड लेबल छपाई साठी बारकोड प्रकार.'),
(136822, 607, 46, 'पाचव्या (5) पाया Metarsal'),
(136823, 608, 46, 'पाचव्या (5) Metarsal पाया:'),
(136824, 609, 46, 'बष्किर'),
(136825, 610, 46, 'बास्क'),
(136826, 611, 46, 'बॅच दावा'),
(136827, 612, 46, 'बॅच दळणवळण साधन'),
(136828, 613, 46, 'बॅच भरणा प्रवेश'),
(136829, 614, 46, 'बॅच देयके'),
(136830, 615, 46, 'बॅच प्रक्रिया सुरू; या थोडा वेळ लागू शकतो.'),
(136831, 616, 46, 'बॅच परिणाम'),
(136832, 617, 46, 'BatchCom'),
(136833, 618, 46, 'धीर धरा, काही फायली प्रक्रिया काही मिनिटे लागू शकतात!'),
(136834, 619, 46, 'त्या आयडी अस्तित्वात नाही कारण.'),
(136835, 620, 46, 'सुरू'),
(136836, 621, 46, 'तारीख सुरू'),
(136837, 623, 46, 'सेवा वर्ष-mm-dd या सुरूवातीस तारीख'),
(136838, 624, 46, 'कॅलेंडर कार्यक्रम दिवसाचा तास सुरू.'),
(136839, 625, 46, 'बेलारूसी'),
(136840, 626, 46, 'ढेकर देणे'),
(136841, 628, 46, 'बंगाली'),
(136842, 629, 46, 'Bengali- बांगला'),
(136843, 630, 46, 'दरम्यान'),
(136844, 631, 46, 'द्वि-दिशा'),
(136845, 632, 46, 'बिहारी'),
(136846, 633, 46, 'द्विपक्षीय'),
(136847, 634, 46, 'द्विपक्षीय:'),
(136848, 636, 46, 'बिल दिनांक:'),
(136849, 637, 46, 'बिल / गोळा'),
(136850, 638, 46, 'बिल'),
(136851, 640, 46, 'बिलिंग'),
(136852, 641, 46, 'बिलिंग (पर्यायी लिहा)'),
(136853, 642, 46, 'बिलिंग लक्ष द्या'),
(136854, 644, 46, 'विनंतीकृत सेवा बिलिंग कोड'),
(136855, 645, 46, 'बिलिंग कोड'),
(136856, 646, 46, 'बिलिंग डेटा'),
(136857, 647, 46, 'बिलिंग विभाग'),
(136858, 648, 46, 'बिलिंग सुविधा'),
(136859, 649, 46, 'बिलिंग माहिती'),
(136860, 650, 46, 'बिलिंग स्थान'),
(136861, 655, 46, 'बिलिंग व्यवस्थापक'),
(136862, 656, 46, 'बिलिंग टीप'),
(136863, 657, 46, 'साठी बिलिंग टीप '),
(136864, 658, 46, 'बिलिंग टीप:'),
(136865, 659, 46, 'बिलिंग रांग परिणाम:'),
(136866, 660, 46, 'बिलिंग अहवाल'),
(136867, 661, 46, 'बिलिंग स्थिती'),
(136868, 662, 46, 'बिलिंग स्थिती = बिल न केलेली'),
(136869, 663, 46, 'ते बिलिंग '),
(136870, 665, 46, 'बायोप्सी'),
(136871, 666, 46, 'जन्म तारीख'),
(136872, 667, 46, 'जन्म-24 महिने'),
(136873, 668, 46, 'बिस्लामा'),
(136874, 669, 46, 'ब्लॅक'),
(136875, 670, 46, 'ब्लॅक फुफ्फुसांचा'),
(136876, 671, 46, 'काळे किंवा आफ्रिकन अमेरिकन'),
(136877, 672, 46, 'मूत्राशय कर्करोग'),
(136878, 673, 46, 'मूत्राशय इन्फेक्शन्स'),
(136879, 674, 46, 'कोरे फॉर्म'),
(136880, 675, 46, 'समस्या रक्तस्त्राव'),
(136881, 676, 46, 'अंध स्पॉट'),
(136882, 677, 46, 'गोळा येणे'),
(136883, 678, 46, 'अवरोधित'),
(136884, 679, 46, 'रक्त'),
(136885, 680, 46, 'रक्तदाब'),
(136886, 681, 46, 'रक्तदाब'),
(136887, 682, 46, 'रक्तरंजित नाक'),
(136888, 683, 46, 'ब्लू क्रॉस ब्लू शिल्ड'),
(136889, 684, 46, 'या अहवालात निळ्या रेषा माहिती आहेत. ब्लॅक ओळी पूर्वी अस्तित्वात असलेली माहिती दर्शवतात. ग्रीन ओळी यशस्वीरित्या लागू होते की बदल दाखवा. लाल रेषा त्रुटी, किंवा लागू केले नाही ते बदल सूचित; या स्वतः प्रक्रिया करणे आवश्यक आहे. सध्या नाकारला दावे आणि पैसे reversals स्वयं हाताळले नाहीत आणि त्यामुळे लाल दिसेल.'),
(136890, 685, 46, 'अंधुक दिसणे'),
(136891, 686, 46, 'बीएमआय'),
(136892, 687, 46, 'बीएमआय स्थिती'),
(136893, 689, 46, 'शरीर प्रदेश'),
(136894, 690, 46, 'शरीर साइट'),
(136895, 691, 46, 'शरीर साइट, लागू असल्यास'),
(136896, 692, 46, 'हाड दयाळूपणा:'),
(136897, 693, 46, 'हाड दयाळूपणा: सरासरीचा घोटा'),
(136898, 694, 46, 'बुलियन'),
(136899, 695, 46, 'बोस्नियन'),
(136900, 696, 46, 'बॉट'),
(136901, 697, 46, 'दोन्ही कान'),
(136902, 698, 46, 'दोन्ही कान'),
(136903, 699, 46, 'तळ'),
(136904, 700, 46, 'तळ समास (पीएक्स)'),
(136905, 701, 46, 'बॉक्स 10 अ रोजगार संबंधित '),
(136906, 702, 46, 'बॉक्स 10 ब ऑटो अपघात '),
(136907, 703, 46, 'बॉक्स 10 सी इतर अपघात '),
(136908, 704, 46, 'बॉक्स 14 तारीख पात्रता'),
(136909, 705, 46, 'बॉक्स 15 इतर तारीख पात्रता'),
(136910, 706, 46, 'बॉक्स 15 त्याच किंवा तत्सम आजार (वर्ष-mm-dd या) दिनांक:'),
(136911, 707, 46, 'त्याच किंवा तत्सम आजार / इतर तारीख (वर्ष-mm-dd या) च्या बॉक्स 15 दिनांक:'),
(136912, 708, 46, 'बॉक्स (वर्ष-mm-dd या) पासून काम करण्यास अक्षम 16 दिनांक:'),
(136913, 709, 46, 'बॉक्स (वर्ष-महिना-डीडी) काम करण्यास अक्षम 16 दिनांक:'),
(136914, 710, 46, '(वर्ष-mm-dd या) पासून बॉक्स 18 हॉस्पिटलायझेशन तारीख: '),
(136915, 711, 46, '(वर्ष-महिना-डीडी) बॉक्स 18 हॉस्पिटलायझेशन तारीख: '),
(136916, 712, 46, 'बॉक्स 20 बाहेर लॅब केला जातो काय?'),
(136917, 713, 46, 'बॉक्स 22 मेडीकेडची रीसबमिशनची कोड (ICD-9) '),
(136918, 714, 46, 'बॉक्स 23 प्रायर प्राधिकृत क्रमांक '),
(136919, 715, 46, 'बीपी'),
(136920, 716, 46, 'बीपी डायस्टोतलक'),
(136921, 717, 46, 'बीपी सिस्टॉलीक'),
(136922, 719, 46, 'Bpd'),
(136923, 721, 46, 'BPS'),
(136924, 722, 46, 'ब्राझिलियन पोर्तुगीज'),
(136925, 723, 46, 'स्तनाचा'),
(136926, 724, 46, 'स्तनाचा बायोप्सी');
INSERT INTO `lang_definitions` VALUES
(136927, 725, 46, 'स्तनाचा डिस्चार्ज'),
(136928, 726, 46, 'स्तनाचा रोग'),
(136929, 727, 46, 'स्तनाचा परीक्षा'),
(136930, 728, 46, 'स्तनाचा मास'),
(136931, 730, 46, 'श्वास ध्वनी:'),
(136932, 731, 46, 'ब्रेटन'),
(136933, 732, 46, 'तुटलेली हाडे'),
(136934, 733, 46, 'तुटलेली फॉर्म'),
(136935, 734, 46, 'ब्राँकायटिस फॉर्म'),
(136936, 735, 46, 'ब्राउझ करा'),
(136937, 736, 46, 'रेकॉर्ड साठी ब्राउझ करा'),
(136938, 737, 46, 'थकवा / रक्ताबुर्द'),
(136939, 738, 46, 'बल्गेरियन'),
(136940, 739, 46, 'उजव्या फुगवटा:'),
(136941, 740, 46, 'बर्मी'),
(136942, 741, 46, 'लघवी जळत'),
(136943, 742, 46, 'लघवी जळत'),
(136944, 743, 46, 'व्यवसाय फोन'),
(136945, 744, 46, 'व्यस्त'),
(136946, 745, 46, 'परंतु अद्याप प्रक्रिया केली नाही.'),
(136947, 746, 46, 'नितंब'),
(136948, 747, 46, 'नितंब + S.I.'),
(136949, 748, 46, 'करून'),
(136950, 749, 46, 'करून'),
(136951, 750, 46, 'तोंडून'),
(136952, 751, 46, '/ स्त्रोत करून'),
(136953, 752, 46, 'करून:'),
(136954, 753, 46, 'सी'),
(136955, 754, 46, 'न करता RFC 5425, TLS syslog सर्व्हरकडे सत्यापित करण्यासाठी CA प्रमाणपत्र.'),
(136956, 755, 46, '(सेकंदात) कॅशे आजीवन'),
(136957, 756, 46, 'कॅशे टेम्पलेट आउटपुट?'),
(136958, 757, 46, 'चहाच्या पानांत किंवा कॉफीच्या बियांत असणारे उत्तेजक द्रव्य सेवन'),
(136959, 758, 46, 'दिनदर्शिका'),
(136960, 759, 46, 'कॅलेंडर तास समाप्ती'),
(136961, 760, 46, 'कॅलेंडर मध्यांतर'),
(136962, 761, 46, 'कॅलेंडर स्क्रीन'),
(136963, 762, 46, 'कॅलेंडर सेटिंग्ज'),
(136964, 763, 46, 'कॅलेंडर प्रारंभ तास'),
(136965, 764, 46, 'कॅलेंडर केलेल्या UI'),
(136966, 765, 46, 'कॅलेंडर पहा'),
(136967, 766, 46, 'येथे नाही) (addForm कॉल. <br>'),
(136968, 767, 46, 'कॅलरीज'),
(136969, 768, 46, 'कंबोडियन'),
(136971, 774, 46, 'रद्द करा'),
(136972, 775, 46, 'बदल रद्द करा'),
(136973, 776, 46, 'रद्द'),
(136974, 777, 46, 'कर्करोग'),
(136975, 778, 46, 'कर्करोग स्क्रीनिंग: अपूर्णविराम कर्करोग स्क्रीनिंग'),
(136976, 779, 46, 'कर्करोग स्क्रीनिंग: मध्यमवयानंतरचा'),
(136977, 780, 46, 'कर्करोग स्क्रीनिंग: प्रकल्पग्रस्त डाग'),
(136978, 781, 46, 'कर्करोग स्क्रीनिंग: पुर: स्थ कर्करोग स्क्रीनिंग'),
(136979, 782, 46, 'हे आधीपासूनच विद्यमान आहे, कारण ही नोंदणी जोडू शकत नाही!'),
(136980, 783, 46, 'जोडू शकत नाही / डुप्लिकेट आधिपासूनच अस्तित्वात आहे कारण ही नोंदणी अद्यतनित करा!'),
(136981, 784, 46, 'दुर्लक्ष, संग्रहित केले जाऊ शकत नाही'),
(136982, 785, 46, 'JPEG, रूपांतरीत केले जाऊ शकत नाही. कदाचित ImageMagick स्थापित नाही?'),
(136983, 786, 46, 'दुर्लक्ष, हटविले जाऊ शकत नाही'),
(136984, 787, 46, 'त्याचा प्रकार ब्राउझर द्वारे समर्थीत नाही कारण इनलाइन प्रदर्शित केले जाऊ शकत नाही.'),
(136985, 788, 46, 'त्याचा प्रकार ब्राउझर द्वारे समर्थीत नाही becuase इनलाइन प्रदर्शित केले जाऊ शकत नाही'),
(136986, 789, 46, 'त्याचा प्रकार ब्राउझर द्वारे समर्थीत नाही becuase इनलाइन प्रदर्शित केले जाऊ शकत नाही.'),
(136987, 790, 46, 'तयार करू शकत नाही'),
(136988, 791, 46, 'फाइल निर्माण करू शकत नाही'),
(136989, 792, 46, 'फाइल (SFTP सर्वर पासून) हटवू शकत नाही'),
(136990, 793, 46, 'फाईल हटवू शकत नाही'),
(136991, 794, 46, 'एक गंतव्य फाइलनाव निश्चित करू शकत नाही'),
(136992, 795, 46, 'शोधू शकत नाही '),
(136993, 796, 46, 'एक गंतव्य फाइलनाव शोधू शकत नाही'),
(136994, 799, 46, 'एस क्यू एल-लेजर ग्राहक आयडी पासून रुग्ण शोधू शकत नाही'),
(136995, 800, 46, 'मध्ये ताजा कलम दस्तऐवज संदर्भ शोधू शकत नाही '),
(136996, 801, 46, 'एस क्यू एल-लेजर कर्मचारी पासून प्रदाता शोधू शकत नाही = '),
(136997, 802, 46, 'Payments.Undistributed नकारात्मक आहे संपादीत करू शकत नाही.'),
(136998, 803, 46, 'उघडू शकत नाही '),
(136999, 804, 46, 'निवड Insurance.The देवून घटकाचे पोस्ट करू शकत नाही रुग्णांच्या आहे.'),
(137000, 805, 46, 'निवड Patient.The देवून घटकाचे पोस्ट करू शकत नाही विमा आहे.'),
(137001, 806, 46, 'Payments.Undistributed नकारात्मक आहे पोस्ट करू शकत नाही.'),
(137002, 807, 46, 'वाचू शकत नाही'),
(137003, 808, 46, 'निर्देशिका वाचू शकत नाही'),
(137004, 809, 46, 'आपण अस्तित्वातील नोंद संपादित नाही कारण अद्ययावत करू शकत नाही!'),
(137005, 810, 46, 'भांडवल'),
(137006, 811, 46, 'सर्व भांडवल'),
(137007, 812, 46, 'कुपी'),
(137008, 813, 46, 'कार्ड'),
(137009, 814, 46, 'कार्डिऍक शरीराच्या पोकळीमध्ये कॅथेटर घालणे'),
(137010, 815, 46, 'कार्डिऍक प्रतिध्वनी'),
(137011, 816, 46, 'हृदय व रक्तवाहिन्यासंबंधी'),
(137012, 821, 46, 'कूर्चा / chondral / डिस्क नुकसान'),
(137013, 822, 46, 'कूर्चा इजा'),
(137014, 823, 46, 'Cartoid pulsations नॅथन, स्वरुपात डाळी नॅथन'),
(137015, 824, 46, 'रोख'),
(137016, 825, 46, 'रोख'),
(137017, 826, 46, 'रोख ''आरईसी'''),
(137018, 827, 46, 'प्रदाता रोख पावत्या'),
(137019, 828, 46, 'Catalan- वॅलेन्सियन'),
(137020, 829, 46, 'मोतीबिंदू शस्त्रक्रिया'),
(137021, 830, 46, 'मोतीबिंदु'),
(137022, 831, 46, 'श्रेणी'),
(137023, 832, 46, 'श्रेण्या'),
(137024, 833, 46, 'वर्ग'),
(137025, 834, 46, 'श्रेणी'),
(137026, 835, 46, 'वर्ग '),
(137027, 836, 46, 'वर्ग तपशील'),
(137028, 837, 46, 'वर्ग मर्यादा'),
(137029, 838, 46, 'वर्गवारी नाव'),
(137030, 839, 46, 'वर्ग नाव रिक्त आहे'),
(137031, 840, 46, 'वर्ग / शीर्षक'),
(137032, 841, 46, 'कॉकेशियन'),
(137033, 842, 46, 'चकमकीत / प्राथमिक प्रदाता माहिती प्रिंट पावत्या कारणे'),
(137034, 846, 46, 'CCR मंजूर'),
(137035, 847, 46, 'CCR रुग्णांच्या पुनरावलोकन'),
(137036, 848, 46, 'CCR पुनरावलोकन आणि मान्यता'),
(137037, 850, 46, 'CDR'),
(137038, 851, 46, 'CDR प्रक्रिया प्राधान्य अहवाल'),
(137039, 852, 46, 'सेल'),
(137040, 853, 46, 'सेल फोन'),
(137041, 854, 46, 'सेल फोन नंबर'),
(137042, 855, 46, 'सेल फोन नंबर'),
(137043, 856, 46, 'केंद्रीय प्रमाणपत्र'),
(137044, 857, 46, 'केंद्रीय / दक्षिण अमेरिकन'),
(137045, 858, 46, 'प्रमाणपत्र अधिकृतता सीआरटी फाइल स्थान रिक्त असू शकत नाही'),
(137046, 859, 46, 'प्रमाणपत्र अधिकृतता की फाइल स्थान रिक्त असू शकत नाही'),
(137047, 860, 46, 'प्रमाणपत्र, RFC 5425, TLS syslog सर्व्हरकडे पाठविणे.'),
(137048, 861, 46, 'प्रमाणपत्र वापरकर्ता'),
(137049, 862, 46, 'प्रमाणपत्रे'),
(137050, 863, 46, 'चमारो'),
(137051, 864, 46, 'ChampUS'),
(137052, 865, 46, 'ChampUSVA'),
(137053, 866, 46, 'बदल'),
(137054, 867, 46, 'बदला'),
(137055, 868, 46, 'बदला क्रियाकलाप'),
(137056, 869, 46, 'बदला अयशस्वी झाले! CouchDB त्रुटी कनेक्ट?'),
(137057, 870, 46, 'दृष्टी बदल'),
(137058, 871, 46, 'दृष्टी मध्ये बदला'),
(137059, 872, 46, 'पासवर्ड बदला'),
(137060, 874, 46, 'बदलले'),
(137061, 875, 46, 'बदललेल्या आतडी'),
(137062, 876, 46, 'दस्तऐवज धीराने आयडी बदलत आहे'),
(137063, 877, 46, 'वैशिष्ट्ये'),
(137064, 878, 46, 'उर्वरित वर्ण'),
(137065, 879, 46, 'चार्ज'),
(137066, 880, 46, 'शुल्क समायोजन'),
(137067, 881, 46, 'शुल्क कोड'),
(137068, 882, 46, 'शुल्क'),
(137069, 883, 46, 'चार्ट'),
(137070, 884, 46, 'चार्ट क्रियाकलाप'),
(137071, 885, 46, 'चार्ट चेक-इन / बाहेर क्रियाकलाप अहवाल'),
(137072, 886, 46, 'चार्ट आयडी'),
(137073, 887, 46, 'चार्ट आयडी:'),
(137074, 888, 46, 'चार्ट लेबल'),
(137075, 889, 46, 'चार्ट स्थान क्रियाकलाप'),
(137076, 890, 46, 'चार्ट टीप'),
(137077, 891, 46, 'चार्ट क्रमांक'),
(137078, 892, 46, 'चार्ट स्टोरेज स्थाने'),
(137079, 893, 46, 'चार्ट ट्रॅकर'),
(137080, 894, 46, 'चार्ट TRK'),
(137081, 895, 46, 'चार्ट चेक-इन'),
(137082, 896, 46, 'आउट चार्ट'),
(137083, 897, 46, 'चेचन'),
(137084, 898, 46, 'चेक'),
(137085, 899, 46, 'तपासा'),
(137086, 900, 46, 'सर्व तपासा'),
(137087, 902, 46, 'रक्कम तपासा'),
(137088, 903, 46, 'चेक तारीख'),
(137089, 904, 46, 'सानुकूल भाषा टेबल अनुवाद फरक तपासा.'),
(137090, 906, 46, 'करण्यासाठी तपासा'),
(137091, 907, 46, 'इनपुट डेटा तपासा'),
(137092, 908, 46, 'आलेख आयटम तपासा'),
(137093, 909, 46, 'लॅब परिणाम तपासा'),
(137094, 910, 46, 'चेक मार्क पुनरावलोकन हे कशावरून'),
(137095, 911, 46, 'कोणत्याही तपासा'),
(137096, 912, 46, 'क्रमांक तपासा'),
(137097, 915, 46, 'भरणा तपासा'),
(137098, 916, 46, 'हा एक केलेले फाइल असेल तर बॉक्स चेक करा'),
(137099, 917, 46, 'आपण फक्त त्यांच्या स्वत: च्या पूर्वनिर्धारीतपणे भेटी आणि नाही पाहू प्रदाते इच्छित असल्यास हा तपासा.'),
(137100, 918, 46, 'या निदान पासून समस्या निर्माण तपासणी करा'),
(137101, 919, 46, '/ EOB तारीख तपासा:'),
(137102, 920, 46, '/ EOB नाही तपासा .:'),
(137103, 921, 46, 'तपासा / संदर्भ क्रमांक'),
(137104, 922, 46, 'तपासा / संदर्भ क्रमांक'),
(137105, 923, 46, 'चेकबॉक्स यादी'),
(137106, 924, 46, 'चेकबॉक्स यादी'),
(137107, 925, 46, '/ मजकूर वाईड चेकबॉक्स'),
(137108, 926, 46, '/ मजकूर वाईड चेकबॉक्स'),
(137109, 927, 46, 'नकार आणि HL7 फाइल हटवायचा असेल तर चेकबॉक्स वरील सूचित करतात.'),
(137110, 928, 46, 'चेक-इन'),
(137111, 929, 46, 'चेक-इन केले बॉक्स = होय, रिक्त = नाही'),
(137112, 931, 46, 'लॉक चेकबॉक्सवर चेक या घटनेचा कोणत्याही फॉर्म कोणत्याही पुढील संपादने प्रतिबंध केला जाईल.'),
(137113, 932, 46, 'चेकआऊट'),
(137114, 933, 46, 'चेकसम'),
(137115, 934, 46, 'चेस्ट'),
(137116, 935, 46, 'चेस्ट CTAB'),
(137117, 936, 46, 'छाती दुखणे'),
(137118, 937, 46, 'छाती दुखणे:'),
(137119, 938, 46, 'छाती वेदना'),
(137120, 940, 46, 'Chg'),
(137121, 941, 46, 'Chichewa- Chewa- न्यान्जा'),
(137122, 942, 46, 'मुख्य तक्रार'),
(137123, 943, 46, 'बाल'),
(137124, 945, 46, 'बालपण लसीकरण स्थिती (CQM)'),
(137125, 946, 46, 'थंडी वाजून येणे'),
(137126, 947, 46, 'चीनी'),
(137127, 948, 46, 'चीनी (सरलीकृत)'),
(137128, 949, 46, 'चीनी (पारंपारिक)'),
(137129, 950, 46, 'पाठीचे मणके आणि इतर अस्थी यांची जुळवाजुळव करून उपचार करण्याची पद्धत्'),
(137130, 951, 46, 'पर्याय'),
(137131, 952, 46, 'पित्ताशय काढणे'),
(137132, 953, 46, 'पित्ताशय काढणे'),
(137133, 954, 46, 'Cholecystestomy'),
(137134, 955, 46, 'निवडा'),
(137135, 956, 46, 'विभाग निवडा आणि तो आत एक आयटम क्लिक करा; नंतर इतर विभागात आपण संबंधित आयटम ठळक दिसेल, आणि आपण संबंध जोडणे आणि हटवणे त्या विभागातील क्लिक करू शकता.'),
(137136, 957, 46, 'निकष निवडा'),
(137137, 958, 46, 'डाउनलोड निवडा किंवा इनलाइन प्रदर्शित'),
(137138, 959, 46, 'फाइल निवडा'),
(137139, 960, 46, 'यादीमधून निवडा'),
(137140, 961, 46, 'मांडणी दिशा निवडा'),
(137141, 962, 46, 'यादी निवडा'),
(137142, 963, 46, 'कागद आकार निवडा'),
(137143, 964, 46, 'पीडीएफ languange प्राधान्य निवडा'),
(137144, 965, 46, 'या घटनेचा अहवाल प्रिंट स्वरूप निवडा.'),
(137145, 967, 46, 'क्रॉनिक ब्राँकायटिस'),
(137146, 968, 46, 'तीव्र संयुक्त वेदना'),
(137147, 969, 46, 'तीव्र किडनी रोग (CKD)'),
(137148, 970, 46, 'तीव्र सीरमी पटलाचा दाह यामध्ये बहुधा सांध्यात द्रव जमतो, संधिदाह व दीर्घकाळ दाह झाल्याने ऍकिलोसिस होतो / ओतणे / संयुक्त वेदना / संधिरोग'),
(137149, 971, 46, 'तीव्र / वारंवार येणारा'),
(137150, 972, 46, 'चूवाश'),
(137151, 973, 46, 'यकृत च्या इंद्रियातील र्हासकारक बदल'),
(137152, 974, 46, 'यकृत च्या इंद्रियातील र्हासकारक बदल'),
(137153, 975, 46, 'शहर'),
(137154, 976, 46, 'शहर नाव'),
(137155, 977, 46, 'शहर, राज्य'),
(137156, 978, 46, 'शहर, राज्य पिन'),
(137157, 979, 46, 'शहर / राज्य'),
(137158, 980, 46, 'दावा'),
(137159, 981, 46, 'दावा '),
(137160, 982, 46, 'हक्क स्थिती'),
(137161, 983, 46, 'दावा चाचणी चालू पूर्ण केले आहे'),
(137162, 984, 46, 'हक्काचा प्रकार'),
(137163, 985, 46, 'दावा दाखल करण्यासाठी निर्माण होते'),
(137164, 986, 46, 'दावा दाखल करण्यासाठी निर्माण होते '),
(137165, 987, 46, 'दावे'),
(137166, 988, 46, 'वर्गीकरण'),
(137167, 989, 46, 'साफ करा'),
(137168, 990, 46, 'साफ सक्रिय रुग्ण'),
(137169, 991, 46, 'सर्व स्वच्छ करा'),
(137170, 992, 46, 'साफ HL7 डेटा'),
(137171, 993, 46, 'साफ समर्थन'),
(137172, 994, 46, 'साफ करा Smarty कॅशे'),
(137173, 995, 46, 'EDI 270 बॅच निर्मितीसाठी आवश्यक घर माहिती साफ.'),
(137174, 996, 46, 'CLIA क्रमांक'),
(137175, 997, 46, 'क्लिक करा'),
(137176, 998, 46, 'एक मजकूर फाइल आपल्या वर्ग, उपश्रेणी, आयटम, सामग्री डेटा निर्यात करण्याची ''निर्यात'' क्लिक करा. XML फाइल या फाइल कोणत्याही साम्य पूर्णपणे योगायोग आहे. उघडणे आणि बंद टॅग त्याच ओळीत असणे आवश्यक आहे, ते नाही मोकळी जागा सह लोअरकेस करणे आवश्यक आहे. आयात करण्यासाठी, फाईल ब्राउझ करा आणि ''आयात'' वर क्लिक करा. डेटा पूर्णपणे भिन्न आहे, तर आपल्या विद्यमान डेटा विलीन होईल. समान आयटम नावे आहेत, तर, जुन्या ठेवायला आणि एक नंबर सेव्ह नवीन शेवटी जोडली जाईल.'),
(137177, 999, 46, 'नवीन भाष्य जोडण्यासाठी ग्राफिक एक स्पॉट क्लिक करा काढण्यासाठी पुन्हा क्लिक करा'),
(137178, 1000, 46, 'फाइल ssl.zip मध्ये प्रमाणपत्रे डाउनलोड करण्यासाठी डाउनलोड प्रमाणपत्र क्लिक करा'),
(137179, 1001, 46, 'अधिक क्लिक करा'),
(137180, 1002, 46, 'अधिक माहितीसाठी क्लिक करा'),
(137181, 1003, 46, 'ऑर्डर सारांश क्लिक करा'),
(137182, 1004, 46, 'परिणाम क्लिक करा'),
(137183, 1005, 46, 'इथे क्लिक करा'),
(137184, 1006, 46, 'नवीन रुग्ण जोडण्यासाठी येथे क्लिक करा.'),
(137185, 1007, 46, 'नवीन इजा बदल स्थिती जोडण्याकरीता येथे क्लिक करा आणि दररोज क्रियाकलाप संपादित'),
(137186, 1008, 46, 'दिनांक निवडण्यासाठी येथे क्लिक करा'),
(137187, 1009, 46, 'एक तारीख आणि वेळ निवडण्यासाठी येथे क्लिक करा'),
(137188, 1010, 46, 'प्रारंभ तारीख निवडण्यासाठी येथे क्लिक करा'),
(137189, 1011, 46, 'तारीख वेळ निवडण्यासाठी येथे क्लिक करा'),
(137190, 1012, 46, 'पासून तारीख वेळ निवडण्यासाठी येथे क्लिक करा'),
(137191, 1013, 46, 'तारीख वेळ निवडण्यासाठी येथे क्लिक करा'),
(137192, 1014, 46, 'हे विभाग व्यूहरचित करण्यासाठी येथे क्लिक करा'),
(137193, 1016, 46, 'हे विभाग अक्षम करण्यासाठी येथे क्लिक करा'),
(137194, 1018, 46, 'हे विभाग सक्षम करण्यासाठी येथे क्लिक करा'),
(137195, 1019, 46, 'हे विभाग स्थापन करण्यासाठी येथे क्लिक करा'),
(137196, 1020, 46, 'शोध करण्यासाठी येथे क्लिक करा'),
(137197, 1021, 46, 'प्राधान्य, श्रेणी आणि टोपणनाव सेटिंग्ज अद्यतनित करण्यासाठी येथे क्लिक करा'),
(137198, 1022, 46, 'सर्व पाहण्यासाठी येथे क्लिक करा.'),
(137199, 1023, 46, 'पहा आणि आलेख करण्यासाठी येथे क्लिक करा'),
(137200, 1024, 46, 'पहा आणि सर्व labdata आलेख येथे क्लिक करा.'),
(137201, 1025, 46, 'सर्व मर्मस्थाने पाहण्यासाठी आणि आलेख येथे क्लिक करा.'),
(137202, 1026, 46, 'रुग्णाला तपशील पाहण्यासाठी येथे क्लिक करा'),
(137203, 1027, 46, 'त्यांना सर्व पाहण्यासाठी येथे क्लिक करा.'),
(137204, 1028, 46, 'अधिक माहितीसाठी / संपादित पाहण्यासाठी येथे क्लिक करा'),
(137205, 1029, 46, 'खालील तारखेपासून डेटाबेस प्रकाशन प्रतिष्ठापीत करण्यासाठी बटण क्लिक करा स्थापित'),
(137206, 1030, 46, 'वेळ भाग कोणत्याही वाढ क्लिक करा'),
(137207, 1031, 46, 'रुग्णांच्या फाइल उघडा रुग्ण नाव क्लिक करा'),
(137208, 1032, 46, 'विशिष्ट परिणाम पाहण्यासाठी वरील इनपुट शोध निकष सर्व परिणाम पाहण्यासाठी किंवा कृपया रिफ्रेश क्लिक करा.'),
(137209, 1033, 46, 'निदान जोडण्यासाठी क्लिक करा'),
(137210, 1034, 46, 'नवीन घटक जोडण्यासाठी क्लिक करा'),
(137211, 1035, 46, 'नवीन सल्ला जोडण्यासाठी क्लिक करा'),
(137212, 1036, 46, 'समायोजित करण्यासाठी निदान निवडण्यासाठी क्लिक करा.'),
(137213, 1037, 46, 'डाउनलोड करण्यासाठी क्लिक करा'),
(137214, 1038, 46, 'संपादित करण्यासाठी क्लिक करा'),
(137215, 1039, 46, 'वर्णन संपादित करण्यासाठी क्लिक करा'),
(137216, 1040, 46, 'हा कार्यक्रम संपादित करण्यासाठी क्लिक करा'),
(137217, 1041, 46, 'अहवाल निर्माण करण्यासाठी क्लिक करा'),
(137218, 1042, 46, 'रुग्णाला जुळत क्लिक करा'),
(137219, 1043, 46, 'मुद्रित करण्यासाठी क्लिक करा'),
(137220, 1044, 46, 'प्राप्त (जोडण्यासाठी) क्लिक करा नवीन भरपूर'),
(137221, 1045, 46, 'निवडण्यासाठी क्लिक करा'),
(137222, 1046, 46, 'निवडा क्लिक करा'),
(137223, 1047, 46, 'ही प्रक्रिया एक उद्योग मानक कोड निवडा क्लिक करा'),
(137224, 1048, 46, 'पर्यायी प्रक्रिया कोड निवडा क्लिक करा'),
(137225, 1049, 46, 'निवडा किंवा कोडींग बदलण्यासाठी क्लिक करा'),
(137226, 1050, 46, 'निवडण्यासाठी किंवा CVX कोड बदलू क्लिक करा'),
(137227, 1051, 46, 'निवडा किंवा निदान बदलण्यासाठी क्लिक करा'),
(137228, 1052, 46, 'सेवा कोड निवडा किंवा बदलण्यासाठी क्लिक करा'),
(137229, 1053, 46, 'रुग्णाला निवडण्यासाठी क्लिक करा'),
(137230, 1054, 46, 'संबंधित कोड निवडा क्लिक करा'),
(137231, 1055, 46, 'हा परिणाम असामान्य आहे तर सुरू सेवा निवडण्यासाठी क्लिक करा'),
(137232, 1056, 46, 'इच्छित प्रक्रिया निवडण्यासाठी क्लिक करा'),
(137233, 1057, 46, 'क्रमवारी लावण्यासाठी क्लिक करा'),
(137234, 1058, 46, 'पाहण्यासाठी क्लिक करा'),
(137235, 1059, 46, 'पाहण्यासाठी किंवा संपादित करण्यासाठी क्लिक करा'),
(137236, 1060, 46, 'पाहण्यासाठी क्लिक करा / संपादित करा'),
(137237, 1061, 46, 'खालील तारखेपासून डेटाबेस प्रकाशन सुधारणा श्रेणीसुधार बटणावर क्लिक करा'),
(137238, 1062, 46, 'रुग्णाला जुळण्यासाठी वर दिलेले तिथे क्लिक करा.'),
(137239, 1063, 46, 'क्लिक करा:'),
(137240, 1064, 46, 'क्लायंट प्रमाणपत्र कालबाह्य दिवस'),
(137241, 1065, 46, 'क्लायंट प्रमाणपत्र वैधता कालावधी'),
(137242, 1066, 46, 'क्लायंट प्रमाणपत्र वैधता एक वैध नंबर असावा.'),
(137243, 1067, 46, 'क्लायंट कॉपी'),
(137244, 1069, 46, 'क्लायंट वैद्यकीय इतिहास सारांश'),
(137245, 1070, 46, 'क्लायंटचे नाव'),
(137246, 1071, 46, 'क्लायंट क्रमांक'),
(137247, 1072, 46, 'क्लायंट प्रोफाइल - नवीन ग्राहक'),
(137248, 1073, 46, 'क्लायंट प्रोफाइल - युनिक ग्राहक'),
(137249, 1074, 46, 'ग्राहक'),
(137250, 1075, 46, 'क्लिनिक'),
(137251, 1076, 46, 'क्लिनिक कॉपी'),
(137252, 1077, 46, 'क्लिनिक दैनिक नोंद'),
(137253, 1078, 46, 'क्लिनिक आयडी'),
(137254, 1079, 46, 'क्लिनिकल'),
(137255, 1080, 46, 'क्लिनिकल निर्णय नियम अॅलर्ट व्यवस्थापक'),
(137256, 1081, 46, 'क्लिनिकल इतिहास'),
(137257, 1083, 46, 'क्लिनिकल योजना'),
(137258, 1084, 46, 'क्लिनिकल गुणवत्ता उपाय (CQM)'),
(137259, 1085, 46, 'क्लिनिकल गुणवत्ता उपाय (CQM) - 2011'),
(137260, 1086, 46, 'क्लिनिकल गुणवत्ता उपाय (CQM) - 2014'),
(137261, 1087, 46, 'क्लिनिकल स्मरणपत्रे'),
(137262, 1088, 46, 'क्लिनिकल अहवाल'),
(137263, 1089, 46, 'क्लिनिकल नियम क्रिया वर्ग'),
(137264, 1090, 46, 'क्लिनिकल नियम क्रिया आयटम'),
(137265, 1091, 46, 'क्लिनिकल नियम फिल्टर पद्धती'),
(137266, 1092, 46, 'क्लिनिकल नियम लक्ष्य पद्धती'),
(137267, 1093, 46, 'क्लिनिकल नियम'),
(137268, 1094, 46, 'क्लिनिकल नियम वय मध्यांतरे'),
(137269, 1095, 46, 'क्लिनिकल नियम तुलना'),
(137270, 1096, 46, 'क्लिनिकल नियम प्रकार आढळतात'),
(137271, 1097, 46, 'क्लिनिकल नियम स्मरणपत्र मुळे पर्याय'),
(137272, 1098, 46, 'क्लिनिकल नियम स्मरणपत्र Inactivation पर्याय'),
(137273, 1099, 46, 'क्लिनिकल नियम स्मरणपत्र मध्यांतरे'),
(137274, 1100, 46, 'क्लिनिकल नियम स्मरणपत्र पद्धती'),
(137275, 1101, 46, 'क्लिनिकल नियम लक्ष्य मध्यांतरे'),
(137276, 1102, 46, 'क्लिनिकल लक्ष्य'),
(137277, 1103, 46, 'क्लिनिकल मुदत'),
(137278, 1104, 46, 'क्लिनिकल मुदत कोड (चे)'),
(137279, 1106, 46, 'चिकित्सक'),
(137280, 1107, 46, 'क्लोन'),
(137281, 1108, 46, 'क्लोन मागील भेट द्या'),
(137282, 1109, 46, 'बंद करा'),
(137283, 1110, 46, 'विंडो बंद करा'),
(137284, 1111, 46, 'विंडो बंद करा'),
(137285, 1112, 46, 'बंद'),
(137286, 1113, 46, 'सेमी'),
(137287, 1114, 46, 'सीएमएस 1500 समास'),
(137288, 1115, 46, 'सीएमएस 1500 पेपर फॉर्म स्वरूप'),
(137289, 1116, 46, 'सीएमएस 1500: बॉक्स 31 स्वरूप'),
(137290, 1117, 46, 'सीएमएस 1500: बॉक्स 31 तारीख (सही)'),
(137291, 1118, 46, 'सीएमएस आयडी'),
(137292, 1119, 46, 'सीएमएस पोर्टल'),
(137293, 1120, 46, 'सीएमएस पोर्टल लॉग-इन'),
(137294, 1121, 46, 'सीएमएस पोर्टल लॉगिन आयडी'),
(137295, 1122, 46, 'सीएमएस पोर्टल सक्षम नाही!'),
(137296, 1123, 46, 'सीएमएस पोर्टल पासवर्ड'),
(137297, 1124, 46, 'सीएमएस पोर्टल विनंती'),
(137298, 1125, 46, 'सीएमएस पोर्टल साइट पत्ता'),
(137299, 1126, 46, 'सीएमएस पोर्टल वापरकर्तानाव'),
(137300, 1127, 46, 'अखंड CN2-12'),
(137301, 1128, 46, 'सहकारी पे'),
(137302, 1129, 46, 'सहकारी वेतन दिले जाते'),
(137303, 1130, 46, 'को-पे'),
(137304, 1131, 46, 'कोड'),
(137305, 1132, 46, 'कोड'),
(137306, 1133, 46, 'कोड फाइंडर'),
(137307, 1134, 46, 'कोड दोन अक्षरखालच्यापट्टीतील असणे आवश्यक आहे'),
(137308, 1135, 46, 'कोड किंवा चलन सूचित करण्यासाठी प्रतीक'),
(137309, 1136, 46, 'कोड मजकूर'),
(137310, 1137, 46, 'कोड प्रकार'),
(137311, 1138, 46, 'कोड प्रकार'),
(137312, 1139, 46, 'कोड प्रकार ओळखले गेले नाही'),
(137313, 1140, 46, 'कोड प्रकार अद्याप व्याख्या नाही'),
(137314, 1141, 46, 'कोड प्रकार'),
(137315, 1142, 46, 'कोड (चे)'),
(137316, 1143, 46, 'कोड'),
(137317, 1144, 46, 'कोड'),
(137318, 1145, 46, 'कोडींग'),
(137319, 1146, 46, 'कोडींग (शिक्षणासाठी क्लिक करा)'),
(137320, 1147, 46, 'कोडींग - कोणत्याही चकमकी (राइट, पर्यायी wsome)'),
(137321, 1148, 46, 'कोडींग - माझ्या चकमकी (राइट, पर्यायी wsome)'),
(137322, 1149, 46, 'अधिकृत नाही कोडींग'),
(137323, 1150, 46, 'कॉफी'),
(137324, 1151, 46, 'कॉफी वापरा'),
(137325, 1152, 46, 'Coinsurance'),
(137326, 1153, 46, 'Coll वाईड / O'),
(137327, 1154, 46, 'संकुचित'),
(137328, 1155, 46, 'संकुचित'),
(137329, 1156, 46, 'सर्व संकुचित करा'),
(137330, 1157, 46, 'सर्व संकुचित करा'),
(137331, 1158, 46, 'सर्व संकुचित करा'),
(137332, 1160, 46, 'संकलन तारीख'),
(137333, 1161, 46, 'संग्रह'),
(137334, 1162, 46, 'संग्रह अहवाल'),
(137335, 1163, 46, 'अपूर्णविराम कर्करोग'),
(137336, 1164, 46, 'अपूर्णविराम कर्करोग स्क्रीनिंग'),
(137337, 1165, 46, 'अपूर्णविराम कर्करोग शस्त्रक्रिया'),
(137338, 1166, 46, 'Colonoscopy'),
(137339, 1167, 46, 'colonoscopy'),
(137340, 1168, 46, 'रंग'),
(137341, 1169, 46, 'रंग: abbr'),
(137342, 1170, 46, 'स्तंभ'),
(137343, 1171, 46, 'स्तंभ'),
(137344, 1172, 46, 'बरेच यात'),
(137345, 1173, 46, 'स्वल्पविराम'),
(137346, 1174, 46, 'टिप्पणी'),
(137347, 1175, 46, 'कोणत्याही टिप्पण्या नाहीत'),
(137348, 1176, 46, 'हा परिणाम किंवा शिफारस टिप्पण्या'),
(137349, 1177, 46, 'व्यावसायिक इन्शुरन्स कंपनी'),
(137350, 1178, 46, 'बदल'),
(137351, 1179, 46, 'संवाद'),
(137352, 1180, 46, 'संचार'),
(137353, 1182, 46, 'कंपनी'),
(137354, 1183, 46, 'संस्थेचे नाव'),
(137355, 1184, 46, 'पूर्ण'),
(137356, 1186, 46, 'पूर्ण'),
(137357, 1188, 46, 'पूर्ण?'),
(137358, 1190, 46, 'सेवा प्रदाता करून गुंतागुंत'),
(137359, 1191, 46, 'गर्भपात गुंतागुंत'),
(137360, 1192, 46, 'घटक'),
(137361, 1193, 46, 'संगणक अनुदानित वैद्यकीय तसं क्रम प्रणाली'),
(137362, 1194, 46, 'निष्कर्ष'),
(137363, 1198, 46, 'Config'),
(137364, 1199, 46, 'संरचना'),
(137365, 1200, 46, 'संरचना आयात / निर्यात'),
(137366, 1201, 46, 'संरचना यशस्वीरित्या जतन केले'),
(137367, 1202, 46, 'क्लायंट बाजूला SSL प्रमाणपत्र वापरू अपाचे आणि LibreEHR संरचीत करा.'),
(137368, 1203, 46, 'क्लायंट बाजूला SSL प्रमाणपत्र वापरू अपाचे संयोजीत करा Name'),
(137369, 1204, 46, 'HTTPS वापरा करण्यासाठी अपाचे कॉन्फिगर करा.'),
(137370, 1205, 46, 'क्लायंट बाजूला SSL प्रमाणपत्र वापरू LIBREEHR संयोजीत करा Name'),
(137371, 1206, 46, 'ट्रॅक संयोजीत करा Name'),
(137372, 1207, 46, 'ट्रॅक संयोजीत करा Name'),
(137373, 1208, 46, 'नवीन रुग्णांच्या तयार करा पुष्टी करा'),
(137374, 1209, 46, 'नवीन संकेतशब्द कन्फर्म करा'),
(137375, 1210, 46, 'भरणा पुष्टी करा'),
(137376, 1214, 46, 'जन्मजात'),
(137377, 1215, 46, 'Conjuntiva, अलविदा'),
(137378, 1216, 46, 'कनेक्शन त्रुटी'),
(137379, 1217, 46, 'कने'),
(137380, 1218, 46, 'सतत'),
(137381, 1219, 46, 'सतत नाव'),
(137382, 1220, 46, 'सतत नाव रिक्त आहे'),
(137383, 1221, 46, 'स्थिर'),
(137384, 1222, 46, 'बद्धकोष्ठता'),
(137385, 1223, 46, 'घटनात्मक'),
(137386, 1226, 46, 'सल्ला संक्षिप्त वर्णन'),
(137387, 1227, 46, 'संपर्क'),
(137388, 1228, 46, 'संपर्क ईमेल'),
(137389, 1229, 46, 'संपर्क ई-मेल पत्ता'),
(137390, 1230, 46, 'संपर्क EMR थेट phiMail थेट संदेश सेवा सदस्यता'),
(137391, 1231, 46, 'संपर्क माहिती'),
(137392, 1232, 46, 'कॉन्टॅक्ट लेन्स'),
(137393, 1233, 46, 'संपर्क वैद्यकीय माहिती एकत्रीकरण, प्रयोगशाळा एक्सचेंज सेवा http://mi-squared.com येथे एलएलसी.'),
(137394, 1234, 46, 'ERx सेवा सदस्यता http://zhservices.com येथे http://mi-squared.com किंवा ZH आरोग्य वैद्यकीय माहिती एकत्रीकरण, एलएलसी संपर्क साधा'),
(137395, 1236, 46, 'संपर्क नाव'),
(137396, 1237, 46, 'संपर्क व्यक्ती'),
(137397, 1238, 46, 'संपर्क फोन'),
(137398, 1239, 46, 'संपर्क फोन नंबर'),
(137399, 1240, 46, 'ERx सेवा सदस्यता संपर्क ZMG, एलएलसी (zmghealth@gmail.com)'),
(137400, 1241, 46, 'चार खालील आयटम किमान तीन आहेत:'),
(137401, 1242, 46, 'कंटेनर गट नाव'),
(137402, 1243, 46, 'सामग्री'),
(137403, 1244, 46, 'सामग्री'),
(137404, 1245, 46, 'संदर्भ'),
(137405, 1246, 46, 'संदर्भ नाव टी रिक्त असू '' करू शकता'),
(137406, 1247, 46, 'सुरू ठेवा'),
(137407, 1248, 46, 'काळजी दस्तऐवज सातत्य (सीसीडीची)'),
(137408, 1249, 46, 'काळजी रेकॉर्ड सातत्य (CCR)'),
(137409, 1250, 46, 'विरुद्ध ग्राहक'),
(137410, 1251, 46, 'संततिनियमन'),
(137411, 1252, 46, 'संततिनियमन मुद्दे'),
(137412, 1253, 46, 'गर्भनिरोधक गुंतागुंत (स्पष्ट करा)'),
(137413, 1254, 46, 'गर्भनिरोधक पद्धत'),
(137414, 1255, 46, 'गर्भनिरोधक उत्पादने'),
(137415, 1256, 46, 'गर्भनिरोधक सेवा पूर्वी सुरु'),
(137416, 1257, 46, 'गर्भनिरोधक प्रारंभ'),
(137417, 1258, 46, 'नियंत्रण आयडी'),
(137418, 1259, 46, 'नियंत्रण क्रमांक'),
(137419, 1261, 46, 'COPAY'),
(137420, 1262, 46, 'Copay'),
(137421, 1263, 46, 'CoPay'),
(137422, 1264, 46, 'सकारात्मक नाही Copay'),
(137423, 1265, 46, 'Copay अदा'),
(137424, 1266, 46, 'Copays'),
(137425, 1267, 46, 'COPD'),
(137426, 1268, 46, 'रुग्णांच्या चार्ट कॉपी करा पृष्ठे'),
(137427, 1269, 46, 'कॉपी मूल्ये'),
(137428, 1270, 46, 'डेटाबेस फाइल कॉपी करत आहे. हे काही वेळ लागेल ...'),
(137429, 1271, 46, 'कॉपीराइट सूचना'),
(137430, 1272, 46, 'कॉर्निश'),
(137431, 1273, 46, 'कोरोनरी आर्टरी बायपास'),
(137432, 1274, 46, 'कोरोनरी आर्टरी बायपास ग्राफ्ट (CABG)'),
(137433, 1275, 46, 'दुरुस्त'),
(137434, 1276, 46, 'कोर्सिकी'),
(137435, 1277, 46, 'CouchDB'),
(137436, 1278, 46, 'CouchDB कनेक्शन अयशस्वी.'),
(137437, 1279, 46, 'CouchDB डेटाबेस'),
(137438, 1280, 46, 'CouchDB डेटाबेस नाव'),
(137439, 1281, 46, 'CouchDB यजमान'),
(137440, 1282, 46, 'CouchDB यजमाननाव'),
(137441, 1283, 46, 'CouchDB लॉग सक्षम'),
(137442, 1284, 46, 'CouchDB पासवर्ड'),
(137443, 1285, 46, 'CouchDB पोर्ट'),
(137444, 1286, 46, 'CouchDB पोर्ट'),
(137445, 1287, 46, 'CouchDB जतन करणे अयशस्वी झाले'),
(137446, 1288, 46, 'CouchDB UserName'),
(137447, 1289, 46, 'खोकला'),
(137448, 1290, 46, 'खोकला:'),
(137449, 1291, 46, 'सर्व्हरशी कनेक्ट करणे शक्य नाही'),
(137450, 1293, 46, 'टेबल उघडू शकत नाही'),
(137451, 1294, 46, 'फाइल वाचणे शक्य झाले नाही'),
(137452, 1295, 46, 'फाइल वाचणे शक्य झाले नाही'),
(137453, 1296, 46, 'मुळे सर्व्हर समस्या ईमेल पाठवू शकत नाही, '),
(137454, 1297, 46, 'मुळे सर्व्हर समस्या ईमेल पाठवू शकत नाही. '),
(137455, 1298, 46, 'बॅकअप निर्देशिका तयार करू शकत नाही:'),
(137456, 1299, 46, 'निर्देशिका काढू शकलो नाही:'),
(137457, 1300, 46, 'जुन्या बॅकअप फाइल काढून टाकू शकत नाही:'),
(137458, 1301, 46, 'जुन्या निर्यात फाइल काढून टाकू शकत नाही:'),
(137459, 1302, 46, 'Coumadin व्यवस्थापन - भारतीय रुपया देखरेख'),
(137460, 1303, 46, 'पद्धत करून Couns'),
(137461, 1304, 46, 'समुपदेशन'),
(137462, 1305, 46, 'समुपदेशन उपक्रम'),
(137463, 1306, 46, 'COUNTER या रेफरल प्रपत्र'),
(137464, 1307, 46, 'प्रति-रेफरल'),
(137465, 1308, 46, 'देश'),
(137466, 1309, 46, 'देश डेटा प्रकार'),
(137467, 1310, 46, 'देश यादी'),
(137468, 1311, 46, 'देश यादी (राइट, addonly पर्यायी)'),
(137469, 1312, 46, 'देश नाव दोन अक्षरे प्रतिनिधित्व पाहिजे. (उदाहरण: युनायटेड स्टेट्स आहे)'),
(137470, 1313, 46, 'कंट्री'),
(137471, 1315, 46, 'कुपन'),
(137472, 1318, 46, 'CPT'),
(137473, 1319, 46, 'CPT कोड'),
(137474, 1320, 46, 'CPT कोड'),
(137475, 1321, 46, 'CPT4 प्रक्रिया / सेवा'),
(137476, 1322, 46, 'CPTII कामगिरी उपाय'),
(137477, 1323, 46, 'CQM'),
(137478, 1324, 46, 'Crackles:'),
(137479, 1325, 46, 'मलई'),
(137480, 1326, 46, 'प्रत्येक वापरकर्ता किंवा क्लाएंट मशीन करीता क्लाएंट साइड SSL प्रमाणपत्र तयार करा.'),
(137481, 1327, 46, 'वापरकर्ता किंवा क्लाएंट यजमाननाव एकतर एक क्लाएंट साइड SSL प्रमाणपत्र तयार करा.'),
(137482, 1328, 46, 'नवीन ट्रॅक तयार करा'),
(137483, 1329, 46, 'इव्हेंट तयार करा'),
(137484, 1330, 46, 'तयार करा आणि संपूर्ण बॅकअप डाउनलोड'),
(137485, 1331, 46, 'तयार करा आणि ट्रॅक सुधारण्यासाठी'),
(137486, 1332, 46, 'बॅकअप तयार करा'),
(137487, 1333, 46, 'बॅच तयार करा'),
(137488, 1334, 46, 'क्लायंट प्रमाणपत्र तयार'),
(137489, 1335, 46, 'क्लायंट बाजूला SSL प्रमाणपत्र तयार करा'),
(137490, 1336, 46, 'डुप्लिकेट तयार करा'),
(137491, 1337, 46, 'चकमकीत तयार करा'),
(137492, 1338, 46, 'Eventlog बॅकअप तयार करा'),
(137493, 1339, 46, 'नवीन समस्या तयार करा'),
(137494, 1340, 46, 'नवीन रुग्णांच्या तयार करा'),
(137495, 1341, 46, 'नवीन ट्रॅक तयार करा'),
(137496, 1342, 46, 'Offsite Portal ेय तयार करा'),
(137497, 1343, 46, 'Onsite Portal ेय तयार करा'),
(137498, 1344, 46, 'रुग्णांच्या टीप तयार करा'),
(137499, 1345, 46, 'SSL प्रमाणपत्र प्राधिकरण आणि सर्व्हर प्रमाणपत्र तयार करा.'),
(137500, 1346, 46, 'भेट द्या तयार करा'),
(137501, 1347, 46, 'तयार'),
(137502, 1348, 46, 'निर्यात फाइल निर्माण करणे'),
(137503, 1349, 46, 'नवीन ट्रॅक तयार करणे अयशस्वी झाले'),
(137504, 1350, 46, 'दूरस्थ यजमानावर ही फाईल तयार करणे अयशस्वी झाले'),
(137505, 1351, 46, 'निर्माणकर्ता'),
(137506, 1352, 46, 'क्रेडिट'),
(137507, 1353, 46, 'क्रेडीट कार्ड'),
(137508, 1354, 46, 'क्रेडिट'),
(137509, 1355, 46, 'क्री'),
(137510, 1356, 46, 'निकष'),
(137511, 1357, 46, 'क्रोएशियन'),
(137512, 1358, 46, 'Crohn  ''चे रोग'),
(137513, 1359, 46, 'Crohns रोग'),
(137514, 1360, 46, 'सी निर्यात'),
(137515, 1361, 46, 'सी फाइल'),
(137516, 1362, 46, 'सी टेबल'),
(137517, 1363, 46, 'CU.MM'),
(137518, 1364, 46, 'क्यूबा'),
(137519, 1365, 46, 'चलन दशांश स्थाने'),
(137520, 1366, 46, 'चलन दशमान पॉइंट प्रतीक'),
(137521, 1367, 46, 'चलन Designator'),
(137522, 1368, 46, 'चलन हजारो विभाजक'),
(137523, 1369, 46, 'वर्तमान'),
(137524, 1370, 46, 'वर्तमान मद्यार्क'),
(137525, 1371, 46, 'वर्तमान सल्ला'),
(137526, 1372, 46, 'वर्तमान निकष'),
(137527, 1373, 46, 'चालू दिवस हायलाइट रंग'),
(137528, 1374, 46, 'चालू दररोज धूम्रपान'),
(137529, 1375, 46, 'वर्तमान फाइल नाव बदलण्यात आले'),
(137530, 1376, 46, 'वर्तमान हॅश'),
(137531, 1377, 46, 'वर्तमान स्थान'),
(137532, 1378, 46, 'वर्तमान औषधे'),
(137533, 1379, 46, 'वर्तमान संकेतशब्द'),
(137534, 1380, 46, 'वर्तमान रुग्णांच्या'),
(137535, 1381, 46, 'वर्तमान पं फक्त'),
(137536, 1382, 46, 'वर्तमान अंमली औषधे'),
(137537, 1383, 46, 'चालू काही दिवस धूम्रपान'),
(137538, 1385, 46, 'वर्तमान मूल्य'),
(137539, 1386, 46, 'सध्या सक्रिय'),
(137540, 1387, 46, 'सध्या चालू'),
(137541, 1388, 46, 'सध्या कोणतेही सुविधा आहेत.'),
(137542, 1389, 46, 'कशिंग Syndrom'),
(137543, 1390, 46, 'कशिंग सिंड्रोम'),
(137544, 1392, 46, 'सानुकूल'),
(137545, 1393, 46, 'सानुकूल इनपुट?');
INSERT INTO `lang_definitions` VALUES
(137546, 1394, 46, 'सानुकूल टेबल'),
(137547, 1396, 46, 'CVX कोड'),
(137548, 1397, 46, 'CVX कोड मॅपिंग'),
(137549, 1398, 46, 'CVX लसीकरण'),
(137550, 1399, 46, 'सायकल'),
(137551, 1400, 46, 'CYP'),
(137552, 1401, 46, 'CYP फॅक्टर'),
(137553, 1402, 46, 'CYP अहवाल'),
(137554, 1403, 46, 'चेक'),
(137555, 1404, 46, 'डी'),
(137556, 1405, 46, 'डी अँड सी'),
(137557, 1406, 46, 'D & E ची'),
(137558, 1407, 46, 'D.O.B.'),
(137559, 1408, 46, 'दररोज'),
(137560, 1409, 46, 'दैनिक नोंद'),
(137561, 1410, 46, 'डॅनिश'),
(137562, 1411, 46, 'डेटा अलाईक डेटाबेस आधीपासूनच आहे, कोड आणि / किंवा वर्णन बदला'),
(137563, 1412, 46, 'डेटा अलाईक डेटाबेस आधीपासूनच आहे, सतत नाव बदला'),
(137564, 1413, 46, 'डेटा स्तंभ'),
(137565, 1416, 46, 'डेटा त्रुटी'),
(137566, 1417, 46, 'डेटा'),
(137567, 1419, 46, 'सर्व चकमक डेटा आतापर्यंत'),
(137568, 1420, 46, 'डेटा प्रकार'),
(137569, 1421, 46, 'डेटाबेस'),
(137570, 1422, 46, 'डाटाबेस स्थापित केले नाही.'),
(137571, 1423, 46, 'डेटाबेस ठिगळ'),
(137572, 1424, 46, 'डेटाबेस अहवाल'),
(137573, 1425, 46, 'डेटाबेस सुधारणा पूर्ण.'),
(137574, 1426, 46, 'DataCols 1 आणि 999 दरम्यान एक संख्या असणे आवश्यक आहे'),
(137575, 1427, 46, 'तारीख'),
(137576, 1428, 46, 'DATE रोजी'),
(137577, 1429, 46, 'तारीख आणि वेळ प्रशासित'),
(137578, 1431, 46, 'तारीख प्रशासित'),
(137579, 1432, 46, 'तारीख आणि नमुना संग्रह वेळ'),
(137580, 1433, 46, 'या निरीक्षण तारीख आणि वेळ'),
(137581, 1435, 46, 'दिनांक व वेळ नमुना गोळा झाले की,'),
(137582, 1436, 46, 'तारीख आज पेक्षा जास्त असू शकत नाही'),
(137583, 1437, 46, 'तारीख गर्भनिरोधक सेवा सुरुवातीला प्रदान'),
(137584, 1438, 46, 'तारीख तयार'),
(137585, 1439, 46, 'तारीख मृत'),
(137586, 1440, 46, 'तारीख नष्ट'),
(137587, 1441, 46, 'तारीख प्रदर्शन स्वरूप'),
(137588, 1442, 46, 'नियुक्ती शेवट तारखेचे स्वरुप वैध नाही'),
(137589, 1443, 46, 'नियुक्ती प्रारंभ तारखेचे स्वरुप वैध नाही'),
(137590, 1444, 46, 'पुढील भेट तारखेचे स्वरुप वैध नाही'),
(137591, 1445, 46, 'पासून पाहिले नाही तारखेचे स्वरुप वैध नाही'),
(137592, 1446, 46, 'पासून पाहिले तारखेचे स्वरुप वैध नाही'),
(137593, 1447, 46, 'तारीख लसीकरण माहिती विधाने दिली'),
(137594, 1448, 46, 'दिनांक कोड गहाळ आहे '),
(137595, 1449, 46, 'तारीख मास्टर निकष'),
(137596, 1450, 46, 'बँक डिपॉझिट, वर्ष-mm-dd या तारीख'),
(137597, 1451, 46, 'बिलिंग तारीख'),
(137598, 1452, 46, 'जन्म तारीख'),
(137599, 1453, 46, 'जन्म तारीख'),
(137600, 1454, 46, 'जन्म तारीख'),
(137601, 1455, 46, 'प्रवेश दिनांक'),
(137602, 1456, 46, 'इजा तारीख'),
(137603, 1458, 46, 'पैसे वर्ष-mm-dd या तारीख'),
(137604, 1459, 46, 'संदर्भ तारीख'),
(137605, 1460, 46, 'उत्तर तारीख'),
(137606, 1461, 46, 'अहवाल तारीख'),
(137607, 1462, 46, 'सेवा तारीख'),
(137608, 1463, 46, 'सेवा तारीख'),
(137609, 1464, 46, 'सेवा तारीख = आज'),
(137610, 1465, 46, 'सेवा मिमी / DD / YYYY तारीख'),
(137611, 1466, 46, 'सेवा दिनांक:'),
(137612, 1467, 46, 'याची सही व तारीख'),
(137613, 1468, 46, 'स्थिती बदला तारीख'),
(137614, 1469, 46, 'या क्रमाने तारीख'),
(137615, 1470, 46, 'हा अहवाल दिनांक'),
(137616, 1471, 46, 'इच्छित विधान तारीख'),
(137617, 1472, 46, 'तारीख आदेश'),
(137618, 1474, 46, 'तारीख निवड'),
(137619, 1475, 46, 'तारीख निवड'),
(137620, 1476, 46, 'प्रेषित तारीख'),
(137621, 1477, 46, 'तारीख संदेश पाठविला'),
(137622, 1478, 46, 'तारीख वेळ'),
(137623, 1479, 46, 'तारीख मूल्ये रिक्त असू शकत नाही.'),
(137624, 1480, 46, 'तारीख / Appt'),
(137625, 1481, 46, 'तारीख / टिपा'),
(137626, 1482, 46, 'अंतिम तारीख / टिपा'),
(137627, 1483, 46, 'तारीख / वेळ'),
(137628, 1484, 46, 'दिनांक:'),
(137629, 1485, 46, 'संदेश लॉग दिनांक'),
(137630, 1486, 46, 'दिवस'),
(137631, 1487, 46, 'दिवस'),
(137632, 1489, 46, 'दिवस पहा'),
(137633, 1490, 46, 'दिवस (चे)'),
(137634, 1491, 46, 'दिवस (चे) एम एफ'),
(137635, 1492, 46, 'दिवस'),
(137636, 1493, 46, 'दिवस'),
(137637, 1494, 46, 'दिवसांपूर्वी'),
(137638, 1495, 46, 'दिवस आणि खेळ मिस'),
(137639, 1496, 46, 'गेल्या चकमकीत पासून दिवस'),
(137640, 1497, 46, 'दिवस मिस'),
(137641, 1498, 46, 'स्तंभ प्रति दिवस:'),
(137642, 1500, 46, 'दिवस / कर्नल:'),
(137643, 1501, 46, 'डीबी स्थापित'),
(137644, 1502, 46, 'डीडी / आहे MM / YYYY'),
(137645, 1503, 46, 'डे ओळख'),
(137646, 1504, 46, 'डे ओळख प्रक्रिया पूर्ण'),
(137647, 1505, 46, 'डे ओळख प्रक्रिया सुरु आहे'),
(137648, 1506, 46, 'डे ओळख प्रक्रिया सुरु केले आणि पार्श्वभूमीत चालू आहे'),
(137649, 1507, 46, 'डे ओळखले डेटा पूर्ण होऊ शकत नाही'),
(137650, 1508, 46, 'डी-ओळख येथे साठवले जाईल'),
(137651, 1509, 46, 'DEA'),
(137652, 1511, 46, 'बहिरा'),
(137653, 1512, 46, 'डीबग माहिती'),
(137654, 1514, 46, 'डिबगिंग'),
(137655, 1515, 46, 'डिसेंबर'),
(137656, 1516, 46, 'मृत'),
(137657, 1517, 46, 'डिसेंबर'),
(137658, 1518, 46, '# वेगळे करून दशमान पौंड किंवा पाउंड आणि औन्स (उदा 5 # 4)'),
(137659, 1519, 46, 'निर्देशीत करण्यासाठी नकार दिला'),
(137660, 1520, 46, 'पात्र'),
(137661, 1521, 46, 'पात्र हवामान'),
(137662, 1522, 46, 'डीफॉल्ट'),
(137663, 1523, 46, 'डीफॉल्ट कॅलेंडर पहा'),
(137664, 1524, 46, 'मुलभूत चकमकीत फॉर्म आयडी'),
(137665, 1526, 46, 'मुलभूत सुविधा'),
(137666, 1527, 46, 'मुलभूत भाषा'),
(137667, 1528, 46, 'अनुमती देण्यात येईल किंवा निवडलेल्या कोणत्याही इतर तर मुलभूत भाषा.'),
(137668, 1529, 46, 'मुलभूत यादी (addonly पर्यायी, लिहा)'),
(137669, 1530, 46, 'डीफॉल्ट पद्धत'),
(137670, 1531, 46, 'डीफॉल्ट संकेतशब्द कालबाह्य दिवस'),
(137671, 1532, 46, 'दिवस डीफॉल्ट संकेतशब्द समाप्ती कालावधी. 0 हे वैशिष्ट्य अक्षम आहे याचा अर्थ.'),
(137672, 1533, 46, 'डीफॉल्ट रुग्णांच्या देश'),
(137673, 1535, 46, 'डीफॉल्ट प्राधान्य'),
(137674, 1536, 46, 'डीफॉल्ट प्रदाता'),
(137675, 1537, 46, 'डीफॉल्ट श्रेणी'),
(137676, 1538, 46, 'भेट द्या डीफॉल्ट कारण'),
(137677, 1540, 46, 'डीफॉल्ट सेटिंग'),
(137678, 1541, 46, 'रुग्ण यादी नवीन विंडो चेकबॉक्स डीफॉल्ट स्थिती.'),
(137679, 1542, 46, 'डीफॉल्ट टेम्पलेट'),
(137680, 1546, 46, 'डीफॉल्ट युनिट'),
(137681, 1547, 46, 'डीफॉल्ट मूल्य'),
(137682, 1548, 46, 'डीफॉल्ट वखार'),
(137683, 1549, 46, 'डीफॉल्ट X12 भागीदार'),
(137684, 1550, 46, 'डीफॉल्ट / ग्लोबल'),
(137685, 1551, 46, 'देल'),
(137686, 1552, 46, 'देल'),
(137687, 1553, 46, 'विलंब पुनरावृत्ती (> 12 मो)'),
(137688, 1554, 46, 'हटवा'),
(137689, 1555, 46, 'हटवा'),
(137690, 1556, 46, 'आयडी (चे) सह श्रेणी हटवा: '),
(137691, 1557, 46, 'वर्ग हटवा'),
(137692, 1559, 46, 'हटवा अयशस्वी झाले!'),
(137693, 1560, 46, 'गट हटवा'),
(137694, 1561, 46, 'यादी हटवा'),
(137695, 1562, 46, 'पृष्ठे हटवा'),
(137696, 1563, 46, 'रुग्णांच्या, आढळतात, फॉर्म, अंक, दस्तऐवज, भरणा, बिलिंग किंवा व्यवहार हटवा'),
(137697, 1565, 46, 'पंक्ती हटवा'),
(137698, 1566, 46, 'निवडलेले आयटम हटवा'),
(137699, 1567, 46, 'निवडलेले विनंत्या हटवा'),
(137700, 1568, 46, 'यशस्वी हटवा.'),
(137701, 1569, 46, 'या दस्तऐवजात हटवा'),
(137702, 1570, 46, 'हा फॉर्म हटवा'),
(137703, 1571, 46, 'ही नोट हटवू'),
(137704, 1572, 46, 'यशस्वीरित्या हटविले'),
(137705, 1573, 46, 'यशस्वीरित्या हटविले.'),
(137706, 1574, 46, 'हटवत आहे'),
(137707, 1575, 46, 'हा कार्यक्रम हटविणे पूर्ववत केले जाऊ शकत नाही. तो गेले आहे एकदा तो वसूल करणे शक्य नाही. आपण हा कार्यक्रम हटवू इच्छित आपल्याला खात्री आहे?'),
(137708, 1576, 46, 'डिलिव्हरी पुष्टी'),
(137709, 1577, 46, 'डिलिव्हरी निर्दिष्ट थेट पत्ता करण्याची परवानगी नाही आहे.'),
(137710, 1578, 46, 'डिलिव्हरी सध्या निर्दिष्ट थेट पत्ता करण्याची परवानगी देण्यात आली नाही.'),
(137711, 1579, 46, 'संलग्न वैद्यकीय दस्तऐवज डिलिव्हरी रुग्ण केली'),
(137712, 1580, 46, 'संलग्न वैद्यकीय दस्तऐवज डिलिव्हरी रुग्ण केली.'),
(137713, 1581, 46, 'वेड'),
(137714, 1582, 46, 'लोकसंख्याशास्त्र'),
(137715, 1583, 46, 'लोकसंख्याशास्त्र (पर्यायी addonly, लिहा)'),
(137716, 1585, 46, 'लोकसंख्याशास्त्र फिल्टर निकष'),
(137717, 1586, 46, 'लोकसंख्याशास्त्र अधिकृत नाही'),
(137718, 1587, 46, 'लोकसंख्याशास्त्र अधिकृत नाही.'),
(137719, 1588, 46, 'नाकारला'),
(137720, 1589, 46, 'भाजक'),
(137721, 1590, 46, 'दंत'),
(137722, 1591, 46, 'दंत समस्या सूची'),
(137723, 1592, 46, 'दंत मुद्दे'),
(137724, 1593, 46, 'अवलंबित्व मॉड्यूल'),
(137725, 1594, 46, 'अवलंबित्व समस्या'),
(137726, 1595, 46, 'आपण एक X12 दावा परीक्षा तर आपण HCFA बिले रिकामी पृष्ठावर आउटपुट जसे HCFA दिसेल परीक्षा बिल प्रकारावर अवलंबून असून, आपण काहीसे अस्पष्ट मजकूर आणि माहिती अनेक ओळी दिसेल. त्या अस्पष्ट मजकूर X12 EDI 4010A स्वरूप आहे. आपण कधी कधी dominoes किंवा squiglies दिसत विचित्र वर्ण, या अशा पृष्ठ फीड म्हणून कंट्रोल अक्षर आहेत आणि सामान्य असतात दिसेल.'),
(137727, 1596, 46, 'ठेव तारीख'),
(137728, 1597, 46, 'ठेव तारीख आज पेक्षा जास्त असू शकत नाही'),
(137729, 1598, 46, 'ठेव दिनांक:'),
(137730, 1599, 46, 'उदासीन'),
(137731, 1600, 46, 'उदासीनता'),
(137732, 1601, 46, 'DESC'),
(137733, 1602, 46, 'वर्णन'),
(137734, 1603, 46, 'वर्णन'),
(137735, 1604, 46, 'वर्णन मुलभूत पाठ्य आहे'),
(137736, 1605, 46, 'प्रकटीकरण वर्णन'),
(137737, 1606, 46, 'ही प्रक्रिया किंवा परिणाम कोड वर्णन'),
(137738, 1607, 46, 'वर्णन भाषांतर'),
(137739, 1608, 46, 'इच्छित फाइलनाव'),
(137740, 1609, 46, 'गंतव्य'),
(137741, 1610, 46, 'गंतव्य फाइलनाव'),
(137742, 1611, 46, 'लोट नष्ट'),
(137743, 1612, 46, 'नष्ट ...'),
(137744, 1613, 46, 'नष्ट'),
(137745, 1614, 46, 'नष्ट औषधे'),
(137746, 1615, 46, 'नष्ट औषधे अहवाल'),
(137747, 1616, 46, 'तपशील'),
(137748, 1617, 46, 'माहिती'),
(137749, 1619, 46, 'विकास विकृती'),
(137750, 1620, 46, 'मधुमेह'),
(137751, 1621, 46, 'मधुमेह'),
(137752, 1622, 46, 'मधुमेह: ब्लड प्रेशर व्यवस्थापन (CQM)'),
(137753, 1623, 46, 'मधुमेह: डोळ्याचा परीक्षा'),
(137754, 1624, 46, 'मधुमेह: डोळ्याचा परीक्षा (CQM)'),
(137755, 1625, 46, 'मधुमेह: पाऊल परीक्षा'),
(137756, 1626, 46, 'मधुमेह: पाऊल परीक्षा (CQM)'),
(137757, 1627, 46, 'मधुमेह: HbA1c गरीब नियंत्रण (CQM)'),
(137758, 1628, 46, 'मधुमेह: हिमोग्लोबिन A1C'),
(137759, 1629, 46, 'मधुमेह: LDL व्यवस्थापन व नियंत्रण (CQM)'),
(137760, 1630, 46, 'मधुमेह: लघवी Microalbumin'),
(137761, 1631, 46, 'Diag'),
(137762, 1632, 46, 'निदान'),
(137763, 1633, 46, 'निदान'),
(137764, 1634, 46, 'निदान कोड'),
(137765, 1635, 46, 'निदान कोड'),
(137766, 1636, 46, 'निदान तारीख'),
(137767, 1637, 46, 'निदान एक लिंक चकमकीत मध्ये कोड करणे आवश्यक आहे'),
(137768, 1638, 46, 'निदान नाव'),
(137769, 1639, 46, 'निदान अहवाल'),
(137770, 1640, 46, 'निदान अहवाल'),
(137771, 1641, 46, 'निदान अहवाल केवळ'),
(137772, 1642, 46, 'निदान शीर्षक'),
(137773, 1643, 46, 'निदान:'),
(137774, 1644, 46, 'निदान: '),
(137775, 1645, 46, 'निदान कसोटी:'),
(137776, 1646, 46, 'Dials'),
(137777, 1647, 46, 'Diaphragms / कॅप्स'),
(137778, 1648, 46, 'अतिसार'),
(137779, 1650, 46, 'शुद्धलेखन'),
(137780, 1651, 46, 'शुद्धलेखन: '),
(137781, 1652, 46, 'तुम्ही HIPAA सूचना एक प्रत प्राप्त होते का?'),
(137782, 1653, 46, 'प्रकाश:'),
(137783, 1654, 46, 'डिजिटली केलेली स्वाक्षरी'),
(137784, 1657, 46, 'थेट मेल'),
(137785, 1658, 46, 'थेट संदेश लॉग'),
(137786, 1659, 46, 'थेट संदेश प्राप्त झाला नाही.'),
(137787, 1660, 46, 'थेट संदेश सध्या अनुपलब्ध आहे.'),
(137788, 1661, 46, 'थेट संदेश अयशस्वी पाठवा.'),
(137789, 1663, 46, 'संचालक नाव'),
(137790, 1664, 46, 'निर्देशिका हटवणे अयशस्वी; चालू.'),
(137791, 1665, 46, 'अपंगत्व'),
(137792, 1666, 46, 'अक्षम करा'),
(137793, 1667, 46, 'अक्षम करा दिनदर्शिका'),
(137794, 1668, 46, 'अक्षम करा चार्ट ट्रॅकर'),
(137795, 1669, 46, 'अक्षम करा लसीकरण'),
(137796, 1670, 46, 'जुन्या मेट्रिक मर्मस्थाने फॉर्म अक्षम'),
(137797, 1672, 46, 'PhpMyAdmin अक्षम करा'),
(137798, 1673, 46, 'अक्षम करा चांगले'),
(137799, 1674, 46, 'अक्षम करा वापरकर्ता गट'),
(137800, 1675, 46, 'अक्षम'),
(137801, 1676, 46, 'अपंग'),
(137802, 1677, 46, 'मोठे गट आरोग्य योजना वय 65 अंतर्गत अपंग लाभार्थी (LGHP)'),
(137803, 1678, 46, 'DISC'),
(137804, 1679, 46, 'टाकून द्यायचा'),
(137805, 1680, 46, 'टाकून'),
(137806, 1681, 46, 'स्त्राव'),
(137807, 1682, 46, 'मूत्रमार्ग खाज'),
(137808, 1684, 46, 'उजव्या स्त्राव'),
(137809, 1685, 46, 'उजव्या स्त्राव:'),
(137810, 1688, 46, 'सोडण्यात'),
(137811, 1689, 46, 'प्रकटीकरण माहिती'),
(137812, 1690, 46, 'प्रकटीकरण प्रकार'),
(137813, 1691, 46, 'प्रकटीकरण प्रकार'),
(137814, 1692, 46, 'माहितीचे प्रकटीकरण'),
(137815, 1694, 46, 'सवलत'),
(137816, 1695, 46, 'सवलत रक्कम'),
(137817, 1696, 46, 'सवलत पातळी'),
(137818, 1697, 46, 'सवलत टक्केवारी'),
(137819, 1698, 46, 'सवलत आर्थिक प्रमाणात'),
(137820, 1699, 46, 'टक्केवारी विरोध म्हणून चेकआउटवर वेळी सवलत, पैसे प्रमाणात प्रवेश केला आहे.'),
(137821, 1700, 46, 'अलग निकाल'),
(137822, 1701, 46, 'रोग'),
(137823, 1702, 46, 'सांधा निखळणे'),
(137824, 1703, 46, 'Disp #'),
(137825, 1704, 46, 'पाठवणे'),
(137826, 1705, 46, 'पाठवणे प्राप्त दस्तऐवज'),
(137827, 1706, 46, 'Dispensed'),
(137828, 1707, 46, 'लोकसंख्याशास्त्र पृष्ठ मध्ये आगाऊ निर्देशांचे प्रदर्शित करा.'),
(137829, 1708, 46, 'प्रदर्शन दस्तऐवज'),
(137830, 1709, 46, 'प्रदर्शन कार्यक्रम ब्लॉक तारखा?'),
(137831, 1710, 46, 'अमेरिकन वजन प्रदर्शन स्वरूप'),
(137832, 1711, 46, 'किती कार्यक्रम प्रदर्शित?'),
(137833, 1713, 46, 'ब्लॉक प्रदर्शन स्थान नाही?'),
(137834, 1714, 46, 'प्रदर्शन नाव'),
(137835, 1715, 46, 'कॅलेंडर प्रदर्शित?'),
(137836, 1718, 46, 'प्रदर्शन आज  ''चे ब्लॉक कार्यक्रम?'),
(137837, 1719, 46, 'ब्लॉक विषय प्रदर्शित?'),
(137838, 1720, 46, 'ब्लॉक आगामी कार्यक्रम प्रदर्शित?'),
(137839, 1721, 46, 'प्रदर्शित स्तंभ'),
(137840, 1722, 46, 'सर्वात अलीकडील माहिती खालील संख्या प्रदर्शित करत आहे:'),
(137841, 1723, 46, 'सर्वात अलीकडील नोट्स खालील संख्या प्रदर्शित'),
(137842, 1724, 46, 'सर्वात अलीकडील नोट्स खालील संख्या प्रदर्शित करत आहे:'),
(137843, 1725, 46, 'वितरण'),
(137844, 1726, 46, 'वितरण'),
(137845, 1727, 46, 'वितरक'),
(137846, 1728, 46, 'Divehi- Dhivehi- Maldivian-'),
(137847, 1729, 46, 'डायव्हर्टीक्युलमचा क्षोभ'),
(137848, 1730, 46, 'डायव्हर्टीक्युलमचा क्षोभ शस्त्रक्रिया'),
(137849, 1731, 46, 'Divirticulitis'),
(137850, 1732, 46, 'Divirticulitis शस्त्रक्रिया'),
(137851, 1733, 46, 'घटस्फोटीत'),
(137852, 1734, 46, 'चक्कर:'),
(137853, 1735, 46, 'बदलू ​​नका'),
(137854, 1737, 46, 'ऍलर्जी NewCrop अपलोड प्रदर्शित करू नका'),
(137855, 1739, 46, 'NewCrop अपलोड औषधे प्रदर्शित करू नका'),
(137856, 1742, 46, 'कॅलेंडर प्रदर्शित करू नका.'),
(137857, 1744, 46, 'नाही यादी आणि कोणत्याही उत्पादने विक्री'),
(137858, 1745, 46, 'अधिकृत करणे रुग्ण नोट्स आवश्यक नाही'),
(137859, 1746, 46, 'ऑर्डर Resuscitate करू नका'),
(137860, 1747, 46, 'जतन नाही'),
(137861, 1748, 46, 'पर्याय नाही'),
(137862, 1749, 46, 'काही करू नको'),
(137863, 1751, 46, 'आपण खरोखर हटवू इच्छिता का'),
(137864, 1752, 46, 'आपण खरोखर निवड हटवू इच्छिता का?'),
(137865, 1753, 46, 'आपण खरोखर हा गट हटवू इच्छिता का'),
(137866, 1754, 46, 'आपण खरोखर हटवू इच्छिता का?'),
(137867, 1755, 46, 'तुम्हाला पुढे जायचे आहे का?'),
(137868, 1756, 46, 'आपण हे हटवू इच्छिता का?'),
(137869, 1757, 46, 'आपण हटवू इच्छिता का?'),
(137870, 1758, 46, 'आपण या रेकॉर्ड काढू इच्छित आहे का?'),
(137871, 1759, 46, 'आपण या नवीन रुग्ण जोडून पुढे जायचे आहे का?'),
(137872, 1760, 46, 'आपण नवीन नाव पुढे जायचे आहे का?'),
(137873, 1761, 46, 'आपण कायमचे या लसीकरण रेकॉर्ड हटवू इच्छिता?'),
(137874, 1762, 46, 'डीओबी'),
(137875, 1763, 46, 'डीओबी शक्य असल्यास प्रविष्ट करा, गहाळ आहे'),
(137876, 1764, 46, 'डॉक्स'),
(137877, 1765, 46, 'डॉक्टर'),
(137878, 1766, 46, 'डॉक्टर:'),
(137879, 1767, 46, 'डॉक्टर  ''चे नाव आणि स्वाक्षरी'),
(137880, 1768, 46, 'दस्तऐवज'),
(137881, 1769, 46, 'दस्तऐवज'),
(137882, 1770, 46, 'दस्तऐवज श्रेणी'),
(137883, 1771, 46, 'लॅब परिणाम दस्तऐवज श्रेणी विद्यमान नाही'),
(137884, 1772, 46, 'इलेक्ट्रॉनिक प्राप्त लॅब परिणाम संग्रह दस्तऐवज श्रेणी नाव.'),
(137885, 1774, 46, 'दस्तऐवज वर्ग किंवा टाकून द्या'),
(137886, 1775, 46, 'दस्तऐवज रुग्णाला आयडी हलविले जाऊ शकत नाही'),
(137887, 1777, 46, 'दस्तऐवज तारीख'),
(137888, 1778, 46, 'दस्तऐवज तारीख आणि समस्या यशस्वीरित्या अद्यतनित केले'),
(137889, 1779, 46, 'दस्तऐवज ID'),
(137890, 1780, 46, 'दस्तऐवज नवीन श्रेणी हलविले'),
(137891, 1781, 46, 'दस्तऐवज रुग्णाला आयडी हलविले'),
(137892, 1783, 46, 'दस्तऐवज माहिती पॅनल चेक निधन झाले.'),
(137893, 1784, 46, 'दस्तऐवज संग्रह पद्धत'),
(137894, 1785, 46, 'दस्तऐवज यशस्वीरित्या पुनर्नामित करण्यात आली.'),
(137895, 1786, 46, 'दस्तऐवज यशस्वीरित्या आढळतात धर्तीवर'),
(137896, 1787, 46, 'दस्तऐवज साचा व्यवस्थापन'),
(137897, 1788, 46, 'दस्तऐवज टेम्पलेट'),
(137898, 1789, 46, 'दस्तऐवज (चे)'),
(137899, 1790, 46, 'दस्तऐवज / इमेजिंग स्टोअर'),
(137900, 1791, 46, 'दस्तऐवज'),
(137901, 1792, 46, 'दस्तऐवज (पर्यायी addonly, लिहा)'),
(137902, 1794, 46, 'डीओई'),
(137903, 1796, 46, 'PV1 चकमकीत संख्या जुळत नाही'),
(137904, 1797, 46, 'वैध दिसत नाही'),
(137905, 1798, 46, 'हा प्रकार संबंधित कोड परवानगी आहे का?'),
(137906, 1799, 46, 'घरगुती भागीदार'),
(137907, 1800, 46, 'जतन करू नका'),
(137908, 1801, 46, 'डॉन  ''टी जतन करा'),
(137909, 1802, 46, 'डॉन  ''टी बदल जतन करा'),
(137910, 1803, 46, 'पूर्ण झाले'),
(137911, 1804, 46, 'केले:'),
(137912, 1805, 46, 'पूर्ण झाले. आता डाउनलोड पाठवेल.'),
(137913, 1806, 46, 'डॉस'),
(137914, 1807, 46, 'डोस'),
(137915, 1809, 46, 'डबल क्लिक करा संपादित करण्यासाठी'),
(137916, 1810, 46, 'डबल दृष्टी'),
(137917, 1811, 46, 'डाउनलोड'),
(137918, 1814, 46, 'तरीही डाउनलोड करा'),
(137919, 1815, 46, ', बिलिंग फाइल डाउनलोड करा बिल म्हणून लेखा खूण पोस्ट'),
(137920, 1817, 46, 'डाउनलोड प्रमाणपत्र'),
(137921, 1818, 46, 'डाउनलोड कॉन्फिगरेशन डेटा'),
(137922, 1819, 46, 'या रुग्ण आणि भेट दस्तऐवज टेम्प्लेट डाउनलोड करा'),
(137923, 1820, 46, 'एनक्रिप्टेड फाइल डाउनलोड'),
(137924, 1823, 46, 'Offsite पोर्टल कनेक्शन फाइल्स डाउनलोड'),
(137925, 1824, 46, 'डाउनलोड करा किंवा टेम्पलेट हटवा'),
(137926, 1825, 46, 'डाउनलोड पीडीएफ'),
(137927, 1827, 46, 'डाउनलोड निवडलेले स्टेटमेन्ट'),
(137928, 1828, 46, 'डॉ तपासा'),
(137929, 1829, 46, 'डॉ भेट द्या'),
(137930, 1830, 46, 'डॉ'),
(137931, 1831, 46, 'हलवा ड्रॅग करा'),
(137932, 1832, 46, 'Dribbling'),
(137933, 1833, 46, 'वाहन चालक परवाना किंवा राज्य आयडी'),
(137934, 1834, 46, 'औषध'),
(137935, 1835, 46, 'औषध फाइंडर'),
(137936, 1836, 46, 'औषध अर्ज'),
(137937, 1837, 46, 'औषध आयडी गहाळ!'),
(137938, 1838, 46, 'औषध मध्यांतरे'),
(137939, 1839, 46, 'औषध यादी'),
(137940, 1840, 46, 'औषध नाव'),
(137941, 1841, 46, 'औषध मार्ग'),
(137942, 1845, 46, 'औषध युनिट'),
(137943, 1846, 46, 'औषधे'),
(137944, 1847, 46, 'औषधे आणि उत्पादने'),
(137945, 1848, 46, 'कोरड्या तोंड'),
(137946, 1849, 46, 'DSMIV निदान'),
(137947, 1850, 46, 'विमुक्त 1'),
(137948, 1851, 46, 'विमुक्त 2'),
(137949, 1852, 46, 'विमुक्त 3'),
(137950, 1853, 46, 'विमुक्त 4'),
(137951, 1854, 46, 'विमुक्त 5'),
(137952, 1855, 46, 'DTaP 1'),
(137953, 1856, 46, 'DTaP 2'),
(137954, 1857, 46, 'DTaP 3'),
(137955, 1858, 46, 'DTaP 4'),
(137956, 1859, 46, 'DTaP 5'),
(137957, 1860, 46, 'मुळे'),
(137958, 1861, 46, 'मुळे तारीख'),
(137959, 1862, 46, 'मुळे तारीख मि.मी. / डीडी / वर्ष किंवा वर्ष-mm-dd या'),
(137960, 1863, 46, 'मुळे दिनांक:'),
(137961, 1864, 46, 'मुळे इन'),
(137962, 1865, 46, 'मुळे पं'),
(137963, 1866, 46, 'मुळे लवकरच'),
(137964, 1867, 46, 'मुळे स्थिती'),
(137965, 1868, 46, 'मुळे अद्यतनित स्थिती'),
(137966, 1869, 46, 'LibreEHR डेटाबेस डम्पिंग'),
(137967, 1870, 46, 'डम्पिंग LibreEHR वेब निर्देशिका झाड'),
(137968, 1871, 46, 'PhpGACL डेटाबेस डम्पिंग'),
(137969, 1872, 46, 'डम्पिंग phpGACL वेब निर्देशिका झाड'),
(137970, 1873, 46, 'डम्पिंग एस क्यू एल-लेजर डेटाबेस'),
(137971, 1874, 46, 'डम्पिंग एस क्यू एल-लेजर वेब निर्देशिका झाड'),
(137972, 1875, 46, 'Dup तपासा'),
(137973, 1876, 46, 'ओळीवर डुप्लिकेट आयडी'),
(137974, 1877, 46, 'ओळीवर डुप्लीकेट नाव'),
(137975, 1878, 46, 'दुप्पट चेतावणी'),
(137976, 1879, 46, 'मुखत्यार टिकाऊ पॉवर'),
(137977, 1880, 46, 'कालावधी'),
(137978, 1881, 46, 'कालावधी'),
(137979, 1882, 46, 'डच'),
(137980, 1883, 46, 'Dx रिपब्लिक'),
(137981, 1884, 46, 'गिळण्यामध्ये अडचण'),
(137982, 1885, 46, 'Dyspnea:'),
(137983, 1886, 46, 'लघवी होताना वेदना होणे'),
(137984, 1887, 46, 'जोंगखा'),
(137985, 1888, 46, 'ई-नियम?'),
(137986, 1889, 46, 'ई-अहवाल'),
(137987, 1890, 46, 'ई-Rx'),
(137988, 1892, 46, 'ई-Rx नूतनीकरण'),
(137989, 1893, 46, 'पूर्ण म्हणून प्रत्येक प्राप्तकर्ता त्यांच्या स्वत: च्या संदेश सेट करणे आवश्यक आहे.'),
(137990, 1894, 46, 'लवकर पुनरावृत्ती (<2 मो)'),
(137991, 1895, 46, 'कान'),
(137992, 1896, 46, 'ECG'),
(137993, 1897, 46, 'eClaims'),
(137994, 1898, 46, 'सूज'),
(137995, 1899, 46, 'EDI इतिहास'),
(137996, 1900, 46, 'EDI इतिहास'),
(137997, 1901, 46, 'EDI हक्क प्रतिसाद फायली संचयित आणि निष्कर्षांचा अर्थ लावणे यासाठी (फी अंतर्गत) EDI इतिहास'),
(137998, 1902, 46, 'EDI-271 फाइल अपलोड करा'),
(137999, 1903, 46, 'EDI-271 प्रतिसाद फाइल अपलोड करा'),
(138000, 1904, 46, 'संपादित करा'),
(138001, 1905, 46, 'संपादित करा'),
(138002, 1906, 46, 'संपादित करा अॅलर्जी'),
(138003, 1907, 46, 'संपादित करा कॅटेगरीज'),
(138004, 1908, 46, 'संपादित करा व्याख्या'),
(138005, 1909, 46, 'संपादित करा व्याख्या'),
(138006, 1910, 46, 'संपादित करा निदान साठी'),
(138007, 1911, 46, 'संपादित करा प्रकटीकरण'),
(138008, 1912, 46, 'संपादित करा सुविधा'),
(138009, 1913, 46, 'संपादित करा सुविधा'),
(138010, 1914, 46, 'संपादित करा सुविधा माहिती'),
(138011, 1915, 46, 'संपादित करा सुविधा विशिष्ट वापरकर्ता माहिती'),
(138012, 1916, 46, 'संपादित करा फाइल'),
(138013, 1917, 46, 'फॉर्म संपादित करा'),
(138014, 1918, 46, 'संपादित करा ग्लोबल सेटिंग्ज'),
(138015, 1919, 46, 'संपादित करा अधिकृत नाही!'),
(138016, 1920, 46, 'संपादित करा लेआउट'),
(138017, 1921, 46, 'सूची संपादित करा'),
(138018, 1922, 46, 'संपादित करा भरणा'),
(138019, 1923, 46, 'संपादित करा संरचना'),
(138020, 1924, 46, 'वापरकर्ता संपादन करा'),
(138021, 1925, 46, 'वापरकर्ता संपादन करा सेटिंग्ज'),
(138022, 1926, 46, 'आपला प्रविष्ट केलेला डेटा संपादित करा'),
(138023, 1927, 46, 'संपादन अयशस्वी'),
(138024, 1928, 46, 'शिक्षण'),
(138025, 1929, 46, 'शिक्षण तारीख'),
(138026, 1930, 46, 'शैक्षणिक साहित्य'),
(138027, 1931, 46, 'अधिक माहिती साठी * हे GNU General Public परवाना मध्ये. * * आपण या कार्यक्रमात सोबत हे GNU General Public परवान्याची एक प्रत * प्राप्त पाहिजे; नाही तर, मोफत लिहा '),
(138028, 1932, 46, 'प्रभावी तारीख'),
(138029, 1934, 46, 'परिणामकारकता'),
(138030, 1935, 46, 'EIN'),
(138031, 1936, 46, 'Ejaculations'),
(138032, 1937, 46, 'वळणदार'),
(138033, 1938, 46, 'वळणदार समस्या'),
(138034, 1939, 46, 'इलेक्ट्रॉनिक'),
(138035, 1942, 46, 'इलेक्ट्रॉनिक Remits'),
(138036, 1943, 46, 'इलेक्ट्रॉनिक अहवाल'),
(138037, 1944, 46, 'पात्रता'),
(138038, 1945, 46, 'पात्रता 270 चौकशी बॅच'),
(138039, 1946, 46, 'पात्रता प्रतिसाद'),
(138040, 1947, 46, 'मुले पुरवठा लस लस पात्रता स्थिती'),
(138041, 1948, 46, 'पात्र'),
(138042, 1949, 46, 'ईमेल'),
(138043, 1950, 46, 'ई-मेल'),
(138044, 1951, 46, 'ई-मेल पत्ता'),
(138045, 1952, 46, 'ईमेल पत्ता गहाळ आहे'),
(138046, 1953, 46, 'रुग्ण स्मरणपत्रांकरिता प्रेषक ई-मेल पत्ता. रुग्णाला स्मरणपत्रे प्रत्युत्तरे या पत्त्यावर निर्देशित केले जाईल. हे मदत टाळण्यासाठी आपल्या क्लिनिकमध्ये  ''डोमेन एक पत्ता वापरू जंक मेल फोल्डर्स जाणे रुग्णाला स्मरणपत्रे प्रतिबंध करणे महत्वाचे आहे.'),
(138047, 1954, 46, 'ई-मेल पत्ता, जर असेल तर, प्रशासकीय सूचना प्राप्त करण्यासाठी.'),
(138048, 1955, 46, 'ई-मेल पत्ता, जर असेल तर, आपत्कालीन लॉगिन वापरकर्ता सक्रिय संदेश प्राप्त करण्यासाठी.'),
(138049, 1956, 46, 'ईमेल प्रमाणिकरण'),
(138050, 1957, 46, 'Batchcom ईमेल'),
(138051, 1958, 46, 'ईमेल सूचना'),
(138052, 1959, 46, 'ईमेल सूचना तास'),
(138053, 1960, 46, 'ईमेल सूचना अहवाल'),
(138054, 1961, 46, 'ईमेल आधी पाठवा'),
(138055, 1962, 46, 'ईमेल प्रेषक'),
(138056, 1963, 46, 'ई-मेल पाठविले'),
(138057, 1964, 46, 'ईमेल पाठविला'),
(138058, 1965, 46, 'ईमेल विषय'),
(138059, 1966, 46, 'ईमेल मजकूर, वापरता येण्याजोगे टॅग: *** *** की NAME, म्हणजे प्रिय *** *** NAME ना'),
(138060, 1967, 46, 'ईमेल मजकूर, वापरता येण्याजोगे टॅग: *** *** की NAME, म्हणजे प्रिय *** की NAME *** {{*** हे सतत घटक *** NAME यांनी अनुवाद नाही}.}'),
(138061, 1968, 46, 'वाहतूक पद्धत ईमेल'),
(138062, 1969, 46, 'ईमेल खालील पत्त्यावर पाठविण्यात आला आहे'),
(138063, 1971, 46, 'आणीबाणी संपर्क'),
(138064, 1972, 46, 'आणीबाणी संपर्क व्यक्ती'),
(138065, 1973, 46, 'आणीबाणी संपर्क फोन नंबर'),
(138066, 1974, 46, 'आणीबाणी संततिनियमन'),
(138067, 1975, 46, 'आणीबाणी लॉग-इन'),
(138068, 1976, 46, 'आणीबाणी लॉग-इन ACL यांना आधार देतो निवडले आहे. आणीबाणीच्या काळात आवश्यक तेव्हा वापरकर्ता सक्रिय राज्यात अजूनही आहे, समान वापरकर्ता रद्द सक्रिय आणि सक्रिय करा. सक्रियन किंवा रद्द चालू Administration-> वापरकर्ते भेट द्या.'),
(138069, 1977, 46, 'आणीबाणी लॉग-इन सक्रिय ईमेल इंटरफेस / globals.php फाइलमध्ये खालील सेटिंग्ज कॉन्फिगर करत असल्यावरच प्रसारित जाईल:'),
(138070, 1978, 46, 'आणीबाणी लॉग-इन ई-मेल पत्ता'),
(138071, 1979, 46, 'आणीबाणी लॉगिन वापरकर्ता काहीही करू शकता,'),
(138072, 1980, 46, 'आणीबाणी फोन'),
(138073, 1981, 46, 'भावनिक / वर्तणुकीशी शर्ती व गुंतागुंत'),
(138074, 1982, 46, 'शरिराच्या पेशीजालात किंवा पोकळ्यात अवास्तव हवा असणे'),
(138075, 1983, 46, 'कर्मचारी'),
(138076, 1984, 46, 'नियोक्ता'),
(138077, 1985, 46, 'नियोक्ता पत्ता'),
(138078, 1986, 46, 'नियोक्ता डेटा'),
(138079, 1987, 46, 'नियोक्ता नाव'),
(138080, 1988, 46, 'रिक्त'),
(138081, 1989, 46, 'रिक्त'),
(138082, 1990, 46, 'परवलीचा शब्द रिक्त परवानगी नाही'),
(138083, 1991, 46, 'ईमेल तास मध्ये रिक्त मूल्य'),
(138084, 1992, 46, 'ईमेल प्रेषक मध्ये रिक्त मूल्य'),
(138085, 1993, 46, 'ईमेल विषय मध्ये रिक्त मूल्य'),
(138086, 1994, 46, 'ईमेल मजकूर मध्ये रिक्त मूल्य'),
(138087, 1995, 46, 'प्रदाता नाव मध्ये रिक्त मूल्य'),
(138088, 1996, 46, 'संकेतशब्द मध्ये रिक्त मूल्य'),
(138089, 1997, 46, 'एसएमएस तास मध्ये रिक्त मूल्य'),
(138090, 1998, 46, 'एसएमएस मजकूर मध्ये रिक्त मूल्य'),
(138091, 1999, 46, 'वापरकर्तानाव मध्ये रिक्त मूल्य'),
(138092, 2001, 46, 'सक्षम'),
(138093, 2006, 46, 'एएमसी सूचित सक्षम'),
(138094, 2007, 46, 'एएमसी अहवाल Itemization सक्षम'),
(138095, 2008, 46, 'एएमसी अहवाल देणे सक्षम करा'),
(138096, 2009, 46, 'एएमसी ट्रॅकिंग सक्षम'),
(138097, 2010, 46, 'सुधारणांचाही वैशिष्ट्य सक्षम'),
(138098, 2011, 46, 'ATNA ऑडिटिंग सक्षम'),
(138099, 2012, 46, 'ऑडिट लॉग एनक्रिप्शन सुरू'),
(138100, 2013, 46, 'ऑडिट लॉग सक्षम'),
(138101, 2014, 46, 'ऑडिट माग आणि नोड प्रमाणीकरण (ATNA) सक्षम करा.'),
(138102, 2015, 46, 'सक्षम स्वयंचलित माप गणना (एएमसी) अहवाल'),
(138103, 2016, 46, 'क्लायंट एसएसएल सक्षम'),
(138104, 2017, 46, 'क्लायंट SSL प्रमाणपत्र प्रमाणीकरण सक्षम करा.'),
(138105, 2019, 46, 'क्लिनिकल निर्णय नियम सक्षम करा (CDR)'),
(138106, 2022, 46, 'क्लिनिकल गुणवत्ता माप सक्षम करा (CQM) अहवाल'),
(138107, 2023, 46, 'क्लिनिकल स्मरणपत्र पॉपअप सक्षम'),
(138108, 2024, 46, 'क्लिनिकल स्मरणपत्र विजेट सक्षम'),
(138109, 2025, 46, 'सीएमएस पोर्टल सक्षम'),
(138110, 2026, 46, 'CQM अहवाल Itemization सक्षम'),
(138111, 2027, 46, 'CQM अहवाल देणे सक्षम करा'),
(138112, 2028, 46, 'EDI इतिहास डाव्या मेनू सक्षम'),
(138113, 2030, 46, 'डाव्या मेनू शुल्क सक्षम'),
(138114, 2031, 46, 'Hylafax समर्थन सक्षम'),
(138115, 2033, 46, 'NewCrop erx आयात स्थिती संदेश सक्षम'),
(138116, 2034, 46, 'एएमसी अहवाल Itemization सक्षम'),
(138117, 2035, 46, 'CQM अहवाल Itemization सक्षम'),
(138118, 2036, 46, 'मानक क्लिनिकल नियम अहवाल Itemization सक्षम'),
(138119, 2037, 46, 'लॅब एक्सचेंज सक्षम'),
(138120, 2038, 46, 'लॉक टॉगल सक्षम'),
(138121, 2039, 46, 'CouchDB दस्तऐवज चढवलेल्या संचिका / डाउनलोड लॉग सक्षम'),
(138122, 2040, 46, 'सर्व एस क्यू एल निवडा चौकशी लॉगिंग सक्षम करा.'),
(138123, 2041, 46, 'बॅकअप संबंधित उपक्रम लॉगिंग सक्षम करा.'),
(138124, 2042, 46, 'CDR इंजिन चौकशी लॉगिंग सक्षम करा.'),
(138125, 2043, 46, 'मिश्र उपक्रम लॉगिंग सक्षम करा.'),
(138126, 2044, 46, 'उपक्रम क्रम लॉगिंग सक्षम करा.'),
(138127, 2045, 46, 'रुग्ण रेकॉर्ड बदल लॉगिंग सक्षम करा.'),
(138128, 2046, 46, 'शेड्युलिंग उपक्रम लॉगिंग सक्षम करा.'),
(138129, 2047, 46, 'सुरक्षा आणि प्रशासन उपक्रम लॉगिंग सक्षम करा.'),
(138130, 2049, 46, 'NewCrop eRx सेवा सक्षम'),
(138131, 2051, 46, 'Offsite रुग्णांच्या पोर्टल सक्षम'),
(138132, 2052, 46, 'Offsite रुग्णांच्या पोर्टल सक्षम करा.'),
(138133, 2053, 46, 'Onsite रुग्णांच्या पोर्टल सक्षम'),
(138134, 2055, 46, 'Onsite रुग्णांच्या पोर्टल सक्षम करा.'),
(138135, 2056, 46, 'रुग्णांच्या स्मरणपत्र विजेट सक्षम'),
(138136, 2057, 46, 'PhiMail थेट संदेश सेवा सक्षम'),
(138137, 2058, 46, 'स्वयंचलित माप गणना (एएमसी) आवश्यक डेटा विनंती सक्षम'),
(138138, 2060, 46, 'ऑटोमेटेड माप गणिते ट्रॅकिंग दिनांक अहवाल देणे सक्षम करा (एएमसी)'),
(138139, 2061, 46, 'स्कॅनर समर्थन सक्षम'),
(138140, 2062, 46, 'मानक अहवाल Itemization सक्षम'),
(138141, 2063, 46, 'सूर्यास्त प्रणाली द्वारे ओपन सोअर्स वर्डप्रेस पोर्टल समर्थन सक्षम करा'),
(138142, 2064, 46, 'वैद्यकीय माहिती एकत्रीकरण, एलएलसी लॅब विनिमय सेवा सक्षम करा.'),
(138143, 2065, 46, 'LibreEHR समर्थन, LLC लॅब विनिमय सेवा सक्षम करा.'),
(138144, 2066, 46, 'वापरकर्ता प्रमाणपत्र प्रमाणीकरण सक्षम'),
(138145, 2067, 46, 'ZMG, एलएलसी eRx सेवा सक्षम'),
(138146, 2068, 46, 'सक्षम'),
(138147, 2070, 46, 'बिलिंग कोड आणि पैसे प्रविष्ट जुन्या शुल्क पॅनल सक्षम करते. शिफारस केलेली नाही, त्याऐवजी शुल्क पत्रक वापरा.'),
(138148, 2071, 46, 'Enc'),
(138149, 2072, 46, 'Encnter'),
(138150, 2073, 46, 'चकमकीत'),
(138151, 2074, 46, 'चकमकीत'),
(138152, 2075, 46, 'चकमकीत '),
(138153, 2076, 46, 'तीव्र रूग्णालयात दाखल करून घेतलेला रूग्ण किंवा ईडी आढळतात'),
(138154, 2080, 46, 'चकमकीत डेटा'),
(138155, 2081, 46, 'चकमकीत तारीख'),
(138156, 2084, 46, 'EDI रेकॉर्ड आढळतात'),
(138157, 2086, 46, 'चकमकीत अर्ज'),
(138158, 2087, 46, 'चकमकीत आरोग्य आणि वर्तन मूल्यांकन'),
(138159, 2088, 46, 'चकमकीत इतिहास'),
(138160, 2089, 46, 'चकमकीत आयडी'),
(138161, 2090, 46, 'चकमकीत इन्फ्लूएन्झा'),
(138162, 2091, 46, 'चकमकीत क्रमांक'),
(138163, 2093, 46, 'चकमकीत नर्सिंग स्त्राव'),
(138164, 2094, 46, 'चकमकीत नर्सिंग सुविधा'),
(138165, 2095, 46, 'व्यावसायिक थेरपी आढळतात'),
(138166, 2096, 46, 'चकमकीत कार्यालय भेट'),
(138167, 2097, 46, 'चकमकीत बाह्यरुग्ण विभागातील'),
(138168, 2098, 46, 'चकमकीत बाह्यरुग्ण विभागातील / PCP आणि obgyn वाईड'),
(138169, 2099, 46, 'चकमकीत पृष्ठ आकार'),
(138170, 2100, 46, 'चकमकीत भरणा'),
(138171, 2101, 46, 'चकमकीत गर्भधारणा'),
(138172, 2102, 46, 'प्रतिबंधात्मक औषध आढळतात - व्यक्तीगत सल्ला'),
(138173, 2103, 46, 'प्रतिबंधात्मक औषध आढळतात 40 आणि जुन्या'),
(138174, 2104, 46, 'प्रतिबंधात्मक औषध गट समुपदेशन आढळतात'),
(138175, 2105, 46, 'प्रतिबंधात्मक औषध इतर सेवा आढळतात'),
(138176, 2106, 46, 'आढळतात प्रतिबंधात्मक औषध सेवा 18 आणि त्यापेक्षा मोठ्या'),
(138177, 2107, 46, 'आढळतात मानसिक आणि psychologic');
INSERT INTO `lang_definitions` VALUES
(138178, 2108, 46, 'चकमकीत आकडेवारी'),
(138179, 2109, 46, 'चकमकीत सारांश'),
(138180, 2110, 46, 'चकमक कोड'),
(138181, 2111, 46, 'चकमकीत:'),
(138182, 2112, 46, 'चकमकीत: नॉन-तीव्र inpt, बाह्यरुग्ण विभागातील, किंवा डोळा व त्याला होणार्या रोगांचा अभ्यास आढळतात'),
(138183, 2113, 46, 'चकमकी'),
(138184, 2114, 46, 'चकमकी व नमुने'),
(138185, 2115, 46, 'चकमकी करा & amp; अर्ज'),
(138186, 2116, 46, 'अधिकृत नाही चकमकी'),
(138187, 2117, 46, 'चकमकी अहवाल'),
(138188, 2118, 46, 'चकमकी विभाग'),
(138189, 2120, 46, 'एनक्रिप्शन'),
(138190, 2121, 46, 'समाप्त'),
(138191, 2122, 46, 'शेवट पर्यंत (वर्ष-mm-dd या): '),
(138192, 2123, 46, 'शेवटची तारीख'),
(138193, 2124, 46, 'शेवटची तारीख'),
(138194, 2126, 46, 'अंतिम तारीख सुरू अधिक असावे'),
(138195, 2127, 46, 'समाप्ती तारीख:'),
(138196, 2130, 46, 'अहवालाच्या शेवटी'),
(138197, 2131, 46, 'समाप्त वेळ'),
(138198, 2132, 46, 'Employer`s गट योजना MCP मध्ये एंड-स्टेज रेनल रोग लाभार्थी'),
(138199, 2133, 46, 'सेवा वर्ष-mm-dd या शेवट तारीख'),
(138200, 2134, 46, 'आपण एक श्रेणी दाखल करण्यास इच्छा असेल तर डॉस मिमी / DD / YYYY समाप्ती'),
(138201, 2135, 46, 'कॅलेंडर कार्यक्रम दिवसाचा तास समाप्ती.'),
(138202, 2136, 46, 'ज्याआत असामान्य रक्त'),
(138203, 2137, 46, 'अंत: स्त्राव'),
(138204, 2138, 46, 'Endoscopy'),
(138205, 2141, 46, 'इंग्रजी'),
(138206, 2142, 46, 'इंग्रजी '),
(138207, 2143, 46, 'इंग्रजी (भारतीय)'),
(138208, 2144, 46, 'इंग्रजी (वी)'),
(138209, 2145, 46, 'Hylafax द्वारे वापरले Enscript आदेश.'),
(138210, 2146, 46, 'याची खात्री करा LibreEHR निर्देशिका विशेषाधिकार लिहा आहे'),
(138211, 2147, 46, 'ENT डिस्चार्ज'),
(138212, 2148, 46, 'ENT वेदना'),
(138213, 2149, 46, 'तो असलेले सर्व पावत्या वगळण्याची निदान कोड प्रविष्ट करा'),
(138214, 2150, 46, 'एक दुरुस्ती प्रविष्ट करा ...'),
(138215, 2151, 46, 'येथे पत्र शरीरात प्रवेश'),
(138216, 2152, 46, 'डाटाबेस रूट पासवर्ड प्रविष्ट करा'),
(138217, 2153, 46, 'डाटाबेस रूट वापरकर्तानाव प्रविष्ट करा'),
(138218, 2154, 46, 'निदान प्रविष्ट करा'),
(138219, 2155, 46, 'औषधे प्रविष्ट करा'),
(138220, 2156, 46, 'चकमकीत प्रविष्ट करा'),
(138221, 2157, 46, 'चकमकीत क्रमांक प्रविष्ट करा'),
(138222, 2158, 46, 'लसीकरण प्रविष्ट करा'),
(138223, 2159, 46, 'की प्रविष्ट करा'),
(138224, 2160, 46, 'नवीन डेटा प्रविष्ट करा'),
(138225, 2161, 46, 'नवीन राज्य प्रविष्ट करा'),
(138226, 2162, 46, 'प्राप्तकर्ता  ''चे थेट पत्ता प्रविष्ट करा'),
(138227, 2163, 46, 'या प्रक्रिया LOINC कोड प्रविष्ट करा'),
(138228, 2164, 46, 'पुन्हा ओळख कोड प्रविष्ट करा'),
(138229, 2165, 46, 'वरील आपल्या शोध मापदंड प्रविष्ट करा'),
(138230, 2166, 46, 'त्रुटी प्रविष्ट केला'),
(138231, 2167, 46, 'नोंदी'),
(138232, 2168, 46, 'पर्यावरण'),
(138233, 2169, 46, 'EOB डेटा प्रवेश'),
(138234, 2170, 46, 'EOB पोस्टिंग - इलेक्ट्रॉनिक व्यवहार'),
(138235, 2171, 46, 'EOB पोस्ट - सूचना'),
(138236, 2172, 46, 'EOB पोस्ट - चलन'),
(138237, 2173, 46, 'EOB पोस्टिंग - रुग्णांच्या टीप'),
(138238, 2174, 46, 'EOB पोस्ट - शोध'),
(138239, 2176, 46, 'अपस्मार'),
(138240, 2178, 46, 'ईआरए'),
(138241, 2179, 46, 'ईआरए फायली'),
(138242, 2180, 46, 'ईआरए पोस्ट'),
(138243, 2181, 46, 'पुसून टाका'),
(138244, 2182, 46, 'Erections'),
(138245, 2183, 46, 'त्रुटी'),
(138246, 2184, 46, 'चूक'),
(138247, 2185, 46, 'लॅब परिणाम त्रुटी खात्री पावती'),
(138248, 2187, 46, 'लॅब एक्सचेंज नेटवर्क त्रुटी मिळत लॅब परिणाम'),
(138249, 2188, 46, 'लिंग निवड त्रुटी'),
(138250, 2189, 46, 'HIPAA निवड त्रुटी'),
(138251, 2190, 46, 'प्रक्रिया निवड त्रुटी'),
(138252, 2191, 46, 'एसएमएस गेटवे निवड त्रुटी'),
(138253, 2192, 46, 'निवड "क्रमवारी लावा" मध्ये त्रुटी'),
(138254, 2193, 46, 'फाइल Gzip संक्षेप त्रुटी: '),
(138255, 2194, 46, 'होय कवा नाही पर्याय त्रुटी'),
(138256, 2195, 46, 'त्रुटी पहिल्या वाचन फाइल अपलोड'),
(138257, 2196, 46, 'प्रक्रिया करताना त्रुटी फाइल'),
(138258, 2197, 46, 'प्रक्रिया करताना त्रुटी अपलोड'),
(138259, 2198, 46, 'त्रुटी काढत संदेश'),
(138260, 2199, 46, 'लॅब एक्सचेंज नेटवर्क त्रुटी प्राप्त परिणाम'),
(138261, 2200, 46, 'मूल्ये पुनर्प्राप्त करताना त्रुटी.'),
(138262, 2201, 46, 'जतन करताना त्रुटी आली दस्तऐवज'),
(138263, 2202, 46, 'LibreEHR वापरकर्ता फाइल विशेषाधिकार मंजूर करताना त्रुटी.'),
(138264, 2205, 46, 'त्रुटी फॉर्म नोंदणी करताना!'),
(138265, 2206, 46, 'त्रुटी फाइल जतन करताना'),
(138266, 2208, 46, 'दाखल लिहित असताना त्रुटी'),
(138267, 2209, 46, 'त्रुटी (चे) नवीन परिणाम पासून आली'),
(138268, 2210, 46, 'त्रुटी, फाइल अस्तित्वात नाही'),
(138269, 2211, 46, 'सर्व्हर डेटा गोळा करण्यासाठी त्रुटी अक्षम आहोत,'),
(138270, 2212, 46, 'त्रुटी, क्लायंट प्रमाणपत्र तयार करण्यात अक्षम.'),
(138271, 2213, 46, 'त्रुटी, admin.p12 प्रमाणपत्र तयार करण्यात अक्षम.'),
(138272, 2214, 46, 'त्रुटी, प्रमाणपत्र तयार करण्यात अक्षम.'),
(138273, 2215, 46, 'त्रुटी, सर्व्हर प्रमाणपत्र तयार करण्यात अक्षम.'),
(138274, 2216, 46, 'फाइल उघडू शकत नाही त्रुटी,'),
(138275, 2217, 46, 'त्रुटी, वापरकर्ता प्रमाणपत्र प्रमाणीकरण LibreEHR सक्षम नाही'),
(138276, 2218, 46, 'त्रुटी. आपण संग्रहण / Tar.php PHP विभाग स्थापित करणे आवश्यक आहे.'),
(138277, 2219, 46, 'त्रुटी: table.sql, तुटलेली फॉर्म उघडू शकत नाही?'),
(138278, 2220, 46, 'त्रुटी: ओळीवर आयडी डुप्लीकेट'),
(138279, 2221, 46, 'त्रुटी: ओळीवर डुप्लीकेट नाव'),
(138280, 2222, 46, 'त्रुटी: फील्ड'),
(138281, 2223, 46, 'त्रुटी: ZipArchive कृपया PHP विभाग गहाळ'),
(138282, 2224, 46, 'त्रुटी: नाही ICD आयात डिरेक्ट्री.'),
(138283, 2225, 46, 'त्रुटी: पासवर्ड जुळत नाही. आपल्या टाइपिंग तपासा.'),
(138284, 2226, 46, 'त्रुटी: डॉन  ''टी सामना संकेतशब्द. आपल्या टाइपिंग तपासा.'),
(138285, 2227, 46, 'त्रुटी: फाइल अस्तित्वात नाही'),
(138286, 2228, 46, 'त्रुटी: खालील चल अवैध वर्ण आहेत'),
(138287, 2229, 46, 'त्रुटी: फाइल कॉपी करण्यास अक्षम.'),
(138288, 2230, 46, 'त्रुटी: डाउनलोड संग्रहण तयार करण्यास अक्षम'),
(138289, 2231, 46, 'त्रुटी: Zip संग्रहण तयार करण्यास अक्षम.'),
(138290, 2232, 46, 'त्रुटी: फाइल काढू अक्षम.'),
(138291, 2233, 46, 'त्रुटी: डेटाबेस मध्ये फाइल लोड करण्यात अक्षम.'),
(138292, 2234, 46, 'त्रुटी: आवृत्ती क्रमांक सेट करण्यास अक्षम.'),
(138293, 2235, 46, 'चुका'),
(138294, 2236, 46, 'eRx खाते स्थिती'),
(138295, 2237, 46, 'eRx नोंदी'),
(138296, 2238, 46, 'ERX नाव'),
(138297, 2239, 46, 'ERX पासवर्ड'),
(138298, 2240, 46, 'ERX भूमिका'),
(138299, 2241, 46, 'ERX वापरकर्ता'),
(138300, 2242, 46, 'Erythema:'),
(138301, 2243, 46, 'eSign'),
(138302, 2244, 46, 'eSign लॉग'),
(138303, 2245, 46, 'एस्किमो जातीचे'),
(138304, 2246, 46, 'मुद्दाम तयार केलेली भाषा'),
(138305, 2247, 46, 'स्थापना रुग्णांच्या'),
(138306, 2248, 46, 'एस्टोनियन'),
(138307, 2249, 46, 'वांशिक'),
(138308, 2250, 46, 'वांशिक किंवा शर्यत'),
(138309, 2251, 46, 'वांशिक-शर्यत यादी (addonly पर्यायी, लिहा)'),
(138310, 2252, 46, 'ETIN'),
(138311, 2253, 46, 'कार्यक्रम'),
(138312, 2254, 46, 'कार्यक्रम लागतो'),
(138313, 2255, 46, 'कार्यक्रम वर्ग'),
(138314, 2256, 46, 'कार्यक्रम तारीख'),
(138315, 2257, 46, 'इव्हेंट वर्णन'),
(138316, 2258, 46, 'कार्यक्रम तपशील'),
(138317, 2259, 46, 'कार्यक्रमाची पुनरावृत्ती होत नाही'),
(138318, 2260, 46, 'कार्यक्रम कालावधी'),
(138319, 2261, 46, 'मिनिटांत कार्यक्रम कालावधी'),
(138320, 2262, 46, 'कार्यक्रम शुल्क'),
(138321, 2263, 46, 'कार्यक्रम स्थान'),
(138322, 2264, 46, 'कार्यक्रम प्रत्येक पुनरावृत्ती'),
(138323, 2265, 46, 'कार्यक्रम पुनरावृत्ती'),
(138324, 2266, 46, 'कार्यक्रम सुरू होण्याची वेळ'),
(138325, 2267, 46, 'कार्यक्रम शीर्षक'),
(138326, 2268, 46, 'कार्यक्रम शीर्षक'),
(138327, 2269, 46, 'कार्यक्रम वेबसाइट'),
(138328, 2270, 46, 'आगामी कार्यक्रम'),
(138329, 2271, 46, 'इव्हेंट'),
(138330, 2272, 46, 'नवीन विंडोमध्ये उघडा आगामी कार्यक्रम'),
(138331, 2273, 46, 'प्रत्येक'),
(138332, 2274, 46, 'प्रत्येक'),
(138333, 2275, 46, 'प्रत्येक 3 तास'),
(138334, 2276, 46, 'दर 4 तास'),
(138335, 2277, 46, 'प्रत्येक 5 तास'),
(138336, 2278, 46, 'प्रत्येक 6 तास'),
(138337, 2279, 46, 'प्रत्येक 8 तास'),
(138338, 2280, 46, 'प्रत्येक चौथ्या'),
(138339, 2281, 46, 'प्रत्येक इतर'),
(138340, 2282, 46, 'प्रत्येक तिसरा'),
(138341, 2283, 46, 'प्रत्येक, प्रत्येक इतर, प्रत्येक 3, इ'),
(138342, 2284, 46, 'यू'),
(138343, 2285, 46, 'परीक्षा व परीक्षा परिणाम'),
(138344, 2286, 46, 'परीक्षा, त्यांचे निकाल'),
(138345, 2289, 46, 'परीक्षा'),
(138346, 2290, 46, 'परीक्षा दिनांक'),
(138347, 2291, 46, 'उदाहरण'),
(138348, 2292, 46, 'उदाहरणे'),
(138349, 2293, 46, 'परीक्षा / कसोटी'),
(138350, 2294, 46, 'वगळता'),
(138351, 2295, 46, 'अति जोराचा'),
(138352, 2296, 46, 'वगळलेले रुग्णांना'),
(138353, 2297, 46, 'वर्जित'),
(138354, 2298, 46, 'विशेष प्रदाता संघटना (EPO जर)'),
(138355, 2299, 46, 'कार्यकारी कागद आकार'),
(138356, 2300, 46, 'व्यायाम'),
(138357, 2301, 46, 'व्यायाम नमुने'),
(138358, 2302, 46, 'व्यायाम नमुन्यांची'),
(138359, 2303, 46, 'अस्तित्वात'),
(138360, 2304, 46, 'प्रशासन पासून बाहेर पडा'),
(138361, 2305, 46, 'कालबाह्य'),
(138362, 2306, 46, 'विस्तृत करा'),
(138363, 2307, 46, 'विस्तृत'),
(138364, 2308, 46, 'सर्व विस्तृत करा'),
(138365, 2311, 46, 'विस्तृत दृश्य'),
(138366, 2312, 46, 'असल्याचे form_encounter.pid अपेक्षा '),
(138367, 2313, 46, 'समाप्ती'),
(138368, 2314, 46, 'कालावधी समाप्ती तारीख'),
(138369, 2315, 46, 'कालबाह्य होईल'),
(138370, 2316, 46, 'कालबाह्य'),
(138371, 2317, 46, 'निर्यात'),
(138372, 2318, 46, 'सी म्हणून निर्यात'),
(138373, 2319, 46, 'निर्यात संरचना'),
(138374, 2322, 46, 'निर्यात रुग्णांच्या लोकसंख्याशास्त्र'),
(138375, 2323, 46, 'निर्यात PQRI अहवाल'),
(138376, 2325, 46, 'निर्यात सी निवडलेले'),
(138377, 2326, 46, 'निर्यात संग्रह निवडलेला'),
(138378, 2327, 46, 'सी निर्यात'),
(138379, 2328, 46, 'बाह्य बिलिंग प्रणाली निर्यात'),
(138380, 2329, 46, 'विदेशी देश प्रदर्शनासह'),
(138381, 2330, 46, 'परदेशी झेप'),
(138382, 2331, 46, 'क्रमांक वेळ गोळा'),
(138383, 2332, 46, 'बाह्य'),
(138384, 2334, 46, 'बाह्य डेटा लोड'),
(138385, 2335, 46, 'बाह्य डेटाबेस आयात उपयुक्तता'),
(138386, 2336, 46, 'बाह्य आयडी'),
(138387, 2337, 46, 'बाह्य आयडी'),
(138388, 2338, 46, 'बाह्य अभिज्ञापक'),
(138389, 2339, 46, 'बाह्य फक्त'),
(138390, 2342, 46, 'बाह्य रेफरल'),
(138391, 2343, 46, 'बाह्य रेफरल Followups'),
(138392, 2344, 46, 'बाह्य संदर्भ?'),
(138393, 2345, 46, 'बाह्य संदर्भ'),
(138394, 2346, 46, 'Zip फाइल प्राप्त'),
(138395, 2347, 46, 'फाइल अवतरण. हे काही वेळ लागेल ...'),
(138396, 2348, 46, 'Exudate:'),
(138397, 2349, 46, 'नेत्र चिडचिड'),
(138398, 2350, 46, 'नेत्र वेदना'),
(138399, 2351, 46, 'नेत्र लालसरपणा'),
(138400, 2352, 46, 'डोळे'),
(138401, 2353, 46, 'परवेझ'),
(138402, 2354, 46, 'एफ / एच रक्त समस्या'),
(138403, 2355, 46, 'एफ / एच स्त्री अतिशय केसाळपणा मुख्यत: स्त्रियांमध्ये / Striae'),
(138404, 2356, 46, 'सुविधा'),
(138405, 2357, 46, 'सुविधा'),
(138406, 2358, 46, 'सुविधा'),
(138407, 2359, 46, 'सुविधा प्रशासन'),
(138408, 2360, 46, 'सुविधा शहर'),
(138409, 2361, 46, 'सुविधा कोड'),
(138410, 2362, 46, 'सुविधा देश कोड'),
(138411, 2363, 46, 'सुविधा फॅक्स'),
(138412, 2364, 46, 'सुविधा नाव'),
(138413, 2365, 46, 'सुविधा NPI'),
(138414, 2366, 46, 'सुविधा फोन'),
(138415, 2367, 46, 'सुविधा विशिष्ट वापरकर्ता माहिती'),
(138416, 2368, 46, 'सुविधा राज्य'),
(138417, 2369, 46, 'सुविधा स्ट्रीट'),
(138418, 2370, 46, 'सुविधा पिन'),
(138419, 2372, 46, 'सुविधा:'),
(138420, 2373, 46, 'अयशस्वी'),
(138421, 2374, 46, 'अयशस्वी'),
(138422, 2375, 46, 'अयशस्वी'),
(138423, 2376, 46, 'अयशस्वी रुग्णांना'),
(138424, 2377, 46, 'पोर्टल रुग्णाच्या जोडण्यात अयशस्वी'),
(138425, 2378, 46, 'एक अद्वितीय फाइलनाव मोजणी करण्यासाठी अयशस्वी'),
(138426, 2379, 46, 'तयार करण्यात अयशस्वी'),
(138427, 2380, 46, 'तात्पुरती फोल्डर तयार करण्यात अयशस्वी. CouchDB कार्य करणार नाही.'),
(138428, 2382, 46, 'अयशस्वी.'),
(138429, 2383, 46, 'अपयश'),
(138430, 2384, 46, 'अयशस्वी'),
(138431, 2385, 46, 'अयशस्वी सूचना: थेट संदेश पाठविणे अयशस्वी झाले.'),
(138432, 2390, 46, 'कौटुंबिक इतिहास'),
(138433, 2391, 46, 'काचबिंदू कौटुंबिक इतिहास'),
(138434, 2392, 46, 'कौटुंबिक इतिहास:'),
(138435, 2394, 46, 'कौटुंबिक भरणा'),
(138436, 2395, 46, 'कौटुंबिक आकार'),
(138437, 2396, 46, 'फॅन्सी'),
(138438, 2397, 46, 'फारसी Name'),
(138439, 2398, 46, 'फारसी'),
(138440, 2400, 46, 'पिता'),
(138441, 2401, 46, 'पूर्वजांचा इतिहास'),
(138442, 2402, 46, 'थकवा'),
(138443, 2403, 46, 'थकणे'),
(138444, 2404, 46, 'फॅक्स'),
(138445, 2405, 46, 'फॅक्स संख्या'),
(138446, 2406, 46, 'फॅक्स क्रमांक'),
(138447, 2408, 46, 'फॅक्स / स्कॅन'),
(138448, 2409, 46, 'फॅक्स मध्ये'),
(138449, 2410, 46, 'फॅक्स आउट'),
(138450, 2411, 46, 'वैशिष्ट्ये'),
(138451, 2412, 46, 'फेब्रुवारी'),
(138452, 2413, 46, 'फेब्रुवारी'),
(138453, 2414, 46, 'ECA च्या'),
(138454, 2415, 46, 'फेडरल ड्रग आयडी'),
(138455, 2416, 46, 'फेडरल EIN'),
(138456, 2417, 46, 'फेडरल टॅक्स ID'),
(138457, 2418, 46, 'शुल्क'),
(138458, 2419, 46, 'फी'),
(138459, 2420, 46, 'फी परवानगी नाही'),
(138460, 2421, 46, 'फी पत्रक'),
(138461, 2422, 46, 'फी पत्रक पर्याय'),
(138462, 2423, 46, 'शुल्क'),
(138463, 2424, 46, 'स्त्री'),
(138464, 2425, 46, 'स्त्री एपी'),
(138465, 2426, 46, 'स्त्री कंडोम'),
(138466, 2427, 46, 'स्त्री जी'),
(138467, 2428, 46, 'स्त्री एलसी'),
(138468, 2429, 46, 'स्त्री पी'),
(138469, 2430, 46, 'स्त्री लक्षणे'),
(138470, 2431, 46, 'स्त्री VSC'),
(138471, 2432, 46, 'प्राप्त'),
(138472, 2433, 46, 'पोर्टल खालील फाइल प्राप्त'),
(138473, 2434, 46, 'ताप'),
(138474, 2435, 46, 'ताप:'),
(138475, 2436, 46, 'FH रक्त समस्या'),
(138476, 2437, 46, 'Fibroids'),
(138477, 2438, 46, 'फील्ड'),
(138478, 2439, 46, 'फील्ड ''नाव'' निरर्थक असू शकत नाही'),
(138479, 2441, 46, 'फील्ड प्रकार लोकसंख्याशास्त्र मध्ये नियोक्ता किंवा ग्राहक देश वापरा.'),
(138480, 2442, 46, 'फील्ड प्रकार लोकसंख्याशास्त्र मध्ये नियोक्ता किंवा ग्राहक राज्य वापरा.'),
(138481, 2443, 46, 'फील्ड (चे) गहाळ आहेत!'),
(138482, 2446, 46, 'फिजीचा'),
(138483, 2447, 46, 'फाइल'),
(138484, 2448, 46, 'दस्तऐवजीकरण डिरेक्टरी मध्ये फाइल लॉग बॅकअप तयार करण्याची प्रक्रिया स्वयंचलित कसे जाणून घेण्यासाठी'),
(138485, 2449, 46, 'फाइल स्थान'),
(138486, 2450, 46, 'फाइल व्यवस्थापन'),
(138487, 2453, 46, 'फाइल विशेषाधिकार LibreEHR वापरकर्ता मंजूर.'),
(138488, 2454, 46, 'CouchDB फाइल भरपाई अयशस्वी'),
(138489, 2455, 46, 'फाइल कक्ष'),
(138490, 2456, 46, 'अपलोड फाइल'),
(138491, 2457, 46, 'अपलोड करण्यासाठी फाइल'),
(138492, 2458, 46, 'याच नावाचा फाइल आधिपासूनच स्थान अस्तित्वात नाही:'),
(138493, 2459, 46, 'फाइलनाव'),
(138494, 2460, 46, 'फाइलनाव ".pdf" समाप्त करणे आवश्यक आहे'),
(138495, 2461, 46, 'फायली'),
(138496, 2462, 46, 'फिलिपिनो'),
(138497, 2463, 46, 'खाली पंक्ती कोणत्याही भरा.'),
(138498, 2464, 46, 'फक्त तर रुग्णांना-मेल सूचना पाठवणे येथे भरा'),
(138499, 2465, 46, 'खाली मूल्ये भरा'),
(138500, 2467, 46, 'रो भरा.'),
(138501, 2468, 46, 'फिल्टर'),
(138502, 2469, 46, 'स्थिर फिल्टर'),
(138503, 2470, 46, 'व्याख्या फिल्टर'),
(138504, 2471, 46, 'पासून फिल्टर'),
(138505, 2472, 46, 'फिल्टर'),
(138506, 2473, 46, 'फिल्टर'),
(138507, 2474, 46, 'अंतिम'),
(138508, 2475, 46, 'अंतिम निदान'),
(138509, 2476, 46, 'तज्ञांना अंतिम निदान'),
(138510, 2478, 46, 'आर्थिक'),
(138511, 2479, 46, 'आर्थिक बंद तारीख (वर्ष-mm-dd या)'),
(138512, 2480, 46, 'आर्थिक अहवाल - काहीही'),
(138513, 2481, 46, 'आर्थिक अहवाल - माझ्या चकमकी'),
(138514, 2482, 46, 'आर्थिक समीक्षा तारीख'),
(138515, 2483, 46, 'सेवा कोड वित्तीय सारांश'),
(138516, 2484, 46, 'शोधा'),
(138517, 2485, 46, 'उपलब्ध शोधा'),
(138518, 2486, 46, 'उपलब्ध नियुक्ती शोधा'),
(138519, 2487, 46, 'रुग्णांच्या शोधा'),
(138520, 2488, 46, 'रुग्णांच्या शिक्षण सामुग्री शोधा'),
(138521, 2489, 46, 'परिणाम'),
(138522, 2490, 46, 'तज्ञांना करून परिणाम'),
(138523, 2491, 46, 'ललित'),
(138524, 2492, 46, 'समाप्त देयके'),
(138525, 2493, 46, 'पूर्ण'),
(138526, 2494, 46, 'फिन्निश'),
(138527, 2495, 46, 'प्रथम'),
(138528, 2497, 46, 'आठवड्याच्या पहिल्या दिवशी'),
(138529, 2498, 46, 'पहिले नाव'),
(138530, 2499, 46, 'पहिले नाव'),
(138531, 2500, 46, 'पहिले नाव:'),
(138532, 2501, 46, 'प्रथम भेट द्या किंवा सल्ला'),
(138533, 2502, 46, 'नाव आडनाव'),
(138534, 2503, 46, 'फिटनेस'),
(138535, 2504, 46, 'फिटनेस स्तर'),
(138536, 2505, 46, 'आज या खेळाडू तंदुरुस्ती'),
(138537, 2506, 46, 'फिटनेस चाचणी'),
(138538, 2507, 46, 'फिटनेस खेळावे'),
(138539, 2508, 46, 'चकमकीत तारखा निराकरण - कोणत्याही चकमकी'),
(138540, 2509, 46, 'या निराकरण'),
(138541, 2510, 46, 'फ्लोरिडा'),
(138542, 2511, 46, 'फुशारकी'),
(138543, 2512, 46, 'फ्लो'),
(138544, 2514, 46, 'फ्लू हंगामात'),
(138545, 2515, 46, 'फ्लू सीझन'),
(138546, 2516, 46, 'फ्लू लसीकरण'),
(138547, 2517, 46, 'द्रवपदार्थ आणि इलेक्ट्रोलाइट्सचे समस्या'),
(138548, 2518, 46, 'FMS'),
(138549, 2519, 46, 'फोलिओ कागद आकार'),
(138550, 2520, 46, 'स्वतः अनुसरण करा'),
(138551, 2521, 46, 'प्रतिष्ठापन किंवा खालील डेटाबेस सुधारणा या सूचनांचे पालन करा'),
(138552, 2522, 46, 'पाठपुरावा'),
(138553, 2524, 46, 'कारण पाठपुरावा'),
(138554, 2525, 46, 'खालील नवीन सानुकूल स्थिर आहे:'),
(138555, 2526, 46, 'खालील नवीन सानुकूल भाषा:'),
(138556, 2527, 46, 'नवीन व्याख्या (भाषा, सतत, डेफिनेशन) खालीलप्रमाणे आहे:'),
(138557, 2528, 46, 'ऑडिट लॉग मध्ये खालील ओळी बदल केले गेले आहेत'),
(138558, 2529, 46, 'फॉलोअप सेवा'),
(138559, 2530, 46, 'Followups दशर्िवले'),
(138560, 2531, 46, 'अन्न सहन न होणे'),
(138561, 2532, 46, 'पाऊल'),
(138562, 2533, 46, 'पाऊल समस्या'),
(138563, 2534, 46, 'पाऊल:'),
(138564, 2535, 46, 'फुटबॉल दुखापती'),
(138565, 2536, 46, 'फुटबॉल इजा'),
(138566, 2537, 46, 'फुटबॉल इजा अहवाल'),
(138567, 2538, 46, 'पादत्राणे प्रकार'),
(138568, 2539, 46, 'साठी'),
(138569, 2540, 46, 'साठी'),
(138570, 2541, 46, 'कोड साठी'),
(138571, 2543, 46, 'चकमकीत दावे साठी'),
(138572, 2544, 46, 'उदाहरणार्थ:'),
(138573, 2545, 46, 'HCFA 02/12 बॉक्स 15 तारीख सूचित करते काय निर्देशीत करण्यासाठी पात्रता अन्य तारीख आहे'),
(138574, 2546, 46, 'चकमकीत वर निर्दिष्ट HCFA 02/12 दिसायला लागायच्या तारीख फॉर्म पात्रता आवश्यक आहे'),
(138575, 2547, 46, 'चलन साठी'),
(138576, 2548, 46, 'फक्त वैद्यकीय साठी, प्रस्तुत प्रदाता समान असल्याचे संदर्भ प्रदाता सक्ती.'),
(138577, 2549, 46, 'OBR placer ऑर्डर संख्या'),
(138578, 2550, 46, 'रुग्णाला'),
(138579, 2552, 46, 'उल्लेख संघटना / चिकित्सक साठी'),
(138580, 2553, 46, 'गेल्या'),
(138581, 2554, 46, 'चल साठी'),
(138582, 2555, 46, 'साठी:'),
(138583, 2556, 46, 'फोर्स बिलिंग विजेट ओपन'),
(138584, 2557, 46, 'फोर्स नवीन रुग्णांच्या तयार करा'),
(138585, 2558, 46, 'फोर्स दर्शवा'),
(138586, 2559, 46, 'आधीच सज्ज'),
(138587, 2560, 46, 'फॉर्म'),
(138588, 2561, 46, 'फॉर्म'),
(138589, 2562, 46, 'फॉर्म घटक आढळले नाही'),
(138590, 2563, 46, 'फॉर्म यशस्वीरित्या साइन इन'),
(138591, 2564, 46, 'स्वरूप'),
(138592, 2565, 46, 'स्वरूप'),
(138593, 2566, 46, 'वय प्रदर्शन स्वरूप'),
(138594, 2567, 46, 'एनडीसी साठी अयोग्य स्वरूपात'),
(138595, 2568, 46, 'स्वरूप सर्वात तारखा प्रदर्शित करण्यासाठी वापरली.'),
(138596, 2569, 46, 'स्वरूप सर्वात वेळा प्रदर्शित करण्यासाठी वापरली.'),
(138597, 2570, 46, 'रूपण अहवाल'),
(138598, 2571, 46, 'माजी धूम्रपान'),
(138599, 2572, 46, 'अर्ज'),
(138600, 2573, 46, 'अर्ज प्रशासन'),
(138601, 2575, 46, 'पुढे'),
(138602, 2576, 46, 'फॅक्स द्वारे फॉरवर्ड पृष्ठे'),
(138603, 2577, 46, 'अग्रेषित'),
(138604, 2579, 46, 'चौथ्या'),
(138605, 2581, 46, 'फ्रॅक्चर'),
(138606, 2582, 46, 'Navicula येथे फ्रॅक्चर'),
(138607, 2583, 46, 'फ्रॅक्चर बाजूकडील घोटा'),
(138608, 2584, 46, 'फ्रॅक्चर सरासरीचा घोटा'),
(138609, 2585, 46, 'फ्रॅक्चर पाचव्या (5) पायाभूत पायाचा घोटा व पायाची बोटे जोडणार्या पाच अस्थीपैकी एक'),
(138610, 2586, 46, 'फ्रेम समर्थन आवश्यक'),
(138611, 2587, 46, 'फ्रेंच'),
(138612, 2588, 46, 'फ्रेंच (कॅनेडियन)'),
(138613, 2589, 46, 'फ्रेंच (मानक)'),
(138614, 2590, 46, 'वारंवारता'),
(138615, 2591, 46, 'वारंवार सर्दी'),
(138616, 2592, 46, 'वारंवार आजार'),
(138617, 2593, 46, 'शुक्र'),
(138618, 2594, 46, 'शुक्रवारी'),
(138619, 2595, 46, 'पासून'),
(138620, 2596, 46, 'मधून'),
(138621, 2597, 46, 'पासून'),
(138622, 2598, 46, 'तारीख दिनांक करण्यासाठी पेक्षा जास्त होऊ शकत नाही.'),
(138623, 2599, 46, 'पासून:'),
(138624, 2600, 46, 'पासून: '),
(138625, 2601, 46, 'FROM_CITY'),
(138626, 2602, 46, 'FROM_EMAIL'),
(138627, 2603, 46, 'FROM_FNAME'),
(138628, 2604, 46, 'FROM_LNAME'),
(138629, 2605, 46, 'FROM_MNAME'),
(138630, 2606, 46, 'FROM_PHONE'),
(138631, 2607, 46, 'FROM_PHONECELL'),
(138632, 2608, 46, 'FROM_POSTAL'),
(138633, 2609, 46, 'FROM_STATE'),
(138634, 2610, 46, 'FROM_STREET'),
(138635, 2611, 46, 'FROM_TITLE'),
(138636, 2612, 46, 'FROM_VALEDICTORY'),
(138637, 2613, 46, 'एकही कार्यालय'),
(138638, 2614, 46, 'एकही कार्यालय पावत्या'),
(138639, 2615, 46, 'एकही कार्यालय पावत्या अहवाल'),
(138640, 2616, 46, 'फ्रंट ''आरईसी'''),
(138641, 2617, 46, 'पुढचा अधिकार:'),
(138642, 2618, 46, 'Fula- Fulah- Pulaar- Pular'),
(138643, 2619, 46, 'पूर्ण नाव'),
(138644, 2620, 46, ', MySQL चालविण्याजोगी एक्जीक्यूटेबलच्या संचयीकाचे मार्ग पूर्ण.'),
(138645, 2621, 46, 'पर्ल चालविण्याजोगी एक्जीक्यूटेबलच्या संचयीकाचे मार्ग पूर्ण.'),
(138646, 2622, 46, 'घटना लॉग बॅकअप साठी निर्देशिका पूर्ण मार्ग.'),
(138647, 2623, 46, 'तात्पुरत्या फाइलकरीता वापरलेल्या निर्देशिका पूर्ण मार्ग.'),
(138648, 2624, 46, 'पूर्ण प्ले'),
(138649, 2625, 46, 'पूर्ण प्रशिक्षण'),
(138650, 2626, 46, 'पूर्णपणे अदा'),
(138651, 2631, 46, 'भविष्यातील'),
(138652, 2633, 46, 'जी'),
(138653, 2634, 46, 'जी / एल'),
(138654, 2635, 46, 'गॅलिशियन'),
(138655, 2636, 46, 'पित्त मूत्राशय अट'),
(138656, 2637, 46, 'पित्त दगड'),
(138657, 2638, 46, 'गेम कालावधी'),
(138658, 2639, 46, 'खेळ'),
(138659, 2640, 46, 'खेळ मिस'),
(138660, 2641, 46, 'खेळ / कार्यक्रम'),
(138661, 2642, 46, 'खेळ / आगामी कार्यक्रम मिस'),
(138662, 2643, 46, 'गांडा'),
(138663, 2644, 46, 'जठराची सूज'),
(138664, 2645, 46, 'पोटासंबंधी वेदना'),
(138665, 2646, 46, 'लैंगिकदृष्ट्या कार्यशील'),
(138666, 2647, 46, 'GCAC सांख्यिकी अहवाल'),
(138667, 2648, 46, 'GCAC आकडेवारी'),
(138668, 2649, 46, 'GCAC भेट फॉर्म गहाळ आहे'),
(138669, 2650, 46, 'लिंग'),
(138670, 2651, 46, 'लिंग '),
(138671, 2652, 46, 'सामान्य'),
(138672, 2653, 46, 'सामान्य समस्या सूची'),
(138673, 2655, 46, 'सामान्य सेवा वर्ग'),
(138674, 2656, 46, 'व्युत्पन्न'),
(138675, 2657, 46, 'व्युत्पन्न व CMS 1500 कागद दावे डाउनलोड'),
(138676, 2658, 46, 'व्युत्पन्न आणि HCFA 1500 कागद दावे डाउनलोड'),
(138677, 2659, 46, 'व्युत्पन्न आणि X12 बॅच डाउनलोड'),
(138678, 2660, 46, 'व्युत्पन्न आणि X12 चकमकीत हक्क बॅच डाउनलोड'),
(138679, 2663, 46, 'व्युत्पन्न आणि इलेक्ट्रॉनिक परवानगी चांगले प्रसारित.'),
(138680, 2664, 46, '1500 सीएमएस व्युत्पन्न'),
(138681, 2665, 46, 'सीएमएस 1500 पीडीएफ व्युत्पन्न'),
(138682, 2666, 46, 'सीएमएस 1500 मजकूर व्युत्पन्न'),
(138683, 2667, 46, 'HCFA व्युत्पन्न'),
(138684, 2668, 46, 'चलन व्युत्पन्न'),
(138685, 2669, 46, 'पत्र व्युत्पन्न'),
(138686, 2670, 46, 'पत्र संबंधित व्युत्पन्न '),
(138687, 2671, 46, 'PQRI अहवाल व्युत्पन्न (पद्धत अ)'),
(138688, 2672, 46, 'PQRI अहवाल (पद्धत अ) व्युत्पन्न करा - 2011'),
(138689, 2673, 46, 'PQRI अहवाल व्युत्पन्न (पद्धत इ)'),
(138690, 2674, 46, 'PQRI अहवाल (पद्धत इ) व्युत्पन्न करा - 2011'),
(138691, 2677, 46, 'अहवाल व्युत्पन्न'),
(138692, 2678, 46, 'वापरकर्तानाव आणि संकेतशब्द व्युत्पन्न'),
(138693, 2679, 46, 'X12 व्युत्पन्न'),
(138694, 2680, 46, 'X12 चकमकीत व्युत्पन्न'),
(138695, 2682, 46, 'वर व्युत्पन्न'),
(138696, 2683, 46, 'निर्माण'),
(138697, 2684, 46, 'जननेंद्रिये व मूत्रमार्ग या दोन्हीशी संबंधित मूत्रजननमार्गसंबंधी'),
(138698, 2686, 46, 'जॉर्जियन'),
(138699, 2687, 46, 'जर्मन'),
(138700, 2691, 46, 'HL7 मिळवा'),
(138701, 2692, 46, 'काचबिंदू'),
(138702, 2693, 46, 'काचबिंदू कौटुंबिक इतिहास'),
(138703, 2694, 46, 'ग्लोबल'),
(138704, 2696, 46, 'ग्लोबल आयडी'),
(138705, 2697, 46, 'ग्लोबल सेटिंग्ज'),
(138706, 2698, 46, 'ग्लोबल'),
(138707, 2699, 46, 'जीएम / डॅनिअल'),
(138708, 2700, 46, 'जा'),
(138709, 2701, 46, 'जा'),
(138710, 2704, 46, 'जा'),
(138711, 2705, 46, 'या आठवड्यात जा'),
(138712, 2706, 46, 'आज जा'),
(138713, 2707, 46, 'लक्ष्य एक'),
(138714, 2708, 46, 'ध्येय आणि पद्धती'),
(138715, 2709, 46, 'लक्ष्य ब'),
(138716, 2710, 46, 'लक्ष्य सी'),
(138717, 2711, 46, 'इजा झाली ग्रेड'),
(138718, 2712, 46, 'श्रेणी:'),
(138719, 2713, 46, 'ग्रॅम'),
(138720, 2714, 46, 'एकूण'),
(138721, 2715, 46, 'ग्रँड बेरजा'),
(138722, 2718, 46, 'Graphable'),
(138723, 2720, 46, 'या पेक्षा मोठे'),
(138724, 2721, 46, 'या पेक्षा मोठे किंवा समान'),
(138725, 2722, 46, 'ग्रीक'),
(138726, 2723, 46, 'ग्रीक, आधुनिक'),
(138727, 2724, 46, 'गट'),
(138728, 2725, 46, 'गट नाव'),
(138729, 2726, 46, 'गट नावे रिक्त असू शकत नाही'),
(138730, 2727, 46, 'गट नावे नंबर किंवा मोकळी जागा सुरू करू शकत नाही.'),
(138731, 2728, 46, 'गट नाव नंबर सुरू करू शकत नाही.'),
(138732, 2729, 46, 'गट क्रमांक'),
(138733, 2730, 46, 'गट भरणा'),
(138734, 2731, 46, 'गट:'),
(138735, 2732, 46, 'GROUPNAME'),
(138736, 2733, 46, 'गट आणि प्रवेश नियंत्रण'),
(138737, 2734, 46, 'वाढ चार्ट'),
(138738, 2735, 46, 'वाढ-चार्ट'),
(138739, 2736, 46, 'gtts (थेंब)'),
(138740, 2737, 46, 'Guamanian'),
(138741, 2738, 46, 'गुआरानी'),
(138742, 2739, 46, 'पालक नाव'),
(138743, 2740, 46, 'गुजराती'),
(138744, 2741, 46, 'Gynecological परीक्षा'),
(138745, 2742, 46, 'ह'),
(138746, 2743, 46, 'h.s.'),
(138747, 2744, 46, 'एच / ओ हिपॅटायटीस'),
(138748, 2745, 46, 'यशस्वीरित्या हटविण्यात आले होते. कोणत्याही उप-विभाग उपस्थित असल्यास, खालील हलविले गेले'),
(138749, 2746, 46, 'Haematoma / थकवा'),
(138750, 2747, 46, 'है स्थिती'),
(138751, 2748, 46, 'Haitian- हैतीयन क्रेओल'),
(138752, 2750, 46, 'हाताचा + बोटांनी'),
(138753, 2751, 46, 'हाताचा समस्या'),
(138754, 2752, 46, 'हार्ड डिस्क'),
(138755, 2753, 46, '/ O वाईड दु: ख'),
(138756, 2754, 46, 'भेट दुवा साधला गेला आहे'),
(138757, 2755, 46, 'कालबाह्य झाले आहे'),
(138758, 2756, 46, 'हॅश'),
(138759, 2757, 46, 'हॅश या फाइल अस्तित्वात नाही. एक नवीन हॅश निर्माण झाले.'),
(138760, 2758, 46, 'हॅश जुळत नाही. डेटा तडजोड केली गेली आहे.'),
(138761, 2759, 46, 'हौसा'),
(138762, 2760, 46, 'हवाईयन'),
(138763, 2761, 46, 'घातक उपक्रम'),
(138764, 2762, 46, 'घातक उपक्रम'),
(138765, 2763, 46, 'HCFA गुण फरकाने बाकी'),
(138766, 2764, 46, 'HCFA समास'),
(138767, 2765, 46, 'गुण HCFA शीर्ष समास'),
(138768, 2766, 46, 'HCPCS प्रक्रिया / सेवा'),
(138769, 2767, 46, 'तो PostCalendar '),
(138770, 2768, 46, 'मुख्य'),
(138771, 2769, 46, 'डोके CIRC'),
(138772, 2770, 46, 'डोक्याचा घेर'),
(138773, 2771, 46, 'डोकेदुखी'),
(138774, 2772, 46, 'डोकेदुखी'),
(138775, 2773, 46, 'आरोग्य काळजी ऑपरेशन'),
(138776, 2774, 46, 'हेल्थ केअर ऑपरेशन्स'),
(138777, 2775, 46, 'आरोग्य केंद्र / चिकित्सालय'),
(138778, 2776, 46, 'आरोग्य देखभाल संघटना'),
(138779, 2777, 46, 'आरोग्य देखभाल संघटना (HMO) वैद्यकीय धोका'),
(138780, 2778, 46, 'कमी होणे सुनावणी'),
(138781, 2779, 46, 'हृदयविकाराचा झटका'),
(138782, 2780, 46, 'हृदयरोग'),
(138783, 2781, 46, 'हार्ट अयशस्वी'),
(138784, 2782, 46, 'हार्ट समस्या'),
(138785, 2783, 46, 'हार्ट समस्या'),
(138786, 2784, 46, 'हार्ट शस्त्रक्रिया'),
(138787, 2785, 46, 'हार्ट रोपण'),
(138788, 2786, 46, 'मनात:'),
(138789, 2787, 46, 'छातीत जळजळ'),
(138790, 2788, 46, 'उष्णता किंवा थंड'),
(138791, 2789, 46, 'उष्णता किंवा थंड'),
(138792, 2790, 46, 'हेवी तंबाखू धूम्रपान'),
(138793, 2791, 46, 'हिब्रू'),
(138794, 2792, 46, 'हिब्रू (आधुनिक)'),
(138795, 2793, 46, 'HEENT'),
(138796, 2794, 46, 'उंची'),
(138797, 2795, 46, 'उंची / लांबी'),
(138798, 2796, 46, 'मदत'),
(138799, 2797, 46, 'मदत'),
(138800, 2798, 46, 'जठरामधून रक्त ओकून पडणे'),
(138801, 2799, 46, 'Hematochezia'),
(138802, 2800, 46, 'Hematologic'),
(138803, 2801, 46, 'Hematuria'),
(138804, 2802, 46, 'हिमोग्लोबिन'),
(138805, 2803, 46, 'हिमोग्लोबिन A1C'),
(138806, 2804, 46, 'Hemoptysis'),
(138807, 2805, 46, 'हिपॅटायटीस'),
(138808, 2806, 46, 'हिपॅटायटीस अ 1'),
(138809, 2807, 46, 'हिपॅटायटीस 2'),
(138810, 2808, 46, 'हिपॅटायटीस ब 1'),
(138811, 2809, 46, 'हिपॅटायटीस ब 2'),
(138812, 2810, 46, 'हिपॅटायटीस ब 3'),
(138813, 2811, 46, 'येथे'),
(138814, 2812, 46, 'हरेरो'),
(138815, 2813, 46, 'अन्तर्गळ दुरुस्ती'),
(138816, 2814, 46, 'Herniated डिस्क'),
(138817, 2815, 46, 'नागीण'),
(138818, 2816, 46, 'घुटमळणे'),
(138819, 2817, 46, 'heyyo. तुम्ही येथे केले आहे '),
(138820, 2818, 46, 'Hib 1'),
(138821, 2819, 46, 'Hib 2'),
(138822, 2820, 46, 'Hib 3'),
(138823, 2821, 46, 'Hib 4'),
(138824, 2822, 46, 'लपलेली'),
(138825, 2823, 46, 'लपलेली आगामी कार्यक्रम प्रशासन'),
(138826, 2824, 46, 'लपवा'),
(138827, 2825, 46, 'तपशील लपवा'),
(138828, 2826, 46, 'अहवाल रिक्त ई-साइन इन करा नोंदी लपवा'),
(138829, 2827, 46, 'लपवा एनक्रिप्शन / डिक्रीपश्न पर्याय कागदपत्रांचे व्यवस्थापन मध्ये'),
(138830, 2828, 46, 'लपवा मेनू'),
(138831, 2830, 46, 'लपवा स्मरणपत्रे'),
(138832, 2831, 46, 'लपवा / दाखवा स्तंभ'),
(138833, 2833, 46, 'उच्च'),
(138834, 2834, 46, 'उच्च रक्तदाब'),
(138835, 2835, 46, 'हिंदी'),
(138836, 2836, 46, 'हिप + मांडीचा सांधा'),
(138837, 2837, 46, 'हिप आणि मांडीचा सांधा'),
(138838, 2838, 46, 'हिप समस्या'),
(138839, 2839, 46, 'हिप बदलण्याचे'),
(138840, 2840, 46, 'HIPAA सूचना प्राप्त'),
(138841, 2841, 46, 'हिरी मॉटू'),
(138842, 2842, 46, 'अतिशय केसाळपणा मुख्यत: स्त्रियांमध्ये / Striae'),
(138843, 2843, 46, 'हिस्पॅनिक'),
(138844, 2844, 46, 'हिस्पॅनिक - इतर (यूएस मध्ये जन्मलेल्या)'),
(138845, 2845, 46, 'हिस्पॅनिक - इतर (अमेरिकेच्या बाहेरील जन्म)'),
(138846, 2846, 46, 'हिस्पॅनिक किंवा लॅटिनो'),
(138847, 2847, 46, 'इतिहास'),
(138848, 2848, 46, 'इतिहास डेटा'),
(138849, 2849, 46, 'इतिहास तारीख'),
(138850, 2851, 46, 'इतिहास तक्रारी'),
(138851, 2852, 46, 'इतिहास अधिकृत नाही'),
(138852, 2853, 46, 'हार्ट तक्रारी इतिहास'),
(138853, 2854, 46, 'हिट'),
(138854, 2855, 46, 'एचआयव्ही'),
(138855, 2858, 46, 'HL7 दर्शक'),
(138856, 2860, 46, 'HMOL / एल'),
(138857, 2861, 46, 'मंग'),
(138858, 2862, 46, '[की Ctrl] अनेक निवडी साठी दाबून ठेवा किंवा नीवड अशक्य करा करण्यासाठी'),
(138859, 2863, 46, 'एकाधिक आयटम निवडण्यासाठी Ctrl दाबून ठेवा'),
(138860, 2864, 46, 'अनेक पथके निवडण्यासाठी Ctrl दाबून ठेवा'),
(138861, 2865, 46, 'मुख्यपृष्ठ'),
(138862, 2866, 46, 'मुख्यपृष्ठ फोन'),
(138863, 2867, 46, 'मुख्यपृष्ठ फोन नंबर'),
(138864, 2868, 46, 'बेघरांसाठी किंवा तत्सम?'),
(138865, 2869, 46, 'बेघर, इ'),
(138866, 2870, 46, 'बेघर, इ'),
(138867, 2871, 46, 'आकड्या'),
(138868, 2872, 46, 'होस्ट नाव'),
(138869, 2873, 46, 'नाव रिकामे असू शकत नाही होस्ट'),
(138870, 2875, 46, 'तास'),
(138871, 2876, 46, 'तास'),
(138872, 2878, 46, 'इजा कसे येऊ दिले नाही?'),
(138873, 2879, 46, 'कसे इजा ?: येऊ नाही'),
(138874, 2880, 46, 'ते आम्हाला कसे कळले'),
(138875, 2881, 46, 'किती महिने पुढे कार्यक्रम आगामी चौकशी?'),
(138876, 2882, 46, 'HPI:'),
(138877, 2883, 46, 'एचटी'),
(138878, 2884, 46, 'एचटीएमएल'),
(138879, 2885, 46, 'HTML आउटपुटपहा?'),
(138880, 2886, 46, 'Https LibreEHR समर्थन, LLC लॅब विनिमय सेवा लिंक.'),
(138881, 2887, 46, 'हंगेरियन'),
(138882, 2888, 46, 'Hylafax निर्देशिका'),
(138883, 2889, 46, 'Hylafax Enscript आदेश'),
(138884, 2890, 46, 'Hylafax सर्व्हर'),
(138885, 2891, 46, 'Hylafax सर्व्हर होस्टनाव.'),
(138886, 2892, 46, 'Hyperactive'),
(138887, 2893, 46, 'उच्च रक्तदाब'),
(138888, 2894, 46, 'उच्च रक्तदाब: रक्तदाब मापन'),
(138889, 2895, 46, 'उच्च रक्तदाब: ब्लड प्रेशर परिमाण (CQM)'),
(138890, 2896, 46, 'हायपरथायरॉईडीझमची'),
(138891, 2897, 46, 'हायपोथायरॉईडीझम'),
(138892, 2898, 46, 'Hysterectomy'),
(138893, 2899, 46, 'मी'),
(138894, 2900, 46, 'मी या वेळी व्यस्त आहे.'),
(138895, 2901, 46, 'मी वाचले परवानगी नाही '),
(138896, 2902, 46, 'ICD'),
(138897, 2903, 46, 'ICD10 निदान'),
(138898, 2904, 46, 'ICD10 प्रक्रिया / सेवा'),
(138899, 2905, 46, 'ICD9'),
(138900, 2906, 46, 'ICD9 निदान'),
(138901, 2907, 46, 'ICD9 प्रक्रिया / सेवा'),
(138902, 2908, 46, 'आईसलँडिक'),
(138903, 2909, 46, 'आयडी'),
(138904, 2910, 46, 'आयडी'),
(138905, 2911, 46, 'आयडी रिक्त असू शकत नाही'),
(138906, 2912, 46, 'ओळखपत्र'),
(138907, 2913, 46, 'IDays'),
(138908, 2914, 46, 'म्हणून ओळखले'),
(138909, 2915, 46, 'अभिज्ञापक (एक शब्द)'),
(138910, 2916, 46, 'कोड ओळखणे'),
(138911, 2917, 46, 'सत्र कालबाह्य सेकंद निष्क्रिय'),
(138912, 2918, 46, 'मी करतो');
INSERT INTO `lang_definitions` VALUES
(138913, 2919, 46, 'सर्व कॉलम सर्व डेटा हा फॉर्म पूर्ण आहेत, तर'),
(138914, 2920, 46, 'बिलिंग देवासमोर नीतिमान वापरले जाते, तर निदान कोड प्रकारच्या नाव द्या.'),
(138915, 2921, 46, 'प्रविष्ट केला असल्यास, फक्त सेवा होती ज्यांनी निवडा'),
(138916, 2922, 46, 'तर नाव, lastname किंवा lastname, पहिले काही भाग'),
(138917, 2923, 46, 'करून देवून, तर'),
(138918, 2924, 46, 'व्यक्ती मृत असेल, तर मृत्यूच्या तारखेला प्रविष्ट करा.'),
(138919, 2925, 46, 'या SMTP वापरले असल्यास, server`s यजमाननाव किंवा IP पत्ता.'),
(138920, 2926, 46, 'या SMTP वापरले असल्यास, server`s TCP पोर्ट क्रमांक (सहसा 25).'),
(138921, 2927, 46, 'बेरोजगार तर विद्यार्थी प्रविष्ट'),
(138922, 2928, 46, 'YMD वय प्रदर्शन नीवडल्यास, फक्त वर्षे स्विच तेव्हा वर्षांत या मूल्य जुने रुग्णांना'),
(138923, 2929, 46, 'तुम्ही ePrescription ई-RX भूमिका बदलू असेल, तर ते ePrescription कार्यपद्धत प्रभाव पडू शकतो. आपण कोणत्याही अडचण असेल तर, आपल्या ePrescription विक्रेता संपर्क साधा.'),
(138924, 2930, 46, 'आपण एक सामना निवडा नसेल तर रुग्णाला निर्माण होईल.'),
(138925, 2931, 46, 'आपण इलेक्ट्रॉनिक व्यवहार अपलोड करण्यासाठी निवडलेली असेल, तर नंतर शोध विंडो X12 फाइल पासून जुळणारे पावत्या स्वतः redisplays. (खाली वर्णन केल्याप्रमाणे) आपण पैसे पाठवण्याच्या माहिती लागू करण्यापूर्वी कोणत्याही सुधारणा करण्यासाठी इच्छित असल्यास आपण या चलन संख्या कोणत्याही क्लिक करू शकता. बदल लागू करण्यासाठी, पृष्ठाच्या तळाशी प्रक्रिया ईआरए फाइल या बटणावर क्लिक करा. हे एकसविस्तर अहवाल एक नवीन विंडो निर्मिती होईल.'),
(138926, 2932, 46, 'आपण शोध पृष्ठामधील पे तारीख प्रवेश केला आहे तर, हे अन्यथा X12 फाइल घेतले जातात की पैसे आणि ऍडजस्ट पोस्टिंग तारीख पुन्हा लिहीले जातील. आपण इन्शुरन्स कंपनीला  ''चे प्रक्रिया तारीख ऐवजी आपल्या पोस्टिंग तारीख वापर अहवाल आपल्या पावत्या इच्छित असल्यास हा उद्देशांसाठी अहवाल उपयुक्त असू शकते. हे देखील दुय्यम दावे मध्ये ठेवले आहेत की आधी पैसे आणि ऍडजस्ट तारखा परिणाम होईल हे लक्षात ठेवा.'),
(138927, 2933, 46, 'आपण डेटा प्रकार बदलू किंवा पंक्ती किंवा स्तंभ जोडू इच्छित असल्यास'),
(138928, 2934, 46, 'आपण डेटाबेस सुधारणा करू इच्छित असल्यास, नंतर खालील डिरेक्टरी मध्ये डेटाबेस zip फाइल ठेवा'),
(138929, 2935, 46, 'ईग्बो'),
(138930, 2936, 46, 'दुर्लक्ष करा'),
(138931, 2937, 46, 'आजार'),
(138932, 2938, 46, 'आयएम'),
(138933, 2941, 46, 'इमेजिंग सेवा'),
(138934, 2942, 46, 'लसीकरण'),
(138935, 2943, 46, 'लसीकरण कोड'),
(138936, 2945, 46, 'लसीकरण तारीख'),
(138937, 2946, 46, 'लसीकरण कालावधी समाप्ती तारीख'),
(138938, 2947, 46, 'लसीकरण लोट क्रमांक'),
(138939, 2948, 46, 'लसीकरण निर्माता'),
(138940, 2949, 46, 'लसीकरण नोंदणी'),
(138941, 2950, 46, 'लसीकरण अहवाल'),
(138942, 2951, 46, 'लसीकरण सेवा'),
(138943, 2952, 46, 'लसीकरण शीर्षक'),
(138944, 2953, 46, 'लसीकरण'),
(138945, 2954, 46, 'लसीकरण'),
(138946, 2955, 46, 'Immunologic'),
(138947, 2956, 46, 'रोपण'),
(138948, 2957, 46, 'आयात'),
(138949, 2961, 46, 'ब्राउझर आयात प्रमाणपत्र.'),
(138950, 2962, 46, 'आयात संरचना'),
(138951, 2963, 46, 'आयात वेळ-टू-थेट साठी स्थगित'),
(138952, 2964, 46, 'आयात रुग्णांच्या'),
(138953, 2965, 46, 'रुग्णांच्या लोकसंख्याशास्त्र आयात'),
(138954, 2966, 46, 'महत्वाचे कोड'),
(138955, 2967, 46, 'महत्वाचे: या अपलोड साधन फक्त अद्याप प्रणाली मध्ये प्रवेश केला नाही की रुग्णांना दस्तऐवज अपलोड आहे. आधीच प्रणाली मध्ये लिहिला गेला ज्या रुग्णांना फाइल अपलोड करण्यासाठी, रुग्णांच्या सारांश स्क्रीन आत लिंक अपलोड साधनाचा वापर करा.'),
(138956, 2969, 46, 'लेखा आयात'),
(138957, 2972, 46, 'सुधारित'),
(138958, 2973, 46, 'मध्ये'),
(138959, 2974, 46, 'मध्ये'),
(138960, 2975, 46, 'प्रत्येक डोळ्यात'),
(138961, 2976, 46, 'डावा डोळा'),
(138962, 2977, 46, 'नाकपुडी मध्ये'),
(138963, 2978, 46, 'कार्यालय'),
(138964, 2979, 46, 'उजव्या डोळ्यात'),
(138965, 2980, 46, 'मध्ये घर'),
(138966, 2981, 46, 'निष्क्रिय'),
(138967, 2982, 46, 'निष्क्रिय दिवस'),
(138968, 2983, 46, 'इनबॉक्स'),
(138969, 2986, 46, 'चेकसम समाविष्ट'),
(138970, 2987, 46, 'समाविष्ट पूर्ण'),
(138971, 2988, 46, 'निष्क्रिय वापरकर्ते समाविष्ट'),
(138972, 2989, 46, 'अश्रेणीबद्ध समाविष्ट'),
(138973, 2990, 46, 'भागात तुम्ही लिहिलेला डेटा समाविष्ट करा'),
(138974, 2991, 46, 'मर्मस्थाने समाविष्ट'),
(138975, 2992, 46, 'मर्मस्थाने डेटा समाविष्ट करा?'),
(138976, 2993, 46, 'समावेश'),
(138977, 2994, 46, 'उत्पन्न'),
(138978, 2995, 46, 'लक्ष आवश्यक येणार्या परिणाम:'),
(138979, 2996, 46, 'अपूर्ण'),
(138980, 2997, 46, 'अपूर्ण गर्भपात उपचार'),
(138981, 2998, 46, 'आत्मसंयमाचा'),
(138982, 2999, 46, 'रचना डेटा म्हणून प्रमाणित EHR तंत्रज्ञान मध्ये क्लिनिकल प्रयोगशाळा चाचणी परिणाम अंतर्भूत.'),
(138983, 3000, 46, 'चुकीचा संकेतशब्द!'),
(138984, 3001, 46, 'वाढ:'),
(138985, 3002, 46, 'नुकसान भरपाई विमा'),
(138986, 3003, 46, 'अनिश्चित'),
(138987, 3004, 46, 'भारतीय'),
(138988, 3005, 46, 'विकृती सूचित करते'),
(138989, 3006, 46, 'या समस्येचे सध्या सक्रिय आहे, तर सूचित करते'),
(138990, 3008, 46, 'विशेष वापर निर्देश'),
(138991, 3009, 46, 'गरिब रुग्णांना'),
(138992, 3010, 46, 'गरिब रुग्णांना अहवाल'),
(138993, 3011, 46, 'Indigents'),
(138994, 3013, 46, 'इंडोनेशियन'),
(138995, 3014, 46, 'गर्भपात'),
(138996, 3016, 46, 'अपात्र'),
(138997, 3017, 46, 'संक्रमण / अब्सेस'),
(138998, 3018, 46, 'संक्रमण'),
(138999, 3019, 46, 'Infert Couns'),
(139000, 3020, 46, 'वंध्यत्व'),
(139001, 3021, 46, 'इन्फ्लूएन्झा 1'),
(139002, 3022, 46, 'इन्फ्लूएन्झा 2'),
(139003, 3023, 46, 'रुग्णांना इन्फ्लूएन्झा लसीकरण> = 50 वर्षांचा'),
(139004, 3024, 46, 'रुग्णांना इन्फ्लूएन्झा लसीकरण> = 50 वर्षे (CQM)'),
(139005, 3025, 46, 'इन्फ्लूएन्झा लस'),
(139006, 3026, 46, 'माहिती'),
(139007, 3027, 46, 'माहिती चाचणी 1'),
(139008, 3028, 46, 'माहिती चाचणी 2'),
(139009, 3029, 46, 'माहिती चाचणी 3'),
(139010, 3030, 46, 'माहिती चाचणी 4'),
(139011, 3031, 46, 'माहिती चाचणी 5'),
(139012, 3032, 46, 'माहिती चाचणी 6'),
(139013, 3034, 46, 'inhalations'),
(139014, 3035, 46, 'inhilations'),
(139015, 3036, 46, 'आरंभिक उपचार'),
(139016, 3037, 46, 'आरंभिक वापरकर्ता'),
(139017, 3038, 46, 'Inj / rehab'),
(139018, 3039, 46, 'Injectables'),
(139019, 3040, 46, 'इंजेक्शन'),
(139020, 3041, 46, 'जखमी शरीर भाग'),
(139021, 3042, 46, 'आउट जखमी'),
(139022, 3043, 46, 'इजा'),
(139023, 3044, 46, 'इजा पद्धती'),
(139024, 3045, 46, 'इजा विहंगावलोकन अहवाल'),
(139025, 3046, 46, 'इजा पाळत ठेवणे'),
(139026, 3047, 46, 'इजा प्रकार'),
(139027, 3048, 46, 'इजा / आजार संबंधित'),
(139028, 3049, 46, 'इनलाइन'),
(139029, 3050, 46, 'इनपुट एक MSH विभाग सुरू नाही'),
(139030, 3051, 46, 'इनपुट फील्ड'),
(139031, 3052, 46, 'भारतीय रुपया'),
(139032, 3053, 46, 'इन 1'),
(139033, 3054, 46, 'इन 2 किंवा 3 इन'),
(139034, 3055, 46, 'इन पत्ता'),
(139035, 3056, 46, 'इन समायोजित'),
(139036, 3057, 46, 'इन bundling'),
(139037, 3058, 46, 'इन कोड'),
(139038, 3059, 46, 'इन गट'),
(139039, 3060, 46, 'इन नाव'),
(139040, 3061, 46, 'इन overpaid'),
(139041, 3062, 46, 'इन धोरण'),
(139042, 3063, 46, 'इन परतावा'),
(139043, 3064, 46, 'इन सारांश'),
(139044, 3065, 46, 'Ins1'),
(139045, 3066, 46, 'Ins2'),
(139046, 3067, 46, 'Ins3'),
(139047, 3068, 46, 'समाविष्ट करा'),
(139048, 3069, 46, 'समाविष्ट करा अयशस्वी: '),
(139049, 3070, 46, 'सपाट दगडी पाट्या मध्ये जुन्या घटना घाला'),
(139050, 3072, 46, 'निद्रानाश'),
(139051, 3073, 46, 'लॉग तपासणी'),
(139052, 3074, 46, 'तपासणी'),
(139053, 3075, 46, 'अस्थिरता / सांधा अर्धवट निखळणे'),
(139054, 3076, 46, 'प्रतिष्ठापीत'),
(139055, 3077, 46, 'स्थापित'),
(139056, 3078, 46, 'कोड सेट स्थापित'),
(139057, 3079, 46, 'डीबी प्रतिष्ठापीत'),
(139058, 3080, 46, 'स्थापित प्रकाशन'),
(139059, 3081, 46, 'सूचना'),
(139060, 3082, 46, 'सूचना'),
(139061, 3084, 46, 'सूचना:'),
(139062, 3085, 46, 'उत्पादन ID अपूरी यादी'),
(139063, 3086, 46, 'मधुमेहावरील रामबाण उपाय अवलंबून मधुमेह'),
(139064, 3087, 46, 'विमा'),
(139065, 3088, 46, 'विमा'),
(139066, 3091, 46, 'विमा शिल्लक'),
(139067, 3092, 46, 'विमा शिल्लक मुळे'),
(139068, 3093, 46, 'विमा Comp'),
(139069, 3094, 46, 'विमा कंपन्या'),
(139070, 3095, 46, 'विमा कंपनी'),
(139071, 3096, 46, 'विमा कंपनी शोध जोडा /'),
(139072, 3098, 46, 'विमा डेटा'),
(139073, 3099, 46, 'फाइल विमा माहिती'),
(139074, 3100, 46, 'विमा क्रमांक'),
(139075, 3101, 46, 'विमा भरणा'),
(139076, 3103, 46, 'विमा प्रदाता'),
(139077, 3104, 46, 'विमा प्रकार'),
(139078, 3105, 46, 'इन्शुरन्सचे'),
(139079, 3106, 46, 'विम्याची'),
(139080, 3107, 46, 'प्रवेश निष्कर्ष'),
(139081, 3108, 46, 'प्रवेश दिनांक'),
(139082, 3109, 46, 'बौद्धिक नकार'),
(139083, 3110, 46, 'आंतरभाषिक'),
(139084, 3111, 46, 'बहुभाषी'),
(139085, 3113, 46, 'अंतर्गत त्रुटी - पृष्ठे नाही निवड करण्यात आली!'),
(139086, 3114, 46, 'अंतर्गत त्रुटी - रुग्ण आयडी प्रदान केला नाही होते!'),
(139087, 3115, 46, 'अंतर्गत त्रुटी अपलोड फाइल प्रवेश!'),
(139088, 3116, 46, 'अंतर्गत त्रुटी!'),
(139089, 3117, 46, 'अंतर्गत त्रुटी, नाही औषध ID निर्दिष्ट!'),
(139090, 3118, 46, 'अंतर्गत त्रुटी: MSH-10 शोधू शकत नाही'),
(139091, 3119, 46, 'अंतर्गत त्रुटी: हक्क '),
(139092, 3120, 46, 'अंतर्गत त्रुटी: चकमकीत '''),
(139093, 3121, 46, 'अंतर्गत त्रुटी: PID किंवा चकमकीत गहाळ आहे.'),
(139094, 3122, 46, 'अंतर्गत त्रुटी: आम्ही चकमकीत असल्याचे दिसत नाही!'),
(139095, 3123, 46, 'अंतर्गत अभिज्ञापक (पी आय डी)'),
(139096, 3126, 46, 'अंतर्गत संदर्भ'),
(139097, 3127, 46, 'अंतर्गत वेळ गोळा'),
(139098, 3128, 46, 'आंतरराष्ट्रीय शुल्क'),
(139099, 3129, 46, 'इंटरप्रिटर'),
(139100, 3130, 46, 'इंटरप्रिटर आवश्यक?'),
(139101, 3131, 46, 'अंतर्गत फुफ्फुसाचा रोग'),
(139102, 3132, 46, 'मध्यांतर'),
(139103, 3133, 46, 'मध्यांतर (मिनिटे)'),
(139104, 3134, 46, 'संदेश धनादेश दरम्यान मध्यांतर (मॅन्युअल धनादेश शून्यावर सेट केले फक्त)'),
(139105, 3135, 46, 'हस्तक्षेप'),
(139106, 3136, 46, 'हस्तक्षेप प्रदान'),
(139107, 3137, 46, 'असहिष्णुता'),
(139108, 3139, 46, 'intramuscularly'),
(139109, 3140, 46, 'नसेतून'),
(139110, 3141, 46, 'परिचय'),
(139111, 3142, 46, 'इनुकिटुट्'),
(139112, 3143, 46, 'इनूपियाक'),
(139113, 3144, 46, 'अवैध वर्ण'),
(139114, 3146, 46, 'अवैध बांधता येणे डेटा एन्कोडिंग प्रकार'),
(139115, 3147, 46, 'अवैध लांबी'),
(139116, 3148, 46, 'अवैध नॉन-अंकीय वर्ण'),
(139117, 3149, 46, 'कोड स्रोत अवैध किंवा गहाळ देणारा '),
(139118, 3150, 46, 'अवैध प्राप्तकर्ता पत्ता नाही. कृपया पुन्हा प्रयत्न करा.'),
(139119, 3151, 46, 'अवैध सेवा कोड'),
(139120, 3152, 46, 'अवैध स्रोत नाव "'),
(139121, 3153, 46, 'अवैध वापरकर्ता नाव किंवा संकेतशब्द'),
(139122, 3154, 46, 'InvAmt'),
(139123, 3155, 46, 'यादी'),
(139124, 3156, 46, 'यादी क्रियाकलाप'),
(139125, 3157, 46, 'यादी आणि औषधे आणि गैर-औषध दोन्ही उत्पादनांसाठी विक्री'),
(139126, 3158, 46, 'यादी आणि विक्री औषधे फक्त'),
(139127, 3159, 46, 'यादी ऑर्डर उपलब्ध नाही.'),
(139128, 3160, 46, 'यादी यादी'),
(139129, 3161, 46, 'यादी व्यवहार'),
(139130, 3162, 46, 'अशी यादी तयार करणे'),
(139131, 3163, 46, 'अशी यादी तयार करणे'),
(139132, 3164, 46, 'अशी यादी तयार करणे शिल्लक'),
(139133, 3165, 46, 'अशी यादी तयार करणे शिल्लक पोस्ट करू शकत नाही. कोणत्याही चकमकीत तयार आहे.'),
(139134, 3166, 46, 'अशी यादी तयार करणे तारीख'),
(139135, 3167, 46, 'अशी यादी तयार करणे नाही तारीख आहे!'),
(139136, 3168, 46, 'बील क्रमांक'),
(139137, 3169, 46, 'अशी यादी तयार करणे संदर्भ क्रमांक'),
(139138, 3170, 46, 'अशी यादी तयार करणे संदर्भ क्रमांक पूल, वापरले तर'),
(139139, 3171, 46, 'अशी यादी तयार करणे संदर्भ क्रमांक संचाची'),
(139140, 3172, 46, 'अशी यादी तयार करणे Refno तलाव'),
(139141, 3173, 46, 'अशी यादी तयार करणे:'),
(139142, 3174, 46, 'IPPF'),
(139143, 3175, 46, 'IPPF गर्भपात'),
(139144, 3176, 46, 'IPPF संततिनियमन'),
(139145, 3177, 46, 'साठी IPPF SRH डेटा'),
(139146, 3178, 46, 'IPPF सांख्यिकी अहवाल'),
(139147, 3179, 46, 'IPPF आकडेवारी'),
(139148, 3180, 46, 'IPV 1'),
(139149, 3181, 46, 'IPV 2'),
(139150, 3182, 46, 'IPV 3'),
(139151, 3183, 46, 'IPV 4'),
(139152, 3184, 46, 'आयरिश'),
(139153, 3185, 46, 'अनियमित हार्ट बीट'),
(139154, 3186, 46, 'चिडचिड'),
(139155, 3187, 46, 'चिडून'),
(139156, 3188, 46, 'खालील आकडेवारीचा भिन्न भाषा आवृत्ती आहे'),
(139157, 3189, 46, 'खालील डेटाबेस भिन्न आवृत्ती आहे'),
(139158, 3190, 46, 'खालील आकडेवारीचा अधिक अलीकडील आवृत्ती आहे'),
(139159, 3191, 46, 'आवश्यक फील्ड आहे.'),
(139160, 3192, 46, 'रूट नोड आहे आणि हटविले जाऊ शकत नाही.'),
(139161, 3193, 46, 'खालील डेटाबेस एक विस्तार आहे'),
(139162, 3194, 46, 'या CVX कोड आधीच अस्तित्वात लसीकरण मॅप ठीक आहे?'),
(139163, 3195, 46, 'गहाळ किंवा अज्ञात आहे'),
(139164, 3197, 46, '(दशांश अपूर्णांक ठिक) वैध नाही.'),
(139165, 3198, 46, 'कृपया PHP सुरक्षित मोड वापरत आहे?'),
(139166, 3200, 46, 'फॉर्म मांडणी मजकूर अनुवादित केले आहे का?'),
(139167, 3201, 46, 'याद्या मजकूर अनुवादित केले आहे का?'),
(139168, 3202, 46, 'फाइल कूटबद्ध आहे का?'),
(139169, 3203, 46, 'हे एक क्लिनिकल मुदत कोड प्रकार आहे?'),
(139170, 3204, 46, 'हे निदान प्रकार आहे?'),
(139171, 3205, 46, 'हे एक वैद्यकीय समस्या कोड प्रकार आहे?'),
(139172, 3206, 46, 'हे औषध प्रकार आहे?'),
(139173, 3207, 46, 'हे एक पद्धत / सेवा प्रकार आहे?'),
(139174, 3208, 46, 'हा सक्रिय आहे का?'),
(139175, 3209, 46, 'हा कोड प्रकार सक्रिय आहे का?'),
(139176, 3210, 46, 'दावे वापरले हा कोड प्रकार आहे?'),
(139177, 3211, 46, 'हे खरोखर ठीक आहे का?'),
(139178, 3212, 46, 'फी पत्रक लपवलेले हा प्रकार आहे का?'),
(139179, 3213, 46, 'हे बाह्य एस क्यू एल सपाट दगडी पाट्या वापरत आहे? ते आहे तर, नंतर स्वरूप निवडा.'),
(139180, 3214, 46, 'खूप लांब आहे'),
(139181, 3215, 46, 'आयएसओ 639-2 कोड'),
(139182, 3216, 46, 'अंक'),
(139183, 3217, 46, 'समस्या'),
(139184, 3218, 46, 'जारी केल्याचा दिनांक'),
(139185, 3219, 46, 'अंक आयडी'),
(139186, 3220, 46, 'अंक शीर्षक'),
(139187, 3221, 46, 'समस्या प्रकार'),
(139188, 3222, 46, 'समस्या प्रकार'),
(139189, 3223, 46, 'मुद्दे'),
(139190, 3224, 46, 'मुद्दे (दुखापती / वैद्यकीय / ऍलर्जी)'),
(139191, 3225, 46, 'मुद्दे (दुखापती / वैद्यकीय / ऍलर्जी):'),
(139192, 3226, 46, 'मुद्दे आणि Encounters'),
(139193, 3227, 46, 'मुद्दे आणि Encounters साठी'),
(139194, 3228, 46, 'मुद्दे अधिकृत नाही'),
(139195, 3229, 46, 'मुद्दे विभाग'),
(139196, 3230, 46, 'इटालियन'),
(139197, 3231, 46, 'आयटम'),
(139198, 3232, 46, 'आयटम'),
(139199, 3233, 46, 'आयटम'),
(139200, 3234, 46, 'आयटम अयशस्वी लोड'),
(139201, 3235, 46, 'IU / एल'),
(139202, 3236, 46, 'IUD'),
(139203, 3237, 46, 'चौथा'),
(139204, 3238, 46, 'जानेवारी'),
(139205, 3239, 46, 'जानेवारी'),
(139206, 3240, 46, 'जपानी'),
(139207, 3241, 46, 'कावीळ'),
(139208, 3242, 46, 'जावातील लोक किंवा त्यांची भाषा'),
(139209, 3243, 46, 'कामाचे स्वरूप'),
(139210, 3244, 46, 'नोकरी आयडी'),
(139211, 3245, 46, 'संयुक्त dislocations'),
(139212, 3246, 46, 'संयुक्त वेदना'),
(139213, 3247, 46, 'संयुक्त sprains'),
(139214, 3248, 46, 'जुलै'),
(139215, 3249, 46, 'जुलै'),
(139216, 3250, 46, 'जून'),
(139217, 3251, 46, 'जून'),
(139218, 3252, 46, 'फक्त चेक खालील माहिती आपण आपल्या शोध मापदंड ठेवले जेथे निळा क्षेत्र आहे. आपण रुग्णाला नाव, चार्ट क्रमांक, चकमकीत संख्या किंवा सेवा तारीख, किंवा या कोणत्याही संयोजनात शोधू शकता. आपण फक्त सर्व पावत्या, खुल्या पावत्या, किंवा (रुग्णाने) मुळे आहेत की पावत्या पाहू इच्छित की नाही हे निवडू शकता. शोध सुरू शोध बटणावर क्लिक करा.'),
(139219, 3253, 46, 'फक्त माझे'),
(139220, 3254, 46, 'समर्थन नोंदी'),
(139221, 3255, 46, 'समायोजित'),
(139222, 3256, 46, 'समायोजित / सेव्ह'),
(139223, 3257, 46, 'जॉन {{जस्टिफाय शीर्षलेख}}'),
(139224, 3258, 46, 'के, येथे विश्रांती आहे'),
(139225, 3259, 46, 'कलाल्लिसुत, ग्रीनलँडिक'),
(139226, 3260, 46, 'कन्नड'),
(139227, 3261, 46, 'कनुरी'),
(139228, 3262, 46, 'काश्मिरी'),
(139229, 3263, 46, 'कझाक'),
(139230, 3264, 46, 'की'),
(139231, 3265, 46, 'कीवर्ड'),
(139232, 3266, 46, 'किलो'),
(139233, 3267, 46, 'किलो / मीटर ^ 2'),
(139234, 3268, 46, 'ख्मेर'),
(139235, 3269, 46, 'किडनी कर्करोग'),
(139236, 3270, 46, 'किडनी अयशस्वी'),
(139237, 3271, 46, 'किडनी इन्फेक्शन्स'),
(139238, 3272, 46, 'किडनी स्टोन्स'),
(139239, 3273, 46, 'किडनी रोपण'),
(139240, 3274, 46, 'किकुयू, Gikuyu'),
(139241, 3275, 46, 'किन्यारवांडा'),
(139242, 3276, 46, 'किरुन्दी'),
(139243, 3277, 46, 'गुडघा'),
(139244, 3278, 46, 'गुडघा समस्या'),
(139245, 3279, 46, 'गुडघा बदलण्याचे'),
(139246, 3280, 46, 'कोमी'),
(139247, 3281, 46, 'काँगो'),
(139248, 3282, 46, 'कोरियन'),
(139249, 3283, 46, 'कुर्दिश'),
(139250, 3284, 46, 'Kwanyama, क्वान्यामा'),
(139251, 3285, 46, 'किरगिझ'),
(139252, 3286, 46, 'लॅब'),
(139253, 3287, 46, 'लॅब दस्तऐवज'),
(139254, 3288, 46, 'लॅब एक्सचेंज साइट पत्ता'),
(139255, 3289, 46, 'लॅब एक्सचेंज साइट ID'),
(139256, 3290, 46, 'लॅब एक्सचेंज टोकन आयडी'),
(139257, 3291, 46, 'लॅब ऑर्डर'),
(139258, 3292, 46, 'लॅब विहंगावलोकन'),
(139259, 3293, 46, 'लॅब विहंगावलोकन'),
(139260, 3294, 46, 'लॅब क्वेरी स्थिती'),
(139261, 3295, 46, 'लॅब अहवाल'),
(139262, 3296, 46, 'लॅब निकाल'),
(139263, 3297, 46, 'लॅब परिणाम'),
(139264, 3298, 46, 'लॅब परिणाम वर्गवारी नाव'),
(139265, 3299, 46, 'लॅब परिणाम अहवाल'),
(139266, 3300, 46, 'लॅब सेवा'),
(139267, 3301, 46, 'लॅब परीक्षेचा निकाल'),
(139268, 3302, 46, 'लॅब / फाइल'),
(139269, 3303, 46, 'लेबल'),
(139270, 3304, 46, 'लेबल रिक्त असू शकत नाही'),
(139271, 3305, 46, 'लेबल स्तंभ'),
(139272, 3306, 46, 'हा प्रकार लेबल'),
(139273, 3307, 46, 'LabelCols 1 आणि 999 दरम्यान एक संख्या असणे आवश्यक आहे'),
(139274, 3308, 46, 'लेबले'),
(139275, 3311, 46, 'लॅब्ज'),
(139276, 3312, 46, 'छेद / त्वचा अट'),
(139277, 3313, 46, 'छेद / ओरखडा'),
(139278, 3315, 46, 'लँडस्केप'),
(139279, 3316, 46, 'भाषा'),
(139280, 3317, 46, 'भाषा कोड'),
(139281, 3318, 46, 'भाषा व्याख्या जोडले'),
(139282, 3319, 46, 'भाषा इंटरफेस साधन'),
(139283, 3320, 46, 'भाषा यादी (addonly पर्यायी, लिहा)'),
(139284, 3321, 46, 'भाषा नाव'),
(139285, 3322, 46, 'भाषा:'),
(139286, 3323, 46, 'लाओ'),
(139287, 3324, 46, 'लाओतिअन'),
(139288, 3325, 46, 'गेल्या'),
(139289, 3326, 46, 'अंतिम क्रियाकलाप तारीख'),
(139290, 3327, 46, 'गेल्या आंत्रपुच्छ काढून टाकणे'),
(139291, 3328, 46, 'अंतिम बिल तारीख:'),
(139292, 3329, 46, 'गेल्या स्तनाचा परीक्षा'),
(139293, 3330, 46, 'गेल्या कॅलेंडर वर्ष'),
(139294, 3331, 46, 'गेल्या मोतीबिंदू शस्त्रक्रिया'),
(139295, 3332, 46, 'गेल्या Cholecystestomy'),
(139296, 3333, 46, 'गेल्या आढळतात'),
(139297, 3334, 46, 'गेल्या GYN. परीक्षा'),
(139298, 3335, 46, 'गेल्या हार्ट शस्त्रक्रिया'),
(139299, 3336, 46, 'गेल्या अन्तर्गळ दुरुस्ती'),
(139300, 3337, 46, 'गेल्या हिप बदलण्याचे'),
(139301, 3338, 46, 'गेल्या Hysterectomy'),
(139302, 3339, 46, 'गेल्या गुडघा बदलण्याचे'),
(139303, 3340, 46, 'गेल्या पातळी बिल'),
(139304, 3341, 46, 'गेल्या मध्यमवयानंतरचा'),
(139305, 3342, 46, 'गेल्या मासिक पाळी'),
(139306, 3343, 46, 'शेवटचा महिना'),
(139307, 3344, 46, 'आडनाव'),
(139308, 3345, 46, 'आडनाव'),
(139309, 3346, 46, 'आडनाव:'),
(139310, 3347, 46, 'गेल्या शारीरिक परीक्षा'),
(139311, 3348, 46, 'गेल्या पुर: स्थ परीक्षा'),
(139312, 3349, 46, 'गेल्या मलमार्गविषयक परीक्षा'),
(139313, 3350, 46, 'शेवटचे पुनरावलोकन'),
(139314, 3351, 46, 'गेल्या चालवा सुरु'),
(139315, 3352, 46, 'शेवटी जतन केलेला'),
(139316, 3353, 46, 'गेल्या सिग्मा / Colonoscopy'),
(139317, 3355, 46, 'गेल्या एक किंवा दोन्ही गलग्रंथी काढून टाकणे'),
(139318, 3356, 46, 'गेल्या सुधारणा'),
(139319, 3357, 46, 'अखेरचे सत्यापित रोजी'),
(139320, 3358, 46, 'अंतिम भेट'),
(139321, 3359, 46, 'गेल्या क्ष-किरण'),
(139322, 3360, 46, 'कै पुनरावृत्ती (2-12 मो)'),
(139323, 3361, 46, 'बाजूकडील घोटा'),
(139324, 3362, 46, 'बाजूकडील घोटा:'),
(139325, 3363, 46, 'Laterality'),
(139326, 3364, 46, 'या पद्धतीचा Laterality, लागू असल्यास'),
(139327, 3365, 46, 'laterally आणि PMI परिणाम विस्थापित:'),
(139328, 3367, 46, 'ताज्या भेट द्या किंवा सल्ला'),
(139329, 3368, 46, 'लॅटिन'),
(139330, 3369, 46, 'लाट्वियन'),
(139331, 3372, 46, 'मांडणी'),
(139332, 3373, 46, 'मांडणी आधारित'),
(139333, 3374, 46, 'लेआउट संपादक'),
(139334, 3375, 46, 'मांडणी गट'),
(139335, 3376, 46, 'मांडणी शैली'),
(139336, 3378, 46, 'मांडणी आधारित भेट द्या अर्ज'),
(139337, 3379, 46, 'लेआउट'),
(139338, 3380, 46, 'लेगबाईज'),
(139339, 3381, 46, 'एलबीएस'),
(139340, 3382, 46, 'LDL'),
(139341, 3383, 46, 'सक्रिय अजूनही तर रिक्त सोडा'),
(139342, 3384, 46, 'मूळ फाइलनाव ठेवा करण्यासाठी रिक्त सोडा'),
(139343, 3385, 46, 'जसाच्या तसा पासवर्ड ठेवणे रिक्त सोडा.'),
(139344, 3386, 46, 'सह संदेश सोडा'),
(139345, 3387, 46, 'फॉर्म सोडा'),
(139346, 3388, 46, 'पास वाक्यांश रिक्त सोडून दस्तऐवज कूटबद्ध नाही'),
(139347, 3390, 46, 'बाकी'),
(139348, 3391, 46, 'डाव्या कानात'),
(139349, 3392, 46, 'डाव्या कानात'),
(139350, 3393, 46, 'डावा समास (मिमी)'),
(139351, 3394, 46, 'डावीकडे:'),
(139352, 3395, 46, 'डावीकडे: '),
(139353, 3396, 46, 'लेग वेदना / cramping'),
(139354, 3397, 46, 'कायदेशीर'),
(139355, 3399, 46, 'कायदेशीर कागद आकार'),
(139356, 3400, 46, 'संकेत:'),
(139357, 3401, 46, 'लांबी'),
(139358, 3402, 46, 'सुधारक लांबी, 0 तर कोणीही'),
(139359, 3403, 46, 'च्या पेक्षा कमी'),
(139360, 3404, 46, 'या पेक्षा कमी किंवा समान'),
(139361, 3405, 46, 'कमी-खाजगी माहिती (राइट, addonly पर्यायी)'),
(139362, 3406, 46, 'पत्र'),
(139363, 3407, 46, 'पत्र जनक'),
(139364, 3408, 46, 'पत्र कागद आकार'),
(139365, 3409, 46, 'त्या डॉक्टर चिन्हे नाव'),
(139366, 3410, 46, 'त्या रुग्णाची चिन्हे नाव'),
(139367, 3411, 46, 'निकड पातळी'),
(139368, 3412, 46, 'दायित्व'),
(139369, 3413, 46, 'दायित्व वैद्यकीय'),
(139370, 3414, 46, 'परवाना / आयडी'),
(139371, 3419, 46, 'LicensedPrescriber आडनाव'),
(139372, 3420, 46, 'LicensedPrescriber NPI'),
(139373, 3421, 46, 'LicensedPrescriber UPIN'),
(139374, 3423, 46, 'जीवनशैली'),
(139375, 3424, 46, 'जीवनशैली स्थिती'),
(139376, 3425, 46, 'लीगामेंट झीज तूट किंवा खेचले जाणे'),
(139377, 3426, 46, 'प्रकाश तंबाखू धूम्रपान'),
(139378, 3427, 46, 'लिंबूर्गिश, लिम्बर्गन Name, Limburger'),
(139379, 3428, 46, 'आगामी कार्यक्रम मर्यादा'),
(139380, 3429, 46, 'मर्यादा'),
(139381, 3430, 46, 'लिङ्गला'),
(139382, 3431, 46, 'दुवा'),
(139383, 3432, 46, 'रुग्णांच्या वेबसाईटशी लिंक करा'),
(139384, 3433, 46, 'लिंक्ड'),
(139385, 3434, 46, 'लिंक्ड दस्तऐवज'),
(139386, 3435, 46, 'लिंक्ड प्रक्रिया करण्यासाठी'),
(139387, 3436, 46, 'दस्तऐवज लिंक'),
(139388, 3437, 46, 'प्रक्रिया करण्यासाठी लिंक'),
(139389, 3438, 46, 'यादी'),
(139390, 3439, 46, 'सूची बॉक्स'),
(139391, 3440, 46, 'यादी बॉक्स'),
(139392, 3441, 46, 'जोडू / W सूची बॉक्स'),
(139393, 3442, 46, 'जोडा / W सूची बॉक्स'),
(139394, 3443, 46, 'यादी संपादक'),
(139395, 3444, 46, 'यादी चकमकी'),
(139396, 3445, 46, 'यादी गट'),
(139397, 3446, 46, 'यादी विमा कंपन्या'),
(139398, 3448, 46, 'यादी आयटम संख्या सुरू करू शकत नाही.'),
(139399, 3449, 46, 'यादी आयटम बेकायदेशीर वर्ण आहे (आहेत).'),
(139400, 3451, 46, 'यादी याद्या'),
(139401, 3452, 46, 'यादी नाव'),
(139402, 3453, 46, 'यादी नावे संख्या सुरू करू शकत नाही.'),
(139403, 3454, 46, 'यादी चांगले'),
(139404, 3455, 46, 'वरील देश डेटा प्रकार पर्याय वापरले यादी.'),
(139405, 3456, 46, 'वरील राज्य डेटा प्रकार पर्याय वापरले यादी.'),
(139406, 3457, 46, 'न करता RFC 5425, TLS syslog सर्व्हरकडे पोर्ट ऐकणे.'),
(139407, 3458, 46, 'याद्या'),
(139408, 3459, 46, 'लिथुआनियन'),
(139409, 3460, 46, 'राहण्याची होईल'),
(139410, 3461, 46, 'LLL:'),
(139411, 3462, 46, 'एलएमपी'),
(139412, 3463, 46, 'लोड सर्वसमावेशक सारांश'),
(139413, 3464, 46, 'लोड व्याख्या'),
(139414, 3465, 46, 'लॅब संरचना लोड'),
(139415, 3466, 46, 'लिहायचं प्रश्न पर्याय लोड करा'),
(139416, 3467, 46, 'ऑर्डर व्याख्या लोड'),
(139417, 3468, 46, 'ऑर्डर प्रवेश प्रश्न लोड'),
(139418, 3469, 46, 'लोड यशस्वी. कोड समाविष्ट'),
(139419, 3470, 46, 'लोड करत आहे'),
(139420, 3471, 46, 'डेटाबेस मध्ये फायली लोड करत आहे. हे काही वेळ लागेल ...'),
(139421, 3472, 46, 'LOC'),
(139422, 3473, 46, 'स्थानिक'),
(139423, 3474, 46, 'स्थानिक सामग्री'),
(139424, 3475, 46, 'स्थानीय फाइलप्रणालीवरील'),
(139425, 3476, 46, 'लोकॅल'),
(139426, 3477, 46, 'परिसर'),
(139427, 3478, 46, 'स्थान'),
(139428, 3479, 46, 'तो स्वतः त्याच्या वापर नंतर फाइल हटवली शिफारसीय आहे त्यामुळे libreehr मशीन स्थान आणि, संवेदनशील डाटा असू शकते'),
(139429, 3480, 46, 'या भरपूर स्थान'),
(139430, 3481, 46, 'निर्दिष्ट न स्थान'),
(139431, 3482, 46, 'स्थान जेथे Hylafax स्टोअर्स फॅक्स.'),
(139432, 3483, 46, 'स्कॅन साठवले जातात जेथे स्थान.'),
(139433, 3484, 46, 'स्थान:'),
(139434, 3485, 46, 'लॉक'),
(139435, 3486, 46, 'वैयक्तिकरित्या ई-साइन इन फॉर्म लॉक'),
(139436, 3487, 46, 'लॉक ई-साइन इन चकमकी आणि त्यांच्या फॉर्म'),
(139437, 3488, 46, 'लॉक करायचा?'),
(139438, 3489, 46, 'बंधिस्त'),
(139439, 3492, 46, 'प्रवेश करा'),
(139440, 3493, 46, 'प्रवेश करा'),
(139441, 3494, 46, 'बाहेर पडणे'),
(139442, 3495, 46, 'लॉग इन'),
(139443, 3496, 46, 'म्हणून लॉग इन'),
(139444, 3497, 46, 'म्हणून लॉग इन: '),
(139445, 3498, 46, 'लॉग आऊट केले.'),
(139446, 3499, 46, 'लॉग'),
(139447, 3500, 46, 'प्रवेश करा'),
(139448, 3501, 46, 'प्रवेश करा'),
(139449, 3502, 46, 'पोर्टल प्रवेश वर्डप्रेस वापरकर्ता लॉग-इन नाव'),
(139450, 3503, 46, 'दूर्रस्थ यजमानाशी लॉगिन करा'),
(139451, 3504, 46, 'या दूर्रस्थ यजमानाशी लॉगिन अयशस्वी'),
(139452, 3505, 46, 'बाहेर पडणे'),
(139453, 3506, 46, 'बाहेर पडणे'),
(139454, 3507, 46, 'नोंदी'),
(139455, 3508, 46, 'नोंदी दर्शक'),
(139456, 3510, 46, 'वर बघ'),
(139457, 3511, 46, 'लोट'),
(139458, 3512, 46, 'लोट आयडी गहाळ!'),
(139459, 3513, 46, 'लोट क्रमांक'),
(139460, 3514, 46, 'कमी'),
(139461, 3515, 46, 'निम्न प्राधान्य'),
(139462, 3516, 46, 'कमी चेंडू'),
(139463, 3517, 46, 'सर्वात कमी प्राधान्य'),
(139464, 3518, 46, 'ल्यूबा-कटांगा'),
(139465, 3519, 46, 'पाठीच्या मणक्याचे'),
(139466, 3520, 46, 'लंच'),
(139467, 3521, 46, 'लंच'),
(139468, 3522, 46, 'फुफ्फुसांचा कर्करोग'),
(139469, 3523, 46, 'फुफ्फुसांचा कर्करोग शस्त्रक्रिया'),
(139470, 3524, 46, 'फुफ्फुसे:'),
(139471, 3525, 46, 'फुफ्फुसे:'),
(139472, 3526, 46, 'त्वचाक्षय'),
(139473, 3527, 46, 'डायलर, Letzeburgesch'),
(139474, 3528, 46, 'एम'),
(139475, 3529, 46, 'एम.ए. वर्ग'),
(139476, 3530, 46, 'गर्भपात स्वीकार एम.ए. क्लायंट'),
(139477, 3531, 46, 'एम.ए. आकडेवारी'),
(139478, 3532, 46, 'मॅसेडोनियन'),
(139479, 3533, 46, 'मेल पाठविले'),
(139480, 3534, 46, 'मुख्य'),
(139481, 3535, 46, 'मुख्य पत्ता'),
(139482, 3536, 46, 'मुख्य शीर्ष पट्टीमध्ये स्क्रीन'),
(139483, 3537, 46, 'सक्रिय औषध ऍलर्जी यादी ठेवणे.'),
(139484, 3538, 46, 'सक्रिय औषधोपचार यादी ठेवणे.'),
(139485, 3539, 46, 'वर्तमान आणि सक्रिय निदान एक अप-टू-डेट समस्या यादी ठेवणे.'),
(139486, 3540, 46, 'वर्तमान श्रेणी बदल करा.'),
(139487, 3541, 46, 'नवीन नियुक्ती करा'),
(139488, 3542, 46, 'खात्री करा "'),
(139489, 3543, 46, 'क्लिअरिंग हाऊस अपलोड बॅच मजकूर फायली आणि बिल चिन्हांकित होईल'),
(139490, 3544, 46, 'मालागासे'),
(139491, 3545, 46, 'धुसफूस:'),
(139492, 3546, 46, 'मलय'),
(139493, 3547, 46, 'मल्याळम'),
(139494, 3548, 46, 'पुरुष'),
(139495, 3549, 46, 'पुरुष कंडोम'),
(139496, 3550, 46, 'पुरुष VSC'),
(139497, 3551, 46, 'माल्टीज'),
(139498, 3552, 46, 'मध्यमवयानंतरचा'),
(139499, 3553, 46, 'व्यवस्थापित करा'),
(139500, 3554, 46, 'हूक्सचा व्यवस्थापित करा'),
(139501, 3555, 46, 'मॉड्यूल व्यवस्थापित करा'),
(139502, 3556, 46, 'भाषांतर व्यवस्थापित करा'),
(139503, 3557, 46, 'व्यवस्थापन'),
(139504, 3558, 46, 'अनिवार्य व निर्देशीत फील्ड'),
(139505, 3559, 46, 'फक्त अनिवार्य किंवा निर्दिष्ट फील्ड, dup चेक, नाही शोध'),
(139506, 3560, 46, 'अनिवार्य किंवा निर्दिष्ट फील्ड फक्त, शोध आणि dup तपासणी'),
(139507, 3561, 46, 'मॅन्युअल'),
(139508, 3562, 46, 'मॅन्युअल पोस्ट'),
(139509, 3563, 46, 'निर्माता'),
(139510, 3564, 46, 'मॅन्स्क'),
(139511, 3565, 46, 'मार्च'),
(139512, 3567, 46, 'मराठी (मराठी)'),
(139513, 3568, 46, 'मार्च'),
(139514, 3569, 46, 'वैवाहिक स्थिती'),
(139515, 3570, 46, 'मार्क बिल म्हणून'),
(139516, 3571, 46, 'मार्क बिल पण बिलिंग वगळा म्हणून'),
(139517, 3572, 46, 'मार्क साफ म्हणून'),
(139518, 3573, 46, 'मार्क बिल नाही'),
(139519, 3574, 46, 'पुनरावलोकन या अहवाल चिन्हांकित'),
(139520, 3575, 46, 'साफ म्हणून चिन्हांकित'),
(139521, 3576, 46, 'लग्न'),
(139522, 3577, 46, 'मार्शलीज'),
(139523, 3578, 46, 'मुखवटा'),
(139524, 3579, 46, 'चलन क्रमांकांसाठी मुखवटा'),
(139525, 3580, 46, 'रुग्णांच्या आयडी मास्क'),
(139526, 3581, 46, 'उत्पादन ID मास्क'),
(139527, 3582, 46, 'मॅच'),
(139528, 3583, 46, 'मॅच केस'),
(139529, 3584, 46, 'मॅच सापडले'),
(139530, 3590, 46, 'मॅट्रिक्स'),
(139531, 3591, 46, 'कमाल'),
(139532, 3592, 46, 'कमाल फाइल संख्या गाठली - रीलोड नावे खालील'),
(139533, 3594, 46, 'जबडयाच्या अधिकार:'),
(139534, 3595, 46, 'कमाल वय'),
(139535, 3596, 46, 'कमाल वर्ण'),
(139536, 3597, 46, 'बाहेर पडणे आधी सेकंद जास्तीत जास्त फालतू वेळ. मुलभूत 7200 (2 तास) आहे.'),
(139537, 3600, 46, 'कमाल वाजवी यादी, 0 लागू नाही तर'),
(139538, 3601, 46, 'कमाल आकार'),
(139539, 3602, 46, 'कमाल आकार (0 प्रविष्ट कोणत्याही आकाराचे परवानगी आहे)'),
(139540, 3603, 46, 'मे'),
(139541, 3604, 46, 'महानगरपालिका'),
(139542, 3605, 46, 'मेलबॉर्न क्रिकेट मैदान'),
(139543, 3607, 46, 'पासवर्ड बदलत असताना गेल्या तीन संकेतशब्द नाही अनुमती आहे याचा अर्थ.'),
(139544, 3609, 46, 'गट कोड मोजा'),
(139545, 3611, 46, 'मापन'),
(139546, 3612, 46, 'सरासरीचा घोटा:'),
(139547, 3613, 46, 'मेडीकेडची'),
(139548, 3614, 46, 'वैद्यकीय'),
(139549, 3615, 46, 'वैद्यकीय गर्भपात'),
(139550, 3616, 46, 'वैद्यकीय प्रशासन'),
(139551, 3617, 46, 'वैद्यकीय इतिहास'),
(139552, 3618, 46, 'वैद्यकीय अंक'),
(139553, 3619, 46, 'वैद्यकीय समस्या'),
(139554, 3620, 46, 'वैद्यकीय समस्या'),
(139555, 3621, 46, 'वैद्यकीय समस्या'),
(139556, 3622, 46, 'वैद्यकीय समस्या समस्या सूची'),
(139557, 3623, 46, 'वैद्यकीय समस्या'),
(139558, 3624, 46, 'वैद्यकीय नोंद'),
(139559, 3625, 46, 'वैद्यकीय नोंद #'),
(139560, 3626, 46, 'वैद्यकीय रेकॉर्ड'),
(139561, 3627, 46, 'पाठविलेला वैद्यकीय रेकॉर्ड'),
(139562, 3629, 46, 'वैद्यकीय सारांश दिले'),
(139563, 3630, 46, 'वैद्यकीय प्रणाली'),
(139564, 3631, 46, 'वैद्यकीय प्रकार'),
(139565, 3632, 46, 'वैद्यकीय / इतिहास (राइट, addonly पर्यायी)'),
(139566, 3633, 46, 'वैद्यकीय भाग ब'),
(139567, 3634, 46, 'वैद्यकीय संदर्भकर्त्यामध्ये प्रस्तुतकर्ता आहे'),
(139568, 3635, 46, 'औषधोपचार'),
(139569, 3636, 46, 'औषधोपचार ऍलर्जी यादी'),
(139570, 3637, 46, 'औषधोपचार समस्या सूची'),
(139571, 3638, 46, 'औषधोपचार यादी'),
(139572, 3639, 46, 'औषधोपचार सलोखा सादर?'),
(139573, 3640, 46, 'औषधे'),
(139574, 3641, 46, 'औषधे:'),
(139575, 3642, 46, 'औषध युनिट'),
(139576, 3643, 46, 'मध्यम'),
(139577, 3644, 46, 'MedlinePlus कनेक्ट'),
(139578, 3645, 46, 'सदस्य असोसिएशन सांख्यिकी अहवाल'),
(139579, 3646, 46, 'मेमरी समस्या'),
(139580, 3647, 46, 'पुरुष'),
(139581, 3648, 46, 'पुरुष आणि महिला'),
(139582, 3649, 46, 'पुरुष केवळ'),
(139583, 3650, 46, 'पहिली ऋतुप्राप्ती पहिल्यांदा मासिक पाळी येणे'),
(139584, 3651, 46, 'स्त्रियांच्या जीवनातील मासिकपाळी बंद होतो तो काळ'),
(139585, 3652, 46, 'मासिक फ्लो'),
(139586, 3653, 46, 'मासिक वारंवारता'),
(139587, 3654, 46, 'मानसिक आजार'),
(139588, 3655, 46, 'मेनू मजकूर'),
(139589, 3656, 46, 'मेनू'),
(139590, 3657, 46, 'विलीन'),
(139591, 3658, 46, 'पूर्ण विलीन करा.'),
(139592, 3659, 46, 'रुग्णांना विलीन'),
(139593, 3661, 46, 'संदेश'),
(139594, 3662, 46, 'संदेश आणि स्मरण केंद्र'),
(139595, 3663, 46, 'संदेश सामग्री तो एक दस्तऐवज म्हणून संग्रहित केले गेले आहे, त्यामुळे साधा मजकूर नाही.');
INSERT INTO `lang_definitions` VALUES
(139596, 3664, 46, 'रुग्णाला ते संदेश'),
(139597, 3665, 46, 'संदेश पाठवला'),
(139598, 3666, 46, 'संदेश स्थिती'),
(139599, 3667, 46, 'संदेश शीर्षक'),
(139600, 3668, 46, 'रुग्णाला संदेश'),
(139601, 3669, 46, 'संदेश प्रकार'),
(139602, 3670, 46, 'संदेश:'),
(139603, 3671, 46, 'संदेश'),
(139604, 3672, 46, 'आपण आज पाठविले आहे संदेश'),
(139605, 3673, 46, 'पद्धत'),
(139606, 3674, 46, 'पद्धत आणि विशिष्ट उत्पादन'),
(139607, 3675, 46, 'जाणार्या मेल पाठवून पद्धत.'),
(139608, 3676, 46, 'विनाश पद्धत'),
(139609, 3677, 46, 'मेक्सिकन / MexAmer / Chicano'),
(139610, 3679, 46, 'मिग्रॅ'),
(139611, 3680, 46, 'मिग्रॅ / 1cc'),
(139612, 3681, 46, 'मिग्रॅ / 2cc'),
(139613, 3682, 46, 'मिग्रॅ / 3cc'),
(139614, 3683, 46, 'मिग्रॅ / 4cc'),
(139615, 3684, 46, 'मिग्रॅ / 5cc'),
(139616, 3685, 46, 'Mg / dl'),
(139617, 3686, 46, 'मध्य'),
(139618, 3687, 46, 'मधले नाव'),
(139619, 3688, 46, 'मधले नाव'),
(139620, 3690, 46, 'Midlevel Prescriber DEA'),
(139621, 3691, 46, 'Midlevel Prescriber नाव'),
(139622, 3692, 46, 'Midlevel Prescriber आडनाव'),
(139623, 3693, 46, 'Midlevel Prescriber पूर्वपद'),
(139624, 3694, 46, 'Midlevel Prescriber UPIN'),
(139625, 3695, 46, 'Mien'),
(139626, 3696, 46, 'स्थलांतरित किंवा हंगामी कार्यकर्ता?'),
(139627, 3697, 46, 'स्थलांतरित / हंगामी'),
(139628, 3698, 46, 'रशीद / CU.MM'),
(139629, 3701, 46, 'MIME प्रकार'),
(139630, 3702, 46, 'MimeType'),
(139631, 3703, 46, 'किमान'),
(139632, 3704, 46, 'मि'),
(139633, 3705, 46, 'किमान वय'),
(139634, 3706, 46, 'लघु संयुक्त ताण +/- सीरमी पटलाचा दाह यामध्ये बहुधा सांध्यात द्रव जमतो, संधिदाह व दीर्घकाळ दाह झाल्याने ऍकिलोसिस होतो'),
(139635, 3708, 46, 'मिनिट'),
(139636, 3709, 46, 'मिनिटे'),
(139637, 3710, 46, 'मिनिटे'),
(139638, 3712, 46, 'इतर'),
(139639, 3713, 46, 'इतर बिलिंग पर्याय'),
(139640, 3714, 46, 'HCFA-1500 इतर बिलिंग पर्याय'),
(139641, 3715, 46, 'इतर बिलिंग पर्याय HCFA'),
(139642, 3716, 46, 'विविध'),
(139643, 3717, 46, 'नाही'),
(139644, 3718, 46, 'गहाळ'),
(139645, 3719, 46, 'आवश्यक फील्ड गहाळ'),
(139646, 3720, 46, 'गहाळ शुल्क'),
(139647, 3721, 46, 'गहाळ Mods फक्त'),
(139648, 3722, 46, 'गहाळ किंवा अवैध'),
(139649, 3723, 46, 'पी आय डी गहाळ झाले आहे.'),
(139650, 3724, 46, 'गहाळ अहवाल तारीख'),
(139651, 3725, 46, 'कोड स्रोत देणारा नंतर स्लॅश गहाळ '),
(139652, 3726, 46, 'मिश्र'),
(139653, 3727, 46, 'मिली'),
(139654, 3728, 46, 'DD / MM / YYYY असे'),
(139655, 3729, 46, 'मि.मी. / एचजी'),
(139656, 3730, 46, 'mmHg'),
(139657, 3731, 46, 'एमएमआर 1'),
(139658, 3732, 46, 'एमएमआर 2'),
(139659, 3733, 46, 'मोबाइल'),
(139660, 3734, 46, 'भ्रमणध्वनी'),
(139661, 3735, 46, 'सुधारित केलेली'),
(139662, 3738, 46, 'मध्यम प्राधान्य'),
(139663, 3740, 46, 'मध्यम / निम्न प्राधान्य'),
(139664, 3741, 46, 'सुधारणा'),
(139665, 3742, 46, 'सुधारकांचे'),
(139666, 3743, 46, 'सुधारित'),
(139667, 3745, 46, 'देयके संपादीत'),
(139668, 3746, 46, 'ModLength'),
(139669, 3747, 46, 'विभाग'),
(139670, 3748, 46, 'विभाग निर्देशिका आढळले नाही'),
(139671, 3749, 46, 'विभाग इंस्टॉलर'),
(139672, 3750, 46, 'विभाग नाव'),
(139673, 3751, 46, 'विभाग नाव आधीच अस्तित्वात'),
(139674, 3752, 46, 'मॉड्यूल'),
(139675, 3753, 46, 'सोम'),
(139676, 3754, 46, 'शुक्र गुंतवणूकदारांच्या सोम'),
(139677, 3755, 46, 'सोम, बुध करा & amp; शुक्र'),
(139678, 3756, 46, 'सोमवारी'),
(139679, 3757, 46, 'मंगोलियन'),
(139680, 3758, 46, 'महिना'),
(139681, 3759, 46, 'महिन्यात'),
(139682, 3760, 46, 'महिना पहा'),
(139683, 3761, 46, 'महिना (चे)'),
(139684, 3762, 46, 'मासिक उत्पन्न'),
(139685, 3763, 46, 'महिने'),
(139686, 3765, 46, '100 पेक्षा जास्त रेकॉर्ड सापडले नाही. आपला शोध निकष लहान करा.'),
(139687, 3766, 46, 'अधिक 50 परिणाम पेक्षा, आपल्या शोध अधिक विशिष्ट करा.'),
(139688, 3767, 46, 'सर्वाधिक रकान्याच्या क्रम क्रमवारी बदलण्यासाठी क्लिक केले जाऊ शकते'),
(139689, 3768, 46, 'सर्वात अलीकडील'),
(139690, 3769, 46, 'सर्वात अलीकडील लॅब डेटा:'),
(139691, 3770, 46, 'सर्वात अलीकडील मर्मस्थाने पासून:'),
(139692, 3771, 46, 'आई'),
(139693, 3772, 46, 'आईचे नाव'),
(139694, 3773, 46, 'माता इतिहास'),
(139695, 3774, 46, 'तोंड'),
(139696, 3775, 46, 'हलवा'),
(139697, 3776, 46, 'वर्ग दस्तऐवज हलवा:'),
(139698, 3777, 46, 'खाली हलवा'),
(139699, 3778, 46, 'हलवा अयशस्वी झाले!'),
(139700, 3779, 46, 'रुग्णांच्या हलवा'),
(139701, 3780, 46, 'पुढे व्हा...'),
(139702, 3781, 46, 'पुढे जा'),
(139703, 3782, 46, 'हलवित'),
(139704, 3783, 46, 'श्री.'),
(139705, 3784, 46, 'MRN (पी आय डी)'),
(139706, 3785, 46, 'सौ.'),
(139707, 3786, 46, 'श्रीमती'),
(139708, 3787, 46, 'MSH-11'),
(139709, 3788, 46, 'MSH-3.1'),
(139710, 3789, 46, 'MSH-4.1'),
(139711, 3790, 46, 'MSH-5.1'),
(139712, 3791, 46, 'MSH-6.1'),
(139713, 3793, 46, 'MSH.8 संदेश प्रकार वैध नाही'),
(139714, 3794, 46, 'किमान आधारभूत किंमत कोड'),
(139715, 3795, 46, 'किमान आधारभूत किंमत REMIT ि कोड'),
(139716, 3796, 46, 'मल्टी भाषा साधन'),
(139717, 3797, 46, 'अनेक भागात'),
(139718, 3798, 46, 'एकाधिक फाइल्स Ctrl + click किंवा SHIFT + क्लिक करा वापरून त्यांना निवडून एका वेळी अपलोड केले जाऊ शकते.'),
(139719, 3799, 46, 'अनेक बरेच'),
(139720, 3800, 46, 'अनेक सुधारकांचे, अपूर्ण विराम किंवा मोकळी जागा वेगळे केले जाऊ शकतात 4 जास्तीत जास्त (M1: M2: M3: M4)'),
(139721, 3801, 46, 'अनेक निवडा यादी'),
(139722, 3802, 46, 'बहुजातीय'),
(139723, 3803, 46, 'कुरकुर:'),
(139724, 3804, 46, 'Musc दुखणे'),
(139725, 3805, 46, 'Musc वेदना'),
(139726, 3806, 46, 'Musc लालसरपणा'),
(139727, 3807, 46, 'Musc कडकपणा जाणवणे'),
(139728, 3808, 46, 'Musc सूज'),
(139729, 3809, 46, 'उबदार Musc'),
(139730, 3810, 46, 'स्नायू'),
(139731, 3811, 46, 'स्नायू इजा'),
(139732, 3812, 46, 'अस्थी व स्नायू दोन्ही संस्थांविषयी'),
(139733, 3813, 46, 'या SMTP प्रमाणीकरण वापरले नाही, तर रिक्त असणे आवश्यक आहे.'),
(139734, 3814, 46, 'परस्पर परिभाषित'),
(139735, 3815, 46, 'करणे MVA'),
(139736, 3818, 46, 'मी स्वत:'),
(139737, 3820, 46, 'माओरी'),
(139738, 3821, 46, 'N / A'),
(139739, 3822, 46, 'एन / एक'),
(139740, 3823, 46, 'नाव'),
(139741, 3825, 46, 'नाव (अधिक क्लिक करा)'),
(139742, 3826, 46, '1 नाव'),
(139743, 3827, 46, '2 नाव'),
(139744, 3828, 46, 'नाव आणि लसीकरण प्रशासक शीर्षक'),
(139745, 3829, 46, 'EMR नाव'),
(139746, 3830, 46, 'नाव, उदाहरणार्थ icd9_274.11_en.pdf कारण codetype_code_language.pdf सारखी असणे आवश्यक आहे'),
(139747, 3831, 46, 'आगामी कार्यक्रम नाव'),
(139748, 3832, 46, 'विमा कंपनीचे नाव'),
(139749, 3833, 46, 'प्रदाता नाव'),
(139750, 3834, 46, 'रुग्ण स्मरणपत्रांकरिता प्रेषक नाव.'),
(139751, 3835, 46, 'नाव भाषांतर'),
(139752, 3836, 46, 'नाव / मूल्य'),
(139753, 3837, 46, 'नाव:'),
(139754, 3838, 46, 'नाकपुडया:'),
(139755, 3839, 46, 'नाकपुडया: सामान्य अधिकार'),
(139756, 3840, 46, 'अनुनासिक श्लेष्मल त्वचा गुलाबी, septum midline'),
(139757, 3841, 46, 'राष्ट्र टिपा'),
(139758, 3842, 46, 'राष्ट्र टिपा संरचीत करा'),
(139759, 3843, 46, 'राष्ट्र टिपा बटणे बदला'),
(139760, 3844, 46, 'राष्ट्रीयत्व'),
(139761, 3845, 46, 'NationNotes'),
(139762, 3846, 46, 'मूळ डेटा लोड'),
(139763, 3847, 46, 'मुळ हवाईयन किंवा इतर पॅसिफिक आयलॅंडर'),
(139764, 3851, 46, 'नऊरु'),
(139765, 3852, 46, 'मळमळणे'),
(139766, 3853, 46, 'नावाजो, Navaho'),
(139767, 3854, 46, 'नेव्हिगेशन'),
(139768, 3855, 46, 'सुचालन क्षेत्र चकमकीत फॉर्म समावेश'),
(139769, 3856, 46, 'सुचालन क्षेत्र frameset पूर्ण उंची वापरते'),
(139770, 3857, 46, 'सुचालन क्षेत्र भेट द्या अर्ज'),
(139771, 3858, 46, 'नेव्हिगेशन क्षेत्र रूंदी'),
(139772, 3859, 46, 'सुचालन मेनू रेडिओ बटण जोड समाविष्टीत आहे ज्यामध्ये'),
(139773, 3860, 46, 'नेव्हिगेशन मेनू एक झाड दृश्य आहे'),
(139774, 3861, 46, 'सुचालन एक सरकता मेनू वापरते'),
(139775, 3862, 46, 'एनडीसी'),
(139776, 3863, 46, 'एनडीसी डेटा'),
(139777, 3864, 46, 'एनडीसी क्रमांक'),
(139778, 3865, 46, 'डोंगा'),
(139779, 3866, 46, 'मान'),
(139780, 3867, 46, 'मान समस्या'),
(139781, 3868, 46, 'लवचिक मान'),
(139782, 3869, 46, 'वर्णन प्रविष्ट करणे आवश्यक आहे'),
(139783, 3870, 46, 'रिटर्न मूल्य प्रविष्ट करणे आवश्यक आहे'),
(139784, 3871, 46, 'अभिज्ञापक प्रविष्ट करणे आवश्यक आहे'),
(139785, 3872, 46, 'शीर्षक प्रविष्ट करणे आवश्यक'),
(139786, 3873, 46, 'प्रमाणिकरण गरज'),
(139787, 3874, 46, 'गरजा जस्टिफाय करा'),
(139788, 3875, 46, 'माध्यमिक बिलिंग गरज'),
(139789, 3876, 46, 'नकारात्मक'),
(139790, 3877, 46, 'नकारात्मक'),
(139791, 3879, 46, 'नेपाळी'),
(139792, 3880, 46, 'मज्जातंतू इजा'),
(139793, 3881, 46, 'मज्जासंस्थेसंबंधीचा स्थिती / मज्जातंतू नुकसान'),
(139794, 3882, 46, 'न्यूरो-नाण्यासारखा'),
(139795, 3883, 46, 'न्यूरो-अशक्तपणा'),
(139796, 3884, 46, 'Neurologic'),
(139797, 3885, 46, 'कधीही'),
(139798, 3886, 46, 'कधीही मद्यार्क'),
(139799, 3887, 46, 'कधीही धूम्रपान'),
(139800, 3888, 46, 'नवीन'),
(139801, 3889, 46, 'नवीन =>'),
(139802, 3890, 46, 'नवीन Acceptors'),
(139803, 3892, 46, 'नवीन ऍलर्जी'),
(139804, 3893, 46, 'नवीन दुरुस्ती विनंती'),
(139805, 3894, 46, 'नवीन नियुक्ती'),
(139806, 3895, 46, 'नवीन श्रेणी'),
(139807, 3896, 46, 'नवीन श्रेणी'),
(139808, 3897, 46, 'नवीन ग्राहक'),
(139809, 3898, 46, 'नवीन सल्ला'),
(139810, 3899, 46, 'नवीन पीक'),
(139811, 3900, 46, 'नवी व्याख्या संच जोडले'),
(139812, 3901, 46, 'नवीन दस्तऐवज'),
(139813, 3902, 46, 'नवीन दस्तऐवज'),
(139814, 3904, 46, 'नवीन आढळतात'),
(139815, 3905, 46, 'आयडी तयार नवीन चकमकीत'),
(139816, 3906, 46, 'नवीन चकमकीत फॉर्म'),
(139817, 3907, 46, 'नवीन चकमकी अधिकृत नाही'),
(139818, 3908, 46, 'नवीन Enctr'),
(139819, 3909, 46, 'नवीन सुविधा माहिती'),
(139820, 3910, 46, 'नवीन फाइल'),
(139821, 3911, 46, 'नवीन फायली'),
(139822, 3912, 46, 'नवीन गट'),
(139823, 3913, 46, 'नवीन गट माहिती'),
(139824, 3914, 46, 'नवीन Inj / स्थिती'),
(139825, 3916, 46, 'आगामी कार्यक्रम नवीन मर्यादा'),
(139826, 3917, 46, 'नवीन यादी'),
(139827, 3918, 46, 'नवीन ऑर्डर'),
(139828, 3919, 46, 'नवीन परिच्छेद'),
(139829, 3920, 46, 'नवीन पासवर्ड'),
(139830, 3921, 46, 'नवीन रुग्णांच्या'),
(139831, 3922, 46, 'नवी रुग्ण'),
(139832, 3923, 46, 'नवीन रुग्णांच्या आढळतात'),
(139833, 3924, 46, 'नवीन रुग्णांच्या फॉर्म'),
(139834, 3925, 46, 'नवीन रुग्णांच्या आयडी'),
(139835, 3926, 46, 'नवीन भरणा'),
(139836, 3927, 46, 'नवीन पोर्टल लॉगिन'),
(139837, 3928, 46, 'नवीन पं'),
(139838, 3929, 46, 'लॅब एक्सचेंज नवीन परिणाम'),
(139839, 3930, 46, 'नवीन शोध'),
(139840, 3931, 46, 'नवीन सबमिशन'),
(139841, 3932, 46, 'नवीन वापरकर्ता'),
(139842, 3933, 46, 'नवीन मूल्य'),
(139843, 3934, 46, 'नवीन भेट द्या'),
(139844, 3935, 46, 'नवीन / शोध'),
(139845, 3936, 46, 'NewCrop खाते स्थिती'),
(139846, 3937, 46, 'NewCrop प्रशासन'),
(139847, 3938, 46, 'NewCrop कॉल अयशस्वी'),
(139848, 3939, 46, 'NewCrop डॉक्टर'),
(139849, 3940, 46, 'NewCrop eRx खाते आयडी'),
(139850, 3944, 46, 'NewCrop eRx नाव'),
(139851, 3945, 46, 'NewCrop eRx भागीदार नाव'),
(139852, 3946, 46, 'NewCrop eRx पासवर्ड'),
(139853, 3947, 46, 'NewCrop eRX भूमिका'),
(139854, 3948, 46, 'NewCrop eRx भूमिका'),
(139855, 3949, 46, 'NewCrop eRx साइट पत्ता'),
(139856, 3950, 46, 'अॅलर्जी साठी NewCrop eRx SOAP विनंती वेळ-टू-थेट'),
(139857, 3951, 46, 'औषधे साठी NewCrop eRx SOAP विनंती वेळ-टू-थेट'),
(139858, 3954, 46, 'NewCrop eRx वेब सेवा पत्ता'),
(139859, 3955, 46, 'NewCrop व्यवस्थापक'),
(139860, 3956, 46, 'NewCrop MedEntry'),
(139861, 3957, 46, 'NewCrop Midlevel Prescriber'),
(139862, 3958, 46, 'NewCrop नर्स'),
(139863, 3959, 46, 'NewCrop देखरेख डॉक्टर'),
(139864, 3960, 46, 'घ्या'),
(139865, 3961, 46, 'वृत्तपत्र'),
(139866, 3962, 46, 'पुढील'),
(139867, 3964, 46, 'उद्या'),
(139868, 3965, 46, 'पुढील महिन्यात'),
(139869, 3966, 46, 'पुढील महिन्यात (मेनू ठेवण्यासाठी)'),
(139870, 3967, 46, 'पुढील अनुसूचित चालवा'),
(139871, 3968, 46, 'पुढील आठवडा'),
(139872, 3969, 46, 'पुढील वर्षी (मेनू ठेवण्यासाठी)'),
(139873, 3970, 46, 'निक नाव'),
(139874, 3971, 46, 'टोपणनाव'),
(139875, 3973, 46, 'रात्र घाम'),
(139876, 3974, 46, 'नॅथन, EXT जननेंद्रिये, vag श्लेष्मल त्वचा, गर्भाशय'),
(139877, 3975, 46, 'कोणत्याही'),
(139878, 3976, 46, 'नाही'),
(139879, 3977, 46, 'प्रवेश'),
(139880, 3978, 46, 'सक्रिय रुग्ण स्मरणपत्रे.'),
(139881, 3979, 46, 'कोणत्याही ग्रंथीचा कुठलाही रोग (2 भागात आवश्यक)'),
(139882, 3980, 46, 'आढळले नाही समायोजन कारण प्रकार'),
(139883, 3981, 46, 'कोणत्याही adnexal प्रेमळपणा / पशुपालकांना'),
(139884, 3982, 46, 'उपलब्ध नाही दुरुस्ती विनंत्या'),
(139885, 3983, 46, 'कोणत्याही नियुक्ती'),
(139886, 3984, 46, 'कोणत्याही ऑडिट लॉग निवडलेली तारीख श्रेणी आढळले छेडछाड.'),
(139887, 3985, 46, 'कोणत्याही बिलिंग प्रणाली सध्या सक्रिय आहे'),
(139888, 3986, 46, 'OFX निर्यात मध्ये समाविष्ट करण्यासाठी आढळली नाहीत बिले'),
(139889, 3987, 46, 'कोणत्याही बिले OFX निर्यात मध्ये समाविष्ट करण्यासाठी सापडले प्रवास'),
(139890, 3989, 46, 'कोणत्याही कोड निर्दिष्ट करण्यात आला!'),
(139891, 3990, 46, 'या उपक्रमातील परिभाषित नाही संरचना'),
(139892, 3992, 46, 'कोणत्याही निदान'),
(139893, 3993, 46, 'दस्तऐवज आढळले नाहीत'),
(139894, 3994, 46, 'कोणत्याही चकमकीत निर्माण करता येऊ शकते'),
(139895, 3995, 46, 'समाप्तीची तारीख नाही'),
(139896, 3996, 46, 'आढळले नाही नोंदी, नोंद जोडण्यासाठी खालील फॉर्म वापरा.'),
(139897, 3997, 46, 'कोणत्याही त्रुटी आढळल्या'),
(139898, 3998, 46, 'कोणत्याही आगामी कार्यक्रम'),
(139899, 4000, 46, 'कोणत्याही फायली प्रतिष्ठापनासाठी आयोजित'),
(139900, 4001, 46, 'समूह निवड करण्यात आली'),
(139901, 4002, 46, 'कोणत्याही अन्तर्गळ'),
(139902, 4003, 46, 'या उपक्रमातील उपलब्ध नाही हूक्सचा'),
(139903, 4004, 46, 'या उपक्रमातील सक्षम केलेले कोणतेही हूक्सचा'),
(139904, 4005, 46, 'कोणत्याही इजा / आजार'),
(139905, 4006, 46, 'कोणत्याही विमा कंपन्या सापडले'),
(139906, 4007, 46, 'कोणत्याही समस्या नाहीत'),
(139907, 4008, 46, 'या घटनेचा नाही मुद्दे.'),
(139908, 4009, 46, 'निवडलेल्या विभागातील अंतर्गत कोणतेही आयटम नाहीत'),
(139909, 4010, 46, 'कोणतेही आयटम निवडले होते!'),
(139910, 4024, 46, 'कोणत्याही लॅब डेटा दस्तऐवजीकरण.'),
(139911, 4025, 46, 'कोणत्याही लॉग फाइल निवडलेली तारीख अस्तित्वात'),
(139912, 4027, 46, 'कोणत्याही पशुपालकांना, प्रेमळपणा'),
(139913, 4028, 46, 'दिलेल्या पुन्हा Idenitification कोड आढळले नाही सामन्यात रुग्णांच्या रेकॉर्ड'),
(139914, 4029, 46, 'जुळण्या आढळल्या नाहीत. पुन्हा शोध प्रयत्न करा.'),
(139915, 4030, 46, 'जुळण्या आढळल्या नाहीत.'),
(139916, 4031, 46, 'जुळण्या आढळल्या नाहीत. आता नवीन रुग्ण तयार करा?'),
(139917, 4032, 46, 'कोणतेही जुळणारे रेकॉर्ड सापडले'),
(139918, 4033, 46, 'नवीन परिणाम आढळले'),
(139919, 4034, 46, 'कोणत्याही टिपा'),
(139920, 4035, 46, 'कोणत्याही ogrganomegoly'),
(139921, 4036, 46, 'कोणत्याही संबंधी या काळात सापडले नाहीत.'),
(139922, 4037, 46, 'अन्य कोणताही फोन नंबर सूचीबद्ध'),
(139923, 4038, 46, 'पॅरामीटर निवड'),
(139924, 4039, 46, 'आढळली नाहीत भागीदार'),
(139925, 4040, 46, 'दिलेल्या निवड निकष आढळले नाही रुग्णांच्या रेकॉर्ड'),
(139926, 4041, 46, 'दिलेल्या पुन्हा ओळख कोड आढळले नाही रुग्णांच्या रेकॉर्ड'),
(139927, 4042, 46, 'कोणत्याही गौण सूज'),
(139928, 4043, 46, 'कोणत्याही औषध सापडले'),
(139929, 4044, 46, 'कोणत्याही चांगले आढळले'),
(139930, 4045, 46, 'कोणत्याही सादर आजार / दुखापत'),
(139931, 4046, 46, 'मागील नोंदी.'),
(139932, 4047, 46, 'कोणत्याही प्राथमिक व्यवसाय अस्तित्व सुविधा यादी निवडलेल्या'),
(139933, 4048, 46, 'नाही अगोदर चकमकी.'),
(139934, 4049, 46, 'या घटनेचा नाही कार्यपद्धती.'),
(139935, 4051, 46, 'कोणत्याही प्रदाते सापडले'),
(139936, 4052, 46, 'कोणत्याही पुरळ किंवा असामान्य विकृती'),
(139937, 4053, 46, 'कोणतीही रेकॉर्ड सापडले'),
(139938, 4055, 46, 'कोणत्याही रेकॉर्ड सापडले नाही. आपला शोध निकष विस्तृत करा.'),
(139939, 4056, 46, 'स्मरणपत्रे'),
(139940, 4057, 46, 'कोणतेही परिणाम वरील शोध निकष, सापडले.'),
(139941, 4058, 46, 'परिणाम नाहीत'),
(139942, 4059, 46, 'कोणतेही परिणाम आढळले नाहीत'),
(139943, 4060, 46, 'कोणत्याही परिणाम साठी शोध सापडले'),
(139944, 4061, 46, 'कोणतेही परिणाम आढळले नाहीत, पुन्हा प्रयत्न करा.'),
(139945, 4062, 46, 'कोणतेही परिणाम, पुन्हा ट्रे करा.'),
(139946, 4063, 46, 'कोणतेही परिणाम, पुन्हा प्रयत्न करा.'),
(139947, 4064, 46, 'कोणत्याही सेटिंग्ज उपक्रमातील avaliable'),
(139948, 4065, 46, 'कोणताही शो'),
(139949, 4066, 46, 'फाइल नाही स्वाक्षर्या'),
(139950, 4067, 46, 'कोणत्याही सायनस दयाळूपणा:'),
(139951, 4068, 46, 'कोणत्याही त्वचा dimpling किंवा आईच्या गाठी'),
(139952, 4069, 46, 'नाही अशा CONTEXT NAME ना'),
(139953, 4070, 46, 'सारणी निवडले! एक टेबल निवडा.'),
(139954, 4071, 46, 'कोणत्याही testicular प्रेमळपणा, जनतेला'),
(139955, 4072, 46, 'कोणत्याही थरार किंवा heaves'),
(139956, 4073, 46, 'निवडलेला नाही ट्रॅक'),
(139957, 4074, 46, 'ट्रॅक दस्तऐवजीकरण गेले आहेत.'),
(139958, 4075, 46, 'कोणत्याही भेट'),
(139959, 4076, 46, 'कोणत्याही मर्मस्थाने दस्तऐवजीकरण गेले आहेत.'),
(139960, 4077, 46, 'नाही, रद्द करा'),
(139961, 4078, 46, 'ऑटो समावेश नाही-दोष विमा प्राथमिक आहे'),
(139962, 4079, 46, 'कोणत्याही:'),
(139963, 4080, 46, 'रात्री लघवी जास्त प्रमाणात होणे'),
(139964, 4081, 46, 'नॉन अदा'),
(139965, 4082, 46, 'नॉन अहवाल नोंदविले'),
(139966, 4083, 46, 'नॉन विशिष्ट इजा'),
(139967, 4084, 46, 'नॉन-इलेक्ट्रॉनिक'),
(139968, 4085, 46, 'नॉन-मधुमेहावरील रामबाण उपाय अवलंबून मधुमेह'),
(139969, 4086, 46, 'नॉन-विम्याची'),
(139970, 4087, 46, 'नॉन-SRH वैद्यकीय'),
(139971, 4088, 46, 'नॉन-SRH नॉन-वैद्यकीय'),
(139972, 4089, 46, 'काहीही'),
(139973, 4090, 46, 'कोणीही'),
(139974, 4091, 46, 'काहीही व्याख्या'),
(139975, 4092, 46, 'काहीही दस्तऐवजीकरण गेले आहेत'),
(139976, 4093, 46, 'वरीलपैकी काहीही नाही'),
(139977, 4094, 46, 'शीर्ष वितरण रो काहीही पूर्ण रिकामी होऊ शकतो.'),
(139978, 4095, 46, 'Noninsulin अवलंबून मधुमेह'),
(139979, 4096, 46, 'किंवा'),
(139980, 4097, 46, 'सामान्य'),
(139981, 4098, 46, 'सामान्य बी.एल.'),
(139982, 4099, 46, 'सामान्य कार्डिऍक परीक्षा:'),
(139983, 4100, 46, 'सामान्य कार्डिऍक परीक्षा: '),
(139984, 4101, 46, 'सामान्य फुफ्फुसांचा परीक्षा:'),
(139985, 4102, 46, 'सामान्य फुफ्फुसांचा परीक्षा: '),
(139986, 4103, 46, 'सामान्य कार्यालय भेट द्या'),
(139987, 4104, 46, 'सामान्य घशाखालील भाग:'),
(139988, 4105, 46, 'सामान्य अधिकार'),
(139989, 4106, 46, 'सामान्य अधिकार:'),
(139990, 4107, 46, 'सामान्य पहा'),
(139991, 4108, 46, 'सामान्य:'),
(139992, 4109, 46, 'साधारणपणे हे तपासले पाहिजे. नियंत्रण प्रवेश संबंधित नाही.'),
(139993, 4110, 46, 'उत्तरी देबेली'),
(139994, 4111, 46, 'नॉर्दन सामी'),
(139995, 4112, 46, 'नॉर्वेजियन'),
(139996, 4113, 46, 'नॉर्वेजियन बोकमाल'),
(139997, 4114, 46, 'नॉर्वेजियन न्योर्स्क'),
(139998, 4115, 46, 'नाक'),
(139999, 4116, 46, 'Nosebleed'),
(140000, 4117, 46, 'नाही एक पत्र किंवा संख्या'),
(140001, 4119, 46, 'सर्व फील्ड सर्व कोड किंवा कोड प्रकार आवश्यक आहेत नाही.'),
(140002, 4120, 46, 'परवानगी नाही'),
(140003, 4121, 46, 'प्रशासक गट हटवू परवानगी नाही'),
(140004, 4122, 46, 'संपादित करण्याची अनुमती नाही'),
(140005, 4123, 46, 'सर्व सुरक्षा वस्तू निष्क्रिय करण्याची परवानगी नाही'),
(140006, 4124, 46, 'नाही प्रशासक ACL यांना आधार देतो काही निष्क्रिय करण्याची परवानगी'),
(140007, 4125, 46, 'प्रशासक गट प्रशासक वापरकर्ता काढण्यासाठी परवानगी नाही'),
(140008, 4126, 46, 'प्रशासक गट या वापरकर्त्याच्या काढण्यासाठी परवानगी नाही'),
(140009, 4127, 46, 'लागू नाही'),
(140010, 4128, 46, 'PostCalendar विभाग प्रवेश करण्यास अधिकृत नाही'),
(140011, 4129, 46, 'अधिकृत नाही'),
(140012, 4130, 46, 'अधिकृत नाही'),
(140013, 4131, 46, 'या संघात अधिकृत नाही!'),
(140014, 4132, 46, 'या संघात अधिकृत नाही.'),
(140015, 4133, 46, 'वापरकर्ते व्यवस्थापित करण्यासाठी अधिकृत नाही!'),
(140016, 4134, 46, 'परिणाम साइन इन करण्यासाठी अधिकृत नाही'),
(140017, 4135, 46, 'उपलब्ध नाही'),
(140018, 4137, 46, 'बिल नाही'),
(140019, 4138, 46, 'चेक-इन केले नाही'),
(140020, 4139, 46, 'बाहेर तपासले नाही'),
(140021, 4140, 46, 'कोड नाही'),
(140022, 4141, 46, 'मुळे नाही'),
(140023, 4143, 46, 'तपासणी नाही'),
(140024, 4144, 46, 'तपासणी नाही:'),
(140025, 4145, 46, 'तपासणी नाही: '),
(140026, 4146, 46, 'आढळले नाही'),
(140027, 4148, 46, 'आढळले नाही!'),
(140028, 4149, 46, 'हिस्पॅनिक किंवा लॅटिनो नाही'),
(140029, 4150, 46, 'स्थापित नाही'),
(140030, 4151, 46, 'स्थापित नाही'),
(140031, 4152, 46, 'पासून पाहिले नाही'),
(140032, 4153, 46, 'पाठविले नाही'),
(140033, 4154, 46, 'नाही पण पाठविले'),
(140034, 4155, 46, 'हिन्दू नाही'),
(140035, 4156, 46, 'हिन्दू नाही.'),
(140036, 4157, 46, 'टीप'),
(140037, 4158, 46, 'टीप कोड'),
(140038, 4159, 46, 'तो आपण स्थापित क्लिक केल्यानंतर पूर्णपणे प्रक्रिया 5-10 मिनिटे लागतील टीप'),
(140039, 4160, 46, 'तुम्ही अपग्रेड क्लिक करा नंतर तो पूर्णपणे प्रक्रिया 5-10 मिनिटे लागतील टीप'),
(140040, 4161, 46, 'की ऑडिट लॉग लक्षात ठेवा वरील सक्षम करणे आवश्यक'),
(140041, 4162, 46, 'टीप प्रकार'),
(140042, 4163, 46, 'टीप: 12:00 दुपारी पंतप्रधान आहे, आहे नाही'),
(140043, 4164, 46, 'टीप: बाह्य डेटा आयात आपले हार्डवेअर संरचना अवलंबून एक तासापेक्षा अधिक घेऊ शकता. उदाहरणार्थ, RxNorm डेटा सारण्या एक 6 दशलक्ष पंक्ती जास्त असतात.'),
(140044, 4165, 46, 'सुचना: केवळ वर्षातून दोनदा आंतरराष्ट्रीय Snomed प्रकाशन सध्या समर्थीत आहे'),
(140045, 4166, 46, 'सुचना: केवळ पूर्ण मासिक RxNorm प्रकाशन सध्या समर्थीत आहे'),
(140046, 4168, 46, 'टीप: हा कोड अधिकृत वापरकर्ता नोंदलेली नाही. केवळ अधिकृत कोड प्रक्रिया उघडा वैद्यकीय बिल भरण्याची नेटवर्क अपलोड केले जाऊ शकते. आपण या कोड अपलोड करण्याची इच्छा असेल तर, येथे एक अधिकृत वापरकर्ता निवडा.'),
(140047, 4170, 46, 'सुचना: डुप्लिकेट नावे फायली अपलोड आपोआप पुनर्नामित करणे फाइल (उदाहरणार्थ, file.jpg file.1.jpg होईल) होऊ आहे. नाव रुग्ण दर, नाही श्रेणी प्रति अद्वितीय मानले जातात.'),
(140048, 4171, 46, 'सुचना: डुप्लिकेट नावे फायली अपलोड केलेल्या फाइल्स स्वयंचलितपणे नामकरण करतील. उदाहरणार्थ ''तो <i> file.jpg </ I>'' ''तो <i> file.jpg.1 </ I>'' होईल. नाव रुग्ण दर, नाही श्रेणी प्रति अद्वितीय मानले जातात.'),
(140049, 4172, 46, 'नोट्स'),
(140050, 4173, 46, 'नोट्स - कोणत्याही चकमकी (addonly पर्यायी, लिहा)'),
(140051, 4174, 46, 'नोट्स - माझ्या चकमकी (addonly पर्यायी, लिहा)'),
(140052, 4175, 46, 'अधिकृत नाही नोट्स'),
(140053, 4176, 46, 'मंजूरीसाठी प्रलंबित काहीही'),
(140054, 4177, 46, 'काहीही रेकॉर्ड'),
(140055, 4179, 46, 'काहीही ऍलर्जी साठी आयात करण्यासाठी'),
(140056, 4180, 46, 'लिहून दिलेली औषधे व आयात काहीही'),
(140057, 4181, 46, 'दर्शवण्यासाठी काही नाही'),
(140058, 4182, 46, 'काहीही निवड करण्यात आली'),
(140059, 4183, 46, 'सूचना प्राप्त'),
(140060, 4184, 46, 'सूचना :: PostCalendar सादर / बदल'),
(140061, 4185, 46, 'सूचना'),
(140062, 4186, 46, 'सूचना ई-मेल पत्ता'),
(140063, 4188, 46, 'सूचना'),
(140064, 4189, 46, 'कार्यक्रम सबमिशनची / बदल बद्दल प्रशासन सूचित करा?'),
(140065, 4190, 46, 'नोव्हेंबर'),
(140066, 4191, 46, 'नोव्हेंबर'),
(140067, 4192, 46, 'आता पोस्ट:'),
(140068, 4193, 46, 'आता छपाई'),
(140069, 4194, 46, 'आता $ stmt_count स्टेटमेन्ट छपाई आणि चकमकी अद्ययावत करणे.'),
(140070, 4195, 46, 'आता $ stmt_count स्टेटमेन्ट छपाई आणि पावत्या अद्ययावत करणे.'),
(140071, 4196, 46, 'आता $ stmt_count स्टेटमेन्ट मुद्रण; चकमकी अद्यतनित केला जाणार नाही.'),
(140072, 4197, 46, 'आता $ stmt_count स्टेटमेन्ट मुद्रण; पावत्या अद्यतनित केला जाणार नाही.'),
(140073, 4198, 46, 'NPI'),
(140074, 4199, 46, 'NQF'),
(140075, 4200, 46, 'क्रमांक'),
(140076, 4201, 46, 'क्रमांक लॅब्ज'),
(140077, 4204, 46, 'वर्ष दृश्य स्तंभ संख्या.'),
(140078, 4211, 46, 'क्लायंट प्रमाणपत्र वैध आहे की दिवस संख्या.'),
(140079, 4213, 46, 'चलन, सहसा 0 किंवा 2 दशांश बिंदू नंतर अंक संख्या.'),
(140080, 4214, 46, 'चकमक क्रमांक प्रति पृष्ठ प्रदर्शित करण्यासाठी.'),
(140081, 4215, 46, 'जर असेल तर खेळ किंवा प्रसंग संख्या, नाही'),
(140082, 4216, 46, 'आगाऊ तास संख्या ईमेल सूचना पाठवू.'),
(140083, 4217, 46, 'आगाऊ तास संख्या फोन सूचना पाठविण्यासाठी.'),
(140084, 4218, 46, 'आगाऊ तास संख्या एसएमएस सूचना पाठवू.'),
(140085, 4221, 46, 'गेल्या इतिहास स्तंभ संख्या'),
(140086, 4222, 46, 'रुग्णांची संख्या रुग्ण यादीत प्रति पृष्ठ प्रदर्शित करण्यासाठी.'),
(140087, 4223, 46, 'नाण्यासारखा'),
(140088, 4224, 46, 'अंश'),
(140089, 4225, 46, 'अंकीय प्रदर्शन आदेश'),
(140090, 4226, 46, 'Nuosu'),
(140091, 4227, 46, 'पोषण'),
(140092, 4228, 46, 'पौष्टिक'),
(140093, 4229, 46, 'O.A.F.V.'),
(140094, 4230, 46, 'शनि, O2'),
(140095, 4231, 46, 'लठ्ठपणा मी'),
(140096, 4232, 46, 'लठ्ठपणा दुसरा'),
(140097, 4233, 46, 'लठ्ठपणा तिसरा'),
(140098, 4234, 46, 'उद्देश'),
(140099, 4236, 46, 'ऑक्सितान'),
(140100, 4237, 46, 'उद्योग'),
(140101, 4239, 46, 'घटना'),
(140102, 4240, 46, 'ऑक्टोबर'),
(140103, 4241, 46, 'ऑक्टोबर'),
(140104, 4242, 46, 'ओव्हरड्राफ्ट'),
(140105, 4243, 46, 'च्या'),
(140106, 4244, 46, 'प्रमाणात'),
(140107, 4245, 46, 'गोळ्या'),
(140108, 4246, 46, 'महिन्याच्या प्रत्येक'),
(140109, 4247, 46, 'Ofc टिपा'),
(140110, 4248, 46, 'बंद'),
(140111, 4249, 46, 'कार्यालय टिपा'),
(140112, 4250, 46, 'कार्यालय भेट द्या'),
(140113, 4251, 46, 'अधिकृत क्लिनिकल गुणवत्ता उपाय (CQM) माप गट'),
(140114, 4252, 46, 'रुग्णांच्या पोर्टल offsite HTTPS दुवा.'),
(140115, 4253, 46, 'रुग्णांच्या पोर्टल offsite HTTPS दुवा. (रुग्णांच्या दुवा)'),
(140116, 4254, 46, 'Offsite रुग्णांच्या पोर्टल पासवर्ड'),
(140117, 4255, 46, 'Offsite रुग्णांच्या पोर्टल पासवर्ड (नोंदणीकृत नाही, तर रिक्त ठेवा).'),
(140118, 4256, 46, 'Offsite रुग्णांच्या पोर्टल प्रदाता आयडी'),
(140119, 4257, 46, 'Offsite रुग्णांच्या पोर्टल प्रदाता आयडी (नोंदणीकृत नाही, तर रिक्त ठेवा).'),
(140120, 4258, 46, 'Offsite रुग्णांच्या पोर्टल साइट पत्ता'),
(140121, 4259, 46, 'Offsite रुग्णांच्या पोर्टल साइट पत्ता (रुग्णांच्या दुवा)'),
(140122, 4260, 46, 'Offsite रुग्णांच्या पोर्टल वापरकर्तानाव'),
(140123, 4261, 46, 'Offsite रुग्णांच्या पोर्टल वापरकर्तानाव (नोंदणीकृत नाही, तर रिक्त ठेवा).'),
(140124, 4262, 46, 'Offsite पोर्टल वेब सेवा अपयशी'),
(140125, 4263, 46, 'संतती'),
(140126, 4264, 46, 'संतती इतिहास'),
(140127, 4265, 46, 'सुगंधी'),
(140128, 4266, 46, 'Ojibwe, ओजिब्वा'),
(140129, 4267, 46, 'ठीक आहे'),
(140130, 4268, 46, 'या इतर पॉपअप विंडो बंद करण्यासाठी ओके?'),
(140131, 4269, 46, 'दिनांक GCAC समस्या दुवा ओके'),
(140132, 4270, 46, 'जुने'),
(140133, 4271, 46, 'ओल्ड चर्च स्लाव्होनिक, चर्च स्लाव्होनिक, ओल्ड बल्गेरियन'),
(140134, 4272, 46, 'जुने ग्राहक'),
(140135, 4273, 46, 'जुने फ्रॅक्चर नॉन / अस्थिभंगाचे अयोग्य सांघणे'),
(140136, 4274, 46, 'डाव्या मेनू जुन्या शैली मांडणी'),
(140137, 4275, 46, 'शोध किंवा दुप्पट चेक न जुन्या प्रकारची स्थिर फॉर्म'),
(140138, 4276, 46, 'जुने'),
(140139, 4277, 46, 'वगळणे'),
(140140, 4278, 46, 'मान्य वगळणे'),
(140141, 4279, 46, 'रुग्ण लोकसंख्याशास्त्र मध्ये नियोक्ता माहिती वगळणे'),
(140142, 4280, 46, 'बनवायला झटपट नियोक्ते'),
(140143, 4281, 46, 'नंतर डोस भाग होण्यासाठी कोणत्या फॉर्म, मार्ग आणि मध्यांतर वगळणे'),
(140144, 4282, 46, 'विमा वगळणे आणि लोकसंख्याशास्त्र काही इतर गोष्टी तयार'),
(140145, 4283, 46, 'अंतर्गत वापरकर्त्यांसाठी वगळणे?'),
(140146, 4284, 46, 'सहकारी वेतन आयोगाच्या पैसे पद्धत वगळणे'),
(140147, 4285, 46, 'autoassign करण्यासाठी वगळणे'),
(140148, 4286, 46, 'वर'),
(140149, 4287, 46, 'रोजी'),
(140150, 4288, 46, 'हातावर'),
(140151, 4289, 46, 'ऑर्डर रोजी'),
(140152, 4290, 46, 'साइटवर'),
(140153, 4291, 46, 'प्राथमिक व्यवसाय सुविधा सेट झाल्यावर, ते बदलले जाऊ नये. सुविधा बदलणे NewCrop ePrescription कार्य प्रभावित करेल.'),
(140154, 4292, 46, 'आपण आपला संकेतशब्द बदलला एकदा, आपण पुन्हा लॉग इन करणे आवश्यक आहे.'),
(140155, 4297, 46, 'ऑनलाईन समर्थन'),
(140156, 4298, 46, 'ऑनलाईन समर्थन दुवा'),
(140157, 4299, 46, 'फक्त सक्रिय'),
(140158, 4300, 46, 'फक्त लागू प्रदाता किंवा collated यादी वरील निवड करण्यात आली होती तर. केवळ प्राथमिक प्रदाता प्राथमिक प्रदाता आहे की रुग्णांना निवडते. चकमकीत प्रदाता पाहिले आहे की सर्व रुग्णांना निवडते.'),
(140159, 4302, 46, 'फक्त तर बिलिंग स्थान'),
(140160, 4303, 46, 'फक्त निष्क्रिय'),
(140161, 4304, 46, 'फक्त माझे'),
(140162, 4305, 46, 'फक्त शो निदान अहवाल कोड'),
(140163, 4306, 46, 'फक्त शो सेवा कोड वित्त अहवाल कोड'),
(140164, 4307, 46, 'फक्त सक्रीय चांगले अपलोड'),
(140165, 4309, 46, 'चालू लक्षणे किंवा आजार दिसायला लागायच्या'),
(140166, 4310, 46, 'आजार दिसायला लागायच्या:'),
(140167, 4311, 46, 'Ilness दिसायला लागायच्या: '),
(140168, 4312, 46, 'सूज दिसायला लागायच्या:'),
(140169, 4313, 46, 'दिसायला लागायच्या / हॉस्पिटल. तारीख:'),
(140170, 4314, 46, 'Onsite रुग्णांच्या पोर्टल साइट पत्ता'),
(140171, 4315, 46, 'अरेरे!'),
(140172, 4316, 46, 'ओपन'),
(140173, 4318, 46, 'नवीन विंडोमध्ये उघडा'),
(140174, 4319, 46, 'ओपन रुग्णांच्या'),
(140175, 4321, 46, 'ओपन Today`s भेट द्या'),
(140176, 4322, 46, 'LibreEHR आधीच एक प्रमाणपत्र अधिकृतता कॉन्फिगर केले आहे.'),
(140177, 4323, 46, 'LibreEHR अर्ज वर्ग'),
(140178, 4324, 46, 'LibreEHR डेटाबेस अपग्रेड'),
(140179, 4325, 46, 'डी-ओळखीसाठी LibreEHR डेटाबेस अपग्रेड'),
(140180, 4326, 46, 'LibreEHR योगदान डिरेक्टरी मध्ये येणारे फाइल ओळखत नाही. तुम्ही, MySQL डेटाबेस मध्ये supported_external_dataloads टेबल मध्ये प्रकाशन संरचीत करणे आवश्यक आहे कारण हे सर्वात शक्यता आहे.'),
(140181, 4327, 46, 'तो क्लायंट प्रमाणपत्र तयार करू शकता करण्यापूर्वी LibreEHR प्रमाणपत्रे वापरण्यासाठी कॉन्फिगर केले जाऊ आवश्यक आहे.'),
(140182, 4328, 46, 'LibreEHR वापरकर्ता प्रमाणीकरण करण्यासाठी Javascript आवश्यक आहे.'),
(140183, 4329, 46, 'LibreEHR वापरकर्ते'),
(140184, 4330, 46, 'संबंधी'),
(140185, 4332, 46, 'Opthalmic'),
(140186, 4333, 46, 'पर्याय'),
(140187, 4334, 46, 'पर्याय दस्तऐवज संचय पद्धत जतन करणे.'),
(140188, 4335, 46, 'पर्याय यादी आणि उत्पादने विक्री समर्थन'),
(140189, 4336, 46, 'पर्यायी'),
(140190, 4337, 46, 'रुग्ण सारांश पृष्ठ पाहिले जाऊ शकते की एक ओळखपत्र प्रतिमा पर्यायी श्रेणी नाव.'),
(140191, 4338, 46, 'रुग्ण सारांश पृष्ठ पाहिले जाऊ शकते की फोटो प्रतिमा पर्यायी श्रेणी नाव.'),
(140192, 4339, 46, 'दस्तऐवजाची पर्यायी श्रेणी नाव रुग्णाच्या सारांश पृष्ठ या निर्देशित पानाशी जोडले आहेत. आपण त्यांच्या ओळखपत्र पाहण्यासाठी एक रुग्ण नावावर क्लिक करा.'),
(140193, 4340, 46, 'परिणाम स्वहस्ते नोंद पर्यायी मुलभूत श्रेणी'),
(140194, 4341, 46, 'परिणाम स्वहस्ते नोंद पर्यायी मुलभूत युनिट'),
(140195, 4342, 46, 'पर्यायी गंतव्य नाव'),
(140196, 4343, 46, 'पर्यायी औषध नाव, वाइल्डकार्ड म्हणून% वापर'),
(140197, 4344, 46, 'पर्यायी लसीकरण नाव किंवा कोड, एक वाइल्डकार्ड म्हणून% वापर'),
(140198, 4345, 46, 'हा कार्यक्रम बद्दल माहिती पर्यायी'),
(140199, 4346, 46, 'पर्यायी भरपूर संख्या एक वाइल्डकार्ड म्हणून% वापर'),
(140200, 4347, 46, 'पर्यायी अंकीय रुग्ण आयडी');
INSERT INTO `lang_definitions` VALUES
(140201, 4348, 46, 'पर्यायी प्रक्रिया कोड'),
(140202, 4349, 46, 'पर्यायी पद्धत / सेवा कोड'),
(140203, 4350, 46, 'पर्याय'),
(140204, 4351, 46, 'किंवा'),
(140205, 4352, 46, 'किंवा'),
(140206, 4353, 46, 'किंवा निवडा'),
(140207, 4354, 46, 'किंवा क्लिक करा आणि जलद निवड ड्रॅग करा.'),
(140208, 4356, 46, 'किंवा बाहेर'),
(140209, 4357, 46, 'किंवा यादी निवडा'),
(140210, 4358, 46, 'किंवा ते कमी करण्यासाठी Shift-क्लिक करा'),
(140211, 4359, 46, 'किंवा ईआरए फाइल अपलोड करा:'),
(140212, 4360, 46, 'तोंडावाटे'),
(140213, 4361, 46, 'तोंडावाटे श्लेष्मल त्वचा गुलाबी, स्पष्ट घसा'),
(140214, 4362, 46, 'ऑर्डर'),
(140215, 4363, 46, 'ऑर्डर आणि निकाल प्रकार'),
(140216, 4364, 46, 'ऑर्डर कॅटलॉग'),
(140217, 4365, 46, 'ऑर्डर तारीख'),
(140218, 4366, 46, 'ऑर्डर वर्णन'),
(140219, 4367, 46, 'पासून ऑर्डर'),
(140220, 4368, 46, 'क्रम आयडी'),
(140221, 4369, 46, 'ऑर्डर 1 आणि 999 दरम्यान एक संख्या असणे आवश्यक आहे'),
(140222, 4370, 46, 'ऑर्डर नाव'),
(140223, 4371, 46, 'ऑर्डर अग्रक्रम'),
(140224, 4372, 46, 'ऑर्डर प्रोसेसर'),
(140225, 4373, 46, 'ऑर्डर परिणाम'),
(140226, 4374, 46, 'ऑर्डर स्थिती'),
(140227, 4375, 46, 'ऑर्डर पुतळे'),
(140228, 4376, 46, 'ऑर्डर सारांश'),
(140229, 4377, 46, 'ऑर्डर ट्रॅक'),
(140230, 4378, 46, 'ऑर्डर प्रकार'),
(140231, 4380, 46, 'ऑर्डर / परिणाम प्रकार'),
(140232, 4381, 46, 'आदेश दिले'),
(140233, 4382, 46, 'करून आदेश दिले'),
(140234, 4383, 46, 'आदेश दिले प्रक्रिया'),
(140235, 4384, 46, 'क्रम प्रदाता'),
(140236, 4385, 46, 'ऑर्डर मार्ग'),
(140237, 4386, 46, 'अवयव इजा'),
(140238, 4387, 46, 'संघटना'),
(140239, 4388, 46, 'संस्थेचे नाव'),
(140240, 4389, 46, 'संस्थात्मक एकक नाव'),
(140241, 4390, 46, 'संस्था'),
(140242, 4391, 46, 'X 3 orientated'),
(140243, 4392, 46, 'मूळ'),
(140244, 4393, 46, 'मूळ चेकसम'),
(140245, 4394, 46, 'ओरिया'),
(140246, 4395, 46, 'ओरोमो'),
(140247, 4396, 46, 'घशाखालील भाग: '),
(140248, 4397, 46, 'Orthopnea'),
(140249, 4398, 46, 'ओएस'),
(140250, 4399, 46, 'Osetoarthritis'),
(140251, 4400, 46, 'ओसेशियन Name, ओस्सेटिक'),
(140252, 4401, 46, 'अस्थीचिकित्सेबाबत'),
(140253, 4402, 46, 'इतर'),
(140254, 4403, 46, 'इतर'),
(140255, 4404, 46, 'इतर (स्पष्ट करा)'),
(140256, 4405, 46, 'इतर - हिन्दू'),
(140257, 4406, 46, 'इतर फेडरल कार्यक्रम'),
(140258, 4407, 46, 'इतर HCFA'),
(140259, 4408, 46, 'इतर इजा इतरत्र निर्दिष्ट नाही'),
(140260, 4409, 46, 'इतर दायित्व विमा प्राथमिक आहे'),
(140261, 4410, 46, 'महिना'),
(140262, 4411, 46, 'इतर नॉन-फेडरल कार्यक्रम'),
(140263, 4412, 46, 'इतर टिपा'),
(140264, 4413, 46, 'इतर सुसंबध्द लक्षणे'),
(140265, 4414, 46, 'इतर सुसंबध्द लक्षणे:'),
(140266, 4415, 46, 'इतर पोर्तुगाल resp'),
(140267, 4416, 46, 'वापर इजा चेंडू इतर ताण /'),
(140268, 4417, 46, 'सर्जिकल इतर'),
(140269, 4418, 46, 'इतर / जेनेरिक गर्भपात-संबंधित'),
(140270, 4420, 46, 'दुसरे काही'),
(140271, 4421, 46, 'अन्यथा आपण अस्तित्वातील डाटा पासून / संदर्भ नाश करीन.'),
(140272, 4422, 46, 'ऑटवा पायाचा घोटा नियम'),
(140273, 4423, 46, 'OU'),
(140274, 4424, 46, 'झेल.एकही'),
(140275, 4425, 46, 'कार्यालय आउट'),
(140276, 4426, 46, 'परदेशी रेफरल'),
(140277, 4427, 46, 'परिणाम'),
(140278, 4428, 46, 'आउटलुक'),
(140279, 4429, 46, 'आउटपुट प्रकार'),
(140280, 4430, 46, 'डिस्चार्ज एकूण स्थिती'),
(140281, 4431, 46, 'थकीत'),
(140282, 4432, 46, 'Overuse'),
(140283, 4433, 46, 'विहंगावलोकन'),
(140284, 4434, 46, 'जादा वजन'),
(140285, 4435, 46, 'HIPAA निवड पुन्हा खोडून'),
(140286, 4437, 46, 'ऑक्सिजन संपृक्तता'),
(140287, 4438, 46, 'औंस'),
(140288, 4439, 46, 'पी'),
(140289, 4440, 46, 'p.c.'),
(140290, 4441, 46, 'घेता'),
(140291, 4442, 46, 'p.r.n.'),
(140292, 4443, 46, 'पॅसिफिक आयलॅंडर'),
(140293, 4444, 46, 'Paedeatric'),
(140294, 4445, 46, 'पृष्ठ'),
(140295, 4446, 46, 'पृष्ठे'),
(140296, 4447, 46, 'सशुल्क'),
(140297, 4448, 46, 'तुम्ही वाटप करतो की देय रक्कम'),
(140298, 4449, 46, 'सशुल्क रक्कम'),
(140299, 4450, 46, 'सशुल्क मार्गे'),
(140300, 4451, 46, 'वेदना'),
(140301, 4453, 46, 'कापणे'),
(140302, 4454, 46, 'पँजाबी Name, पंजाबी'),
(140303, 4455, 46, 'प्रकल्पग्रस्त डाग'),
(140304, 4456, 46, 'पेपर'),
(140305, 4457, 46, 'कागद आकार'),
(140306, 4458, 46, 'अर्धांगवायू'),
(140307, 4459, 46, 'पालक'),
(140308, 4461, 46, 'पार्स HL7'),
(140309, 4463, 46, 'भागीदार'),
(140310, 4464, 46, 'भागीदार नाव'),
(140311, 4466, 46, 'पश्तो, पश्तो'),
(140312, 4467, 46, 'पास लिहिलंय'),
(140313, 4468, 46, 'दस्तऐवज उकल करण्यासाठी वाक्यांश पास'),
(140314, 4469, 46, 'उत्तीर्ण रुग्णांना'),
(140315, 4470, 46, 'निष्क्रीय अॅलर्ट'),
(140316, 4471, 46, 'निष्क्रीय अॅलर्ट नियम'),
(140317, 4472, 46, 'पासवर्ड'),
(140318, 4473, 46, 'पासवर्ड बदला'),
(140319, 4474, 46, 'संकेतशब्द बदल यशस्वी'),
(140320, 4475, 46, 'पासवर्ड यशस्वी बदला.'),
(140321, 4476, 46, 'पासवर्ड किमान आवश्यकता पूर्ण करत नाही आणि चार खालील आयटम किमान तीन असणे आवश्यक आहे: एक संख्या, एक छोटे आकार पत्र, एक लोअरकेस पत्र, विशेष अक्षर (नाही leter किंवा संख्या).'),
(140322, 4477, 46, 'पासवर्ड समाप्ती अतिरिक्त कालावधी'),
(140323, 4479, 46, 'फोन गेटवे पासवर्ड. Maviq द्वारे प्रदान स्वयंचलित VoIP सेवा. अधिक माहितीसाठी http://signup.maviq.com भेट द्या.'),
(140324, 4480, 46, 'एसएमएस गेटवे संकेतशब्द'),
(140325, 4481, 46, 'एसएमएस गेटवे पासवर्ड.'),
(140326, 4482, 46, 'वरील वापरकर्ता संकेतशब्द'),
(140327, 4483, 46, 'पासवर्ड सुरक्षा अलीकडे सुधारीत केले आहे.'),
(140328, 4484, 46, 'पासवर्ड CouchDB कनेक्ट करण्यासाठी'),
(140329, 4485, 46, 'संकेतशब्द खूप लहान. किमान 8 वर्ण आवश्यक.'),
(140330, 4486, 46, 'पासवर्ड:'),
(140331, 4487, 46, 'पासवर्ड जुळत नका!'),
(140332, 4488, 46, 'मागील Appoinments'),
(140333, 4489, 46, 'मागील नियुक्ती प्रदर्शन विजेट'),
(140334, 4490, 46, 'गेल्या'),
(140335, 4491, 46, 'मागील मुळे'),
(140336, 4492, 46, 'गेल्या मुळे मध्यांतर (क्लिनिकल स्मरणपत्रे)'),
(140337, 4493, 46, 'गेल्या मुळे मध्यांतर (रुग्णांच्या स्मरणपत्रे)'),
(140338, 4494, 46, 'मागील चकमकीत यादी'),
(140339, 4495, 46, 'मागील Encounters'),
(140340, 4496, 46, 'मागील Encounters आणि दस्तऐवज'),
(140341, 4497, 46, 'गेल्या Encounters'),
(140342, 4498, 46, 'HL7 डेटा पेस्ट करा'),
(140343, 4499, 46, 'खाली दिलेल्या टेक्स्ट कक्षात आयात डेटा पेस्ट करा:'),
(140344, 4500, 46, 'पॅट'),
(140345, 4502, 46, 'ठिगळ'),
(140346, 4508, 46, 'इव्हेंट लॉग बॅकअप करीता मार्ग'),
(140347, 4509, 46, 'CA प्रमाणपत्र फाइल मार्ग'),
(140348, 4510, 46, 'सीए की फाइल मार्ग'),
(140349, 4511, 46, ', MySQL Binaries मार्ग'),
(140350, 4512, 46, 'पर्ल Binaries मार्ग'),
(140351, 4513, 46, 'तात्पुरत्या फाइल्स मार्ग'),
(140352, 4514, 46, 'रुग्णांच्या'),
(140353, 4515, 46, 'रुग्ण'),
(140354, 4516, 46, 'रुग्ण'),
(140355, 4517, 46, 'रुग्णांच्या पत्ता'),
(140356, 4518, 46, 'रुग्णांच्या पत्ता गहाळ आहे'),
(140357, 4521, 46, 'रुग्णांच्या ऍलर्जी'),
(140358, 4522, 46, 'रुग्णांच्या अॅलर्जी'),
(140359, 4523, 46, 'रुग्णांच्या नियुक्ती'),
(140360, 4524, 46, 'रुग्णांच्या शिल्लक'),
(140361, 4525, 46, 'रुग्णांच्या शिल्लक मुळे'),
(140362, 4528, 46, 'रुग्णांच्या चार्ट आयडी'),
(140363, 4529, 46, 'रुग्णांच्या चेकआऊट'),
(140364, 4530, 46, 'धीराने चेकआऊट '),
(140365, 4531, 46, 'रुग्णांच्या शहर'),
(140366, 4532, 46, 'रुग्णांच्या शहर गहाळ आहे'),
(140367, 4533, 46, 'पाठविले रुग्णांच्या दळणवळण'),
(140368, 4534, 46, 'पाठविलेला रुग्णांच्या Comunication'),
(140369, 4535, 46, 'रुग्णांच्या देश'),
(140370, 4536, 46, 'रुग्णांच्या देश गहाळ आहे. तसेच आपण ग्लोबल सेटिंग्ज मध्ये डीफॉल्ट रुग्णांच्या देश सेट केले नाही'),
(140371, 4537, 46, 'रुग्णांच्या व्याप्ती'),
(140372, 4539, 46, 'रुग्णांच्या डेटा'),
(140373, 4541, 46, 'जन्म रुग्णांच्या तारीख गहाळ आहे'),
(140374, 4542, 46, 'रुग्णांच्या तपशील'),
(140375, 4543, 46, 'रुग्णांच्या डीओबी'),
(140376, 4544, 46, 'रुग्णांच्या दस्तऐवज'),
(140377, 4545, 46, 'रुग्णांच्या शिक्षण'),
(140378, 4546, 46, 'रुग्णांच्या शिक्षण सामुग्री'),
(140379, 4547, 46, 'रुग्णांच्या आढळतात'),
(140380, 4548, 46, 'रुग्णांच्या चकमकीत फॉर्म'),
(140381, 4549, 46, 'रुग्णांच्या Encounters'),
(140382, 4550, 46, 'रुग्णांच्या फाइंडर'),
(140383, 4551, 46, 'रुग्णांच्या नाव'),
(140384, 4553, 46, 'रुग्णांच्या नाव गहाळ आहे'),
(140385, 4558, 46, 'रुग्णांच्या लिंग'),
(140386, 4559, 46, 'रुग्णांच्या लिंग गहाळ आहे'),
(140387, 4560, 46, 'रुग्णांच्या रुग्ण पोर्टल अधिकृत नाही.'),
(140388, 4561, 46, 'रुग्णांच्या इतिहास'),
(140389, 4562, 46, 'रुग्णांच्या इतिहास / जीवनशैली'),
(140390, 4563, 46, 'रुग्णांच्या मुख्यपृष्ठ फोन'),
(140391, 4564, 46, 'रुग्णांच्या आयडी'),
(140392, 4565, 46, 'रुग्णांच्या आयडी'),
(140393, 4566, 46, 'रुग्णांच्या ओळखपत्र'),
(140394, 4567, 46, 'रुग्णांच्या आयडी वर्गवारी नाव'),
(140395, 4568, 46, 'रुग्णांच्या लसीकरण'),
(140396, 4569, 46, 'रुग्णांच्या माहिती'),
(140397, 4570, 46, 'रुग्णांच्या सूचना'),
(140398, 4571, 46, 'रुग्णांच्या विमा वितरण'),
(140399, 4572, 46, 'रुग्णांच्या विमा वितरण अहवाल'),
(140400, 4573, 46, 'रुग्णांच्या मुद्दे'),
(140401, 4574, 46, 'रुग्णांच्या लेबल प्रकार'),
(140402, 4575, 46, 'रुग्णांच्या आडनाव'),
(140403, 4577, 46, 'रुग्णांच्या आडनाव गहाळ आहे'),
(140404, 4581, 46, 'रुग्णांच्या यादी'),
(140405, 4582, 46, 'रुग्णांच्या यादी स्तंभ'),
(140406, 4584, 46, 'रुग्णांच्या यादी नवीन विंडोमध्ये'),
(140407, 4585, 46, 'रुग्णांच्या यादी पृष्ठ आकार'),
(140408, 4586, 46, 'रुग्णांच्या शोधा चुका'),
(140409, 4587, 46, 'रुग्णांच्या वैद्यकीय समस्या'),
(140410, 4588, 46, 'रुग्णांच्या औषधे'),
(140411, 4589, 46, 'रुग्णांच्या नाव'),
(140412, 4590, 46, 'रुग्णांच्या नाव आणि पत्ता:'),
(140413, 4593, 46, 'रुग्णांच्या नाव आवश्यक'),
(140414, 4595, 46, 'रुग्णांच्या टीप'),
(140415, 4596, 46, 'रुग्णांच्या टीप प्रकार'),
(140416, 4597, 46, 'रुग्णांच्या टिपा'),
(140417, 4598, 46, 'रुग्णांच्या टीपा (पर्यायी addonly, लिहा)'),
(140418, 4599, 46, 'रुग्णांच्या क्रमांक'),
(140419, 4600, 46, 'रुग्णांच्या भरणा'),
(140420, 4602, 46, 'रुग्णांच्या फोटो वर्गवारी नाव'),
(140421, 4603, 46, 'रुग्णांच्या पोर्टल'),
(140422, 4604, 46, 'रुग्णांच्या पोर्टल कनेक्टिव्हिटी समस्या'),
(140423, 4605, 46, 'रुग्णांच्या पोर्टल बंद आहे'),
(140424, 4606, 46, 'रुग्णांच्या पोर्टल लॉग-इन'),
(140425, 4607, 46, 'रुग्णांच्या पोर्टल वेब पत्ता'),
(140426, 4608, 46, 'रुग्णांच्या छापील अहवाल'),
(140427, 4609, 46, 'रुग्णांच्या रेकॉर्ड अहवाल'),
(140428, 4610, 46, 'रुग्णांच्या रेकॉर्ड विनंती'),
(140429, 4611, 46, 'रुग्णांच्या रेकॉर्ड विनंती'),
(140430, 4613, 46, 'रुग्णांच्या स्मरणपत्र'),
(140431, 4614, 46, 'रुग्णांच्या स्मरणपत्र बॅच ईयोब'),
(140432, 4615, 46, 'रुग्णांच्या स्मरणपत्र निर्मिती प्रक्रिया प्राधान्य'),
(140433, 4616, 46, 'रुग्णांच्या स्मरणपत्र नियम'),
(140434, 4617, 46, 'रुग्णांच्या स्मरणपत्र प्रेषक ईमेल'),
(140435, 4618, 46, 'रुग्णांच्या स्मरणपत्र प्रेषकाचे नाव'),
(140436, 4619, 46, 'रुग्णांच्या स्मरणपत्रे'),
(140437, 4620, 46, 'रुग्णांच्या अहवाल'),
(140438, 4621, 46, 'रुग्णांच्या विनंती'),
(140439, 4622, 46, 'रुग्णांच्या विनंती वैद्यकीय रेकॉर्ड'),
(140440, 4623, 46, 'रुग्णांच्या परिणाम'),
(140441, 4624, 46, 'रुग्णांच्या शोध परिणाम शैली'),
(140442, 4625, 46, 'रुग्णांच्या शोध जोडा / स्क्रीन'),
(140443, 4626, 46, 'रुग्णांच्या सेटिंग'),
(140444, 4627, 46, 'रुग्णांच्या राज्य'),
(140445, 4629, 46, 'रुग्णांच्या सारांश'),
(140446, 4630, 46, 'रुग्णांच्या व्यवहार'),
(140447, 4631, 46, 'रुग्णांच्या पिन'),
(140448, 4632, 46, 'आपण प्रविष्ट केलेला लोकसंख्याशास्त्रीय माहिती जुळत डाटाबेस सहनशील (चे).'),
(140449, 4633, 46, 'रुग्णांच्या / ग्राहक'),
(140450, 4634, 46, 'रुग्णांच्या:'),
(140451, 4635, 46, 'PatientID'),
(140452, 4636, 46, 'रुग्णांना'),
(140453, 4637, 46, 'रुग्णांना प्रक्रिया'),
(140454, 4638, 46, 'द्या'),
(140455, 4639, 46, 'चेकबॉक्स "पूर्ण झाले" करण्यासाठी लक्ष द्या. इन्शुरन्सचे पूर्ण चिन्हांकित केली आहेत नंतर आम्ही बाकी अदा रुग्णाला विचारून सुरू होईल; आपण पूर्ण इन्शुरन्सचे सर्व चिन्हांकित अपयशी तर उर्वरित रक्कम गोळा जाणार नाही! रुग्णाला अदा करावी, असे समतोल आहे, तर या रुग्णाला स्टेटमेन्ट दिसणारे भाषा परिणाम होईल तसेच, नंतर, योग्य योग्य तारीख सेट.'),
(140456, 4640, 46, 'तारीख द्या:'),
(140457, 4641, 46, 'पे स्थिती'),
(140458, 4642, 46, 'ज्याला पैसे दिले तो मनुष्य नाव'),
(140459, 4643, 46, 'देणारा'),
(140460, 4644, 46, 'देणारा प्रकार'),
(140461, 4645, 46, 'भरणे'),
(140462, 4646, 46, 'अस्तित्व भरणे'),
(140463, 4647, 46, 'भरणा'),
(140464, 4648, 46, 'पैसे'),
(140465, 4649, 46, 'भरणा समायोजन कोड'),
(140466, 4650, 46, 'रक्कम'),
(140467, 4651, 46, 'भरणा रक्कम'),
(140468, 4652, 46, 'भरणा रक्कम संख्यात्मक असणे आवश्यक आहे'),
(140469, 4653, 46, 'भरणा वर्ग'),
(140470, 4654, 46, 'भरणा तारीख'),
(140471, 4655, 46, 'देयक वर प्रवेश केला'),
(140472, 4656, 46, 'पासून भरणा'),
(140473, 4657, 46, 'भरणा गेटवे'),
(140474, 4658, 46, 'भरणा इन'),
(140475, 4659, 46, 'भरणा यादी'),
(140476, 4660, 46, 'भरणा पद्धत'),
(140477, 4661, 46, 'करून भरणा क्रमवारी लावा'),
(140478, 4662, 46, 'भरणा स्थिती'),
(140479, 4663, 46, 'भरणा प्रकार'),
(140480, 4664, 46, 'कोड भरणा मूल्य '),
(140481, 4665, 46, 'देयके'),
(140482, 4667, 46, 'PCP'),
(140483, 4668, 46, 'PCT (%) पंक्ती'),
(140484, 4669, 46, 'पीडीएफ'),
(140485, 4670, 46, 'पीडीएफ डाउनलोड स्टेटमेन्ट निवडलेले'),
(140486, 4671, 46, 'पीडीएफ भाषा'),
(140487, 4672, 46, 'फॉन्ट आणि नितंब'),
(140488, 4673, 46, 'Pemphigus'),
(140489, 4674, 46, 'प्रलंबित'),
(140490, 4675, 46, 'मंजूरीसाठी प्रलंबित'),
(140491, 4676, 46, 'एफ / यू प्रलंबित'),
(140492, 4677, 46, 'प्रलंबित फॉलोअप'),
(140493, 4678, 46, 'परिणाम पासून प्रलंबित फॉलोअप'),
(140494, 4679, 46, 'ऑर्डर प्रलंबित'),
(140495, 4680, 46, 'प्रलंबित द्यावे'),
(140496, 4681, 46, 'प्रलंबित पुनरावलोकन'),
(140497, 4682, 46, 'प्रलंबित Rx संख्या'),
(140498, 4684, 46, 'पेनिंग्टन फर्म LibreEHR विरुद्ध'),
(140499, 4685, 46, 'पाचक व्रण रोग'),
(140500, 4686, 46, 'चकमकीत प्रति'),
(140501, 4687, 46, 'मि दर'),
(140502, 4688, 46, 'प्रति नाकपुडी'),
(140503, 4689, 46, 'नाकपुडी दर'),
(140504, 4690, 46, 'प्रति Oris'),
(140505, 4691, 46, 'oris दर'),
(140506, 4692, 46, 'गुदाशय प्रति'),
(140507, 4693, 46, 'गुदाशय दर'),
(140508, 4694, 46, 'टक्के'),
(140509, 4697, 46, 'शतमान'),
(140510, 4698, 46, 'सच्छिद्र अधिकार:'),
(140511, 4699, 46, 'शोध सुरू'),
(140512, 4700, 46, 'ही क्रिया'),
(140513, 4701, 46, 'कामगिरी टक्केवारी'),
(140514, 4703, 46, 'सुरू प्रयोगशाळा सुविधा'),
(140515, 4705, 46, 'कालावधी'),
(140516, 4706, 46, 'वापरकर्ता एक कालबाह्य पासवर्ड प्रवेश करू शकता, जेथे दिवसांत कालावधी.'),
(140517, 4707, 46, 'Perioperative केअर'),
(140518, 4708, 46, 'गौण'),
(140519, 4709, 46, 'Unsalted संकेतशब्द परवानगी'),
(140520, 4710, 46, 'पर्शियन'),
(140521, 4711, 46, 'फारसी (फारसी)'),
(140522, 4712, 46, 'व्यक्ती'),
(140523, 4713, 46, 'वैयक्तिकृत'),
(140524, 4714, 46, 'पदव्युत्तर'),
(140525, 4715, 46, 'Pharm'),
(140526, 4716, 46, 'Pharm कॉम संख्या'),
(140527, 4717, 46, 'औषध'),
(140528, 4718, 46, 'फार्मसी'),
(140529, 4719, 46, 'फार्मसी दवाखान्याला'),
(140530, 4720, 46, 'Pheumothorax'),
(140531, 4721, 46, 'सीसीडीची पाठवा परवानगी द्या phiMail'),
(140532, 4722, 46, 'phiMail CCR पाठवा परवानगी द्या'),
(140533, 4723, 46, 'phiMail संदेश मध्यांतर (मिनिटे) तपासा'),
(140534, 4724, 46, 'phiMail सूचना वापरकर्ता'),
(140535, 4725, 46, 'phiMail पासवर्ड'),
(140536, 4726, 46, 'phiMail सर्व्हर पत्ता'),
(140537, 4727, 46, 'phiMail वापरकर्तानाव'),
(140538, 4729, 46, 'फोन'),
(140539, 4730, 46, 'फोन कॉल सूची'),
(140540, 4731, 46, 'फोन कॉल यादी अहवाल'),
(140541, 4732, 46, 'फोन सेल'),
(140542, 4733, 46, 'फोन गेटवे पासवर्ड'),
(140543, 4734, 46, 'फोन गेटवे URL मध्ये'),
(140544, 4735, 46, 'फोन गेटवे वापरकर्तानाव'),
(140545, 4736, 46, 'फोन मुख्यपृष्ठ'),
(140546, 4737, 46, 'फोन सूचना तास'),
(140547, 4738, 46, 'फोन नंबर'),
(140548, 4739, 46, 'फोन नंबर'),
(140549, 4740, 46, 'प्रकाश सहन न होणे'),
(140550, 4741, 46, 'फोटो'),
(140551, 4742, 46, 'कृपया PHP संकुचित'),
(140552, 4743, 46, 'कृपया PHP वलय विभाग आपल्या सर्व्हर सक्षम करणे आवश्यक आहे.'),
(140553, 4744, 46, 'कृपया PHP मिळवला'),
(140554, 4745, 46, 'PHP-GACL प्रवेश नियंत्रणे बंद आहेत'),
(140555, 4746, 46, 'कृपया PHP-gacl स्थापित नाही'),
(140556, 4747, 46, 'शारीरिक परीक्षा'),
(140557, 4749, 46, 'फिजिशियन विनंती'),
(140558, 4750, 46, 'फिजिशियन स्वाक्षरी'),
(140559, 4752, 46, 'डॉक्टरांची'),
(140560, 4753, 46, 'निवडा'),
(140561, 4754, 46, 'निवडा'),
(140562, 4755, 46, 'एक सीएसएस थीम निवडा.'),
(140563, 4756, 46, 'पी आय डी'),
(140564, 4757, 46, 'पी आय डी (ओटीपोटाच्या दाहक रोग)'),
(140565, 4758, 46, 'गोळी आकार'),
(140566, 4759, 46, 'गोळ्या'),
(140567, 4760, 46, 'प्रतिष्ठापीत करण्यासाठी पर्याय इच्छित असल्यास खालील निर्देशिका मध्ये डेटाबेस zip फाइल ठेवा'),
(140568, 4761, 46, 'खालील निर्देशिका मध्ये डाउनलोड ICD 10 डेटाबेस झिप फाइल ठेवा'),
(140569, 4762, 46, 'खालील निर्देशिका मध्ये डाउनलोड ICD 9 डेटाबेस zip फाइल ठेवा'),
(140570, 4763, 46, 'खालील निर्देशिका मध्ये डाउनलोड RxNorm डेटाबेस zip फाइल ठेवा'),
(140571, 4764, 46, 'खालील निर्देशिका मध्ये डाउनलोड Snomed डेटाबेस zip फाइल ठेवा'),
(140572, 4765, 46, 'प्लेसहोल्डर'),
(140573, 4766, 46, 'प्लेसहोल्डर (रिक्त ACLs करीता राखून ठेवेल)'),
(140574, 4767, 46, 'साधा मजकूर'),
(140575, 4768, 46, 'योजना'),
(140576, 4771, 46, 'योजनेचे नाव'),
(140577, 4775, 46, 'योजना सेट'),
(140578, 4779, 46, 'योजना:'),
(140579, 4782, 46, 'योजना'),
(140580, 4784, 46, 'प्लेअर'),
(140581, 4785, 46, 'जागा'),
(140582, 4786, 46, 'वरील माहिती चुकीची असेल तर कॉल करा'),
(140583, 4787, 46, 'कृपया आपला संकेतशब्द बदला.'),
(140584, 4788, 46, 'एक फाइल निवडा'),
(140585, 4789, 46, 'एक रुग्ण निवडा'),
(140586, 4790, 46, 'सूचीमधून एक वैध निवड निवडा.'),
(140587, 4791, 46, 'एक वैध निवड निवडा.'),
(140588, 4792, 46, 'एक मूल्य निवडा'),
(140589, 4793, 46, 'वरील तारीख श्रेणी मापदंड निवडा, आणि परिणाम पाहण्यासाठी रिफ्रेश क्लिक करा.'),
(140590, 4794, 46, 'योग्य रूपण EDI-271 फाइल निवडा'),
(140591, 4795, 46, 'डे ओळखले डेटा डाउनलोड करण्यासाठी डाउनलोड बटण क्लिक करा'),
(140592, 4796, 46, 'पुन्हा ओळखले डेटा डाउनलोड करण्यासाठी डाउनलोड बटण क्लिक करा'),
(140593, 4797, 46, 'ही विंडो बंद करा.'),
(140594, 4798, 46, 'नवीन नाव तुलना करा'),
(140595, 4800, 46, 'पुढे जाण्यापूर्वी मूल्य (चे) दुरुस्त करा!'),
(140596, 4801, 46, 'पुढे जाण्यापूर्वी खालील निर्देशिका तयार करा'),
(140597, 4802, 46, 'तो facimile द्वारे प्राप्त केले जात नाही तोपर्यंत या नियम मान्य करू नका.'),
(140598, 4803, 46, 'तो पुस्तक द्वारे प्राप्त केले जात नाही तोपर्यंत या नियम मान्य करू नका.'),
(140599, 4804, 46, 'आपल्या ब्राउझर थांबवू किंवा हा लेख जास्त 10 मिनिटे कालावधी पश्चात आहेत तोपर्यंत चालत असताना बटण रीलोड वापरू नका कृपया, ही प्रक्रिया सर्व्हरवर थांबवू आणि uneccesary संसाधने नष्ट करीन होत नाही.'),
(140600, 4805, 46, 'वलय विस्तार सक्षम करा कृपया'),
(140601, 4806, 46, 'OpenSSL विस्तार सक्षम करा कृपया'),
(140602, 4807, 46, 'SOAP विस्तार सक्षम करा कृपया'),
(140603, 4808, 46, 'एक्स एम एल विस्तार सक्षम करा कृपया'),
(140604, 4809, 46, 'पुनरावलोकन अंतिम तारीख प्रविष्ट करा.'),
(140605, 4810, 46, 'एक तारीख प्रविष्ट करा.'),
(140606, 4811, 46, 'योग्य तारीख प्रविष्ट करा'),
(140607, 4812, 46, 'कृपया संदेश प्रविष्ट करा'),
(140608, 4813, 46, 'फक्त संख्या आणि एक दशांश चिन्ह वापरून आर्थिक रक्कम प्रविष्ट करा.'),
(140609, 4814, 46, 'एक नवीन संकेतशब्द प्रविष्ट करा'),
(140610, 4815, 46, 'कृपया नाव प्रविष्ट करा!'),
(140611, 4816, 46, 'वर वैध थेट पत्ता प्रविष्ट करा.'),
(140612, 4817, 46, 'किमान आयटमची नाव प्रविष्ट करा'),
(140613, 4818, 46, 'किमान ट्रॅक नाव प्रविष्ट करा'),
(140614, 4819, 46, 'योग्य पुन्हा ओळख कोड प्रविष्ट करा'),
(140615, 4820, 46, 'तारीख सुरू पेक्षा अंतिम तारीख मोठे प्रविष्ट करा!'),
(140616, 4821, 46, 'नवीन शोध स्ट्रिंग प्रविष्ट करा'),
(140617, 4822, 46, 'योग्य पुन्हा ओळख कोड प्रविष्ट करा'),
(140618, 4823, 46, 'संकेतशब्द प्रविष्ट करा'),
(140619, 4824, 46, 'चेक क्रमांक भरा'),
(140620, 4825, 46, 'भरा कृपया तपासा / संदर्भ क्रमांक'),
(140621, 4826, 46, 'तारीख भरा'),
(140622, 4827, 46, 'भरणा रक्कम भरा'),
(140623, 4828, 46, 'भरणा वर्ग भरा'),
(140624, 4829, 46, 'पासून भरणा भरा'),
(140625, 4830, 46, 'पोस्ट करण्यासाठी तारीख भरा'),
(140626, 4831, 46, 'पुढे जाण्याआधी भरा.'),
(140627, 4832, 46, 'भेट कारण सूचित करा'),
(140628, 4833, 46, 'इनपुट शोध निकष अधिक आणि अहवाल सुरू करण्यासाठी सबमिट करा क्लिक करा.'),
(140629, 4834, 46, 'इनपुट शोध निकष वरील, आणि क्लिक करा परिणाम पाहण्यासाठी सबमिट करा.'),
(140630, 4835, 46, 'इनपुट शोध निकष वरील, आणि क्लिक करा परिणाम पाहण्यासाठी सबमिट करा. (परिणाम एक पॉप अप विंडो मध्ये प्रदर्शित केले जाईल)'),
(140631, 4836, 46, 'पुन्हा लॉगिन करा.'),
(140632, 4837, 46, 'या काही मिनिटे पर्यंत, खूप वेळ लागू शकतो कृपया लक्षात घ्या की, आपल्या वेब ब्राउझर या वेळी अतिशय सक्रिय दिसून पण एक बिल निर्मिती एक क्लिष्ट प्रक्रिया आहे आणि आपल्या वेब ब्राउझर केवळ अधिक माहितीसाठी वाट पाहत आहे शकत नाही.'),
(140633, 4838, 46, 'कृपया लक्षात ठेवा: स्थिर केस सेन्सेटिव्ह आहेत आणि कोणत्याही स्ट्रिंग परवानगी आहे.'),
(140634, 4839, 46, 'फक्त अक्षर वर्ण वापरा'),
(140635, 4840, 46, 'फक्त एकही मोकळी जागा सह अक्षर वर्ण वापरा'),
(140636, 4841, 46, 'ही रक्कम अदा करा'),
(140637, 4842, 46, 'खालील निर्देशिका मध्ये तुमचा प्रतिष्ठापन फाइल ठेवा'),
(140638, 4843, 46, 'पहा करा'),
(140639, 4844, 46, 'पासवर्ड रीसेट करा.'),
(140640, 4845, 46, 'डी-ओळख खेळत आधी अपॅची सर्व्हर पुन्हा सुरू करा'),
(140641, 4846, 46, 'संलग्न पीडीएफ पहा.'),
(140642, 4847, 46, 'कृपया निवडा'),
(140643, 4849, 46, 'कृपया एक भाषा निवडा'),
(140644, 4850, 46, 'एक रुग्णांच्या निवडा.'),
(140645, 4851, 46, 'आपल्या सुविधा कर ID म्हणून ''कर आयडी'' एक प्राथमिक व्यवसाय अस्तित्व सुविधा निवडा. आपण स्वतंत्र व्यवसायी असाल तर, कृपया आपल्या कर आयडी वापरा. या NewCrop प्रणाली मध्ये तुमची ओळख वापरले जाते.'),
(140646, 4853, 46, 'एक प्रक्रिया प्रदाता सिलेक्ट करा'),
(140647, 4854, 46, 'एक प्राप्तकर्ता निवडा'),
(140648, 4855, 46, 'प्रारंभ तारीख आणि शेवटी तारीख निवडा'),
(140649, 4856, 46, 'एक वैध प्राप्तकर्ता निवडा'),
(140650, 4857, 46, 'एक सक्रिय गट निवडा'),
(140651, 4858, 46, 'कोड एक समायोजन कारण निवडा '),
(140652, 4859, 46, 'एक कार्यक्रम निवडा'),
(140653, 4860, 46, 'कोणत्याही शोध पर्याय निवडा.'),
(140654, 4863, 46, 'किमान एक नियम निवडा करा!'),
(140655, 4864, 46, 'चकमकीत निवडा'),
(140656, 4865, 46, 'कॉपी किंवा अग्रेषित करण्यासाठी इच्छित पाने निवडा:'),
(140657, 4866, 46, 'भरणा पद्धत निवडा'),
(140658, 4867, 46, 'भरणा प्रकार निवडा करा.'),
(140659, 4868, 46, 'भेट श्रेणी निवडा'),
(140660, 4869, 46, '270 बॅच तयार करणे आवश्यक X12 भागीदार निवडा, कृपया'),
(140661, 4870, 46, 'सेट करा'),
(140662, 4871, 46, 'शून्य परत de_identification_config वेरियेबल सेट करा'),
(140663, 4873, 46, 'नवीन डे ओळख प्रक्रिया सुरू करा'),
(140664, 4874, 46, 'डे ओळख प्रक्रीया, कार्य, टेबल समाविष्ट करण्यासाठी LibreEHR डेटाबेस श्रेणीसुधारित करा'),
(140665, 4875, 46, 'अधिक माहिती साठी डी ओळख त्रुटी लॉग टेबल पहा'),
(140666, 4876, 46, 'काही वेळानंतर डे ओळख स्क्रीन भेट द्या'),
(140667, 4877, 46, 'काही वेळानंतर पुन्हा ओळख स्क्रीन भेट द्या'),
(140668, 4878, 46, 'काही वेळानंतर स्क्रीन भेट द्या'),
(140669, 4879, 46, 'प्लॉट आयटम'),
(140670, 4880, 46, 'प्लॉट निवडलेले आयटम'),
(140671, 4881, 46, 'अनेकवचनी'),
(140672, 4882, 46, 'पंतप्रधान'),
(140673, 4883, 46, 'पंतप्रधान कार्यक्रम'),
(140674, 4884, 46, 'PMT पद्धत'),
(140675, 4885, 46, 'PND'),
(140676, 4886, 46, 'Pneumococcal धातूंचा गण 1'),
(140677, 4887, 46, 'Pneumococcal धातू चालवणे 2'),
(140678, 4888, 46, 'Pneumococcal धातू चालवणे 3'),
(140679, 4889, 46, 'Pneumococcal धातूंचा गण 4'),
(140680, 4890, 46, 'Pneumococcal लस'),
(140681, 4891, 46, 'न्यूमोनिया लसीकरण'),
(140682, 4892, 46, 'जुने प्रौढांसाठी न्यूमोनिया लसीकरण स्थिती'),
(140683, 4893, 46, 'जुने प्रौढांसाठी न्यूमोनिया लसीकरण स्थिती (CQM)'),
(140684, 4894, 46, 'Podiatric'),
(140685, 4895, 46, 'Podiatry'),
(140686, 4896, 46, 'सेवा पॉइंट (पीओएस)'),
(140687, 4897, 46, 'धोरण'),
(140688, 4898, 46, 'धोरण कोणत्याही'),
(140689, 4899, 46, 'धोरण क्रमांक'),
(140690, 4900, 46, 'पोलिश'),
(140691, 4901, 46, 'Polydypsia'),
(140692, 4902, 46, 'Polyps'),
(140693, 4903, 46, 'द्रवपदार्थाच्या अतिसेवनाने किंवा मधुमेहामुळे लघवीला फार होणे'),
(140694, 4904, 46, 'गरीब भूक'),
(140695, 4905, 46, 'गरीब फिरत'),
(140696, 4906, 46, 'गरीब सुनावणी'),
(140697, 4907, 46, 'पॉप अप हे अहवाल पाहण्यासाठी सक्षम करणे आवश्यक आहे'),
(140698, 4908, 46, 'घटना वर्ष दृश्य वसाहत?'),
(140699, 4909, 46, 'पॉपअप'),
(140700, 4910, 46, 'पोर्टल'),
(140701, 4911, 46, 'पोर्टल क्रियाकलाप'),
(140702, 4912, 46, 'पोर्टल आयडी'),
(140703, 4913, 46, 'पोर्टल आयडी पोर्टल विनंती जुळत नाही!'),
(140704, 4914, 46, 'पोर्टल पासवर्ड गहाळ आहे'),
(140705, 4915, 46, 'पोर्टल विनंत्या'),
(140706, 4916, 46, 'पोर्ट्रेट'),
(140707, 4917, 46, 'पोर्तुगीज'),
(140708, 4918, 46, 'पोर्तुगीज (ब्राझिलियन)'),
(140709, 4919, 46, 'पोर्तुगीज (युरोपियन)'),
(140710, 4920, 46, 'पीओएस कोड'),
(140711, 4921, 46, 'स्थिती'),
(140712, 4922, 46, 'सकारात्मक'),
(140713, 4923, 46, 'सकारात्मक'),
(140714, 4925, 46, 'पोस्ट साठी'),
(140715, 4926, 46, 'पोस्ट नाक ठिबक'),
(140716, 4927, 46, 'पोस्ट देयके'),
(140717, 4928, 46, 'पोस्ट होणारी'),
(140718, 4929, 46, 'बिल म्हणून लेखा खूण पोस्ट'),
(140719, 4930, 46, 'तारीख करण्यासाठी पोस्ट करा'),
(140720, 4931, 46, 'तारीख करण्यासाठी पोस्ट आज पेक्षा जास्त असू शकत नाही'),
(140721, 4932, 46, 'तारीख करण्यासाठी पोस्ट आर्थिक बंद होण्याची तारीख पेक्षा जास्त असणे आवश्यक आहे.'),
(140722, 4933, 46, 'पोस्ट-गर्भपात केअर'),
(140723, 4934, 46, 'पोस्ट-गर्भपात संततिनियमन'),
(140724, 4935, 46, 'पोस्ट-गर्भपात समुपदेशन'),
(140725, 4936, 46, 'पोस्ट-गर्भपात फॉलोअप'),
(140726, 4937, 46, 'पोस्टल'),
(140727, 4938, 46, 'पिन कोड'),
(140728, 4939, 46, 'पिन कोड'),
(140729, 4941, 46, 'PostCalendar'),
(140730, 4942, 46, 'PostCalendar प्रशासन'),
(140731, 4943, 46, 'PostCalendar वर्ग सेटिंग्ज'),
(140732, 4944, 46, 'PostCalendar ग्लोबल सेटिंग्ज'),
(140733, 4945, 46, 'वर पोस्टेड'),
(140734, 4946, 46, 'पोस्ट तारीख'),
(140735, 4947, 46, 'स्थिती {स्थिती साठी {संक्षेप}}'),
(140736, 4948, 46, 'द्वारा समर्थित'),
(140737, 4949, 46, 'PPE + मागील सह / Surg HX'),
(140738, 4950, 46, 'PQRI'),
(140739, 4951, 46, 'PQRI नोंदणी आयडी'),
(140740, 4952, 46, 'PQRI नोंदणी नाव'),
(140741, 4953, 46, 'सराव'),
(140742, 4954, 46, 'सराव डीफॉल्ट सेटिंग'),
(140743, 4955, 46, 'सराव सेटिंग्ज'),
(140744, 4956, 46, 'चिकित्सक'),
(140745, 4957, 46, 'पूर्व सहभाग मूल्यांकन'),
(140746, 4958, 46, 'पूर्व पे'),
(140747, 4959, 46, 'पूर्व भरणा'),
(140748, 4960, 46, 'पूर्व गर्भपात सल्ला'),
(140749, 4961, 46, 'पूर्व गर्भपात समुपदेशन'),
(140750, 4962, 46, 'प्राधान्य मांजर'),
(140751, 4963, 46, 'प्राधान्य'),
(140752, 4964, 46, 'प्राधान्ये'),
(140753, 4965, 46, 'प्राधान्य इव्हेंट वर्ग'),
(140754, 4966, 46, 'प्राधान्य भाषा'),
(140755, 4967, 46, 'पसंतीचे फार्मसी'),
(140756, 4968, 46, 'पसंतीचे प्रदाता संघटना (PPO)'),
(140757, 4969, 46, 'Preg कसोटी'),
(140758, 4970, 46, 'प्राथमिक'),
(140759, 4971, 46, 'अहवाल चालवा करण्यासाठी तयारी'),
(140760, 4972, 46, 'प्रिपेमेंट'),
(140761, 4973, 46, 'नियम'),
(140762, 4974, 46, 'नियम त्याच्या मर्यादा गाठली आहे'),
(140763, 4975, 46, 'डॉक्टरांनी सांगितलेली इतिहास'),
(140764, 4976, 46, 'नियम इतिहास आयात यशस्वीरित्या पूर्ण'),
(140765, 4977, 46, 'डॉक्टरांनी सांगितलेली लेबल'),
(140766, 4978, 46, 'डॉक्टरांनी सांगितलेली अहवाल'),
(140767, 4979, 46, 'चांगले'),
(140768, 4980, 46, 'चांगले आणि Dispensations'),
(140769, 4981, 46, 'चांगले आणि इतर संदर्भ'),
(140770, 4982, 46, 'तज्ञांना करून चांगले आणि / किंवा संदर्भ'),
(140771, 4983, 46, 'चांगले अहवाल'),
(140772, 4984, 46, 'चांगले / संदर्भ'),
(140773, 4985, 46, 'सध्याची'),
(140774, 4986, 46, 'सादर तक्रार'),
(140775, 4987, 46, 'सादर अंक (चे)'),
(140776, 4988, 46, 'प्रेस पुढे जाण्यासाठी सुरू ठेवा'),
(140777, 4989, 46, 'असे गृहीत धरले निदान'),
(140778, 4990, 46, 'तज्ञांना करून असे गृहीत धरले निदान'),
(140779, 4991, 46, 'मागील'),
(140780, 4992, 46, 'मागील सह / Surg HX'),
(140781, 4993, 46, 'मागील. या महिन्यापासून (मेनू ठेवण्यासाठी)'),
(140782, 4994, 46, 'मागील. या वर्षापासून (मेनू ठेवण्यासाठी)'),
(140783, 4995, 46, 'निवारक केअर'),
(140784, 4996, 46, 'प्रतिबंध rehab'),
(140785, 4998, 46, 'इव्हेंटचे पूर्वावलोकन'),
(140786, 5000, 46, 'पूर्वावलोकन'),
(140787, 5001, 46, 'मागील'),
(140788, 5002, 46, 'मागील सल्लामसलत'),
(140789, 5003, 46, 'मागील दिवस'),
(140790, 5004, 46, 'मागील इतिहास / स्क्रिनिंग'),
(140791, 5005, 46, 'मागील महिना'),
(140792, 5006, 46, 'मागील आठवडा'),
(140793, 5007, 46, 'किंमत'),
(140794, 5008, 46, 'किंमत सूट'),
(140795, 5009, 46, 'किंमत पातळी'),
(140796, 5010, 46, 'किंमत स्तर:'),
(140797, 5011, 46, 'किंमती'),
(140798, 5012, 46, 'प्राथमिक'),
(140799, 5013, 46, 'प्राथमिक व्यवसाय अस्तित्व'),
(140800, 5014, 46, 'प्राथमिक व्यवसाय अस्तित्व कर आयडी NewCrop ePrescription खाते आयडी म्हणून वापरले जाते. सुविधा बदलणे NewCrop कार्य प्रभावित करेल.'),
(140801, 5022, 46, 'प्राथमिक इन'),
(140802, 5023, 46, 'प्राथमिक विमा'),
(140803, 5024, 46, 'प्राथमिक विमा डेटा'),
(140804, 5025, 46, 'प्राथमिक विमा प्रदाता'),
(140805, 5026, 46, 'प्राथमिक प्रदाता'),
(140806, 5027, 46, 'प्रिंट'),
(140807, 5028, 46, 'प्रिंट (एचटीएमएल)'),
(140808, 5029, 46, '(PDF) मुद्रित'),
(140809, 5030, 46, 'प्रिंट संशोधन'),
(140810, 5031, 46, 'कोणतीही चकमकीत छापा'),
(140811, 5032, 46, 'कोरे रेफरल फॉर्म प्रिंट'),
(140812, 5033, 46, 'प्रिंट आदेश'),
(140813, 5034, 46, 'प्रिंट तारीख'),
(140814, 5038, 46, 'संपूर्ण सूची छापा'),
(140815, 5039, 46, 'प्रिंट स्वरूप'),
(140816, 5040, 46, 'चार पॅनेल छापा'),
(140817, 5042, 46, 'प्रिंट संदेश'),
(140818, 5043, 46, 'प्रिंट अनेक'),
(140819, 5044, 46, 'फॅक्स करण्यासाठी मल्टिपल प्रिंट'),
(140820, 5045, 46, 'प्रिंट नाव, चिन्ह आणि तारीख.'),
(140821, 5046, 46, 'प्रिंट टिपा'),
(140822, 5047, 46, 'प्रिंट पृष्ठ 1'),
(140823, 5048, 46, 'प्रिंट पृष्ठ 2'),
(140824, 5049, 46, 'रुग्णांच्या पत्ता लेबल छापा'),
(140825, 5051, 46, 'प्रदाता करून प्रिंट पावत्या'),
(140826, 5052, 46, 'प्रिंट नोंद'),
(140827, 5053, 46, 'निवडलेले स्टेटमेन्ट छापा'),
(140828, 5054, 46, 'प्रिंट शॉट नोंद'),
(140829, 5056, 46, 'या घटनेचा छापा'),
(140830, 5057, 46, 'ही टीप छापा'),
(140831, 5058, 46, 'या टीप छापा'),
(140832, 5060, 46, 'फॅक्स वर मुद्रण करा'),
(140833, 5061, 46, 'प्रिंट पहा'),
(140834, 5062, 46, 'मुद्रण'),
(140835, 5063, 46, 'प्रिंट आवृत्ती'),
(140836, 5064, 46, 'छापील'),
(140837, 5066, 46, 'मुद्रण परिणाम:'),
(140838, 5067, 46, 'मुद्रण वगळले; चाचणी आउटपुट पहा');
INSERT INTO `lang_definitions` VALUES
(140839, 5068, 46, 'मुद्रण वगळले; चाचणी आउटपुट पहा '),
(140840, 5069, 46, 'आधी प्रमाणिकरण'),
(140841, 5070, 46, 'आधी प्राधिकृत फॉर्म'),
(140842, 5071, 46, 'आधी भेट द्या'),
(140843, 5072, 46, 'प्राधान्य'),
(140844, 5073, 46, 'प्राधान्य '),
(140845, 5074, 46, 'खाजगी'),
(140846, 5075, 46, 'समस्या'),
(140847, 5076, 46, 'समस्या DX'),
(140848, 5077, 46, 'समस्या यादी'),
(140849, 5078, 46, 'समस्या'),
(140850, 5079, 46, 'समस्या / समस्या'),
(140851, 5080, 46, 'Proc फलंदाज'),
(140852, 5081, 46, 'Proc मांजर'),
(140853, 5082, 46, 'Proc लोड'),
(140854, 5083, 46, 'Proc प्रलंबित रेव'),
(140855, 5084, 46, 'Proc नीति'),
(140856, 5085, 46, 'Proc द्यावे'),
(140857, 5086, 46, 'प्रक्रिया'),
(140858, 5087, 46, 'प्रक्रिया शरीर साइट'),
(140859, 5088, 46, 'प्रक्रिया बुलियन परिणाम'),
(140860, 5089, 46, 'संहिता'),
(140861, 5090, 46, 'प्रक्रिया कोड'),
(140862, 5091, 46, 'प्रक्रिया Lateralities'),
(140863, 5092, 46, 'प्रक्रिया नाव'),
(140864, 5093, 46, 'प्रक्रिया ऑर्डर'),
(140865, 5094, 46, 'प्रक्रिया करण्यासाठी'),
(140866, 5095, 46, 'प्रक्रिया ऑर्डर'),
(140867, 5096, 46, 'प्रक्रिया ऑर्डर सापडली नाही'),
(140868, 5097, 46, 'प्रक्रिया आदेश व अहवाल'),
(140869, 5098, 46, 'प्रक्रिया शोधक'),
(140870, 5099, 46, 'प्रक्रिया प्रदाता'),
(140871, 5100, 46, 'प्रक्रिया प्रदाता'),
(140872, 5101, 46, 'प्रक्रिया प्रदाते'),
(140873, 5102, 46, 'प्रक्रिया अहवाल'),
(140874, 5103, 46, 'प्रक्रिया अहवाल पुतळे'),
(140875, 5104, 46, 'प्रक्रिया परिणाम असाधारण'),
(140876, 5105, 46, 'प्रक्रिया परिणाम पुतळे'),
(140877, 5106, 46, 'प्रक्रिया परिणाम'),
(140878, 5107, 46, 'प्रक्रिया मार्ग'),
(140879, 5108, 46, 'प्रक्रिया नमुना प्रकार'),
(140880, 5109, 46, 'प्रक्रिया सांख्यिकी अहवाल'),
(140881, 5110, 46, 'प्रक्रिया प्रकार'),
(140882, 5111, 46, 'प्रक्रिया प्रकार'),
(140883, 5112, 46, 'प्रक्रिया युनिट'),
(140884, 5113, 46, 'प्रक्रिया / सेवा'),
(140885, 5114, 46, 'प्रक्रियांची'),
(140886, 5115, 46, 'प्रक्रिया'),
(140887, 5116, 46, 'प्रक्रिया आणि स्मरणपत्रे पाठवा'),
(140888, 5117, 46, 'प्रक्रिया ईआरए फाइल'),
(140889, 5118, 46, 'सी रेकॉर्ड नवीन फाइल प्रक्रिया'),
(140890, 5119, 46, 'प्रक्रिया स्मरणपत्रे'),
(140891, 5120, 46, 'प्रक्रिया काही वेळ लागतो'),
(140892, 5121, 46, 'प्रक्रिया'),
(140893, 5122, 46, 'करून प्रक्रिया'),
(140894, 5123, 46, 'प्रक्रिया तारीख'),
(140895, 5124, 46, 'यशस्वीरित्या प्रक्रिया'),
(140896, 5125, 46, 'प्रक्रिया'),
(140897, 5126, 46, 'प्रक्रिया आणि पाठवत रुग्णांच्या स्मरणपत्रे'),
(140898, 5127, 46, 'रुग्णांच्या स्मरणपत्रे प्रक्रिया'),
(140899, 5128, 46, 'प्रक्रिया वेळ'),
(140900, 5129, 46, 'उत्पादन'),
(140901, 5130, 46, 'उत्पादन नियमनाच्या पद्धत'),
(140902, 5131, 46, 'उत्पादन'),
(140903, 5132, 46, 'उत्पादने'),
(140904, 5133, 46, 'उत्पादने पण डॉक्टरांनी सांगितलेली औषधे आणि नाही टेम्पलेट'),
(140905, 5134, 46, 'प्रा'),
(140906, 5135, 46, 'प्रगती टिपा'),
(140907, 5136, 46, 'पुर: स्थ कर्करोग'),
(140908, 5137, 46, 'पुर: स्थ कर्करोग स्क्रीनिंग'),
(140909, 5138, 46, 'पुर: स्थ परीक्षा'),
(140910, 5139, 46, 'पुर: स्थ समस्या'),
(140911, 5140, 46, '/ O enlrgmt, गाठी, निविदा वाईड पुर: स्थ'),
(140912, 5141, 46, 'प्रोटोकॉल'),
(140913, 5142, 46, 'संपूर्ण मार्ग प्रदान'),
(140914, 5143, 46, 'फाइल परिपूर्ण मार्ग प्रदान'),
(140915, 5145, 46, 'प्रत्येक कार्यालय भेट रुग्णांना वैद्यकीय सारांश द्या.'),
(140916, 5146, 46, 'विनंतीनुसार, (निदान चाचणी परिणाम, समस्या यादी, औषधोपचार सूची, औषधोपचार ऍलर्जी समावेश) त्यांच्या आरोग्याची माहिती इलेक्ट्रॉनिक प्रत असलेल्या रुग्णांना द्या.'),
(140917, 5147, 46, 'मालिका उपलब्ध असल्याने माहिती चार व्यवसाय दिवसांच्या आत (लॅब परिणाम, समस्या यादी, औषधोपचार सूची, औषधोपचार ऍलर्जी समावेश) त्यांच्या आरोग्याची माहिती वेळेवर इलेक्ट्रॉनिक प्रवेश असलेल्या रुग्णांना द्या.'),
(140918, 5148, 46, 'भेटीची रुग्णाला रेकॉर्ड द्या'),
(140919, 5149, 46, 'वैध ई-मेल पत्ता द्या'),
(140920, 5150, 46, 'क्लिनिकल सारांश प्रदान?'),
(140921, 5151, 46, 'प्रदान शिक्षण संसाधन (चे)?'),
(140922, 5152, 46, 'प्रदाता'),
(140923, 5153, 46, 'प्रदाता आयडी'),
(140924, 5154, 46, 'प्रदाता आयडी'),
(140925, 5155, 46, 'निर्देशीतचौकटीतदर्शवा सुविधा येथे प्रदाता आयडी'),
(140926, 5156, 46, 'प्रदाता जुळणारे चुका'),
(140927, 5159, 46, 'प्रदाता क्रमांक'),
(140928, 5160, 46, 'प्रदाता नातेसंबंध'),
(140929, 5162, 46, 'प्रदाता:'),
(140930, 5163, 46, 'प्रदाते'),
(140931, 5164, 46, 'प्रदाते NPI'),
(140932, 5165, 46, 'प्रदाते संपूर्ण कॅलेंडर पहा'),
(140933, 5166, 46, 'Prv'),
(140934, 5167, 46, 'PSA'),
(140935, 5168, 46, 'सोरायसिस'),
(140936, 5169, 46, 'Psych निदान'),
(140937, 5170, 46, 'Psych औषधोपचार'),
(140938, 5171, 46, 'मानसिक'),
(140939, 5172, 46, 'मानसिक संक्षिप्त पत्र'),
(140940, 5173, 46, 'मानसिक निदान'),
(140941, 5174, 46, 'मानसिक परीक्षा'),
(140942, 5175, 46, 'मानसिक इतिहास'),
(140943, 5176, 46, 'मानसिक घेणे'),
(140944, 5177, 46, 'मानसिक औषधोपचार'),
(140945, 5178, 46, 'पं%'),
(140946, 5179, 46, 'पं टिपा'),
(140947, 5180, 46, 'पं टिपा / प्रमाणिकरण'),
(140948, 5181, 46, 'पं overpaid'),
(140949, 5182, 46, 'पं अदा'),
(140950, 5183, 46, 'पं आरईसी विनंती'),
(140951, 5184, 46, 'पं परतावा'),
(140952, 5185, 46, 'पं जाहीर'),
(140953, 5186, 46, 'पं अहवाल'),
(140954, 5187, 46, 'पी.टी. विद्यार्थी, किंवा रिक्त सोडा'),
(140955, 5188, 46, 'PT_CITY'),
(140956, 5189, 46, 'PT_DOB'),
(140957, 5190, 46, 'PT_EMAIL'),
(140958, 5191, 46, 'PT_FNAME'),
(140959, 5192, 46, 'PT_LNAME'),
(140960, 5193, 46, 'PT_MNAME'),
(140961, 5194, 46, 'PT_PHONE_CELL'),
(140962, 5195, 46, 'PT_PHONE_HOME'),
(140963, 5196, 46, 'PT_POSTAL'),
(140964, 5197, 46, 'PT_SSN'),
(140965, 5198, 46, 'PT_STATE'),
(140966, 5199, 46, 'PT_STREET'),
(140967, 5201, 46, 'सार्वजनिक'),
(140968, 5203, 46, 'सार्वजनिक आरोग्य सेवा (PHS) पर्यंत किंवा इतर फेडरल एजन्सी'),
(140969, 5204, 46, 'पोर्टो रिकन'),
(140970, 5205, 46, 'फुफ्फुसे'),
(140971, 5206, 46, 'पल्स'),
(140972, 5207, 46, 'पंजाबी'),
(140973, 5208, 46, 'खरेदी'),
(140974, 5209, 46, 'खरेदी / परत'),
(140975, 5210, 46, 'खरेदी'),
(140976, 5211, 46, 'पी {{जस्टिफाय शीर्षलेख}}'),
(140977, 5212, 46, 'पाली'),
(140978, 5213, 46, 'q.3h'),
(140979, 5214, 46, 'q.4h'),
(140980, 5215, 46, 'q.5h'),
(140981, 5216, 46, 'q.6h'),
(140982, 5217, 46, 'q.8h'),
(140983, 5218, 46, 'q.d.'),
(140984, 5219, 46, 'q.i.d.'),
(140985, 5220, 46, 'QOH'),
(140986, 5221, 46, 'QOH मासिक वापर पेक्षा कमी आहे'),
(140987, 5222, 46, 'Qty'),
(140988, 5223, 46, 'QTY'),
(140989, 5224, 46, 'गुणवत्ता'),
(140990, 5225, 46, 'गुणवत्ता उपाय (CQM)'),
(140991, 5226, 46, 'प्रमाण'),
(140992, 5227, 46, 'एनडीसी संख्या'),
(140993, 5228, 46, 'हाताला प्रमाण'),
(140994, 5229, 46, 'प्रमाण निरुपयोगी दिसते'),
(140995, 5230, 46, 'क्वेचुआ'),
(140996, 5231, 46, 'प्रश्न चिन्ह'),
(140997, 5232, 46, 'HCFA बॅच प्रक्रिया रांगेत'),
(140998, 5233, 46, 'HCFA बॅच प्रक्रिया व छपाई रांगेत'),
(140999, 5234, 46, 'यूबी-92 बॅच प्रक्रिया रांगेत'),
(141000, 5235, 46, 'यूबी-92 बॅच प्रक्रिया व छपाई रांगेत'),
(141001, 5236, 46, 'रांगेत आहे'),
(141002, 5237, 46, 'रांगेत आहे आगामी कार्यक्रम प्रशासन'),
(141003, 5238, 46, 'रांगेत'),
(141004, 5240, 46, 'रांगेत सबमिशन प्रशासन'),
(141005, 5241, 46, 'बाहेर पडा'),
(141006, 5242, 46, 'मद्यार्क बाहेर पडा'),
(141007, 5243, 46, 'आर'),
(141008, 5244, 46, 'रुग्णांच्या, आढळतात, किंवा ट्रेस साठी RA चा'),
(141009, 5245, 46, 'शर्यत'),
(141010, 5246, 46, 'शर्यत आणि धर्म'),
(141011, 5247, 46, 'शर्यत / धर्म'),
(141012, 5248, 46, 'रेडिओ'),
(141013, 5249, 46, 'रेडिओ बटण'),
(141014, 5251, 46, 'श्रेणी'),
(141015, 5252, 46, 'पुरळ उठणे'),
(141016, 5253, 46, 'दर'),
(141017, 5254, 46, 'प्रमाण'),
(141018, 5255, 46, 'कच्चा अहवाल'),
(141019, 5256, 46, 'ओळख पुन्हा'),
(141020, 5257, 46, 'ओळख प्रक्रिया पूर्ण पुन्हा'),
(141021, 5258, 46, 'ओळख पुन्हा प्रक्रिया सुरु आहे'),
(141022, 5259, 46, 'पुन्हा ओळख येथे साठवले जाईल'),
(141023, 5260, 46, '-इजा पुन्हा?'),
(141024, 5261, 46, 'पुन्हा-उघडा'),
(141025, 5262, 46, 'पुन्हा-उघडले'),
(141026, 5263, 46, 'प्रतिक्रिया'),
(141027, 5264, 46, 'प्रतिक्रिया'),
(141028, 5265, 46, 'वाचा'),
(141029, 5267, 46, 'केवळ-वाचनीय इतिहास'),
(141030, 5268, 46, 'खरे नाव'),
(141031, 5269, 46, 'खरोखर हटवू'),
(141032, 5270, 46, 'कारण'),
(141033, 5271, 46, 'कारण मृत'),
(141034, 5272, 46, 'मृत्यू कारण'),
(141035, 5274, 46, 'संदर्भ कारण'),
(141036, 5275, 46, 'भेट कारण'),
(141037, 5276, 46, 'कारण / फॉर्म'),
(141038, 5277, 46, 'पावती'),
(141039, 5278, 46, 'भरणा पावती'),
(141040, 5279, 46, 'पावती'),
(141041, 5280, 46, 'भरणा पद्धत अहवालाद्वारे पावत्या'),
(141042, 5281, 46, 'पावत्या सारांश'),
(141043, 5282, 46, 'प्राप्त'),
(141044, 5283, 46, 'प्राप्त'),
(141045, 5284, 46, 'प्राप्त फॅक्स'),
(141046, 5285, 46, 'प्राप्त, पुनरावलोकन नाही'),
(141047, 5286, 46, 'प्राप्त, पुनरावलोकन न केलेले'),
(141048, 5287, 46, 'स्वीकारणारा'),
(141049, 5288, 46, 'स्वीकारणारा आयडी'),
(141050, 5289, 46, 'स्वीकारणारा आयडी (ISA08)'),
(141051, 5290, 46, 'स्वीकारणारा आयडी क्वालिफायर (ISA07)'),
(141052, 5291, 46, 'स्वीकारणारा आयडी'),
(141053, 5292, 46, 'अलीकडील तीन संकेतशब्द परवानगी नाही.'),
(141054, 5293, 46, 'प्राप्तकर्ता'),
(141055, 5294, 46, 'प्राप्तकर्ता यादी रिक्त आहे'),
(141056, 5295, 46, 'प्राप्तकर्ता नाव'),
(141057, 5296, 46, 'प्रकटीकरण प्राप्त'),
(141058, 5297, 46, 'प्राप्तकर्ता स्थिती पूर्ण झाले नसल्यास आवश्यक'),
(141059, 5298, 46, 'शिफारस'),
(141060, 5299, 46, 'अनुसरण साठी शिफारस'),
(141061, 5300, 46, 'शिफारसी'),
(141062, 5301, 46, 'शिफारसी आणि उपचार'),
(141063, 5302, 46, 'तज्ञांना केलेल्या शिफारसी'),
(141064, 5303, 46, 'नोंद'),
(141065, 5304, 46, 'रेकॉर्ड आधीच अस्तित्वात'),
(141066, 5310, 46, 'महत्वाच्या चिन्हे मध्ये रेकॉर्ड आणि चार्ट बदल.'),
(141067, 5311, 46, 'नोंद लोकसंख्याशास्त्र.'),
(141068, 5312, 46, 'रेकॉर्ड प्रकटीकरण'),
(141069, 5313, 46, 'फिटनेस नोंद'),
(141070, 5314, 46, 'रेकॉर्ड भरणा'),
(141071, 5315, 46, 'रेकॉर्ड विनंती तारीख'),
(141072, 5316, 46, '13 वर्षे किंवा त्यापेक्षा जास्त वयाचे रुग्णांना नोंद धूम्रपान स्थिती.'),
(141073, 5317, 46, 'रेकॉर्ड'),
(141074, 5318, 46, 'रेकॉर्ड सापडले'),
(141075, 5319, 46, 'रेकॉर्ड सापडले नाही.'),
(141076, 5320, 46, 'मनोरंजनाच्या औषध वापर'),
(141077, 5321, 46, 'अंमली औषधे'),
(141078, 5322, 46, 'मलमार्गविषयक'),
(141079, 5323, 46, 'मलमार्गविषयक परीक्षा'),
(141080, 5324, 46, 'rectally'),
(141081, 5325, 46, 'पुनर्निर्देशन'),
(141082, 5326, 46, 'लालसरपणा'),
(141083, 5327, 46, 'कमी:'),
(141084, 5328, 46, 'पहा'),
(141085, 5329, 46, 'करून पहा'),
(141086, 5330, 46, 'तारीख पहा'),
(141087, 5331, 46, 'पहा'),
(141088, 5332, 46, 'संदर्भ वर्गीकरण (धोका पातळी)'),
(141089, 5333, 46, 'परिणाम संदर्भ श्रेणी'),
(141090, 5334, 46, 'संदर्भ कारण'),
(141091, 5335, 46, 'Referer'),
(141092, 5336, 46, 'Referer नाव आणि स्वाक्षरी'),
(141093, 5337, 46, 'रेफरल'),
(141094, 5338, 46, 'करून रेफरल'),
(141095, 5339, 46, 'रेफरल कार्ड'),
(141096, 5340, 46, 'रेफरल तारीख'),
(141097, 5341, 46, 'रेफरल फॉर्म'),
(141098, 5342, 46, 'रेफरल प्रपत्र'),
(141099, 5343, 46, 'रेफरल आयडी'),
(141100, 5345, 46, 'रेफरल स्रोत'),
(141101, 5346, 46, 'Encounters साठी रेफरल स्रोत'),
(141102, 5347, 46, 'करण्यासाठी रेफरल'),
(141103, 5348, 46, 'संदर्भ'),
(141104, 5349, 46, 'संदर्भ अहवाल'),
(141105, 5350, 46, 'यांच्या संदर्भाने'),
(141106, 5351, 46, 'यांच्या संदर्भाने'),
(141107, 5352, 46, 'संदर्भित'),
(141108, 5353, 46, 'संदर्भकर्त्यामध्ये'),
(141109, 5354, 46, 'संदर्भकर्त्यामध्ये पत्ता'),
(141110, 5355, 46, 'संदर्भकर्त्यामध्ये निदान'),
(141111, 5356, 46, 'संदर्भकर्त्यामध्ये निदान'),
(141112, 5357, 46, 'संदर्भ वैद्य आणि सराव'),
(141113, 5358, 46, 'संदर्भ प्रदाता'),
(141114, 5359, 46, 'भरण्यासाठी'),
(141115, 5360, 46, 'Refills'),
(141116, 5361, 46, 'refills'),
(141117, 5362, 46, 'सामान्य reflexes'),
(141118, 5363, 46, 'रिफ्रेश'),
(141119, 5365, 46, 'रीफ्रेश स्मरणपत्रे'),
(141120, 5368, 46, 'राज्य नकार दिला'),
(141121, 5369, 46, 'reg_re'),
(141122, 5370, 46, 'नोंदणी'),
(141123, 5371, 46, 'नोंदणी'),
(141124, 5372, 46, 'नोंदणीकृत'),
(141125, 5373, 46, 'नोंदणीकृत'),
(141126, 5374, 46, 'नोंदणीकृत मॉड्यूल'),
(141127, 5375, 46, 'नोंदणी दिनांक'),
(141128, 5376, 46, 'नोंदणी फॉर्म'),
(141129, 5377, 46, 'पुनर्वसन'),
(141130, 5379, 46, 'नाकारले'),
(141131, 5380, 46, 'दुराचरण संभाव्य'),
(141132, 5381, 46, 'संबंधित'),
(141133, 5382, 46, 'संबंधित'),
(141134, 5383, 46, 'संबंधित समस्या'),
(141135, 5384, 46, 'संबंधित रुग्णांच्या टिपा'),
(141136, 5385, 46, 'नाते (चे) / मुले'),
(141137, 5386, 46, 'संबंध'),
(141138, 5387, 46, 'नातेसंबंध'),
(141139, 5388, 46, 'या घटकाच्या सापेक्ष क्रम'),
(141140, 5389, 46, 'नातेवाईक'),
(141141, 5390, 46, 'नातेवाईक रक्तदाब'),
(141142, 5391, 46, 'नातेवाईक कर्करोग'),
(141143, 5392, 46, 'नातेवाईक मधुमेह'),
(141144, 5393, 46, 'नातेवाईक अपस्मार'),
(141145, 5394, 46, 'नातेवाईक हार्ट'),
(141146, 5395, 46, 'नातेवाईक मानसिक आजार'),
(141147, 5396, 46, 'नातेवाईक स्ट्रोक'),
(141148, 5397, 46, 'नातेवाईक आत्महत्या'),
(141149, 5398, 46, 'नातेवाईक क्षयरोग'),
(141150, 5399, 46, 'रिले आरोग्य श्रेय हे वापरकर्ता खाते गहाळ आहेत.'),
(141151, 5400, 46, 'रिले आरोग्य आयडी'),
(141152, 5402, 46, 'प्रकाशन तारीख'),
(141153, 5403, 46, 'धर्म'),
(141154, 5406, 46, 'कृपया पुन्हा लॉगिन'),
(141155, 5407, 46, 'Remdr'),
(141156, 5408, 46, 'निवडलेले सुविधा लक्षात ठेवा'),
(141157, 5409, 46, 'स्मरण'),
(141158, 5410, 46, 'स्मरण कालांतराने'),
(141159, 5411, 46, 'स्मरण पण पाठविलेला नाही'),
(141160, 5412, 46, 'स्मरण रोजी पाठविले'),
(141161, 5413, 46, 'स्मरणपत्रे'),
(141162, 5414, 46, 'REMIT ि ते'),
(141163, 5415, 46, 'दूरस्थ होस्ट'),
(141164, 5416, 46, 'काढा'),
(141165, 5419, 46, 'गट काढा'),
(141166, 5420, 46, 'गट फॉर्म काढा'),
(141167, 5421, 46, 'लसीकरण समर्थन काढून'),
(141168, 5422, 46, 'PhpMyAdmin समर्थन काढून'),
(141169, 5423, 46, 'चांगले समर्थन काढून'),
(141170, 5425, 46, 'चार्ट ट्रॅकर वैशिष्ट्य काढून'),
(141171, 5426, 46, 'मूत्रपिंडासंबंधीचा स्टोन्स'),
(141172, 5427, 46, 'पुनर्नामित करा'),
(141173, 5428, 46, 'गट पुनर्नामित करा'),
(141174, 5429, 46, 'प्रस्तुतीकरण'),
(141175, 5430, 46, 'प्रस्तुत प्रदाता'),
(141176, 5431, 46, 'प्रस्तुत प्रदाता क्रमांक'),
(141177, 5432, 46, 'पुन्हा क्रमवारी लावा'),
(141178, 5433, 46, 'पुन्हा क्रमवारी लावा वेळी'),
(141179, 5434, 46, 'पुन्हा क्रमवारी लावा बिंदू गाठली आहे'),
(141180, 5435, 46, 'लागू नाही तर बिंदू, 0 पुन्हा ऑर्डर'),
(141181, 5436, 46, 'रिपब्लिक'),
(141182, 5437, 46, 'नवीन संकेतशब्द पुन्हा करा'),
(141183, 5438, 46, 'वारंवार कार्यक्रम'),
(141184, 5439, 46, 'माहिती पुनरावृत्ती:'),
(141185, 5440, 46, 'पुनरावृत्ती'),
(141186, 5441, 46, 'बदलली'),
(141187, 5442, 46, 'संपूर्ण कोड संच बदला'),
(141188, 5443, 46, 'बदलले'),
(141189, 5444, 46, 'प्रत्युत्तर द्या उत्तर रद्द तारीख'),
(141190, 5445, 46, 'प्रतिसाद द्या'),
(141191, 5446, 46, 'अहवाल'),
(141192, 5447, 46, 'अहवाल - क्लिनिकल'),
(141193, 5449, 46, 'करून अहवाल'),
(141194, 5451, 46, 'अहवाल एंड (आरोपांमुळे केअर तारीख)'),
(141195, 5452, 46, 'अहवाल रुग्णाला पाठविण्यात आले आहे.'),
(141196, 5453, 46, 'इतिहास / परिणाम नोंदवा'),
(141197, 5454, 46, 'अहवाल परिणाम'),
(141198, 5455, 46, 'अहवाल परिणाम / इतिहास'),
(141199, 5456, 46, 'अहवाल प्रारंभ (असे गृहीत धरले केअर तारीख)'),
(141200, 5457, 46, 'अहवाल स्थिती'),
(141201, 5458, 46, 'अहवाल बेरजा'),
(141202, 5459, 46, 'अहवाल / फॉर्म'),
(141203, 5460, 46, 'Reportable'),
(141204, 5461, 46, 'नोंदविले'),
(141205, 5462, 46, 'नोंदविले तारीख'),
(141206, 5463, 46, 'अहवाल'),
(141207, 5465, 46, 'विनंती वर्णन'),
(141208, 5466, 46, 'विनंती गहाळ आहे!'),
(141209, 5467, 46, 'विनंती दुर्लक्ष - दावे प्रक्रिया आधीच चालू आहे!'),
(141210, 5469, 46, 'विनंती स्थिती'),
(141211, 5470, 46, 'विनंती प्रकार'),
(141212, 5471, 46, 'विनंती प्रकार अंमलबजावणी झाली नाही'),
(141213, 5472, 46, 'विनंती'),
(141214, 5473, 46, 'विनंती तारीख'),
(141215, 5474, 46, 'विनंतीकृत सेवा'),
(141216, 5475, 46, 'मजबूत संकेतशब्द आवश्यक'),
(141217, 5476, 46, 'युनिक संकेतशब्द आवश्यक'),
(141218, 5477, 46, 'आवश्यक'),
(141219, 5478, 46, 'आवश्यक सहकारी पे'),
(141220, 5479, 46, 'आवश्यक फील्ड गहाळ: अपलोड करण्यासाठी EDI-271 फाइल निवडा'),
(141221, 5480, 46, 'आवश्यक फील्ड गहाळ: प्रथम नाव प्रविष्ट करा'),
(141222, 5481, 46, 'आवश्यक फील्ड गहाळ: अंतिम नाव प्रविष्ट करा'),
(141223, 5482, 46, 'आवश्यक फील्ड गहाळ: वापरकर्ता नाव प्रविष्ट करा'),
(141224, 5483, 46, 'जरूरी माहिती'),
(141225, 5484, 46, 'आवश्यकता'),
(141226, 5485, 46, 'राखीव'),
(141227, 5486, 46, 'राखीव'),
(141228, 5487, 46, 'अनुसूचित सुट्टीतील वेळ परिभाषित करण्यासाठी वापरासाठी राखीव'),
(141229, 5488, 46, 'एक प्रदाता उपलब्ध भेटी नसेल तेव्हा परिभाषित करण्यासाठी राखीव.'),
(141230, 5489, 46, 'नमूद केल्याप्रमाणे एक घटना नाही तेव्हा परिभाषित करण्यासाठी राखीव.'),
(141231, 5490, 46, 'एक प्रदाता नंतर भेटी haveavailable शकते तेव्हा राखीव todefine.'),
(141232, 5491, 46, 'रीसेट करा'),
(141233, 5492, 46, 'Offsite Portal ेय रीसेट करा'),
(141234, 5493, 46, 'Onsite Portal ेय रीसेट करा'),
(141235, 5495, 46, 'Resn'),
(141236, 5496, 46, 'सोडवलेले'),
(141237, 5497, 46, 'श्वसन'),
(141238, 5498, 46, 'कृत्रिम श्वासोच्छ्वास प्रयत्न unlabored'),
(141239, 5499, 46, 'श्वसन'),
(141240, 5501, 46, 'वापरकर्ता प्रशासन सेट वेळापत्रक सुविधा नसलेल्या अधिकृत वापरकर्त्यांना प्रतिबंधित करा.'),
(141241, 5502, 46, 'सुविधा वापरकर्ते प्रतिबंधित'),
(141242, 5503, 46, 'प्रतिबंधित प्रशिक्षण'),
(141243, 5504, 46, 'निकाल'),
(141244, 5505, 46, 'निकाल नाव'),
(141245, 5506, 46, 'निकाल स्थिती'),
(141246, 5507, 46, 'परिणाम स्थिती किंवा विकृती गहाळ आहे'),
(141247, 5508, 46, 'निकाल, एक वाइल्डकार्ड म्हणून% वापर'),
(141248, 5509, 46, 'परिणाम'),
(141249, 5510, 46, 'परिणाम आणि'),
(141250, 5511, 46, 'परिणाम साठी शोध सापडले'),
(141251, 5512, 46, 'परिणाम गट'),
(141252, 5513, 46, 'परिणाम फक्त'),
(141253, 5514, 46, 'परिणाम मार्ग'),
(141254, 5515, 46, 'प्रति पृष्ठ परिणाम'),
(141255, 5516, 46, 'परिणाम / माहिती'),
(141256, 5517, 46, 'रेटिनासंबंधी परीक्षा'),
(141257, 5518, 46, 'उजव्या मागे:'),
(141258, 5519, 46, 'परत'),
(141259, 5520, 46, 'आपल्या देयक भाग वरील परत'),
(141260, 5521, 46, 'कॅलेंडर कडे परत'),
(141261, 5522, 46, 'परिणाम अहवाल द्या परत'),
(141262, 5523, 46, 'या पृष्ठावर परत जा आणि आपण ICD10 विभाग हेडर वर क्लिक करून ICD10 प्रतिष्ठापन प्रक्रिया पूर्ण करण्यास सक्षम असेल'),
(141263, 5524, 46, 'या पृष्ठावर परत जा आणि आपण ICD9 विभाग हेडर वर क्लिक करून ICD9 प्रतिष्ठापन प्रक्रिया पूर्ण करण्यास सक्षम असेल'),
(141264, 5525, 46, 'या पृष्ठावर परत जा आणि आपण RXNORM विभाग हेडर वर क्लिक करून RxNorm प्रतिष्ठापन प्रक्रिया पूर्ण करण्यास सक्षम असेल'),
(141265, 5526, 46, 'या पृष्ठावर परत जा आणि आपण SNOMED विभाग हेडर वर क्लिक करून Snomed प्रतिष्ठापन प्रक्रिया पूर्ण करण्यास सक्षम असेल'),
(141266, 5527, 46, 'परत मूल्य'),
(141267, 5528, 46, 'परत भेट द्या'),
(141268, 5529, 46, 'प्ले परत'),
(141269, 5530, 46, 'चारपैकी तीन संकेतशब्द पुनर्वापरासाठी नाही परवानगी!'),
(141270, 5531, 46, 'पुनरावलोकन'),
(141271, 5532, 46, 'पुनरावलोकन व मंजूर'),
(141272, 5534, 46, 'PMH पुनरावलोकन:'),
(141273, 5535, 46, 'प्रणाली पुनरावलोकन'),
(141274, 5536, 46, 'सिस्टम तपासणी पुनरावलोकन'),
(141275, 5537, 46, 'पुनरावलोकन'),
(141276, 5538, 46, 'आवृत्ती'),
(141277, 5539, 46, 'संधी वांत'),
(141278, 5540, 46, 'Rheumotoid संधिवात'),
(141279, 5541, 46, 'उजव्या'),
(141280, 5542, 46, 'उजवा कान'),
(141281, 5543, 46, 'उजवा कान'),
(141282, 5544, 46, 'उजवा समास (मिमी)'),
(141283, 5545, 46, 'उजवीकडे:'),
(141284, 5546, 46, 'कान मध्ये चव अजूनही जिभेवर'),
(141285, 5547, 46, 'कान मध्ये चव अजूनही जिभेवर'),
(141286, 5549, 46, 'जोखीम घटक'),
(141287, 5550, 46, 'जोखीम स्तर'),
(141288, 5551, 46, 'RLL:'),
(141289, 5552, 46, 'रॉम'),
(141290, 5553, 46, 'रोमानियन'),
(141291, 5554, 46, 'रोमांश'),
(141292, 5560, 46, 'रोस्टर'),
(141293, 5561, 46, 'मार्ग'),
(141294, 5562, 46, 'प्रशासन मार्ग, लागू असल्यास'),
(141295, 5563, 46, 'पराभव'),
(141296, 5564, 46, 'पंक्ती'),
(141297, 5565, 46, 'मोर न RRR'),
(141298, 5566, 46, 'घासणे:'),
(141299, 5567, 46, 'Rubs:'),
(141300, 5568, 46, 'नियम'),
(141301, 5569, 46, 'नियम जोडा'),
(141302, 5570, 46, 'नियम तपशील'),
(141303, 5572, 46, 'नियम संपादित करा'),
(141304, 5575, 46, 'सेट राज्य'),
(141305, 5576, 46, 'नियम सेट आणि योजना सेट निवडी सुसंगत नाहीत. निराकरण करा आणि पुन्हा सबमिट करा.'),
(141306, 5578, 46, 'नियम'),
(141307, 5580, 46, 'नियम संरचना'),
(141308, 5581, 46, 'आदेश कार्यरत: '),
(141309, 5582, 46, 'फुटणे'),
(141310, 5583, 46, 'रशियन'),
(141311, 5584, 46, 'RX'),
(141312, 5585, 46, 'RX'),
(141313, 5586, 46, 'RX तळ समास (पीएक्स)'),
(141314, 5587, 46, 'RX DEA # सक्षम'),
(141315, 5588, 46, 'RX NPI सक्षम'),
(141316, 5589, 46, 'RX राज्य एलआयसी सक्षम करा. #'),
(141317, 5590, 46, 'RX डावा समास (पीएक्स)'),
(141318, 5591, 46, 'RX कागद आकार'),
(141319, 5592, 46, 'RX उजवा समास (पीएक्स)'),
(141320, 5593, 46, 'RX शो DEA #'),
(141321, 5594, 46, 'RX शो NPI'),
(141322, 5595, 46, 'RX शो राज्य एलआयसी. #'),
(141323, 5596, 46, 'RX शीर्ष समास (पीएक्स)'),
(141324, 5597, 46, 'RXCUI औषधोपचार'),
(141325, 5598, 46, 'RxNorm'),
(141326, 5599, 46, 'RxNorm डेटाबेस'),
(141327, 5600, 46, 'एस'),
(141328, 5601, 46, 'S.S.'),
(141329, 5602, 46, 'S3,:'),
(141330, 5603, 46, 'वर S4:'),
(141331, 5604, 46, 'एसए * * परवाना वाचण्यासाठी दस्तऐवज / license.txt किंवा ला भेट द्या वाचा * http://www.gnu.org/copyleft/gpl.html * * / // ============ ================================================== =========== // '),
(141332, 5605, 46, 'विक्री'),
(141333, 5606, 46, 'विक्री'),
(141334, 5607, 46, 'आयटम विक्री'),
(141335, 5608, 46, 'उत्पादन अहवाल विक्री'),
(141336, 5609, 46, 'लाळ'),
(141337, 5610, 46, 'त्याच दिवशी'),
(141338, 5611, 46, 'सामोअन'),
(141339, 5612, 46, 'नमुना'),
(141340, 5613, 46, 'मंजूरी प्रकार'),
(141341, 5614, 46, 'सांगो'),
(141342, 5615, 46, 'संस्कृत (Saṁskṛta)'),
(141343, 5616, 46, 'सर्दिनियन'),
(141344, 5617, 46, 'शनि'),
(141345, 5618, 46, 'शनि करा & amp; सन'),
(141346, 5619, 46, 'शनिवारी'),
(141347, 5620, 46, 'जतन करा'),
(141348, 5621, 46, 'सेव्ह'),
(141349, 5622, 46, 'जतन करा आणि बंद करा'),
(141350, 5623, 46, 'जतन करा आणि विनंती हटवा'),
(141351, 5624, 46, 'जतन करा आणि न्याय देणे'),
(141352, 5625, 46, 'जतन करा आणि प्रक्षेपित'),
(141353, 5626, 46, 'नवीन म्हणून जतन करा'),
(141354, 5627, 46, 'नवीन टीप जतन करा'),
(141355, 5628, 46, 'जतन करा प्रमाणपत्र सेटिंग्ज'),
(141356, 5629, 46, 'बदल जतन करा'),
(141357, 5630, 46, 'जतन करा फॉर्म'),
(141358, 5631, 46, 'जतन करा लसीकरण'),
(141359, 5632, 46, 'नवीन क्षेत्र जतन करा'),
(141360, 5633, 46, 'नवीन गट जतन करा'),
(141361, 5634, 46, 'नवीन यादी जतन करा'),
(141362, 5635, 46, 'नवीन टेम्पलेट जतन'),
(141363, 5636, 46, 'वगळणे निवडी जतन करा'),
(141364, 5637, 46, 'रुग्णांच्या लोकसंख्याशास्त्र जतन करा'),
(141365, 5638, 46, 'चार्ट आयडी यशस्वी जतन करा'),
(141366, 5639, 46, 'जतन करा व्यवहार'),
(141367, 5640, 46, 'यशस्वीरित्या जतन'),
(141368, 5641, 46, 'स्कॅन'),
(141369, 5642, 46, 'स्कॅन चकमकीत टीप'),
(141370, 5643, 46, 'स्कॅनर निर्देशिका'),
(141371, 5644, 46, 'मध्ये स्कॅनर'),
(141372, 5645, 46, 'वेळापत्रक'),
(141373, 5646, 46, 'वेळापत्रक सुविधा:'),
(141374, 5647, 46, 'स्कूल सुचना'),
(141375, 5648, 46, 'कशेरूदंडाच्या एका बाजूला असलेला बाक'),
(141376, 5649, 46, 'स्कॉटिश गॅलिक Gaelic-'),
(141377, 5650, 46, 'स्क्रीनिंग / चाचणी'),
(141378, 5651, 46, 'शॉन'),
(141379, 5652, 46, 'शॉन पत्ता'),
(141380, 5653, 46, 'शॉन शहर'),
(141381, 5654, 46, 'शॉन देश'),
(141382, 5655, 46, 'शॉन परिसर'),
(141383, 5656, 46, 'शॉन पोस्टल कोड'),
(141384, 5657, 46, 'शॉन राज्य'),
(141385, 5658, 46, 'शॉन पिन कोड'),
(141386, 5659, 46, 'शोध'),
(141387, 5661, 46, 'शोध'),
(141388, 5662, 46, 'पुन्हा शोध'),
(141389, 5663, 46, 'सर्व स्तंभ शोधा'),
(141390, 5664, 46, 'शोध घ्या:'),
(141391, 5665, 46, 'शोधा'),
(141392, 5666, 46, 'शोध घ्या:'),
(141393, 5667, 46, 'शोध'),
(141394, 5668, 46, 'शोधा'),
(141395, 5669, 46, 'शोधा किंवा रुग्णांच्या जोडा'),
(141396, 5670, 46, 'शोध भरणा'),
(141397, 5671, 46, 'शोध परिणाम'),
(141398, 5672, 46, 'शोध परिणाम:'),
(141399, 5673, 46, 'शोध निवडलेले'),
(141400, 5674, 46, 'शोध स्ट्रिंग डेटाबेसमध्ये यादी जुळत नाही'),
(141401, 5675, 46, 'शोध स्ट्रिंग किमान तीन वर्ण असणे आवश्यक आहे'),
(141402, 5676, 46, 'शोध मजकूर'),
(141403, 5677, 46, 'कार्यक्रम शोधा'),
(141404, 5678, 46, 'शोध जोडा /'),
(141405, 5679, 46, 'शोध जोडा / ववमाकते'),
(141406, 5680, 46, 'भेटी शोध'),
(141407, 5681, 46, 'शोध घेत आहे ...'),
(141408, 5682, 46, 'Seatbelt वापरा'),
(141409, 5683, 46, 'Seatbelt वापर'),
(141410, 5684, 46, 'दुसरा'),
(141411, 5687, 46, 'माध्यमिक'),
(141412, 5688, 46, 'माध्यमिक विमा'),
(141413, 5689, 46, 'माध्यमिक विमा डेटा'),
(141414, 5690, 46, 'माध्यमिक विमा प्रदाता'),
(141415, 5691, 46, 'माध्यमिक वैद्यकीय प्रकार'),
(141416, 5693, 46, 'कलम आयडी'),
(141417, 5694, 46, 'कलम आयडी आणि नाव रिकामे असू शकत नाही'),
(141418, 5695, 46, 'विभागाचे नाव'),
(141419, 5696, 46, 'कलम यशस्वीरित्या जतन'),
(141420, 5698, 46, 'सुरक्षा'),
(141421, 5699, 46, 'सर्व पाहा'),
(141422, 5700, 46, 'अधिकृत पहा'),
(141423, 5701, 46, 'वाढ-चार्ट पहा'),
(141424, 5702, 46, 'व्युत्पन्न दावे शेवटच्या सेटमध्ये संदेश पहा'),
(141425, 5704, 46, 'पासून पाहिले'),
(141426, 5705, 46, 'या विभागाचा नाव'),
(141427, 5706, 46, 'विभागांना बॅच दावा'),
(141428, 5707, 46, 'फेफरे येतात'),
(141429, 5708, 46, 'Sel'),
(141430, 5709, 46, 'निवडा'),
(141431, 5710, 46, 'निवडा'),
(141432, 5711, 46, 'एक घटक निवडा'),
(141433, 5712, 46, 'एक संदर्भ निवडा'),
(141434, 5713, 46, 'पंक्ती टक्केवारी निवडा किंवा किंवा तारखा निवडण्यासाठी'),
(141435, 5714, 46, 'एक वेळ कालावधी निवडा'),
(141436, 5715, 46, 'वापरकर्ता निवडा'),
(141437, 5716, 46, 'सर्व निवडा'),
(141438, 5717, 46, 'दुरुस्ती तारिख निवडा'),
(141439, 5718, 46, 'प्रिंट दुरुस्त्या निवडा'),
(141441, 5720, 46, 'श्रेणी निवडा'),
(141442, 5721, 46, 'संप्रेषण प्राधान्ये निवडा'),
(141443, 5722, 46, 'हटवू संबंधित चेकबॉक्स निवडा'),
(141444, 5723, 46, 'निवडा निकष काढा'),
(141445, 5724, 46, 'सी टेबल निवडा'),
(141446, 5725, 46, 'डे ओळख डेटा आवश्यक निवडा'),
(141447, 5726, 46, 'निवडा डेटा डी ओळखले डेटा समाविष्ट करणे'),
(141448, 5727, 46, 'तारीख निवडा'),
(141449, 5728, 46, 'इच्छित संघात निवडा'),
(141450, 5729, 46, 'निवडा निदान'),
(141451, 5730, 46, 'डे ओळख विनंती निदान निवडा'),
(141452, 5731, 46, 'निवडा औषध'),
(141453, 5732, 46, 'निवडा औषधे'),
(141454, 5733, 46, 'डे ओळख विनंती निवडा औषधे'),
(141455, 5734, 46, 'निवडा EDI-271 फाइल'),
(141456, 5735, 46, 'निवडा आढळतात'),
(141457, 5736, 46, 'निवडा क्षेत्र'),
(141458, 5737, 46, 'निवडा फील्ड'),
(141459, 5738, 46, 'मुद्रणासाठी निवडा'),
(141460, 5739, 46, 'निवडा लसीकरण'),
(141461, 5740, 46, 'डे ओळख विनंती लसीकरण निवडा'),
(141462, 5741, 46, 'टाइप करून, विमा निवडा'),
(141463, 5742, 46, 'निवडा अंक'),
(141464, 5743, 46, 'आयटम निवडा'),
(141465, 5744, 46, 'भाषा निवडा'),
(141466, 5745, 46, 'एक निवडा'),
(141467, 5746, 46, 'सेवा समायोजित करण्यासाठी एक किंवा अधिक निदान कोड निवडा'),
(141468, 5747, 46, 'अपलोड करण्यासाठी एक किंवा अधिक फायली निवडा'),
(141469, 5748, 46, 'निवडा आउटपुट'),
(141470, 5750, 46, 'विनंती निवडा'),
(141471, 5752, 46, 'निवडा स्रोत'),
(141472, 5753, 46, 'निवडा साचा'),
(141473, 5754, 46, 'निर्यात संरचना आयटम निवडा'),
(141474, 5755, 46, 'या दिवशी कोणत्याही नाही कार्यक्रमांसाठी प्रामुख्याने जबाबदार समस्या निवडा'),
(141475, 5756, 46, 'डाव्या nav स्क्रीन मध्ये पॉपअप पासून रुग्ण पत्ता लेबले मुद्रित निवडा.'),
(141476, 5757, 46, 'ट्रॅक निवडा'),
(141477, 5759, 46, 'निवडा वापरकर्ता'),
(141478, 5760, 46, 'ड्रापडाउनसूची पासून निवडा वापरकर्ते'),
(141479, 5761, 46, 'जर असेल तर, लॉगिन निवड केली जाऊ शकते, जे भाषा निवडा. (फक्त समर्पक परवानगी सर्व भाषा बंद आहे वरील)'),
(141480, 5762, 46, 'गट नष्ट करण्यासाठी होय निवडा'),
(141481, 5765, 46, 'निवडलेले'),
(141482, 5766, 46, 'निवडलेले आढळतात'),
(141483, 5767, 46, 'या (ही एक गट काम नाही आहे) प्रत्येक प्राप्तकर्ता प्रक्रिया करणे आवश्यक आहे की एक संदेश तयार होईल निवडणे.'),
(141484, 5768, 46, 'स्वत:'),
(141485, 5769, 46, 'स्वत: ची पे'),
(141486, 5771, 46, 'पाठवा'),
(141487, 5772, 46, 'एक दि स्मरणपत्र पाठवा'),
(141488, 5773, 46, 'एक स्मरणपत्र पाठवा'),
(141489, 5774, 46, 'प्रगतीपथावर पाठवा'),
(141490, 5775, 46, 'संदेश पाठवा'),
(141491, 5776, 46, 'स्मरणपत्रे बॅच पाठवा'),
(141492, 5777, 46, 'प्रतिबंधात्मक / पाठपुरावा काळजी धीराने प्राधान्य टक्के रुग्णांना स्मरणपत्रे पाठवा.'),
(141493, 5778, 46, 'संदर्भ सह सारांश पाठवा'),
(141494, 5779, 46, 'या फाइल पाठवा'),
(141495, 5780, 46, 'हा संदेश पाठवा'),
(141496, 5781, 46, 'ला पाठवणे'),
(141497, 5784, 46, 'सर्व पाठवा'),
(141498, 5786, 46, 'पोर्टल पाठवा'),
(141499, 5787, 46, 'पोर्टल पाठवा'),
(141500, 5788, 46, 'प्रेषक'),
(141501, 5789, 46, 'प्रेषक ID'),
(141502, 5790, 46, 'प्रेषक ID (ISA06)'),
(141503, 5791, 46, 'प्रेषक ID क्वालिफायर (ISA05)'),
(141504, 5792, 46, 'प्रेषक आयडी'),
(141505, 5793, 46, 'करण्यासाठी पाठवत आहे'),
(141506, 5794, 46, 'संवेदनांचा'),
(141507, 5795, 46, 'संवेदनशीलता:'),
(141508, 5796, 46, 'ज्ञानेंद्रियांचा परीक्षा सामान्य'),
(141509, 5797, 46, 'पाठविलेला'),
(141510, 5798, 46, 'पाठविले - पुष्टी'),
(141511, 5799, 46, 'करून पाठविलेला सर्व करिता रिक्त सोडा'),
(141512, 5800, 46, 'पाठविले:'),
(141513, 5801, 46, 'तारीख पाठविली'),
(141514, 5802, 46, 'प्रेषित आयटम्स'),
(141515, 5803, 46, 'वैद्यकीय रेकॉर्ड पाठविले?'),
(141516, 5804, 46, 'यशस्वीरित्या पाठवले'),
(141517, 5807, 46, 'प्रिंटर पाठविले.'),
(141518, 5808, 46, 'सर्व रिक्त सोडा पाठविले'),
(141519, 5809, 46, 'यांना प्रेषित:'),
(141520, 5810, 46, 'पाठवला, पण चेंडू अद्याप पुष्टी नाही.'),
(141521, 5811, 46, 'पाठविलेला प्राप्त झाले नाही'),
(141522, 5812, 46, 'सप्टेंबर'),
(141523, 5813, 46, 'विभक्त'),
(141524, 5814, 46, 'सप्टेंबर'),
(141525, 5815, 46, 'Seq'),
(141526, 5816, 46, 'क्रम'),
(141527, 5817, 46, 'सर्बियन'),
(141528, 5818, 46, 'Serv रिपब्लिक'),
(141529, 5819, 46, 'सर्व्हर ऑफलाइन असू शकते'),
(141530, 5820, 46, 'सर्व्हर संदेश:'),
(141531, 5821, 46, 'सेवा'),
(141532, 5822, 46, 'सेवा वर्ग'),
(141533, 5823, 46, 'सेवा कोड'),
(141534, 5824, 46, 'सेवा कोड वित्त अहवाल'),
(141535, 5825, 46, 'सेवा कोड'),
(141536, 5826, 46, 'सेवा तारीख'),
(141537, 5827, 46, 'सेवा दिनांक:'),
(141538, 5829, 46, 'सेवा स्थान'),
(141539, 5830, 46, 'सेवा नाव'),
(141540, 5831, 46, 'सेवा तज्ञांना द्वारे प्रदान'),
(141541, 5832, 46, 'सेवा अहवाल'),
(141542, 5833, 46, 'फक्त अहवाल सेवा'),
(141543, 5834, 46, 'सेवा'),
(141544, 5835, 46, 'वर्ग करून सेवा'),
(141545, 5836, 46, 'सेवा प्रदान'),
(141546, 5837, 46, 'सेवा प्रदान'),
(141547, 5838, 46, 'सेवा / उत्पादने'),
(141548, 5839, 46, 'सत्र प्रकार'),
(141549, 5840, 46, 'सेट'),
(141550, 5841, 46, 'लॉगिन दरम्यान निवडले सुविधा लक्षात एक सुविधा कुकी सेट करा.'),
(141551, 5842, 46, 'पूर्ण म्हणून सेट करा'),
(141552, 5843, 46, 'CDR इंजिन आधारित अहवाल सेट प्रक्रिया प्राधान्य.'),
(141553, 5844, 46, '(पूर्ण क्लिनिकमध्ये मोडमध्ये) रुग्णांच्या स्मरणपत्रे निर्मितीसाठी सेट प्रक्रिया प्राधान्य.'),
(141554, 5845, 46, 'पूर्ण अचूक पथ या सेट करा. HTTPS वरील ग्राहकाला SSL प्रमाणपत्र तयार करण्यासाठी.'),
(141555, 5846, 46, 'करण्यासाठी सेट'),
(141556, 5847, 46, 'डीफॉल्ट सेट'),
(141557, 5848, 46, 'डेटाबेस मध्ये आवृत्ती क्रमांक सेट करत आहे ...'),
(141558, 5849, 46, 'सेटिंग्ज'),
(141559, 5851, 46, 'तीव्र मांडली आहे'),
(141560, 5853, 46, 'वेदना तीव्रता'),
(141561, 5854, 46, 'वेदना तीव्रता:'),
(141562, 5855, 46, 'लिंग'),
(141563, 5856, 46, 'अश्लील रोग संसर्गजन्य'),
(141564, 5857, 46, 'केलेला SFTP'),
(141565, 5858, 46, 'SHA-1 हॅश'),
(141566, 5859, 46, 'सामायिकरण'),
(141567, 5860, 46, 'सर्व्हर पासून छपाई साठी शेल आदेश.'),
(141568, 5862, 46, 'शोना'),
(141569, 5863, 46, 'लघु वर्णन'),
(141570, 5864, 46, 'धाप लागणे'),
(141571, 5865, 46, 'धाप लागणे'),
(141572, 5866, 46, 'श्वास 2 लागणे'),
(141573, 5867, 46, 'शॉट नोंद'),
(141574, 5868, 46, 'म्हणून नोंद शॉट:');
INSERT INTO `lang_definitions` VALUES
(141575, 5869, 46, 'सक्षम पाहिजे'),
(141576, 5870, 46, 'nnnnn-NNNN-एन जसे पाहिजे'),
(141577, 5871, 46, 'दोन अक्षरे असावे'),
(141578, 5872, 46, '10 अंक असणे आवश्यक आहे'),
(141579, 5873, 46, 'केवळ 10 अंक असणे आवश्यक आहे'),
(141580, 5874, 46, 'खांदा'),
(141581, 5875, 46, 'खांदा + गळ्याभोवतालचे हाड'),
(141582, 5876, 46, 'खांदा समस्या'),
(141583, 5877, 46, 'दर्शवा'),
(141584, 5878, 46, 'सक्रिय दर्शवा'),
(141585, 5880, 46, 'सगळं दाखवा'),
(141586, 5881, 46, 'सर्व प्रक्रीया दर्शवा'),
(141587, 5883, 46, 'सर्व व्यवहार दर्शवा'),
(141588, 5884, 46, 'म्हणून व्यस्त दर्शवा'),
(141589, 5885, 46, 'दाखवा अधिकृत'),
(141590, 5886, 46, 'शो उपलब्ध टाइम्स'),
(141591, 5887, 46, 'दर्शवा अमेरिका आणि मेट्रिक दोन्ही (मुख्य युनिट मेट्रिक आहे)'),
(141592, 5888, 46, 'दर्शवा अमेरिका आणि मेट्रिक (मुख्य युनिट अमेरिकन आहे) दोन्ही'),
(141593, 5889, 46, 'तपशील दाखवा'),
(141594, 5890, 46, 'शो चुका फक्त?'),
(141595, 5891, 46, 'आलेख दर्शवा'),
(141596, 5892, 46, 'Mouseover कार्यक्रम मजकूर घिरट्या दिसून येते?'),
(141597, 5893, 46, 'दर्शवा किती इव्हेंट्स प्रशासन पृष्ठांवर?'),
(141598, 5894, 46, 'शो निष्क्रिय'),
(141599, 5896, 46, 'मेनू दर्शवा'),
(141600, 5897, 46, 'मेट्रिक केवळ दर्शवा'),
(141601, 5898, 46, 'टिपा दर्शवा'),
(141602, 5900, 46, 'वगळले नाही फक्त प्रक्रीया दर्शवा'),
(141603, 5901, 46, 'रुग्णांच्या टिपा दर्शवा'),
(141604, 5902, 46, 'शो पाउंड आणि औन्स'),
(141605, 5903, 46, 'दशांश मूल्य म्हणून दर्शवा पाउंड'),
(141606, 5904, 46, 'प्राथमिक पूर्ण दर्शवा'),
(141607, 5905, 46, 'शो स्मरणपत्रे'),
(141608, 5906, 46, 'शो अहवाल'),
(141609, 5907, 46, 'दर्शवा शोध / ब्लॉक दुवे सादर?'),
(141610, 5910, 46, 'ऍड यादी विजेट सानुकूल राज्य फॉर्म (शीर्षक आणि संक्षेप विचारेल) दर्शवा.'),
(141611, 5911, 46, 'नाही समस्या या वर्गात प्रविष्ट केले, तरी रुग्णाला सारांश स्क्रीन वर या वर्गात दर्शवा.'),
(141612, 5912, 46, 'दर्शवा ट्रॅक इतिहास'),
(141613, 5913, 46, 'शो बिल न केलेली फक्त'),
(141614, 5914, 46, 'केवळ यूएस दर्शवा'),
(141615, 5915, 46, 'दर्शवित'),
(141616, 5916, 46, 'परिणाम दर्शवित'),
(141617, 5918, 46, 'भावंडे इतिहास'),
(141618, 5920, 46, 'भावंड'),
(141619, 5921, 46, 'विळा सेल'),
(141620, 5922, 46, 'Sig'),
(141621, 5923, 46, 'सिग्मा / Colonoscopy'),
(141622, 5924, 46, 'साइन इन करा'),
(141623, 5925, 46, 'लॅब परिणाम (, लेखन addonly पर्यायी) साइन इन करा'),
(141624, 5926, 46, 'साइन इन करा परिणाम'),
(141625, 5927, 46, 'स्वाक्षरी'),
(141626, 5928, 46, 'फाइल सही'),
(141627, 5929, 46, 'स्वाक्षरी:'),
(141628, 5930, 46, 'साइन इन Rx'),
(141629, 5932, 46, 'महत्त्वाच्या सूज:'),
(141630, 5933, 46, 'सरलीकृत'),
(141631, 5934, 46, 'सरलीकृत सहकारी पे'),
(141632, 5935, 46, 'सरलीकृत लोकसंख्याशास्त्र'),
(141633, 5936, 46, 'सरलीकृत चांगले'),
(141634, 5937, 46, 'असल्याने'),
(141635, 5938, 46, 'विनम्र,'),
(141636, 5939, 46, 'सिंधी'),
(141637, 5940, 46, 'सिंगल'),
(141638, 5941, 46, 'सिंगल-निवड यादी'),
(141639, 5942, 46, 'यादीत जोडण्यासाठी क्षमता सिंगल निवड यादी'),
(141640, 5943, 46, 'असामान्य'),
(141641, 5944, 46, 'सिंहली'),
(141642, 5945, 46, 'सिंहली, सिंहली'),
(141643, 5946, 46, 'सायनस समस्या'),
(141644, 5947, 46, 'सायनस शस्त्रक्रिया'),
(141645, 5948, 46, 'सायनस प्रेमळपणा:'),
(141646, 5949, 46, 'सायनुसायटिस'),
(141647, 5950, 46, 'साइट'),
(141648, 5951, 46, 'साइट ID'),
(141649, 5952, 46, 'वैद्यकीय माहिती एकत्रीकरण, एलएलसी लॅब एक्सचेंज सेवा साइट ID.'),
(141650, 5953, 46, 'LibreEHR समर्थन, LLC लॅब विनिमय सेवा साइट आयडी.'),
(141651, 5956, 46, 'आकार'),
(141652, 5957, 46, 'आकार 1 आणि 999 दरम्यान एक संख्या असणे आवश्यक आहे'),
(141653, 5958, 46, 'आकार / यादी'),
(141654, 5959, 46, 'त्वचा'),
(141655, 5960, 46, 'त्वचा कर्करोग'),
(141656, 5961, 46, 'त्वचा रोग'),
(141657, 5962, 46, 'इतर त्वचा'),
(141658, 5963, 46, 'रुग्णांच्या नोंदी प्राधिकृत जा'),
(141659, 5964, 46, 'वगळण्याबद्दल विभाग'),
(141660, 5965, 46, 'सोडून देत एस क्यू एल-लेजर डंप - विंडोज सर्व्हर लागू नाही'),
(141661, 5967, 46, 'झोप नमुने'),
(141662, 5968, 46, 'झोप नमुन्यांची'),
(141663, 5969, 46, 'झोपलेला'),
(141664, 5970, 46, 'स्लोव्हाक'),
(141665, 5971, 46, 'स्लोवेन'),
(141666, 5972, 46, 'एस.एम. कर्ज वाईड ओ /'),
(141667, 5973, 46, 'Smarty कॅशे साफ केले गेले'),
(141668, 5974, 46, 'धूम्रपान, अज्ञात वर्तमान स्थिती'),
(141669, 5976, 46, 'धूम्रपान स्थिती'),
(141670, 5977, 46, 'एसएमएस प्रमाणिकरण'),
(141671, 5978, 46, 'एसएमएस गेटवे'),
(141672, 5979, 46, 'एसएमएस गेटवे API की'),
(141673, 5980, 46, 'एसएमएस गेटवे API की'),
(141674, 5981, 46, 'एसएमएस गेटवे पासवर्ड'),
(141675, 5982, 46, 'एसएमएस गेटवे वापरकर्तानाव'),
(141676, 5983, 46, 'एसएमएस अधिसूचना'),
(141677, 5984, 46, 'एसएमएस अधिसूचना तास'),
(141678, 5985, 46, 'एसएमएस पाठवा आधी'),
(141679, 5986, 46, 'एसएमएस पाठविले'),
(141680, 5987, 46, 'SMS मजकूर, वापरता येण्याजोगे टॅग: *** *** की NAME, *** *** प्रदात्याकडून, *** *** हे DATE, *** *** startTime, *** ENDTIME *** प्रवास म्हणजे प्रिय *** *** NAME ना'),
(141681, 5988, 46, 'एसएमएस / ई-मेल अॅलर्ट सेटिंग्ज'),
(141682, 5989, 46, 'प्रमाणीकरणासाठी या SMTP संकेतशब्द'),
(141683, 5992, 46, 'SMTP सर्व्हर यजमाननाव'),
(141684, 5993, 46, 'SMTP सर्व्हर पोर्ट क्रमांक'),
(141685, 5994, 46, 'प्रमाणीकरणासाठी या SMTP वापरकर्ता'),
(141686, 5995, 46, 'SNOMED'),
(141687, 5996, 46, 'SNOMED (RF1) क्लिनिकल मुदत'),
(141688, 5997, 46, 'SNOMED (RF1) निदान'),
(141689, 5998, 46, 'SNOMED (RF1) प्रक्रिया'),
(141690, 5999, 46, 'SNOMED (RF2) निदान'),
(141691, 6000, 46, 'SNOMED क्लिनिकल मुदत'),
(141692, 6001, 46, 'SNOMED डेटाबेस'),
(141693, 6002, 46, 'SNOMED निदान'),
(141694, 6003, 46, 'SNOMED प्रक्रिया'),
(141695, 6004, 46, 'धम्माल'),
(141696, 6005, 46, 'SOAP'),
(141697, 6006, 46, 'सामाजिक अडचणी'),
(141698, 6009, 46, 'सामाजिक इतिहास:'),
(141699, 6010, 46, 'सामाजिक सुरक्षा क्रमांक'),
(141700, 6011, 46, 'उपाय'),
(141701, 6012, 46, 'सोमाली'),
(141702, 6013, 46, 'मनाहून भिन्न अशा शरीराविषयी संदर्भ'),
(141703, 6014, 46, 'काही अधिकृत प्रदर्शित केले गेलेले नाहीत. सर्व पाहण्यासाठी येथे क्लिक करा'),
(141704, 6015, 46, 'काही कोड प्रदर्शित केले गेलेले नाहीत.'),
(141705, 6016, 46, 'काही चकमकी प्रदर्शित केले गेलेले नाहीत. सर्व पाहण्यासाठी येथे क्लिक करा.'),
(141706, 6017, 46, 'काही त्रुटी डे ओळख प्रक्रिया दरम्यान आली आहे'),
(141707, 6018, 46, 'काही नोट्स प्रदर्शित केले गेलेले नाहीत.'),
(141708, 6019, 46, 'काही कार्यालय नोट्स प्रदर्शित केले गेलेले नाहीत. सर्व पाहण्यासाठी येथे क्लिक करा.'),
(141709, 6020, 46, 'काही शब्द'),
(141710, 6021, 46, 'कोणीतरी दुसरे फक्त या भेट बदलले आहे. हे पृष्ठ रद्द करा आणि पुन्हा प्रयत्न करा.'),
(141711, 6023, 46, 'काहीतरी चूक झाली. कृपया पुन्हा प्रयत्न करा.'),
(141712, 6024, 46, 'लवकरच मुळे मध्यांतर (क्लिनिकल स्मरणपत्रे)'),
(141713, 6025, 46, 'लवकरच मुळे मध्यांतर (रुग्णांच्या स्मरणपत्रे)'),
(141714, 6026, 46, 'घसा खवखवणे'),
(141715, 6027, 46, 'क्षमस्व नाही नियुक्ती मुदत आहे'),
(141716, 6028, 46, 'क्षमस्व, आपली फाइल अपलोड करताना समस्या आली'),
(141717, 6029, 46, 'नुसार क्रमवारी लावा'),
(141718, 6030, 46, 'क्रमवारी लावा करून'),
(141719, 6031, 46, 'चेकसम लावा'),
(141720, 6032, 46, 'टिप्पण्या क्रमवारी लावा'),
(141721, 6033, 46, 'सीआरटी वापरकर्ता द्वारे क्रमवारीत लावा'),
(141722, 6034, 46, 'तारखेप्रमाणे लावा'),
(141723, 6035, 46, 'तारीख / वेळ लावा'),
(141724, 6036, 46, 'इव्हेंट लावा'),
(141725, 6037, 46, 'गट क्रमवारी लावा'),
(141726, 6038, 46, 'नवीन चेकसम लावा'),
(141727, 6039, 46, 'जुन्या चेकसम लावा'),
(141728, 6040, 46, 'PatientID लावा'),
(141729, 6041, 46, 'यशस्वी लावा'),
(141730, 6042, 46, 'लुडबुड तारीख / वेळ लावा'),
(141731, 6043, 46, 'वापरकर्ता द्वारे क्रमवारीत लावा'),
(141732, 6044, 46, 'लस लावा'),
(141733, 6045, 46, 'क्रमवारी लावा खाली'),
(141734, 6046, 46, 'क्रमवारी लावा परिणाम'),
(141735, 6047, 46, 'क्रमवारी लावा अप'),
(141736, 6048, 46, 'स्रोत'),
(141737, 6049, 46, 'स्त्रोत फाइल'),
(141738, 6050, 46, 'स्त्रोत फाइल पथ'),
(141739, 6051, 46, 'स्त्रोत कोड गहाळ आहे '),
(141740, 6052, 46, 'स्रोत लोट'),
(141741, 6054, 46, 'स्रोत रुग्णांच्या'),
(141742, 6055, 46, 'स्रोत रुग्ण नाही डीओबी आहे'),
(141743, 6056, 46, 'स्रोत रुग्ण आढळले नाही'),
(141744, 6057, 46, 'स्त्रोत:'),
(141745, 6058, 46, 'दक्षिणात्य देबेली'),
(141746, 6059, 46, 'सेसोथो'),
(141747, 6060, 46, 'जागा'),
(141748, 6061, 46, 'स्पेस'),
(141749, 6062, 46, 'स्पॅनिश'),
(141750, 6063, 46, 'स्पॅनिश (लॅटिन अमेरिकन)'),
(141751, 6064, 46, 'स्पॅनिश (स्पेन)'),
(141752, 6065, 46, 'Spanish- कॅस्टेलियन'),
(141753, 6066, 46, 'विशेष वर्ण अनुमत नाहीत'),
(141754, 6067, 46, 'मर्मस्थाने फॉर्म विशेष उपचार'),
(141755, 6068, 46, 'स्पेशॅलिस्ट'),
(141756, 6069, 46, 'स्पेशॅलिस्ट नाव आणि स्वाक्षरी'),
(141757, 6071, 46, 'विशेष'),
(141758, 6072, 46, 'विशेष प्रणाल्या'),
(141759, 6073, 46, 'विशेष:'),
(141760, 6074, 46, 'विशिष्ट'),
(141761, 6075, 46, 'विशिष्ट अर्ज'),
(141762, 6076, 46, 'विशिष्ट नियमनाच्या सेवा'),
(141763, 6077, 46, 'विशिष्ट निकाल'),
(141764, 6078, 46, 'विशिष्ट सेवा'),
(141765, 6079, 46, 'निर्दिष्ट'),
(141766, 6080, 46, 'कोड स्वरूपण निर्दिष्ट करते. # = अंक * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141767, 6081, 46, 'कोड स्वरूपण निर्दिष्ट करते. # = अंक @ = अल्फा, * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141768, 6082, 46, 'अशी यादी तयार करणे संदर्भ क्रमांक स्वरूपण निर्दिष्ट करते. # = अंक * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141769, 6083, 46, 'अशी यादी तयार करणे संदर्भ क्रमांक स्वरूपण निर्दिष्ट करते. # = अंक @ = अल्फा, * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141770, 6084, 46, 'उत्पादन एनडीसी फील्ड स्वरूपण निर्दिष्ट करते. # = अंक * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141771, 6085, 46, 'उत्पादन एनडीसी फील्ड स्वरूपण निर्दिष्ट करते. # = अंक @ = अल्फा, * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141772, 6086, 46, 'बाह्य रुग्ण आयडी स्वरूपण निर्दिष्ट करते. # = अंक * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141773, 6087, 46, 'बाह्य रुग्ण आयडी स्वरूपण निर्दिष्ट करते. # = अंक @ = अल्फा, * = कोणत्याही वर्ण. रिक्त वापरले तर नाही.'),
(141774, 6088, 46, 'नमुना'),
(141775, 6089, 46, 'नमुना संख्या / अभिज्ञापक'),
(141776, 6090, 46, 'नमुना प्रकार'),
(141777, 6092, 46, 'भाषण शुद्धलेखन'),
(141778, 6093, 46, 'Spermicides'),
(141779, 6094, 46, 'शस्त्रक्रियेद्वार प्लीहा काढून टाकणे'),
(141780, 6095, 46, 'पती, पत्नी'),
(141781, 6096, 46, 'पती इतिहास'),
(141782, 6097, 46, 'खाकरा'),
(141783, 6098, 46, 'खाकरा:'),
(141784, 6099, 46, 'SQ'),
(141785, 6100, 46, 'एस क्यू एल'),
(141786, 6102, 46, 'संघ'),
(141787, 6103, 46, 'संघ सदस्यत्व'),
(141788, 6104, 46, 'संघ'),
(141789, 6105, 46, 'SRH'),
(141790, 6106, 46, 'SRH - कुटुंब नियोजन'),
(141791, 6107, 46, 'SRH नॉन कुटुंब नियोजन'),
(141792, 6108, 46, 'SRH संदर्भ'),
(141793, 6109, 46, 'SRH भेट द्या फॉर्म'),
(141794, 6110, 46, 'SRV तारीख'),
(141795, 6111, 46, 'एस'),
(141796, 6112, 46, 'SSL प्रमाणपत्र प्रशासन'),
(141797, 6113, 46, 'SSN'),
(141798, 6114, 46, 'स्थिरता'),
(141799, 6115, 46, 'आयोजित रिलीझ'),
(141800, 6116, 46, 'मानक'),
(141801, 6117, 46, 'स्टॅन्डर्ड कोड'),
(141802, 6118, 46, 'मानक उपाय'),
(141803, 6119, 46, 'मानक उपाय (सक्रिय सूचना)'),
(141804, 6120, 46, 'मानक उपाय (निष्क्रीय सूचना)'),
(141805, 6121, 46, 'मानक उपाय (रुग्णांच्या स्मरणपत्रे)'),
(141806, 6122, 46, 'मानक नाव'),
(141807, 6123, 46, 'मानक; सरलीकृत: केवळ शीर्षक, तारीख, टिप्पण्या आणि सक्रीय चेकबॉक्स सुरू; नाही निदान, घटना, शेवटी तारीख, संदर्भित-किंवा खेळ फील्ड. ; फुटबॉल इजा'),
(141808, 6124, 46, 'प्रारंभ'),
(141809, 6125, 46, '(वर्ष-mm-dd या) सुरू करा: '),
(141810, 6126, 46, 'आणखी अहवाल प्रारंभ'),
(141811, 6128, 46, 'प्रारंभ तारीख'),
(141812, 6129, 46, 'या क्लिनिक येथे प्रारंभ तारीख'),
(141813, 6130, 46, 'प्रारंभ तारीख अंतिम तारखेपूर्वी पेक्षा जास्त असू नये'),
(141814, 6131, 46, 'प्रारंभ तारीख:'),
(141815, 6132, 46, 'प्रारंभ तारीख:'),
(141816, 6133, 46, 'प्रारंभ वेळ'),
(141817, 6134, 46, 'तारीख सुरू करत आहे'),
(141818, 6135, 46, 'stat'),
(141819, 6136, 46, 'राज्य'),
(141820, 6137, 46, 'स्टेट डेटा प्रकार'),
(141821, 6138, 46, 'राज्य एलआयसी. #'),
(141822, 6139, 46, 'राज्य परवाना क्रमांक'),
(141823, 6140, 46, 'राज्य यादी'),
(141824, 6141, 46, 'राज्य यादी (राइट, addonly पर्यायी)'),
(141825, 6142, 46, 'राज्य यादी विजेट सानुकूल फील्ड'),
(141826, 6143, 46, 'राज्य किंवा प्रांत'),
(141827, 6144, 46, 'राज्य / परिसर'),
(141828, 6145, 46, 'राज्य / परगणा'),
(141829, 6146, 46, 'निवेदन सारांश'),
(141830, 6147, 46, 'स्टेटमेन्ट आणि अद्यतनित पावत्या.'),
(141831, 6148, 46, 'स्टेटमेन्ट पाठवलेले:'),
(141832, 6149, 46, 'स्टेटमेन्ट; पावत्या अद्यतनित केला जाणार नाही.'),
(141833, 6150, 46, 'स्टॅटिक मजकूर'),
(141834, 6151, 46, 'सांख्यिकी'),
(141835, 6152, 46, 'आकडेवारी'),
(141836, 6153, 46, 'स्थिती'),
(141837, 6154, 46, 'प्रवेश स्थिती'),
(141838, 6155, 46, 'दावा स्थिती'),
(141839, 6156, 46, 'स्टेटस को'''),
(141840, 6158, 46, 'एसटीडी / एड्स Couns'),
(141841, 6159, 46, 'Stength आणि वातानुकूलन'),
(141842, 6163, 46, 'अपलोड CCR एक्स एम एल स्टेप्स'),
(141843, 6164, 46, 'डीएसएम चौथा डेटाबेस प्रतिष्ठापीत करण्यासाठी पायऱ्या'),
(141844, 6165, 46, 'ICD 10 डेटाबेस प्रतिष्ठापीत करण्यासाठी पायऱ्या'),
(141845, 6166, 46, 'ICD 9 डेटाबेस प्रतिष्ठापीत करण्यासाठी पायऱ्या'),
(141846, 6167, 46, 'RxNorm डेटाबेस प्रतिष्ठापीत करण्यासाठी पायऱ्या'),
(141847, 6168, 46, 'Snomed डेटाबेस प्रतिष्ठापीत करण्यासाठी पायऱ्या'),
(141848, 6169, 46, 'ताठ सांधे'),
(141849, 6170, 46, 'कडक होणे'),
(141850, 6171, 46, 'शेअर महिने'),
(141851, 6172, 46, 'पोटात सुधारणांमुळे'),
(141852, 6173, 46, 'थांबवा'),
(141853, 6174, 46, 'संचयित हॅश'),
(141854, 6175, 46, 'स्नायू ताण'),
(141855, 6176, 46, 'प्रवाह'),
(141856, 6177, 46, 'स्ट्रीट'),
(141857, 6178, 46, 'मार्ग पत्ता'),
(141858, 6179, 46, 'स्ट्रीट आणि क्रमांक'),
(141859, 6180, 46, 'शक्ती'),
(141860, 6181, 46, 'शक्ती आणि वातानुकूलन'),
(141861, 6182, 46, 'गळ्याचा आजार'),
(141862, 6183, 46, 'ताण फ्रॅक्चर'),
(141863, 6184, 46, 'ताण चाचणी'),
(141864, 6185, 46, 'स्ट्रोक'),
(141865, 6186, 46, 'अनेक, एक छोटे आकार पत्र, एक लोअरकेस पत्र, विशेष अक्षर: तीव्र पासवर्ड कमीत कमी 8 वर्ण, आणि किमान तीन अर्थ.'),
(141866, 6187, 46, 'शैली'),
(141867, 6188, 46, 'फॉर्म शैली नवीन रुग्ण समाविष्ट करण्यासाठी वापरले'),
(141868, 6189, 46, 'उप-श्रेणी'),
(141869, 6190, 46, 'उप-एकूण'),
(141870, 6191, 46, 'उपवर्ग'),
(141871, 6192, 46, 'उपवर्ग'),
(141872, 6193, 46, 'subcutaneously'),
(141873, 6194, 46, 'विषय'),
(141874, 6195, 46, 'काल्पनिक'),
(141875, 6196, 46, 'जिभेच्या खाली'),
(141876, 6197, 46, 'जिभेच्या खाली'),
(141877, 6198, 46, 'सबमिट'),
(141878, 6199, 46, 'सादर'),
(141879, 6200, 46, 'सर्व सामग्री सबमिट'),
(141880, 6201, 46, 'सबमिट करा आणि विनंती हटवा'),
(141881, 6202, 46, 'इव्हेंट सबमिट'),
(141882, 6203, 46, 'फॉर्म सादर करतेवेळी'),
(141883, 6204, 46, 'निवडलेले सामग्री सबमिट'),
(141884, 6205, 46, 'सादर'),
(141885, 6206, 46, 'सादर केलेल्या'),
(141886, 6207, 46, 'सबमिट EDI एक्सेस नंबर (PER06)'),
(141887, 6208, 46, 'ग्राहक'),
(141888, 6209, 46, 'ग्राहक पत्ता'),
(141889, 6210, 46, 'ग्राहक शहर'),
(141890, 6211, 46, 'ग्राहक देश'),
(141891, 6212, 46, 'जन्म ग्राहक दिनांक'),
(141892, 6213, 46, 'ग्राहक नियोक्ता'),
(141893, 6214, 46, 'ग्राहक नियोक्ता (SE) मध्ये'),
(141894, 6215, 46, 'ग्राहक नियोक्ता पत्ता'),
(141895, 6216, 46, 'ग्राहक नियोक्ता शहर'),
(141896, 6217, 46, 'ग्राहक नियोक्ता देश'),
(141897, 6218, 46, 'ग्राहक नियोक्ता राज्य'),
(141898, 6219, 46, 'ग्राहक नियोक्ता स्ट्रीट'),
(141899, 6220, 46, 'ग्राहक नियोक्ता पिन'),
(141900, 6221, 46, 'ग्राहक नियोक्ता पिन कोड'),
(141901, 6222, 46, 'ग्राहक नाव'),
(141902, 6223, 46, 'ग्राहक गेल्या नाव'),
(141903, 6224, 46, 'ग्राहक मध्य नाव'),
(141904, 6225, 46, 'ग्राहक फोन'),
(141905, 6226, 46, 'ग्राहक संबंध'),
(141906, 6227, 46, 'ग्राहक संबंध स्वत: ची नाही आहे पण नाव एकच आहे! हे खरोखर ठीक आहे का?'),
(141907, 6228, 46, 'ग्राहक संबंध स्वत: ची नाही पण एस संख्या समान आहे!'),
(141908, 6229, 46, 'ग्राहक संबंध स्वत: ची पण नाव भिन्न आहे! हे खरोखर ठीक आहे का?'),
(141909, 6230, 46, 'ग्राहक संबंध स्वत: ची आहे पण एस संख्या भिन्न आहे!'),
(141910, 6231, 46, 'ग्राहक लिंग'),
(141911, 6232, 46, 'ग्राहक एस'),
(141912, 6233, 46, 'ग्राहक राज्य'),
(141913, 6234, 46, 'ग्राहक पिन'),
(141914, 6235, 46, 'Subscribter फोन'),
(141915, 6237, 46, 'पर्याय'),
(141916, 6238, 46, 'पर्याय परवानगी'),
(141917, 6240, 46, 'यशस्वी'),
(141918, 6241, 46, 'यश'),
(141919, 6242, 46, 'लॅब निकाल यशस्वी खात्री पावती'),
(141920, 6243, 46, 'यश मिळवणे लॅब परिणाम'),
(141921, 6244, 46, 'लॅब एक्सचेंज नेटवर्कपासून यशस्वी प्राप्त करणे परिणाम'),
(141922, 6246, 46, 'यशस्वीरित्या जोडले श्रेणी'),
(141923, 6247, 46, 'यशस्वीरित्या श्रेणी जोडले'),
(141924, 6248, 46, 'यशस्वीपणे हटविले'),
(141925, 6249, 46, 'यशस्वीरित्या तपशील आयात केला. प्रलंबित मंजूरी स्क्रीन रुग्ण मंजूर करा'),
(141926, 6250, 46, 'यशस्वीरित्या डेटाबेस स्थापित.'),
(141927, 6251, 46, 'यशस्वीरित्या खालील डेटाबेस स्थापित'),
(141928, 6252, 46, 'यशस्वीरित्या सुधारित'),
(141929, 6253, 46, 'यशस्वीपणे वाटप करू Saved.Would?'),
(141930, 6254, 46, 'यशस्वीपणे वितरित करा, करू Saved.Would?'),
(141931, 6256, 46, 'यशस्वीरित्या संग्रहीत झाले.'),
(141932, 6257, 46, 'यशस्वीरित्या डेटाबेस सुधारीत.'),
(141933, 6258, 46, 'यशस्वीरित्या खालील डेटाबेस सुधारीत'),
(141934, 6259, 46, 'यशस्वीरित्या.'),
(141935, 6260, 46, 'आत्महत्या'),
(141936, 6261, 46, 'सारांश'),
(141937, 6262, 46, 'सारांश'),
(141938, 6265, 46, 'सन'),
(141939, 6266, 46, 'सुंदानीज'),
(141940, 6267, 46, 'रविवारी'),
(141941, 6268, 46, 'Superbill'),
(141942, 6269, 46, 'Superbill कोड'),
(141943, 6270, 46, 'Superbill कोड प्रशासन'),
(141944, 6271, 46, 'Superbill अहवाल'),
(141945, 6272, 46, 'Superbill / फी पत्रक'),
(141946, 6273, 46, 'Superbills'),
(141947, 6274, 46, 'कधी कधी आढळतात फॉर्म किंवा मार्गाचे डाव सावरला म्हणून संदर्भित Superbills, सर्वात वैद्यकीय पद्धती एक अत्यावश्यक भाग आहेत.'),
(141948, 6275, 46, 'Superuser'),
(141949, 6276, 46, 'देखरेख'),
(141950, 6278, 46, 'डॉक्टर DEA देखरेख'),
(141951, 6279, 46, 'देखरेख डॉक्टर नाव'),
(141952, 6280, 46, 'देखरेख डॉक्टर आडनाव'),
(141953, 6281, 46, 'डॉक्टर NPI देखरेख'),
(141954, 6282, 46, 'डॉक्टर UPIN देखरेख'),
(141955, 6283, 46, 'पुरवठादार सुविधा नाव'),
(141956, 6284, 46, 'अनेक प्रदाते लागू समर्थन कॅलेंडर कार्यक्रम'),
(141957, 6285, 46, 'बॅकअप पृष्ठाद्वारे संरचना डाटाचे समर्थन आयात / निर्यात.'),
(141958, 6286, 46, 'समर्थन मल्टी प्रदाता आगामी कार्यक्रम'),
(141959, 6288, 46, 'TripleDES एनक्रिप्शन / डिक्रिप्शन फक्त समर्थन पुरवतो.'),
(141960, 6289, 46, 'पृष्ठभाग प्रकार'),
(141961, 6290, 46, 'शस्त्रक्रिया'),
(141962, 6291, 46, 'शस्त्रक्रिया'),
(141963, 6292, 46, 'शस्त्रक्रिया समस्या सूची'),
(141964, 6293, 46, 'निलंबित'),
(141965, 6294, 46, 'निलंबन'),
(141966, 6295, 46, 'SVC तारीख'),
(141967, 6296, 46, 'SVC दिनांक:'),
(141968, 6297, 46, 'स्वाहिली'),
(141969, 6298, 46, 'स्वाती'),
(141970, 6299, 46, 'घाम येणे:'),
(141971, 6300, 46, 'स्वीडिश'),
(141972, 6301, 46, 'सूज'),
(141973, 6302, 46, 'उजव्या सूज'),
(141974, 6303, 46, 'सुजलेल्या सांधे'),
(141975, 6304, 46, 'सुजलेल्या लसीका नोडस्'),
(141976, 6305, 46, 'चलन दशांश चिन्ह म्हणून वापरले प्रतीक. दशांश स्थाने 0 आहे वापरले नाही.'),
(141977, 6306, 46, 'प्रतीक चलन हजारो विलग करण्यासाठी केला.'),
(141978, 6307, 46, 'लक्षणे'),
(141979, 6308, 46, 'समक्रमित करा'),
(141980, 6309, 46, 'सानुकूल भाषा टेबल अनुवाद समक्रमित करा.'),
(141981, 6310, 46, 'नवीन सानुकूल सतत समक्रमित:'),
(141982, 6311, 46, 'नवीन सानुकूल भाषा समक्रमित:'),
(141983, 6312, 46, 'नवीन व्याख्या समक्रमित (भाषा, सतत, व्याख्या):'),
(141984, 6313, 46, 'बेशुद्धावस्था'),
(141985, 6314, 46, 'सिंड्रोमिक पाळत ठेवणे'),
(141986, 6315, 46, 'सिंड्रोमिक पाळत ठेवणे - नॉन तक्रार केलेल्या समस्या'),
(141987, 6316, 46, 'सिंड्रोमिक पाळत ठेवणे अहवाल'),
(141988, 6317, 46, 'सीरमी पटलाचा दाह यामध्ये बहुधा सांध्यात द्रव जमतो, संधिदाह व दीर्घकाळ दाह झाल्याने ऍकिलोसिस होतो, अतिक्रमण, बर्साचा दाह'),
(141989, 6318, 46, 'प्रणाली'),
(141990, 6322, 46, 'टी'),
(141991, 6323, 46, 't.i.d.'),
(141992, 6324, 46, 'T.V.'),
(141993, 6325, 46, 'टेबल'),
(141994, 6327, 46, 'टेबल निर्माण होऊ शकली नाही'),
(141995, 6328, 46, 'टेबल अद्यतन अयशस्वी'),
(141996, 6329, 46, 'सपाट दगडी पाट्या'),
(141997, 6330, 46, 'टॅबलेट'),
(141998, 6331, 46, 'चकमकीत टॅग'),
(141999, 6332, 46, 'टागालॉग'),
(142000, 6333, 46, 'ताहितीयन'),
(142001, 6334, 46, 'ताजिक'),
(142002, 6335, 46, 'घ्या'),
(142003, 6336, 46, 'ड्रॉप डाऊन पासून, विमा घ्या'),
(142004, 6337, 46, 'ड्रॉप डाऊन पासून, त्यांच्या लायकीप्रमाणे'),
(142005, 6338, 46, 'परत घेणे'),
(142006, 6339, 46, 'वेळ लागतो'),
(142007, 6340, 46, 'उंच नेव्हिगेशन क्षेत्र'),
(142008, 6341, 46, 'तामिळ'),
(142009, 6342, 46, 'लुडबुड तारीख'),
(142010, 6343, 46, 'बदल चेकसम'),
(142011, 6344, 46, 'लक्ष्य आणि स्रोत डीओबी जुळत नाही'),
(142012, 6345, 46, 'लक्ष्य आणि स्रोत PID समान असू शकत नाहीत!'),
(142013, 6346, 46, 'लक्ष्य आणि स्रोत SSN जुळत नाही'),
(142014, 6347, 46, 'लक्ष्य तारीख'),
(142015, 6348, 46, 'लक्ष्य रुग्णांच्या'),
(142016, 6349, 46, 'लक्ष्य रुग्ण नाही डीओबी आहे'),
(142017, 6350, 46, 'लक्ष्य रुग्ण आढळले नाही'),
(142018, 6351, 46, 'लक्ष्य / हिंसक गट'),
(142019, 6352, 46, 'तातार'),
(142020, 6354, 46, 'कर आयडी'),
(142021, 6355, 46, 'कर दर'),
(142022, 6356, 46, 'कर'),
(142023, 6357, 46, 'वर्गीकरणाची तत्वे'),
(142024, 6358, 46, 'टीडी'),
(142025, 6359, 46, 'टीम इजा विहंगावलोकन'),
(142026, 6360, 46, 'टीम रोस्टर'),
(142027, 6361, 46, 'टीम रोस्टर पहा'),
(142028, 6362, 46, 'टीम / पथक'),
(142029, 6363, 46, 'तेल'),
(142030, 6364, 46, 'टेलिफोन देश कोड'),
(142031, 6365, 46, 'तेलगू'),
(142032, 6366, 46, 'ताप'),
(142033, 6367, 46, 'ताप स्थान'),
(142034, 6368, 46, 'ताप पद्धत'),
(142035, 6369, 46, 'तापमान'),
(142036, 6370, 46, 'साचा'),
(142037, 6371, 46, 'साचा नाव'),
(142038, 6372, 46, 'साचा नाव नंबर सुरू करू शकत नाही.'),
(142039, 6373, 46, 'साचा:'),
(142040, 6374, 46, 'टेम्पलेट'),
(142041, 6375, 46, 'ऐहिक आर्टरी'),
(142042, 6376, 46, 'कक्लेनिअस इजा'),
(142043, 6377, 46, 'Tendonitis / osis / बर्साचा दाह'),
(142044, 6378, 46, 'घुटमळणारा चलन संदर्भ नाही'),
(142045, 6379, 46, 'दर्जा'),
(142046, 6380, 46, 'तृतीय विमा'),
(142047, 6381, 46, 'तृतीय विमा डेटा'),
(142048, 6382, 46, 'तृतीय विमा प्रदाता'),
(142049, 6383, 46, 'कसोटी शेड्युलिंग'),
(142050, 6384, 46, 'कसोटी प्रणाली'),
(142051, 6385, 46, 'मजकूर'),
(142052, 6386, 46, 'मजकूर निदान'),
(142053, 6387, 46, 'मजकूर क्षेत्रात'),
(142054, 6393, 46, 'मजकूर-तारीख'),
(142055, 6394, 46, 'मजकूर-तारीख'),
(142056, 6395, 46, 'Textarea'),
(142057, 6396, 46, 'textarea'),
(142058, 6397, 46, 'मजकूरबॉक्स'),
(142059, 6398, 46, 'मजकूर बॉक्स'),
(142060, 6399, 46, 'मजकूरबॉक्स यादी'),
(142061, 6400, 46, 'बॉक्स यादी'),
(142062, 6401, 46, 'थाई'),
(142063, 6402, 46, 'धन्यवाद'),
(142064, 6403, 46, 'निवड केल्याबद्दल धन्यवाद'),
(142065, 6404, 46, 'साफ करा'' बटणावर क्लिक करा सर्व भाष्य काढेल.'),
(142066, 6405, 46, 'उपरोक्त विधान अयशस्वी'),
(142067, 6406, 46, 'अपॅची SSL सर्व्हर प्रमाणपत्र आणि सार्वजनिक की'),
(142068, 6407, 46, 'प्रमाणपत्र'),
(142069, 6408, 46, 'हक्क फाइल: '),
(142070, 6409, 46, 'सुसंगत आयोजित अमेरिकन विस्तार SNOMED संकुल आधिपासूनच प्रतिष्ठापीत केले गेले आहे.'),
(142071, 6410, 46, 'संबंधित खाजगी की'),
(142072, 6411, 46, 'माहिती एकाग्रता चाचणी हा फॉर्म अयशस्वी झाले'),
(142073, 6413, 46, 'नकार कोड आहे'),
(142074, 6414, 46, 'नकार गट कोड आहे'),
(142075, 6415, 46, 'गंतव्य फॉर्म बंद करण्यात आले'),
(142076, 6416, 46, 'गंतव्य फॉर्म बंद होते; मी तुमची निवड वर कार्य करू शकत नाही.'),
(142077, 6417, 46, 'ही प्रक्रिया करत अस्तित्व'),
(142078, 6418, 46, 'काळजी काळजी किंवा प्रदाता दुसर्या सेटिंग एक रुग्ण प्राप्त किंवा चकमकीत औषध समेट सुरू संबंधित आहे विश्वास ठेवतो मालिका, पात्र हॉस्पिटल किंवा CAH.'),
(142079, 6421, 46, 'काळजी काळजी किंवा प्रदाता दुसर्या सेटिंग त्यांच्या रुग्ण संक्रमणे किंवा काळजी किंवा संदर्भ प्रत्येक संक्रमण काळजी रेकॉर्ड सारांश देणे आवश्यक आहे काळजी दुसर्या प्रदाता त्यांच्या रुग्णाला जर संदर्भ कोण मालिका, पात्र हॉस्पिटल किंवा CAH.'),
(142080, 6422, 46, 'कार्यक्रम (चे) मंजूर झालेली आहेत.'),
(142081, 6423, 46, 'कार्यक्रम (चे) लपवली गेली आहे.'),
(142082, 6424, 46, 'निर्यात डेटा खालील मजकूर क्षेत्रात दिसून येत आहे. आपण कॉपी आणि एक ई-मेल किंवा इतर कोणत्याही इच्छित गंतव्य पेस्ट करू शकता.'),
(142083, 6426, 46, 'निर्यात डेटा खालील मजकूर क्षेत्रात दिसून येत आहे. आपण कॉपी आणि एक ई-मेल किंवा इतर कोणत्याही इच्छित गंतव्य पेस्ट करू शकता.'),
(142084, 6427, 46, 'निर्यात डेटा खालील मजकूर क्षेत्रात दिसून येत आहे. आपण कॉपी आणि एक ई-मेल किंवा इतर कोणत्याही इच्छित गंतव्य पेस्ट करू शकता. {{पुढील भाषांतर तयार दरम्यान हटवणे मार्क}}'),
(142085, 6428, 46, 'फाइल CouchDB जतन केले जाऊ शकत नाही.'),
(142086, 6429, 46, 'फाइल यशस्वी ही त्रुटी सहसा स्टोरेज प्रणाली वरील परवानग्या समस्या संबंधित आहे, असे नामकरण करण्यात जाऊ शकत नाही.'),
(142087, 6430, 46, 'फाइल यशस्वी संग्रहित केले जाऊ शकत नाही, ही त्रुटी सहसा स्टोरेज प्रणाली वरील परवानग्या समस्या संबंधित आहे'),
(142088, 6431, 46, 'पहिल्या ("लक्ष्य") चार्ट सर्वाधिक संपूर्ण आणि अचूक मानले जाते की एक आहे. लोकसंख्याशास्त्र, हे एक इतिहास आणि विमा विभाग राहतील.'),
(142089, 6433, 46, 'पहिले पाऊल युनिफाइड वैद्यकीय भाषा प्रणाली वेब साइट खाते उघडण्यासाठी आहे'),
(142090, 6434, 46, 'खालील कॅलेंडर कार्यक्रम जोडले गेले आहे:'),
(142091, 6435, 46, 'खालील कॅलेंडर कार्यक्रम modifed केले आहे:'),
(142092, 6436, 46, 'खालील आपल्या वर्गात यादी काढला जाईल'),
(142093, 6437, 46, 'खालील डेटाबेस प्रकाशन सध्या स्थापित केले आहे'),
(142094, 6438, 46, 'खालील कागदपत्रे या थेट संदेशात संलग्न होते:'),
(142095, 6439, 46, 'खालील EDI फाईल अपलोड झाली आहे'),
(142096, 6440, 46, 'खालील आणीबाणी लॉगिन वापरकर्ता सक्रिय आहे:'),
(142097, 6441, 46, 'खालील त्रुटी आली'),
(142098, 6442, 46, 'खालील क्षेत्र अवैध मूल्य आहे'),
(142099, 6444, 46, 'खालील फील्ड आवश्यक आहेत'),
(142100, 6446, 46, 'खालील फील्ड विनंती पाठविण्यासाठी भरले पाहिजेत.'),
(142101, 6447, 46, 'खालील आंतरराष्ट्रीय Snomed प्रकाशन भाषा समर्थित आहेत'),
(142102, 6448, 46, 'खालील समस्या त्याच निदान कोड आहे. चकमकीत समस्या अद्यतनित केला जाणार नाही. त्याऐवजी चकमकीत संवादचा वापर करा.'),
(142103, 6449, 46, 'ATNA ऑडिट रेपॉजिटरी मशीन यजमाननाव.'),
(142104, 6450, 46, 'प्रारंभिक विंडो अशी यादी तयार करणे शोध पृष्ठ आहे. शीर्षस्थानी आपण एक स्रोत (उदा तपासणी संख्या) मध्ये प्रवेश करू शकते, तारीख द्या आणि रक्कम तपासा. ''टी प्रत्येक दावा पुन्हा प्रती आणि त्यांना प्रविष्ट करणे आवश्यक आहे  आपण डॉन जेणेकरून स्रोत आणि वेतन तारीख कारण आहे. आपण प्रविष्ट की रक्कम आपण पूर्ण करता तेव्हा शून्य येथे समाप्त होईल, अशी आशा पैसे भाग दिले आहे आणि आहे की प्रत्येक अशी यादी तयार करणे साठी कमी करता येईल.'),
(142105, 6451, 46, 'स्थापना निर्देशिका तयार करणे आवश्यक आहे.'),
(142106, 6452, 46, 'स्थापित आंतरराष्ट्रीय SNOMED आवृत्ती आयोजित अमेरिकन विस्तार SNOMED पॅकेज सुसंगत नाही.'),
(142107, 6453, 46, 'स्थापित आंतरराष्ट्रीय SNOMED आवृत्ती कालबाह्य आहे आणि आयोजित अमेरिकन विस्तार SNOMED फाइल सुसंगत नाही.'),
(142108, 6454, 46, 'प्रतिष्ठापीत आवृत्ती आणि आयोजित फाईल्स समान आहेत.'),
(142109, 6455, 46, 'प्रतिष्ठापीत आवृत्ती आयोजित फाइल अधिक अलीकडील आवृत्ती आहे.'),
(142110, 6456, 46, 'फॉर्म वापरकर्ता दिसते की लेबल'),
(142111, 6457, 46, 'लांबी वर्ण खालील संख्या जास्त नसावी'),
(142112, 6458, 46, 'दोन चार्ट साठी SSN आणि डीओबी एकसारखे आहेत तोपर्यंत विलीन करणार नाही. DOBs रिक्त असू शकत नाही.'),
(142113, 6459, 46, 'संदेश यावेळी पाठवले जाऊ शकत नाही.'),
(142114, 6460, 46, 'नवीन श्रेणी एक उप-श्रेणी असेल '),
(142115, 6461, 46, 'नवीन पासवर्ड वर्तमान संकेतशब्द समान असू शकत नाही.'),
(142116, 6462, 46, 'नवीन पासवर्ड फील्ड समान नाहीत.'),
(142117, 6463, 46, 'आयोजित फाइल्स नंबर चूक आहे. केवळ आपण श्रेणीसुधारित / प्रतिष्ठापीत करण्यासाठी इच्छा आहे की फाइल ठेवा.'),
(142118, 6464, 46, 'आयोजित फाइल्स नंबर चूक आहे. केवळ आपण श्रेणीसुधारित / प्रतिष्ठापीत करण्यासाठी इच्छा आहे की फाइल ठेवा.'),
(142119, 6465, 46, 'पान लोकसंख्याशास्त्र पुनर्निर्देशित केले जाईल. आपण पुन्हा NewCrop देशातील क्षेत्र आणि रेट क्लिक संपादित करू शकता.'),
(142120, 6466, 46, 'पासवर्ड कमीत कमी आठ वर्ण, आणि पाहिजे करणे आवश्यक आहे'),
(142121, 6467, 46, 'आपण प्रविष्ट केलेला संकेतशब्द अवैध आहे'),
(142122, 6468, 46, 'रुग्ण रेकॉर्ड विनंती नोंद करण्यात आली आहे.'),
(142123, 6469, 46, 'रुग्ण स्मरणपत्रे पाठवली गेली आहेत'),
(142124, 6470, 46, 'रुग्ण स्मरणपत्रे अद्यतनित केले गेले आहेत'),
(142125, 6471, 46, 'रुग्ण हा फॉर्म सबमिट करताना लॉग इन झाले नाही'),
(142126, 6472, 46, 'या date.This खाली जाऊ शकत नाही पोस्ट पैसे खात्री मागील तारखा अंतिम अहवाल कोणीही पोस्ट घेतल्यानंतर.'),
(142127, 6473, 46, 'पोर्टल या रुग्ण आणि फॉर्म डेटा आहे. आता तो लोड?'),
(142128, 6474, 46, 'कच्चा डेटा फीड प्रकाशन पासून मिळू शकते'),
(142129, 6475, 46, 'उर्वरित माहिती खाली आपण स्वतः पोस्ट आहेत, किंवा आपण स्वहस्ते दुरुस्त्या करत आहात लागू होतो फक्त जर.'),
(142130, 6476, 46, 'विनंती केलेला दस्तऐवज फाइलप्रणालीवरील अपेक्षित स्थान उपस्थित नाही किंवा त्यात प्रवेश करण्यासाठी पुरेसे परवानगी नाहीत');
INSERT INTO `lang_definitions` VALUES
(142131, 6477, 46, 'विनंती केलेला दस्तऐवज फाइलप्रणालीवरील अपेक्षित स्थान उपस्थित नाही किंवा त्यात प्रवेश करण्यासाठी पुरेसे परवानगी नाहीत.'),
(142132, 6479, 46, 'दुसरा ("स्रोत") चार्ट त्याच्या लोकसंख्याशास्त्र, इतिहास आणि विमा विभाग टाकून आहे. त्याची इतर डेटा लक्ष्य चार्ट मध्ये विलीन केले जातील.'),
(142133, 6480, 46, 'स्त्रोत आणि तारिक स्तंभ म्हणून साधारणपणे आपण त्या स्पर्श करण्याची आवश्यकता नाही, पहिल्या पानावरील कॉपी केले आहेत. आपण समायोजित स्तंभ, किंवा दोन्ही, पे कॉलममध्ये समायोजन रक्कम भरणा रक्कम लावू शकता. आपण आपोआप त्या ओळीवर आयटम शुल्क उर्वरित बंद लिहितात की एक समायोजन मूल्य मोजणी करण्यासाठी उजवीकडे "प" क्लिक करू शकता.'),
(142134, 6481, 46, 'आयोजित फायली तारखा सर्व समान प्रकाशन पासून नाहीत सोडा.'),
(142135, 6482, 46, 'आयोजित फायली आवृत्ती त्याच प्रकाशन सर्व नाही.'),
(142136, 6483, 46, 'आयोजित अमेरिकन विस्तार SNOMED संकुल आंतरराष्ट्रीय SNOMED संकुल स्थापित करण्यात आले आहे नंतर होईपर्यंत स्थापित केले जाऊ शकत नाही.'),
(142137, 6484, 46, 'कॅलेंडर वेळ ग्रॅन्यूलॅरिटी आणि नियोजित भेट स्लॉट मिनीटे लहान मध्यांतर.'),
(142138, 6485, 46, 'सध्याच्या भाषा फॉर्म दिसेल भाषांतरीत लेबल'),
(142139, 6486, 46, 'सध्याच्या भाषा दिसून येईल की, अनुवादित शीर्षक'),
(142140, 6487, 46, 'चालू भाषेत वर्णन अनुवादासाठी'),
(142141, 6488, 46, 'अनुवाद सपाट दगडी पाट्या समक्रमित केले जातात.'),
(142142, 6489, 46, 'या घटकाच्या प्रकार'),
(142143, 6490, 46, 'ही प्रक्रिया किंवा परिणाम ओळख विक्रेता-निर्देशीत कोड'),
(142144, 6491, 46, 'X12 फाइल तसेच परिणामी एचटीएमएल उत्पादन अहवाल मुख्य LibreEHR स्थापना निर्देशिका च्या "युग" उपनिर्देशिकेत संग्रहीत केले जाते. आपण वेळोवेळी या संग्रह पहा इच्छित असेल. URL आहे'),
(142145, 6492, 46, 'Zip फाइल खालील आयटम समाविष्ट असेल'),
(142146, 6493, 46, 'थीम'),
(142147, 6494, 46, 'मग कच्चा डेटा फीड प्रकाशन पासून मिळू शकते'),
(142148, 6495, 46, 'उपचारात्मक इंजेक्शन'),
(142149, 6496, 46, 'आहेत'),
(142150, 6497, 46, 'नाही चांगले सध्या आहेत'),
(142151, 6498, 46, 'आपल्या सबमिशन त्रुटी आहेत. हे खाली वर्णन केलेल्या आहेत.'),
(142152, 6499, 46, 'पोर्टल लॉगिन सह अनेक रुग्णांना आहेत'),
(142153, 6500, 46, 'बाहेर तपासले नाही चार्ट आहेत.'),
(142154, 6501, 46, 'या रुग्णाला रेकॉर्ड नाही माहिती आहेत.'),
(142155, 6502, 46, 'कोणतीही नवीन सबमिशन आहेत'),
(142156, 6503, 46, 'या रुग्णाला फाइल नाही नोट्स आहेत.'),
(142157, 6504, 46, 'या रुग्णाला फाइल नाही व्यवहार आहेत.'),
(142158, 6505, 46, 'पाठवून एक मेल त्रुटी झाली आहे'),
(142159, 6506, 46, 'नावाचा एक वर्गात आधीच आहे'),
(142160, 6507, 46, 'नावाचा एक फक्त खालील उपवर्ग तेथे आधीच आहे'),
(142161, 6508, 46, 'नावाच्या एका आयटम आधीपासून आहे'),
(142162, 6509, 46, 'खुले रुग्ण रेकॉर्ड विनंती आधीपासूनच आहे.'),
(142163, 6510, 46, 'ए खाते नाही COA नोंद आहे '),
(142164, 6511, 46, 'रोख खाते नाही COA नोंद आहे '),
(142165, 6512, 46, 'उत्पन्न खाते नाही COA नोंद आहे '),
(142166, 6513, 46, 'सध्याचे कोणतेही रुग्ण आहे'),
(142167, 6514, 46, 'या विषयावर कोणतेही स्थानिक सामग्री आहे.'),
(142168, 6515, 46, 'अशी यादी तयार करणे आयडी नाही जुळणी आहे'),
(142169, 6516, 46, 'अशी यादी तयार करणे आयडी नाही सामना = आहे '),
(142170, 6517, 46, 'सेवा आयडी नाही भाग नोंद आहे '),
(142171, 6518, 46, 'पोर्टल लॉगिन नाही रुग्ण आहे'),
(142172, 6519, 46, 'संदेश पाठविताना एक समस्या आली.'),
(142173, 6520, 46, 'आपल्या विनंतीवर प्रक्रिया करताना एक त्रुटी आली.'),
(142174, 6521, 46, 'खालील स्ट्रिंग एक LibreEHR एस क्यू एल अंतर्मुख त्रुटी आली होती'),
(142175, 6522, 46, 'हे 2012 दुवे आहेत'),
(142176, 6523, 46, 'उजव्या thickened:'),
(142177, 6524, 46, 'मांडीवर'),
(142178, 6525, 46, 'मांडीवर + गुडघ्याच्या मागच्या दोन स्नायूंना जोडणारा दोरीसारखा दिसणारा स्नायू'),
(142179, 6526, 46, 'कार्यालय मागे गोष्टी फक्त वाचू शकता'),
(142180, 6527, 46, 'कार्यालय परत गोष्टी वाचा प्रविष्ट पण नाही संपादीत करू शकता'),
(142181, 6528, 46, 'कार्यालय परत गोष्टी वाचा आणि सुधारित करू शकतो'),
(142182, 6529, 46, 'कार्यालय परत गोष्टी वाचा आणि अंशतः संपादीत करू शकता'),
(142183, 6530, 46, 'चिकित्सक फक्त वाचू शकता गोष्टी'),
(142184, 6531, 46, 'चिकित्सक वाचा आणि प्रविष्ट पण नाही संपादीत करू शकता गोष्टी'),
(142185, 6532, 46, 'चिकित्सक वाचा आणि सुधारित करू शकतो गोष्टी'),
(142186, 6533, 46, 'चिकित्सक वाचा आणि अंशतः संपादीत करू शकता गोष्टी'),
(142187, 6534, 46, 'एकही कार्यालय फक्त वाचू शकतात गोष्टी'),
(142188, 6535, 46, 'एकही कार्यालय वाचा आणि प्रविष्ट पण नाही संपादीत करू शकता गोष्टी'),
(142189, 6536, 46, 'एकही कार्यालय वाचा आणि सुधारित करू शकतो गोष्टी'),
(142190, 6537, 46, 'एकही कार्यालय वाचा आणि अंशतः संपादीत करू शकता गोष्टी'),
(142191, 6538, 46, 'डॉक्टरांची फक्त वाचू शकता गोष्टी'),
(142192, 6539, 46, 'डॉक्टरांची वाचा आणि प्रविष्ट पण नाही संपादीत करू शकता गोष्टी'),
(142193, 6540, 46, 'डॉक्टरांची वाचा आणि सुधारित करू शकतो गोष्टी'),
(142194, 6541, 46, 'डॉक्टरांची वाचा आणि अंशतः संपादीत करू शकता गोष्टी'),
(142195, 6542, 46, 'तिसरा'),
(142196, 6544, 46, 'ही क्रिया पूर्ववत केली जाऊ शकत नाही.'),
(142197, 6545, 46, 'ही क्रिया पूर्ववत केली जाऊ शकत नाही.'),
(142198, 6547, 46, 'ही क्रिया लॉग इन केले जाईल'),
(142199, 6549, 46, 'या नियोजित भेट स्लॉट आधीच तरीही हे वापरू वापरले जाते?'),
(142200, 6550, 46, 'या नियोजित भेट स्लॉट उपलब्ध नाही, कृपया दुसरे निवडा.'),
(142201, 6551, 46, 'हे कॅलेंडर वर्ष'),
(142202, 6552, 46, 'हा हक्क रद्द करण्यात आली आहे.'),
(142203, 6553, 46, 'हा हक्क बंद केले गेले आहे.'),
(142204, 6554, 46, 'हा हक्क denied.Reason आहे: -'),
(142205, 6555, 46, 'हा हक्क पुढील स्तरावर पाठविली जाणार आहे.'),
(142206, 6556, 46, 'हा कोड प्रकार संबंध स्वीकारत नाही.'),
(142207, 6557, 46, 'या संदर्भात हटविले जाईल श्रेणी, समाविष्टीत आहे. आपण अद्याप सुरू ठेवू इच्छिता?'),
(142208, 6558, 46, 'या भेटी कॅलेंडरवर प्रदर्शित कसे ठरवते.'),
(142209, 6559, 46, 'या नियुक्ती वापरली रंग स्कीमा द्वारे निश्चित केले जाते'),
(142210, 6561, 46, 'या घटनेचा'),
(142211, 6562, 46, 'या घटनेचा बिल आले आहे. आपण तो बदलू गरज असेल तर, तो पुन्हा उघडले करणे आवश्यक आहे.'),
(142212, 6563, 46, 'या घटनेचा लॉक केलेले आहे. कोणत्याही नवीन फॉर्म जोडले जाऊ शकते.'),
(142213, 6564, 46, 'हे वैशिष्ट्य अद्याप उपलब्ध नाही'),
(142214, 6565, 46, 'हा पर्याय अतिशय प्रायोगिक आणि नाही पूर्णपणे चाचणी केली आहे. आपल्या स्वत: च्या जोखमीवर वापरा!'),
(142215, 6566, 46, 'या चलन संख्या बदलण्यात आला आहे '),
(142216, 6569, 46, 'या मुख्य चार्ट विलीन आणि नंतर हटविली जाऊ आहे की चार्ट आहे.'),
(142217, 6571, 46, 'या विलीन डेटा प्राप्त आहे की मुख्य चार्ट आहे.'),
(142218, 6572, 46, 'हे स्थान'),
(142219, 6573, 46, 'हा संदेश मजकूर आपोआप जतन केला नाही. कॉपी सामग्री ते योग्य जतन आणि.'),
(142220, 6574, 46, 'हे विभाग द्वारे वापरले जात आहे '),
(142221, 6575, 46, 'या विभागाचा चाचणी मोड मध्ये आहे. डेटाबेस बदलले जाणार नाही.'),
(142222, 6576, 46, 'या विभागाचा EOB डेटा कार्यक्षम प्रवेश प्रोत्साहन देते.'),
(142223, 6577, 46, 'तारीख करण्यासाठी हा महिना'),
(142224, 6578, 46, 'ही ऑर्डर आधीच प्रसारित होते'),
(142225, 6579, 46, 'हे पृष्ठ आपल्याला आपण स्थापित आणि सुधारणा करू शकता, असे समर्थीत बाह्य dataloads प्रत्येक पुनरावलोकन करण्यास परवानगी देते. खाली प्रत्येक विभाग व्याज विशिष्ट डेटाबेस स्थिती पुनरावलोकन विभाग शिर्षक वर क्लिक करून विस्तृत जाऊ शकते.'),
(142226, 6580, 46, 'सुरक्षा कारणांसाठी निष्क्रिय हे पान.'),
(142227, 6581, 46, 'आम्ही प्रत्येक वेळी कृपया पुन्हा लॉगिन क्लिक करा करण्याची गरज नाही, त्यामुळे इनलाइन होईल हे पान, लॉगीन पेज यांचा समावेश आहे.'),
(142228, 6582, 46, 'या रुग्ण नाही क्रियाकलाप आहे.'),
(142229, 6583, 46, 'या रुग्ण आयडी आधीच वापरात आहे!'),
(142230, 6584, 46, 'हे उत्पादन कोठार केवळ एकच भरपूर परवानगी देतो.'),
(142231, 6585, 46, 'हा प्रोटोकॉल लागू केले नाही'),
(142232, 6586, 46, 'हा अहवाल सध्या केवळ ICD9 कोड काम.'),
(142233, 6589, 46, 'या बॉक्समध्ये 31 तारीख समाविष्ट करण्यासाठी नाही हे निश्चित करते.'),
(142234, 6590, 46, 'या बिलिंग विभाग निर्माण पाहिजे फॉर्म कोणत्या पुनरावृत्ती निर्देशीत करते'),
(142235, 6591, 46, 'ही पद्धत आपण पुढील वापरासाठी जतन करण्यासाठी जी फाइल निर्माण होईल. फाइल पुन्हा निर्माण होऊ शकत नाही. आपण पुढे जाऊ इच्छिता का?'),
(142236, 6592, 46, 'या वापरकर्ता कोणत्याही गटाचे सदस्य नाही'),
(142237, 6593, 46, 'या वापरकर्ता नवीन येणारे थेट संदेश सूचना प्राप्त होईल'),
(142238, 6594, 46, 'या उपयुक्तता प्रायोगिक अवस्थेत आहे. ती वापरत करण्यापूर्वी आपल्या डेटाबेस आणि दस्तऐवज बॅकअप!'),
(142239, 6595, 46, 'या भेट नवीन गर्भनिरोधक वापर सुरु'),
(142240, 6596, 46, 'या भेट GCAC फॉर्म, रेफरल किंवा प्रक्रिया सेवा आवश्यक आहे.'),
(142241, 6597, 46, 'हे आता नापसंत जुन्या मेट्रिक फक्त-मर्मस्थाने फॉर्म होता.'),
(142242, 6598, 46, 'तारीख या आठवड्यात'),
(142243, 6600, 46, 'या CCR (संगोपन अिभलेख सातत्य) आणि सीसीडीची (संगोपन डॉक्युमेंट सातत्य) अहवाल सक्रिय करणार नाही.'),
(142244, 6602, 46, 'या डिबगिंग ( ''बनावट '') भाषा निवड अनुमती देईल.'),
(142245, 6605, 46, 'हे शारीरिक डेटा अपडेट एक "कोरडे एकही रन नाही" असेल.'),
(142246, 6606, 46, 'या डांबर स्वरूपात बॅकअप तयार आणि नंतर आपण सुरक्षित करू शकता त्यामुळे आपल्या वेब ब्राउझर पाठविले जाईल'),
(142247, 6607, 46, 'या एनक्रिप्शन व डिक्रिप्शन वैशिष्ट्ये दस्तऐवज निष्क्रिय, आणि UI त्यांना मदत करणार नाही.'),
(142248, 6608, 46, 'या ज्या मुलांना पालक चकमकीत सर्व प्रकारच्या संपादन बटणावर अक्षम ई-स्वाक्षरी केलेले आहे'),
(142249, 6609, 46, 'या ई-स्वाक्षरी केलेले आहे की, कोणत्याही स्वरूपात संपादन बटणावर अक्षम करेल'),
(142250, 6611, 46, 'ही व्यक्ती फॉर्म ऐवजी, एक संपूर्ण चकमकीत साइन इन सक्षम होईल'),
(142251, 6612, 46, 'या स्वतंत्रपणे वैयक्तिक फॉर्म साइन इन सक्षम होईल'),
(142252, 6613, 46, 'हे नेहमी खुली असल्याचे रुग्णांच्या सारांश स्क्रीन मध्ये बिलिंग विजेट सक्ती करेल.'),
(142253, 6614, 46, 'या लॉक वापरकर्ता (स्वतंत्र लॉकिंग आणि साइन इन) पर्याय देईल'),
(142254, 6615, 46, 'हा रुग्ण अहवाल रिक्त ई-चिन्ह नोंदी लपवेल'),
(142255, 6616, 46, 'हा एक दोन रुग्ण चार्ट विलीन होईल. एक रुग्ण चुकून डुप्लीकेट केले आहे तेव्हा तो उपयुक्त आहे. अनेकदा घडते, तर आपल्या कार्यालयात प्रक्रीया निराकरण - नियमितपणे या चालवू नका!'),
(142256, 6617, 46, 'हा ई-चांगले साइट होणार प्रतिबंधित करणार नाही.'),
(142257, 6619, 46, 'या मानक CVX लसीकरण यादी ऐवजी सानुकूल लसीकरण यादी वापरेल.'),
(142258, 6622, 46, 'वक्षस्थळाविषयी मणक्याचे'),
(142259, 6623, 46, 'Thous / CU.MM'),
(142260, 6625, 46, 'घसा'),
(142261, 6626, 46, 'घसा कर्करोग'),
(142262, 6627, 46, 'घसा कर्करोग शस्त्रक्रिया'),
(142263, 6628, 46, 'रक्त गोठणे / स्ट्रोक'),
(142264, 6629, 46, 'गुरु'),
(142265, 6630, 46, 'Thurdsay'),
(142266, 6631, 46, 'गुरुवारी'),
(142267, 6632, 46, 'सामान्य थायरॉईड'),
(142268, 6633, 46, 'थायरॉईड समस्या'),
(142269, 6634, 46, 'TIA'),
(142270, 6635, 46, 'तिबेटी मानक, तिबेटी, केंद्रीय'),
(142271, 6636, 46, 'Tid'),
(142272, 6637, 46, 'टिग्रिन्या'),
(142273, 6638, 46, 'वेळ'),
(142274, 6639, 46, 'वेळ प्रदर्शन स्वरूप'),
(142275, 6640, 46, 'जोडा (मिनिटे 1-60) वेळ बढती'),
(142276, 6641, 46, 'वेळ निवड'),
(142277, 6642, 46, 'वेळ स्लॉट खुले आहे, बचत कार्यक्रम'),
(142278, 6643, 46, 'वेळ-टू-थेट सेकंदात अॅलर्जी SOAP विनंती'),
(142279, 6644, 46, 'वेळ-टू-थेट सेकंदात औषधे SOAP विनंती'),
(142280, 6647, 46, 'समयोचित कार्यक्रम'),
(142281, 6648, 46, 'टाइम्स अरे (एन / अ)'),
(142282, 6649, 46, 'शिक्का आणि मजकूर'),
(142283, 6650, 46, 'टीआयएन'),
(142284, 6651, 46, 'कानांतील गुणगुण किंवा तत्सम होणारा आवाज'),
(142285, 6652, 46, 'शीर्षक'),
(142286, 6653, 46, 'शीर्षक व्ही'),
(142287, 6654, 46, 'TitleCols 1 आणि 999 दरम्यान एक संख्या असणे आवश्यक आहे'),
(142288, 6655, 46, 'शोध शिर्षके फाईल नाव'),
(142289, 6656, 46, 'तिलकरत्ने  ''एस:'),
(142290, 6657, 46, 'TMS / EAMs / कायर्कारी अिभयंता, EXT नाक'),
(142291, 6658, 46, 'करण्यासाठी'),
(142292, 6659, 46, 'ते'),
(142293, 6660, 46, 'ते'),
(142294, 6661, 46, 'फाइल परिपूर्ण मार्ग'),
(142295, 6662, 46, 'नोट्स जोडण्यासाठी, क्लिक करा '),
(142296, 6663, 46, 'टीपा जोडण्यासाठी इथे क्लिक करा'),
(142297, 6664, 46, 'प्रभावित क्षेत्र'),
(142298, 6665, 46, 'प्रभावित क्षेत्र'),
(142299, 6666, 46, 'आपोआप विशिष्ट नमुना उघडण्यासाठी. काही क्रीडा संघ येथे football_injury_audit वापरा.'),
(142300, 6667, 46, 'बिलिंग पहा'),
(142301, 6668, 46, 'वर्गात'),
(142302, 6669, 46, 'क्लिनिकल पहा'),
(142303, 6670, 46, 'Copay करण्यासाठी'),
(142304, 6671, 46, 'तारीख करण्यासाठी तारखेपासून पेक्षा नंतर असणे आवश्यक आहे!'),
(142305, 6672, 46, 'Ded''ble करण्यासाठी'),
(142306, 6673, 46, 'Dems करण्यासाठी'),
(142307, 6674, 46, ', क्लाएंट साइड SSL प्रमाणपत्र अक्षम करण्यासाठी अपॅची संरचना फाइल आणि संच ओळी वरील टिप्पणी'),
(142308, 6675, 46, 'HTTPS वरील अक्षम करण्यासाठी, अपॅची संरचना फाइल वरील ओळी टिप्पणी आणि Apache सर्व्हर पुन्हा सुरू करा.'),
(142309, 6676, 46, 'क्लायंट बाजूला SSL प्रमाणपत्र सक्षम करण्यासाठी'),
(142310, 6677, 46, 'क्लायंट बाजूला SSL प्रमाणपत्र प्रमाणीकरण सक्षम करा करायचे असल्यास, https केले आहे.'),
(142311, 6678, 46, 'फक्त HTTPS वरील सक्षम करण्यासाठी, वरील बदल सुरू आणि Apache सर्व्हर पुन्हा सुरू करा. आपण देखील क्लाएंट साइड प्रमाणपत्र संयोजीत करू इच्छित असल्यास, पुढील विभागात कॉन्फिगर करा.'),
(142312, 6679, 46, 'Enctr करण्यासाठी'),
(142313, 6680, 46, 'लिंग फिल्टर'),
(142314, 6681, 46, 'इतिहास'),
(142315, 6682, 46, 'मुद्दे'),
(142316, 6683, 46, 'या घटनेचा दुवा / सध्याच्या समस्या सल्ला क्लिक करा '),
(142317, 6684, 46, '/ या घटनेचा निर्देशित पानाशी जोडले आहेत अस्तित्वातील समस्या सल्ला, तो प्रकाशित करा आणि मग [जतन] क्लिक करा वरील इच्छित समस्या क्लिक करा. अनेक समस्या निवडण्यासाठी [की Ctrl] बटण दाबून ठेवा.'),
(142318, 6685, 46, 'पुन्हा लॉगिन करण्यासाठी'),
(142319, 6686, 46, 'माहिती रेकॉर्ड करण्यासाठी, क्लिक करा'),
(142320, 6687, 46, 'चालविण्यासाठी'),
(142321, 6688, 46, 'सेटअप HTTPS क्लायंट प्रमाणपत्र प्रमाणीकरण असलेल्या प्रवेश करण्यासाठी, पुढील गोष्टी'),
(142322, 6689, 46, 'त्वचा करण्यासाठी'),
(142323, 6690, 46, 'त्वचा'),
(142324, 6691, 46, 'या भेट?'),
(142325, 6692, 46, 'CCR आधीच रुग्ण रुग्णांच्या सारांश Screen-> कागदपत्रे वापर विद्यमान दस्तऐवज अपलोड करा. नवीन रुग्ण वापर CCR दस्तऐवज Miscellanous-> नवीन दस्तऐवज स्क्रीन'),
(142326, 6693, 46, 'करण्यासाठी:'),
(142327, 6694, 46, 'करण्यासाठी: '),
(142328, 6695, 46, 'TO_CITY'),
(142329, 6696, 46, 'TO_FAX'),
(142330, 6697, 46, 'TO_FNAME'),
(142331, 6698, 46, 'TO_LNAME'),
(142332, 6699, 46, 'TO_MNAME'),
(142333, 6700, 46, 'TO_ORGANIZATION'),
(142334, 6701, 46, 'TO_PHONE'),
(142335, 6702, 46, 'TO_PHONECELL'),
(142336, 6703, 46, 'TO_POSTAL'),
(142337, 6704, 46, 'TO_STATE'),
(142338, 6705, 46, 'TO_STREET'),
(142339, 6706, 46, 'TO_TITLE'),
(142340, 6707, 46, 'TO_VALEDICTORY'),
(142341, 6708, 46, 'तंबाखू'),
(142342, 6709, 46, 'तंबाखू समाप्ती हस्तक्षेप'),
(142343, 6710, 46, 'तंबाखू समाप्ती हस्तक्षेप (CQM)'),
(142344, 6711, 46, 'तंबाखूचा वापर'),
(142345, 6712, 46, 'तंबाखूचा वापर'),
(142346, 6713, 46, 'तंबाखूचा वापर मूल्यांकन'),
(142347, 6714, 46, 'तंबाखूचा वापर मूल्यांकन (CQM)'),
(142348, 6715, 46, 'आज'),
(142349, 6716, 46, 'आज'),
(142350, 6717, 46, 'आज'),
(142351, 6718, 46, 'आज  ''चे शिल्लक'),
(142352, 6719, 46, 'आज  ''चे शुल्क'),
(142353, 6720, 46, 'आज  ''चे दिनांक'),
(142354, 6721, 46, 'आज  ''चे आगामी कार्यक्रम'),
(142355, 6722, 46, 'टॉगल सर्व'),
(142356, 6723, 46, 'वैद्यकीय माहिती एकत्रीकरण, एलएलसी लॅब एक्सचेंज सेवा टोकन आयडी.'),
(142357, 6724, 46, 'LibreEHR समर्थन, LLC लॅब एक्सचेंज सेवा टोकन आयडी.'),
(142358, 6725, 46, 'टोंगा (टोंगा बेटे)'),
(142359, 6726, 46, 'एक किंवा दोन्ही गलग्रंथी काढून टाकणे'),
(142360, 6727, 46, 'एक किंवा दोन्ही गलग्रंथी काढून टाकणे'),
(142361, 6728, 46, 'शीर्ष'),
(142362, 6729, 46, 'शीर्ष समास (मिमी)'),
(142363, 6730, 46, 'विषय'),
(142364, 6731, 46, 'एकूण'),
(142365, 6732, 46, 'एकूण'),
(142366, 6733, 46, 'एकूण सक्रिय क्रिया'),
(142367, 6734, 46, 'सुधारणा नंतर एकूण सक्रिय स्मरणपत्रे'),
(142368, 6735, 46, 'सुधारणा करण्यापूर्वी एकूण सक्रिय स्मरणपत्रे'),
(142369, 6737, 46, 'मुळे एकूण रक्कम'),
(142370, 6738, 46, 'एकूण किती रक्कम'),
(142371, 6739, 46, 'एकूण शिल्लक मुळे'),
(142372, 6740, 46, 'एकूण शुल्क'),
(142373, 6741, 46, 'एकूण शुल्क'),
(142374, 6742, 46, 'एकूण ग्राहक'),
(142375, 6743, 46, 'एकूण खर्च'),
(142376, 6744, 46, 'चेक संख्या खालील एकूण वितरण पूर्ण नाही आहे'),
(142377, 6745, 46, 'एकूण नोंदी'),
(142378, 6746, 46, 'ई-मेल द्वारे पाठवले एकूण अयशस्वी स्मरणपत्रे'),
(142379, 6747, 46, 'फोन द्वारे पाठवले एकूण अयशस्वी स्मरणपत्रे'),
(142380, 6748, 46, 'एकूण'),
(142381, 6749, 46, 'एकूण '),
(142382, 6750, 46, 'श्रेणी एकूण'),
(142383, 6751, 46, 'एकूण डोस स्मरणपत्रे'),
(142384, 6752, 46, 'एकूण नवीन स्मरणपत्रे'),
(142385, 6753, 46, 'भेटी एकूण संख्या'),
(142386, 6755, 46, 'लसीकरण एकूण संख्या'),
(142387, 6756, 46, 'मुद्दे एकूण संख्या'),
(142388, 6758, 46, 'रुग्णांना एकूण संख्या'),
(142389, 6760, 46, 'एकूण रुग्णांच्या शिल्लक'),
(142390, 6761, 46, 'एकूण रुग्णांना'),
(142391, 6764, 46, 'एकूण रेकॉर्ड सापडले'),
(142392, 6765, 46, 'एकूण SRH आणि कुटुंब नियोजन'),
(142393, 6766, 46, 'ई-मेल द्वारे पाठवले एकूण यशस्वी स्मरणपत्रे'),
(142394, 6767, 46, 'फोन द्वारे पाठवले एकूण यशस्वी स्मरणपत्रे'),
(142395, 6770, 46, 'एकूण जसाच्या तसा स्मरणपत्रे'),
(142396, 6771, 46, 'प्रक्रिया पाठवून नंतर एकूण न पाठविलेले स्मरणपत्रे'),
(142397, 6772, 46, 'सुधारणा नंतर एकूण न पाठविलेले स्मरणपत्रे'),
(142398, 6773, 46, 'पाठवून प्रक्रिया करण्यापूर्वी एकूण न पाठविलेले स्मरणपत्रे'),
(142399, 6774, 46, 'सुधारणा करण्यापूर्वी एकूण न पाठविलेले स्मरणपत्रे'),
(142400, 6775, 46, 'एकूण अद्यतनित केले स्मरणपत्रे'),
(142401, 6776, 46, 'बेरीज'),
(142402, 6777, 46, 'साठी बेरीज'),
(142403, 6778, 46, 'साठी बेरीज '),
(142404, 6780, 46, 'ते {{}} श्रेणी'),
(142405, 6782, 46, 'ट्रॅक'),
(142406, 6783, 46, 'ट्रॅक अहवाल'),
(142407, 6784, 46, 'ट्रॅक'),
(142408, 6785, 46, 'प्रशिक्षण प्रकार'),
(142409, 6786, 46, 'व्यवहार'),
(142410, 6787, 46, 'व्यवहार'),
(142411, 6788, 46, 'व्यवहार'),
(142412, 6789, 46, 'गंतव्य खूप व्यवहार अयशस्वी, अपुरा प्रमाणात'),
(142413, 6790, 46, 'व्यवहार अयशस्वी, प्रमाणात पेक्षा कमी शून्य आहे'),
(142414, 6791, 46, 'व्यवहार प्रकार'),
(142415, 6792, 46, 'व्यवहार'),
(142416, 6793, 46, 'व्यवहार'),
(142417, 6794, 46, 'व्यवहार (पर्यायी लिहा)'),
(142418, 6795, 46, 'व्यवहार / संदर्भ'),
(142419, 6797, 46, 'ट्रान्सफर'),
(142420, 6798, 46, 'ट्रान्सफर तारीख'),
(142421, 6799, 46, 'स्रोत खूप अयशस्वी, अपुरा प्रमाणात हस्तांतरण'),
(142422, 6800, 46, 'ट्रान्सफर सारांश'),
(142423, 6801, 46, 'हस्तांतरण'),
(142424, 6804, 46, 'हस्तांतरणासाठी'),
(142425, 6806, 46, 'काळजी संक्रमण / हस्तांतरण?'),
(142426, 6807, 46, 'एक्सेस कंट्रोल गट अनुवाद'),
(142427, 6808, 46, 'नियुक्ती श्रेणी भाषांतर'),
(142428, 6809, 46, 'दस्तऐवज श्रेणी भाषांतर'),
(142429, 6810, 46, 'लेआउट अनुवाद'),
(142430, 6811, 46, 'याद्या भाषांतर'),
(142431, 6812, 46, 'रुग्णांच्या टीप शोध शिर्षके फाईल नाव अनुवाद'),
(142432, 6813, 46, 'या अनुवाद'),
(142433, 6814, 46, 'भाषांतर'),
(142434, 6815, 46, 'अनुवाद'),
(142435, 6816, 46, 'प्रक्षेपित'),
(142436, 6817, 46, 'प्रसारित अयशस्वी'),
(142437, 6818, 46, 'निवडलेले ऑर्डर प्रक्षेपित'),
(142438, 6819, 46, 'शरीराला झालेली जखम'),
(142439, 6820, 46, 'उपचार'),
(142440, 6822, 46, 'उपचार गोल'),
(142441, 6823, 46, 'उपचार योजना'),
(142442, 6824, 46, 'उपचार नियोजन'),
(142443, 6825, 46, 'उपचार प्राप्त'),
(142444, 6826, 46, 'उपचार:'),
(142445, 6827, 46, 'उपचार: '),
(142446, 6828, 46, 'कल'),
(142447, 6829, 46, 'trftime ($ month_format, mktime (0, 0, 0, $ मी, 1, 2000))); $ month_value'),
(142448, 6830, 46, 'कारक बिंदू / निराळा सिंड्रोम / Doms / आडकाठी करणे'),
(142449, 6831, 46, 'Trimalleolar'),
(142450, 6832, 46, 'ट्रंक आणि उदर'),
(142451, 6833, 46, 'विश्वसनीय थेट ई-मेल पत्ता'),
(142452, 6834, 46, 'विश्वसनीय ईमेल'),
(142453, 6835, 46, 'विद्यमान वापरकर्तानाव वापरकर्ता तयार करण्याचा प्रयत्न करत आहे!'),
(142454, 6836, 46, 'सोंगा'),
(142455, 6837, 46, 'टीस्पून'),
(142456, 6838, 46, 'त्स्वाना'),
(142457, 6839, 46, 'TTS'),
(142458, 6840, 46, 'क्षयरोग'),
(142459, 6841, 46, 'मंगळ'),
(142460, 6842, 46, 'मंगळ केलेले & amp; Thur'),
(142461, 6843, 46, 'मंगळवारी'),
(142462, 6844, 46, 'Tumour'),
(142463, 6845, 46, 'तुर्की'),
(142464, 6846, 46, 'तुर्की'),
(142465, 6847, 46, 'ट्वी'),
(142466, 6848, 46, 'दररोज दोनदा'),
(142467, 6850, 46, 'मध्यकर्णाविषयी पडदा'),
(142468, 6851, 46, 'प्रकार'),
(142469, 6852, 46, 'प्रकार आयडी किंवा (मोकळी जागा समावेश) Name.3 किमान इतके वर्ण.'),
(142470, 6853, 46, 'स्तंभ प्रकार रुग्ण शोध परिणाम प्रदर्शित'),
(142471, 6854, 46, 'प्रकटीकरण प्रकार'),
(142472, 6855, 46, 'आगामी कार्यक्रम प्रकार'),
(142473, 6856, 46, 'स्क्रीन लेआउट प्रकार'),
(142474, 6857, 46, 'टाइप करा किंवा येथे रुग्ण अभिज्ञापक स्कॅन'),
(142475, 6858, 46, 'येथे आपला संदेश टाइप करा'),
(142476, 6859, 46, 'ऑर्डर आणि परिणाम प्रकार'),
(142477, 6864, 46, 'कॅल्गरी स्पोर्ट्स मेडिसिन केंद्र विद्यापीठ द्वारे प्रदान UCSMC कोड'),
(142478, 6865, 46, 'युक्रेनियन'),
(142479, 6866, 46, 'Ulcerations'),
(142480, 6867, 46, 'वाया गेलेल्या आतड्याला आलेली सूज'),
(142481, 6868, 46, 'अल्सर:'),
(142482, 6869, 46, 'निर्देशिका प्रवेश करण्यात अक्षम'),
(142483, 6870, 46, 'URL मध्ये प्रवेश करण्यात अक्षम'),
(142484, 6871, 46, 'तयार करण्यात अक्षम'),
(142485, 6872, 46, 'रुग्ण दस्तऐवज उपनिर्देशिकेत तयार करण्यात अक्षम'),
(142486, 6873, 46, 'या फाइल मध्ये डेटा शोधण्यात अक्षम.'),
(142487, 6874, 46, 'Ar_activity या देयक जुळण्यासाठी अक्षम'),
(142488, 6875, 46, 'लिहिण्याची परवानगी द्या अर्ज संरचना संपादीत करणे अक्षम'),
(142489, 6876, 46, 'लागू न केलेले'),
(142490, 6877, 46, 'नियुक्त न'),
(142491, 6878, 46, 'अनधिकृत'),
(142492, 6879, 46, 'EPrescription अनधिकृत प्रवेश'),
(142493, 6880, 46, 'अनधिकृत प्रवेश.'),
(142494, 6881, 46, 'बिल न केलेली'),
(142495, 6882, 46, 'बिल न केलेली फक्त'),
(142496, 6884, 46, 'जिभेखाली'),
(142497, 6885, 46, 'कमी वजनाचे'),
(142498, 6886, 46, 'Undiagnosed'),
(142499, 6887, 46, 'अवितरित'),
(142500, 6888, 46, 'अवितरित'),
(142501, 6889, 46, 'अवितरित आहे'),
(142502, 6890, 46, 'चेकआऊट पूर्ववत करा'),
(142503, 6892, 46, 'युनिक ग्राहक'),
(142504, 6893, 46, 'हा प्रकार युनिक मनुष्य-वाचण्यायोग्य अभिज्ञापक'),
(142505, 6894, 46, 'युनिक नवीन ग्राहक'),
(142506, 6895, 46, 'हा प्रकार युनिक अंकीय अभिज्ञापक'),
(142507, 6896, 46, 'युनिक पाहिले रुग्णांना'),
(142508, 6897, 46, 'युनिक पाहिले रुग्णांना अहवाल'),
(142509, 6898, 46, 'युनिक पोलीस अधीक्षक'),
(142510, 6899, 46, 'युनिट'),
(142511, 6900, 46, 'युनिट'),
(142512, 6901, 46, 'युनिट'),
(142513, 6902, 46, 'परिणाम मूल्य लागू युनिट'),
(142514, 6903, 46, 'भेट द्या फॉर्म युनिट'),
(142515, 6904, 46, 'युनिट एक संख्या असणे आवश्यक'),
(142516, 6905, 46, 'युनिट व्याख्या नाही'),
(142517, 6906, 46, 'युनिट / एल'),
(142518, 6907, 46, 'अज्ञात'),
(142519, 6908, 46, 'अज्ञात (लॉग इन पहा)'),
(142520, 6910, 46, 'अज्ञात कधीही smoked तर'),
(142521, 6911, 46, 'अज्ञात वा N / A'),
(142522, 6912, 46, 'अज्ञात वापरकर्ता आयडी:'),
(142523, 6913, 46, 'रुग्ण दुवा रद्द'),
(142524, 6914, 46, 'अनामित विमा कंपनी'),
(142525, 6915, 46, 'नोंदणी रद्द'),
(142526, 6916, 46, 'नोंदणी रद्द मॉड्यूल'),
(142527, 6918, 46, 'सर्व न निवडलेले करा'),
(142528, 6919, 46, 'न निवडलेले'),
(142529, 6920, 46, 'निर्दिष्ट न केलेले'),
(142530, 6921, 46, 'भागात तुम्ही लिहिलेला'),
(142531, 6922, 46, 'असमर्थित डाटाबेस लोड फाइल'),
(142532, 6924, 46, 'पर्यंत'),
(142533, 6925, 46, 'जन्मत: च मेलेल्या दाखल'),
(142534, 6926, 46, 'न वापरलेले'),
(142535, 6927, 46, 'UOR'),
(142536, 6928, 46, 'इथपर्यंत'),
(142537, 6929, 46, 'आगामी नियुक्ती'),
(142538, 6930, 46, 'पुढील कार्यक्रम'),
(142539, 6931, 46, 'अद्यतन'),
(142540, 6932, 46, 'सुधारणा'),
(142541, 6933, 46, 'सक्रिय अद्यतन'),
(142542, 6934, 46, 'फाईली अद्यतनित करा'),
(142543, 6935, 46, 'अद्यतन माहिती'),
(142544, 6936, 46, 'अद्यतन यादी'),
(142545, 6937, 46, 'अद्यतन प्रदाता क्रमांक'),
(142546, 6938, 46, 'अद्यतन निवडलेले आयटम'),
(142547, 6939, 46, 'फाइलमध्ये खालील चलने अद्यतनित करा'),
(142548, 6940, 46, 'वापरकर्ता अद्यतनित करा माहिती'),
(142549, 6942, 46, 'लोकसंख्याशास्त्र अद्यतनित करीत आहे अधिकृत नाही.'),
(142550, 6943, 46, 'जागतिक संरचना पूर्वनिर्धारित अद्यतनित करीत आहे'),
(142551, 6944, 46, 'आवृत्ती निर्देशक अद्यतनित करीत आहे'),
(142552, 6945, 46, 'श्रेणीसुधारित करा'),
(142553, 6946, 46, 'अपग्रेड'),
(142554, 6947, 46, 'अपग्रेड डेटाबेस'),
(142555, 6948, 46, 'डी-ओळख प्रक्रिया आवश्यक प्रक्रियांची, कार्य आणि सपाट दगडी पाट्या समाविष्ट करण्यासाठी LibreEHR डेटाबेस सुधारणा'),
(142556, 6949, 46, 'सुधारणा सुरू राहील'),
(142557, 6950, 46, 'UPIN'),
(142558, 6951, 46, 'अपलोड करा'),
(142559, 6952, 46, 'टेम्पलेट अपलोड करा'),
(142560, 6953, 46, 'अपलोड करा आणि स्थापित'),
(142561, 6954, 46, 'कॉन्फिगरेशन डेटा अपलोड करा'),
(142562, 6955, 46, 'अपलोड करा दस्तऐवज'),
(142563, 6956, 46, 'अपलोड करा अयशस्वी झाले!'),
(142564, 6957, 46, 'प्रतिमा अपलोड करा'),
(142565, 6958, 46, 'आयात फाइल अपलोड करा:'),
(142566, 6959, 46, 'रुग्ण शिक्षण पीडीएफ अपलोड करा'),
(142567, 6960, 46, 'अपलोड करा यशस्वीरित्या प्रक्रिया'),
(142568, 6961, 46, 'अपलोड करा अहवाल'),
(142569, 6962, 46, 'श्रेणी CCR अंतर्गत XML फाइल अपलोड करा'),
(142570, 6963, 46, 'या फाइल अपलोड करा:'),
(142571, 6964, 46, 'एक चलन संख्या "मॅन्युअल पोस्टिंग विंडो" क्लिक यावर दिसते. येथे आपण, बीजक देय तारीख आणि नोट्स बदलू तुम्ही पोस्ट ज्यांच्याकडून पक्ष निवडा, आणि सर्व अपेक्षा paymants प्राप्त केले आहेत, जे इन्शुरन्सचे निवडू शकता. प्रत्येक बिलिंग कोड जे एक रक्कम आकारण्यात आला सर्वात महत्त्वाचे म्हणजे, आपण पेमेंट आणि समायोजन माहिती दाखल करू शकता.'),
(142572, 6965, 46, 'शोध केल्यानंतर आपण पावत्या एक यादी दिली जाते. आपण मॅन्युअल पोस्टिंग डेटा एंट्री पृष्ठ आहे जे एक दुसरा विंडो उघडण्यासाठी बीजक क्रमांक एक वर क्लिक करू शकता. जेव्हा तुम्ही सहनशील धनादेश एकही कार्यालय कर्मचारी दिसेल की एक लक्षात ठेवा प्रविष्ट करू इच्छित असल्यास आपण एक रुग्ण नावावर क्लिक करा शकते, व तुम्ही रुग्णाला स्टेटमेन्ट वर दिसतात आणि त्या स्टेटमेन्ट मुद्रित करण्यासाठी पावत्या निवडू शकता.'),
(142573, 6966, 46, 'उच्च हाताने'),
(142574, 6967, 46, 'उर्दू'),
(142575, 6968, 46, 'निकड'),
(142576, 6970, 46, 'लघवी'),
(142577, 6971, 46, 'लघवी dribbling'),
(142578, 6972, 46, 'लघवी वारंवारता'),
(142579, 6973, 46, 'लघवी अनिश्चितता'),
(142580, 6974, 46, 'लघवी Microalbumin'),
(142581, 6975, 46, 'लघवी प्रवाह'),
(142582, 6976, 46, 'लघवी निकडीच्या'),
(142583, 6977, 46, 'URL मध्ये'),
(142584, 6979, 46, 'LibreEHR समर्थन URL.'),
(142585, 6981, 46, 'फोन गेटवे URL. Maviq द्वारे प्रदान स्वयंचलित VoIP सेवा. अधिक माहितीसाठी http://signup.maviq.com भेट द्या.'),
(142586, 6982, 46, 'पोर्टल समर्थन वर्डप्रेस साइटसाठी URL'),
(142587, 6985, 46, 'वापर'),
(142588, 6986, 46, 'वापर सूचक (ISA15)'),
(142589, 6987, 46, 'फक्त त्या स्तंभ वर्गीकरण शेतात एकटे% वापरा'),
(142590, 6988, 46, '24 तास वेळ स्वरूप वापरायचे?'),
(142591, 6990, 46, 'योग्य असेल तर रुग्णाला त्या स्रोत रुग्ण-विशिष्ट शिक्षण संसाधने ओळखणे आणि प्रदान करण्यासाठी प्रमाणित EHR तंत्रज्ञानाचा वापर.'),
(142592, 6991, 46, 'वापर शुल्क पॅनेल'),
(142593, 6992, 46, 'थेट राज्य, स्थानिक आणि व्यावसायिक निर्देशानुसार वैद्यकीय नोंद मध्ये आदेश प्रविष्ट करू शकता अशा कोणत्याही परवाना आरोग्य व्यावसायिक केलेल्या औषध ऑर्डर CPOE वापरा.'),
(142594, 6997, 46, 'सानुकूल लसीकरण यादी वापरा'),
(142595, 6999, 46, 'वापर तारीख श्रेणी'),
(142596, 7000, 46, 'वापरा डीफॉल्ट'),
(142597, 7001, 46, 'काढा हटवा पर्याय वापरा.'),
(142598, 7002, 46, 'आंतरराष्ट्रीय तारीख शैली वापरण्यासाठी?'),
(142599, 7003, 46, 'वापर स्रोत फाइलनाव'),
(142600, 7004, 46, 'खरेदी किंवा हस्तांतरण खालील फील्ड वापरा.'),
(142601, 7005, 46, 'फक्त नवीन प्रतिष्ठापीत साइट हे वैशिष्ट्य वापरा, '),
(142602, 7006, 46, 'विषय वापरा?'),
(142603, 7007, 46, 'वापरकर्ता'),
(142604, 7009, 46, 'वापरकर्ता / गट'),
(142605, 7010, 46, 'वापरकर्ता प्रशासन'),
(142606, 7011, 46, 'वापरकर्ता व सुविधा प्रशासन'),
(142607, 7012, 46, 'वापरकर्ता व गट प्रशासन'),
(142608, 7013, 46, 'वापरकर्ता हटविला जाऊ शकत नाही'),
(142609, 7014, 46, 'वापरकर्ता प्रमाणपत्र प्रमाणीकरण अक्षम आहे'),
(142610, 7015, 46, 'वापरकर्ता परिभाषित'),
(142611, 7016, 46, 'वापरकर्ता परिभाषित क्षेत्र 11');
INSERT INTO `lang_definitions` VALUES
(142612, 7017, 46, 'वापरकर्ता परिभाषित क्षेत्र 12'),
(142613, 7018, 46, 'वापरकर्ता परिभाषित फील्ड'),
(142614, 7019, 46, 'वापरकर्ता परिभाषित यादी 1'),
(142615, 7020, 46, 'वापरकर्ता परिभाषित यादी 2'),
(142616, 7021, 46, 'वापरकर्ता परिभाषित यादी 3'),
(142617, 7022, 46, 'वापरकर्ता परिभाषित यादी 4'),
(142618, 7023, 46, 'वापरकर्ता परिभाषित यादी 5'),
(142619, 7024, 46, 'वापरकर्ता परिभाषित यादी 6'),
(142620, 7025, 46, 'वापरकर्ता परिभाषित यादी 7'),
(142621, 7026, 46, 'वापरकर्ता परिभाषित मजकूर 1'),
(142622, 7027, 46, 'वापरकर्ता परिभाषित मजकूर 2'),
(142623, 7028, 46, 'वापरकर्ता परिभाषित मजकूर 3'),
(142624, 7029, 46, 'वापरकर्ता परिभाषित मजकूर 4'),
(142625, 7030, 46, 'वापरकर्ता परिभाषित मजकूर 5'),
(142626, 7031, 46, 'वापरकर्ता परिभाषित मजकूर 6'),
(142627, 7032, 46, 'वापरकर्ता परिभाषित मजकूर 7'),
(142628, 7033, 46, 'वापरकर्ता परिभाषित मजकूर 8'),
(142629, 7034, 46, 'वापरकर्ता नाव'),
(142630, 7037, 46, 'वापरकर्ता लॉगॉन (वरील दुसरे 03 मोकळी जागा सोडल्यास) (ISA02)'),
(142631, 7038, 46, 'वापरकर्ता लॉगऑन आवश्यक सूचक (ISA01 ~ 00 किंवा 03 वापर करा)'),
(142632, 7039, 46, 'उपयोगकर्ता पुस्तिका'),
(142633, 7040, 46, 'वापरकर्ता सदस्यता'),
(142634, 7041, 46, 'वापरकर्ता नाव'),
(142635, 7042, 46, 'वापरकर्ता नाव किंवा होस्ट नाव रिकामे असू शकत नाही'),
(142636, 7043, 46, 'वापरकर्ता किंवा होस्ट नाव'),
(142637, 7044, 46, 'वापरकर्ता संकेतशब्द (ISA04 ~ तर वरील 01, जिथे रजा मोकळी जागा)'),
(142638, 7045, 46, 'वापरकर्ता संकेतशब्द सूचक (ISA03 ~ 00 किंवा 01 वापर करा) आवश्यक'),
(142639, 7046, 46, 'वापरकर्ता सेटिंग्ज'),
(142640, 7047, 46, 'वापरकर्ता विशिष्ट सेटिंग'),
(142641, 7048, 46, 'वापरकर्ता  ''चे नवीन पासवर्ड'),
(142642, 7049, 46, 'वापरकर्तानाव'),
(142643, 7051, 46, 'फोन गेटवे वापरकर्त्याचे नाव. Maviq द्वारे प्रदान स्वयंचलित VoIP सेवा. अधिक माहितीसाठी http://signup.maviq.com भेट द्या.'),
(142644, 7052, 46, 'एसएमएस गेटवे वापरकर्त्याचे नाव'),
(142645, 7053, 46, 'एसएमएस गेटवे वापरकर्त्याचे नाव.'),
(142646, 7054, 46, 'CouchDB कनेक्ट वापरकर्त्याचे नाव'),
(142647, 7055, 46, 'वापरकर्तानाव:'),
(142648, 7056, 46, 'वापरकर्ते'),
(142649, 7057, 46, 'वापरकर्ते / गट / नोंदी प्रशासन'),
(142650, 7058, 46, 'PHP <a href="http://php.net/strftime"> जेही काही strftime </a> स्वरूप वापरत'),
(142651, 7059, 46, 'UTIs'),
(142652, 7060, 46, 'उईघुर, उईघुर'),
(142653, 7061, 46, 'उझ्बेक'),
(142654, 7062, 46, 'सुट्टीतील'),
(142655, 7063, 46, 'सुट्टीतील'),
(142656, 7064, 46, 'लस'),
(142657, 7065, 46, 'योनीतून रिंग'),
(142658, 7066, 46, 'समारोप'),
(142659, 7067, 46, 'सत्यापित'),
(142660, 7068, 46, 'मूल्य'),
(142661, 7069, 46, 'मूल्य 1'),
(142662, 7070, 46, 'मूल्य 2'),
(142663, 7072, 46, 'मूल्य संख्यात्मक असावे'),
(142664, 7073, 46, 'Var1'),
(142665, 7074, 46, 'Var2'),
(142666, 7075, 46, 'एक वेरियेबल डी-ओळख सुधारणा स्क्रिप्ट चालवितेवेळी'),
(142667, 7076, 46, 'कांजण्या 1'),
(142668, 7077, 46, 'कांजण्या 2'),
(142669, 7078, 46, 'अशुद्ध रक्तवाहिन्या फुगून झालेल्या गाठींचा नसा'),
(142670, 7079, 46, 'रक्तवहिन्यासंबंधीचा स्थिती'),
(142671, 7080, 46, 'रक्तवहिन्यासंबंधीचा इजा'),
(142672, 7081, 46, 'रक्तवहिन्यासंबंधीचा शस्त्रक्रिया'),
(142673, 7082, 46, 'व्हेंदा'),
(142674, 7083, 46, 'विक्रेता'),
(142675, 7084, 46, 'आवृत्ती'),
(142676, 7085, 46, 'भोवळ'),
(142677, 7086, 46, 'Veteran`s प्रशासन'),
(142678, 7087, 46, 'वृद्धांची प्रशासन योजना'),
(142679, 7088, 46, 'VFC'),
(142680, 7089, 46, 'व्हिएतनामी'),
(142681, 7090, 46, 'दृश्य'),
(142682, 7091, 46, 'पहा'),
(142683, 7092, 46, 'पहा अॅलर्जी'),
(142684, 7093, 46, 'एक x12-835 ईआरए फाइल पहा'),
(142685, 7094, 46, 'पहा बॅच दावा x12 मजकूर'),
(142686, 7097, 46, 'व्यापक रुग्णांच्या अहवाल पहा'),
(142687, 7098, 46, 'सी सपाट दगडी पाट्या पहा'),
(142688, 7100, 46, 'पहा दस्तऐवज'),
(142689, 7101, 46, 'पहा चकमकीत'),
(142690, 7102, 46, 'पहा ईआरए x12 मजकूर'),
(142691, 7103, 46, 'एक पॉपअप विंडो मध्ये पहा कार्यक्रम?'),
(142692, 7104, 46, 'पहा सुविधा विशिष्ट वापरकर्ता माहिती'),
(142693, 7106, 46, 'स्थानिक x12 फाइल पहा'),
(142694, 7107, 46, 'पहा लॉग'),
(142695, 7108, 46, 'पहा पृष्ठ 1'),
(142696, 7109, 46, 'पहा पृष्ठ 2'),
(142697, 7110, 46, 'पहा मागील आणि भविष्यातील स्मरणपत्रे'),
(142698, 7111, 46, 'पहा रुग्णांच्या'),
(142699, 7116, 46, 'पहा संबंधित चकमकी'),
(142700, 7117, 46, 'अहवाल पहा'),
(142701, 7118, 46, 'रीडमी फाइल पहा'),
(142702, 7121, 46, 'पहा / संपादित करा अॅलर्जी'),
(142703, 7122, 46, 'पहा / संपादित करा समस्या'),
(142704, 7123, 46, 'पहा / प्रिंट'),
(142705, 7124, 46, 'पहा:'),
(142706, 7125, 46, 'व्हिसा'),
(142707, 7126, 46, 'व्हिसा / एम / एमेक्स / विरूद्ध'),
(142708, 7127, 46, 'त्यासंबंधी नुकसान / शरीराला झालेली जखम / शस्त्रक्रिया'),
(142709, 7132, 46, 'भेट द्या वर्ग'),
(142710, 7133, 46, 'वर्ग भेट द्या:'),
(142711, 7134, 46, 'भेटीची तारीख'),
(142712, 7135, 46, 'भेटीची तारीख'),
(142713, 7137, 46, 'भेट द्या अर्ज'),
(142714, 7138, 46, 'इतिहासास भेट द्या'),
(142715, 7140, 46, 'भेटी'),
(142716, 7141, 46, 'पासून भेटी'),
(142717, 7142, 46, 'महत्वाच्या चिन्हे'),
(142718, 7143, 46, 'मर्मस्थाने'),
(142719, 7144, 46, 'मर्मस्थाने (मेट्रिक)'),
(142720, 7145, 46, 'मर्मस्थाने फॉर्म पर्याय'),
(142721, 7146, 46, 'आवाज'),
(142722, 7147, 46, 'आवाज पाठविले'),
(142723, 7148, 46, 'ओलापुक'),
(142724, 7149, 46, 'उलट्या होणे'),
(142725, 7151, 46, 'प'),
(142726, 7152, 46, 'कंबर CIRC'),
(142727, 7153, 46, 'कंबर परीघ'),
(142728, 7154, 46, 'प्रतीक्षा करीत आहे'),
(142729, 7155, 46, 'आत या'),
(142730, 7156, 46, 'वालून'),
(142731, 7157, 46, 'वॉल्ट पेनिंग्टन'),
(142732, 7158, 46, 'वखार'),
(142733, 7159, 46, 'वखार कमाल, 0 लागू नाही तर'),
(142734, 7160, 46, 'वखार किमान 0 लागू नाही तर'),
(142735, 7161, 46, 'गोदामांची'),
(142736, 7162, 46, 'उबदार'),
(142737, 7163, 46, 'चेतावणी'),
(142738, 7164, 46, 'चेतावणी'),
(142739, 7166, 46, 'चेतावणी, आधीच डेटाबेस मध्ये अस्तित्वात क्रमांक तपासा'),
(142740, 7167, 46, 'चेतावणी, रुग्णाला समस्या यादीत संदिग्ध कोड आहे!'),
(142741, 7168, 46, 'चेतावणी: एक भेट आधीच आज या रुग्णाला तयार केला होता!'),
(142742, 7169, 46, 'चेतावणी: आपण 2012-10-31 स्पॅनिश आवृत्ती वापरत असाल तर, नंतर आपण (जाहीर फाइल  "डबल झिप " होते कारण हे आहे) योगदान / snomed मध्ये ठेऊन आधी एकदा तो अनझिप करणे आवश्यक आहे लक्षात ठेवा.'),
(142743, 7170, 46, 'चेतावणी: रुग्णांच्या आयडी अद्वितीय नाही!'),
(142744, 7171, 46, 'चेतावणी: हा अपलोड फाइल पासून डेटा संरचना माहिती खोडून पुन्हा होईल!'),
(142745, 7173, 46, 'सावधानता'),
(142746, 7175, 46, 'आधीच अपलोड केले'),
(142747, 7176, 46, 'सापडले नाही'),
(142748, 7177, 46, 'आम्ही योग्य शिल्लक प्रॉम्प्ट पेमेंट प्रशंसा'),
(142749, 7178, 46, 'आम्ही आमच्या बाह्यरुग्ण विभागातील मानिसक चिकित्सालय मूल्यमापन आणि उपचारांसाठी आपल्या वरील रुग्ण पाहिले आहे. या रेफरल धन्यवाद.'),
(142750, 7179, 46, 'अशक्तपणा'),
(142751, 7181, 46, 'वेब शोध'),
(142752, 7182, 46, 'वेबसाइट'),
(142753, 7183, 46, 'Onsite रुग्णांच्या पोर्टल वेबसाइट दुवा.'),
(142754, 7184, 46, 'बुध'),
(142755, 7185, 46, 'बुधवारी'),
(142756, 7186, 46, 'आठवडा'),
(142757, 7187, 46, 'आठवड्यात'),
(142758, 7188, 46, 'आठवडा पहा'),
(142759, 7189, 46, 'आठवडा (चे)'),
(142760, 7190, 46, 'साप्ताहिक एक्सपोजर्स्'),
(142761, 7191, 46, 'आठवडे'),
(142762, 7192, 46, 'आठवडे'),
(142763, 7193, 46, 'वजन'),
(142764, 7194, 46, 'मुले आणि पौगंडावस्थेतील वजन मूल्यांकन आणि समुपदेशन'),
(142765, 7195, 46, 'मुले आणि पौगंडावस्थेतील वजन मूल्यांकन आणि समुपदेशन (CQM)'),
(142766, 7196, 46, 'वजन बदला'),
(142767, 7197, 46, 'वजन कमी होणे'),
(142768, 7198, 46, 'वजन कमी होणे चिकित्सालय'),
(142769, 7199, 46, 'आपले स्वागत आहे'),
(142770, 7200, 46, 'वेल्श'),
(142771, 7201, 46, 'पाश्चात्य फ्रिशियन'),
(142772, 7202, 46, 'काय गणना करावी आहे?'),
(142773, 7203, 46, 'Wheezes:'),
(142774, 7204, 46, 'घरघर'),
(142775, 7205, 46, 'घरघर:'),
(142776, 7207, 46, 'पूर्ण झाल्यानंतर, आपल्या आवडी लागू करण्यासाठी (खाली) सबमिट करा क्लिक करा.'),
(142777, 7208, 46, 'कोठे स्कॅन संबंधित शकते किंवा कागदी दस्तऐवज मिलेल?'),
(142778, 7209, 46, 'विम्याची की नाही'),
(142779, 7211, 46, 'Whiplash'),
(142780, 7212, 46, 'व्हाइट'),
(142781, 7213, 46, 'कोण'),
(142782, 7214, 46, 'कोण काय?'),
(142783, 7215, 46, 'विधवा झालेली किंवा विधुर झालेला'),
(142784, 7216, 46, 'रूंदी'),
(142785, 7217, 46, 'डाव्या सुचालन फ्रेम पिक्सेल मध्ये रुंदी.'),
(142786, 7219, 46, 'चेक केलेले आयटम प्लॉट'),
(142787, 7220, 46, 'प्राधान्यकृत भाषा'),
(142788, 7221, 46, 'सह निवडले:'),
(142789, 7222, 46, 'जुन्या नाव'),
(142790, 7224, 46, 'ज्याच्यापाशी आम्हांला एक संदेश देऊ शकतात?'),
(142791, 7225, 46, 'स्थगित'),
(142792, 7226, 46, 'तासांच्या आत'),
(142793, 7227, 46, 'तासांच्या आत:'),
(142794, 7228, 46, 'मिनिटातच'),
(142795, 7229, 46, 'मिनिटातच:'),
(142796, 7230, 46, 'सुविधा न करता'),
(142797, 7231, 46, 'प्रदाता न करता'),
(142798, 7232, 46, 'अद्यतन न करता'),
(142799, 7233, 46, 'साक्षीदार'),
(142800, 7234, 46, 'आठवडा'),
(142801, 7235, 46, 'WNL'),
(142802, 7236, 46, 'वोलोफ'),
(142803, 7237, 46, 'महिला'),
(142804, 7238, 46, 'महिला केवळ'),
(142805, 7239, 46, 'वर्डप्रेस पोर्टल'),
(142806, 7240, 46, 'कार्य'),
(142807, 7241, 46, 'कार्य सुचना'),
(142808, 7242, 46, 'कार्य फोन'),
(142809, 7243, 46, 'कार्य फोन नंबर'),
(142810, 7244, 46, 'संबंधित कार्य?'),
(142811, 7245, 46, 'कार्य / शिक्षण / छंद'),
(142812, 7246, 46, 'कार्य / शाळा टीप'),
(142813, 7247, 46, 'काम करवून घेणे'),
(142814, 7248, 46, 'Worker`s नुकसान भरपाई'),
(142815, 7249, 46, 'कामगार भरपाई आरोग्य योजना'),
(142816, 7250, 46, 'नियोक्ता गट आरोग्य योजना ज्येष्ठ नागरीक लाभार्थी किंवा जोडीदार काम'),
(142817, 7251, 46, 'कार्यरत आहे ... हे एक मिनिट लागू शकतो.'),
(142818, 7252, 46, 'वाईट'),
(142819, 7253, 46, 'तुम्ही जागतिक खाते लागू करण्यासाठी रक्कम इच्छिता?'),
(142820, 7254, 46, 'आपण साफ म्हणून त्यांना चिन्हांकित करणे आवडेल.'),
(142821, 7255, 46, 'आपण वाटप करू इच्छिता?'),
(142822, 7256, 46, 'आपण या रुग्णांच्या वितरण रद्द करू इच्छिता?'),
(142823, 7257, 46, 'आपण भरणा वितरण हटवा करू इच्छिता?'),
(142824, 7258, 46, 'देयके हटवा करू इच्छिता?'),
(142825, 7259, 46, 'आपण समाप्त पेमेंट संपादीत करा व करू इच्छिता?'),
(142826, 7260, 46, 'देयके संपादीत करू इच्छिता?'),
(142827, 7261, 46, 'आपण समाप्त पेमेंट पोस्ट करा आणि करू इच्छिता?'),
(142828, 7262, 46, 'देयके पोस्ट करू इच्छिता?'),
(142829, 7263, 46, 'आपण जतन करू इच्छिता?'),
(142830, 7264, 46, 'मनगट'),
(142831, 7265, 46, 'मनगट आणि हात'),
(142832, 7266, 46, 'मनगट समस्या'),
(142833, 7267, 46, 'लिहा'),
(142834, 7268, 46, 'बंद लिहू'),
(142835, 7269, 46, 'एकदा लिहा'),
(142836, 7270, 46, 'wsome'),
(142837, 7271, 46, 'WT'),
(142838, 7273, 46, 'नाम रद्द'),
(142839, 7274, 46, 'नाम रद्द'),
(142840, 7275, 46, 'क्ष-किरण'),
(142841, 7276, 46, 'एक्स-रे इंटरप्रिटेशन'),
(142842, 7277, 46, 'एक्स-रे इंटरप्रिटेशन'),
(142843, 7278, 46, 'X12 फक्त: बदलण्याचे दावा '),
(142844, 7279, 46, 'X12 भागीदार'),
(142845, 7280, 46, 'X12 भागीदार'),
(142846, 7281, 46, 'x12 मजकूर'),
(142847, 7282, 46, 'खोसा'),
(142848, 7284, 46, 'युवराज'),
(142849, 7285, 46, 'वर्ष'),
(142850, 7286, 46, 'वर्ष'),
(142851, 7287, 46, 'वर्ष पहा'),
(142852, 7288, 46, 'वर्ष (चे)'),
(142853, 7289, 46, 'वर्ष'),
(142854, 7290, 46, 'वर्षे किंवा महिने'),
(142855, 7291, 46, 'वर्ष, महिने आणि दिवस'),
(142856, 7292, 46, 'होय'),
(142857, 7293, 46, 'होय'),
(142858, 7294, 46, 'होय'),
(142859, 7295, 46, 'होय!'),
(142860, 7296, 46, 'होय, हटवा आणि लॉग'),
(142861, 7298, 46, 'होय नाही'),
(142862, 7299, 46, 'होय:'),
(142863, 7300, 46, 'यिद्दी'),
(142864, 7301, 46, 'योरूबा'),
(142865, 7303, 46, 'आपण कायमचे विद्यमान टेम्प्लेट पुनर्स्थित आहेत. तुम्हाला नक्की पुढे जायचे?'),
(142866, 7304, 46, 'आपण देवाची कृपा लॉग-इन काळात आहेत. आपल्याला आपला संकेतशब्द बदला'),
(142867, 7305, 46, 'आपण हा कार्यक्रम हटवू परवानगी नाही'),
(142868, 7306, 46, 'हा कार्यक्रम संपादित करण्याची परवानगी नाही'),
(142869, 7307, 46, 'आपण या अधिकृत नाही.'),
(142870, 7308, 46, 'आपण या संघात प्रवेश करण्यास अधिकृत नाही आहेत.'),
(142871, 7309, 46, 'आपण / संपादित करा मुद्दे जोडण्यासाठी अधिकृत नाही'),
(142872, 7310, 46, 'आपण भेटी शेड्यूल अधिकृत नाही.'),
(142873, 7311, 46, 'आपण या चकमकीत पाहण्यासाठी अधिकृत नाही.'),
(142874, 7312, 46, 'आपण जुन्या चकमकीत विरुद्ध पोस्ट आहेत?'),
(142875, 7313, 46, 'आपण थेट हे कार्य प्रवेश करू शकत नाही.'),
(142876, 7314, 46, 'आपण थेट या पृष्ठावर प्रवेश करू शकत नाही.'),
(142877, 7315, 46, 'आपण एक श्रेणी एक रिक्त मूल्य जोडू शकत नाही!'),
(142878, 7316, 46, 'आपण फक्त खालील उपवर्ग एक रिक्त मूल्य जोडू शकत नाही!'),
(142879, 7317, 46, 'आपण एक आयटम एक रिक्त मूल्य जोडू शकत नाही!'),
(142880, 7318, 46, 'आपण होय एक पूर्ण मूल्य भावी तारीख प्रविष्ट करू शकत नाही.'),
(142881, 7319, 46, 'आपण कोणत्याही क्रिया निवडा नाही.'),
(142882, 7320, 46, 'आपण पाहण्यासाठी प्रवेश नाही / हे लक्षात ठेवा संपादित'),
(142883, 7321, 46, 'आपण लॉक केलेले आहे, जे सामग्री बदलू करण्याचा प्रयत्न केला आहे. आपण हे करू इच्छित असल्यास लॉक काढून टाका. ओळ, काढून टाकणे, अनलॉक करण्यासाठी, ''/ * लॉक :: * /'''),
(142884, 7322, 46, 'आपण यशस्वीरित्या लॉग आउट केले आहे.'),
(142885, 7323, 46, 'आपण फक्त फाइल .txt अपलोड करू शकता'),
(142886, 7324, 46, 'आपण वैकल्पिकरित्या एक फाइल पासून HL7 परिणाम अपलोड करू शकता'),
(142887, 7325, 46, 'आपण नवीन रुग्णांच्या चकमकीत स्वरूपात मुलभूत तक्रार म्हणून मजकूर येथे ठेवा शकते.'),
(142888, 7326, 46, 'आपण दस्तऐवज कूटबद्ध करण्यासाठी पास वाक्यांश प्रविष्ट करणे आवश्यक आहे'),
(142889, 7327, 46, 'आपण वापरकर्ता संकेतशब्द बदलण्यासाठी आपल्या स्वत: च्या संकेतशब्द प्रविष्ट करणे आवश्यक आहे. जसाच्या तसा पासवर्ड ठेवणे रिक्त सोडा.'),
(142890, 7329, 46, 'आपण प्रथम निवडण्यासाठी किंवा रुग्णाला जोडणे आवश्यक आहे.'),
(142891, 7330, 46, 'आपण प्रथम निवडा किंवा चकमकीत तयार करणे आवश्यक आहे.'),
(142892, 7331, 46, 'आपण भेट श्रेणी निवडणे आवश्यक आहे'),
(142893, 7332, 46, 'आपण भेट श्रेणी निवडणे आवश्यक आहे.'),
(142894, 7333, 46, 'आपण सुरू ठेवण्यासाठी काही फील्ड निवडणे आवश्यक आहे.'),
(142895, 7334, 46, 'हा हक्क यशस्वीरित्या निर्माण दर्शन दिले असेल तर तुम्ही हा चाचणी चालू पाहिजे परंतु प्रत्यक्ष हक्क फाइल कोणताही डेटा किंवा असू नवं पुस्तक घेऊन येतो डेटा रक्कम केवळ एक अपूर्ण भाग असू शकत नाही. X12 तो दावा योग्य पूर्ण असेल तर निर्धारित करण्यासाठी एक अधिक कठीण प्रक्रिया आहे दावा ते, वाचनीय मानवी आहेत कारण HCFA हक्क स्पष्ट आहे.'),
(142896, 7335, 46, 'आपण कमीत कमी एक संदर्भ निवडा पाहिजे'),
(142897, 7336, 46, 'आपण कमीत कमी एक प्रदाता निवडा पाहिजे'),
(142898, 7338, 46, 'आपले क्लिनिकल अहवाल'),
(142899, 7339, 46, 'आपले अंतिम तारीख अवैध आहे'),
(142900, 7340, 46, 'आपला कार्यक्रम हटवला गेला आहे.'),
(142901, 7341, 46, 'आपला कार्यक्रम बदलण्यात आला आहे.'),
(142902, 7342, 46, 'आपला कार्यक्रम सादर केले गेले.'),
(142903, 7343, 46, 'आपली फाईल बरीच मोठी आहे'),
(142904, 7344, 46, 'आपले लॅब परिणाम'),
(142905, 7345, 46, 'आपले यादी नाव नाव गरजा पूर्ण करण्यासाठी बदलण्यात आले आहे.'),
(142906, 7346, 46, 'आपला संदेश डिलिव्हरी सादर करण्यात आला होता'),
(142907, 7347, 46, 'या वर्गात, प्रक्रिया किंवा परिणाम आपले नाव'),
(142908, 7348, 46, 'आपला संकेतशब्द'),
(142909, 7349, 46, 'आपला संकेतशब्द कालबाह्य झाला. कृपया आपला संकेतशब्द बदला.'),
(142910, 7350, 46, 'आपला पासवर्ड कालबाह्य होत आहे'),
(142911, 7351, 46, 'आपला संकेतशब्द आज कालबाह्य. कृपया आपला संकेतशब्द बदला.'),
(142912, 7352, 46, 'तुमचा पासवर्ड तुमच्या स्वाक्षरी आहे'),
(142913, 7353, 46, 'आपले PostCalendar संरचना पूर्वनिर्धारित वापर रीसेट केले आहे.'),
(142914, 7354, 46, 'आपले PostCalendar संरचना सुधारीत केले आहे.'),
(142915, 7355, 46, 'आपले पुनरावृत्ती वारंवारता एक पूर्णांक असणे आवश्यक आहे.'),
(142916, 7356, 46, 'आपले पुनरावृत्ती वारंवारता किमान 1 असणे आवश्यक आहे.'),
(142917, 7357, 46, 'आपले प्रारंभ तारीख आपल्या अंतिम तारीख पेक्षा जास्त आहे'),
(142918, 7358, 46, 'आपले प्रारंभ तारीख अवैध आहे'),
(142919, 7359, 46, 'आपले सबमिशन अयशस्वी.'),
(142920, 7360, 46, 'वर्ष-mm-dd या'),
(142921, 7361, 46, 'YYYY-MM-डीडी'),
(142922, 7362, 46, 'वर्ष-mm-dd या तारीख दस्तऐवज संबद्ध'),
(142923, 7363, 46, 'वर्ष-mm-dd या तारीख नष्ट'),
(142924, 7364, 46, 'जन्म वर्ष-mm-dd या तारीख'),
(142925, 7365, 46, 'जन्म वर्ष-mm-dd या तारीख'),
(142926, 7366, 46, 'समाप्तिची वर्ष-mm-dd या तारीख'),
(142927, 7367, 46, 'दिसायला लागायच्या किंवा दवाखान्यात भरती वर्ष-mm-dd या तारीख'),
(142928, 7368, 46, 'वर्ष-mm-dd या लागायच्या, शस्त्रक्रिया तारीख किंवा औषधोपचार सुरू'),
(142929, 7369, 46, 'खरेदी किंवा हस्तांतरण वर्ष-mm-dd या तारीख'),
(142930, 7370, 46, 'वर्ष-mm-dd या पुनर्प्राप्ती तारीख किंवा औषधोपचार शेवटी'),
(142931, 7371, 46, 'परत वर्ष-mm-dd या तारीख खेळण्यासाठी'),
(142932, 7372, 46, 'सेवा वर्ष-mm-dd या तारीख'),
(142933, 7373, 46, 'या पत्राची वर्ष-mm-dd या तारीख'),
(142934, 7374, 46, 'वर्ष-mm-dd या अद्ययावत खेळण्यासाठी परत'),
(142935, 7375, 46, 'वर्ष-mm-dd या दस्तऐवज तारीख'),
(142936, 7376, 46, 'वर्ष-mm-dd या कार्यक्रम तारीख किंवा सुरू तारीख'),
(142937, 7377, 46, 'वर्ष-mm-dd या एच: मीटर शेवटची तारीख'),
(142938, 7378, 46, 'वर्ष-mm-dd या एच: मीटर समाप्ती तारीख'),
(142939, 7379, 46, 'वर्ष-mm-dd या एच: मीटर प्रारंभ तारीख'),
(142940, 7380, 46, 'वर्ष-mm-dd या एच: मीटर प्रारंभ तारीख'),
(142941, 7381, 46, 'वर्ष-MM-DD HH:-mm-ss'),
(142942, 7382, 46, 'वर्ष-mm-dd या तास (24): मिनिटे'),
(142943, 7383, 46, 'हा कार्यक्रम करण्याची शेवटची तारीख वर्ष-mm-dd'),
(142944, 7385, 46, 'ZEF विभाग अंतर्गत त्रुटी'),
(142945, 7386, 46, 'तुलनात्मक अभ्यासात विभाग'),
(142946, 7387, 46, 'शून्य'),
(142947, 7388, 46, 'झुआंग, चुआंग'),
(142948, 7389, 46, 'पिन'),
(142949, 7390, 46, 'पिनकोड'),
(142950, 7391, 46, 'पिन / देश:'),
(142951, 7392, 46, 'झुलू'),
(142952, 7393, 46, '  पण '),
(142953, 7394, 46, '  प्रवेश करता येत नाही.'),
(142954, 7395, 46, ' आपण खरोखर हटवू इच्छिता का'),
(142955, 7396, 46, ' औषध'),
(142956, 7397, 46, ' ईमेल पाठवले नाही'),
(142957, 7398, 46, ' पासून'),
(142958, 7399, 46, ' तयार केले गेले आहे. '),
(142959, 7400, 46, ' करण्यात आली आहे पुन्हा उघडले.'),
(142960, 7401, 46, ' इतिहास'),
(142961, 7402, 46, ' क्रमांक नाही'),
(142962, 7403, 46, ' पुन्हा बिलिंग तयार आहे.'),
(142963, 7404, 46, ' LLL:'),
(142964, 7405, 46, ' लोट'),
(142965, 7406, 46, ' मेडीकेडची मूळ संदर्भ क्रमांक '),
(142966, 7407, 46, ' मि'),
(142967, 7408, 46, ' आढळले नाही!'),
(142968, 7409, 46, ' अनेक ब्राउझरमध्ये Pecularities आउटपुट खाली अचानक jerks आपल्या स्क्रीन प्रवेश करतो आणि गोष्टी क्रॅश असावे तरी म्हणून दिसते जेथे अनेक सेकंद लांब थांबणे आहेत शकतो. त्या बाबतीत नाही, शेवटी आपण आउटपुट ओळ ओळ येताना पाहतील. खाली दिसणार्या घडणारा संख्या असू शकते, हे अगदी दुसरे काहीच तरी वर जात क्रियाकलाप आहे प्रदर्शित केले जाऊ शकते सूचित आहे. या संख्या बिलिंग सामग्री आलटून पालटून जाईल आणि त्या सामान्य आहे.'),
(142969, 7410, 46, ' नियम त्याच्या मर्यादा गाठली आहे'),
(142970, 7411, 46, ' पर्यंत'),
(142971, 7412, 46, ' सुधारणा डेटाबेसमध्ये नाही, अयशस्वी?'),
(142972, 7413, 46, ' फक्त बिल म्हणून चिन्हांकित करण्यात आला.'),
(142973, 7414, 46, ' यशस्वीरित्या रांगेत होते.'),
(142974, 7415, 46, '! / O भेट वाईड बाकी'),
(142975, 7416, 46, '"कोड'),
(142976, 7417, 46, '"PostCalendar सेटिंग्ज चेक-इन केले आहे!'),
(142977, 7418, 46, '# इन / कल्ला समस्या'),
(142978, 7419, 46, 'गोळ्या #:'),
(142979, 7420, 46, '$'),
(142980, 7421, 46, '$ केले कोडींग'),
(142981, 7422, 46, '$ लेबल (वर्ष-mm-dd या): '),
(142982, 7423, 46, '%'),
(142983, 7424, 46, '% रद्द <24'),
(142984, 7425, 46, '% रद्द <24 '),
(142985, 7426, 46, 'विद्यमान पण नाही पाहिजे.'),
(142986, 7427, 46, '(% _ कुठलेही अक्षर सामने, कोणत्याही स्ट्रिंग सामने)'),
(142987, 7428, 46, '([Ctrl] + अनेक प्राप्तकर्ता निवडण्यासाठी क्लिक करा)'),
(142988, 7429, 46, '(परत)'),
(142989, 7430, 46, '(संपादित करण्यासाठी क्लिक करा)'),
(142990, 7431, 46, '(स्वयंचलित VOIP पुढील प्रक्रिया सेवा प्रदाता पाठविले आहे, तर ई-मेल वितरण तातडीने आहे.)'),
(142991, 7432, 46, '(अधिक)'),
(142992, 7433, 46, '(नवीन रुग्णांच्या)'),
(142993, 7434, 46, '(नोट्स आणि अधिकृत)'),
(142994, 7435, 46, '(रुग्णांच्या टिपा)'),
(142995, 7436, 46, '(या एक निवडा, किंवा आपल्या स्वत: शीर्षक टाइप करा)'),
(142996, 7437, 46, '(Shift-) वर क्लिक करा किंवा ड्रॅग मूल्य बदलण्यासाठी'),
(142997, 7438, 46, '* स्मरण केले'),
(142998, 7439, 46, '** मुद्दे शस्त्रक्रिया हलवा करा!'),
(142999, 7440, 46, '* आवश्यक'),
(143000, 7441, 46, '#ERROR!'),
(143001, 7442, 46, '- नाही'),
(143002, 7443, 46, '- सर्व -'),
(143003, 7444, 46, '--Select Role--'),
(143004, 7445, 46, '.'),
(143005, 7446, 46, '0'),
(143006, 7447, 46, '0-10'),
(143007, 7448, 46, '0-24'),
(143008, 7449, 46, '02/12 {{ग्लोबल मध्ये सीएमएस 1500 स्वरूप तारीख पुनरावृत्ती सेटिंग}}'),
(143009, 7450, 46, '08/05 {{ग्लोबल मध्ये सीएमएस 1500 स्वरूप तारीख पुनरावृत्ती सेटिंग}}'),
(143010, 7451, 46, '1'),
(143011, 7452, 46, '1 = उत्तर अमेरिका. इतर देश कोड यादी http://www.wtng.info/ पहा.'),
(143012, 7453, 46, 'आता 1 दिवस'),
(143013, 7454, 46, 'आता 1 महिना'),
(143014, 7455, 46, '1 आठवडा आता पासून'),
(143015, 7456, 46, '1 वर्ष आता पासून'),
(143016, 7457, 46, 'पाय नाण्यासारखा किंवा फिकट गुलाबी रंग 4. चढवणे पाय आणि पाय विकसित तोपर्यंत दोन दिवस 1.Rest 2. बर्फ 3. संक्षेप ठिकाणी जमिनीच्या पृष्ठभागावर खत घालणे सोडून'),
(143017, 7458, 46, '11-14'),
(143018, 7459, 46, '12 तास'),
(143019, 7460, 46, '15-19'),
(143020, 7461, 46, '1'),
(143021, 7462, 46, '2'),
(143022, 7463, 46, '2 दिवस आता पासून'),
(143023, 7464, 46, '2 महिने आता पासून'),
(143024, 7465, 46, '2 आठवडे आता पासून'),
(143025, 7466, 46, '2 वर्षे आता पासून'),
(143026, 7467, 46, '2-20 वर्षे'),
(143027, 7468, 46, '20-24'),
(143028, 7469, 46, '2011 ऑटोमेटेड माप गणना (एएमसी)'),
(143029, 7470, 46, '2011 क्लिनिकल गुणवत्ता उपाय (CQM)'),
(143030, 7471, 46, '2011 अधिकृत क्लिनिकल गुणवत्ता उपाय (CQM) माप गट'),
(143031, 7472, 46, '2014 ऑटोमेटेड माप गणना (एएमसी)'),
(143032, 7475, 46, '2014 क्लिनिकल गुणवत्ता उपाय (CQM)'),
(143033, 7476, 46, '2014 अधिकृत क्लिनिकल गुणवत्ता उपाय (CQM) माप गट'),
(143034, 7477, 46, '2111-13'),
(143035, 7478, 46, '24 तास'),
(143036, 7479, 46, '25+'),
(143037, 7480, 46, '25-29'),
(143038, 7481, 46, '2'),
(143039, 7482, 46, '3 दिवस आता पासून'),
(143040, 7483, 46, '3 महिने'),
(143041, 7484, 46, '3 महिने आता पासून'),
(143042, 7485, 46, '3 वेळा दररोज'),
(143043, 7486, 46, '3 आठवडे आता पासून'),
(143044, 7487, 46, '30-34'),
(143045, 7488, 46, '35-39'),
(143046, 7489, 46, '3'),
(143047, 7490, 46, '4 दिवस आता पासून'),
(143048, 7491, 46, '4 महिने'),
(143049, 7492, 46, '4 महिने आता पासून'),
(143050, 7493, 46, '4 वेळा रोज'),
(143051, 7494, 46, '4 आठवडे आता पासून'),
(143052, 7495, 46, '40-44'),
(143053, 7496, 46, '45+'),
(143054, 7497, 46, '465,9, URI वर'),
(143055, 7498, 46, '466,0, ब्राँकायटिस, तीव्र NOS'),
(143056, 7499, 46, '486,0, न्यूमोनिया, तीव्र'),
(143057, 7500, 46, '491,21, COPD तीव्रता'),
(143058, 7501, 46, '491,8, ब्राँकायटिस, तीव्र'),
(143059, 7502, 46, '493,92, दमा, तीव्र Exac.'),
(143060, 7503, 46, '496,0, COPD'),
(143061, 7504, 46, '4'),
(143062, 7505, 46, '5 दिवस आता पासून'),
(143063, 7506, 46, '5 महिने आता पासून'),
(143064, 7507, 46, '5 आठवडे आता पासून'),
(143065, 7508, 46, '519,7, श्वासवाहिन्यांमधील बिनपट्टयांच्या स्नायूंच्या आकस्मिक आकुंचनामुळे श्वसनास होणारा अडथळा'),
(143066, 7509, 46, '5'),
(143067, 7510, 46, '6 दिवस आता पासून'),
(143068, 7511, 46, '6 महिने'),
(143069, 7512, 46, '6 महिने आता पासून'),
(143070, 7513, 46, '6 आठवडे आता पासून'),
(143071, 7514, 46, '6'),
(143072, 7515, 46, '7 महिने आता पासून'),
(143073, 7516, 46, '8 महिने आता पासून'),
(143074, 7517, 46, '824,0 फ्रॅक्चर, सरासरीचा घोटा, बंद'),
(143075, 7518, 46, '824,2 फ्रॅक्चर, बाजूकडील घोटा, बंद'),
(143076, 7519, 46, '824,6 फ्रॅक्चर, Trimalleolar बंद'),
(143077, 7520, 46, '825,32 फ्रॅक्चर, होडीच्या आकाराचे च्या (घोट्याच्या)'),
(143078, 7521, 46, '825,35 फ्रॅक्चर पाचव्या (5) पायाभूत पायाचा घोटा व पायाची बोटे जोडणार्या पाच अस्थीपैकी एक'),
(143079, 7522, 46, '845,00 घोट्याच्या लचक NOS'),
(143080, 7523, 46, '845,01 लचक सरासरीचा (त्रिकोणी) अल्प.'),
(143081, 7524, 46, '845,02 लचक, Calcaneal fibular'),
(143082, 7525, 46, '9 महिने आता पासून'),
(143083, 7526, 46, '99212 स्थापना - uncomplicated'),
(143084, 7527, 46, '99213 स्थापना - कमी जटिलता'),
(143085, 7528, 46, '<परीक्षा खोलीत'),
(143086, 7529, 46, '> बाहेर चेक-इन'),
(143087, 7530, 46, '?'),
(143088, 7531, 46, '? कोणताही शो'),
(143089, 7532, 46, '@ आगमन'),
(143090, 7533, 46, '[बदला पहा]'),
(143091, 7534, 46, '[शेवटच्या चकमकीत तारीख]'),
(143092, 7535, 46, '[शेवटच्या चकमकीत असल्याने दिवस]'),
(143093, 7536, 46, '[EOBs]'),
(143094, 7537, 46, '[निर्यात OFX]'),
(143095, 7538, 46, '[शिफारस केलेली नाही]'),
(143096, 7539, 46, '[चकमक क्रमांक]'),
(143097, 7540, 46, '[अहवाल]'),
(143098, 7541, 46, '[सर्व निवडा]'),
(143099, 7542, 46, '[एस क्यू एल-लेजर]'),
(143100, 7543, 46, '[प्रारंभ बॅच प्रक्रिया]'),
(143101, 7544, 46, '[पहा लॉग]'),
(143102, 7545, 46, '[पहा प्रिंट अहवाल]'),
(143103, 7546, 46, '_PC_DUR_HOURS'),
(143104, 7547, 46, '_PC_DUR_MINUTES'),
(143105, 7548, 46, '_PC_LOCALE'),
(143106, 7549, 46, '~ उशीरा आगमन'),
(143107, 1, 47, 'A'),
(143108, 2, 47, 'U hubso tirsiga ama tirsiga qaanta si aad u aqoonsato bixinta'),
(143109, 3, 47, 'Cadeynta macmiilka ee mareynta isticmallaha'),
(143110, 4, 47, 'Waxaa ku lifaaqan waraaqaha rugta caafimaadka'),
(143111, 5, 47, 'Waxaa ku lifaaqan waraaqaha rugta caafimaadka.'),
(143112, 7, 47, 'Waxaa loo baahanyahay qeybiye.'),
(143113, 8, 47, 'Qaabeysanaha kulanka ee GCAC waa in lagu daraa la kulankan.'),
(143114, 9, 47, 'Tirsiga barxadan waa loo baahanyahay'),
(143115, 10, 47, 'Tirsiga barxadan waa loo baahanyahay!'),
(143116, 11, 47, 'Xarfaha yaryar'),
(143117, 12, 47, 'Tiro'),
(143118, 14, 47, 'Bukaan aqoonsigan lehi wuu ku jiraa halkan.'),
(143119, 15, 47, 'Bukaan magacan lehi wuu ku jiraa halkan.'),
(143120, 16, 47, 'Bukaan caymiska bulshada lehi wuu ku jiraa halkan.'),
(143121, 17, 47, 'Tirada togan waxay ku tusi doonaan in balamo hore oo badani ku jireen agabka koobaaya shaashada Bukaanku (tabanaha tirada waxay ku tusi doonaan balamo si hoos u dhaadhaac leh)'),
(143122, 18, 47, 'Tirada togan waxay ku tusi doonaan in balamo hore oo badani ku jireen agabka koobaaya shaashada Bukaanku.'),
(143123, 19, 47, 'Meesha ay ka soo baxdo raacdadu waxa laga filayaa in ay gaar ahaato markast oo la kulmo.'),
(143124, 20, 47, 'Waxa loo baahanyahay xidhaalka la xidhiidha IPPF!'),
(143125, 1, 48, 'dummy'),
(143126, 2, 48, 'dummy'),
(143127, 3, 48, 'dummy'),
(143128, 4, 48, 'dummy'),
(143129, 5, 48, 'dummy'),
(143130, 6, 48, 'dummy'),
(143131, 7, 48, 'dummy'),
(143132, 8, 48, 'dummy'),
(143133, 9, 48, 'dummy'),
(143134, 10, 48, 'dummy'),
(143135, 11, 48, 'dummy'),
(143136, 12, 48, 'dummy'),
(143137, 13, 48, 'dummy'),
(143138, 14, 48, 'dummy'),
(143139, 15, 48, 'dummy'),
(143140, 16, 48, 'dummy'),
(143141, 17, 48, 'dummy'),
(143142, 18, 48, 'dummy'),
(143143, 19, 48, 'dummy'),
(143144, 20, 48, 'dummy'),
(143145, 21, 48, 'dummy'),
(143146, 22, 48, 'dummy'),
(143147, 23, 48, 'dummy'),
(143148, 24, 48, 'dummy'),
(143149, 25, 48, 'dummy'),
(143150, 26, 48, 'dummy'),
(143151, 27, 48, 'dummy'),
(143152, 28, 48, 'dummy'),
(143153, 29, 48, 'dummy'),
(143154, 30, 48, 'dummy'),
(143155, 31, 48, 'dummy'),
(143156, 32, 48, 'dummy'),
(143157, 33, 48, 'dummy'),
(143158, 34, 48, 'dummy'),
(143159, 35, 48, 'dummy'),
(143160, 36, 48, 'dummy'),
(143161, 37, 48, 'dummy'),
(143162, 38, 48, 'dummy'),
(143163, 39, 48, 'dummy'),
(143164, 40, 48, 'dummy'),
(143165, 41, 48, 'dummy'),
(143166, 42, 48, 'dummy'),
(143167, 43, 48, 'dummy'),
(143168, 44, 48, 'dummy'),
(143169, 45, 48, 'dummy'),
(143170, 46, 48, 'dummy'),
(143171, 47, 48, 'dummy'),
(143172, 48, 48, 'dummy'),
(143173, 49, 48, 'dummy'),
(143174, 50, 48, 'dummy'),
(143175, 51, 48, 'dummy'),
(143176, 52, 48, 'dummy'),
(143177, 53, 48, 'dummy'),
(143178, 54, 48, 'dummy'),
(143179, 55, 48, 'dummy'),
(143180, 56, 48, 'dummy'),
(143181, 57, 48, 'dummy'),
(143182, 58, 48, 'dummy'),
(143183, 59, 48, 'dummy'),
(143184, 60, 48, 'dummy'),
(143185, 61, 48, 'dummy'),
(143186, 62, 48, 'dummy'),
(143187, 63, 48, 'dummy'),
(143188, 64, 48, 'dummy'),
(143189, 65, 48, 'dummy'),
(143190, 66, 48, 'dummy'),
(143191, 67, 48, 'dummy'),
(143192, 68, 48, 'dummy'),
(143193, 69, 48, 'dummy'),
(143194, 70, 48, 'dummy'),
(143195, 71, 48, 'dummy'),
(143196, 72, 48, 'dummy'),
(143197, 73, 48, 'dummy'),
(143198, 74, 48, 'dummy'),
(143199, 75, 48, 'dummy'),
(143200, 76, 48, 'dummy'),
(143201, 77, 48, 'dummy'),
(143202, 78, 48, 'dummy'),
(143203, 79, 48, 'dummy'),
(143204, 80, 48, 'dummy'),
(143205, 81, 48, 'dummy'),
(143206, 82, 48, 'dummy'),
(143207, 83, 48, 'dummy'),
(143208, 84, 48, 'dummy'),
(143209, 85, 48, 'dummy'),
(143210, 86, 48, 'dummy'),
(143211, 87, 48, 'dummy'),
(143212, 88, 48, 'dummy'),
(143213, 89, 48, 'dummy'),
(143214, 90, 48, 'dummy'),
(143215, 91, 48, 'dummy'),
(143216, 92, 48, 'dummy'),
(143217, 93, 48, 'dummy'),
(143218, 94, 48, 'dummy'),
(143219, 95, 48, 'dummy'),
(143220, 96, 48, 'dummy'),
(143221, 97, 48, 'dummy'),
(143222, 98, 48, 'dummy'),
(143223, 99, 48, 'dummy'),
(143224, 100, 48, 'dummy'),
(143225, 101, 48, 'dummy'),
(143226, 102, 48, 'dummy'),
(143227, 103, 48, 'dummy'),
(143228, 104, 48, 'dummy'),
(143229, 105, 48, 'dummy'),
(143230, 106, 48, 'dummy'),
(143231, 107, 48, 'dummy'),
(143232, 108, 48, 'dummy'),
(143233, 109, 48, 'dummy'),
(143234, 110, 48, 'dummy'),
(143235, 111, 48, 'dummy'),
(143236, 112, 48, 'dummy'),
(143237, 113, 48, 'dummy'),
(143238, 114, 48, 'dummy'),
(143239, 115, 48, 'dummy'),
(143240, 116, 48, 'dummy'),
(143241, 117, 48, 'dummy'),
(143242, 118, 48, 'dummy'),
(143243, 119, 48, 'dummy'),
(143244, 120, 48, 'dummy'),
(143245, 121, 48, 'dummy'),
(143246, 122, 48, 'dummy'),
(143247, 123, 48, 'dummy'),
(143248, 124, 48, 'dummy'),
(143249, 125, 48, 'dummy'),
(143250, 126, 48, 'dummy'),
(143251, 127, 48, 'dummy'),
(143252, 128, 48, 'dummy'),
(143253, 129, 48, 'dummy'),
(143254, 130, 48, 'dummy'),
(143255, 131, 48, 'dummy'),
(143256, 132, 48, 'dummy'),
(143257, 133, 48, 'dummy'),
(143258, 134, 48, 'dummy'),
(143259, 135, 48, 'dummy'),
(143260, 136, 48, 'dummy'),
(143261, 137, 48, 'dummy'),
(143262, 138, 48, 'dummy'),
(143263, 139, 48, 'dummy'),
(143264, 140, 48, 'dummy'),
(143265, 141, 48, 'dummy'),
(143266, 142, 48, 'dummy'),
(143267, 143, 48, 'dummy'),
(143268, 144, 48, 'dummy'),
(143269, 145, 48, 'dummy'),
(143270, 146, 48, 'dummy'),
(143271, 147, 48, 'dummy'),
(143272, 148, 48, 'dummy'),
(143273, 149, 48, 'dummy'),
(143274, 150, 48, 'dummy'),
(143275, 151, 48, 'dummy'),
(143276, 152, 48, 'dummy'),
(143277, 153, 48, 'dummy'),
(143278, 154, 48, 'dummy'),
(143279, 155, 48, 'dummy'),
(143280, 156, 48, 'dummy'),
(143281, 157, 48, 'dummy'),
(143282, 158, 48, 'dummy'),
(143283, 159, 48, 'dummy'),
(143284, 160, 48, 'dummy'),
(143285, 161, 48, 'dummy'),
(143286, 162, 48, 'dummy'),
(143287, 163, 48, 'dummy'),
(143288, 164, 48, 'dummy'),
(143289, 165, 48, 'dummy'),
(143290, 166, 48, 'dummy'),
(143291, 167, 48, 'dummy'),
(143292, 168, 48, 'dummy'),
(143293, 169, 48, 'dummy'),
(143294, 170, 48, 'dummy'),
(143295, 171, 48, 'dummy'),
(143296, 172, 48, 'dummy'),
(143297, 173, 48, 'dummy'),
(143298, 174, 48, 'dummy'),
(143299, 175, 48, 'dummy'),
(143300, 176, 48, 'dummy'),
(143301, 177, 48, 'dummy'),
(143302, 178, 48, 'dummy'),
(143303, 179, 48, 'dummy'),
(143304, 180, 48, 'dummy'),
(143305, 181, 48, 'dummy'),
(143306, 182, 48, 'dummy'),
(143307, 183, 48, 'dummy'),
(143308, 184, 48, 'dummy'),
(143309, 185, 48, 'dummy'),
(143310, 186, 48, 'dummy'),
(143311, 187, 48, 'dummy'),
(143312, 188, 48, 'dummy'),
(143313, 189, 48, 'dummy'),
(143314, 190, 48, 'dummy'),
(143315, 191, 48, 'dummy'),
(143316, 192, 48, 'dummy'),
(143317, 193, 48, 'dummy'),
(143318, 194, 48, 'dummy'),
(143319, 195, 48, 'dummy'),
(143320, 196, 48, 'dummy'),
(143321, 197, 48, 'dummy'),
(143322, 198, 48, 'dummy'),
(143323, 199, 48, 'dummy'),
(143324, 200, 48, 'dummy'),
(143325, 201, 48, 'dummy'),
(143326, 202, 48, 'dummy'),
(143327, 203, 48, 'dummy'),
(143328, 204, 48, 'dummy'),
(143329, 205, 48, 'dummy'),
(143330, 206, 48, 'dummy'),
(143331, 207, 48, 'dummy'),
(143332, 208, 48, 'dummy'),
(143333, 209, 48, 'dummy'),
(143334, 210, 48, 'dummy'),
(143335, 211, 48, 'dummy'),
(143336, 212, 48, 'dummy'),
(143337, 213, 48, 'dummy'),
(143338, 214, 48, 'dummy'),
(143339, 215, 48, 'dummy'),
(143340, 216, 48, 'dummy'),
(143341, 217, 48, 'dummy'),
(143342, 218, 48, 'dummy'),
(143343, 219, 48, 'dummy'),
(143344, 220, 48, 'dummy'),
(143345, 221, 48, 'dummy'),
(143346, 222, 48, 'dummy'),
(143347, 223, 48, 'dummy'),
(143348, 224, 48, 'dummy'),
(143349, 225, 48, 'dummy'),
(143350, 226, 48, 'dummy'),
(143351, 227, 48, 'dummy'),
(143352, 228, 48, 'dummy'),
(143353, 229, 48, 'dummy'),
(143354, 230, 48, 'dummy'),
(143355, 231, 48, 'dummy'),
(143356, 232, 48, 'dummy'),
(143357, 233, 48, 'dummy'),
(143358, 234, 48, 'dummy'),
(143359, 235, 48, 'dummy'),
(143360, 236, 48, 'dummy'),
(143361, 237, 48, 'dummy'),
(143362, 238, 48, 'dummy'),
(143363, 239, 48, 'dummy'),
(143364, 240, 48, 'dummy'),
(143365, 241, 48, 'dummy'),
(143366, 242, 48, 'dummy'),
(143367, 243, 48, 'dummy'),
(143368, 244, 48, 'dummy'),
(143369, 245, 48, 'dummy'),
(143370, 246, 48, 'dummy'),
(143371, 247, 48, 'dummy'),
(143372, 248, 48, 'dummy'),
(143373, 249, 48, 'dummy'),
(143374, 250, 48, 'dummy'),
(143375, 251, 48, 'dummy'),
(143376, 252, 48, 'dummy'),
(143377, 253, 48, 'dummy'),
(143378, 254, 48, 'dummy'),
(143379, 255, 48, 'dummy'),
(143380, 256, 48, 'dummy'),
(143381, 257, 48, 'dummy'),
(143382, 258, 48, 'dummy'),
(143383, 259, 48, 'dummy'),
(143384, 260, 48, 'dummy'),
(143385, 261, 48, 'dummy'),
(143386, 262, 48, 'dummy'),
(143387, 263, 48, 'dummy'),
(143388, 264, 48, 'dummy'),
(143389, 265, 48, 'dummy'),
(143390, 266, 48, 'dummy'),
(143391, 267, 48, 'dummy'),
(143392, 268, 48, 'dummy'),
(143393, 269, 48, 'dummy'),
(143394, 270, 48, 'dummy'),
(143395, 271, 48, 'dummy'),
(143396, 272, 48, 'dummy'),
(143397, 273, 48, 'dummy'),
(143398, 274, 48, 'dummy'),
(143399, 275, 48, 'dummy'),
(143400, 276, 48, 'dummy'),
(143401, 277, 48, 'dummy'),
(143402, 278, 48, 'dummy'),
(143403, 279, 48, 'dummy'),
(143404, 280, 48, 'dummy'),
(143405, 281, 48, 'dummy'),
(143406, 282, 48, 'dummy'),
(143407, 283, 48, 'dummy'),
(143408, 284, 48, 'dummy'),
(143409, 285, 48, 'dummy'),
(143410, 286, 48, 'dummy'),
(143411, 287, 48, 'dummy'),
(143412, 288, 48, 'dummy'),
(143413, 289, 48, 'dummy'),
(143414, 290, 48, 'dummy'),
(143415, 291, 48, 'dummy'),
(143416, 292, 48, 'dummy');
INSERT INTO `lang_definitions` VALUES
(143417, 293, 48, 'dummy'),
(143418, 294, 48, 'dummy'),
(143419, 295, 48, 'dummy'),
(143420, 296, 48, 'dummy'),
(143421, 297, 48, 'dummy'),
(143422, 298, 48, 'dummy'),
(143423, 299, 48, 'dummy'),
(143424, 300, 48, 'dummy'),
(143425, 301, 48, 'dummy'),
(143426, 302, 48, 'dummy'),
(143427, 303, 48, 'dummy'),
(143428, 304, 48, 'dummy'),
(143429, 305, 48, 'dummy'),
(143430, 306, 48, 'dummy'),
(143431, 307, 48, 'dummy'),
(143432, 308, 48, 'dummy'),
(143433, 309, 48, 'dummy'),
(143434, 310, 48, 'dummy'),
(143435, 311, 48, 'dummy'),
(143436, 312, 48, 'dummy'),
(143437, 313, 48, 'dummy'),
(143438, 314, 48, 'dummy'),
(143439, 315, 48, 'dummy'),
(143440, 316, 48, 'dummy'),
(143441, 317, 48, 'dummy'),
(143442, 318, 48, 'dummy'),
(143443, 319, 48, 'dummy'),
(143444, 320, 48, 'dummy'),
(143445, 321, 48, 'dummy'),
(143446, 322, 48, 'dummy'),
(143447, 323, 48, 'dummy'),
(143448, 324, 48, 'dummy'),
(143449, 325, 48, 'dummy'),
(143450, 326, 48, 'dummy'),
(143451, 327, 48, 'dummy'),
(143452, 328, 48, 'dummy'),
(143453, 329, 48, 'dummy'),
(143454, 330, 48, 'dummy'),
(143455, 331, 48, 'dummy'),
(143456, 332, 48, 'dummy'),
(143457, 333, 48, 'dummy'),
(143458, 334, 48, 'dummy'),
(143459, 335, 48, 'dummy'),
(143460, 336, 48, 'dummy'),
(143461, 337, 48, 'dummy'),
(143462, 338, 48, 'dummy'),
(143463, 339, 48, 'dummy'),
(143464, 340, 48, 'dummy'),
(143465, 341, 48, 'dummy'),
(143466, 342, 48, 'dummy'),
(143467, 343, 48, 'dummy'),
(143468, 344, 48, 'dummy'),
(143469, 345, 48, 'dummy'),
(143470, 346, 48, 'dummy'),
(143471, 347, 48, 'dummy'),
(143472, 348, 48, 'dummy'),
(143473, 349, 48, 'dummy'),
(143474, 350, 48, 'dummy'),
(143475, 351, 48, 'dummy'),
(143476, 352, 48, 'dummy'),
(143477, 353, 48, 'dummy'),
(143478, 354, 48, 'dummy'),
(143479, 355, 48, 'dummy'),
(143480, 356, 48, 'dummy'),
(143481, 357, 48, 'dummy'),
(143482, 358, 48, 'dummy'),
(143483, 359, 48, 'dummy'),
(143484, 360, 48, 'dummy'),
(143485, 361, 48, 'dummy'),
(143486, 362, 48, 'dummy'),
(143487, 363, 48, 'dummy'),
(143488, 364, 48, 'dummy'),
(143489, 365, 48, 'dummy'),
(143490, 366, 48, 'dummy'),
(143491, 367, 48, 'dummy'),
(143492, 368, 48, 'dummy'),
(143493, 369, 48, 'dummy'),
(143494, 370, 48, 'dummy'),
(143495, 371, 48, 'dummy'),
(143496, 372, 48, 'dummy'),
(143497, 373, 48, 'dummy'),
(143498, 374, 48, 'dummy'),
(143499, 375, 48, 'dummy'),
(143500, 376, 48, 'dummy'),
(143501, 377, 48, 'dummy'),
(143502, 378, 48, 'dummy'),
(143503, 379, 48, 'dummy'),
(143504, 380, 48, 'dummy'),
(143505, 381, 48, 'dummy'),
(143506, 382, 48, 'dummy'),
(143507, 383, 48, 'dummy'),
(143508, 384, 48, 'dummy'),
(143509, 385, 48, 'dummy'),
(143510, 386, 48, 'dummy'),
(143511, 387, 48, 'dummy'),
(143512, 388, 48, 'dummy'),
(143513, 389, 48, 'dummy'),
(143514, 390, 48, 'dummy'),
(143515, 391, 48, 'dummy'),
(143516, 392, 48, 'dummy'),
(143517, 393, 48, 'dummy'),
(143518, 394, 48, 'dummy'),
(143519, 395, 48, 'dummy'),
(143520, 396, 48, 'dummy'),
(143521, 397, 48, 'dummy'),
(143522, 398, 48, 'dummy'),
(143523, 399, 48, 'dummy'),
(143524, 400, 48, 'dummy'),
(143525, 401, 48, 'dummy'),
(143526, 402, 48, 'dummy'),
(143527, 403, 48, 'dummy'),
(143528, 404, 48, 'dummy'),
(143529, 405, 48, 'dummy'),
(143530, 406, 48, 'dummy'),
(143531, 407, 48, 'dummy'),
(143532, 408, 48, 'dummy'),
(143533, 409, 48, 'dummy'),
(143534, 410, 48, 'dummy'),
(143535, 411, 48, 'dummy'),
(143536, 412, 48, 'dummy'),
(143537, 413, 48, 'dummy'),
(143538, 414, 48, 'dummy'),
(143539, 415, 48, 'dummy'),
(143540, 416, 48, 'dummy'),
(143541, 417, 48, 'dummy'),
(143542, 418, 48, 'dummy'),
(143543, 419, 48, 'dummy'),
(143544, 420, 48, 'dummy'),
(143545, 421, 48, 'dummy'),
(143546, 422, 48, 'dummy'),
(143547, 423, 48, 'dummy'),
(143548, 424, 48, 'dummy'),
(143549, 425, 48, 'dummy'),
(143550, 426, 48, 'dummy'),
(143551, 427, 48, 'dummy'),
(143552, 428, 48, 'dummy'),
(143553, 429, 48, 'dummy'),
(143554, 430, 48, 'dummy'),
(143555, 431, 48, 'dummy'),
(143556, 432, 48, 'dummy'),
(143557, 433, 48, 'dummy'),
(143558, 434, 48, 'dummy'),
(143559, 435, 48, 'dummy'),
(143560, 436, 48, 'dummy'),
(143561, 437, 48, 'dummy'),
(143562, 438, 48, 'dummy'),
(143563, 439, 48, 'dummy'),
(143564, 440, 48, 'dummy'),
(143565, 441, 48, 'dummy'),
(143566, 442, 48, 'dummy'),
(143567, 443, 48, 'dummy'),
(143568, 444, 48, 'dummy'),
(143569, 445, 48, 'dummy'),
(143570, 446, 48, 'dummy'),
(143571, 447, 48, 'dummy'),
(143572, 448, 48, 'dummy'),
(143573, 449, 48, 'dummy'),
(143574, 450, 48, 'dummy'),
(143575, 451, 48, 'dummy'),
(143576, 452, 48, 'dummy'),
(143577, 453, 48, 'dummy'),
(143578, 454, 48, 'dummy'),
(143579, 455, 48, 'dummy'),
(143580, 456, 48, 'dummy'),
(143581, 457, 48, 'dummy'),
(143582, 458, 48, 'dummy'),
(143583, 459, 48, 'dummy'),
(143584, 460, 48, 'dummy'),
(143585, 461, 48, 'dummy'),
(143586, 462, 48, 'dummy'),
(143587, 463, 48, 'dummy'),
(143588, 464, 48, 'dummy'),
(143589, 465, 48, 'dummy'),
(143590, 466, 48, 'dummy'),
(143591, 467, 48, 'dummy'),
(143592, 468, 48, 'dummy'),
(143593, 469, 48, 'dummy'),
(143594, 470, 48, 'dummy'),
(143595, 471, 48, 'dummy'),
(143596, 472, 48, 'dummy'),
(143597, 473, 48, 'dummy'),
(143598, 474, 48, 'dummy'),
(143599, 475, 48, 'dummy'),
(143600, 476, 48, 'dummy'),
(143601, 477, 48, 'dummy'),
(143602, 478, 48, 'dummy'),
(143603, 479, 48, 'dummy'),
(143604, 480, 48, 'dummy'),
(143605, 481, 48, 'dummy'),
(143606, 482, 48, 'dummy'),
(143607, 483, 48, 'dummy'),
(143608, 484, 48, 'dummy'),
(143609, 485, 48, 'dummy'),
(143610, 486, 48, 'dummy'),
(143611, 487, 48, 'dummy'),
(143612, 488, 48, 'dummy'),
(143613, 489, 48, 'dummy'),
(143614, 490, 48, 'dummy'),
(143615, 491, 48, 'dummy'),
(143616, 492, 48, 'dummy'),
(143617, 493, 48, 'dummy'),
(143618, 494, 48, 'dummy'),
(143619, 495, 48, 'dummy'),
(143620, 496, 48, 'dummy'),
(143621, 497, 48, 'dummy'),
(143622, 498, 48, 'dummy'),
(143623, 499, 48, 'dummy'),
(143624, 500, 48, 'dummy'),
(143625, 501, 48, 'dummy'),
(143626, 502, 48, 'dummy'),
(143627, 503, 48, 'dummy'),
(143628, 504, 48, 'dummy'),
(143629, 505, 48, 'dummy'),
(143630, 506, 48, 'dummy'),
(143631, 507, 48, 'dummy'),
(143632, 508, 48, 'dummy'),
(143633, 509, 48, 'dummy'),
(143634, 510, 48, 'dummy'),
(143635, 511, 48, 'dummy'),
(143636, 512, 48, 'dummy'),
(143637, 513, 48, 'dummy'),
(143638, 514, 48, 'dummy'),
(143639, 515, 48, 'dummy'),
(143640, 516, 48, 'dummy'),
(143641, 517, 48, 'dummy'),
(143642, 518, 48, 'dummy'),
(143643, 519, 48, 'dummy'),
(143644, 520, 48, 'dummy'),
(143645, 521, 48, 'dummy'),
(143646, 522, 48, 'dummy'),
(143647, 523, 48, 'dummy'),
(143648, 524, 48, 'dummy'),
(143649, 525, 48, 'dummy'),
(143650, 526, 48, 'dummy'),
(143651, 527, 48, 'dummy'),
(143652, 528, 48, 'dummy'),
(143653, 529, 48, 'dummy'),
(143654, 530, 48, 'dummy'),
(143655, 531, 48, 'dummy'),
(143656, 532, 48, 'dummy'),
(143657, 533, 48, 'dummy'),
(143658, 534, 48, 'dummy'),
(143659, 535, 48, 'dummy'),
(143660, 536, 48, 'dummy'),
(143661, 537, 48, 'dummy'),
(143662, 538, 48, 'dummy'),
(143663, 539, 48, 'dummy'),
(143664, 540, 48, 'dummy'),
(143665, 541, 48, 'dummy'),
(143666, 542, 48, 'dummy'),
(143667, 543, 48, 'dummy'),
(143668, 544, 48, 'dummy'),
(143669, 545, 48, 'dummy'),
(143670, 546, 48, 'dummy'),
(143671, 547, 48, 'dummy'),
(143672, 548, 48, 'dummy'),
(143673, 549, 48, 'dummy'),
(143674, 550, 48, 'dummy'),
(143675, 551, 48, 'dummy'),
(143676, 552, 48, 'dummy'),
(143677, 553, 48, 'dummy'),
(143678, 554, 48, 'dummy'),
(143679, 555, 48, 'dummy'),
(143680, 556, 48, 'dummy'),
(143681, 557, 48, 'dummy'),
(143682, 558, 48, 'dummy'),
(143683, 559, 48, 'dummy'),
(143684, 560, 48, 'dummy'),
(143685, 561, 48, 'dummy'),
(143686, 562, 48, 'dummy'),
(143687, 563, 48, 'dummy'),
(143688, 564, 48, 'dummy'),
(143689, 565, 48, 'dummy'),
(143690, 566, 48, 'dummy'),
(143691, 567, 48, 'dummy'),
(143692, 568, 48, 'dummy'),
(143693, 569, 48, 'dummy'),
(143694, 570, 48, 'dummy'),
(143695, 571, 48, 'dummy'),
(143696, 572, 48, 'dummy'),
(143697, 573, 48, 'dummy'),
(143698, 574, 48, 'dummy'),
(143699, 575, 48, 'dummy'),
(143700, 576, 48, 'dummy'),
(143701, 577, 48, 'dummy'),
(143702, 578, 48, 'dummy'),
(143703, 579, 48, 'dummy'),
(143704, 580, 48, 'dummy'),
(143705, 581, 48, 'dummy'),
(143706, 582, 48, 'dummy'),
(143707, 583, 48, 'dummy'),
(143708, 584, 48, 'dummy'),
(143709, 585, 48, 'dummy'),
(143710, 586, 48, 'dummy'),
(143711, 587, 48, 'dummy'),
(143712, 588, 48, 'dummy'),
(143713, 589, 48, 'dummy'),
(143714, 590, 48, 'dummy'),
(143715, 591, 48, 'dummy'),
(143716, 592, 48, 'dummy'),
(143717, 593, 48, 'dummy'),
(143718, 594, 48, 'dummy'),
(143719, 595, 48, 'dummy'),
(143720, 596, 48, 'dummy'),
(143721, 597, 48, 'dummy'),
(143722, 598, 48, 'dummy'),
(143723, 599, 48, 'dummy'),
(143724, 600, 48, 'dummy'),
(143725, 601, 48, 'dummy'),
(143726, 602, 48, 'dummy'),
(143727, 603, 48, 'dummy'),
(143728, 604, 48, 'dummy'),
(143729, 605, 48, 'dummy'),
(143730, 606, 48, 'dummy'),
(143731, 607, 48, 'dummy'),
(143732, 608, 48, 'dummy'),
(143733, 609, 48, 'dummy'),
(143734, 610, 48, 'dummy'),
(143735, 611, 48, 'dummy'),
(143736, 612, 48, 'dummy'),
(143737, 613, 48, 'dummy'),
(143738, 614, 48, 'dummy'),
(143739, 615, 48, 'dummy'),
(143740, 616, 48, 'dummy'),
(143741, 617, 48, 'dummy'),
(143742, 618, 48, 'dummy'),
(143743, 619, 48, 'dummy'),
(143744, 620, 48, 'dummy'),
(143745, 621, 48, 'dummy'),
(143746, 622, 48, 'dummy'),
(143747, 623, 48, 'dummy'),
(143748, 624, 48, 'dummy'),
(143749, 625, 48, 'dummy'),
(143750, 626, 48, 'dummy'),
(143751, 627, 48, 'dummy'),
(143752, 628, 48, 'dummy'),
(143753, 629, 48, 'dummy'),
(143754, 630, 48, 'dummy'),
(143755, 631, 48, 'dummy'),
(143756, 632, 48, 'dummy'),
(143757, 633, 48, 'dummy'),
(143758, 634, 48, 'dummy'),
(143759, 635, 48, 'dummy'),
(143760, 636, 48, 'dummy'),
(143761, 637, 48, 'dummy'),
(143762, 638, 48, 'dummy'),
(143763, 639, 48, 'dummy'),
(143764, 640, 48, 'dummy'),
(143765, 641, 48, 'dummy'),
(143766, 642, 48, 'dummy'),
(143767, 643, 48, 'dummy'),
(143768, 644, 48, 'dummy'),
(143769, 645, 48, 'dummy'),
(143770, 646, 48, 'dummy'),
(143771, 647, 48, 'dummy'),
(143772, 648, 48, 'dummy'),
(143773, 649, 48, 'dummy'),
(143774, 650, 48, 'dummy'),
(143775, 651, 48, 'dummy'),
(143776, 652, 48, 'dummy'),
(143777, 653, 48, 'dummy'),
(143778, 654, 48, 'dummy'),
(143779, 655, 48, 'dummy'),
(143780, 656, 48, 'dummy'),
(143781, 657, 48, 'dummy'),
(143782, 658, 48, 'dummy'),
(143783, 659, 48, 'dummy'),
(143784, 660, 48, 'dummy'),
(143785, 661, 48, 'dummy'),
(143786, 662, 48, 'dummy'),
(143787, 663, 48, 'dummy'),
(143788, 664, 48, 'dummy'),
(143789, 665, 48, 'dummy'),
(143790, 666, 48, 'dummy'),
(143791, 667, 48, 'dummy'),
(143792, 668, 48, 'dummy'),
(143793, 669, 48, 'dummy'),
(143794, 670, 48, 'dummy'),
(143795, 671, 48, 'dummy'),
(143796, 672, 48, 'dummy'),
(143797, 673, 48, 'dummy'),
(143798, 674, 48, 'dummy'),
(143799, 675, 48, 'dummy'),
(143800, 676, 48, 'dummy'),
(143801, 677, 48, 'dummy'),
(143802, 678, 48, 'dummy'),
(143803, 679, 48, 'dummy'),
(143804, 680, 48, 'dummy'),
(143805, 681, 48, 'dummy'),
(143806, 682, 48, 'dummy'),
(143807, 683, 48, 'dummy'),
(143808, 684, 48, 'dummy'),
(143809, 685, 48, 'dummy'),
(143810, 686, 48, 'dummy'),
(143811, 687, 48, 'dummy'),
(143812, 688, 48, 'dummy'),
(143813, 689, 48, 'dummy'),
(143814, 690, 48, 'dummy'),
(143815, 691, 48, 'dummy'),
(143816, 692, 48, 'dummy'),
(143817, 693, 48, 'dummy'),
(143818, 694, 48, 'dummy'),
(143819, 695, 48, 'dummy'),
(143820, 696, 48, 'dummy'),
(143821, 697, 48, 'dummy'),
(143822, 698, 48, 'dummy'),
(143823, 699, 48, 'dummy'),
(143824, 700, 48, 'dummy'),
(143825, 701, 48, 'dummy'),
(143826, 702, 48, 'dummy'),
(143827, 703, 48, 'dummy'),
(143828, 704, 48, 'dummy'),
(143829, 705, 48, 'dummy'),
(143830, 706, 48, 'dummy'),
(143831, 707, 48, 'dummy'),
(143832, 708, 48, 'dummy'),
(143833, 709, 48, 'dummy'),
(143834, 710, 48, 'dummy'),
(143835, 711, 48, 'dummy'),
(143836, 712, 48, 'dummy'),
(143837, 713, 48, 'dummy'),
(143838, 714, 48, 'dummy'),
(143839, 715, 48, 'dummy'),
(143840, 716, 48, 'dummy'),
(143841, 717, 48, 'dummy'),
(143842, 718, 48, 'dummy'),
(143843, 719, 48, 'dummy'),
(143844, 720, 48, 'dummy'),
(143845, 721, 48, 'dummy'),
(143846, 722, 48, 'dummy'),
(143847, 723, 48, 'dummy'),
(143848, 724, 48, 'dummy'),
(143849, 725, 48, 'dummy'),
(143850, 726, 48, 'dummy'),
(143851, 727, 48, 'dummy'),
(143852, 728, 48, 'dummy'),
(143853, 729, 48, 'dummy'),
(143854, 730, 48, 'dummy'),
(143855, 731, 48, 'dummy'),
(143856, 732, 48, 'dummy'),
(143857, 733, 48, 'dummy'),
(143858, 734, 48, 'dummy'),
(143859, 735, 48, 'dummy'),
(143860, 736, 48, 'dummy'),
(143861, 737, 48, 'dummy'),
(143862, 738, 48, 'dummy'),
(143863, 739, 48, 'dummy'),
(143864, 740, 48, 'dummy'),
(143865, 741, 48, 'dummy'),
(143866, 742, 48, 'dummy'),
(143867, 743, 48, 'dummy'),
(143868, 744, 48, 'dummy'),
(143869, 745, 48, 'dummy'),
(143870, 746, 48, 'dummy'),
(143871, 747, 48, 'dummy'),
(143872, 748, 48, 'dummy'),
(143873, 749, 48, 'dummy'),
(143874, 750, 48, 'dummy'),
(143875, 751, 48, 'dummy'),
(143876, 752, 48, 'dummy'),
(143877, 753, 48, 'dummy'),
(143878, 754, 48, 'dummy'),
(143879, 755, 48, 'dummy'),
(143880, 756, 48, 'dummy'),
(143881, 757, 48, 'dummy'),
(143882, 758, 48, 'dummy'),
(143883, 759, 48, 'dummy'),
(143884, 760, 48, 'dummy'),
(143885, 761, 48, 'dummy'),
(143886, 762, 48, 'dummy'),
(143887, 763, 48, 'dummy'),
(143888, 764, 48, 'dummy'),
(143889, 765, 48, 'dummy'),
(143890, 766, 48, 'dummy'),
(143891, 767, 48, 'dummy'),
(143892, 768, 48, 'dummy'),
(143893, 769, 48, 'dummy'),
(143894, 770, 48, 'dummy'),
(143895, 771, 48, 'dummy'),
(143896, 772, 48, 'dummy'),
(143897, 773, 48, 'dummy'),
(143898, 774, 48, 'dummy'),
(143899, 775, 48, 'dummy'),
(143900, 776, 48, 'dummy'),
(143901, 777, 48, 'dummy'),
(143902, 778, 48, 'dummy'),
(143903, 779, 48, 'dummy'),
(143904, 780, 48, 'dummy'),
(143905, 781, 48, 'dummy'),
(143906, 782, 48, 'dummy'),
(143907, 783, 48, 'dummy'),
(143908, 784, 48, 'dummy'),
(143909, 785, 48, 'dummy'),
(143910, 786, 48, 'dummy'),
(143911, 787, 48, 'dummy'),
(143912, 788, 48, 'dummy'),
(143913, 789, 48, 'dummy'),
(143914, 790, 48, 'dummy'),
(143915, 791, 48, 'dummy'),
(143916, 792, 48, 'dummy'),
(143917, 793, 48, 'dummy'),
(143918, 794, 48, 'dummy'),
(143919, 795, 48, 'dummy'),
(143920, 796, 48, 'dummy'),
(143921, 797, 48, 'dummy'),
(143922, 798, 48, 'dummy'),
(143923, 799, 48, 'dummy'),
(143924, 800, 48, 'dummy'),
(143925, 801, 48, 'dummy'),
(143926, 802, 48, 'dummy'),
(143927, 803, 48, 'dummy'),
(143928, 804, 48, 'dummy'),
(143929, 805, 48, 'dummy'),
(143930, 806, 48, 'dummy'),
(143931, 807, 48, 'dummy'),
(143932, 808, 48, 'dummy'),
(143933, 809, 48, 'dummy'),
(143934, 810, 48, 'dummy'),
(143935, 811, 48, 'dummy'),
(143936, 812, 48, 'dummy'),
(143937, 813, 48, 'dummy'),
(143938, 814, 48, 'dummy'),
(143939, 815, 48, 'dummy'),
(143940, 816, 48, 'dummy'),
(143941, 817, 48, 'dummy'),
(143942, 818, 48, 'dummy'),
(143943, 819, 48, 'dummy'),
(143944, 820, 48, 'dummy'),
(143945, 821, 48, 'dummy'),
(143946, 822, 48, 'dummy'),
(143947, 823, 48, 'dummy'),
(143948, 824, 48, 'dummy'),
(143949, 825, 48, 'dummy'),
(143950, 826, 48, 'dummy'),
(143951, 827, 48, 'dummy'),
(143952, 828, 48, 'dummy'),
(143953, 829, 48, 'dummy'),
(143954, 830, 48, 'dummy'),
(143955, 831, 48, 'dummy'),
(143956, 832, 48, 'dummy'),
(143957, 833, 48, 'dummy'),
(143958, 834, 48, 'dummy'),
(143959, 835, 48, 'dummy'),
(143960, 836, 48, 'dummy'),
(143961, 837, 48, 'dummy'),
(143962, 838, 48, 'dummy'),
(143963, 839, 48, 'dummy'),
(143964, 840, 48, 'dummy'),
(143965, 841, 48, 'dummy'),
(143966, 842, 48, 'dummy'),
(143967, 843, 48, 'dummy'),
(143968, 844, 48, 'dummy'),
(143969, 845, 48, 'dummy'),
(143970, 846, 48, 'dummy'),
(143971, 847, 48, 'dummy'),
(143972, 848, 48, 'dummy'),
(143973, 849, 48, 'dummy'),
(143974, 850, 48, 'dummy'),
(143975, 851, 48, 'dummy'),
(143976, 852, 48, 'dummy'),
(143977, 853, 48, 'dummy'),
(143978, 854, 48, 'dummy'),
(143979, 855, 48, 'dummy'),
(143980, 856, 48, 'dummy'),
(143981, 857, 48, 'dummy'),
(143982, 858, 48, 'dummy'),
(143983, 859, 48, 'dummy'),
(143984, 860, 48, 'dummy'),
(143985, 861, 48, 'dummy'),
(143986, 862, 48, 'dummy'),
(143987, 863, 48, 'dummy'),
(143988, 864, 48, 'dummy'),
(143989, 865, 48, 'dummy'),
(143990, 866, 48, 'dummy'),
(143991, 867, 48, 'dummy'),
(143992, 868, 48, 'dummy'),
(143993, 869, 48, 'dummy'),
(143994, 870, 48, 'dummy'),
(143995, 871, 48, 'dummy'),
(143996, 872, 48, 'dummy'),
(143997, 873, 48, 'dummy'),
(143998, 874, 48, 'dummy'),
(143999, 875, 48, 'dummy'),
(144000, 876, 48, 'dummy'),
(144001, 877, 48, 'dummy'),
(144002, 878, 48, 'dummy'),
(144003, 879, 48, 'dummy'),
(144004, 880, 48, 'dummy'),
(144005, 881, 48, 'dummy'),
(144006, 882, 48, 'dummy'),
(144007, 883, 48, 'dummy'),
(144008, 884, 48, 'dummy'),
(144009, 885, 48, 'dummy'),
(144010, 886, 48, 'dummy'),
(144011, 887, 48, 'dummy'),
(144012, 888, 48, 'dummy'),
(144013, 889, 48, 'dummy'),
(144014, 890, 48, 'dummy'),
(144015, 891, 48, 'dummy'),
(144016, 892, 48, 'dummy'),
(144017, 893, 48, 'dummy'),
(144018, 894, 48, 'dummy'),
(144019, 895, 48, 'dummy'),
(144020, 896, 48, 'dummy'),
(144021, 897, 48, 'dummy'),
(144022, 898, 48, 'dummy'),
(144023, 899, 48, 'dummy'),
(144024, 900, 48, 'dummy'),
(144025, 901, 48, 'dummy'),
(144026, 902, 48, 'dummy'),
(144027, 903, 48, 'dummy'),
(144028, 904, 48, 'dummy'),
(144029, 905, 48, 'dummy'),
(144030, 906, 48, 'dummy'),
(144031, 907, 48, 'dummy'),
(144032, 908, 48, 'dummy'),
(144033, 909, 48, 'dummy'),
(144034, 910, 48, 'dummy'),
(144035, 911, 48, 'dummy'),
(144036, 912, 48, 'dummy'),
(144037, 913, 48, 'dummy'),
(144038, 914, 48, 'dummy'),
(144039, 915, 48, 'dummy'),
(144040, 916, 48, 'dummy'),
(144041, 917, 48, 'dummy'),
(144042, 918, 48, 'dummy'),
(144043, 919, 48, 'dummy'),
(144044, 920, 48, 'dummy'),
(144045, 921, 48, 'dummy'),
(144046, 922, 48, 'dummy'),
(144047, 923, 48, 'dummy'),
(144048, 924, 48, 'dummy'),
(144049, 925, 48, 'dummy'),
(144050, 926, 48, 'dummy'),
(144051, 927, 48, 'dummy'),
(144052, 928, 48, 'dummy'),
(144053, 929, 48, 'dummy'),
(144054, 930, 48, 'dummy'),
(144055, 931, 48, 'dummy'),
(144056, 932, 48, 'dummy'),
(144057, 933, 48, 'dummy'),
(144058, 934, 48, 'dummy'),
(144059, 935, 48, 'dummy'),
(144060, 936, 48, 'dummy'),
(144061, 937, 48, 'dummy'),
(144062, 938, 48, 'dummy'),
(144063, 939, 48, 'dummy'),
(144064, 940, 48, 'dummy'),
(144065, 941, 48, 'dummy'),
(144066, 942, 48, 'dummy'),
(144067, 943, 48, 'dummy'),
(144068, 944, 48, 'dummy'),
(144069, 945, 48, 'dummy'),
(144070, 946, 48, 'dummy'),
(144071, 947, 48, 'dummy'),
(144072, 948, 48, 'dummy'),
(144073, 949, 48, 'dummy'),
(144074, 950, 48, 'dummy'),
(144075, 951, 48, 'dummy'),
(144076, 952, 48, 'dummy'),
(144077, 953, 48, 'dummy'),
(144078, 954, 48, 'dummy'),
(144079, 955, 48, 'dummy'),
(144080, 956, 48, 'dummy'),
(144081, 957, 48, 'dummy'),
(144082, 958, 48, 'dummy'),
(144083, 959, 48, 'dummy'),
(144084, 960, 48, 'dummy'),
(144085, 961, 48, 'dummy'),
(144086, 962, 48, 'dummy'),
(144087, 963, 48, 'dummy'),
(144088, 964, 48, 'dummy'),
(144089, 965, 48, 'dummy'),
(144090, 966, 48, 'dummy'),
(144091, 967, 48, 'dummy'),
(144092, 968, 48, 'dummy'),
(144093, 969, 48, 'dummy'),
(144094, 970, 48, 'dummy'),
(144095, 971, 48, 'dummy'),
(144096, 972, 48, 'dummy'),
(144097, 973, 48, 'dummy'),
(144098, 974, 48, 'dummy'),
(144099, 975, 48, 'dummy'),
(144100, 976, 48, 'dummy'),
(144101, 977, 48, 'dummy'),
(144102, 978, 48, 'dummy'),
(144103, 979, 48, 'dummy'),
(144104, 980, 48, 'dummy'),
(144105, 981, 48, 'dummy'),
(144106, 982, 48, 'dummy'),
(144107, 983, 48, 'dummy'),
(144108, 984, 48, 'dummy'),
(144109, 985, 48, 'dummy'),
(144110, 986, 48, 'dummy'),
(144111, 987, 48, 'dummy'),
(144112, 988, 48, 'dummy'),
(144113, 989, 48, 'dummy'),
(144114, 990, 48, 'dummy'),
(144115, 991, 48, 'dummy'),
(144116, 992, 48, 'dummy'),
(144117, 993, 48, 'dummy'),
(144118, 994, 48, 'dummy'),
(144119, 995, 48, 'dummy'),
(144120, 996, 48, 'dummy'),
(144121, 997, 48, 'dummy'),
(144122, 998, 48, 'dummy'),
(144123, 999, 48, 'dummy'),
(144124, 1000, 48, 'dummy'),
(144125, 1001, 48, 'dummy'),
(144126, 1002, 48, 'dummy'),
(144127, 1003, 48, 'dummy'),
(144128, 1004, 48, 'dummy'),
(144129, 1005, 48, 'dummy'),
(144130, 1006, 48, 'dummy'),
(144131, 1007, 48, 'dummy'),
(144132, 1008, 48, 'dummy'),
(144133, 1009, 48, 'dummy'),
(144134, 1010, 48, 'dummy'),
(144135, 1011, 48, 'dummy'),
(144136, 1012, 48, 'dummy'),
(144137, 1013, 48, 'dummy'),
(144138, 1014, 48, 'dummy'),
(144139, 1015, 48, 'dummy'),
(144140, 1016, 48, 'dummy'),
(144141, 1017, 48, 'dummy'),
(144142, 1018, 48, 'dummy'),
(144143, 1019, 48, 'dummy'),
(144144, 1020, 48, 'dummy'),
(144145, 1021, 48, 'dummy'),
(144146, 1022, 48, 'dummy'),
(144147, 1023, 48, 'dummy'),
(144148, 1024, 48, 'dummy'),
(144149, 1025, 48, 'dummy'),
(144150, 1026, 48, 'dummy'),
(144151, 1027, 48, 'dummy'),
(144152, 1028, 48, 'dummy'),
(144153, 1029, 48, 'dummy'),
(144154, 1030, 48, 'dummy'),
(144155, 1031, 48, 'dummy'),
(144156, 1032, 48, 'dummy'),
(144157, 1033, 48, 'dummy'),
(144158, 1034, 48, 'dummy'),
(144159, 1035, 48, 'dummy'),
(144160, 1036, 48, 'dummy'),
(144161, 1037, 48, 'dummy'),
(144162, 1038, 48, 'dummy'),
(144163, 1039, 48, 'dummy'),
(144164, 1040, 48, 'dummy'),
(144165, 1041, 48, 'dummy'),
(144166, 1042, 48, 'dummy'),
(144167, 1043, 48, 'dummy'),
(144168, 1044, 48, 'dummy'),
(144169, 1045, 48, 'dummy'),
(144170, 1046, 48, 'dummy'),
(144171, 1047, 48, 'dummy'),
(144172, 1048, 48, 'dummy'),
(144173, 1049, 48, 'dummy'),
(144174, 1050, 48, 'dummy'),
(144175, 1051, 48, 'dummy'),
(144176, 1052, 48, 'dummy'),
(144177, 1053, 48, 'dummy'),
(144178, 1054, 48, 'dummy'),
(144179, 1055, 48, 'dummy'),
(144180, 1056, 48, 'dummy'),
(144181, 1057, 48, 'dummy'),
(144182, 1058, 48, 'dummy'),
(144183, 1059, 48, 'dummy'),
(144184, 1060, 48, 'dummy'),
(144185, 1061, 48, 'dummy'),
(144186, 1062, 48, 'dummy'),
(144187, 1063, 48, 'dummy'),
(144188, 1064, 48, 'dummy'),
(144189, 1065, 48, 'dummy'),
(144190, 1066, 48, 'dummy'),
(144191, 1067, 48, 'dummy'),
(144192, 1068, 48, 'dummy'),
(144193, 1069, 48, 'dummy'),
(144194, 1070, 48, 'dummy'),
(144195, 1071, 48, 'dummy'),
(144196, 1072, 48, 'dummy'),
(144197, 1073, 48, 'dummy'),
(144198, 1074, 48, 'dummy'),
(144199, 1075, 48, 'dummy'),
(144200, 1076, 48, 'dummy'),
(144201, 1077, 48, 'dummy'),
(144202, 1078, 48, 'dummy'),
(144203, 1079, 48, 'dummy'),
(144204, 1080, 48, 'dummy'),
(144205, 1081, 48, 'dummy'),
(144206, 1082, 48, 'dummy'),
(144207, 1083, 48, 'dummy'),
(144208, 1084, 48, 'dummy'),
(144209, 1085, 48, 'dummy'),
(144210, 1086, 48, 'dummy'),
(144211, 1087, 48, 'dummy'),
(144212, 1088, 48, 'dummy'),
(144213, 1089, 48, 'dummy'),
(144214, 1090, 48, 'dummy'),
(144215, 1091, 48, 'dummy'),
(144216, 1092, 48, 'dummy'),
(144217, 1093, 48, 'dummy'),
(144218, 1094, 48, 'dummy'),
(144219, 1095, 48, 'dummy'),
(144220, 1096, 48, 'dummy'),
(144221, 1097, 48, 'dummy'),
(144222, 1098, 48, 'dummy'),
(144223, 1099, 48, 'dummy'),
(144224, 1100, 48, 'dummy'),
(144225, 1101, 48, 'dummy'),
(144226, 1102, 48, 'dummy'),
(144227, 1103, 48, 'dummy'),
(144228, 1104, 48, 'dummy'),
(144229, 1105, 48, 'dummy'),
(144230, 1106, 48, 'dummy'),
(144231, 1107, 48, 'dummy'),
(144232, 1108, 48, 'dummy'),
(144233, 1109, 48, 'dummy'),
(144234, 1110, 48, 'dummy'),
(144235, 1111, 48, 'dummy'),
(144236, 1112, 48, 'dummy'),
(144237, 1113, 48, 'dummy'),
(144238, 1114, 48, 'dummy'),
(144239, 1115, 48, 'dummy'),
(144240, 1116, 48, 'dummy'),
(144241, 1117, 48, 'dummy'),
(144242, 1118, 48, 'dummy'),
(144243, 1119, 48, 'dummy'),
(144244, 1120, 48, 'dummy'),
(144245, 1121, 48, 'dummy'),
(144246, 1122, 48, 'dummy'),
(144247, 1123, 48, 'dummy'),
(144248, 1124, 48, 'dummy'),
(144249, 1125, 48, 'dummy'),
(144250, 1126, 48, 'dummy'),
(144251, 1127, 48, 'dummy'),
(144252, 1128, 48, 'dummy'),
(144253, 1129, 48, 'dummy'),
(144254, 1130, 48, 'dummy'),
(144255, 1131, 48, 'dummy'),
(144256, 1132, 48, 'dummy'),
(144257, 1133, 48, 'dummy'),
(144258, 1134, 48, 'dummy'),
(144259, 1135, 48, 'dummy'),
(144260, 1136, 48, 'dummy'),
(144261, 1137, 48, 'dummy'),
(144262, 1138, 48, 'dummy'),
(144263, 1139, 48, 'dummy'),
(144264, 1140, 48, 'dummy'),
(144265, 1141, 48, 'dummy'),
(144266, 1142, 48, 'dummy'),
(144267, 1143, 48, 'dummy'),
(144268, 1144, 48, 'dummy'),
(144269, 1145, 48, 'dummy'),
(144270, 1146, 48, 'dummy'),
(144271, 1147, 48, 'dummy'),
(144272, 1148, 48, 'dummy'),
(144273, 1149, 48, 'dummy'),
(144274, 1150, 48, 'dummy'),
(144275, 1151, 48, 'dummy'),
(144276, 1152, 48, 'dummy'),
(144277, 1153, 48, 'dummy'),
(144278, 1154, 48, 'dummy'),
(144279, 1155, 48, 'dummy'),
(144280, 1156, 48, 'dummy'),
(144281, 1157, 48, 'dummy'),
(144282, 1158, 48, 'dummy'),
(144283, 1159, 48, 'dummy'),
(144284, 1160, 48, 'dummy'),
(144285, 1161, 48, 'dummy'),
(144286, 1162, 48, 'dummy'),
(144287, 1163, 48, 'dummy'),
(144288, 1164, 48, 'dummy'),
(144289, 1165, 48, 'dummy'),
(144290, 1166, 48, 'dummy'),
(144291, 1167, 48, 'dummy'),
(144292, 1168, 48, 'dummy'),
(144293, 1169, 48, 'dummy'),
(144294, 1170, 48, 'dummy'),
(144295, 1171, 48, 'dummy'),
(144296, 1172, 48, 'dummy'),
(144297, 1173, 48, 'dummy'),
(144298, 1174, 48, 'dummy'),
(144299, 1175, 48, 'dummy'),
(144300, 1176, 48, 'dummy'),
(144301, 1177, 48, 'dummy'),
(144302, 1178, 48, 'dummy'),
(144303, 1179, 48, 'dummy'),
(144304, 1180, 48, 'dummy'),
(144305, 1181, 48, 'dummy'),
(144306, 1182, 48, 'dummy'),
(144307, 1183, 48, 'dummy'),
(144308, 1184, 48, 'dummy'),
(144309, 1185, 48, 'dummy'),
(144310, 1186, 48, 'dummy'),
(144311, 1187, 48, 'dummy'),
(144312, 1188, 48, 'dummy'),
(144313, 1189, 48, 'dummy'),
(144314, 1190, 48, 'dummy'),
(144315, 1191, 48, 'dummy'),
(144316, 1192, 48, 'dummy'),
(144317, 1193, 48, 'dummy'),
(144318, 1194, 48, 'dummy'),
(144319, 1195, 48, 'dummy'),
(144320, 1196, 48, 'dummy'),
(144321, 1197, 48, 'dummy'),
(144322, 1198, 48, 'dummy'),
(144323, 1199, 48, 'dummy'),
(144324, 1200, 48, 'dummy'),
(144325, 1201, 48, 'dummy'),
(144326, 1202, 48, 'dummy'),
(144327, 1203, 48, 'dummy'),
(144328, 1204, 48, 'dummy'),
(144329, 1205, 48, 'dummy'),
(144330, 1206, 48, 'dummy'),
(144331, 1207, 48, 'dummy'),
(144332, 1208, 48, 'dummy'),
(144333, 1209, 48, 'dummy'),
(144334, 1210, 48, 'dummy'),
(144335, 1211, 48, 'dummy'),
(144336, 1212, 48, 'dummy'),
(144337, 1213, 48, 'dummy'),
(144338, 1214, 48, 'dummy'),
(144339, 1215, 48, 'dummy'),
(144340, 1216, 48, 'dummy'),
(144341, 1217, 48, 'dummy'),
(144342, 1218, 48, 'dummy'),
(144343, 1219, 48, 'dummy'),
(144344, 1220, 48, 'dummy'),
(144345, 1221, 48, 'dummy'),
(144346, 1222, 48, 'dummy'),
(144347, 1223, 48, 'dummy'),
(144348, 1224, 48, 'dummy'),
(144349, 1225, 48, 'dummy'),
(144350, 1226, 48, 'dummy'),
(144351, 1227, 48, 'dummy'),
(144352, 1228, 48, 'dummy'),
(144353, 1229, 48, 'dummy'),
(144354, 1230, 48, 'dummy'),
(144355, 1231, 48, 'dummy'),
(144356, 1232, 48, 'dummy'),
(144357, 1233, 48, 'dummy'),
(144358, 1234, 48, 'dummy'),
(144359, 1235, 48, 'dummy'),
(144360, 1236, 48, 'dummy'),
(144361, 1237, 48, 'dummy'),
(144362, 1238, 48, 'dummy'),
(144363, 1239, 48, 'dummy'),
(144364, 1240, 48, 'dummy'),
(144365, 1241, 48, 'dummy'),
(144366, 1242, 48, 'dummy'),
(144367, 1243, 48, 'dummy'),
(144368, 1244, 48, 'dummy'),
(144369, 1245, 48, 'dummy'),
(144370, 1246, 48, 'dummy'),
(144371, 1247, 48, 'dummy'),
(144372, 1248, 48, 'dummy'),
(144373, 1249, 48, 'dummy'),
(144374, 1250, 48, 'dummy'),
(144375, 1251, 48, 'dummy'),
(144376, 1252, 48, 'dummy'),
(144377, 1253, 48, 'dummy'),
(144378, 1254, 48, 'dummy'),
(144379, 1255, 48, 'dummy'),
(144380, 1256, 48, 'dummy'),
(144381, 1257, 48, 'dummy'),
(144382, 1258, 48, 'dummy'),
(144383, 1259, 48, 'dummy'),
(144384, 1260, 48, 'dummy'),
(144385, 1261, 48, 'dummy'),
(144386, 1262, 48, 'dummy'),
(144387, 1263, 48, 'dummy'),
(144388, 1264, 48, 'dummy'),
(144389, 1265, 48, 'dummy'),
(144390, 1266, 48, 'dummy'),
(144391, 1267, 48, 'dummy'),
(144392, 1268, 48, 'dummy'),
(144393, 1269, 48, 'dummy'),
(144394, 1270, 48, 'dummy'),
(144395, 1271, 48, 'dummy'),
(144396, 1272, 48, 'dummy'),
(144397, 1273, 48, 'dummy'),
(144398, 1274, 48, 'dummy'),
(144399, 1275, 48, 'dummy'),
(144400, 1276, 48, 'dummy'),
(144401, 1277, 48, 'dummy'),
(144402, 1278, 48, 'dummy'),
(144403, 1279, 48, 'dummy'),
(144404, 1280, 48, 'dummy'),
(144405, 1281, 48, 'dummy'),
(144406, 1282, 48, 'dummy'),
(144407, 1283, 48, 'dummy'),
(144408, 1284, 48, 'dummy'),
(144409, 1285, 48, 'dummy'),
(144410, 1286, 48, 'dummy'),
(144411, 1287, 48, 'dummy'),
(144412, 1288, 48, 'dummy'),
(144413, 1289, 48, 'dummy'),
(144414, 1290, 48, 'dummy'),
(144415, 1291, 48, 'dummy'),
(144416, 1292, 48, 'dummy'),
(144417, 1293, 48, 'dummy'),
(144418, 1294, 48, 'dummy'),
(144419, 1295, 48, 'dummy'),
(144420, 1296, 48, 'dummy'),
(144421, 1297, 48, 'dummy'),
(144422, 1298, 48, 'dummy'),
(144423, 1299, 48, 'dummy'),
(144424, 1300, 48, 'dummy'),
(144425, 1301, 48, 'dummy'),
(144426, 1302, 48, 'dummy'),
(144427, 1303, 48, 'dummy'),
(144428, 1304, 48, 'dummy'),
(144429, 1305, 48, 'dummy'),
(144430, 1306, 48, 'dummy'),
(144431, 1307, 48, 'dummy'),
(144432, 1308, 48, 'dummy'),
(144433, 1309, 48, 'dummy'),
(144434, 1310, 48, 'dummy'),
(144435, 1311, 48, 'dummy'),
(144436, 1312, 48, 'dummy'),
(144437, 1313, 48, 'dummy'),
(144438, 1314, 48, 'dummy'),
(144439, 1315, 48, 'dummy'),
(144440, 1316, 48, 'dummy'),
(144441, 1317, 48, 'dummy'),
(144442, 1318, 48, 'dummy'),
(144443, 1319, 48, 'dummy'),
(144444, 1320, 48, 'dummy'),
(144445, 1321, 48, 'dummy'),
(144446, 1322, 48, 'dummy'),
(144447, 1323, 48, 'dummy'),
(144448, 1324, 48, 'dummy'),
(144449, 1325, 48, 'dummy'),
(144450, 1326, 48, 'dummy'),
(144451, 1327, 48, 'dummy'),
(144452, 1328, 48, 'dummy'),
(144453, 1329, 48, 'dummy'),
(144454, 1330, 48, 'dummy'),
(144455, 1331, 48, 'dummy'),
(144456, 1332, 48, 'dummy'),
(144457, 1333, 48, 'dummy'),
(144458, 1334, 48, 'dummy'),
(144459, 1335, 48, 'dummy'),
(144460, 1336, 48, 'dummy'),
(144461, 1337, 48, 'dummy'),
(144462, 1338, 48, 'dummy'),
(144463, 1339, 48, 'dummy'),
(144464, 1340, 48, 'dummy'),
(144465, 1341, 48, 'dummy'),
(144466, 1342, 48, 'dummy'),
(144467, 1343, 48, 'dummy'),
(144468, 1344, 48, 'dummy'),
(144469, 1345, 48, 'dummy'),
(144470, 1346, 48, 'dummy'),
(144471, 1347, 48, 'dummy'),
(144472, 1348, 48, 'dummy'),
(144473, 1349, 48, 'dummy'),
(144474, 1350, 48, 'dummy'),
(144475, 1351, 48, 'dummy'),
(144476, 1352, 48, 'dummy'),
(144477, 1353, 48, 'dummy'),
(144478, 1354, 48, 'dummy'),
(144479, 1355, 48, 'dummy'),
(144480, 1356, 48, 'dummy'),
(144481, 1357, 48, 'dummy'),
(144482, 1358, 48, 'dummy'),
(144483, 1359, 48, 'dummy'),
(144484, 1360, 48, 'dummy'),
(144485, 1361, 48, 'dummy'),
(144486, 1362, 48, 'dummy'),
(144487, 1363, 48, 'dummy'),
(144488, 1364, 48, 'dummy'),
(144489, 1365, 48, 'dummy'),
(144490, 1366, 48, 'dummy'),
(144491, 1367, 48, 'dummy'),
(144492, 1368, 48, 'dummy'),
(144493, 1369, 48, 'dummy'),
(144494, 1370, 48, 'dummy'),
(144495, 1371, 48, 'dummy'),
(144496, 1372, 48, 'dummy'),
(144497, 1373, 48, 'dummy'),
(144498, 1374, 48, 'dummy'),
(144499, 1375, 48, 'dummy'),
(144500, 1376, 48, 'dummy'),
(144501, 1377, 48, 'dummy'),
(144502, 1378, 48, 'dummy'),
(144503, 1379, 48, 'dummy'),
(144504, 1380, 48, 'dummy'),
(144505, 1381, 48, 'dummy'),
(144506, 1382, 48, 'dummy'),
(144507, 1383, 48, 'dummy'),
(144508, 1384, 48, 'dummy'),
(144509, 1385, 48, 'dummy'),
(144510, 1386, 48, 'dummy'),
(144511, 1387, 48, 'dummy'),
(144512, 1388, 48, 'dummy'),
(144513, 1389, 48, 'dummy'),
(144514, 1390, 48, 'dummy'),
(144515, 1391, 48, 'dummy'),
(144516, 1392, 48, 'dummy'),
(144517, 1393, 48, 'dummy'),
(144518, 1394, 48, 'dummy'),
(144519, 1395, 48, 'dummy'),
(144520, 1396, 48, 'dummy'),
(144521, 1397, 48, 'dummy'),
(144522, 1398, 48, 'dummy'),
(144523, 1399, 48, 'dummy'),
(144524, 1400, 48, 'dummy'),
(144525, 1401, 48, 'dummy'),
(144526, 1402, 48, 'dummy'),
(144527, 1403, 48, 'dummy'),
(144528, 1404, 48, 'dummy'),
(144529, 1405, 48, 'dummy'),
(144530, 1406, 48, 'dummy'),
(144531, 1407, 48, 'dummy'),
(144532, 1408, 48, 'dummy'),
(144533, 1409, 48, 'dummy'),
(144534, 1410, 48, 'dummy'),
(144535, 1411, 48, 'dummy'),
(144536, 1412, 48, 'dummy'),
(144537, 1413, 48, 'dummy'),
(144538, 1414, 48, 'dummy'),
(144539, 1415, 48, 'dummy'),
(144540, 1416, 48, 'dummy'),
(144541, 1417, 48, 'dummy'),
(144542, 1418, 48, 'dummy'),
(144543, 1419, 48, 'dummy'),
(144544, 1420, 48, 'dummy'),
(144545, 1421, 48, 'dummy'),
(144546, 1422, 48, 'dummy'),
(144547, 1423, 48, 'dummy'),
(144548, 1424, 48, 'dummy'),
(144549, 1425, 48, 'dummy'),
(144550, 1426, 48, 'dummy'),
(144551, 1427, 48, 'dummy'),
(144552, 1428, 48, 'dummy'),
(144553, 1429, 48, 'dummy'),
(144554, 1430, 48, 'dummy'),
(144555, 1431, 48, 'dummy'),
(144556, 1432, 48, 'dummy'),
(144557, 1433, 48, 'dummy'),
(144558, 1434, 48, 'dummy'),
(144559, 1435, 48, 'dummy'),
(144560, 1436, 48, 'dummy'),
(144561, 1437, 48, 'dummy'),
(144562, 1438, 48, 'dummy'),
(144563, 1439, 48, 'dummy'),
(144564, 1440, 48, 'dummy'),
(144565, 1441, 48, 'dummy'),
(144566, 1442, 48, 'dummy'),
(144567, 1443, 48, 'dummy'),
(144568, 1444, 48, 'dummy'),
(144569, 1445, 48, 'dummy'),
(144570, 1446, 48, 'dummy'),
(144571, 1447, 48, 'dummy'),
(144572, 1448, 48, 'dummy'),
(144573, 1449, 48, 'dummy'),
(144574, 1450, 48, 'dummy'),
(144575, 1451, 48, 'dummy'),
(144576, 1452, 48, 'dummy'),
(144577, 1453, 48, 'dummy'),
(144578, 1454, 48, 'dummy'),
(144579, 1455, 48, 'dummy'),
(144580, 1456, 48, 'dummy'),
(144581, 1457, 48, 'dummy'),
(144582, 1458, 48, 'dummy'),
(144583, 1459, 48, 'dummy'),
(144584, 1460, 48, 'dummy'),
(144585, 1461, 48, 'dummy'),
(144586, 1462, 48, 'dummy'),
(144587, 1463, 48, 'dummy'),
(144588, 1464, 48, 'dummy'),
(144589, 1465, 48, 'dummy'),
(144590, 1466, 48, 'dummy'),
(144591, 1467, 48, 'dummy'),
(144592, 1468, 48, 'dummy'),
(144593, 1469, 48, 'dummy'),
(144594, 1470, 48, 'dummy'),
(144595, 1471, 48, 'dummy'),
(144596, 1472, 48, 'dummy'),
(144597, 1473, 48, 'dummy'),
(144598, 1474, 48, 'dummy'),
(144599, 1475, 48, 'dummy'),
(144600, 1476, 48, 'dummy'),
(144601, 1477, 48, 'dummy'),
(144602, 1478, 48, 'dummy'),
(144603, 1479, 48, 'dummy'),
(144604, 1480, 48, 'dummy'),
(144605, 1481, 48, 'dummy'),
(144606, 1482, 48, 'dummy'),
(144607, 1483, 48, 'dummy'),
(144608, 1484, 48, 'dummy'),
(144609, 1485, 48, 'dummy'),
(144610, 1486, 48, 'dummy'),
(144611, 1487, 48, 'dummy'),
(144612, 1488, 48, 'dummy'),
(144613, 1489, 48, 'dummy'),
(144614, 1490, 48, 'dummy'),
(144615, 1491, 48, 'dummy'),
(144616, 1492, 48, 'dummy'),
(144617, 1493, 48, 'dummy'),
(144618, 1494, 48, 'dummy'),
(144619, 1495, 48, 'dummy'),
(144620, 1496, 48, 'dummy'),
(144621, 1497, 48, 'dummy'),
(144622, 1498, 48, 'dummy'),
(144623, 1499, 48, 'dummy'),
(144624, 1500, 48, 'dummy'),
(144625, 1501, 48, 'dummy'),
(144626, 1502, 48, 'dummy'),
(144627, 1503, 48, 'dummy'),
(144628, 1504, 48, 'dummy'),
(144629, 1505, 48, 'dummy'),
(144630, 1506, 48, 'dummy'),
(144631, 1507, 48, 'dummy'),
(144632, 1508, 48, 'dummy'),
(144633, 1509, 48, 'dummy'),
(144634, 1510, 48, 'dummy'),
(144635, 1511, 48, 'dummy'),
(144636, 1512, 48, 'dummy'),
(144637, 1513, 48, 'dummy'),
(144638, 1514, 48, 'dummy'),
(144639, 1515, 48, 'dummy'),
(144640, 1516, 48, 'dummy'),
(144641, 1517, 48, 'dummy'),
(144642, 1518, 48, 'dummy'),
(144643, 1519, 48, 'dummy'),
(144644, 1520, 48, 'dummy'),
(144645, 1521, 48, 'dummy'),
(144646, 1522, 48, 'dummy'),
(144647, 1523, 48, 'dummy'),
(144648, 1524, 48, 'dummy'),
(144649, 1525, 48, 'dummy'),
(144650, 1526, 48, 'dummy'),
(144651, 1527, 48, 'dummy'),
(144652, 1528, 48, 'dummy'),
(144653, 1529, 48, 'dummy'),
(144654, 1530, 48, 'dummy'),
(144655, 1531, 48, 'dummy'),
(144656, 1532, 48, 'dummy'),
(144657, 1533, 48, 'dummy'),
(144658, 1534, 48, 'dummy'),
(144659, 1535, 48, 'dummy'),
(144660, 1536, 48, 'dummy'),
(144661, 1537, 48, 'dummy'),
(144662, 1538, 48, 'dummy'),
(144663, 1539, 48, 'dummy'),
(144664, 1540, 48, 'dummy'),
(144665, 1541, 48, 'dummy'),
(144666, 1542, 48, 'dummy'),
(144667, 1543, 48, 'dummy'),
(144668, 1544, 48, 'dummy'),
(144669, 1545, 48, 'dummy'),
(144670, 1546, 48, 'dummy'),
(144671, 1547, 48, 'dummy'),
(144672, 1548, 48, 'dummy'),
(144673, 1549, 48, 'dummy'),
(144674, 1550, 48, 'dummy'),
(144675, 1551, 48, 'dummy'),
(144676, 1552, 48, 'dummy'),
(144677, 1553, 48, 'dummy'),
(144678, 1554, 48, 'dummy'),
(144679, 1555, 48, 'dummy'),
(144680, 1556, 48, 'dummy'),
(144681, 1557, 48, 'dummy'),
(144682, 1558, 48, 'dummy'),
(144683, 1559, 48, 'dummy'),
(144684, 1560, 48, 'dummy'),
(144685, 1561, 48, 'dummy'),
(144686, 1562, 48, 'dummy'),
(144687, 1563, 48, 'dummy'),
(144688, 1564, 48, 'dummy'),
(144689, 1565, 48, 'dummy'),
(144690, 1566, 48, 'dummy'),
(144691, 1567, 48, 'dummy'),
(144692, 1568, 48, 'dummy'),
(144693, 1569, 48, 'dummy'),
(144694, 1570, 48, 'dummy'),
(144695, 1571, 48, 'dummy'),
(144696, 1572, 48, 'dummy'),
(144697, 1573, 48, 'dummy'),
(144698, 1574, 48, 'dummy'),
(144699, 1575, 48, 'dummy'),
(144700, 1576, 48, 'dummy'),
(144701, 1577, 48, 'dummy'),
(144702, 1578, 48, 'dummy'),
(144703, 1579, 48, 'dummy'),
(144704, 1580, 48, 'dummy'),
(144705, 1581, 48, 'dummy'),
(144706, 1582, 48, 'dummy'),
(144707, 1583, 48, 'dummy'),
(144708, 1584, 48, 'dummy'),
(144709, 1585, 48, 'dummy'),
(144710, 1586, 48, 'dummy'),
(144711, 1587, 48, 'dummy'),
(144712, 1588, 48, 'dummy'),
(144713, 1589, 48, 'dummy'),
(144714, 1590, 48, 'dummy'),
(144715, 1591, 48, 'dummy'),
(144716, 1592, 48, 'dummy'),
(144717, 1593, 48, 'dummy'),
(144718, 1594, 48, 'dummy'),
(144719, 1595, 48, 'dummy'),
(144720, 1596, 48, 'dummy'),
(144721, 1597, 48, 'dummy'),
(144722, 1598, 48, 'dummy'),
(144723, 1599, 48, 'dummy'),
(144724, 1600, 48, 'dummy'),
(144725, 1601, 48, 'dummy'),
(144726, 1602, 48, 'dummy'),
(144727, 1603, 48, 'dummy'),
(144728, 1604, 48, 'dummy'),
(144729, 1605, 48, 'dummy'),
(144730, 1606, 48, 'dummy'),
(144731, 1607, 48, 'dummy'),
(144732, 1608, 48, 'dummy'),
(144733, 1609, 48, 'dummy'),
(144734, 1610, 48, 'dummy'),
(144735, 1611, 48, 'dummy'),
(144736, 1612, 48, 'dummy'),
(144737, 1613, 48, 'dummy'),
(144738, 1614, 48, 'dummy'),
(144739, 1615, 48, 'dummy'),
(144740, 1616, 48, 'dummy'),
(144741, 1617, 48, 'dummy'),
(144742, 1618, 48, 'dummy'),
(144743, 1619, 48, 'dummy'),
(144744, 1620, 48, 'dummy'),
(144745, 1621, 48, 'dummy'),
(144746, 1622, 48, 'dummy'),
(144747, 1623, 48, 'dummy'),
(144748, 1624, 48, 'dummy'),
(144749, 1625, 48, 'dummy'),
(144750, 1626, 48, 'dummy'),
(144751, 1627, 48, 'dummy'),
(144752, 1628, 48, 'dummy'),
(144753, 1629, 48, 'dummy'),
(144754, 1630, 48, 'dummy'),
(144755, 1631, 48, 'dummy'),
(144756, 1632, 48, 'dummy'),
(144757, 1633, 48, 'dummy'),
(144758, 1634, 48, 'dummy'),
(144759, 1635, 48, 'dummy'),
(144760, 1636, 48, 'dummy'),
(144761, 1637, 48, 'dummy'),
(144762, 1638, 48, 'dummy'),
(144763, 1639, 48, 'dummy'),
(144764, 1640, 48, 'dummy'),
(144765, 1641, 48, 'dummy'),
(144766, 1642, 48, 'dummy'),
(144767, 1643, 48, 'dummy'),
(144768, 1644, 48, 'dummy'),
(144769, 1645, 48, 'dummy'),
(144770, 1646, 48, 'dummy'),
(144771, 1647, 48, 'dummy'),
(144772, 1648, 48, 'dummy'),
(144773, 1649, 48, 'dummy'),
(144774, 1650, 48, 'dummy'),
(144775, 1651, 48, 'dummy'),
(144776, 1652, 48, 'dummy'),
(144777, 1653, 48, 'dummy'),
(144778, 1654, 48, 'dummy'),
(144779, 1655, 48, 'dummy'),
(144780, 1656, 48, 'dummy'),
(144781, 1657, 48, 'dummy'),
(144782, 1658, 48, 'dummy'),
(144783, 1659, 48, 'dummy'),
(144784, 1660, 48, 'dummy'),
(144785, 1661, 48, 'dummy'),
(144786, 1662, 48, 'dummy'),
(144787, 1663, 48, 'dummy'),
(144788, 1664, 48, 'dummy'),
(144789, 1665, 48, 'dummy'),
(144790, 1666, 48, 'dummy'),
(144791, 1667, 48, 'dummy'),
(144792, 1668, 48, 'dummy'),
(144793, 1669, 48, 'dummy'),
(144794, 1670, 48, 'dummy'),
(144795, 1671, 48, 'dummy'),
(144796, 1672, 48, 'dummy'),
(144797, 1673, 48, 'dummy'),
(144798, 1674, 48, 'dummy'),
(144799, 1675, 48, 'dummy'),
(144800, 1676, 48, 'dummy'),
(144801, 1677, 48, 'dummy'),
(144802, 1678, 48, 'dummy'),
(144803, 1679, 48, 'dummy'),
(144804, 1680, 48, 'dummy'),
(144805, 1681, 48, 'dummy'),
(144806, 1682, 48, 'dummy'),
(144807, 1683, 48, 'dummy'),
(144808, 1684, 48, 'dummy'),
(144809, 1685, 48, 'dummy'),
(144810, 1686, 48, 'dummy'),
(144811, 1687, 48, 'dummy'),
(144812, 1688, 48, 'dummy'),
(144813, 1689, 48, 'dummy'),
(144814, 1690, 48, 'dummy'),
(144815, 1691, 48, 'dummy'),
(144816, 1692, 48, 'dummy'),
(144817, 1693, 48, 'dummy'),
(144818, 1694, 48, 'dummy'),
(144819, 1695, 48, 'dummy'),
(144820, 1696, 48, 'dummy'),
(144821, 1697, 48, 'dummy'),
(144822, 1698, 48, 'dummy'),
(144823, 1699, 48, 'dummy'),
(144824, 1700, 48, 'dummy'),
(144825, 1701, 48, 'dummy'),
(144826, 1702, 48, 'dummy'),
(144827, 1703, 48, 'dummy'),
(144828, 1704, 48, 'dummy'),
(144829, 1705, 48, 'dummy'),
(144830, 1706, 48, 'dummy'),
(144831, 1707, 48, 'dummy'),
(144832, 1708, 48, 'dummy'),
(144833, 1709, 48, 'dummy'),
(144834, 1710, 48, 'dummy'),
(144835, 1711, 48, 'dummy'),
(144836, 1712, 48, 'dummy'),
(144837, 1713, 48, 'dummy'),
(144838, 1714, 48, 'dummy'),
(144839, 1715, 48, 'dummy'),
(144840, 1716, 48, 'dummy'),
(144841, 1717, 48, 'dummy'),
(144842, 1718, 48, 'dummy'),
(144843, 1719, 48, 'dummy'),
(144844, 1720, 48, 'dummy'),
(144845, 1721, 48, 'dummy'),
(144846, 1722, 48, 'dummy'),
(144847, 1723, 48, 'dummy'),
(144848, 1724, 48, 'dummy'),
(144849, 1725, 48, 'dummy'),
(144850, 1726, 48, 'dummy'),
(144851, 1727, 48, 'dummy'),
(144852, 1728, 48, 'dummy'),
(144853, 1729, 48, 'dummy'),
(144854, 1730, 48, 'dummy'),
(144855, 1731, 48, 'dummy'),
(144856, 1732, 48, 'dummy'),
(144857, 1733, 48, 'dummy'),
(144858, 1734, 48, 'dummy'),
(144859, 1735, 48, 'dummy'),
(144860, 1736, 48, 'dummy'),
(144861, 1737, 48, 'dummy'),
(144862, 1738, 48, 'dummy'),
(144863, 1739, 48, 'dummy'),
(144864, 1740, 48, 'dummy'),
(144865, 1741, 48, 'dummy'),
(144866, 1742, 48, 'dummy'),
(144867, 1743, 48, 'dummy'),
(144868, 1744, 48, 'dummy'),
(144869, 1745, 48, 'dummy'),
(144870, 1746, 48, 'dummy'),
(144871, 1747, 48, 'dummy'),
(144872, 1748, 48, 'dummy'),
(144873, 1749, 48, 'dummy'),
(144874, 1750, 48, 'dummy'),
(144875, 1751, 48, 'dummy'),
(144876, 1752, 48, 'dummy'),
(144877, 1753, 48, 'dummy'),
(144878, 1754, 48, 'dummy'),
(144879, 1755, 48, 'dummy'),
(144880, 1756, 48, 'dummy'),
(144881, 1757, 48, 'dummy'),
(144882, 1758, 48, 'dummy'),
(144883, 1759, 48, 'dummy'),
(144884, 1760, 48, 'dummy'),
(144885, 1761, 48, 'dummy'),
(144886, 1762, 48, 'dummy'),
(144887, 1763, 48, 'dummy'),
(144888, 1764, 48, 'dummy'),
(144889, 1765, 48, 'dummy'),
(144890, 1766, 48, 'dummy'),
(144891, 1767, 48, 'dummy'),
(144892, 1768, 48, 'dummy'),
(144893, 1769, 48, 'dummy'),
(144894, 1770, 48, 'dummy'),
(144895, 1771, 48, 'dummy'),
(144896, 1772, 48, 'dummy'),
(144897, 1773, 48, 'dummy'),
(144898, 1774, 48, 'dummy'),
(144899, 1775, 48, 'dummy'),
(144900, 1776, 48, 'dummy'),
(144901, 1777, 48, 'dummy'),
(144902, 1778, 48, 'dummy'),
(144903, 1779, 48, 'dummy'),
(144904, 1780, 48, 'dummy'),
(144905, 1781, 48, 'dummy'),
(144906, 1782, 48, 'dummy'),
(144907, 1783, 48, 'dummy'),
(144908, 1784, 48, 'dummy'),
(144909, 1785, 48, 'dummy'),
(144910, 1786, 48, 'dummy'),
(144911, 1787, 48, 'dummy'),
(144912, 1788, 48, 'dummy'),
(144913, 1789, 48, 'dummy'),
(144914, 1790, 48, 'dummy'),
(144915, 1791, 48, 'dummy'),
(144916, 1792, 48, 'dummy'),
(144917, 1793, 48, 'dummy'),
(144918, 1794, 48, 'dummy'),
(144919, 1795, 48, 'dummy'),
(144920, 1796, 48, 'dummy'),
(144921, 1797, 48, 'dummy'),
(144922, 1798, 48, 'dummy'),
(144923, 1799, 48, 'dummy'),
(144924, 1800, 48, 'dummy'),
(144925, 1801, 48, 'dummy'),
(144926, 1802, 48, 'dummy'),
(144927, 1803, 48, 'dummy'),
(144928, 1804, 48, 'dummy'),
(144929, 1805, 48, 'dummy'),
(144930, 1806, 48, 'dummy'),
(144931, 1807, 48, 'dummy'),
(144932, 1808, 48, 'dummy'),
(144933, 1809, 48, 'dummy'),
(144934, 1810, 48, 'dummy'),
(144935, 1811, 48, 'dummy'),
(144936, 1812, 48, 'dummy'),
(144937, 1813, 48, 'dummy'),
(144938, 1814, 48, 'dummy'),
(144939, 1815, 48, 'dummy'),
(144940, 1816, 48, 'dummy'),
(144941, 1817, 48, 'dummy'),
(144942, 1818, 48, 'dummy'),
(144943, 1819, 48, 'dummy'),
(144944, 1820, 48, 'dummy'),
(144945, 1821, 48, 'dummy'),
(144946, 1822, 48, 'dummy'),
(144947, 1823, 48, 'dummy'),
(144948, 1824, 48, 'dummy'),
(144949, 1825, 48, 'dummy'),
(144950, 1826, 48, 'dummy'),
(144951, 1827, 48, 'dummy'),
(144952, 1828, 48, 'dummy'),
(144953, 1829, 48, 'dummy'),
(144954, 1830, 48, 'dummy'),
(144955, 1831, 48, 'dummy'),
(144956, 1832, 48, 'dummy'),
(144957, 1833, 48, 'dummy'),
(144958, 1834, 48, 'dummy'),
(144959, 1835, 48, 'dummy'),
(144960, 1836, 48, 'dummy'),
(144961, 1837, 48, 'dummy'),
(144962, 1838, 48, 'dummy'),
(144963, 1839, 48, 'dummy'),
(144964, 1840, 48, 'dummy'),
(144965, 1841, 48, 'dummy'),
(144966, 1842, 48, 'dummy'),
(144967, 1843, 48, 'dummy'),
(144968, 1844, 48, 'dummy'),
(144969, 1845, 48, 'dummy'),
(144970, 1846, 48, 'dummy'),
(144971, 1847, 48, 'dummy'),
(144972, 1848, 48, 'dummy'),
(144973, 1849, 48, 'dummy'),
(144974, 1850, 48, 'dummy'),
(144975, 1851, 48, 'dummy'),
(144976, 1852, 48, 'dummy'),
(144977, 1853, 48, 'dummy'),
(144978, 1854, 48, 'dummy'),
(144979, 1855, 48, 'dummy'),
(144980, 1856, 48, 'dummy'),
(144981, 1857, 48, 'dummy'),
(144982, 1858, 48, 'dummy'),
(144983, 1859, 48, 'dummy'),
(144984, 1860, 48, 'dummy'),
(144985, 1861, 48, 'dummy'),
(144986, 1862, 48, 'dummy'),
(144987, 1863, 48, 'dummy'),
(144988, 1864, 48, 'dummy'),
(144989, 1865, 48, 'dummy'),
(144990, 1866, 48, 'dummy'),
(144991, 1867, 48, 'dummy'),
(144992, 1868, 48, 'dummy'),
(144993, 1869, 48, 'dummy'),
(144994, 1870, 48, 'dummy'),
(144995, 1871, 48, 'dummy'),
(144996, 1872, 48, 'dummy'),
(144997, 1873, 48, 'dummy'),
(144998, 1874, 48, 'dummy'),
(144999, 1875, 48, 'dummy'),
(145000, 1876, 48, 'dummy'),
(145001, 1877, 48, 'dummy'),
(145002, 1878, 48, 'dummy'),
(145003, 1879, 48, 'dummy'),
(145004, 1880, 48, 'dummy'),
(145005, 1881, 48, 'dummy'),
(145006, 1882, 48, 'dummy'),
(145007, 1883, 48, 'dummy'),
(145008, 1884, 48, 'dummy'),
(145009, 1885, 48, 'dummy'),
(145010, 1886, 48, 'dummy'),
(145011, 1887, 48, 'dummy'),
(145012, 1888, 48, 'dummy'),
(145013, 1889, 48, 'dummy'),
(145014, 1890, 48, 'dummy'),
(145015, 1891, 48, 'dummy'),
(145016, 1892, 48, 'dummy'),
(145017, 1893, 48, 'dummy'),
(145018, 1894, 48, 'dummy'),
(145019, 1895, 48, 'dummy'),
(145020, 1896, 48, 'dummy'),
(145021, 1897, 48, 'dummy'),
(145022, 1898, 48, 'dummy'),
(145023, 1899, 48, 'dummy'),
(145024, 1900, 48, 'dummy'),
(145025, 1901, 48, 'dummy'),
(145026, 1902, 48, 'dummy'),
(145027, 1903, 48, 'dummy'),
(145028, 1904, 48, 'dummy'),
(145029, 1905, 48, 'dummy'),
(145030, 1906, 48, 'dummy'),
(145031, 1907, 48, 'dummy'),
(145032, 1908, 48, 'dummy'),
(145033, 1909, 48, 'dummy'),
(145034, 1910, 48, 'dummy'),
(145035, 1911, 48, 'dummy'),
(145036, 1912, 48, 'dummy'),
(145037, 1913, 48, 'dummy'),
(145038, 1914, 48, 'dummy'),
(145039, 1915, 48, 'dummy'),
(145040, 1916, 48, 'dummy'),
(145041, 1917, 48, 'dummy'),
(145042, 1918, 48, 'dummy'),
(145043, 1919, 48, 'dummy'),
(145044, 1920, 48, 'dummy'),
(145045, 1921, 48, 'dummy'),
(145046, 1922, 48, 'dummy'),
(145047, 1923, 48, 'dummy'),
(145048, 1924, 48, 'dummy'),
(145049, 1925, 48, 'dummy'),
(145050, 1926, 48, 'dummy'),
(145051, 1927, 48, 'dummy'),
(145052, 1928, 48, 'dummy'),
(145053, 1929, 48, 'dummy'),
(145054, 1930, 48, 'dummy'),
(145055, 1931, 48, 'dummy'),
(145056, 1932, 48, 'dummy'),
(145057, 1933, 48, 'dummy'),
(145058, 1934, 48, 'dummy'),
(145059, 1935, 48, 'dummy'),
(145060, 1936, 48, 'dummy'),
(145061, 1937, 48, 'dummy'),
(145062, 1938, 48, 'dummy'),
(145063, 1939, 48, 'dummy'),
(145064, 1940, 48, 'dummy'),
(145065, 1941, 48, 'dummy'),
(145066, 1942, 48, 'dummy'),
(145067, 1943, 48, 'dummy'),
(145068, 1944, 48, 'dummy'),
(145069, 1945, 48, 'dummy'),
(145070, 1946, 48, 'dummy'),
(145071, 1947, 48, 'dummy'),
(145072, 1948, 48, 'dummy'),
(145073, 1949, 48, 'dummy'),
(145074, 1950, 48, 'dummy'),
(145075, 1951, 48, 'dummy'),
(145076, 1952, 48, 'dummy'),
(145077, 1953, 48, 'dummy'),
(145078, 1954, 48, 'dummy'),
(145079, 1955, 48, 'dummy'),
(145080, 1956, 48, 'dummy'),
(145081, 1957, 48, 'dummy'),
(145082, 1958, 48, 'dummy'),
(145083, 1959, 48, 'dummy'),
(145084, 1960, 48, 'dummy'),
(145085, 1961, 48, 'dummy'),
(145086, 1962, 48, 'dummy'),
(145087, 1963, 48, 'dummy'),
(145088, 1964, 48, 'dummy'),
(145089, 1965, 48, 'dummy'),
(145090, 1966, 48, 'dummy'),
(145091, 1967, 48, 'dummy'),
(145092, 1968, 48, 'dummy'),
(145093, 1969, 48, 'dummy'),
(145094, 1970, 48, 'dummy'),
(145095, 1971, 48, 'dummy'),
(145096, 1972, 48, 'dummy'),
(145097, 1973, 48, 'dummy'),
(145098, 1974, 48, 'dummy'),
(145099, 1975, 48, 'dummy'),
(145100, 1976, 48, 'dummy'),
(145101, 1977, 48, 'dummy'),
(145102, 1978, 48, 'dummy'),
(145103, 1979, 48, 'dummy'),
(145104, 1980, 48, 'dummy'),
(145105, 1981, 48, 'dummy'),
(145106, 1982, 48, 'dummy'),
(145107, 1983, 48, 'dummy'),
(145108, 1984, 48, 'dummy'),
(145109, 1985, 48, 'dummy'),
(145110, 1986, 48, 'dummy'),
(145111, 1987, 48, 'dummy'),
(145112, 1988, 48, 'dummy'),
(145113, 1989, 48, 'dummy'),
(145114, 1990, 48, 'dummy'),
(145115, 1991, 48, 'dummy'),
(145116, 1992, 48, 'dummy'),
(145117, 1993, 48, 'dummy'),
(145118, 1994, 48, 'dummy'),
(145119, 1995, 48, 'dummy'),
(145120, 1996, 48, 'dummy'),
(145121, 1997, 48, 'dummy'),
(145122, 1998, 48, 'dummy'),
(145123, 1999, 48, 'dummy'),
(145124, 2000, 48, 'dummy'),
(145125, 2001, 48, 'dummy'),
(145126, 2002, 48, 'dummy'),
(145127, 2003, 48, 'dummy'),
(145128, 2004, 48, 'dummy'),
(145129, 2005, 48, 'dummy'),
(145130, 2006, 48, 'dummy'),
(145131, 2007, 48, 'dummy'),
(145132, 2008, 48, 'dummy'),
(145133, 2009, 48, 'dummy'),
(145134, 2010, 48, 'dummy'),
(145135, 2011, 48, 'dummy'),
(145136, 2012, 48, 'dummy'),
(145137, 2013, 48, 'dummy'),
(145138, 2014, 48, 'dummy'),
(145139, 2015, 48, 'dummy'),
(145140, 2016, 48, 'dummy'),
(145141, 2017, 48, 'dummy'),
(145142, 2018, 48, 'dummy'),
(145143, 2019, 48, 'dummy'),
(145144, 2020, 48, 'dummy'),
(145145, 2021, 48, 'dummy'),
(145146, 2022, 48, 'dummy'),
(145147, 2023, 48, 'dummy'),
(145148, 2024, 48, 'dummy'),
(145149, 2025, 48, 'dummy'),
(145150, 2026, 48, 'dummy'),
(145151, 2027, 48, 'dummy'),
(145152, 2028, 48, 'dummy'),
(145153, 2029, 48, 'dummy'),
(145154, 2030, 48, 'dummy'),
(145155, 2031, 48, 'dummy'),
(145156, 2032, 48, 'dummy'),
(145157, 2033, 48, 'dummy'),
(145158, 2034, 48, 'dummy'),
(145159, 2035, 48, 'dummy'),
(145160, 2036, 48, 'dummy'),
(145161, 2037, 48, 'dummy'),
(145162, 2038, 48, 'dummy'),
(145163, 2039, 48, 'dummy'),
(145164, 2040, 48, 'dummy'),
(145165, 2041, 48, 'dummy'),
(145166, 2042, 48, 'dummy'),
(145167, 2043, 48, 'dummy'),
(145168, 2044, 48, 'dummy'),
(145169, 2045, 48, 'dummy'),
(145170, 2046, 48, 'dummy'),
(145171, 2047, 48, 'dummy'),
(145172, 2048, 48, 'dummy'),
(145173, 2049, 48, 'dummy'),
(145174, 2050, 48, 'dummy'),
(145175, 2051, 48, 'dummy'),
(145176, 2052, 48, 'dummy'),
(145177, 2053, 48, 'dummy'),
(145178, 2054, 48, 'dummy'),
(145179, 2055, 48, 'dummy'),
(145180, 2056, 48, 'dummy'),
(145181, 2057, 48, 'dummy'),
(145182, 2058, 48, 'dummy'),
(145183, 2059, 48, 'dummy'),
(145184, 2060, 48, 'dummy'),
(145185, 2061, 48, 'dummy'),
(145186, 2062, 48, 'dummy'),
(145187, 2063, 48, 'dummy'),
(145188, 2064, 48, 'dummy'),
(145189, 2065, 48, 'dummy'),
(145190, 2066, 48, 'dummy'),
(145191, 2067, 48, 'dummy'),
(145192, 2068, 48, 'dummy'),
(145193, 2069, 48, 'dummy'),
(145194, 2070, 48, 'dummy'),
(145195, 2071, 48, 'dummy'),
(145196, 2072, 48, 'dummy'),
(145197, 2073, 48, 'dummy'),
(145198, 2074, 48, 'dummy'),
(145199, 2075, 48, 'dummy'),
(145200, 2076, 48, 'dummy'),
(145201, 2077, 48, 'dummy'),
(145202, 2078, 48, 'dummy'),
(145203, 2079, 48, 'dummy'),
(145204, 2080, 48, 'dummy'),
(145205, 2081, 48, 'dummy'),
(145206, 2082, 48, 'dummy'),
(145207, 2083, 48, 'dummy'),
(145208, 2084, 48, 'dummy'),
(145209, 2085, 48, 'dummy'),
(145210, 2086, 48, 'dummy'),
(145211, 2087, 48, 'dummy'),
(145212, 2088, 48, 'dummy'),
(145213, 2089, 48, 'dummy'),
(145214, 2090, 48, 'dummy'),
(145215, 2091, 48, 'dummy'),
(145216, 2092, 48, 'dummy'),
(145217, 2093, 48, 'dummy'),
(145218, 2094, 48, 'dummy'),
(145219, 2095, 48, 'dummy'),
(145220, 2096, 48, 'dummy'),
(145221, 2097, 48, 'dummy'),
(145222, 2098, 48, 'dummy'),
(145223, 2099, 48, 'dummy'),
(145224, 2100, 48, 'dummy'),
(145225, 2101, 48, 'dummy'),
(145226, 2102, 48, 'dummy'),
(145227, 2103, 48, 'dummy'),
(145228, 2104, 48, 'dummy'),
(145229, 2105, 48, 'dummy'),
(145230, 2106, 48, 'dummy'),
(145231, 2107, 48, 'dummy'),
(145232, 2108, 48, 'dummy'),
(145233, 2109, 48, 'dummy'),
(145234, 2110, 48, 'dummy'),
(145235, 2111, 48, 'dummy'),
(145236, 2112, 48, 'dummy'),
(145237, 2113, 48, 'dummy'),
(145238, 2114, 48, 'dummy'),
(145239, 2115, 48, 'dummy'),
(145240, 2116, 48, 'dummy'),
(145241, 2117, 48, 'dummy'),
(145242, 2118, 48, 'dummy'),
(145243, 2119, 48, 'dummy'),
(145244, 2120, 48, 'dummy'),
(145245, 2121, 48, 'dummy'),
(145246, 2122, 48, 'dummy'),
(145247, 2123, 48, 'dummy'),
(145248, 2124, 48, 'dummy'),
(145249, 2125, 48, 'dummy'),
(145250, 2126, 48, 'dummy'),
(145251, 2127, 48, 'dummy'),
(145252, 2128, 48, 'dummy'),
(145253, 2129, 48, 'dummy'),
(145254, 2130, 48, 'dummy'),
(145255, 2131, 48, 'dummy'),
(145256, 2132, 48, 'dummy'),
(145257, 2133, 48, 'dummy'),
(145258, 2134, 48, 'dummy'),
(145259, 2135, 48, 'dummy'),
(145260, 2136, 48, 'dummy'),
(145261, 2137, 48, 'dummy'),
(145262, 2138, 48, 'dummy'),
(145263, 2139, 48, 'dummy'),
(145264, 2140, 48, 'dummy'),
(145265, 2141, 48, 'dummy'),
(145266, 2142, 48, 'dummy'),
(145267, 2143, 48, 'dummy'),
(145268, 2144, 48, 'dummy'),
(145269, 2145, 48, 'dummy'),
(145270, 2146, 48, 'dummy'),
(145271, 2147, 48, 'dummy'),
(145272, 2148, 48, 'dummy'),
(145273, 2149, 48, 'dummy'),
(145274, 2150, 48, 'dummy'),
(145275, 2151, 48, 'dummy'),
(145276, 2152, 48, 'dummy'),
(145277, 2153, 48, 'dummy'),
(145278, 2154, 48, 'dummy'),
(145279, 2155, 48, 'dummy'),
(145280, 2156, 48, 'dummy'),
(145281, 2157, 48, 'dummy'),
(145282, 2158, 48, 'dummy'),
(145283, 2159, 48, 'dummy'),
(145284, 2160, 48, 'dummy'),
(145285, 2161, 48, 'dummy'),
(145286, 2162, 48, 'dummy'),
(145287, 2163, 48, 'dummy'),
(145288, 2164, 48, 'dummy'),
(145289, 2165, 48, 'dummy'),
(145290, 2166, 48, 'dummy'),
(145291, 2167, 48, 'dummy'),
(145292, 2168, 48, 'dummy');
INSERT INTO `lang_definitions` VALUES
(145293, 2169, 48, 'dummy'),
(145294, 2170, 48, 'dummy'),
(145295, 2171, 48, 'dummy'),
(145296, 2172, 48, 'dummy'),
(145297, 2173, 48, 'dummy'),
(145298, 2174, 48, 'dummy'),
(145299, 2175, 48, 'dummy'),
(145300, 2176, 48, 'dummy'),
(145301, 2177, 48, 'dummy'),
(145302, 2178, 48, 'dummy'),
(145303, 2179, 48, 'dummy'),
(145304, 2180, 48, 'dummy'),
(145305, 2181, 48, 'dummy'),
(145306, 2182, 48, 'dummy'),
(145307, 2183, 48, 'dummy'),
(145308, 2184, 48, 'dummy'),
(145309, 2185, 48, 'dummy'),
(145310, 2186, 48, 'dummy'),
(145311, 2187, 48, 'dummy'),
(145312, 2188, 48, 'dummy'),
(145313, 2189, 48, 'dummy'),
(145314, 2190, 48, 'dummy'),
(145315, 2191, 48, 'dummy'),
(145316, 2192, 48, 'dummy'),
(145317, 2193, 48, 'dummy'),
(145318, 2194, 48, 'dummy'),
(145319, 2195, 48, 'dummy'),
(145320, 2196, 48, 'dummy'),
(145321, 2197, 48, 'dummy'),
(145322, 2198, 48, 'dummy'),
(145323, 2199, 48, 'dummy'),
(145324, 2200, 48, 'dummy'),
(145325, 2201, 48, 'dummy'),
(145326, 2202, 48, 'dummy'),
(145327, 2203, 48, 'dummy'),
(145328, 2204, 48, 'dummy'),
(145329, 2205, 48, 'dummy'),
(145330, 2206, 48, 'dummy'),
(145331, 2207, 48, 'dummy'),
(145332, 2208, 48, 'dummy'),
(145333, 2209, 48, 'dummy'),
(145334, 2210, 48, 'dummy'),
(145335, 2211, 48, 'dummy'),
(145336, 2212, 48, 'dummy'),
(145337, 2213, 48, 'dummy'),
(145338, 2214, 48, 'dummy'),
(145339, 2215, 48, 'dummy'),
(145340, 2216, 48, 'dummy'),
(145341, 2217, 48, 'dummy'),
(145342, 2218, 48, 'dummy'),
(145343, 2219, 48, 'dummy'),
(145344, 2220, 48, 'dummy'),
(145345, 2221, 48, 'dummy'),
(145346, 2222, 48, 'dummy'),
(145347, 2223, 48, 'dummy'),
(145348, 2224, 48, 'dummy'),
(145349, 2225, 48, 'dummy'),
(145350, 2226, 48, 'dummy'),
(145351, 2227, 48, 'dummy'),
(145352, 2228, 48, 'dummy'),
(145353, 2229, 48, 'dummy'),
(145354, 2230, 48, 'dummy'),
(145355, 2231, 48, 'dummy'),
(145356, 2232, 48, 'dummy'),
(145357, 2233, 48, 'dummy'),
(145358, 2234, 48, 'dummy'),
(145359, 2235, 48, 'dummy'),
(145360, 2236, 48, 'dummy'),
(145361, 2237, 48, 'dummy'),
(145362, 2238, 48, 'dummy'),
(145363, 2239, 48, 'dummy'),
(145364, 2240, 48, 'dummy'),
(145365, 2241, 48, 'dummy'),
(145366, 2242, 48, 'dummy'),
(145367, 2243, 48, 'dummy'),
(145368, 2244, 48, 'dummy'),
(145369, 2245, 48, 'dummy'),
(145370, 2246, 48, 'dummy'),
(145371, 2247, 48, 'dummy'),
(145372, 2248, 48, 'dummy'),
(145373, 2249, 48, 'dummy'),
(145374, 2250, 48, 'dummy'),
(145375, 2251, 48, 'dummy'),
(145376, 2252, 48, 'dummy'),
(145377, 2253, 48, 'dummy'),
(145378, 2254, 48, 'dummy'),
(145379, 2255, 48, 'dummy'),
(145380, 2256, 48, 'dummy'),
(145381, 2257, 48, 'dummy'),
(145382, 2258, 48, 'dummy'),
(145383, 2259, 48, 'dummy'),
(145384, 2260, 48, 'dummy'),
(145385, 2261, 48, 'dummy'),
(145386, 2262, 48, 'dummy'),
(145387, 2263, 48, 'dummy'),
(145388, 2264, 48, 'dummy'),
(145389, 2265, 48, 'dummy'),
(145390, 2266, 48, 'dummy'),
(145391, 2267, 48, 'dummy'),
(145392, 2268, 48, 'dummy'),
(145393, 2269, 48, 'dummy'),
(145394, 2270, 48, 'dummy'),
(145395, 2271, 48, 'dummy'),
(145396, 2272, 48, 'dummy'),
(145397, 2273, 48, 'dummy'),
(145398, 2274, 48, 'dummy'),
(145399, 2275, 48, 'dummy'),
(145400, 2276, 48, 'dummy'),
(145401, 2277, 48, 'dummy'),
(145402, 2278, 48, 'dummy'),
(145403, 2279, 48, 'dummy'),
(145404, 2280, 48, 'dummy'),
(145405, 2281, 48, 'dummy'),
(145406, 2282, 48, 'dummy'),
(145407, 2283, 48, 'dummy'),
(145408, 2284, 48, 'dummy'),
(145409, 2285, 48, 'dummy'),
(145410, 2286, 48, 'dummy'),
(145411, 2287, 48, 'dummy'),
(145412, 2288, 48, 'dummy'),
(145413, 2289, 48, 'dummy'),
(145414, 2290, 48, 'dummy'),
(145415, 2291, 48, 'dummy'),
(145416, 2292, 48, 'dummy'),
(145417, 2293, 48, 'dummy'),
(145418, 2294, 48, 'dummy'),
(145419, 2295, 48, 'dummy'),
(145420, 2296, 48, 'dummy'),
(145421, 2297, 48, 'dummy'),
(145422, 2298, 48, 'dummy'),
(145423, 2299, 48, 'dummy'),
(145424, 2300, 48, 'dummy'),
(145425, 2301, 48, 'dummy'),
(145426, 2302, 48, 'dummy'),
(145427, 2303, 48, 'dummy'),
(145428, 2304, 48, 'dummy'),
(145429, 2305, 48, 'dummy'),
(145430, 2306, 48, 'dummy'),
(145431, 2307, 48, 'dummy'),
(145432, 2308, 48, 'dummy'),
(145433, 2309, 48, 'dummy'),
(145434, 2310, 48, 'dummy'),
(145435, 2311, 48, 'dummy'),
(145436, 2312, 48, 'dummy'),
(145437, 2313, 48, 'dummy'),
(145438, 2314, 48, 'dummy'),
(145439, 2315, 48, 'dummy'),
(145440, 2316, 48, 'dummy'),
(145441, 2317, 48, 'dummy'),
(145442, 2318, 48, 'dummy'),
(145443, 2319, 48, 'dummy'),
(145444, 2320, 48, 'dummy'),
(145445, 2321, 48, 'dummy'),
(145446, 2322, 48, 'dummy'),
(145447, 2323, 48, 'dummy'),
(145448, 2324, 48, 'dummy'),
(145449, 2325, 48, 'dummy'),
(145450, 2326, 48, 'dummy'),
(145451, 2327, 48, 'dummy'),
(145452, 2328, 48, 'dummy'),
(145453, 2329, 48, 'dummy'),
(145454, 2330, 48, 'dummy'),
(145455, 2331, 48, 'dummy'),
(145456, 2332, 48, 'dummy'),
(145457, 2333, 48, 'dummy'),
(145458, 2334, 48, 'dummy'),
(145459, 2335, 48, 'dummy'),
(145460, 2336, 48, 'dummy'),
(145461, 2337, 48, 'dummy'),
(145462, 2338, 48, 'dummy'),
(145463, 2339, 48, 'dummy'),
(145464, 2340, 48, 'dummy'),
(145465, 2341, 48, 'dummy'),
(145466, 2342, 48, 'dummy'),
(145467, 2343, 48, 'dummy'),
(145468, 2344, 48, 'dummy'),
(145469, 2345, 48, 'dummy'),
(145470, 2346, 48, 'dummy'),
(145471, 2347, 48, 'dummy'),
(145472, 2348, 48, 'dummy'),
(145473, 2349, 48, 'dummy'),
(145474, 2350, 48, 'dummy'),
(145475, 2351, 48, 'dummy'),
(145476, 2352, 48, 'dummy'),
(145477, 2353, 48, 'dummy'),
(145478, 2354, 48, 'dummy'),
(145479, 2355, 48, 'dummy'),
(145480, 2356, 48, 'dummy'),
(145481, 2357, 48, 'dummy'),
(145482, 2358, 48, 'dummy'),
(145483, 2359, 48, 'dummy'),
(145484, 2360, 48, 'dummy'),
(145485, 2361, 48, 'dummy'),
(145486, 2362, 48, 'dummy'),
(145487, 2363, 48, 'dummy'),
(145488, 2364, 48, 'dummy'),
(145489, 2365, 48, 'dummy'),
(145490, 2366, 48, 'dummy'),
(145491, 2367, 48, 'dummy'),
(145492, 2368, 48, 'dummy'),
(145493, 2369, 48, 'dummy'),
(145494, 2370, 48, 'dummy'),
(145495, 2371, 48, 'dummy'),
(145496, 2372, 48, 'dummy'),
(145497, 2373, 48, 'dummy'),
(145498, 2374, 48, 'dummy'),
(145499, 2375, 48, 'dummy'),
(145500, 2376, 48, 'dummy'),
(145501, 2377, 48, 'dummy'),
(145502, 2378, 48, 'dummy'),
(145503, 2379, 48, 'dummy'),
(145504, 2380, 48, 'dummy'),
(145505, 2381, 48, 'dummy'),
(145506, 2382, 48, 'dummy'),
(145507, 2383, 48, 'dummy'),
(145508, 2384, 48, 'dummy'),
(145509, 2385, 48, 'dummy'),
(145510, 2386, 48, 'dummy'),
(145511, 2387, 48, 'dummy'),
(145512, 2388, 48, 'dummy'),
(145513, 2389, 48, 'dummy'),
(145514, 2390, 48, 'dummy'),
(145515, 2391, 48, 'dummy'),
(145516, 2392, 48, 'dummy'),
(145517, 2393, 48, 'dummy'),
(145518, 2394, 48, 'dummy'),
(145519, 2395, 48, 'dummy'),
(145520, 2396, 48, 'dummy'),
(145521, 2397, 48, 'dummy'),
(145522, 2398, 48, 'dummy'),
(145523, 2399, 48, 'dummy'),
(145524, 2400, 48, 'dummy'),
(145525, 2401, 48, 'dummy'),
(145526, 2402, 48, 'dummy'),
(145527, 2403, 48, 'dummy'),
(145528, 2404, 48, 'dummy'),
(145529, 2405, 48, 'dummy'),
(145530, 2406, 48, 'dummy'),
(145531, 2407, 48, 'dummy'),
(145532, 2408, 48, 'dummy'),
(145533, 2409, 48, 'dummy'),
(145534, 2410, 48, 'dummy'),
(145535, 2411, 48, 'dummy'),
(145536, 2412, 48, 'dummy'),
(145537, 2413, 48, 'dummy'),
(145538, 2414, 48, 'dummy'),
(145539, 2415, 48, 'dummy'),
(145540, 2416, 48, 'dummy'),
(145541, 2417, 48, 'dummy'),
(145542, 2418, 48, 'dummy'),
(145543, 2419, 48, 'dummy'),
(145544, 2420, 48, 'dummy'),
(145545, 2421, 48, 'dummy'),
(145546, 2422, 48, 'dummy'),
(145547, 2423, 48, 'dummy'),
(145548, 2424, 48, 'dummy'),
(145549, 2425, 48, 'dummy'),
(145550, 2426, 48, 'dummy'),
(145551, 2427, 48, 'dummy'),
(145552, 2428, 48, 'dummy'),
(145553, 2429, 48, 'dummy'),
(145554, 2430, 48, 'dummy'),
(145555, 2431, 48, 'dummy'),
(145556, 2432, 48, 'dummy'),
(145557, 2433, 48, 'dummy'),
(145558, 2434, 48, 'dummy'),
(145559, 2435, 48, 'dummy'),
(145560, 2436, 48, 'dummy'),
(145561, 2437, 48, 'dummy'),
(145562, 2438, 48, 'dummy'),
(145563, 2439, 48, 'dummy'),
(145564, 2440, 48, 'dummy'),
(145565, 2441, 48, 'dummy'),
(145566, 2442, 48, 'dummy'),
(145567, 2443, 48, 'dummy'),
(145568, 2444, 48, 'dummy'),
(145569, 2445, 48, 'dummy'),
(145570, 2446, 48, 'dummy'),
(145571, 2447, 48, 'dummy'),
(145572, 2448, 48, 'dummy'),
(145573, 2449, 48, 'dummy'),
(145574, 2450, 48, 'dummy'),
(145575, 2451, 48, 'dummy'),
(145576, 2452, 48, 'dummy'),
(145577, 2453, 48, 'dummy'),
(145578, 2454, 48, 'dummy'),
(145579, 2455, 48, 'dummy'),
(145580, 2456, 48, 'dummy'),
(145581, 2457, 48, 'dummy'),
(145582, 2458, 48, 'dummy'),
(145583, 2459, 48, 'dummy'),
(145584, 2460, 48, 'dummy'),
(145585, 2461, 48, 'dummy'),
(145586, 2462, 48, 'dummy'),
(145587, 2463, 48, 'dummy'),
(145588, 2464, 48, 'dummy'),
(145589, 2465, 48, 'dummy'),
(145590, 2466, 48, 'dummy'),
(145591, 2467, 48, 'dummy'),
(145592, 2468, 48, 'dummy'),
(145593, 2469, 48, 'dummy'),
(145594, 2470, 48, 'dummy'),
(145595, 2471, 48, 'dummy'),
(145596, 2472, 48, 'dummy'),
(145597, 2473, 48, 'dummy'),
(145598, 2474, 48, 'dummy'),
(145599, 2475, 48, 'dummy'),
(145600, 2476, 48, 'dummy'),
(145601, 2477, 48, 'dummy'),
(145602, 2478, 48, 'dummy'),
(145603, 2479, 48, 'dummy'),
(145604, 2480, 48, 'dummy'),
(145605, 2481, 48, 'dummy'),
(145606, 2482, 48, 'dummy'),
(145607, 2483, 48, 'dummy'),
(145608, 2484, 48, 'dummy'),
(145609, 2485, 48, 'dummy'),
(145610, 2486, 48, 'dummy'),
(145611, 2487, 48, 'dummy'),
(145612, 2488, 48, 'dummy'),
(145613, 2489, 48, 'dummy'),
(145614, 2490, 48, 'dummy'),
(145615, 2491, 48, 'dummy'),
(145616, 2492, 48, 'dummy'),
(145617, 2493, 48, 'dummy'),
(145618, 2494, 48, 'dummy'),
(145619, 2495, 48, 'dummy'),
(145620, 2496, 48, 'dummy'),
(145621, 2497, 48, 'dummy'),
(145622, 2498, 48, 'dummy'),
(145623, 2499, 48, 'dummy'),
(145624, 2500, 48, 'dummy'),
(145625, 2501, 48, 'dummy'),
(145626, 2502, 48, 'dummy'),
(145627, 2503, 48, 'dummy'),
(145628, 2504, 48, 'dummy'),
(145629, 2505, 48, 'dummy'),
(145630, 2506, 48, 'dummy'),
(145631, 2507, 48, 'dummy'),
(145632, 2508, 48, 'dummy'),
(145633, 2509, 48, 'dummy'),
(145634, 2510, 48, 'dummy'),
(145635, 2511, 48, 'dummy'),
(145636, 2512, 48, 'dummy'),
(145637, 2513, 48, 'dummy'),
(145638, 2514, 48, 'dummy'),
(145639, 2515, 48, 'dummy'),
(145640, 2516, 48, 'dummy'),
(145641, 2517, 48, 'dummy'),
(145642, 2518, 48, 'dummy'),
(145643, 2519, 48, 'dummy'),
(145644, 2520, 48, 'dummy'),
(145645, 2521, 48, 'dummy'),
(145646, 2522, 48, 'dummy'),
(145647, 2523, 48, 'dummy'),
(145648, 2524, 48, 'dummy'),
(145649, 2525, 48, 'dummy'),
(145650, 2526, 48, 'dummy'),
(145651, 2527, 48, 'dummy'),
(145652, 2528, 48, 'dummy'),
(145653, 2529, 48, 'dummy'),
(145654, 2530, 48, 'dummy'),
(145655, 2531, 48, 'dummy'),
(145656, 2532, 48, 'dummy'),
(145657, 2533, 48, 'dummy'),
(145658, 2534, 48, 'dummy'),
(145659, 2535, 48, 'dummy'),
(145660, 2536, 48, 'dummy'),
(145661, 2537, 48, 'dummy'),
(145662, 2538, 48, 'dummy'),
(145663, 2539, 48, 'dummy'),
(145664, 2540, 48, 'dummy'),
(145665, 2541, 48, 'dummy'),
(145666, 2542, 48, 'dummy'),
(145667, 2543, 48, 'dummy'),
(145668, 2544, 48, 'dummy'),
(145669, 2545, 48, 'dummy'),
(145670, 2546, 48, 'dummy'),
(145671, 2547, 48, 'dummy'),
(145672, 2548, 48, 'dummy'),
(145673, 2549, 48, 'dummy'),
(145674, 2550, 48, 'dummy'),
(145675, 2551, 48, 'dummy'),
(145676, 2552, 48, 'dummy'),
(145677, 2553, 48, 'dummy'),
(145678, 2554, 48, 'dummy'),
(145679, 2555, 48, 'dummy'),
(145680, 2556, 48, 'dummy'),
(145681, 2557, 48, 'dummy'),
(145682, 2558, 48, 'dummy'),
(145683, 2559, 48, 'dummy'),
(145684, 2560, 48, 'dummy'),
(145685, 2561, 48, 'dummy'),
(145686, 2562, 48, 'dummy'),
(145687, 2563, 48, 'dummy'),
(145688, 2564, 48, 'dummy'),
(145689, 2565, 48, 'dummy'),
(145690, 2566, 48, 'dummy'),
(145691, 2567, 48, 'dummy'),
(145692, 2568, 48, 'dummy'),
(145693, 2569, 48, 'dummy'),
(145694, 2570, 48, 'dummy'),
(145695, 2571, 48, 'dummy'),
(145696, 2572, 48, 'dummy'),
(145697, 2573, 48, 'dummy'),
(145698, 2574, 48, 'dummy'),
(145699, 2575, 48, 'dummy'),
(145700, 2576, 48, 'dummy'),
(145701, 2577, 48, 'dummy'),
(145702, 2578, 48, 'dummy'),
(145703, 2579, 48, 'dummy'),
(145704, 2580, 48, 'dummy'),
(145705, 2581, 48, 'dummy'),
(145706, 2582, 48, 'dummy'),
(145707, 2583, 48, 'dummy'),
(145708, 2584, 48, 'dummy'),
(145709, 2585, 48, 'dummy'),
(145710, 2586, 48, 'dummy'),
(145711, 2587, 48, 'dummy'),
(145712, 2588, 48, 'dummy'),
(145713, 2589, 48, 'dummy'),
(145714, 2590, 48, 'dummy'),
(145715, 2591, 48, 'dummy'),
(145716, 2592, 48, 'dummy'),
(145717, 2593, 48, 'dummy'),
(145718, 2594, 48, 'dummy'),
(145719, 2595, 48, 'dummy'),
(145720, 2596, 48, 'dummy'),
(145721, 2597, 48, 'dummy'),
(145722, 2598, 48, 'dummy'),
(145723, 2599, 48, 'dummy'),
(145724, 2600, 48, 'dummy'),
(145725, 2601, 48, 'dummy'),
(145726, 2602, 48, 'dummy'),
(145727, 2603, 48, 'dummy'),
(145728, 2604, 48, 'dummy'),
(145729, 2605, 48, 'dummy'),
(145730, 2606, 48, 'dummy'),
(145731, 2607, 48, 'dummy'),
(145732, 2608, 48, 'dummy'),
(145733, 2609, 48, 'dummy'),
(145734, 2610, 48, 'dummy'),
(145735, 2611, 48, 'dummy'),
(145736, 2612, 48, 'dummy'),
(145737, 2613, 48, 'dummy'),
(145738, 2614, 48, 'dummy'),
(145739, 2615, 48, 'dummy'),
(145740, 2616, 48, 'dummy'),
(145741, 2617, 48, 'dummy'),
(145742, 2618, 48, 'dummy'),
(145743, 2619, 48, 'dummy'),
(145744, 2620, 48, 'dummy'),
(145745, 2621, 48, 'dummy'),
(145746, 2622, 48, 'dummy'),
(145747, 2623, 48, 'dummy'),
(145748, 2624, 48, 'dummy'),
(145749, 2625, 48, 'dummy'),
(145750, 2626, 48, 'dummy'),
(145751, 2627, 48, 'dummy'),
(145752, 2628, 48, 'dummy'),
(145753, 2629, 48, 'dummy'),
(145754, 2630, 48, 'dummy'),
(145755, 2631, 48, 'dummy'),
(145756, 2632, 48, 'dummy'),
(145757, 2633, 48, 'dummy'),
(145758, 2634, 48, 'dummy'),
(145759, 2635, 48, 'dummy'),
(145760, 2636, 48, 'dummy'),
(145761, 2637, 48, 'dummy'),
(145762, 2638, 48, 'dummy'),
(145763, 2639, 48, 'dummy'),
(145764, 2640, 48, 'dummy'),
(145765, 2641, 48, 'dummy'),
(145766, 2642, 48, 'dummy'),
(145767, 2643, 48, 'dummy'),
(145768, 2644, 48, 'dummy'),
(145769, 2645, 48, 'dummy'),
(145770, 2646, 48, 'dummy'),
(145771, 2647, 48, 'dummy'),
(145772, 2648, 48, 'dummy'),
(145773, 2649, 48, 'dummy'),
(145774, 2650, 48, 'dummy'),
(145775, 2651, 48, 'dummy'),
(145776, 2652, 48, 'dummy'),
(145777, 2653, 48, 'dummy'),
(145778, 2654, 48, 'dummy'),
(145779, 2655, 48, 'dummy'),
(145780, 2656, 48, 'dummy'),
(145781, 2657, 48, 'dummy'),
(145782, 2658, 48, 'dummy'),
(145783, 2659, 48, 'dummy'),
(145784, 2660, 48, 'dummy'),
(145785, 2661, 48, 'dummy'),
(145786, 2662, 48, 'dummy'),
(145787, 2663, 48, 'dummy'),
(145788, 2664, 48, 'dummy'),
(145789, 2665, 48, 'dummy'),
(145790, 2666, 48, 'dummy'),
(145791, 2667, 48, 'dummy'),
(145792, 2668, 48, 'dummy'),
(145793, 2669, 48, 'dummy'),
(145794, 2670, 48, 'dummy'),
(145795, 2671, 48, 'dummy'),
(145796, 2672, 48, 'dummy'),
(145797, 2673, 48, 'dummy'),
(145798, 2674, 48, 'dummy'),
(145799, 2675, 48, 'dummy'),
(145800, 2676, 48, 'dummy'),
(145801, 2677, 48, 'dummy'),
(145802, 2678, 48, 'dummy'),
(145803, 2679, 48, 'dummy'),
(145804, 2680, 48, 'dummy'),
(145805, 2681, 48, 'dummy'),
(145806, 2682, 48, 'dummy'),
(145807, 2683, 48, 'dummy'),
(145808, 2684, 48, 'dummy'),
(145809, 2685, 48, 'dummy'),
(145810, 2686, 48, 'dummy'),
(145811, 2687, 48, 'dummy'),
(145812, 2688, 48, 'dummy'),
(145813, 2689, 48, 'dummy'),
(145814, 2690, 48, 'dummy'),
(145815, 2691, 48, 'dummy'),
(145816, 2692, 48, 'dummy'),
(145817, 2693, 48, 'dummy'),
(145818, 2694, 48, 'dummy'),
(145819, 2695, 48, 'dummy'),
(145820, 2696, 48, 'dummy'),
(145821, 2697, 48, 'dummy'),
(145822, 2698, 48, 'dummy'),
(145823, 2699, 48, 'dummy'),
(145824, 2700, 48, 'dummy'),
(145825, 2701, 48, 'dummy'),
(145826, 2702, 48, 'dummy'),
(145827, 2703, 48, 'dummy'),
(145828, 2704, 48, 'dummy'),
(145829, 2705, 48, 'dummy'),
(145830, 2706, 48, 'dummy'),
(145831, 2707, 48, 'dummy'),
(145832, 2708, 48, 'dummy'),
(145833, 2709, 48, 'dummy'),
(145834, 2710, 48, 'dummy'),
(145835, 2711, 48, 'dummy'),
(145836, 2712, 48, 'dummy'),
(145837, 2713, 48, 'dummy'),
(145838, 2714, 48, 'dummy'),
(145839, 2715, 48, 'dummy'),
(145840, 2716, 48, 'dummy'),
(145841, 2717, 48, 'dummy'),
(145842, 2718, 48, 'dummy'),
(145843, 2719, 48, 'dummy'),
(145844, 2720, 48, 'dummy'),
(145845, 2721, 48, 'dummy'),
(145846, 2722, 48, 'dummy'),
(145847, 2723, 48, 'dummy'),
(145848, 2724, 48, 'dummy'),
(145849, 2725, 48, 'dummy'),
(145850, 2726, 48, 'dummy'),
(145851, 2727, 48, 'dummy'),
(145852, 2728, 48, 'dummy'),
(145853, 2729, 48, 'dummy'),
(145854, 2730, 48, 'dummy'),
(145855, 2731, 48, 'dummy'),
(145856, 2732, 48, 'dummy'),
(145857, 2733, 48, 'dummy'),
(145858, 2734, 48, 'dummy'),
(145859, 2735, 48, 'dummy'),
(145860, 2736, 48, 'dummy'),
(145861, 2737, 48, 'dummy'),
(145862, 2738, 48, 'dummy'),
(145863, 2739, 48, 'dummy'),
(145864, 2740, 48, 'dummy'),
(145865, 2741, 48, 'dummy'),
(145866, 2742, 48, 'dummy'),
(145867, 2743, 48, 'dummy'),
(145868, 2744, 48, 'dummy'),
(145869, 2745, 48, 'dummy'),
(145870, 2746, 48, 'dummy'),
(145871, 2747, 48, 'dummy'),
(145872, 2748, 48, 'dummy'),
(145873, 2749, 48, 'dummy'),
(145874, 2750, 48, 'dummy'),
(145875, 2751, 48, 'dummy'),
(145876, 2752, 48, 'dummy'),
(145877, 2753, 48, 'dummy'),
(145878, 2754, 48, 'dummy'),
(145879, 2755, 48, 'dummy'),
(145880, 2756, 48, 'dummy'),
(145881, 2757, 48, 'dummy'),
(145882, 2758, 48, 'dummy'),
(145883, 2759, 48, 'dummy'),
(145884, 2760, 48, 'dummy'),
(145885, 2761, 48, 'dummy'),
(145886, 2762, 48, 'dummy'),
(145887, 2763, 48, 'dummy'),
(145888, 2764, 48, 'dummy'),
(145889, 2765, 48, 'dummy'),
(145890, 2766, 48, 'dummy'),
(145891, 2767, 48, 'dummy'),
(145892, 2768, 48, 'dummy'),
(145893, 2769, 48, 'dummy'),
(145894, 2770, 48, 'dummy'),
(145895, 2771, 48, 'dummy'),
(145896, 2772, 48, 'dummy'),
(145897, 2773, 48, 'dummy'),
(145898, 2774, 48, 'dummy'),
(145899, 2775, 48, 'dummy'),
(145900, 2776, 48, 'dummy'),
(145901, 2777, 48, 'dummy'),
(145902, 2778, 48, 'dummy'),
(145903, 2779, 48, 'dummy'),
(145904, 2780, 48, 'dummy'),
(145905, 2781, 48, 'dummy'),
(145906, 2782, 48, 'dummy'),
(145907, 2783, 48, 'dummy'),
(145908, 2784, 48, 'dummy'),
(145909, 2785, 48, 'dummy'),
(145910, 2786, 48, 'dummy'),
(145911, 2787, 48, 'dummy'),
(145912, 2788, 48, 'dummy'),
(145913, 2789, 48, 'dummy'),
(145914, 2790, 48, 'dummy'),
(145915, 2791, 48, 'dummy'),
(145916, 2792, 48, 'dummy'),
(145917, 2793, 48, 'dummy'),
(145918, 2794, 48, 'dummy'),
(145919, 2795, 48, 'dummy'),
(145920, 2796, 48, 'dummy'),
(145921, 2797, 48, 'dummy'),
(145922, 2798, 48, 'dummy'),
(145923, 2799, 48, 'dummy'),
(145924, 2800, 48, 'dummy'),
(145925, 2801, 48, 'dummy'),
(145926, 2802, 48, 'dummy'),
(145927, 2803, 48, 'dummy'),
(145928, 2804, 48, 'dummy'),
(145929, 2805, 48, 'dummy'),
(145930, 2806, 48, 'dummy'),
(145931, 2807, 48, 'dummy'),
(145932, 2808, 48, 'dummy'),
(145933, 2809, 48, 'dummy'),
(145934, 2810, 48, 'dummy'),
(145935, 2811, 48, 'dummy'),
(145936, 2812, 48, 'dummy'),
(145937, 2813, 48, 'dummy'),
(145938, 2814, 48, 'dummy'),
(145939, 2815, 48, 'dummy'),
(145940, 2816, 48, 'dummy'),
(145941, 2817, 48, 'dummy'),
(145942, 2818, 48, 'dummy'),
(145943, 2819, 48, 'dummy'),
(145944, 2820, 48, 'dummy'),
(145945, 2821, 48, 'dummy'),
(145946, 2822, 48, 'dummy'),
(145947, 2823, 48, 'dummy'),
(145948, 2824, 48, 'dummy'),
(145949, 2825, 48, 'dummy'),
(145950, 2826, 48, 'dummy'),
(145951, 2827, 48, 'dummy'),
(145952, 2828, 48, 'dummy'),
(145953, 2829, 48, 'dummy'),
(145954, 2830, 48, 'dummy'),
(145955, 2831, 48, 'dummy'),
(145956, 2832, 48, 'dummy'),
(145957, 2833, 48, 'dummy'),
(145958, 2834, 48, 'dummy'),
(145959, 2835, 48, 'dummy'),
(145960, 2836, 48, 'dummy'),
(145961, 2837, 48, 'dummy'),
(145962, 2838, 48, 'dummy'),
(145963, 2839, 48, 'dummy'),
(145964, 2840, 48, 'dummy'),
(145965, 2841, 48, 'dummy'),
(145966, 2842, 48, 'dummy'),
(145967, 2843, 48, 'dummy'),
(145968, 2844, 48, 'dummy'),
(145969, 2845, 48, 'dummy'),
(145970, 2846, 48, 'dummy'),
(145971, 2847, 48, 'dummy'),
(145972, 2848, 48, 'dummy'),
(145973, 2849, 48, 'dummy'),
(145974, 2850, 48, 'dummy'),
(145975, 2851, 48, 'dummy'),
(145976, 2852, 48, 'dummy'),
(145977, 2853, 48, 'dummy'),
(145978, 2854, 48, 'dummy'),
(145979, 2855, 48, 'dummy'),
(145980, 2856, 48, 'dummy'),
(145981, 2857, 48, 'dummy'),
(145982, 2858, 48, 'dummy'),
(145983, 2859, 48, 'dummy'),
(145984, 2860, 48, 'dummy'),
(145985, 2861, 48, 'dummy'),
(145986, 2862, 48, 'dummy'),
(145987, 2863, 48, 'dummy'),
(145988, 2864, 48, 'dummy'),
(145989, 2865, 48, 'dummy'),
(145990, 2866, 48, 'dummy'),
(145991, 2867, 48, 'dummy'),
(145992, 2868, 48, 'dummy'),
(145993, 2869, 48, 'dummy'),
(145994, 2870, 48, 'dummy'),
(145995, 2871, 48, 'dummy'),
(145996, 2872, 48, 'dummy'),
(145997, 2873, 48, 'dummy'),
(145998, 2874, 48, 'dummy'),
(145999, 2875, 48, 'dummy'),
(146000, 2876, 48, 'dummy'),
(146001, 2877, 48, 'dummy'),
(146002, 2878, 48, 'dummy'),
(146003, 2879, 48, 'dummy'),
(146004, 2880, 48, 'dummy'),
(146005, 2881, 48, 'dummy'),
(146006, 2882, 48, 'dummy'),
(146007, 2883, 48, 'dummy'),
(146008, 2884, 48, 'dummy'),
(146009, 2885, 48, 'dummy'),
(146010, 2886, 48, 'dummy'),
(146011, 2887, 48, 'dummy'),
(146012, 2888, 48, 'dummy'),
(146013, 2889, 48, 'dummy'),
(146014, 2890, 48, 'dummy'),
(146015, 2891, 48, 'dummy'),
(146016, 2892, 48, 'dummy'),
(146017, 2893, 48, 'dummy'),
(146018, 2894, 48, 'dummy'),
(146019, 2895, 48, 'dummy'),
(146020, 2896, 48, 'dummy'),
(146021, 2897, 48, 'dummy'),
(146022, 2898, 48, 'dummy'),
(146023, 2899, 48, 'dummy'),
(146024, 2900, 48, 'dummy'),
(146025, 2901, 48, 'dummy'),
(146026, 2902, 48, 'dummy'),
(146027, 2903, 48, 'dummy'),
(146028, 2904, 48, 'dummy'),
(146029, 2905, 48, 'dummy'),
(146030, 2906, 48, 'dummy'),
(146031, 2907, 48, 'dummy'),
(146032, 2908, 48, 'dummy'),
(146033, 2909, 48, 'dummy'),
(146034, 2910, 48, 'dummy'),
(146035, 2911, 48, 'dummy'),
(146036, 2912, 48, 'dummy'),
(146037, 2913, 48, 'dummy'),
(146038, 2914, 48, 'dummy'),
(146039, 2915, 48, 'dummy'),
(146040, 2916, 48, 'dummy'),
(146041, 2917, 48, 'dummy'),
(146042, 2918, 48, 'dummy'),
(146043, 2919, 48, 'dummy'),
(146044, 2920, 48, 'dummy'),
(146045, 2921, 48, 'dummy'),
(146046, 2922, 48, 'dummy'),
(146047, 2923, 48, 'dummy'),
(146048, 2924, 48, 'dummy'),
(146049, 2925, 48, 'dummy'),
(146050, 2926, 48, 'dummy'),
(146051, 2927, 48, 'dummy'),
(146052, 2928, 48, 'dummy'),
(146053, 2929, 48, 'dummy'),
(146054, 2930, 48, 'dummy'),
(146055, 2931, 48, 'dummy'),
(146056, 2932, 48, 'dummy'),
(146057, 2933, 48, 'dummy'),
(146058, 2934, 48, 'dummy'),
(146059, 2935, 48, 'dummy'),
(146060, 2936, 48, 'dummy'),
(146061, 2937, 48, 'dummy'),
(146062, 2938, 48, 'dummy'),
(146063, 2939, 48, 'dummy'),
(146064, 2940, 48, 'dummy'),
(146065, 2941, 48, 'dummy'),
(146066, 2942, 48, 'dummy'),
(146067, 2943, 48, 'dummy'),
(146068, 2944, 48, 'dummy'),
(146069, 2945, 48, 'dummy'),
(146070, 2946, 48, 'dummy'),
(146071, 2947, 48, 'dummy'),
(146072, 2948, 48, 'dummy'),
(146073, 2949, 48, 'dummy'),
(146074, 2950, 48, 'dummy'),
(146075, 2951, 48, 'dummy'),
(146076, 2952, 48, 'dummy'),
(146077, 2953, 48, 'dummy'),
(146078, 2954, 48, 'dummy'),
(146079, 2955, 48, 'dummy'),
(146080, 2956, 48, 'dummy'),
(146081, 2957, 48, 'dummy'),
(146082, 2958, 48, 'dummy'),
(146083, 2959, 48, 'dummy'),
(146084, 2960, 48, 'dummy'),
(146085, 2961, 48, 'dummy'),
(146086, 2962, 48, 'dummy'),
(146087, 2963, 48, 'dummy'),
(146088, 2964, 48, 'dummy'),
(146089, 2965, 48, 'dummy'),
(146090, 2966, 48, 'dummy'),
(146091, 2967, 48, 'dummy'),
(146092, 2968, 48, 'dummy'),
(146093, 2969, 48, 'dummy'),
(146094, 2970, 48, 'dummy'),
(146095, 2971, 48, 'dummy'),
(146096, 2972, 48, 'dummy'),
(146097, 2973, 48, 'dummy'),
(146098, 2974, 48, 'dummy'),
(146099, 2975, 48, 'dummy'),
(146100, 2976, 48, 'dummy'),
(146101, 2977, 48, 'dummy'),
(146102, 2978, 48, 'dummy'),
(146103, 2979, 48, 'dummy'),
(146104, 2980, 48, 'dummy'),
(146105, 2981, 48, 'dummy'),
(146106, 2982, 48, 'dummy'),
(146107, 2983, 48, 'dummy'),
(146108, 2984, 48, 'dummy'),
(146109, 2985, 48, 'dummy'),
(146110, 2986, 48, 'dummy'),
(146111, 2987, 48, 'dummy'),
(146112, 2988, 48, 'dummy'),
(146113, 2989, 48, 'dummy'),
(146114, 2990, 48, 'dummy'),
(146115, 2991, 48, 'dummy'),
(146116, 2992, 48, 'dummy'),
(146117, 2993, 48, 'dummy'),
(146118, 2994, 48, 'dummy'),
(146119, 2995, 48, 'dummy'),
(146120, 2996, 48, 'dummy'),
(146121, 2997, 48, 'dummy'),
(146122, 2998, 48, 'dummy'),
(146123, 2999, 48, 'dummy'),
(146124, 3000, 48, 'dummy'),
(146125, 3001, 48, 'dummy'),
(146126, 3002, 48, 'dummy'),
(146127, 3003, 48, 'dummy'),
(146128, 3004, 48, 'dummy'),
(146129, 3005, 48, 'dummy'),
(146130, 3006, 48, 'dummy'),
(146131, 3007, 48, 'dummy'),
(146132, 3008, 48, 'dummy'),
(146133, 3009, 48, 'dummy'),
(146134, 3010, 48, 'dummy'),
(146135, 3011, 48, 'dummy'),
(146136, 3012, 48, 'dummy'),
(146137, 3013, 48, 'dummy'),
(146138, 3014, 48, 'dummy'),
(146139, 3015, 48, 'dummy'),
(146140, 3016, 48, 'dummy'),
(146141, 3017, 48, 'dummy'),
(146142, 3018, 48, 'dummy'),
(146143, 3019, 48, 'dummy'),
(146144, 3020, 48, 'dummy'),
(146145, 3021, 48, 'dummy'),
(146146, 3022, 48, 'dummy'),
(146147, 3023, 48, 'dummy'),
(146148, 3024, 48, 'dummy'),
(146149, 3025, 48, 'dummy'),
(146150, 3026, 48, 'dummy'),
(146151, 3027, 48, 'dummy'),
(146152, 3028, 48, 'dummy'),
(146153, 3029, 48, 'dummy'),
(146154, 3030, 48, 'dummy'),
(146155, 3031, 48, 'dummy'),
(146156, 3032, 48, 'dummy'),
(146157, 3033, 48, 'dummy'),
(146158, 3034, 48, 'dummy'),
(146159, 3035, 48, 'dummy'),
(146160, 3036, 48, 'dummy'),
(146161, 3037, 48, 'dummy'),
(146162, 3038, 48, 'dummy'),
(146163, 3039, 48, 'dummy'),
(146164, 3040, 48, 'dummy'),
(146165, 3041, 48, 'dummy'),
(146166, 3042, 48, 'dummy'),
(146167, 3043, 48, 'dummy'),
(146168, 3044, 48, 'dummy'),
(146169, 3045, 48, 'dummy'),
(146170, 3046, 48, 'dummy'),
(146171, 3047, 48, 'dummy'),
(146172, 3048, 48, 'dummy'),
(146173, 3049, 48, 'dummy'),
(146174, 3050, 48, 'dummy'),
(146175, 3051, 48, 'dummy'),
(146176, 3052, 48, 'dummy'),
(146177, 3053, 48, 'dummy'),
(146178, 3054, 48, 'dummy'),
(146179, 3055, 48, 'dummy'),
(146180, 3056, 48, 'dummy'),
(146181, 3057, 48, 'dummy'),
(146182, 3058, 48, 'dummy'),
(146183, 3059, 48, 'dummy'),
(146184, 3060, 48, 'dummy'),
(146185, 3061, 48, 'dummy'),
(146186, 3062, 48, 'dummy'),
(146187, 3063, 48, 'dummy'),
(146188, 3064, 48, 'dummy'),
(146189, 3065, 48, 'dummy'),
(146190, 3066, 48, 'dummy'),
(146191, 3067, 48, 'dummy'),
(146192, 3068, 48, 'dummy'),
(146193, 3069, 48, 'dummy'),
(146194, 3070, 48, 'dummy'),
(146195, 3071, 48, 'dummy'),
(146196, 3072, 48, 'dummy'),
(146197, 3073, 48, 'dummy'),
(146198, 3074, 48, 'dummy'),
(146199, 3075, 48, 'dummy'),
(146200, 3076, 48, 'dummy'),
(146201, 3077, 48, 'dummy'),
(146202, 3078, 48, 'dummy'),
(146203, 3079, 48, 'dummy'),
(146204, 3080, 48, 'dummy'),
(146205, 3081, 48, 'dummy'),
(146206, 3082, 48, 'dummy'),
(146207, 3083, 48, 'dummy'),
(146208, 3084, 48, 'dummy'),
(146209, 3085, 48, 'dummy'),
(146210, 3086, 48, 'dummy'),
(146211, 3087, 48, 'dummy'),
(146212, 3088, 48, 'dummy'),
(146213, 3089, 48, 'dummy'),
(146214, 3090, 48, 'dummy'),
(146215, 3091, 48, 'dummy'),
(146216, 3092, 48, 'dummy'),
(146217, 3093, 48, 'dummy'),
(146218, 3094, 48, 'dummy'),
(146219, 3095, 48, 'dummy'),
(146220, 3096, 48, 'dummy'),
(146221, 3097, 48, 'dummy'),
(146222, 3098, 48, 'dummy'),
(146223, 3099, 48, 'dummy'),
(146224, 3100, 48, 'dummy'),
(146225, 3101, 48, 'dummy'),
(146226, 3102, 48, 'dummy'),
(146227, 3103, 48, 'dummy'),
(146228, 3104, 48, 'dummy'),
(146229, 3105, 48, 'dummy'),
(146230, 3106, 48, 'dummy'),
(146231, 3107, 48, 'dummy'),
(146232, 3108, 48, 'dummy'),
(146233, 3109, 48, 'dummy'),
(146234, 3110, 48, 'dummy'),
(146235, 3111, 48, 'dummy'),
(146236, 3112, 48, 'dummy'),
(146237, 3113, 48, 'dummy'),
(146238, 3114, 48, 'dummy'),
(146239, 3115, 48, 'dummy'),
(146240, 3116, 48, 'dummy'),
(146241, 3117, 48, 'dummy'),
(146242, 3118, 48, 'dummy'),
(146243, 3119, 48, 'dummy'),
(146244, 3120, 48, 'dummy'),
(146245, 3121, 48, 'dummy'),
(146246, 3122, 48, 'dummy'),
(146247, 3123, 48, 'dummy'),
(146248, 3124, 48, 'dummy'),
(146249, 3125, 48, 'dummy'),
(146250, 3126, 48, 'dummy'),
(146251, 3127, 48, 'dummy'),
(146252, 3128, 48, 'dummy'),
(146253, 3129, 48, 'dummy'),
(146254, 3130, 48, 'dummy'),
(146255, 3131, 48, 'dummy'),
(146256, 3132, 48, 'dummy'),
(146257, 3133, 48, 'dummy'),
(146258, 3134, 48, 'dummy'),
(146259, 3135, 48, 'dummy'),
(146260, 3136, 48, 'dummy'),
(146261, 3137, 48, 'dummy'),
(146262, 3138, 48, 'dummy'),
(146263, 3139, 48, 'dummy'),
(146264, 3140, 48, 'dummy'),
(146265, 3141, 48, 'dummy'),
(146266, 3142, 48, 'dummy'),
(146267, 3143, 48, 'dummy'),
(146268, 3144, 48, 'dummy'),
(146269, 3145, 48, 'dummy'),
(146270, 3146, 48, 'dummy'),
(146271, 3147, 48, 'dummy'),
(146272, 3148, 48, 'dummy'),
(146273, 3149, 48, 'dummy'),
(146274, 3150, 48, 'dummy'),
(146275, 3151, 48, 'dummy'),
(146276, 3152, 48, 'dummy'),
(146277, 3153, 48, 'dummy'),
(146278, 3154, 48, 'dummy'),
(146279, 3155, 48, 'dummy'),
(146280, 3156, 48, 'dummy'),
(146281, 3157, 48, 'dummy'),
(146282, 3158, 48, 'dummy'),
(146283, 3159, 48, 'dummy'),
(146284, 3160, 48, 'dummy'),
(146285, 3161, 48, 'dummy'),
(146286, 3162, 48, 'dummy'),
(146287, 3163, 48, 'dummy'),
(146288, 3164, 48, 'dummy'),
(146289, 3165, 48, 'dummy'),
(146290, 3166, 48, 'dummy'),
(146291, 3167, 48, 'dummy'),
(146292, 3168, 48, 'dummy'),
(146293, 3169, 48, 'dummy'),
(146294, 3170, 48, 'dummy'),
(146295, 3171, 48, 'dummy'),
(146296, 3172, 48, 'dummy'),
(146297, 3173, 48, 'dummy'),
(146298, 3174, 48, 'dummy'),
(146299, 3175, 48, 'dummy'),
(146300, 3176, 48, 'dummy'),
(146301, 3177, 48, 'dummy'),
(146302, 3178, 48, 'dummy'),
(146303, 3179, 48, 'dummy'),
(146304, 3180, 48, 'dummy'),
(146305, 3181, 48, 'dummy'),
(146306, 3182, 48, 'dummy'),
(146307, 3183, 48, 'dummy'),
(146308, 3184, 48, 'dummy'),
(146309, 3185, 48, 'dummy'),
(146310, 3186, 48, 'dummy'),
(146311, 3187, 48, 'dummy'),
(146312, 3188, 48, 'dummy'),
(146313, 3189, 48, 'dummy'),
(146314, 3190, 48, 'dummy'),
(146315, 3191, 48, 'dummy'),
(146316, 3192, 48, 'dummy'),
(146317, 3193, 48, 'dummy'),
(146318, 3194, 48, 'dummy'),
(146319, 3195, 48, 'dummy'),
(146320, 3196, 48, 'dummy'),
(146321, 3197, 48, 'dummy'),
(146322, 3198, 48, 'dummy'),
(146323, 3199, 48, 'dummy'),
(146324, 3200, 48, 'dummy'),
(146325, 3201, 48, 'dummy'),
(146326, 3202, 48, 'dummy'),
(146327, 3203, 48, 'dummy'),
(146328, 3204, 48, 'dummy'),
(146329, 3205, 48, 'dummy'),
(146330, 3206, 48, 'dummy'),
(146331, 3207, 48, 'dummy'),
(146332, 3208, 48, 'dummy'),
(146333, 3209, 48, 'dummy'),
(146334, 3210, 48, 'dummy'),
(146335, 3211, 48, 'dummy'),
(146336, 3212, 48, 'dummy'),
(146337, 3213, 48, 'dummy'),
(146338, 3214, 48, 'dummy'),
(146339, 3215, 48, 'dummy'),
(146340, 3216, 48, 'dummy'),
(146341, 3217, 48, 'dummy'),
(146342, 3218, 48, 'dummy'),
(146343, 3219, 48, 'dummy'),
(146344, 3220, 48, 'dummy'),
(146345, 3221, 48, 'dummy'),
(146346, 3222, 48, 'dummy'),
(146347, 3223, 48, 'dummy'),
(146348, 3224, 48, 'dummy'),
(146349, 3225, 48, 'dummy'),
(146350, 3226, 48, 'dummy'),
(146351, 3227, 48, 'dummy'),
(146352, 3228, 48, 'dummy'),
(146353, 3229, 48, 'dummy'),
(146354, 3230, 48, 'dummy'),
(146355, 3231, 48, 'dummy'),
(146356, 3232, 48, 'dummy'),
(146357, 3233, 48, 'dummy'),
(146358, 3234, 48, 'dummy'),
(146359, 3235, 48, 'dummy'),
(146360, 3236, 48, 'dummy'),
(146361, 3237, 48, 'dummy'),
(146362, 3238, 48, 'dummy'),
(146363, 3239, 48, 'dummy'),
(146364, 3240, 48, 'dummy'),
(146365, 3241, 48, 'dummy'),
(146366, 3242, 48, 'dummy'),
(146367, 3243, 48, 'dummy'),
(146368, 3244, 48, 'dummy'),
(146369, 3245, 48, 'dummy'),
(146370, 3246, 48, 'dummy'),
(146371, 3247, 48, 'dummy'),
(146372, 3248, 48, 'dummy'),
(146373, 3249, 48, 'dummy'),
(146374, 3250, 48, 'dummy'),
(146375, 3251, 48, 'dummy'),
(146376, 3252, 48, 'dummy'),
(146377, 3253, 48, 'dummy'),
(146378, 3254, 48, 'dummy'),
(146379, 3255, 48, 'dummy'),
(146380, 3256, 48, 'dummy'),
(146381, 3257, 48, 'dummy'),
(146382, 3258, 48, 'dummy'),
(146383, 3259, 48, 'dummy'),
(146384, 3260, 48, 'dummy'),
(146385, 3261, 48, 'dummy'),
(146386, 3262, 48, 'dummy'),
(146387, 3263, 48, 'dummy'),
(146388, 3264, 48, 'dummy'),
(146389, 3265, 48, 'dummy'),
(146390, 3266, 48, 'dummy'),
(146391, 3267, 48, 'dummy'),
(146392, 3268, 48, 'dummy'),
(146393, 3269, 48, 'dummy'),
(146394, 3270, 48, 'dummy'),
(146395, 3271, 48, 'dummy'),
(146396, 3272, 48, 'dummy'),
(146397, 3273, 48, 'dummy'),
(146398, 3274, 48, 'dummy'),
(146399, 3275, 48, 'dummy'),
(146400, 3276, 48, 'dummy'),
(146401, 3277, 48, 'dummy'),
(146402, 3278, 48, 'dummy'),
(146403, 3279, 48, 'dummy'),
(146404, 3280, 48, 'dummy'),
(146405, 3281, 48, 'dummy'),
(146406, 3282, 48, 'dummy'),
(146407, 3283, 48, 'dummy'),
(146408, 3284, 48, 'dummy'),
(146409, 3285, 48, 'dummy'),
(146410, 3286, 48, 'dummy'),
(146411, 3287, 48, 'dummy'),
(146412, 3288, 48, 'dummy'),
(146413, 3289, 48, 'dummy'),
(146414, 3290, 48, 'dummy'),
(146415, 3291, 48, 'dummy'),
(146416, 3292, 48, 'dummy'),
(146417, 3293, 48, 'dummy'),
(146418, 3294, 48, 'dummy'),
(146419, 3295, 48, 'dummy'),
(146420, 3296, 48, 'dummy'),
(146421, 3297, 48, 'dummy'),
(146422, 3298, 48, 'dummy'),
(146423, 3299, 48, 'dummy'),
(146424, 3300, 48, 'dummy'),
(146425, 3301, 48, 'dummy'),
(146426, 3302, 48, 'dummy'),
(146427, 3303, 48, 'dummy'),
(146428, 3304, 48, 'dummy'),
(146429, 3305, 48, 'dummy'),
(146430, 3306, 48, 'dummy'),
(146431, 3307, 48, 'dummy'),
(146432, 3308, 48, 'dummy'),
(146433, 3309, 48, 'dummy'),
(146434, 3310, 48, 'dummy'),
(146435, 3311, 48, 'dummy'),
(146436, 3312, 48, 'dummy'),
(146437, 3313, 48, 'dummy'),
(146438, 3314, 48, 'dummy'),
(146439, 3315, 48, 'dummy'),
(146440, 3316, 48, 'dummy'),
(146441, 3317, 48, 'dummy'),
(146442, 3318, 48, 'dummy'),
(146443, 3319, 48, 'dummy'),
(146444, 3320, 48, 'dummy'),
(146445, 3321, 48, 'dummy'),
(146446, 3322, 48, 'dummy'),
(146447, 3323, 48, 'dummy'),
(146448, 3324, 48, 'dummy'),
(146449, 3325, 48, 'dummy'),
(146450, 3326, 48, 'dummy'),
(146451, 3327, 48, 'dummy'),
(146452, 3328, 48, 'dummy'),
(146453, 3329, 48, 'dummy'),
(146454, 3330, 48, 'dummy'),
(146455, 3331, 48, 'dummy'),
(146456, 3332, 48, 'dummy'),
(146457, 3333, 48, 'dummy'),
(146458, 3334, 48, 'dummy'),
(146459, 3335, 48, 'dummy'),
(146460, 3336, 48, 'dummy'),
(146461, 3337, 48, 'dummy'),
(146462, 3338, 48, 'dummy'),
(146463, 3339, 48, 'dummy'),
(146464, 3340, 48, 'dummy'),
(146465, 3341, 48, 'dummy'),
(146466, 3342, 48, 'dummy'),
(146467, 3343, 48, 'dummy'),
(146468, 3344, 48, 'dummy'),
(146469, 3345, 48, 'dummy'),
(146470, 3346, 48, 'dummy'),
(146471, 3347, 48, 'dummy'),
(146472, 3348, 48, 'dummy'),
(146473, 3349, 48, 'dummy'),
(146474, 3350, 48, 'dummy'),
(146475, 3351, 48, 'dummy'),
(146476, 3352, 48, 'dummy'),
(146477, 3353, 48, 'dummy'),
(146478, 3354, 48, 'dummy'),
(146479, 3355, 48, 'dummy'),
(146480, 3356, 48, 'dummy'),
(146481, 3357, 48, 'dummy'),
(146482, 3358, 48, 'dummy'),
(146483, 3359, 48, 'dummy'),
(146484, 3360, 48, 'dummy'),
(146485, 3361, 48, 'dummy'),
(146486, 3362, 48, 'dummy'),
(146487, 3363, 48, 'dummy'),
(146488, 3364, 48, 'dummy'),
(146489, 3365, 48, 'dummy'),
(146490, 3366, 48, 'dummy'),
(146491, 3367, 48, 'dummy'),
(146492, 3368, 48, 'dummy'),
(146493, 3369, 48, 'dummy'),
(146494, 3370, 48, 'dummy'),
(146495, 3371, 48, 'dummy'),
(146496, 3372, 48, 'dummy'),
(146497, 3373, 48, 'dummy'),
(146498, 3374, 48, 'dummy'),
(146499, 3375, 48, 'dummy'),
(146500, 3376, 48, 'dummy'),
(146501, 3377, 48, 'dummy'),
(146502, 3378, 48, 'dummy'),
(146503, 3379, 48, 'dummy'),
(146504, 3380, 48, 'dummy'),
(146505, 3381, 48, 'dummy'),
(146506, 3382, 48, 'dummy'),
(146507, 3383, 48, 'dummy'),
(146508, 3384, 48, 'dummy'),
(146509, 3385, 48, 'dummy'),
(146510, 3386, 48, 'dummy'),
(146511, 3387, 48, 'dummy'),
(146512, 3388, 48, 'dummy'),
(146513, 3389, 48, 'dummy'),
(146514, 3390, 48, 'dummy'),
(146515, 3391, 48, 'dummy'),
(146516, 3392, 48, 'dummy'),
(146517, 3393, 48, 'dummy'),
(146518, 3394, 48, 'dummy'),
(146519, 3395, 48, 'dummy'),
(146520, 3396, 48, 'dummy'),
(146521, 3397, 48, 'dummy'),
(146522, 3398, 48, 'dummy'),
(146523, 3399, 48, 'dummy'),
(146524, 3400, 48, 'dummy'),
(146525, 3401, 48, 'dummy'),
(146526, 3402, 48, 'dummy'),
(146527, 3403, 48, 'dummy'),
(146528, 3404, 48, 'dummy'),
(146529, 3405, 48, 'dummy'),
(146530, 3406, 48, 'dummy'),
(146531, 3407, 48, 'dummy'),
(146532, 3408, 48, 'dummy'),
(146533, 3409, 48, 'dummy'),
(146534, 3410, 48, 'dummy'),
(146535, 3411, 48, 'dummy'),
(146536, 3412, 48, 'dummy'),
(146537, 3413, 48, 'dummy'),
(146538, 3414, 48, 'dummy'),
(146539, 3415, 48, 'dummy'),
(146540, 3416, 48, 'dummy'),
(146541, 3417, 48, 'dummy'),
(146542, 3418, 48, 'dummy'),
(146543, 3419, 48, 'dummy'),
(146544, 3420, 48, 'dummy'),
(146545, 3421, 48, 'dummy'),
(146546, 3422, 48, 'dummy'),
(146547, 3423, 48, 'dummy'),
(146548, 3424, 48, 'dummy'),
(146549, 3425, 48, 'dummy'),
(146550, 3426, 48, 'dummy'),
(146551, 3427, 48, 'dummy'),
(146552, 3428, 48, 'dummy'),
(146553, 3429, 48, 'dummy'),
(146554, 3430, 48, 'dummy'),
(146555, 3431, 48, 'dummy'),
(146556, 3432, 48, 'dummy'),
(146557, 3433, 48, 'dummy'),
(146558, 3434, 48, 'dummy'),
(146559, 3435, 48, 'dummy'),
(146560, 3436, 48, 'dummy'),
(146561, 3437, 48, 'dummy'),
(146562, 3438, 48, 'dummy'),
(146563, 3439, 48, 'dummy'),
(146564, 3440, 48, 'dummy'),
(146565, 3441, 48, 'dummy'),
(146566, 3442, 48, 'dummy'),
(146567, 3443, 48, 'dummy'),
(146568, 3444, 48, 'dummy'),
(146569, 3445, 48, 'dummy'),
(146570, 3446, 48, 'dummy'),
(146571, 3447, 48, 'dummy'),
(146572, 3448, 48, 'dummy'),
(146573, 3449, 48, 'dummy'),
(146574, 3450, 48, 'dummy'),
(146575, 3451, 48, 'dummy'),
(146576, 3452, 48, 'dummy'),
(146577, 3453, 48, 'dummy'),
(146578, 3454, 48, 'dummy'),
(146579, 3455, 48, 'dummy'),
(146580, 3456, 48, 'dummy'),
(146581, 3457, 48, 'dummy'),
(146582, 3458, 48, 'dummy'),
(146583, 3459, 48, 'dummy'),
(146584, 3460, 48, 'dummy'),
(146585, 3461, 48, 'dummy'),
(146586, 3462, 48, 'dummy'),
(146587, 3463, 48, 'dummy'),
(146588, 3464, 48, 'dummy'),
(146589, 3465, 48, 'dummy'),
(146590, 3466, 48, 'dummy'),
(146591, 3467, 48, 'dummy'),
(146592, 3468, 48, 'dummy'),
(146593, 3469, 48, 'dummy'),
(146594, 3470, 48, 'dummy'),
(146595, 3471, 48, 'dummy'),
(146596, 3472, 48, 'dummy'),
(146597, 3473, 48, 'dummy'),
(146598, 3474, 48, 'dummy'),
(146599, 3475, 48, 'dummy'),
(146600, 3476, 48, 'dummy'),
(146601, 3477, 48, 'dummy'),
(146602, 3478, 48, 'dummy'),
(146603, 3479, 48, 'dummy'),
(146604, 3480, 48, 'dummy'),
(146605, 3481, 48, 'dummy'),
(146606, 3482, 48, 'dummy'),
(146607, 3483, 48, 'dummy'),
(146608, 3484, 48, 'dummy'),
(146609, 3485, 48, 'dummy'),
(146610, 3486, 48, 'dummy'),
(146611, 3487, 48, 'dummy'),
(146612, 3488, 48, 'dummy'),
(146613, 3489, 48, 'dummy'),
(146614, 3490, 48, 'dummy'),
(146615, 3491, 48, 'dummy'),
(146616, 3492, 48, 'dummy'),
(146617, 3493, 48, 'dummy'),
(146618, 3494, 48, 'dummy'),
(146619, 3495, 48, 'dummy'),
(146620, 3496, 48, 'dummy'),
(146621, 3497, 48, 'dummy'),
(146622, 3498, 48, 'dummy'),
(146623, 3499, 48, 'dummy'),
(146624, 3500, 48, 'dummy'),
(146625, 3501, 48, 'dummy'),
(146626, 3502, 48, 'dummy'),
(146627, 3503, 48, 'dummy'),
(146628, 3504, 48, 'dummy'),
(146629, 3505, 48, 'dummy'),
(146630, 3506, 48, 'dummy'),
(146631, 3507, 48, 'dummy'),
(146632, 3508, 48, 'dummy'),
(146633, 3509, 48, 'dummy'),
(146634, 3510, 48, 'dummy'),
(146635, 3511, 48, 'dummy'),
(146636, 3512, 48, 'dummy'),
(146637, 3513, 48, 'dummy'),
(146638, 3514, 48, 'dummy'),
(146639, 3515, 48, 'dummy'),
(146640, 3516, 48, 'dummy'),
(146641, 3517, 48, 'dummy'),
(146642, 3518, 48, 'dummy'),
(146643, 3519, 48, 'dummy'),
(146644, 3520, 48, 'dummy'),
(146645, 3521, 48, 'dummy'),
(146646, 3522, 48, 'dummy'),
(146647, 3523, 48, 'dummy'),
(146648, 3524, 48, 'dummy'),
(146649, 3525, 48, 'dummy'),
(146650, 3526, 48, 'dummy'),
(146651, 3527, 48, 'dummy'),
(146652, 3528, 48, 'dummy'),
(146653, 3529, 48, 'dummy'),
(146654, 3530, 48, 'dummy'),
(146655, 3531, 48, 'dummy'),
(146656, 3532, 48, 'dummy'),
(146657, 3533, 48, 'dummy'),
(146658, 3534, 48, 'dummy'),
(146659, 3535, 48, 'dummy'),
(146660, 3536, 48, 'dummy'),
(146661, 3537, 48, 'dummy'),
(146662, 3538, 48, 'dummy'),
(146663, 3539, 48, 'dummy'),
(146664, 3540, 48, 'dummy'),
(146665, 3541, 48, 'dummy'),
(146666, 3542, 48, 'dummy'),
(146667, 3543, 48, 'dummy'),
(146668, 3544, 48, 'dummy'),
(146669, 3545, 48, 'dummy'),
(146670, 3546, 48, 'dummy'),
(146671, 3547, 48, 'dummy'),
(146672, 3548, 48, 'dummy'),
(146673, 3549, 48, 'dummy'),
(146674, 3550, 48, 'dummy'),
(146675, 3551, 48, 'dummy'),
(146676, 3552, 48, 'dummy'),
(146677, 3553, 48, 'dummy'),
(146678, 3554, 48, 'dummy'),
(146679, 3555, 48, 'dummy'),
(146680, 3556, 48, 'dummy'),
(146681, 3557, 48, 'dummy'),
(146682, 3558, 48, 'dummy'),
(146683, 3559, 48, 'dummy'),
(146684, 3560, 48, 'dummy'),
(146685, 3561, 48, 'dummy'),
(146686, 3562, 48, 'dummy'),
(146687, 3563, 48, 'dummy'),
(146688, 3564, 48, 'dummy'),
(146689, 3565, 48, 'dummy'),
(146690, 3566, 48, 'dummy'),
(146691, 3567, 48, 'dummy'),
(146692, 3568, 48, 'dummy'),
(146693, 3569, 48, 'dummy'),
(146694, 3570, 48, 'dummy'),
(146695, 3571, 48, 'dummy'),
(146696, 3572, 48, 'dummy'),
(146697, 3573, 48, 'dummy'),
(146698, 3574, 48, 'dummy'),
(146699, 3575, 48, 'dummy'),
(146700, 3576, 48, 'dummy'),
(146701, 3577, 48, 'dummy'),
(146702, 3578, 48, 'dummy'),
(146703, 3579, 48, 'dummy'),
(146704, 3580, 48, 'dummy'),
(146705, 3581, 48, 'dummy'),
(146706, 3582, 48, 'dummy'),
(146707, 3583, 48, 'dummy'),
(146708, 3584, 48, 'dummy'),
(146709, 3585, 48, 'dummy'),
(146710, 3586, 48, 'dummy'),
(146711, 3587, 48, 'dummy'),
(146712, 3588, 48, 'dummy'),
(146713, 3589, 48, 'dummy'),
(146714, 3590, 48, 'dummy'),
(146715, 3591, 48, 'dummy'),
(146716, 3592, 48, 'dummy'),
(146717, 3593, 48, 'dummy'),
(146718, 3594, 48, 'dummy'),
(146719, 3595, 48, 'dummy'),
(146720, 3596, 48, 'dummy'),
(146721, 3597, 48, 'dummy'),
(146722, 3598, 48, 'dummy'),
(146723, 3599, 48, 'dummy'),
(146724, 3600, 48, 'dummy'),
(146725, 3601, 48, 'dummy'),
(146726, 3602, 48, 'dummy'),
(146727, 3603, 48, 'dummy'),
(146728, 3604, 48, 'dummy'),
(146729, 3605, 48, 'dummy'),
(146730, 3606, 48, 'dummy'),
(146731, 3607, 48, 'dummy'),
(146732, 3608, 48, 'dummy'),
(146733, 3609, 48, 'dummy'),
(146734, 3610, 48, 'dummy'),
(146735, 3611, 48, 'dummy'),
(146736, 3612, 48, 'dummy'),
(146737, 3613, 48, 'dummy'),
(146738, 3614, 48, 'dummy'),
(146739, 3615, 48, 'dummy'),
(146740, 3616, 48, 'dummy'),
(146741, 3617, 48, 'dummy'),
(146742, 3618, 48, 'dummy'),
(146743, 3619, 48, 'dummy'),
(146744, 3620, 48, 'dummy'),
(146745, 3621, 48, 'dummy'),
(146746, 3622, 48, 'dummy'),
(146747, 3623, 48, 'dummy'),
(146748, 3624, 48, 'dummy'),
(146749, 3625, 48, 'dummy'),
(146750, 3626, 48, 'dummy'),
(146751, 3627, 48, 'dummy'),
(146752, 3628, 48, 'dummy'),
(146753, 3629, 48, 'dummy'),
(146754, 3630, 48, 'dummy'),
(146755, 3631, 48, 'dummy'),
(146756, 3632, 48, 'dummy'),
(146757, 3633, 48, 'dummy'),
(146758, 3634, 48, 'dummy'),
(146759, 3635, 48, 'dummy'),
(146760, 3636, 48, 'dummy'),
(146761, 3637, 48, 'dummy'),
(146762, 3638, 48, 'dummy'),
(146763, 3639, 48, 'dummy'),
(146764, 3640, 48, 'dummy'),
(146765, 3641, 48, 'dummy'),
(146766, 3642, 48, 'dummy'),
(146767, 3643, 48, 'dummy'),
(146768, 3644, 48, 'dummy'),
(146769, 3645, 48, 'dummy'),
(146770, 3646, 48, 'dummy'),
(146771, 3647, 48, 'dummy'),
(146772, 3648, 48, 'dummy'),
(146773, 3649, 48, 'dummy'),
(146774, 3650, 48, 'dummy'),
(146775, 3651, 48, 'dummy'),
(146776, 3652, 48, 'dummy'),
(146777, 3653, 48, 'dummy'),
(146778, 3654, 48, 'dummy'),
(146779, 3655, 48, 'dummy'),
(146780, 3656, 48, 'dummy'),
(146781, 3657, 48, 'dummy'),
(146782, 3658, 48, 'dummy'),
(146783, 3659, 48, 'dummy'),
(146784, 3660, 48, 'dummy'),
(146785, 3661, 48, 'dummy'),
(146786, 3662, 48, 'dummy'),
(146787, 3663, 48, 'dummy'),
(146788, 3664, 48, 'dummy'),
(146789, 3665, 48, 'dummy'),
(146790, 3666, 48, 'dummy'),
(146791, 3667, 48, 'dummy'),
(146792, 3668, 48, 'dummy'),
(146793, 3669, 48, 'dummy'),
(146794, 3670, 48, 'dummy'),
(146795, 3671, 48, 'dummy'),
(146796, 3672, 48, 'dummy'),
(146797, 3673, 48, 'dummy'),
(146798, 3674, 48, 'dummy'),
(146799, 3675, 48, 'dummy'),
(146800, 3676, 48, 'dummy'),
(146801, 3677, 48, 'dummy'),
(146802, 3678, 48, 'dummy'),
(146803, 3679, 48, 'dummy'),
(146804, 3680, 48, 'dummy'),
(146805, 3681, 48, 'dummy'),
(146806, 3682, 48, 'dummy'),
(146807, 3683, 48, 'dummy'),
(146808, 3684, 48, 'dummy'),
(146809, 3685, 48, 'dummy'),
(146810, 3686, 48, 'dummy'),
(146811, 3687, 48, 'dummy'),
(146812, 3688, 48, 'dummy'),
(146813, 3689, 48, 'dummy'),
(146814, 3690, 48, 'dummy'),
(146815, 3691, 48, 'dummy'),
(146816, 3692, 48, 'dummy'),
(146817, 3693, 48, 'dummy'),
(146818, 3694, 48, 'dummy'),
(146819, 3695, 48, 'dummy'),
(146820, 3696, 48, 'dummy'),
(146821, 3697, 48, 'dummy'),
(146822, 3698, 48, 'dummy'),
(146823, 3699, 48, 'dummy'),
(146824, 3700, 48, 'dummy'),
(146825, 3701, 48, 'dummy'),
(146826, 3702, 48, 'dummy'),
(146827, 3703, 48, 'dummy'),
(146828, 3704, 48, 'dummy'),
(146829, 3705, 48, 'dummy'),
(146830, 3706, 48, 'dummy'),
(146831, 3707, 48, 'dummy'),
(146832, 3708, 48, 'dummy'),
(146833, 3709, 48, 'dummy'),
(146834, 3710, 48, 'dummy'),
(146835, 3711, 48, 'dummy'),
(146836, 3712, 48, 'dummy'),
(146837, 3713, 48, 'dummy'),
(146838, 3714, 48, 'dummy'),
(146839, 3715, 48, 'dummy'),
(146840, 3716, 48, 'dummy'),
(146841, 3717, 48, 'dummy'),
(146842, 3718, 48, 'dummy'),
(146843, 3719, 48, 'dummy'),
(146844, 3720, 48, 'dummy'),
(146845, 3721, 48, 'dummy'),
(146846, 3722, 48, 'dummy'),
(146847, 3723, 48, 'dummy'),
(146848, 3724, 48, 'dummy'),
(146849, 3725, 48, 'dummy'),
(146850, 3726, 48, 'dummy'),
(146851, 3727, 48, 'dummy'),
(146852, 3728, 48, 'dummy'),
(146853, 3729, 48, 'dummy'),
(146854, 3730, 48, 'dummy'),
(146855, 3731, 48, 'dummy'),
(146856, 3732, 48, 'dummy'),
(146857, 3733, 48, 'dummy'),
(146858, 3734, 48, 'dummy'),
(146859, 3735, 48, 'dummy'),
(146860, 3736, 48, 'dummy'),
(146861, 3737, 48, 'dummy'),
(146862, 3738, 48, 'dummy'),
(146863, 3739, 48, 'dummy'),
(146864, 3740, 48, 'dummy'),
(146865, 3741, 48, 'dummy'),
(146866, 3742, 48, 'dummy'),
(146867, 3743, 48, 'dummy'),
(146868, 3744, 48, 'dummy'),
(146869, 3745, 48, 'dummy'),
(146870, 3746, 48, 'dummy'),
(146871, 3747, 48, 'dummy'),
(146872, 3748, 48, 'dummy'),
(146873, 3749, 48, 'dummy'),
(146874, 3750, 48, 'dummy'),
(146875, 3751, 48, 'dummy'),
(146876, 3752, 48, 'dummy'),
(146877, 3753, 48, 'dummy'),
(146878, 3754, 48, 'dummy'),
(146879, 3755, 48, 'dummy'),
(146880, 3756, 48, 'dummy'),
(146881, 3757, 48, 'dummy'),
(146882, 3758, 48, 'dummy'),
(146883, 3759, 48, 'dummy'),
(146884, 3760, 48, 'dummy'),
(146885, 3761, 48, 'dummy'),
(146886, 3762, 48, 'dummy'),
(146887, 3763, 48, 'dummy'),
(146888, 3764, 48, 'dummy'),
(146889, 3765, 48, 'dummy'),
(146890, 3766, 48, 'dummy'),
(146891, 3767, 48, 'dummy'),
(146892, 3768, 48, 'dummy'),
(146893, 3769, 48, 'dummy'),
(146894, 3770, 48, 'dummy'),
(146895, 3771, 48, 'dummy'),
(146896, 3772, 48, 'dummy'),
(146897, 3773, 48, 'dummy'),
(146898, 3774, 48, 'dummy'),
(146899, 3775, 48, 'dummy'),
(146900, 3776, 48, 'dummy'),
(146901, 3777, 48, 'dummy'),
(146902, 3778, 48, 'dummy'),
(146903, 3779, 48, 'dummy'),
(146904, 3780, 48, 'dummy'),
(146905, 3781, 48, 'dummy'),
(146906, 3782, 48, 'dummy'),
(146907, 3783, 48, 'dummy'),
(146908, 3784, 48, 'dummy'),
(146909, 3785, 48, 'dummy'),
(146910, 3786, 48, 'dummy'),
(146911, 3787, 48, 'dummy'),
(146912, 3788, 48, 'dummy'),
(146913, 3789, 48, 'dummy'),
(146914, 3790, 48, 'dummy'),
(146915, 3791, 48, 'dummy'),
(146916, 3792, 48, 'dummy'),
(146917, 3793, 48, 'dummy'),
(146918, 3794, 48, 'dummy'),
(146919, 3795, 48, 'dummy'),
(146920, 3796, 48, 'dummy'),
(146921, 3797, 48, 'dummy'),
(146922, 3798, 48, 'dummy'),
(146923, 3799, 48, 'dummy'),
(146924, 3800, 48, 'dummy'),
(146925, 3801, 48, 'dummy'),
(146926, 3802, 48, 'dummy'),
(146927, 3803, 48, 'dummy'),
(146928, 3804, 48, 'dummy'),
(146929, 3805, 48, 'dummy'),
(146930, 3806, 48, 'dummy'),
(146931, 3807, 48, 'dummy'),
(146932, 3808, 48, 'dummy'),
(146933, 3809, 48, 'dummy'),
(146934, 3810, 48, 'dummy'),
(146935, 3811, 48, 'dummy'),
(146936, 3812, 48, 'dummy'),
(146937, 3813, 48, 'dummy'),
(146938, 3814, 48, 'dummy'),
(146939, 3815, 48, 'dummy'),
(146940, 3816, 48, 'dummy'),
(146941, 3817, 48, 'dummy'),
(146942, 3818, 48, 'dummy'),
(146943, 3819, 48, 'dummy'),
(146944, 3820, 48, 'dummy'),
(146945, 3821, 48, 'dummy'),
(146946, 3822, 48, 'dummy'),
(146947, 3823, 48, 'dummy'),
(146948, 3824, 48, 'dummy'),
(146949, 3825, 48, 'dummy'),
(146950, 3826, 48, 'dummy'),
(146951, 3827, 48, 'dummy'),
(146952, 3828, 48, 'dummy'),
(146953, 3829, 48, 'dummy'),
(146954, 3830, 48, 'dummy'),
(146955, 3831, 48, 'dummy'),
(146956, 3832, 48, 'dummy'),
(146957, 3833, 48, 'dummy'),
(146958, 3834, 48, 'dummy'),
(146959, 3835, 48, 'dummy'),
(146960, 3836, 48, 'dummy'),
(146961, 3837, 48, 'dummy'),
(146962, 3838, 48, 'dummy'),
(146963, 3839, 48, 'dummy'),
(146964, 3840, 48, 'dummy'),
(146965, 3841, 48, 'dummy'),
(146966, 3842, 48, 'dummy'),
(146967, 3843, 48, 'dummy'),
(146968, 3844, 48, 'dummy'),
(146969, 3845, 48, 'dummy'),
(146970, 3846, 48, 'dummy'),
(146971, 3847, 48, 'dummy'),
(146972, 3848, 48, 'dummy'),
(146973, 3849, 48, 'dummy'),
(146974, 3850, 48, 'dummy'),
(146975, 3851, 48, 'dummy'),
(146976, 3852, 48, 'dummy'),
(146977, 3853, 48, 'dummy'),
(146978, 3854, 48, 'dummy'),
(146979, 3855, 48, 'dummy'),
(146980, 3856, 48, 'dummy'),
(146981, 3857, 48, 'dummy'),
(146982, 3858, 48, 'dummy'),
(146983, 3859, 48, 'dummy'),
(146984, 3860, 48, 'dummy'),
(146985, 3861, 48, 'dummy'),
(146986, 3862, 48, 'dummy'),
(146987, 3863, 48, 'dummy'),
(146988, 3864, 48, 'dummy'),
(146989, 3865, 48, 'dummy'),
(146990, 3866, 48, 'dummy'),
(146991, 3867, 48, 'dummy'),
(146992, 3868, 48, 'dummy'),
(146993, 3869, 48, 'dummy'),
(146994, 3870, 48, 'dummy'),
(146995, 3871, 48, 'dummy'),
(146996, 3872, 48, 'dummy'),
(146997, 3873, 48, 'dummy'),
(146998, 3874, 48, 'dummy'),
(146999, 3875, 48, 'dummy'),
(147000, 3876, 48, 'dummy'),
(147001, 3877, 48, 'dummy'),
(147002, 3878, 48, 'dummy'),
(147003, 3879, 48, 'dummy'),
(147004, 3880, 48, 'dummy'),
(147005, 3881, 48, 'dummy'),
(147006, 3882, 48, 'dummy'),
(147007, 3883, 48, 'dummy'),
(147008, 3884, 48, 'dummy'),
(147009, 3885, 48, 'dummy'),
(147010, 3886, 48, 'dummy'),
(147011, 3887, 48, 'dummy'),
(147012, 3888, 48, 'dummy'),
(147013, 3889, 48, 'dummy'),
(147014, 3890, 48, 'dummy'),
(147015, 3891, 48, 'dummy'),
(147016, 3892, 48, 'dummy'),
(147017, 3893, 48, 'dummy'),
(147018, 3894, 48, 'dummy'),
(147019, 3895, 48, 'dummy'),
(147020, 3896, 48, 'dummy'),
(147021, 3897, 48, 'dummy'),
(147022, 3898, 48, 'dummy'),
(147023, 3899, 48, 'dummy'),
(147024, 3900, 48, 'dummy'),
(147025, 3901, 48, 'dummy'),
(147026, 3902, 48, 'dummy'),
(147027, 3903, 48, 'dummy'),
(147028, 3904, 48, 'dummy'),
(147029, 3905, 48, 'dummy'),
(147030, 3906, 48, 'dummy'),
(147031, 3907, 48, 'dummy'),
(147032, 3908, 48, 'dummy'),
(147033, 3909, 48, 'dummy'),
(147034, 3910, 48, 'dummy'),
(147035, 3911, 48, 'dummy'),
(147036, 3912, 48, 'dummy'),
(147037, 3913, 48, 'dummy'),
(147038, 3914, 48, 'dummy'),
(147039, 3915, 48, 'dummy'),
(147040, 3916, 48, 'dummy'),
(147041, 3917, 48, 'dummy'),
(147042, 3918, 48, 'dummy'),
(147043, 3919, 48, 'dummy'),
(147044, 3920, 48, 'dummy'),
(147045, 3921, 48, 'dummy'),
(147046, 3922, 48, 'dummy'),
(147047, 3923, 48, 'dummy'),
(147048, 3924, 48, 'dummy'),
(147049, 3925, 48, 'dummy'),
(147050, 3926, 48, 'dummy'),
(147051, 3927, 48, 'dummy'),
(147052, 3928, 48, 'dummy'),
(147053, 3929, 48, 'dummy'),
(147054, 3930, 48, 'dummy'),
(147055, 3931, 48, 'dummy'),
(147056, 3932, 48, 'dummy'),
(147057, 3933, 48, 'dummy'),
(147058, 3934, 48, 'dummy'),
(147059, 3935, 48, 'dummy'),
(147060, 3936, 48, 'dummy'),
(147061, 3937, 48, 'dummy'),
(147062, 3938, 48, 'dummy'),
(147063, 3939, 48, 'dummy'),
(147064, 3940, 48, 'dummy'),
(147065, 3941, 48, 'dummy'),
(147066, 3942, 48, 'dummy'),
(147067, 3943, 48, 'dummy'),
(147068, 3944, 48, 'dummy'),
(147069, 3945, 48, 'dummy'),
(147070, 3946, 48, 'dummy'),
(147071, 3947, 48, 'dummy'),
(147072, 3948, 48, 'dummy'),
(147073, 3949, 48, 'dummy'),
(147074, 3950, 48, 'dummy'),
(147075, 3951, 48, 'dummy'),
(147076, 3952, 48, 'dummy'),
(147077, 3953, 48, 'dummy'),
(147078, 3954, 48, 'dummy'),
(147079, 3955, 48, 'dummy'),
(147080, 3956, 48, 'dummy'),
(147081, 3957, 48, 'dummy'),
(147082, 3958, 48, 'dummy'),
(147083, 3959, 48, 'dummy'),
(147084, 3960, 48, 'dummy'),
(147085, 3961, 48, 'dummy'),
(147086, 3962, 48, 'dummy'),
(147087, 3963, 48, 'dummy'),
(147088, 3964, 48, 'dummy'),
(147089, 3965, 48, 'dummy'),
(147090, 3966, 48, 'dummy'),
(147091, 3967, 48, 'dummy'),
(147092, 3968, 48, 'dummy'),
(147093, 3969, 48, 'dummy'),
(147094, 3970, 48, 'dummy'),
(147095, 3971, 48, 'dummy'),
(147096, 3972, 48, 'dummy'),
(147097, 3973, 48, 'dummy'),
(147098, 3974, 48, 'dummy'),
(147099, 3975, 48, 'dummy'),
(147100, 3976, 48, 'dummy'),
(147101, 3977, 48, 'dummy'),
(147102, 3978, 48, 'dummy'),
(147103, 3979, 48, 'dummy'),
(147104, 3980, 48, 'dummy'),
(147105, 3981, 48, 'dummy'),
(147106, 3982, 48, 'dummy'),
(147107, 3983, 48, 'dummy'),
(147108, 3984, 48, 'dummy'),
(147109, 3985, 48, 'dummy'),
(147110, 3986, 48, 'dummy'),
(147111, 3987, 48, 'dummy'),
(147112, 3988, 48, 'dummy'),
(147113, 3989, 48, 'dummy'),
(147114, 3990, 48, 'dummy'),
(147115, 3991, 48, 'dummy'),
(147116, 3992, 48, 'dummy'),
(147117, 3993, 48, 'dummy'),
(147118, 3994, 48, 'dummy'),
(147119, 3995, 48, 'dummy'),
(147120, 3996, 48, 'dummy'),
(147121, 3997, 48, 'dummy'),
(147122, 3998, 48, 'dummy'),
(147123, 3999, 48, 'dummy'),
(147124, 4000, 48, 'dummy'),
(147125, 4001, 48, 'dummy'),
(147126, 4002, 48, 'dummy'),
(147127, 4003, 48, 'dummy'),
(147128, 4004, 48, 'dummy'),
(147129, 4005, 48, 'dummy'),
(147130, 4006, 48, 'dummy'),
(147131, 4007, 48, 'dummy'),
(147132, 4008, 48, 'dummy'),
(147133, 4009, 48, 'dummy'),
(147134, 4010, 48, 'dummy'),
(147135, 4011, 48, 'dummy'),
(147136, 4012, 48, 'dummy'),
(147137, 4013, 48, 'dummy'),
(147138, 4014, 48, 'dummy'),
(147139, 4015, 48, 'dummy'),
(147140, 4016, 48, 'dummy'),
(147141, 4017, 48, 'dummy'),
(147142, 4018, 48, 'dummy');
INSERT INTO `lang_definitions` VALUES
(147143, 4019, 48, 'dummy'),
(147144, 4020, 48, 'dummy'),
(147145, 4021, 48, 'dummy'),
(147146, 4022, 48, 'dummy'),
(147147, 4023, 48, 'dummy'),
(147148, 4024, 48, 'dummy'),
(147149, 4025, 48, 'dummy'),
(147150, 4026, 48, 'dummy'),
(147151, 4027, 48, 'dummy'),
(147152, 4028, 48, 'dummy'),
(147153, 4029, 48, 'dummy'),
(147154, 4030, 48, 'dummy'),
(147155, 4031, 48, 'dummy'),
(147156, 4032, 48, 'dummy'),
(147157, 4033, 48, 'dummy'),
(147158, 4034, 48, 'dummy'),
(147159, 4035, 48, 'dummy'),
(147160, 4036, 48, 'dummy'),
(147161, 4037, 48, 'dummy'),
(147162, 4038, 48, 'dummy'),
(147163, 4039, 48, 'dummy'),
(147164, 4040, 48, 'dummy'),
(147165, 4041, 48, 'dummy'),
(147166, 4042, 48, 'dummy'),
(147167, 4043, 48, 'dummy'),
(147168, 4044, 48, 'dummy'),
(147169, 4045, 48, 'dummy'),
(147170, 4046, 48, 'dummy'),
(147171, 4047, 48, 'dummy'),
(147172, 4048, 48, 'dummy'),
(147173, 4049, 48, 'dummy'),
(147174, 4050, 48, 'dummy'),
(147175, 4051, 48, 'dummy'),
(147176, 4052, 48, 'dummy'),
(147177, 4053, 48, 'dummy'),
(147178, 4054, 48, 'dummy'),
(147179, 4055, 48, 'dummy'),
(147180, 4056, 48, 'dummy'),
(147181, 4057, 48, 'dummy'),
(147182, 4058, 48, 'dummy'),
(147183, 4059, 48, 'dummy'),
(147184, 4060, 48, 'dummy'),
(147185, 4061, 48, 'dummy'),
(147186, 4062, 48, 'dummy'),
(147187, 4063, 48, 'dummy'),
(147188, 4064, 48, 'dummy'),
(147189, 4065, 48, 'dummy'),
(147190, 4066, 48, 'dummy'),
(147191, 4067, 48, 'dummy'),
(147192, 4068, 48, 'dummy'),
(147193, 4069, 48, 'dummy'),
(147194, 4070, 48, 'dummy'),
(147195, 4071, 48, 'dummy'),
(147196, 4072, 48, 'dummy'),
(147197, 4073, 48, 'dummy'),
(147198, 4074, 48, 'dummy'),
(147199, 4075, 48, 'dummy'),
(147200, 4076, 48, 'dummy'),
(147201, 4077, 48, 'dummy'),
(147202, 4078, 48, 'dummy'),
(147203, 4079, 48, 'dummy'),
(147204, 4080, 48, 'dummy'),
(147205, 4081, 48, 'dummy'),
(147206, 4082, 48, 'dummy'),
(147207, 4083, 48, 'dummy'),
(147208, 4084, 48, 'dummy'),
(147209, 4085, 48, 'dummy'),
(147210, 4086, 48, 'dummy'),
(147211, 4087, 48, 'dummy'),
(147212, 4088, 48, 'dummy'),
(147213, 4089, 48, 'dummy'),
(147214, 4090, 48, 'dummy'),
(147215, 4091, 48, 'dummy'),
(147216, 4092, 48, 'dummy'),
(147217, 4093, 48, 'dummy'),
(147218, 4094, 48, 'dummy'),
(147219, 4095, 48, 'dummy'),
(147220, 4096, 48, 'dummy'),
(147221, 4097, 48, 'dummy'),
(147222, 4098, 48, 'dummy'),
(147223, 4099, 48, 'dummy'),
(147224, 4100, 48, 'dummy'),
(147225, 4101, 48, 'dummy'),
(147226, 4102, 48, 'dummy'),
(147227, 4103, 48, 'dummy'),
(147228, 4104, 48, 'dummy'),
(147229, 4105, 48, 'dummy'),
(147230, 4106, 48, 'dummy'),
(147231, 4107, 48, 'dummy'),
(147232, 4108, 48, 'dummy'),
(147233, 4109, 48, 'dummy'),
(147234, 4110, 48, 'dummy'),
(147235, 4111, 48, 'dummy'),
(147236, 4112, 48, 'dummy'),
(147237, 4113, 48, 'dummy'),
(147238, 4114, 48, 'dummy'),
(147239, 4115, 48, 'dummy'),
(147240, 4116, 48, 'dummy'),
(147241, 4117, 48, 'dummy'),
(147242, 4118, 48, 'dummy'),
(147243, 4119, 48, 'dummy'),
(147244, 4120, 48, 'dummy'),
(147245, 4121, 48, 'dummy'),
(147246, 4122, 48, 'dummy'),
(147247, 4123, 48, 'dummy'),
(147248, 4124, 48, 'dummy'),
(147249, 4125, 48, 'dummy'),
(147250, 4126, 48, 'dummy'),
(147251, 4127, 48, 'dummy'),
(147252, 4128, 48, 'dummy'),
(147253, 4129, 48, 'dummy'),
(147254, 4130, 48, 'dummy'),
(147255, 4131, 48, 'dummy'),
(147256, 4132, 48, 'dummy'),
(147257, 4133, 48, 'dummy'),
(147258, 4134, 48, 'dummy'),
(147259, 4135, 48, 'dummy'),
(147260, 4136, 48, 'dummy'),
(147261, 4137, 48, 'dummy'),
(147262, 4138, 48, 'dummy'),
(147263, 4139, 48, 'dummy'),
(147264, 4140, 48, 'dummy'),
(147265, 4141, 48, 'dummy'),
(147266, 4142, 48, 'dummy'),
(147267, 4143, 48, 'dummy'),
(147268, 4144, 48, 'dummy'),
(147269, 4145, 48, 'dummy'),
(147270, 4146, 48, 'dummy'),
(147271, 4147, 48, 'dummy'),
(147272, 4148, 48, 'dummy'),
(147273, 4149, 48, 'dummy'),
(147274, 4150, 48, 'dummy'),
(147275, 4151, 48, 'dummy'),
(147276, 4152, 48, 'dummy'),
(147277, 4153, 48, 'dummy'),
(147278, 4154, 48, 'dummy'),
(147279, 4155, 48, 'dummy'),
(147280, 4156, 48, 'dummy'),
(147281, 4157, 48, 'dummy'),
(147282, 4158, 48, 'dummy'),
(147283, 4159, 48, 'dummy'),
(147284, 4160, 48, 'dummy'),
(147285, 4161, 48, 'dummy'),
(147286, 4162, 48, 'dummy'),
(147287, 4163, 48, 'dummy'),
(147288, 4164, 48, 'dummy'),
(147289, 4165, 48, 'dummy'),
(147290, 4166, 48, 'dummy'),
(147291, 4167, 48, 'dummy'),
(147292, 4168, 48, 'dummy'),
(147293, 4169, 48, 'dummy'),
(147294, 4170, 48, 'dummy'),
(147295, 4171, 48, 'dummy'),
(147296, 4172, 48, 'dummy'),
(147297, 4173, 48, 'dummy'),
(147298, 4174, 48, 'dummy'),
(147299, 4175, 48, 'dummy'),
(147300, 4176, 48, 'dummy'),
(147301, 4177, 48, 'dummy'),
(147302, 4178, 48, 'dummy'),
(147303, 4179, 48, 'dummy'),
(147304, 4180, 48, 'dummy'),
(147305, 4181, 48, 'dummy'),
(147306, 4182, 48, 'dummy'),
(147307, 4183, 48, 'dummy'),
(147308, 4184, 48, 'dummy'),
(147309, 4185, 48, 'dummy'),
(147310, 4186, 48, 'dummy'),
(147311, 4187, 48, 'dummy'),
(147312, 4188, 48, 'dummy'),
(147313, 4189, 48, 'dummy'),
(147314, 4190, 48, 'dummy'),
(147315, 4191, 48, 'dummy'),
(147316, 4192, 48, 'dummy'),
(147317, 4193, 48, 'dummy'),
(147318, 4194, 48, 'dummy'),
(147319, 4195, 48, 'dummy'),
(147320, 4196, 48, 'dummy'),
(147321, 4197, 48, 'dummy'),
(147322, 4198, 48, 'dummy'),
(147323, 4199, 48, 'dummy'),
(147324, 4200, 48, 'dummy'),
(147325, 4201, 48, 'dummy'),
(147326, 4202, 48, 'dummy'),
(147327, 4203, 48, 'dummy'),
(147328, 4204, 48, 'dummy'),
(147329, 4205, 48, 'dummy'),
(147330, 4206, 48, 'dummy'),
(147331, 4207, 48, 'dummy'),
(147332, 4208, 48, 'dummy'),
(147333, 4209, 48, 'dummy'),
(147334, 4210, 48, 'dummy'),
(147335, 4211, 48, 'dummy'),
(147336, 4212, 48, 'dummy'),
(147337, 4213, 48, 'dummy'),
(147338, 4214, 48, 'dummy'),
(147339, 4215, 48, 'dummy'),
(147340, 4216, 48, 'dummy'),
(147341, 4217, 48, 'dummy'),
(147342, 4218, 48, 'dummy'),
(147343, 4219, 48, 'dummy'),
(147344, 4220, 48, 'dummy'),
(147345, 4221, 48, 'dummy'),
(147346, 4222, 48, 'dummy'),
(147347, 4223, 48, 'dummy'),
(147348, 4224, 48, 'dummy'),
(147349, 4225, 48, 'dummy'),
(147350, 4226, 48, 'dummy'),
(147351, 4227, 48, 'dummy'),
(147352, 4228, 48, 'dummy'),
(147353, 4229, 48, 'dummy'),
(147354, 4230, 48, 'dummy'),
(147355, 4231, 48, 'dummy'),
(147356, 4232, 48, 'dummy'),
(147357, 4233, 48, 'dummy'),
(147358, 4234, 48, 'dummy'),
(147359, 4235, 48, 'dummy'),
(147360, 4236, 48, 'dummy'),
(147361, 4237, 48, 'dummy'),
(147362, 4238, 48, 'dummy'),
(147363, 4239, 48, 'dummy'),
(147364, 4240, 48, 'dummy'),
(147365, 4241, 48, 'dummy'),
(147366, 4242, 48, 'dummy'),
(147367, 4243, 48, 'dummy'),
(147368, 4244, 48, 'dummy'),
(147369, 4245, 48, 'dummy'),
(147370, 4246, 48, 'dummy'),
(147371, 4247, 48, 'dummy'),
(147372, 4248, 48, 'dummy'),
(147373, 4249, 48, 'dummy'),
(147374, 4250, 48, 'dummy'),
(147375, 4251, 48, 'dummy'),
(147376, 4252, 48, 'dummy'),
(147377, 4253, 48, 'dummy'),
(147378, 4254, 48, 'dummy'),
(147379, 4255, 48, 'dummy'),
(147380, 4256, 48, 'dummy'),
(147381, 4257, 48, 'dummy'),
(147382, 4258, 48, 'dummy'),
(147383, 4259, 48, 'dummy'),
(147384, 4260, 48, 'dummy'),
(147385, 4261, 48, 'dummy'),
(147386, 4262, 48, 'dummy'),
(147387, 4263, 48, 'dummy'),
(147388, 4264, 48, 'dummy'),
(147389, 4265, 48, 'dummy'),
(147390, 4266, 48, 'dummy'),
(147391, 4267, 48, 'dummy'),
(147392, 4268, 48, 'dummy'),
(147393, 4269, 48, 'dummy'),
(147394, 4270, 48, 'dummy'),
(147395, 4271, 48, 'dummy'),
(147396, 4272, 48, 'dummy'),
(147397, 4273, 48, 'dummy'),
(147398, 4274, 48, 'dummy'),
(147399, 4275, 48, 'dummy'),
(147400, 4276, 48, 'dummy'),
(147401, 4277, 48, 'dummy'),
(147402, 4278, 48, 'dummy'),
(147403, 4279, 48, 'dummy'),
(147404, 4280, 48, 'dummy'),
(147405, 4281, 48, 'dummy'),
(147406, 4282, 48, 'dummy'),
(147407, 4283, 48, 'dummy'),
(147408, 4284, 48, 'dummy'),
(147409, 4285, 48, 'dummy'),
(147410, 4286, 48, 'dummy'),
(147411, 4287, 48, 'dummy'),
(147412, 4288, 48, 'dummy'),
(147413, 4289, 48, 'dummy'),
(147414, 4290, 48, 'dummy'),
(147415, 4291, 48, 'dummy'),
(147416, 4292, 48, 'dummy'),
(147417, 4293, 48, 'dummy'),
(147418, 4294, 48, 'dummy'),
(147419, 4295, 48, 'dummy'),
(147420, 4296, 48, 'dummy'),
(147421, 4297, 48, 'dummy'),
(147422, 4298, 48, 'dummy'),
(147423, 4299, 48, 'dummy'),
(147424, 4300, 48, 'dummy'),
(147425, 4301, 48, 'dummy'),
(147426, 4302, 48, 'dummy'),
(147427, 4303, 48, 'dummy'),
(147428, 4304, 48, 'dummy'),
(147429, 4305, 48, 'dummy'),
(147430, 4306, 48, 'dummy'),
(147431, 4307, 48, 'dummy'),
(147432, 4308, 48, 'dummy'),
(147433, 4309, 48, 'dummy'),
(147434, 4310, 48, 'dummy'),
(147435, 4311, 48, 'dummy'),
(147436, 4312, 48, 'dummy'),
(147437, 4313, 48, 'dummy'),
(147438, 4314, 48, 'dummy'),
(147439, 4315, 48, 'dummy'),
(147440, 4316, 48, 'dummy'),
(147441, 4317, 48, 'dummy'),
(147442, 4318, 48, 'dummy'),
(147443, 4319, 48, 'dummy'),
(147444, 4320, 48, 'dummy'),
(147445, 4321, 48, 'dummy'),
(147446, 4322, 48, 'dummy'),
(147447, 4323, 48, 'dummy'),
(147448, 4324, 48, 'dummy'),
(147449, 4325, 48, 'dummy'),
(147450, 4326, 48, 'dummy'),
(147451, 4327, 48, 'dummy'),
(147452, 4328, 48, 'dummy'),
(147453, 4329, 48, 'dummy'),
(147454, 4330, 48, 'dummy'),
(147455, 4331, 48, 'dummy'),
(147456, 4332, 48, 'dummy'),
(147457, 4333, 48, 'dummy'),
(147458, 4334, 48, 'dummy'),
(147459, 4335, 48, 'dummy'),
(147460, 4336, 48, 'dummy'),
(147461, 4337, 48, 'dummy'),
(147462, 4338, 48, 'dummy'),
(147463, 4339, 48, 'dummy'),
(147464, 4340, 48, 'dummy'),
(147465, 4341, 48, 'dummy'),
(147466, 4342, 48, 'dummy'),
(147467, 4343, 48, 'dummy'),
(147468, 4344, 48, 'dummy'),
(147469, 4345, 48, 'dummy'),
(147470, 4346, 48, 'dummy'),
(147471, 4347, 48, 'dummy'),
(147472, 4348, 48, 'dummy'),
(147473, 4349, 48, 'dummy'),
(147474, 4350, 48, 'dummy'),
(147475, 4351, 48, 'dummy'),
(147476, 4352, 48, 'dummy'),
(147477, 4353, 48, 'dummy'),
(147478, 4354, 48, 'dummy'),
(147479, 4355, 48, 'dummy'),
(147480, 4356, 48, 'dummy'),
(147481, 4357, 48, 'dummy'),
(147482, 4358, 48, 'dummy'),
(147483, 4359, 48, 'dummy'),
(147484, 4360, 48, 'dummy'),
(147485, 4361, 48, 'dummy'),
(147486, 4362, 48, 'dummy'),
(147487, 4363, 48, 'dummy'),
(147488, 4364, 48, 'dummy'),
(147489, 4365, 48, 'dummy'),
(147490, 4366, 48, 'dummy'),
(147491, 4367, 48, 'dummy'),
(147492, 4368, 48, 'dummy'),
(147493, 4369, 48, 'dummy'),
(147494, 4370, 48, 'dummy'),
(147495, 4371, 48, 'dummy'),
(147496, 4372, 48, 'dummy'),
(147497, 4373, 48, 'dummy'),
(147498, 4374, 48, 'dummy'),
(147499, 4375, 48, 'dummy'),
(147500, 4376, 48, 'dummy'),
(147501, 4377, 48, 'dummy'),
(147502, 4378, 48, 'dummy'),
(147503, 4379, 48, 'dummy'),
(147504, 4380, 48, 'dummy'),
(147505, 4381, 48, 'dummy'),
(147506, 4382, 48, 'dummy'),
(147507, 4383, 48, 'dummy'),
(147508, 4384, 48, 'dummy'),
(147509, 4385, 48, 'dummy'),
(147510, 4386, 48, 'dummy'),
(147511, 4387, 48, 'dummy'),
(147512, 4388, 48, 'dummy'),
(147513, 4389, 48, 'dummy'),
(147514, 4390, 48, 'dummy'),
(147515, 4391, 48, 'dummy'),
(147516, 4392, 48, 'dummy'),
(147517, 4393, 48, 'dummy'),
(147518, 4394, 48, 'dummy'),
(147519, 4395, 48, 'dummy'),
(147520, 4396, 48, 'dummy'),
(147521, 4397, 48, 'dummy'),
(147522, 4398, 48, 'dummy'),
(147523, 4399, 48, 'dummy'),
(147524, 4400, 48, 'dummy'),
(147525, 4401, 48, 'dummy'),
(147526, 4402, 48, 'dummy'),
(147527, 4403, 48, 'dummy'),
(147528, 4404, 48, 'dummy'),
(147529, 4405, 48, 'dummy'),
(147530, 4406, 48, 'dummy'),
(147531, 4407, 48, 'dummy'),
(147532, 4408, 48, 'dummy'),
(147533, 4409, 48, 'dummy'),
(147534, 4410, 48, 'dummy'),
(147535, 4411, 48, 'dummy'),
(147536, 4412, 48, 'dummy'),
(147537, 4413, 48, 'dummy'),
(147538, 4414, 48, 'dummy'),
(147539, 4415, 48, 'dummy'),
(147540, 4416, 48, 'dummy'),
(147541, 4417, 48, 'dummy'),
(147542, 4418, 48, 'dummy'),
(147543, 4419, 48, 'dummy'),
(147544, 4420, 48, 'dummy'),
(147545, 4421, 48, 'dummy'),
(147546, 4422, 48, 'dummy'),
(147547, 4423, 48, 'dummy'),
(147548, 4424, 48, 'dummy'),
(147549, 4425, 48, 'dummy'),
(147550, 4426, 48, 'dummy'),
(147551, 4427, 48, 'dummy'),
(147552, 4428, 48, 'dummy'),
(147553, 4429, 48, 'dummy'),
(147554, 4430, 48, 'dummy'),
(147555, 4431, 48, 'dummy'),
(147556, 4432, 48, 'dummy'),
(147557, 4433, 48, 'dummy'),
(147558, 4434, 48, 'dummy'),
(147559, 4435, 48, 'dummy'),
(147560, 4436, 48, 'dummy'),
(147561, 4437, 48, 'dummy'),
(147562, 4438, 48, 'dummy'),
(147563, 4439, 48, 'dummy'),
(147564, 4440, 48, 'dummy'),
(147565, 4441, 48, 'dummy'),
(147566, 4442, 48, 'dummy'),
(147567, 4443, 48, 'dummy'),
(147568, 4444, 48, 'dummy'),
(147569, 4445, 48, 'dummy'),
(147570, 4446, 48, 'dummy'),
(147571, 4447, 48, 'dummy'),
(147572, 4448, 48, 'dummy'),
(147573, 4449, 48, 'dummy'),
(147574, 4450, 48, 'dummy'),
(147575, 4451, 48, 'dummy'),
(147576, 4452, 48, 'dummy'),
(147577, 4453, 48, 'dummy'),
(147578, 4454, 48, 'dummy'),
(147579, 4455, 48, 'dummy'),
(147580, 4456, 48, 'dummy'),
(147581, 4457, 48, 'dummy'),
(147582, 4458, 48, 'dummy'),
(147583, 4459, 48, 'dummy'),
(147584, 4460, 48, 'dummy'),
(147585, 4461, 48, 'dummy'),
(147586, 4462, 48, 'dummy'),
(147587, 4463, 48, 'dummy'),
(147588, 4464, 48, 'dummy'),
(147589, 4465, 48, 'dummy'),
(147590, 4466, 48, 'dummy'),
(147591, 4467, 48, 'dummy'),
(147592, 4468, 48, 'dummy'),
(147593, 4469, 48, 'dummy'),
(147594, 4470, 48, 'dummy'),
(147595, 4471, 48, 'dummy'),
(147596, 4472, 48, 'dummy'),
(147597, 4473, 48, 'dummy'),
(147598, 4474, 48, 'dummy'),
(147599, 4475, 48, 'dummy'),
(147600, 4476, 48, 'dummy'),
(147601, 4477, 48, 'dummy'),
(147602, 4478, 48, 'dummy'),
(147603, 4479, 48, 'dummy'),
(147604, 4480, 48, 'dummy'),
(147605, 4481, 48, 'dummy'),
(147606, 4482, 48, 'dummy'),
(147607, 4483, 48, 'dummy'),
(147608, 4484, 48, 'dummy'),
(147609, 4485, 48, 'dummy'),
(147610, 4486, 48, 'dummy'),
(147611, 4487, 48, 'dummy'),
(147612, 4488, 48, 'dummy'),
(147613, 4489, 48, 'dummy'),
(147614, 4490, 48, 'dummy'),
(147615, 4491, 48, 'dummy'),
(147616, 4492, 48, 'dummy'),
(147617, 4493, 48, 'dummy'),
(147618, 4494, 48, 'dummy'),
(147619, 4495, 48, 'dummy'),
(147620, 4496, 48, 'dummy'),
(147621, 4497, 48, 'dummy'),
(147622, 4498, 48, 'dummy'),
(147623, 4499, 48, 'dummy'),
(147624, 4500, 48, 'dummy'),
(147625, 4501, 48, 'dummy'),
(147626, 4502, 48, 'dummy'),
(147627, 4503, 48, 'dummy'),
(147628, 4504, 48, 'dummy'),
(147629, 4505, 48, 'dummy'),
(147630, 4506, 48, 'dummy'),
(147631, 4507, 48, 'dummy'),
(147632, 4508, 48, 'dummy'),
(147633, 4509, 48, 'dummy'),
(147634, 4510, 48, 'dummy'),
(147635, 4511, 48, 'dummy'),
(147636, 4512, 48, 'dummy'),
(147637, 4513, 48, 'dummy'),
(147638, 4514, 48, 'dummy'),
(147639, 4515, 48, 'dummy'),
(147640, 4516, 48, 'dummy'),
(147641, 4517, 48, 'dummy'),
(147642, 4518, 48, 'dummy'),
(147643, 4519, 48, 'dummy'),
(147644, 4520, 48, 'dummy'),
(147645, 4521, 48, 'dummy'),
(147646, 4522, 48, 'dummy'),
(147647, 4523, 48, 'dummy'),
(147648, 4524, 48, 'dummy'),
(147649, 4525, 48, 'dummy'),
(147650, 4526, 48, 'dummy'),
(147651, 4527, 48, 'dummy'),
(147652, 4528, 48, 'dummy'),
(147653, 4529, 48, 'dummy'),
(147654, 4530, 48, 'dummy'),
(147655, 4531, 48, 'dummy'),
(147656, 4532, 48, 'dummy'),
(147657, 4533, 48, 'dummy'),
(147658, 4534, 48, 'dummy'),
(147659, 4535, 48, 'dummy'),
(147660, 4536, 48, 'dummy'),
(147661, 4537, 48, 'dummy'),
(147662, 4538, 48, 'dummy'),
(147663, 4539, 48, 'dummy'),
(147664, 4540, 48, 'dummy'),
(147665, 4541, 48, 'dummy'),
(147666, 4542, 48, 'dummy'),
(147667, 4543, 48, 'dummy'),
(147668, 4544, 48, 'dummy'),
(147669, 4545, 48, 'dummy'),
(147670, 4546, 48, 'dummy'),
(147671, 4547, 48, 'dummy'),
(147672, 4548, 48, 'dummy'),
(147673, 4549, 48, 'dummy'),
(147674, 4550, 48, 'dummy'),
(147675, 4551, 48, 'dummy'),
(147676, 4552, 48, 'dummy'),
(147677, 4553, 48, 'dummy'),
(147678, 4554, 48, 'dummy'),
(147679, 4555, 48, 'dummy'),
(147680, 4556, 48, 'dummy'),
(147681, 4557, 48, 'dummy'),
(147682, 4558, 48, 'dummy'),
(147683, 4559, 48, 'dummy'),
(147684, 4560, 48, 'dummy'),
(147685, 4561, 48, 'dummy'),
(147686, 4562, 48, 'dummy'),
(147687, 4563, 48, 'dummy'),
(147688, 4564, 48, 'dummy'),
(147689, 4565, 48, 'dummy'),
(147690, 4566, 48, 'dummy'),
(147691, 4567, 48, 'dummy'),
(147692, 4568, 48, 'dummy'),
(147693, 4569, 48, 'dummy'),
(147694, 4570, 48, 'dummy'),
(147695, 4571, 48, 'dummy'),
(147696, 4572, 48, 'dummy'),
(147697, 4573, 48, 'dummy'),
(147698, 4574, 48, 'dummy'),
(147699, 4575, 48, 'dummy'),
(147700, 4576, 48, 'dummy'),
(147701, 4577, 48, 'dummy'),
(147702, 4578, 48, 'dummy'),
(147703, 4579, 48, 'dummy'),
(147704, 4580, 48, 'dummy'),
(147705, 4581, 48, 'dummy'),
(147706, 4582, 48, 'dummy'),
(147707, 4583, 48, 'dummy'),
(147708, 4584, 48, 'dummy'),
(147709, 4585, 48, 'dummy'),
(147710, 4586, 48, 'dummy'),
(147711, 4587, 48, 'dummy'),
(147712, 4588, 48, 'dummy'),
(147713, 4589, 48, 'dummy'),
(147714, 4590, 48, 'dummy'),
(147715, 4591, 48, 'dummy'),
(147716, 4592, 48, 'dummy'),
(147717, 4593, 48, 'dummy'),
(147718, 4594, 48, 'dummy'),
(147719, 4595, 48, 'dummy'),
(147720, 4596, 48, 'dummy'),
(147721, 4597, 48, 'dummy'),
(147722, 4598, 48, 'dummy'),
(147723, 4599, 48, 'dummy'),
(147724, 4600, 48, 'dummy'),
(147725, 4601, 48, 'dummy'),
(147726, 4602, 48, 'dummy'),
(147727, 4603, 48, 'dummy'),
(147728, 4604, 48, 'dummy'),
(147729, 4605, 48, 'dummy'),
(147730, 4606, 48, 'dummy'),
(147731, 4607, 48, 'dummy'),
(147732, 4608, 48, 'dummy'),
(147733, 4609, 48, 'dummy'),
(147734, 4610, 48, 'dummy'),
(147735, 4611, 48, 'dummy'),
(147736, 4612, 48, 'dummy'),
(147737, 4613, 48, 'dummy'),
(147738, 4614, 48, 'dummy'),
(147739, 4615, 48, 'dummy'),
(147740, 4616, 48, 'dummy'),
(147741, 4617, 48, 'dummy'),
(147742, 4618, 48, 'dummy'),
(147743, 4619, 48, 'dummy'),
(147744, 4620, 48, 'dummy'),
(147745, 4621, 48, 'dummy'),
(147746, 4622, 48, 'dummy'),
(147747, 4623, 48, 'dummy'),
(147748, 4624, 48, 'dummy'),
(147749, 4625, 48, 'dummy'),
(147750, 4626, 48, 'dummy'),
(147751, 4627, 48, 'dummy'),
(147752, 4628, 48, 'dummy'),
(147753, 4629, 48, 'dummy'),
(147754, 4630, 48, 'dummy'),
(147755, 4631, 48, 'dummy'),
(147756, 4632, 48, 'dummy'),
(147757, 4633, 48, 'dummy'),
(147758, 4634, 48, 'dummy'),
(147759, 4635, 48, 'dummy'),
(147760, 4636, 48, 'dummy'),
(147761, 4637, 48, 'dummy'),
(147762, 4638, 48, 'dummy'),
(147763, 4639, 48, 'dummy'),
(147764, 4640, 48, 'dummy'),
(147765, 4641, 48, 'dummy'),
(147766, 4642, 48, 'dummy'),
(147767, 4643, 48, 'dummy'),
(147768, 4644, 48, 'dummy'),
(147769, 4645, 48, 'dummy'),
(147770, 4646, 48, 'dummy'),
(147771, 4647, 48, 'dummy'),
(147772, 4648, 48, 'dummy'),
(147773, 4649, 48, 'dummy'),
(147774, 4650, 48, 'dummy'),
(147775, 4651, 48, 'dummy'),
(147776, 4652, 48, 'dummy'),
(147777, 4653, 48, 'dummy'),
(147778, 4654, 48, 'dummy'),
(147779, 4655, 48, 'dummy'),
(147780, 4656, 48, 'dummy'),
(147781, 4657, 48, 'dummy'),
(147782, 4658, 48, 'dummy'),
(147783, 4659, 48, 'dummy'),
(147784, 4660, 48, 'dummy'),
(147785, 4661, 48, 'dummy'),
(147786, 4662, 48, 'dummy'),
(147787, 4663, 48, 'dummy'),
(147788, 4664, 48, 'dummy'),
(147789, 4665, 48, 'dummy'),
(147790, 4666, 48, 'dummy'),
(147791, 4667, 48, 'dummy'),
(147792, 4668, 48, 'dummy'),
(147793, 4669, 48, 'dummy'),
(147794, 4670, 48, 'dummy'),
(147795, 4671, 48, 'dummy'),
(147796, 4672, 48, 'dummy'),
(147797, 4673, 48, 'dummy'),
(147798, 4674, 48, 'dummy'),
(147799, 4675, 48, 'dummy'),
(147800, 4676, 48, 'dummy'),
(147801, 4677, 48, 'dummy'),
(147802, 4678, 48, 'dummy'),
(147803, 4679, 48, 'dummy'),
(147804, 4680, 48, 'dummy'),
(147805, 4681, 48, 'dummy'),
(147806, 4682, 48, 'dummy'),
(147807, 4683, 48, 'dummy'),
(147808, 4684, 48, 'dummy'),
(147809, 4685, 48, 'dummy'),
(147810, 4686, 48, 'dummy'),
(147811, 4687, 48, 'dummy'),
(147812, 4688, 48, 'dummy'),
(147813, 4689, 48, 'dummy'),
(147814, 4690, 48, 'dummy'),
(147815, 4691, 48, 'dummy'),
(147816, 4692, 48, 'dummy'),
(147817, 4693, 48, 'dummy'),
(147818, 4694, 48, 'dummy'),
(147819, 4695, 48, 'dummy'),
(147820, 4696, 48, 'dummy'),
(147821, 4697, 48, 'dummy'),
(147822, 4698, 48, 'dummy'),
(147823, 4699, 48, 'dummy'),
(147824, 4700, 48, 'dummy'),
(147825, 4701, 48, 'dummy'),
(147826, 4702, 48, 'dummy'),
(147827, 4703, 48, 'dummy'),
(147828, 4704, 48, 'dummy'),
(147829, 4705, 48, 'dummy'),
(147830, 4706, 48, 'dummy'),
(147831, 4707, 48, 'dummy'),
(147832, 4708, 48, 'dummy'),
(147833, 4709, 48, 'dummy'),
(147834, 4710, 48, 'dummy'),
(147835, 4711, 48, 'dummy'),
(147836, 4712, 48, 'dummy'),
(147837, 4713, 48, 'dummy'),
(147838, 4714, 48, 'dummy'),
(147839, 4715, 48, 'dummy'),
(147840, 4716, 48, 'dummy'),
(147841, 4717, 48, 'dummy'),
(147842, 4718, 48, 'dummy'),
(147843, 4719, 48, 'dummy'),
(147844, 4720, 48, 'dummy'),
(147845, 4721, 48, 'dummy'),
(147846, 4722, 48, 'dummy'),
(147847, 4723, 48, 'dummy'),
(147848, 4724, 48, 'dummy'),
(147849, 4725, 48, 'dummy'),
(147850, 4726, 48, 'dummy'),
(147851, 4727, 48, 'dummy'),
(147852, 4728, 48, 'dummy'),
(147853, 4729, 48, 'dummy'),
(147854, 4730, 48, 'dummy'),
(147855, 4731, 48, 'dummy'),
(147856, 4732, 48, 'dummy'),
(147857, 4733, 48, 'dummy'),
(147858, 4734, 48, 'dummy'),
(147859, 4735, 48, 'dummy'),
(147860, 4736, 48, 'dummy'),
(147861, 4737, 48, 'dummy'),
(147862, 4738, 48, 'dummy'),
(147863, 4739, 48, 'dummy'),
(147864, 4740, 48, 'dummy'),
(147865, 4741, 48, 'dummy'),
(147866, 4742, 48, 'dummy'),
(147867, 4743, 48, 'dummy'),
(147868, 4744, 48, 'dummy'),
(147869, 4745, 48, 'dummy'),
(147870, 4746, 48, 'dummy'),
(147871, 4747, 48, 'dummy'),
(147872, 4748, 48, 'dummy'),
(147873, 4749, 48, 'dummy'),
(147874, 4750, 48, 'dummy'),
(147875, 4751, 48, 'dummy'),
(147876, 4752, 48, 'dummy'),
(147877, 4753, 48, 'dummy'),
(147878, 4754, 48, 'dummy'),
(147879, 4755, 48, 'dummy'),
(147880, 4756, 48, 'dummy'),
(147881, 4757, 48, 'dummy'),
(147882, 4758, 48, 'dummy'),
(147883, 4759, 48, 'dummy'),
(147884, 4760, 48, 'dummy'),
(147885, 4761, 48, 'dummy'),
(147886, 4762, 48, 'dummy'),
(147887, 4763, 48, 'dummy'),
(147888, 4764, 48, 'dummy'),
(147889, 4765, 48, 'dummy'),
(147890, 4766, 48, 'dummy'),
(147891, 4767, 48, 'dummy'),
(147892, 4768, 48, 'dummy'),
(147893, 4769, 48, 'dummy'),
(147894, 4770, 48, 'dummy'),
(147895, 4771, 48, 'dummy'),
(147896, 4772, 48, 'dummy'),
(147897, 4773, 48, 'dummy'),
(147898, 4774, 48, 'dummy'),
(147899, 4775, 48, 'dummy'),
(147900, 4776, 48, 'dummy'),
(147901, 4777, 48, 'dummy'),
(147902, 4778, 48, 'dummy'),
(147903, 4779, 48, 'dummy'),
(147904, 4780, 48, 'dummy'),
(147905, 4781, 48, 'dummy'),
(147906, 4782, 48, 'dummy'),
(147907, 4783, 48, 'dummy'),
(147908, 4784, 48, 'dummy'),
(147909, 4785, 48, 'dummy'),
(147910, 4786, 48, 'dummy'),
(147911, 4787, 48, 'dummy'),
(147912, 4788, 48, 'dummy'),
(147913, 4789, 48, 'dummy'),
(147914, 4790, 48, 'dummy'),
(147915, 4791, 48, 'dummy'),
(147916, 4792, 48, 'dummy'),
(147917, 4793, 48, 'dummy'),
(147918, 4794, 48, 'dummy'),
(147919, 4795, 48, 'dummy'),
(147920, 4796, 48, 'dummy'),
(147921, 4797, 48, 'dummy'),
(147922, 4798, 48, 'dummy'),
(147923, 4799, 48, 'dummy'),
(147924, 4800, 48, 'dummy'),
(147925, 4801, 48, 'dummy'),
(147926, 4802, 48, 'dummy'),
(147927, 4803, 48, 'dummy'),
(147928, 4804, 48, 'dummy'),
(147929, 4805, 48, 'dummy'),
(147930, 4806, 48, 'dummy'),
(147931, 4807, 48, 'dummy'),
(147932, 4808, 48, 'dummy'),
(147933, 4809, 48, 'dummy'),
(147934, 4810, 48, 'dummy'),
(147935, 4811, 48, 'dummy'),
(147936, 4812, 48, 'dummy'),
(147937, 4813, 48, 'dummy'),
(147938, 4814, 48, 'dummy'),
(147939, 4815, 48, 'dummy'),
(147940, 4816, 48, 'dummy'),
(147941, 4817, 48, 'dummy'),
(147942, 4818, 48, 'dummy'),
(147943, 4819, 48, 'dummy'),
(147944, 4820, 48, 'dummy'),
(147945, 4821, 48, 'dummy'),
(147946, 4822, 48, 'dummy'),
(147947, 4823, 48, 'dummy'),
(147948, 4824, 48, 'dummy'),
(147949, 4825, 48, 'dummy'),
(147950, 4826, 48, 'dummy'),
(147951, 4827, 48, 'dummy'),
(147952, 4828, 48, 'dummy'),
(147953, 4829, 48, 'dummy'),
(147954, 4830, 48, 'dummy'),
(147955, 4831, 48, 'dummy'),
(147956, 4832, 48, 'dummy'),
(147957, 4833, 48, 'dummy'),
(147958, 4834, 48, 'dummy'),
(147959, 4835, 48, 'dummy'),
(147960, 4836, 48, 'dummy'),
(147961, 4837, 48, 'dummy'),
(147962, 4838, 48, 'dummy'),
(147963, 4839, 48, 'dummy'),
(147964, 4840, 48, 'dummy'),
(147965, 4841, 48, 'dummy'),
(147966, 4842, 48, 'dummy'),
(147967, 4843, 48, 'dummy'),
(147968, 4844, 48, 'dummy'),
(147969, 4845, 48, 'dummy'),
(147970, 4846, 48, 'dummy'),
(147971, 4847, 48, 'dummy'),
(147972, 4848, 48, 'dummy'),
(147973, 4849, 48, 'dummy'),
(147974, 4850, 48, 'dummy'),
(147975, 4851, 48, 'dummy'),
(147976, 4852, 48, 'dummy'),
(147977, 4853, 48, 'dummy'),
(147978, 4854, 48, 'dummy'),
(147979, 4855, 48, 'dummy'),
(147980, 4856, 48, 'dummy'),
(147981, 4857, 48, 'dummy'),
(147982, 4858, 48, 'dummy'),
(147983, 4859, 48, 'dummy'),
(147984, 4860, 48, 'dummy'),
(147985, 4861, 48, 'dummy'),
(147986, 4862, 48, 'dummy'),
(147987, 4863, 48, 'dummy'),
(147988, 4864, 48, 'dummy'),
(147989, 4865, 48, 'dummy'),
(147990, 4866, 48, 'dummy'),
(147991, 4867, 48, 'dummy'),
(147992, 4868, 48, 'dummy'),
(147993, 4869, 48, 'dummy'),
(147994, 4870, 48, 'dummy'),
(147995, 4871, 48, 'dummy'),
(147996, 4872, 48, 'dummy'),
(147997, 4873, 48, 'dummy'),
(147998, 4874, 48, 'dummy'),
(147999, 4875, 48, 'dummy'),
(148000, 4876, 48, 'dummy'),
(148001, 4877, 48, 'dummy'),
(148002, 4878, 48, 'dummy'),
(148003, 4879, 48, 'dummy'),
(148004, 4880, 48, 'dummy'),
(148005, 4881, 48, 'dummy'),
(148006, 4882, 48, 'dummy'),
(148007, 4883, 48, 'dummy'),
(148008, 4884, 48, 'dummy'),
(148009, 4885, 48, 'dummy'),
(148010, 4886, 48, 'dummy'),
(148011, 4887, 48, 'dummy'),
(148012, 4888, 48, 'dummy'),
(148013, 4889, 48, 'dummy'),
(148014, 4890, 48, 'dummy'),
(148015, 4891, 48, 'dummy'),
(148016, 4892, 48, 'dummy'),
(148017, 4893, 48, 'dummy'),
(148018, 4894, 48, 'dummy'),
(148019, 4895, 48, 'dummy'),
(148020, 4896, 48, 'dummy'),
(148021, 4897, 48, 'dummy'),
(148022, 4898, 48, 'dummy'),
(148023, 4899, 48, 'dummy'),
(148024, 4900, 48, 'dummy'),
(148025, 4901, 48, 'dummy'),
(148026, 4902, 48, 'dummy'),
(148027, 4903, 48, 'dummy'),
(148028, 4904, 48, 'dummy'),
(148029, 4905, 48, 'dummy'),
(148030, 4906, 48, 'dummy'),
(148031, 4907, 48, 'dummy'),
(148032, 4908, 48, 'dummy'),
(148033, 4909, 48, 'dummy'),
(148034, 4910, 48, 'dummy'),
(148035, 4911, 48, 'dummy'),
(148036, 4912, 48, 'dummy'),
(148037, 4913, 48, 'dummy'),
(148038, 4914, 48, 'dummy'),
(148039, 4915, 48, 'dummy'),
(148040, 4916, 48, 'dummy'),
(148041, 4917, 48, 'dummy'),
(148042, 4918, 48, 'dummy'),
(148043, 4919, 48, 'dummy'),
(148044, 4920, 48, 'dummy'),
(148045, 4921, 48, 'dummy'),
(148046, 4922, 48, 'dummy'),
(148047, 4923, 48, 'dummy'),
(148048, 4924, 48, 'dummy'),
(148049, 4925, 48, 'dummy'),
(148050, 4926, 48, 'dummy'),
(148051, 4927, 48, 'dummy'),
(148052, 4928, 48, 'dummy'),
(148053, 4929, 48, 'dummy'),
(148054, 4930, 48, 'dummy'),
(148055, 4931, 48, 'dummy'),
(148056, 4932, 48, 'dummy'),
(148057, 4933, 48, 'dummy'),
(148058, 4934, 48, 'dummy'),
(148059, 4935, 48, 'dummy'),
(148060, 4936, 48, 'dummy'),
(148061, 4937, 48, 'dummy'),
(148062, 4938, 48, 'dummy'),
(148063, 4939, 48, 'dummy'),
(148064, 4940, 48, 'dummy'),
(148065, 4941, 48, 'dummy'),
(148066, 4942, 48, 'dummy'),
(148067, 4943, 48, 'dummy'),
(148068, 4944, 48, 'dummy'),
(148069, 4945, 48, 'dummy'),
(148070, 4946, 48, 'dummy'),
(148071, 4947, 48, 'dummy'),
(148072, 4948, 48, 'dummy'),
(148073, 4949, 48, 'dummy'),
(148074, 4950, 48, 'dummy'),
(148075, 4951, 48, 'dummy'),
(148076, 4952, 48, 'dummy'),
(148077, 4953, 48, 'dummy'),
(148078, 4954, 48, 'dummy'),
(148079, 4955, 48, 'dummy'),
(148080, 4956, 48, 'dummy'),
(148081, 4957, 48, 'dummy'),
(148082, 4958, 48, 'dummy'),
(148083, 4959, 48, 'dummy'),
(148084, 4960, 48, 'dummy'),
(148085, 4961, 48, 'dummy'),
(148086, 4962, 48, 'dummy'),
(148087, 4963, 48, 'dummy'),
(148088, 4964, 48, 'dummy'),
(148089, 4965, 48, 'dummy'),
(148090, 4966, 48, 'dummy'),
(148091, 4967, 48, 'dummy'),
(148092, 4968, 48, 'dummy'),
(148093, 4969, 48, 'dummy'),
(148094, 4970, 48, 'dummy'),
(148095, 4971, 48, 'dummy'),
(148096, 4972, 48, 'dummy'),
(148097, 4973, 48, 'dummy'),
(148098, 4974, 48, 'dummy'),
(148099, 4975, 48, 'dummy'),
(148100, 4976, 48, 'dummy'),
(148101, 4977, 48, 'dummy'),
(148102, 4978, 48, 'dummy'),
(148103, 4979, 48, 'dummy'),
(148104, 4980, 48, 'dummy'),
(148105, 4981, 48, 'dummy'),
(148106, 4982, 48, 'dummy'),
(148107, 4983, 48, 'dummy'),
(148108, 4984, 48, 'dummy'),
(148109, 4985, 48, 'dummy'),
(148110, 4986, 48, 'dummy'),
(148111, 4987, 48, 'dummy'),
(148112, 4988, 48, 'dummy'),
(148113, 4989, 48, 'dummy'),
(148114, 4990, 48, 'dummy'),
(148115, 4991, 48, 'dummy'),
(148116, 4992, 48, 'dummy'),
(148117, 4993, 48, 'dummy'),
(148118, 4994, 48, 'dummy'),
(148119, 4995, 48, 'dummy'),
(148120, 4996, 48, 'dummy'),
(148121, 4997, 48, 'dummy'),
(148122, 4998, 48, 'dummy'),
(148123, 4999, 48, 'dummy'),
(148124, 5000, 48, 'dummy'),
(148125, 5001, 48, 'dummy'),
(148126, 5002, 48, 'dummy'),
(148127, 5003, 48, 'dummy'),
(148128, 5004, 48, 'dummy'),
(148129, 5005, 48, 'dummy'),
(148130, 5006, 48, 'dummy'),
(148131, 5007, 48, 'dummy'),
(148132, 5008, 48, 'dummy'),
(148133, 5009, 48, 'dummy'),
(148134, 5010, 48, 'dummy'),
(148135, 5011, 48, 'dummy'),
(148136, 5012, 48, 'dummy'),
(148137, 5013, 48, 'dummy'),
(148138, 5014, 48, 'dummy'),
(148139, 5015, 48, 'dummy'),
(148140, 5016, 48, 'dummy'),
(148141, 5017, 48, 'dummy'),
(148142, 5018, 48, 'dummy'),
(148143, 5019, 48, 'dummy'),
(148144, 5020, 48, 'dummy'),
(148145, 5021, 48, 'dummy'),
(148146, 5022, 48, 'dummy'),
(148147, 5023, 48, 'dummy'),
(148148, 5024, 48, 'dummy'),
(148149, 5025, 48, 'dummy'),
(148150, 5026, 48, 'dummy'),
(148151, 5027, 48, 'dummy'),
(148152, 5028, 48, 'dummy'),
(148153, 5029, 48, 'dummy'),
(148154, 5030, 48, 'dummy'),
(148155, 5031, 48, 'dummy'),
(148156, 5032, 48, 'dummy'),
(148157, 5033, 48, 'dummy'),
(148158, 5034, 48, 'dummy'),
(148159, 5035, 48, 'dummy'),
(148160, 5036, 48, 'dummy'),
(148161, 5037, 48, 'dummy'),
(148162, 5038, 48, 'dummy'),
(148163, 5039, 48, 'dummy'),
(148164, 5040, 48, 'dummy'),
(148165, 5041, 48, 'dummy'),
(148166, 5042, 48, 'dummy'),
(148167, 5043, 48, 'dummy'),
(148168, 5044, 48, 'dummy'),
(148169, 5045, 48, 'dummy'),
(148170, 5046, 48, 'dummy'),
(148171, 5047, 48, 'dummy'),
(148172, 5048, 48, 'dummy'),
(148173, 5049, 48, 'dummy'),
(148174, 5050, 48, 'dummy'),
(148175, 5051, 48, 'dummy'),
(148176, 5052, 48, 'dummy'),
(148177, 5053, 48, 'dummy'),
(148178, 5054, 48, 'dummy'),
(148179, 5055, 48, 'dummy'),
(148180, 5056, 48, 'dummy'),
(148181, 5057, 48, 'dummy'),
(148182, 5058, 48, 'dummy'),
(148183, 5059, 48, 'dummy'),
(148184, 5060, 48, 'dummy'),
(148185, 5061, 48, 'dummy'),
(148186, 5062, 48, 'dummy'),
(148187, 5063, 48, 'dummy'),
(148188, 5064, 48, 'dummy'),
(148189, 5065, 48, 'dummy'),
(148190, 5066, 48, 'dummy'),
(148191, 5067, 48, 'dummy'),
(148192, 5068, 48, 'dummy'),
(148193, 5069, 48, 'dummy'),
(148194, 5070, 48, 'dummy'),
(148195, 5071, 48, 'dummy'),
(148196, 5072, 48, 'dummy'),
(148197, 5073, 48, 'dummy'),
(148198, 5074, 48, 'dummy'),
(148199, 5075, 48, 'dummy'),
(148200, 5076, 48, 'dummy'),
(148201, 5077, 48, 'dummy'),
(148202, 5078, 48, 'dummy'),
(148203, 5079, 48, 'dummy'),
(148204, 5080, 48, 'dummy'),
(148205, 5081, 48, 'dummy'),
(148206, 5082, 48, 'dummy'),
(148207, 5083, 48, 'dummy'),
(148208, 5084, 48, 'dummy'),
(148209, 5085, 48, 'dummy'),
(148210, 5086, 48, 'dummy'),
(148211, 5087, 48, 'dummy'),
(148212, 5088, 48, 'dummy'),
(148213, 5089, 48, 'dummy'),
(148214, 5090, 48, 'dummy'),
(148215, 5091, 48, 'dummy'),
(148216, 5092, 48, 'dummy'),
(148217, 5093, 48, 'dummy'),
(148218, 5094, 48, 'dummy'),
(148219, 5095, 48, 'dummy'),
(148220, 5096, 48, 'dummy'),
(148221, 5097, 48, 'dummy'),
(148222, 5098, 48, 'dummy'),
(148223, 5099, 48, 'dummy'),
(148224, 5100, 48, 'dummy'),
(148225, 5101, 48, 'dummy'),
(148226, 5102, 48, 'dummy'),
(148227, 5103, 48, 'dummy'),
(148228, 5104, 48, 'dummy'),
(148229, 5105, 48, 'dummy'),
(148230, 5106, 48, 'dummy'),
(148231, 5107, 48, 'dummy'),
(148232, 5108, 48, 'dummy'),
(148233, 5109, 48, 'dummy'),
(148234, 5110, 48, 'dummy'),
(148235, 5111, 48, 'dummy'),
(148236, 5112, 48, 'dummy'),
(148237, 5113, 48, 'dummy'),
(148238, 5114, 48, 'dummy'),
(148239, 5115, 48, 'dummy'),
(148240, 5116, 48, 'dummy'),
(148241, 5117, 48, 'dummy'),
(148242, 5118, 48, 'dummy'),
(148243, 5119, 48, 'dummy'),
(148244, 5120, 48, 'dummy'),
(148245, 5121, 48, 'dummy'),
(148246, 5122, 48, 'dummy'),
(148247, 5123, 48, 'dummy'),
(148248, 5124, 48, 'dummy'),
(148249, 5125, 48, 'dummy'),
(148250, 5126, 48, 'dummy'),
(148251, 5127, 48, 'dummy'),
(148252, 5128, 48, 'dummy'),
(148253, 5129, 48, 'dummy'),
(148254, 5130, 48, 'dummy'),
(148255, 5131, 48, 'dummy'),
(148256, 5132, 48, 'dummy'),
(148257, 5133, 48, 'dummy'),
(148258, 5134, 48, 'dummy'),
(148259, 5135, 48, 'dummy'),
(148260, 5136, 48, 'dummy'),
(148261, 5137, 48, 'dummy'),
(148262, 5138, 48, 'dummy'),
(148263, 5139, 48, 'dummy'),
(148264, 5140, 48, 'dummy'),
(148265, 5141, 48, 'dummy'),
(148266, 5142, 48, 'dummy'),
(148267, 5143, 48, 'dummy'),
(148268, 5144, 48, 'dummy'),
(148269, 5145, 48, 'dummy'),
(148270, 5146, 48, 'dummy'),
(148271, 5147, 48, 'dummy'),
(148272, 5148, 48, 'dummy'),
(148273, 5149, 48, 'dummy'),
(148274, 5150, 48, 'dummy'),
(148275, 5151, 48, 'dummy'),
(148276, 5152, 48, 'dummy'),
(148277, 5153, 48, 'dummy'),
(148278, 5154, 48, 'dummy'),
(148279, 5155, 48, 'dummy'),
(148280, 5156, 48, 'dummy'),
(148281, 5157, 48, 'dummy'),
(148282, 5158, 48, 'dummy'),
(148283, 5159, 48, 'dummy'),
(148284, 5160, 48, 'dummy'),
(148285, 5161, 48, 'dummy'),
(148286, 5162, 48, 'dummy'),
(148287, 5163, 48, 'dummy'),
(148288, 5164, 48, 'dummy'),
(148289, 5165, 48, 'dummy'),
(148290, 5166, 48, 'dummy'),
(148291, 5167, 48, 'dummy'),
(148292, 5168, 48, 'dummy'),
(148293, 5169, 48, 'dummy'),
(148294, 5170, 48, 'dummy'),
(148295, 5171, 48, 'dummy'),
(148296, 5172, 48, 'dummy'),
(148297, 5173, 48, 'dummy'),
(148298, 5174, 48, 'dummy'),
(148299, 5175, 48, 'dummy'),
(148300, 5176, 48, 'dummy'),
(148301, 5177, 48, 'dummy'),
(148302, 5178, 48, 'dummy'),
(148303, 5179, 48, 'dummy'),
(148304, 5180, 48, 'dummy'),
(148305, 5181, 48, 'dummy'),
(148306, 5182, 48, 'dummy'),
(148307, 5183, 48, 'dummy'),
(148308, 5184, 48, 'dummy'),
(148309, 5185, 48, 'dummy'),
(148310, 5186, 48, 'dummy'),
(148311, 5187, 48, 'dummy'),
(148312, 5188, 48, 'dummy'),
(148313, 5189, 48, 'dummy'),
(148314, 5190, 48, 'dummy'),
(148315, 5191, 48, 'dummy'),
(148316, 5192, 48, 'dummy'),
(148317, 5193, 48, 'dummy'),
(148318, 5194, 48, 'dummy'),
(148319, 5195, 48, 'dummy'),
(148320, 5196, 48, 'dummy'),
(148321, 5197, 48, 'dummy'),
(148322, 5198, 48, 'dummy'),
(148323, 5199, 48, 'dummy'),
(148324, 5200, 48, 'dummy'),
(148325, 5201, 48, 'dummy'),
(148326, 5202, 48, 'dummy'),
(148327, 5203, 48, 'dummy'),
(148328, 5204, 48, 'dummy'),
(148329, 5205, 48, 'dummy'),
(148330, 5206, 48, 'dummy'),
(148331, 5207, 48, 'dummy'),
(148332, 5208, 48, 'dummy'),
(148333, 5209, 48, 'dummy'),
(148334, 5210, 48, 'dummy'),
(148335, 5211, 48, 'dummy'),
(148336, 5212, 48, 'dummy'),
(148337, 5213, 48, 'dummy'),
(148338, 5214, 48, 'dummy'),
(148339, 5215, 48, 'dummy'),
(148340, 5216, 48, 'dummy'),
(148341, 5217, 48, 'dummy'),
(148342, 5218, 48, 'dummy'),
(148343, 5219, 48, 'dummy'),
(148344, 5220, 48, 'dummy'),
(148345, 5221, 48, 'dummy'),
(148346, 5222, 48, 'dummy'),
(148347, 5223, 48, 'dummy'),
(148348, 5224, 48, 'dummy'),
(148349, 5225, 48, 'dummy'),
(148350, 5226, 48, 'dummy'),
(148351, 5227, 48, 'dummy'),
(148352, 5228, 48, 'dummy'),
(148353, 5229, 48, 'dummy'),
(148354, 5230, 48, 'dummy'),
(148355, 5231, 48, 'dummy'),
(148356, 5232, 48, 'dummy'),
(148357, 5233, 48, 'dummy'),
(148358, 5234, 48, 'dummy'),
(148359, 5235, 48, 'dummy'),
(148360, 5236, 48, 'dummy'),
(148361, 5237, 48, 'dummy'),
(148362, 5238, 48, 'dummy'),
(148363, 5239, 48, 'dummy'),
(148364, 5240, 48, 'dummy'),
(148365, 5241, 48, 'dummy'),
(148366, 5242, 48, 'dummy'),
(148367, 5243, 48, 'dummy'),
(148368, 5244, 48, 'dummy'),
(148369, 5245, 48, 'dummy'),
(148370, 5246, 48, 'dummy'),
(148371, 5247, 48, 'dummy'),
(148372, 5248, 48, 'dummy'),
(148373, 5249, 48, 'dummy'),
(148374, 5250, 48, 'dummy'),
(148375, 5251, 48, 'dummy'),
(148376, 5252, 48, 'dummy'),
(148377, 5253, 48, 'dummy'),
(148378, 5254, 48, 'dummy'),
(148379, 5255, 48, 'dummy'),
(148380, 5256, 48, 'dummy'),
(148381, 5257, 48, 'dummy'),
(148382, 5258, 48, 'dummy'),
(148383, 5259, 48, 'dummy'),
(148384, 5260, 48, 'dummy'),
(148385, 5261, 48, 'dummy'),
(148386, 5262, 48, 'dummy'),
(148387, 5263, 48, 'dummy'),
(148388, 5264, 48, 'dummy'),
(148389, 5265, 48, 'dummy'),
(148390, 5266, 48, 'dummy'),
(148391, 5267, 48, 'dummy'),
(148392, 5268, 48, 'dummy'),
(148393, 5269, 48, 'dummy'),
(148394, 5270, 48, 'dummy'),
(148395, 5271, 48, 'dummy'),
(148396, 5272, 48, 'dummy'),
(148397, 5273, 48, 'dummy'),
(148398, 5274, 48, 'dummy'),
(148399, 5275, 48, 'dummy'),
(148400, 5276, 48, 'dummy'),
(148401, 5277, 48, 'dummy'),
(148402, 5278, 48, 'dummy'),
(148403, 5279, 48, 'dummy'),
(148404, 5280, 48, 'dummy'),
(148405, 5281, 48, 'dummy'),
(148406, 5282, 48, 'dummy'),
(148407, 5283, 48, 'dummy'),
(148408, 5284, 48, 'dummy'),
(148409, 5285, 48, 'dummy'),
(148410, 5286, 48, 'dummy'),
(148411, 5287, 48, 'dummy'),
(148412, 5288, 48, 'dummy'),
(148413, 5289, 48, 'dummy'),
(148414, 5290, 48, 'dummy'),
(148415, 5291, 48, 'dummy'),
(148416, 5292, 48, 'dummy'),
(148417, 5293, 48, 'dummy'),
(148418, 5294, 48, 'dummy'),
(148419, 5295, 48, 'dummy'),
(148420, 5296, 48, 'dummy'),
(148421, 5297, 48, 'dummy'),
(148422, 5298, 48, 'dummy'),
(148423, 5299, 48, 'dummy'),
(148424, 5300, 48, 'dummy'),
(148425, 5301, 48, 'dummy'),
(148426, 5302, 48, 'dummy'),
(148427, 5303, 48, 'dummy'),
(148428, 5304, 48, 'dummy'),
(148429, 5305, 48, 'dummy'),
(148430, 5306, 48, 'dummy'),
(148431, 5307, 48, 'dummy'),
(148432, 5308, 48, 'dummy'),
(148433, 5309, 48, 'dummy'),
(148434, 5310, 48, 'dummy'),
(148435, 5311, 48, 'dummy'),
(148436, 5312, 48, 'dummy'),
(148437, 5313, 48, 'dummy'),
(148438, 5314, 48, 'dummy'),
(148439, 5315, 48, 'dummy'),
(148440, 5316, 48, 'dummy'),
(148441, 5317, 48, 'dummy'),
(148442, 5318, 48, 'dummy'),
(148443, 5319, 48, 'dummy'),
(148444, 5320, 48, 'dummy'),
(148445, 5321, 48, 'dummy'),
(148446, 5322, 48, 'dummy'),
(148447, 5323, 48, 'dummy'),
(148448, 5324, 48, 'dummy'),
(148449, 5325, 48, 'dummy'),
(148450, 5326, 48, 'dummy'),
(148451, 5327, 48, 'dummy'),
(148452, 5328, 48, 'dummy'),
(148453, 5329, 48, 'dummy'),
(148454, 5330, 48, 'dummy'),
(148455, 5331, 48, 'dummy'),
(148456, 5332, 48, 'dummy'),
(148457, 5333, 48, 'dummy'),
(148458, 5334, 48, 'dummy'),
(148459, 5335, 48, 'dummy'),
(148460, 5336, 48, 'dummy'),
(148461, 5337, 48, 'dummy'),
(148462, 5338, 48, 'dummy'),
(148463, 5339, 48, 'dummy'),
(148464, 5340, 48, 'dummy'),
(148465, 5341, 48, 'dummy'),
(148466, 5342, 48, 'dummy'),
(148467, 5343, 48, 'dummy'),
(148468, 5344, 48, 'dummy'),
(148469, 5345, 48, 'dummy'),
(148470, 5346, 48, 'dummy'),
(148471, 5347, 48, 'dummy'),
(148472, 5348, 48, 'dummy'),
(148473, 5349, 48, 'dummy'),
(148474, 5350, 48, 'dummy'),
(148475, 5351, 48, 'dummy'),
(148476, 5352, 48, 'dummy'),
(148477, 5353, 48, 'dummy'),
(148478, 5354, 48, 'dummy'),
(148479, 5355, 48, 'dummy'),
(148480, 5356, 48, 'dummy'),
(148481, 5357, 48, 'dummy'),
(148482, 5358, 48, 'dummy'),
(148483, 5359, 48, 'dummy'),
(148484, 5360, 48, 'dummy'),
(148485, 5361, 48, 'dummy'),
(148486, 5362, 48, 'dummy'),
(148487, 5363, 48, 'dummy'),
(148488, 5364, 48, 'dummy'),
(148489, 5365, 48, 'dummy'),
(148490, 5366, 48, 'dummy'),
(148491, 5367, 48, 'dummy'),
(148492, 5368, 48, 'dummy'),
(148493, 5369, 48, 'dummy'),
(148494, 5370, 48, 'dummy'),
(148495, 5371, 48, 'dummy'),
(148496, 5372, 48, 'dummy'),
(148497, 5373, 48, 'dummy'),
(148498, 5374, 48, 'dummy'),
(148499, 5375, 48, 'dummy'),
(148500, 5376, 48, 'dummy'),
(148501, 5377, 48, 'dummy'),
(148502, 5378, 48, 'dummy'),
(148503, 5379, 48, 'dummy'),
(148504, 5380, 48, 'dummy'),
(148505, 5381, 48, 'dummy'),
(148506, 5382, 48, 'dummy'),
(148507, 5383, 48, 'dummy'),
(148508, 5384, 48, 'dummy'),
(148509, 5385, 48, 'dummy'),
(148510, 5386, 48, 'dummy'),
(148511, 5387, 48, 'dummy'),
(148512, 5388, 48, 'dummy'),
(148513, 5389, 48, 'dummy'),
(148514, 5390, 48, 'dummy'),
(148515, 5391, 48, 'dummy'),
(148516, 5392, 48, 'dummy'),
(148517, 5393, 48, 'dummy'),
(148518, 5394, 48, 'dummy'),
(148519, 5395, 48, 'dummy'),
(148520, 5396, 48, 'dummy'),
(148521, 5397, 48, 'dummy'),
(148522, 5398, 48, 'dummy'),
(148523, 5399, 48, 'dummy'),
(148524, 5400, 48, 'dummy'),
(148525, 5401, 48, 'dummy'),
(148526, 5402, 48, 'dummy'),
(148527, 5403, 48, 'dummy'),
(148528, 5404, 48, 'dummy'),
(148529, 5405, 48, 'dummy'),
(148530, 5406, 48, 'dummy'),
(148531, 5407, 48, 'dummy'),
(148532, 5408, 48, 'dummy'),
(148533, 5409, 48, 'dummy'),
(148534, 5410, 48, 'dummy'),
(148535, 5411, 48, 'dummy'),
(148536, 5412, 48, 'dummy'),
(148537, 5413, 48, 'dummy'),
(148538, 5414, 48, 'dummy'),
(148539, 5415, 48, 'dummy'),
(148540, 5416, 48, 'dummy'),
(148541, 5417, 48, 'dummy'),
(148542, 5418, 48, 'dummy'),
(148543, 5419, 48, 'dummy'),
(148544, 5420, 48, 'dummy'),
(148545, 5421, 48, 'dummy'),
(148546, 5422, 48, 'dummy'),
(148547, 5423, 48, 'dummy'),
(148548, 5424, 48, 'dummy'),
(148549, 5425, 48, 'dummy'),
(148550, 5426, 48, 'dummy'),
(148551, 5427, 48, 'dummy'),
(148552, 5428, 48, 'dummy'),
(148553, 5429, 48, 'dummy'),
(148554, 5430, 48, 'dummy'),
(148555, 5431, 48, 'dummy'),
(148556, 5432, 48, 'dummy'),
(148557, 5433, 48, 'dummy'),
(148558, 5434, 48, 'dummy'),
(148559, 5435, 48, 'dummy'),
(148560, 5436, 48, 'dummy'),
(148561, 5437, 48, 'dummy'),
(148562, 5438, 48, 'dummy'),
(148563, 5439, 48, 'dummy'),
(148564, 5440, 48, 'dummy'),
(148565, 5441, 48, 'dummy'),
(148566, 5442, 48, 'dummy'),
(148567, 5443, 48, 'dummy'),
(148568, 5444, 48, 'dummy'),
(148569, 5445, 48, 'dummy'),
(148570, 5446, 48, 'dummy'),
(148571, 5447, 48, 'dummy'),
(148572, 5448, 48, 'dummy'),
(148573, 5449, 48, 'dummy'),
(148574, 5450, 48, 'dummy'),
(148575, 5451, 48, 'dummy'),
(148576, 5452, 48, 'dummy'),
(148577, 5453, 48, 'dummy'),
(148578, 5454, 48, 'dummy'),
(148579, 5455, 48, 'dummy'),
(148580, 5456, 48, 'dummy'),
(148581, 5457, 48, 'dummy'),
(148582, 5458, 48, 'dummy'),
(148583, 5459, 48, 'dummy'),
(148584, 5460, 48, 'dummy'),
(148585, 5461, 48, 'dummy'),
(148586, 5462, 48, 'dummy'),
(148587, 5463, 48, 'dummy'),
(148588, 5464, 48, 'dummy'),
(148589, 5465, 48, 'dummy'),
(148590, 5466, 48, 'dummy'),
(148591, 5467, 48, 'dummy'),
(148592, 5468, 48, 'dummy'),
(148593, 5469, 48, 'dummy'),
(148594, 5470, 48, 'dummy'),
(148595, 5471, 48, 'dummy'),
(148596, 5472, 48, 'dummy'),
(148597, 5473, 48, 'dummy'),
(148598, 5474, 48, 'dummy'),
(148599, 5475, 48, 'dummy'),
(148600, 5476, 48, 'dummy'),
(148601, 5477, 48, 'dummy'),
(148602, 5478, 48, 'dummy'),
(148603, 5479, 48, 'dummy'),
(148604, 5480, 48, 'dummy'),
(148605, 5481, 48, 'dummy'),
(148606, 5482, 48, 'dummy'),
(148607, 5483, 48, 'dummy'),
(148608, 5484, 48, 'dummy'),
(148609, 5485, 48, 'dummy'),
(148610, 5486, 48, 'dummy'),
(148611, 5487, 48, 'dummy'),
(148612, 5488, 48, 'dummy'),
(148613, 5489, 48, 'dummy'),
(148614, 5490, 48, 'dummy'),
(148615, 5491, 48, 'dummy'),
(148616, 5492, 48, 'dummy'),
(148617, 5493, 48, 'dummy'),
(148618, 5494, 48, 'dummy'),
(148619, 5495, 48, 'dummy'),
(148620, 5496, 48, 'dummy'),
(148621, 5497, 48, 'dummy'),
(148622, 5498, 48, 'dummy'),
(148623, 5499, 48, 'dummy'),
(148624, 5500, 48, 'dummy'),
(148625, 5501, 48, 'dummy'),
(148626, 5502, 48, 'dummy'),
(148627, 5503, 48, 'dummy'),
(148628, 5504, 48, 'dummy'),
(148629, 5505, 48, 'dummy'),
(148630, 5506, 48, 'dummy'),
(148631, 5507, 48, 'dummy'),
(148632, 5508, 48, 'dummy'),
(148633, 5509, 48, 'dummy'),
(148634, 5510, 48, 'dummy'),
(148635, 5511, 48, 'dummy'),
(148636, 5512, 48, 'dummy'),
(148637, 5513, 48, 'dummy'),
(148638, 5514, 48, 'dummy'),
(148639, 5515, 48, 'dummy'),
(148640, 5516, 48, 'dummy'),
(148641, 5517, 48, 'dummy'),
(148642, 5518, 48, 'dummy'),
(148643, 5519, 48, 'dummy'),
(148644, 5520, 48, 'dummy'),
(148645, 5521, 48, 'dummy'),
(148646, 5522, 48, 'dummy'),
(148647, 5523, 48, 'dummy'),
(148648, 5524, 48, 'dummy'),
(148649, 5525, 48, 'dummy'),
(148650, 5526, 48, 'dummy'),
(148651, 5527, 48, 'dummy'),
(148652, 5528, 48, 'dummy'),
(148653, 5529, 48, 'dummy'),
(148654, 5530, 48, 'dummy'),
(148655, 5531, 48, 'dummy'),
(148656, 5532, 48, 'dummy'),
(148657, 5533, 48, 'dummy'),
(148658, 5534, 48, 'dummy'),
(148659, 5535, 48, 'dummy'),
(148660, 5536, 48, 'dummy'),
(148661, 5537, 48, 'dummy'),
(148662, 5538, 48, 'dummy'),
(148663, 5539, 48, 'dummy'),
(148664, 5540, 48, 'dummy'),
(148665, 5541, 48, 'dummy'),
(148666, 5542, 48, 'dummy'),
(148667, 5543, 48, 'dummy'),
(148668, 5544, 48, 'dummy'),
(148669, 5545, 48, 'dummy'),
(148670, 5546, 48, 'dummy'),
(148671, 5547, 48, 'dummy'),
(148672, 5548, 48, 'dummy'),
(148673, 5549, 48, 'dummy'),
(148674, 5550, 48, 'dummy'),
(148675, 5551, 48, 'dummy'),
(148676, 5552, 48, 'dummy'),
(148677, 5553, 48, 'dummy'),
(148678, 5554, 48, 'dummy'),
(148679, 5555, 48, 'dummy'),
(148680, 5556, 48, 'dummy'),
(148681, 5557, 48, 'dummy'),
(148682, 5558, 48, 'dummy'),
(148683, 5559, 48, 'dummy'),
(148684, 5560, 48, 'dummy'),
(148685, 5561, 48, 'dummy'),
(148686, 5562, 48, 'dummy'),
(148687, 5563, 48, 'dummy'),
(148688, 5564, 48, 'dummy'),
(148689, 5565, 48, 'dummy'),
(148690, 5566, 48, 'dummy'),
(148691, 5567, 48, 'dummy'),
(148692, 5568, 48, 'dummy'),
(148693, 5569, 48, 'dummy'),
(148694, 5570, 48, 'dummy'),
(148695, 5571, 48, 'dummy'),
(148696, 5572, 48, 'dummy'),
(148697, 5573, 48, 'dummy'),
(148698, 5574, 48, 'dummy'),
(148699, 5575, 48, 'dummy'),
(148700, 5576, 48, 'dummy'),
(148701, 5577, 48, 'dummy'),
(148702, 5578, 48, 'dummy'),
(148703, 5579, 48, 'dummy'),
(148704, 5580, 48, 'dummy'),
(148705, 5581, 48, 'dummy'),
(148706, 5582, 48, 'dummy'),
(148707, 5583, 48, 'dummy'),
(148708, 5584, 48, 'dummy'),
(148709, 5585, 48, 'dummy'),
(148710, 5586, 48, 'dummy'),
(148711, 5587, 48, 'dummy'),
(148712, 5588, 48, 'dummy'),
(148713, 5589, 48, 'dummy'),
(148714, 5590, 48, 'dummy'),
(148715, 5591, 48, 'dummy'),
(148716, 5592, 48, 'dummy'),
(148717, 5593, 48, 'dummy'),
(148718, 5594, 48, 'dummy'),
(148719, 5595, 48, 'dummy'),
(148720, 5596, 48, 'dummy'),
(148721, 5597, 48, 'dummy'),
(148722, 5598, 48, 'dummy'),
(148723, 5599, 48, 'dummy'),
(148724, 5600, 48, 'dummy'),
(148725, 5601, 48, 'dummy'),
(148726, 5602, 48, 'dummy'),
(148727, 5603, 48, 'dummy'),
(148728, 5604, 48, 'dummy'),
(148729, 5605, 48, 'dummy'),
(148730, 5606, 48, 'dummy'),
(148731, 5607, 48, 'dummy'),
(148732, 5608, 48, 'dummy'),
(148733, 5609, 48, 'dummy'),
(148734, 5610, 48, 'dummy'),
(148735, 5611, 48, 'dummy'),
(148736, 5612, 48, 'dummy'),
(148737, 5613, 48, 'dummy'),
(148738, 5614, 48, 'dummy'),
(148739, 5615, 48, 'dummy'),
(148740, 5616, 48, 'dummy'),
(148741, 5617, 48, 'dummy'),
(148742, 5618, 48, 'dummy'),
(148743, 5619, 48, 'dummy'),
(148744, 5620, 48, 'dummy'),
(148745, 5621, 48, 'dummy'),
(148746, 5622, 48, 'dummy'),
(148747, 5623, 48, 'dummy'),
(148748, 5624, 48, 'dummy'),
(148749, 5625, 48, 'dummy'),
(148750, 5626, 48, 'dummy'),
(148751, 5627, 48, 'dummy'),
(148752, 5628, 48, 'dummy'),
(148753, 5629, 48, 'dummy'),
(148754, 5630, 48, 'dummy'),
(148755, 5631, 48, 'dummy'),
(148756, 5632, 48, 'dummy'),
(148757, 5633, 48, 'dummy'),
(148758, 5634, 48, 'dummy'),
(148759, 5635, 48, 'dummy'),
(148760, 5636, 48, 'dummy'),
(148761, 5637, 48, 'dummy'),
(148762, 5638, 48, 'dummy'),
(148763, 5639, 48, 'dummy'),
(148764, 5640, 48, 'dummy'),
(148765, 5641, 48, 'dummy'),
(148766, 5642, 48, 'dummy'),
(148767, 5643, 48, 'dummy'),
(148768, 5644, 48, 'dummy'),
(148769, 5645, 48, 'dummy'),
(148770, 5646, 48, 'dummy'),
(148771, 5647, 48, 'dummy'),
(148772, 5648, 48, 'dummy'),
(148773, 5649, 48, 'dummy'),
(148774, 5650, 48, 'dummy'),
(148775, 5651, 48, 'dummy'),
(148776, 5652, 48, 'dummy'),
(148777, 5653, 48, 'dummy'),
(148778, 5654, 48, 'dummy'),
(148779, 5655, 48, 'dummy'),
(148780, 5656, 48, 'dummy'),
(148781, 5657, 48, 'dummy'),
(148782, 5658, 48, 'dummy'),
(148783, 5659, 48, 'dummy'),
(148784, 5660, 48, 'dummy'),
(148785, 5661, 48, 'dummy'),
(148786, 5662, 48, 'dummy'),
(148787, 5663, 48, 'dummy'),
(148788, 5664, 48, 'dummy'),
(148789, 5665, 48, 'dummy'),
(148790, 5666, 48, 'dummy'),
(148791, 5667, 48, 'dummy'),
(148792, 5668, 48, 'dummy'),
(148793, 5669, 48, 'dummy'),
(148794, 5670, 48, 'dummy'),
(148795, 5671, 48, 'dummy'),
(148796, 5672, 48, 'dummy'),
(148797, 5673, 48, 'dummy'),
(148798, 5674, 48, 'dummy'),
(148799, 5675, 48, 'dummy'),
(148800, 5676, 48, 'dummy'),
(148801, 5677, 48, 'dummy'),
(148802, 5678, 48, 'dummy'),
(148803, 5679, 48, 'dummy'),
(148804, 5680, 48, 'dummy'),
(148805, 5681, 48, 'dummy'),
(148806, 5682, 48, 'dummy'),
(148807, 5683, 48, 'dummy'),
(148808, 5684, 48, 'dummy'),
(148809, 5685, 48, 'dummy'),
(148810, 5686, 48, 'dummy'),
(148811, 5687, 48, 'dummy'),
(148812, 5688, 48, 'dummy'),
(148813, 5689, 48, 'dummy'),
(148814, 5690, 48, 'dummy'),
(148815, 5691, 48, 'dummy'),
(148816, 5692, 48, 'dummy'),
(148817, 5693, 48, 'dummy'),
(148818, 5694, 48, 'dummy'),
(148819, 5695, 48, 'dummy'),
(148820, 5696, 48, 'dummy'),
(148821, 5697, 48, 'dummy'),
(148822, 5698, 48, 'dummy'),
(148823, 5699, 48, 'dummy'),
(148824, 5700, 48, 'dummy'),
(148825, 5701, 48, 'dummy'),
(148826, 5702, 48, 'dummy'),
(148827, 5703, 48, 'dummy'),
(148828, 5704, 48, 'dummy'),
(148829, 5705, 48, 'dummy'),
(148830, 5706, 48, 'dummy'),
(148831, 5707, 48, 'dummy'),
(148832, 5708, 48, 'dummy'),
(148833, 5709, 48, 'dummy'),
(148834, 5710, 48, 'dummy'),
(148835, 5711, 48, 'dummy'),
(148836, 5712, 48, 'dummy'),
(148837, 5713, 48, 'dummy'),
(148838, 5714, 48, 'dummy'),
(148839, 5715, 48, 'dummy'),
(148840, 5716, 48, 'dummy'),
(148841, 5717, 48, 'dummy'),
(148842, 5718, 48, 'dummy'),
(148843, 5719, 48, 'dummy'),
(148844, 5720, 48, 'dummy'),
(148845, 5721, 48, 'dummy'),
(148846, 5722, 48, 'dummy'),
(148847, 5723, 48, 'dummy'),
(148848, 5724, 48, 'dummy'),
(148849, 5725, 48, 'dummy'),
(148850, 5726, 48, 'dummy'),
(148851, 5727, 48, 'dummy'),
(148852, 5728, 48, 'dummy'),
(148853, 5729, 48, 'dummy'),
(148854, 5730, 48, 'dummy'),
(148855, 5731, 48, 'dummy'),
(148856, 5732, 48, 'dummy'),
(148857, 5733, 48, 'dummy'),
(148858, 5734, 48, 'dummy'),
(148859, 5735, 48, 'dummy'),
(148860, 5736, 48, 'dummy'),
(148861, 5737, 48, 'dummy'),
(148862, 5738, 48, 'dummy'),
(148863, 5739, 48, 'dummy'),
(148864, 5740, 48, 'dummy'),
(148865, 5741, 48, 'dummy'),
(148866, 5742, 48, 'dummy'),
(148867, 5743, 48, 'dummy'),
(148868, 5744, 48, 'dummy'),
(148869, 5745, 48, 'dummy'),
(148870, 5746, 48, 'dummy'),
(148871, 5747, 48, 'dummy'),
(148872, 5748, 48, 'dummy'),
(148873, 5749, 48, 'dummy'),
(148874, 5750, 48, 'dummy'),
(148875, 5751, 48, 'dummy'),
(148876, 5752, 48, 'dummy'),
(148877, 5753, 48, 'dummy'),
(148878, 5754, 48, 'dummy'),
(148879, 5755, 48, 'dummy'),
(148880, 5756, 48, 'dummy'),
(148881, 5757, 48, 'dummy'),
(148882, 5758, 48, 'dummy'),
(148883, 5759, 48, 'dummy'),
(148884, 5760, 48, 'dummy'),
(148885, 5761, 48, 'dummy'),
(148886, 5762, 48, 'dummy'),
(148887, 5763, 48, 'dummy'),
(148888, 5764, 48, 'dummy'),
(148889, 5765, 48, 'dummy'),
(148890, 5766, 48, 'dummy'),
(148891, 5767, 48, 'dummy'),
(148892, 5768, 48, 'dummy'),
(148893, 5769, 48, 'dummy'),
(148894, 5770, 48, 'dummy'),
(148895, 5771, 48, 'dummy'),
(148896, 5772, 48, 'dummy'),
(148897, 5773, 48, 'dummy'),
(148898, 5774, 48, 'dummy'),
(148899, 5775, 48, 'dummy'),
(148900, 5776, 48, 'dummy'),
(148901, 5777, 48, 'dummy'),
(148902, 5778, 48, 'dummy'),
(148903, 5779, 48, 'dummy'),
(148904, 5780, 48, 'dummy'),
(148905, 5781, 48, 'dummy'),
(148906, 5782, 48, 'dummy'),
(148907, 5783, 48, 'dummy'),
(148908, 5784, 48, 'dummy'),
(148909, 5785, 48, 'dummy'),
(148910, 5786, 48, 'dummy'),
(148911, 5787, 48, 'dummy'),
(148912, 5788, 48, 'dummy'),
(148913, 5789, 48, 'dummy'),
(148914, 5790, 48, 'dummy'),
(148915, 5791, 48, 'dummy'),
(148916, 5792, 48, 'dummy'),
(148917, 5793, 48, 'dummy'),
(148918, 5794, 48, 'dummy'),
(148919, 5795, 48, 'dummy'),
(148920, 5796, 48, 'dummy'),
(148921, 5797, 48, 'dummy'),
(148922, 5798, 48, 'dummy'),
(148923, 5799, 48, 'dummy'),
(148924, 5800, 48, 'dummy'),
(148925, 5801, 48, 'dummy'),
(148926, 5802, 48, 'dummy'),
(148927, 5803, 48, 'dummy'),
(148928, 5804, 48, 'dummy'),
(148929, 5805, 48, 'dummy'),
(148930, 5806, 48, 'dummy'),
(148931, 5807, 48, 'dummy'),
(148932, 5808, 48, 'dummy'),
(148933, 5809, 48, 'dummy'),
(148934, 5810, 48, 'dummy'),
(148935, 5811, 48, 'dummy'),
(148936, 5812, 48, 'dummy'),
(148937, 5813, 48, 'dummy'),
(148938, 5814, 48, 'dummy'),
(148939, 5815, 48, 'dummy'),
(148940, 5816, 48, 'dummy'),
(148941, 5817, 48, 'dummy'),
(148942, 5818, 48, 'dummy'),
(148943, 5819, 48, 'dummy'),
(148944, 5820, 48, 'dummy'),
(148945, 5821, 48, 'dummy'),
(148946, 5822, 48, 'dummy'),
(148947, 5823, 48, 'dummy'),
(148948, 5824, 48, 'dummy'),
(148949, 5825, 48, 'dummy'),
(148950, 5826, 48, 'dummy'),
(148951, 5827, 48, 'dummy'),
(148952, 5828, 48, 'dummy'),
(148953, 5829, 48, 'dummy'),
(148954, 5830, 48, 'dummy'),
(148955, 5831, 48, 'dummy'),
(148956, 5832, 48, 'dummy'),
(148957, 5833, 48, 'dummy'),
(148958, 5834, 48, 'dummy'),
(148959, 5835, 48, 'dummy'),
(148960, 5836, 48, 'dummy'),
(148961, 5837, 48, 'dummy'),
(148962, 5838, 48, 'dummy'),
(148963, 5839, 48, 'dummy'),
(148964, 5840, 48, 'dummy'),
(148965, 5841, 48, 'dummy'),
(148966, 5842, 48, 'dummy'),
(148967, 5843, 48, 'dummy'),
(148968, 5844, 48, 'dummy'),
(148969, 5845, 48, 'dummy'),
(148970, 5846, 48, 'dummy'),
(148971, 5847, 48, 'dummy'),
(148972, 5848, 48, 'dummy'),
(148973, 5849, 48, 'dummy'),
(148974, 5850, 48, 'dummy'),
(148975, 5851, 48, 'dummy'),
(148976, 5852, 48, 'dummy'),
(148977, 5853, 48, 'dummy'),
(148978, 5854, 48, 'dummy'),
(148979, 5855, 48, 'dummy'),
(148980, 5856, 48, 'dummy'),
(148981, 5857, 48, 'dummy'),
(148982, 5858, 48, 'dummy'),
(148983, 5859, 48, 'dummy'),
(148984, 5860, 48, 'dummy'),
(148985, 5861, 48, 'dummy'),
(148986, 5862, 48, 'dummy'),
(148987, 5863, 48, 'dummy'),
(148988, 5864, 48, 'dummy'),
(148989, 5865, 48, 'dummy'),
(148990, 5866, 48, 'dummy'),
(148991, 5867, 48, 'dummy'),
(148992, 5868, 48, 'dummy');
INSERT INTO `lang_definitions` VALUES
(148993, 5869, 48, 'dummy'),
(148994, 5870, 48, 'dummy'),
(148995, 5871, 48, 'dummy'),
(148996, 5872, 48, 'dummy'),
(148997, 5873, 48, 'dummy'),
(148998, 5874, 48, 'dummy'),
(148999, 5875, 48, 'dummy'),
(149000, 5876, 48, 'dummy'),
(149001, 5877, 48, 'dummy'),
(149002, 5878, 48, 'dummy'),
(149003, 5879, 48, 'dummy'),
(149004, 5880, 48, 'dummy'),
(149005, 5881, 48, 'dummy'),
(149006, 5882, 48, 'dummy'),
(149007, 5883, 48, 'dummy'),
(149008, 5884, 48, 'dummy'),
(149009, 5885, 48, 'dummy'),
(149010, 5886, 48, 'dummy'),
(149011, 5887, 48, 'dummy'),
(149012, 5888, 48, 'dummy'),
(149013, 5889, 48, 'dummy'),
(149014, 5890, 48, 'dummy'),
(149015, 5891, 48, 'dummy'),
(149016, 5892, 48, 'dummy'),
(149017, 5893, 48, 'dummy'),
(149018, 5894, 48, 'dummy'),
(149019, 5895, 48, 'dummy'),
(149020, 5896, 48, 'dummy'),
(149021, 5897, 48, 'dummy'),
(149022, 5898, 48, 'dummy'),
(149023, 5899, 48, 'dummy'),
(149024, 5900, 48, 'dummy'),
(149025, 5901, 48, 'dummy'),
(149026, 5902, 48, 'dummy'),
(149027, 5903, 48, 'dummy'),
(149028, 5904, 48, 'dummy'),
(149029, 5905, 48, 'dummy'),
(149030, 5906, 48, 'dummy'),
(149031, 5907, 48, 'dummy'),
(149032, 5908, 48, 'dummy'),
(149033, 5909, 48, 'dummy'),
(149034, 5910, 48, 'dummy'),
(149035, 5911, 48, 'dummy'),
(149036, 5912, 48, 'dummy'),
(149037, 5913, 48, 'dummy'),
(149038, 5914, 48, 'dummy'),
(149039, 5915, 48, 'dummy'),
(149040, 5916, 48, 'dummy'),
(149041, 5917, 48, 'dummy'),
(149042, 5918, 48, 'dummy'),
(149043, 5919, 48, 'dummy'),
(149044, 5920, 48, 'dummy'),
(149045, 5921, 48, 'dummy'),
(149046, 5922, 48, 'dummy'),
(149047, 5923, 48, 'dummy'),
(149048, 5924, 48, 'dummy'),
(149049, 5925, 48, 'dummy'),
(149050, 5926, 48, 'dummy'),
(149051, 5927, 48, 'dummy'),
(149052, 5928, 48, 'dummy'),
(149053, 5929, 48, 'dummy'),
(149054, 5930, 48, 'dummy'),
(149055, 5931, 48, 'dummy'),
(149056, 5932, 48, 'dummy'),
(149057, 5933, 48, 'dummy'),
(149058, 5934, 48, 'dummy'),
(149059, 5935, 48, 'dummy'),
(149060, 5936, 48, 'dummy'),
(149061, 5937, 48, 'dummy'),
(149062, 5938, 48, 'dummy'),
(149063, 5939, 48, 'dummy'),
(149064, 5940, 48, 'dummy'),
(149065, 5941, 48, 'dummy'),
(149066, 5942, 48, 'dummy'),
(149067, 5943, 48, 'dummy'),
(149068, 5944, 48, 'dummy'),
(149069, 5945, 48, 'dummy'),
(149070, 5946, 48, 'dummy'),
(149071, 5947, 48, 'dummy'),
(149072, 5948, 48, 'dummy'),
(149073, 5949, 48, 'dummy'),
(149074, 5950, 48, 'dummy'),
(149075, 5951, 48, 'dummy'),
(149076, 5952, 48, 'dummy'),
(149077, 5953, 48, 'dummy'),
(149078, 5954, 48, 'dummy'),
(149079, 5955, 48, 'dummy'),
(149080, 5956, 48, 'dummy'),
(149081, 5957, 48, 'dummy'),
(149082, 5958, 48, 'dummy'),
(149083, 5959, 48, 'dummy'),
(149084, 5960, 48, 'dummy'),
(149085, 5961, 48, 'dummy'),
(149086, 5962, 48, 'dummy'),
(149087, 5963, 48, 'dummy'),
(149088, 5964, 48, 'dummy'),
(149089, 5965, 48, 'dummy'),
(149090, 5966, 48, 'dummy'),
(149091, 5967, 48, 'dummy'),
(149092, 5968, 48, 'dummy'),
(149093, 5969, 48, 'dummy'),
(149094, 5970, 48, 'dummy'),
(149095, 5971, 48, 'dummy'),
(149096, 5972, 48, 'dummy'),
(149097, 5973, 48, 'dummy'),
(149098, 5974, 48, 'dummy'),
(149099, 5975, 48, 'dummy'),
(149100, 5976, 48, 'dummy'),
(149101, 5977, 48, 'dummy'),
(149102, 5978, 48, 'dummy'),
(149103, 5979, 48, 'dummy'),
(149104, 5980, 48, 'dummy'),
(149105, 5981, 48, 'dummy'),
(149106, 5982, 48, 'dummy'),
(149107, 5983, 48, 'dummy'),
(149108, 5984, 48, 'dummy'),
(149109, 5985, 48, 'dummy'),
(149110, 5986, 48, 'dummy'),
(149111, 5987, 48, 'dummy'),
(149112, 5988, 48, 'dummy'),
(149113, 5989, 48, 'dummy'),
(149114, 5990, 48, 'dummy'),
(149115, 5991, 48, 'dummy'),
(149116, 5992, 48, 'dummy'),
(149117, 5993, 48, 'dummy'),
(149118, 5994, 48, 'dummy'),
(149119, 5995, 48, 'dummy'),
(149120, 5996, 48, 'dummy'),
(149121, 5997, 48, 'dummy'),
(149122, 5998, 48, 'dummy'),
(149123, 5999, 48, 'dummy'),
(149124, 6000, 48, 'dummy'),
(149125, 6001, 48, 'dummy'),
(149126, 6002, 48, 'dummy'),
(149127, 6003, 48, 'dummy'),
(149128, 6004, 48, 'dummy'),
(149129, 6005, 48, 'dummy'),
(149130, 6006, 48, 'dummy'),
(149131, 6007, 48, 'dummy'),
(149132, 6008, 48, 'dummy'),
(149133, 6009, 48, 'dummy'),
(149134, 6010, 48, 'dummy'),
(149135, 6011, 48, 'dummy'),
(149136, 6012, 48, 'dummy'),
(149137, 6013, 48, 'dummy'),
(149138, 6014, 48, 'dummy'),
(149139, 6015, 48, 'dummy'),
(149140, 6016, 48, 'dummy'),
(149141, 6017, 48, 'dummy'),
(149142, 6018, 48, 'dummy'),
(149143, 6019, 48, 'dummy'),
(149144, 6020, 48, 'dummy'),
(149145, 6021, 48, 'dummy'),
(149146, 6022, 48, 'dummy'),
(149147, 6023, 48, 'dummy'),
(149148, 6024, 48, 'dummy'),
(149149, 6025, 48, 'dummy'),
(149150, 6026, 48, 'dummy'),
(149151, 6027, 48, 'dummy'),
(149152, 6028, 48, 'dummy'),
(149153, 6029, 48, 'dummy'),
(149154, 6030, 48, 'dummy'),
(149155, 6031, 48, 'dummy'),
(149156, 6032, 48, 'dummy'),
(149157, 6033, 48, 'dummy'),
(149158, 6034, 48, 'dummy'),
(149159, 6035, 48, 'dummy'),
(149160, 6036, 48, 'dummy'),
(149161, 6037, 48, 'dummy'),
(149162, 6038, 48, 'dummy'),
(149163, 6039, 48, 'dummy'),
(149164, 6040, 48, 'dummy'),
(149165, 6041, 48, 'dummy'),
(149166, 6042, 48, 'dummy'),
(149167, 6043, 48, 'dummy'),
(149168, 6044, 48, 'dummy'),
(149169, 6045, 48, 'dummy'),
(149170, 6046, 48, 'dummy'),
(149171, 6047, 48, 'dummy'),
(149172, 6048, 48, 'dummy'),
(149173, 6049, 48, 'dummy'),
(149174, 6050, 48, 'dummy'),
(149175, 6051, 48, 'dummy'),
(149176, 6052, 48, 'dummy'),
(149177, 6053, 48, 'dummy'),
(149178, 6054, 48, 'dummy'),
(149179, 6055, 48, 'dummy'),
(149180, 6056, 48, 'dummy'),
(149181, 6057, 48, 'dummy'),
(149182, 6058, 48, 'dummy'),
(149183, 6059, 48, 'dummy'),
(149184, 6060, 48, 'dummy'),
(149185, 6061, 48, 'dummy'),
(149186, 6062, 48, 'dummy'),
(149187, 6063, 48, 'dummy'),
(149188, 6064, 48, 'dummy'),
(149189, 6065, 48, 'dummy'),
(149190, 6066, 48, 'dummy'),
(149191, 6067, 48, 'dummy'),
(149192, 6068, 48, 'dummy'),
(149193, 6069, 48, 'dummy'),
(149194, 6070, 48, 'dummy'),
(149195, 6071, 48, 'dummy'),
(149196, 6072, 48, 'dummy'),
(149197, 6073, 48, 'dummy'),
(149198, 6074, 48, 'dummy'),
(149199, 6075, 48, 'dummy'),
(149200, 6076, 48, 'dummy'),
(149201, 6077, 48, 'dummy'),
(149202, 6078, 48, 'dummy'),
(149203, 6079, 48, 'dummy'),
(149204, 6080, 48, 'dummy'),
(149205, 6081, 48, 'dummy'),
(149206, 6082, 48, 'dummy'),
(149207, 6083, 48, 'dummy'),
(149208, 6084, 48, 'dummy'),
(149209, 6085, 48, 'dummy'),
(149210, 6086, 48, 'dummy'),
(149211, 6087, 48, 'dummy'),
(149212, 6088, 48, 'dummy'),
(149213, 6089, 48, 'dummy'),
(149214, 6090, 48, 'dummy'),
(149215, 6091, 48, 'dummy'),
(149216, 6092, 48, 'dummy'),
(149217, 6093, 48, 'dummy'),
(149218, 6094, 48, 'dummy'),
(149219, 6095, 48, 'dummy'),
(149220, 6096, 48, 'dummy'),
(149221, 6097, 48, 'dummy'),
(149222, 6098, 48, 'dummy'),
(149223, 6099, 48, 'dummy'),
(149224, 6100, 48, 'dummy'),
(149225, 6101, 48, 'dummy'),
(149226, 6102, 48, 'dummy'),
(149227, 6103, 48, 'dummy'),
(149228, 6104, 48, 'dummy'),
(149229, 6105, 48, 'dummy'),
(149230, 6106, 48, 'dummy'),
(149231, 6107, 48, 'dummy'),
(149232, 6108, 48, 'dummy'),
(149233, 6109, 48, 'dummy'),
(149234, 6110, 48, 'dummy'),
(149235, 6111, 48, 'dummy'),
(149236, 6112, 48, 'dummy'),
(149237, 6113, 48, 'dummy'),
(149238, 6114, 48, 'dummy'),
(149239, 6115, 48, 'dummy'),
(149240, 6116, 48, 'dummy'),
(149241, 6117, 48, 'dummy'),
(149242, 6118, 48, 'dummy'),
(149243, 6119, 48, 'dummy'),
(149244, 6120, 48, 'dummy'),
(149245, 6121, 48, 'dummy'),
(149246, 6122, 48, 'dummy'),
(149247, 6123, 48, 'dummy'),
(149248, 6124, 48, 'dummy'),
(149249, 6125, 48, 'dummy'),
(149250, 6126, 48, 'dummy'),
(149251, 6127, 48, 'dummy'),
(149252, 6128, 48, 'dummy'),
(149253, 6129, 48, 'dummy'),
(149254, 6130, 48, 'dummy'),
(149255, 6131, 48, 'dummy'),
(149256, 6132, 48, 'dummy'),
(149257, 6133, 48, 'dummy'),
(149258, 6134, 48, 'dummy'),
(149259, 6135, 48, 'dummy'),
(149260, 6136, 48, 'dummy'),
(149261, 6137, 48, 'dummy'),
(149262, 6138, 48, 'dummy'),
(149263, 6139, 48, 'dummy'),
(149264, 6140, 48, 'dummy'),
(149265, 6141, 48, 'dummy'),
(149266, 6142, 48, 'dummy'),
(149267, 6143, 48, 'dummy'),
(149268, 6144, 48, 'dummy'),
(149269, 6145, 48, 'dummy'),
(149270, 6146, 48, 'dummy'),
(149271, 6147, 48, 'dummy'),
(149272, 6148, 48, 'dummy'),
(149273, 6149, 48, 'dummy'),
(149274, 6150, 48, 'dummy'),
(149275, 6151, 48, 'dummy'),
(149276, 6152, 48, 'dummy'),
(149277, 6153, 48, 'dummy'),
(149278, 6154, 48, 'dummy'),
(149279, 6155, 48, 'dummy'),
(149280, 6156, 48, 'dummy'),
(149281, 6157, 48, 'dummy'),
(149282, 6158, 48, 'dummy'),
(149283, 6159, 48, 'dummy'),
(149284, 6160, 48, 'dummy'),
(149285, 6161, 48, 'dummy'),
(149286, 6162, 48, 'dummy'),
(149287, 6163, 48, 'dummy'),
(149288, 6164, 48, 'dummy'),
(149289, 6165, 48, 'dummy'),
(149290, 6166, 48, 'dummy'),
(149291, 6167, 48, 'dummy'),
(149292, 6168, 48, 'dummy'),
(149293, 6169, 48, 'dummy'),
(149294, 6170, 48, 'dummy'),
(149295, 6171, 48, 'dummy'),
(149296, 6172, 48, 'dummy'),
(149297, 6173, 48, 'dummy'),
(149298, 6174, 48, 'dummy'),
(149299, 6175, 48, 'dummy'),
(149300, 6176, 48, 'dummy'),
(149301, 6177, 48, 'dummy'),
(149302, 6178, 48, 'dummy'),
(149303, 6179, 48, 'dummy'),
(149304, 6180, 48, 'dummy'),
(149305, 6181, 48, 'dummy'),
(149306, 6182, 48, 'dummy'),
(149307, 6183, 48, 'dummy'),
(149308, 6184, 48, 'dummy'),
(149309, 6185, 48, 'dummy'),
(149310, 6186, 48, 'dummy'),
(149311, 6187, 48, 'dummy'),
(149312, 6188, 48, 'dummy'),
(149313, 6189, 48, 'dummy'),
(149314, 6190, 48, 'dummy'),
(149315, 6191, 48, 'dummy'),
(149316, 6192, 48, 'dummy'),
(149317, 6193, 48, 'dummy'),
(149318, 6194, 48, 'dummy'),
(149319, 6195, 48, 'dummy'),
(149320, 6196, 48, 'dummy'),
(149321, 6197, 48, 'dummy'),
(149322, 6198, 48, 'dummy'),
(149323, 6199, 48, 'dummy'),
(149324, 6200, 48, 'dummy'),
(149325, 6201, 48, 'dummy'),
(149326, 6202, 48, 'dummy'),
(149327, 6203, 48, 'dummy'),
(149328, 6204, 48, 'dummy'),
(149329, 6205, 48, 'dummy'),
(149330, 6206, 48, 'dummy'),
(149331, 6207, 48, 'dummy'),
(149332, 6208, 48, 'dummy'),
(149333, 6209, 48, 'dummy'),
(149334, 6210, 48, 'dummy'),
(149335, 6211, 48, 'dummy'),
(149336, 6212, 48, 'dummy'),
(149337, 6213, 48, 'dummy'),
(149338, 6214, 48, 'dummy'),
(149339, 6215, 48, 'dummy'),
(149340, 6216, 48, 'dummy'),
(149341, 6217, 48, 'dummy'),
(149342, 6218, 48, 'dummy'),
(149343, 6219, 48, 'dummy'),
(149344, 6220, 48, 'dummy'),
(149345, 6221, 48, 'dummy'),
(149346, 6222, 48, 'dummy'),
(149347, 6223, 48, 'dummy'),
(149348, 6224, 48, 'dummy'),
(149349, 6225, 48, 'dummy'),
(149350, 6226, 48, 'dummy'),
(149351, 6227, 48, 'dummy'),
(149352, 6228, 48, 'dummy'),
(149353, 6229, 48, 'dummy'),
(149354, 6230, 48, 'dummy'),
(149355, 6231, 48, 'dummy'),
(149356, 6232, 48, 'dummy'),
(149357, 6233, 48, 'dummy'),
(149358, 6234, 48, 'dummy'),
(149359, 6235, 48, 'dummy'),
(149360, 6236, 48, 'dummy'),
(149361, 6237, 48, 'dummy'),
(149362, 6238, 48, 'dummy'),
(149363, 6239, 48, 'dummy'),
(149364, 6240, 48, 'dummy'),
(149365, 6241, 48, 'dummy'),
(149366, 6242, 48, 'dummy'),
(149367, 6243, 48, 'dummy'),
(149368, 6244, 48, 'dummy'),
(149369, 6245, 48, 'dummy'),
(149370, 6246, 48, 'dummy'),
(149371, 6247, 48, 'dummy'),
(149372, 6248, 48, 'dummy'),
(149373, 6249, 48, 'dummy'),
(149374, 6250, 48, 'dummy'),
(149375, 6251, 48, 'dummy'),
(149376, 6252, 48, 'dummy'),
(149377, 6253, 48, 'dummy'),
(149378, 6254, 48, 'dummy'),
(149379, 6255, 48, 'dummy'),
(149380, 6256, 48, 'dummy'),
(149381, 6257, 48, 'dummy'),
(149382, 6258, 48, 'dummy'),
(149383, 6259, 48, 'dummy'),
(149384, 6260, 48, 'dummy'),
(149385, 6261, 48, 'dummy'),
(149386, 6262, 48, 'dummy'),
(149387, 6263, 48, 'dummy'),
(149388, 6264, 48, 'dummy'),
(149389, 6265, 48, 'dummy'),
(149390, 6266, 48, 'dummy'),
(149391, 6267, 48, 'dummy'),
(149392, 6268, 48, 'dummy'),
(149393, 6269, 48, 'dummy'),
(149394, 6270, 48, 'dummy'),
(149395, 6271, 48, 'dummy'),
(149396, 6272, 48, 'dummy'),
(149397, 6273, 48, 'dummy'),
(149398, 6274, 48, 'dummy'),
(149399, 6275, 48, 'dummy'),
(149400, 6276, 48, 'dummy'),
(149401, 6277, 48, 'dummy'),
(149402, 6278, 48, 'dummy'),
(149403, 6279, 48, 'dummy'),
(149404, 6280, 48, 'dummy'),
(149405, 6281, 48, 'dummy'),
(149406, 6282, 48, 'dummy'),
(149407, 6283, 48, 'dummy'),
(149408, 6284, 48, 'dummy'),
(149409, 6285, 48, 'dummy'),
(149410, 6286, 48, 'dummy'),
(149411, 6287, 48, 'dummy'),
(149412, 6288, 48, 'dummy'),
(149413, 6289, 48, 'dummy'),
(149414, 6290, 48, 'dummy'),
(149415, 6291, 48, 'dummy'),
(149416, 6292, 48, 'dummy'),
(149417, 6293, 48, 'dummy'),
(149418, 6294, 48, 'dummy'),
(149419, 6295, 48, 'dummy'),
(149420, 6296, 48, 'dummy'),
(149421, 6297, 48, 'dummy'),
(149422, 6298, 48, 'dummy'),
(149423, 6299, 48, 'dummy'),
(149424, 6300, 48, 'dummy'),
(149425, 6301, 48, 'dummy'),
(149426, 6302, 48, 'dummy'),
(149427, 6303, 48, 'dummy'),
(149428, 6304, 48, 'dummy'),
(149429, 6305, 48, 'dummy'),
(149430, 6306, 48, 'dummy'),
(149431, 6307, 48, 'dummy'),
(149432, 6308, 48, 'dummy'),
(149433, 6309, 48, 'dummy'),
(149434, 6310, 48, 'dummy'),
(149435, 6311, 48, 'dummy'),
(149436, 6312, 48, 'dummy'),
(149437, 6313, 48, 'dummy'),
(149438, 6314, 48, 'dummy'),
(149439, 6315, 48, 'dummy'),
(149440, 6316, 48, 'dummy'),
(149441, 6317, 48, 'dummy'),
(149442, 6318, 48, 'dummy'),
(149443, 6319, 48, 'dummy'),
(149444, 6320, 48, 'dummy'),
(149445, 6321, 48, 'dummy'),
(149446, 6322, 48, 'dummy'),
(149447, 6323, 48, 'dummy'),
(149448, 6324, 48, 'dummy'),
(149449, 6325, 48, 'dummy'),
(149450, 6326, 48, 'dummy'),
(149451, 6327, 48, 'dummy'),
(149452, 6328, 48, 'dummy'),
(149453, 6329, 48, 'dummy'),
(149454, 6330, 48, 'dummy'),
(149455, 6331, 48, 'dummy'),
(149456, 6332, 48, 'dummy'),
(149457, 6333, 48, 'dummy'),
(149458, 6334, 48, 'dummy'),
(149459, 6335, 48, 'dummy'),
(149460, 6336, 48, 'dummy'),
(149461, 6337, 48, 'dummy'),
(149462, 6338, 48, 'dummy'),
(149463, 6339, 48, 'dummy'),
(149464, 6340, 48, 'dummy'),
(149465, 6341, 48, 'dummy'),
(149466, 6342, 48, 'dummy'),
(149467, 6343, 48, 'dummy'),
(149468, 6344, 48, 'dummy'),
(149469, 6345, 48, 'dummy'),
(149470, 6346, 48, 'dummy'),
(149471, 6347, 48, 'dummy'),
(149472, 6348, 48, 'dummy'),
(149473, 6349, 48, 'dummy'),
(149474, 6350, 48, 'dummy'),
(149475, 6351, 48, 'dummy'),
(149476, 6352, 48, 'dummy'),
(149477, 6353, 48, 'dummy'),
(149478, 6354, 48, 'dummy'),
(149479, 6355, 48, 'dummy'),
(149480, 6356, 48, 'dummy'),
(149481, 6357, 48, 'dummy'),
(149482, 6358, 48, 'dummy'),
(149483, 6359, 48, 'dummy'),
(149484, 6360, 48, 'dummy'),
(149485, 6361, 48, 'dummy'),
(149486, 6362, 48, 'dummy'),
(149487, 6363, 48, 'dummy'),
(149488, 6364, 48, 'dummy'),
(149489, 6365, 48, 'dummy'),
(149490, 6366, 48, 'dummy'),
(149491, 6367, 48, 'dummy'),
(149492, 6368, 48, 'dummy'),
(149493, 6369, 48, 'dummy'),
(149494, 6370, 48, 'dummy'),
(149495, 6371, 48, 'dummy'),
(149496, 6372, 48, 'dummy'),
(149497, 6373, 48, 'dummy'),
(149498, 6374, 48, 'dummy'),
(149499, 6375, 48, 'dummy'),
(149500, 6376, 48, 'dummy'),
(149501, 6377, 48, 'dummy'),
(149502, 6378, 48, 'dummy'),
(149503, 6379, 48, 'dummy'),
(149504, 6380, 48, 'dummy'),
(149505, 6381, 48, 'dummy'),
(149506, 6382, 48, 'dummy'),
(149507, 6383, 48, 'dummy'),
(149508, 6384, 48, 'dummy'),
(149509, 6385, 48, 'dummy'),
(149510, 6386, 48, 'dummy'),
(149511, 6387, 48, 'dummy'),
(149512, 6388, 48, 'dummy'),
(149513, 6389, 48, 'dummy'),
(149514, 6390, 48, 'dummy'),
(149515, 6391, 48, 'dummy'),
(149516, 6392, 48, 'dummy'),
(149517, 6393, 48, 'dummy'),
(149518, 6394, 48, 'dummy'),
(149519, 6395, 48, 'dummy'),
(149520, 6396, 48, 'dummy'),
(149521, 6397, 48, 'dummy'),
(149522, 6398, 48, 'dummy'),
(149523, 6399, 48, 'dummy'),
(149524, 6400, 48, 'dummy'),
(149525, 6401, 48, 'dummy'),
(149526, 6402, 48, 'dummy'),
(149527, 6403, 48, 'dummy'),
(149528, 6404, 48, 'dummy'),
(149529, 6405, 48, 'dummy'),
(149530, 6406, 48, 'dummy'),
(149531, 6407, 48, 'dummy'),
(149532, 6408, 48, 'dummy'),
(149533, 6409, 48, 'dummy'),
(149534, 6410, 48, 'dummy'),
(149535, 6411, 48, 'dummy'),
(149536, 6412, 48, 'dummy'),
(149537, 6413, 48, 'dummy'),
(149538, 6414, 48, 'dummy'),
(149539, 6415, 48, 'dummy'),
(149540, 6416, 48, 'dummy'),
(149541, 6417, 48, 'dummy'),
(149542, 6418, 48, 'dummy'),
(149543, 6419, 48, 'dummy'),
(149544, 6420, 48, 'dummy'),
(149545, 6421, 48, 'dummy'),
(149546, 6422, 48, 'dummy'),
(149547, 6423, 48, 'dummy'),
(149548, 6424, 48, 'dummy'),
(149549, 6425, 48, 'dummy'),
(149550, 6426, 48, 'dummy'),
(149551, 6427, 48, 'dummy'),
(149552, 6428, 48, 'dummy'),
(149553, 6429, 48, 'dummy'),
(149554, 6430, 48, 'dummy'),
(149555, 6431, 48, 'dummy'),
(149556, 6432, 48, 'dummy'),
(149557, 6433, 48, 'dummy'),
(149558, 6434, 48, 'dummy'),
(149559, 6435, 48, 'dummy'),
(149560, 6436, 48, 'dummy'),
(149561, 6437, 48, 'dummy'),
(149562, 6438, 48, 'dummy'),
(149563, 6439, 48, 'dummy'),
(149564, 6440, 48, 'dummy'),
(149565, 6441, 48, 'dummy'),
(149566, 6442, 48, 'dummy'),
(149567, 6443, 48, 'dummy'),
(149568, 6444, 48, 'dummy'),
(149569, 6445, 48, 'dummy'),
(149570, 6446, 48, 'dummy'),
(149571, 6447, 48, 'dummy'),
(149572, 6448, 48, 'dummy'),
(149573, 6449, 48, 'dummy'),
(149574, 6450, 48, 'dummy'),
(149575, 6451, 48, 'dummy'),
(149576, 6452, 48, 'dummy'),
(149577, 6453, 48, 'dummy'),
(149578, 6454, 48, 'dummy'),
(149579, 6455, 48, 'dummy'),
(149580, 6456, 48, 'dummy'),
(149581, 6457, 48, 'dummy'),
(149582, 6458, 48, 'dummy'),
(149583, 6459, 48, 'dummy'),
(149584, 6460, 48, 'dummy'),
(149585, 6461, 48, 'dummy'),
(149586, 6462, 48, 'dummy'),
(149587, 6463, 48, 'dummy'),
(149588, 6464, 48, 'dummy'),
(149589, 6465, 48, 'dummy'),
(149590, 6466, 48, 'dummy'),
(149591, 6467, 48, 'dummy'),
(149592, 6468, 48, 'dummy'),
(149593, 6469, 48, 'dummy'),
(149594, 6470, 48, 'dummy'),
(149595, 6471, 48, 'dummy'),
(149596, 6472, 48, 'dummy'),
(149597, 6473, 48, 'dummy'),
(149598, 6474, 48, 'dummy'),
(149599, 6475, 48, 'dummy'),
(149600, 6476, 48, 'dummy'),
(149601, 6477, 48, 'dummy'),
(149602, 6478, 48, 'dummy'),
(149603, 6479, 48, 'dummy'),
(149604, 6480, 48, 'dummy'),
(149605, 6481, 48, 'dummy'),
(149606, 6482, 48, 'dummy'),
(149607, 6483, 48, 'dummy'),
(149608, 6484, 48, 'dummy'),
(149609, 6485, 48, 'dummy'),
(149610, 6486, 48, 'dummy'),
(149611, 6487, 48, 'dummy'),
(149612, 6488, 48, 'dummy'),
(149613, 6489, 48, 'dummy'),
(149614, 6490, 48, 'dummy'),
(149615, 6491, 48, 'dummy'),
(149616, 6492, 48, 'dummy'),
(149617, 6493, 48, 'dummy'),
(149618, 6494, 48, 'dummy'),
(149619, 6495, 48, 'dummy'),
(149620, 6496, 48, 'dummy'),
(149621, 6497, 48, 'dummy'),
(149622, 6498, 48, 'dummy'),
(149623, 6499, 48, 'dummy'),
(149624, 6500, 48, 'dummy'),
(149625, 6501, 48, 'dummy'),
(149626, 6502, 48, 'dummy'),
(149627, 6503, 48, 'dummy'),
(149628, 6504, 48, 'dummy'),
(149629, 6505, 48, 'dummy'),
(149630, 6506, 48, 'dummy'),
(149631, 6507, 48, 'dummy'),
(149632, 6508, 48, 'dummy'),
(149633, 6509, 48, 'dummy'),
(149634, 6510, 48, 'dummy'),
(149635, 6511, 48, 'dummy'),
(149636, 6512, 48, 'dummy'),
(149637, 6513, 48, 'dummy'),
(149638, 6514, 48, 'dummy'),
(149639, 6515, 48, 'dummy'),
(149640, 6516, 48, 'dummy'),
(149641, 6517, 48, 'dummy'),
(149642, 6518, 48, 'dummy'),
(149643, 6519, 48, 'dummy'),
(149644, 6520, 48, 'dummy'),
(149645, 6521, 48, 'dummy'),
(149646, 6522, 48, 'dummy'),
(149647, 6523, 48, 'dummy'),
(149648, 6524, 48, 'dummy'),
(149649, 6525, 48, 'dummy'),
(149650, 6526, 48, 'dummy'),
(149651, 6527, 48, 'dummy'),
(149652, 6528, 48, 'dummy'),
(149653, 6529, 48, 'dummy'),
(149654, 6530, 48, 'dummy'),
(149655, 6531, 48, 'dummy'),
(149656, 6532, 48, 'dummy'),
(149657, 6533, 48, 'dummy'),
(149658, 6534, 48, 'dummy'),
(149659, 6535, 48, 'dummy'),
(149660, 6536, 48, 'dummy'),
(149661, 6537, 48, 'dummy'),
(149662, 6538, 48, 'dummy'),
(149663, 6539, 48, 'dummy'),
(149664, 6540, 48, 'dummy'),
(149665, 6541, 48, 'dummy'),
(149666, 6542, 48, 'dummy'),
(149667, 6543, 48, 'dummy'),
(149668, 6544, 48, 'dummy'),
(149669, 6545, 48, 'dummy'),
(149670, 6546, 48, 'dummy'),
(149671, 6547, 48, 'dummy'),
(149672, 6548, 48, 'dummy'),
(149673, 6549, 48, 'dummy'),
(149674, 6550, 48, 'dummy'),
(149675, 6551, 48, 'dummy'),
(149676, 6552, 48, 'dummy'),
(149677, 6553, 48, 'dummy'),
(149678, 6554, 48, 'dummy'),
(149679, 6555, 48, 'dummy'),
(149680, 6556, 48, 'dummy'),
(149681, 6557, 48, 'dummy'),
(149682, 6558, 48, 'dummy'),
(149683, 6559, 48, 'dummy'),
(149684, 6560, 48, 'dummy'),
(149685, 6561, 48, 'dummy'),
(149686, 6562, 48, 'dummy'),
(149687, 6563, 48, 'dummy'),
(149688, 6564, 48, 'dummy'),
(149689, 6565, 48, 'dummy'),
(149690, 6566, 48, 'dummy'),
(149691, 6567, 48, 'dummy'),
(149692, 6568, 48, 'dummy'),
(149693, 6569, 48, 'dummy'),
(149694, 6570, 48, 'dummy'),
(149695, 6571, 48, 'dummy'),
(149696, 6572, 48, 'dummy'),
(149697, 6573, 48, 'dummy'),
(149698, 6574, 48, 'dummy'),
(149699, 6575, 48, 'dummy'),
(149700, 6576, 48, 'dummy'),
(149701, 6577, 48, 'dummy'),
(149702, 6578, 48, 'dummy'),
(149703, 6579, 48, 'dummy'),
(149704, 6580, 48, 'dummy'),
(149705, 6581, 48, 'dummy'),
(149706, 6582, 48, 'dummy'),
(149707, 6583, 48, 'dummy'),
(149708, 6584, 48, 'dummy'),
(149709, 6585, 48, 'dummy'),
(149710, 6586, 48, 'dummy'),
(149711, 6587, 48, 'dummy'),
(149712, 6588, 48, 'dummy'),
(149713, 6589, 48, 'dummy'),
(149714, 6590, 48, 'dummy'),
(149715, 6591, 48, 'dummy'),
(149716, 6592, 48, 'dummy'),
(149717, 6593, 48, 'dummy'),
(149718, 6594, 48, 'dummy'),
(149719, 6595, 48, 'dummy'),
(149720, 6596, 48, 'dummy'),
(149721, 6597, 48, 'dummy'),
(149722, 6598, 48, 'dummy'),
(149723, 6599, 48, 'dummy'),
(149724, 6600, 48, 'dummy'),
(149725, 6601, 48, 'dummy'),
(149726, 6602, 48, 'dummy'),
(149727, 6603, 48, 'dummy'),
(149728, 6604, 48, 'dummy'),
(149729, 6605, 48, 'dummy'),
(149730, 6606, 48, 'dummy'),
(149731, 6607, 48, 'dummy'),
(149732, 6608, 48, 'dummy'),
(149733, 6609, 48, 'dummy'),
(149734, 6610, 48, 'dummy'),
(149735, 6611, 48, 'dummy'),
(149736, 6612, 48, 'dummy'),
(149737, 6613, 48, 'dummy'),
(149738, 6614, 48, 'dummy'),
(149739, 6615, 48, 'dummy'),
(149740, 6616, 48, 'dummy'),
(149741, 6617, 48, 'dummy'),
(149742, 6618, 48, 'dummy'),
(149743, 6619, 48, 'dummy'),
(149744, 6620, 48, 'dummy'),
(149745, 6621, 48, 'dummy'),
(149746, 6622, 48, 'dummy'),
(149747, 6623, 48, 'dummy'),
(149748, 6624, 48, 'dummy'),
(149749, 6625, 48, 'dummy'),
(149750, 6626, 48, 'dummy'),
(149751, 6627, 48, 'dummy'),
(149752, 6628, 48, 'dummy'),
(149753, 6629, 48, 'dummy'),
(149754, 6630, 48, 'dummy'),
(149755, 6631, 48, 'dummy'),
(149756, 6632, 48, 'dummy'),
(149757, 6633, 48, 'dummy'),
(149758, 6634, 48, 'dummy'),
(149759, 6635, 48, 'dummy'),
(149760, 6636, 48, 'dummy'),
(149761, 6637, 48, 'dummy'),
(149762, 6638, 48, 'dummy'),
(149763, 6639, 48, 'dummy'),
(149764, 6640, 48, 'dummy'),
(149765, 6641, 48, 'dummy'),
(149766, 6642, 48, 'dummy'),
(149767, 6643, 48, 'dummy'),
(149768, 6644, 48, 'dummy'),
(149769, 6645, 48, 'dummy'),
(149770, 6646, 48, 'dummy'),
(149771, 6647, 48, 'dummy'),
(149772, 6648, 48, 'dummy'),
(149773, 6649, 48, 'dummy'),
(149774, 6650, 48, 'dummy'),
(149775, 6651, 48, 'dummy'),
(149776, 6652, 48, 'dummy'),
(149777, 6653, 48, 'dummy'),
(149778, 6654, 48, 'dummy'),
(149779, 6655, 48, 'dummy'),
(149780, 6656, 48, 'dummy'),
(149781, 6657, 48, 'dummy'),
(149782, 6658, 48, 'dummy'),
(149783, 6659, 48, 'dummy'),
(149784, 6660, 48, 'dummy'),
(149785, 6661, 48, 'dummy'),
(149786, 6662, 48, 'dummy'),
(149787, 6663, 48, 'dummy'),
(149788, 6664, 48, 'dummy'),
(149789, 6665, 48, 'dummy'),
(149790, 6666, 48, 'dummy'),
(149791, 6667, 48, 'dummy'),
(149792, 6668, 48, 'dummy'),
(149793, 6669, 48, 'dummy'),
(149794, 6670, 48, 'dummy'),
(149795, 6671, 48, 'dummy'),
(149796, 6672, 48, 'dummy'),
(149797, 6673, 48, 'dummy'),
(149798, 6674, 48, 'dummy'),
(149799, 6675, 48, 'dummy'),
(149800, 6676, 48, 'dummy'),
(149801, 6677, 48, 'dummy'),
(149802, 6678, 48, 'dummy'),
(149803, 6679, 48, 'dummy'),
(149804, 6680, 48, 'dummy'),
(149805, 6681, 48, 'dummy'),
(149806, 6682, 48, 'dummy'),
(149807, 6683, 48, 'dummy'),
(149808, 6684, 48, 'dummy'),
(149809, 6685, 48, 'dummy'),
(149810, 6686, 48, 'dummy'),
(149811, 6687, 48, 'dummy'),
(149812, 6688, 48, 'dummy'),
(149813, 6689, 48, 'dummy'),
(149814, 6690, 48, 'dummy'),
(149815, 6691, 48, 'dummy'),
(149816, 6692, 48, 'dummy'),
(149817, 6693, 48, 'dummy'),
(149818, 6694, 48, 'dummy'),
(149819, 6695, 48, 'dummy'),
(149820, 6696, 48, 'dummy'),
(149821, 6697, 48, 'dummy'),
(149822, 6698, 48, 'dummy'),
(149823, 6699, 48, 'dummy'),
(149824, 6700, 48, 'dummy'),
(149825, 6701, 48, 'dummy'),
(149826, 6702, 48, 'dummy'),
(149827, 6703, 48, 'dummy'),
(149828, 6704, 48, 'dummy'),
(149829, 6705, 48, 'dummy'),
(149830, 6706, 48, 'dummy'),
(149831, 6707, 48, 'dummy'),
(149832, 6708, 48, 'dummy'),
(149833, 6709, 48, 'dummy'),
(149834, 6710, 48, 'dummy'),
(149835, 6711, 48, 'dummy'),
(149836, 6712, 48, 'dummy'),
(149837, 6713, 48, 'dummy'),
(149838, 6714, 48, 'dummy'),
(149839, 6715, 48, 'dummy'),
(149840, 6716, 48, 'dummy'),
(149841, 6717, 48, 'dummy'),
(149842, 6718, 48, 'dummy'),
(149843, 6719, 48, 'dummy'),
(149844, 6720, 48, 'dummy'),
(149845, 6721, 48, 'dummy'),
(149846, 6722, 48, 'dummy'),
(149847, 6723, 48, 'dummy'),
(149848, 6724, 48, 'dummy'),
(149849, 6725, 48, 'dummy'),
(149850, 6726, 48, 'dummy'),
(149851, 6727, 48, 'dummy'),
(149852, 6728, 48, 'dummy'),
(149853, 6729, 48, 'dummy'),
(149854, 6730, 48, 'dummy'),
(149855, 6731, 48, 'dummy'),
(149856, 6732, 48, 'dummy'),
(149857, 6733, 48, 'dummy'),
(149858, 6734, 48, 'dummy'),
(149859, 6735, 48, 'dummy'),
(149860, 6736, 48, 'dummy'),
(149861, 6737, 48, 'dummy'),
(149862, 6738, 48, 'dummy'),
(149863, 6739, 48, 'dummy'),
(149864, 6740, 48, 'dummy'),
(149865, 6741, 48, 'dummy'),
(149866, 6742, 48, 'dummy'),
(149867, 6743, 48, 'dummy'),
(149868, 6744, 48, 'dummy'),
(149869, 6745, 48, 'dummy'),
(149870, 6746, 48, 'dummy'),
(149871, 6747, 48, 'dummy'),
(149872, 6748, 48, 'dummy'),
(149873, 6749, 48, 'dummy'),
(149874, 6750, 48, 'dummy'),
(149875, 6751, 48, 'dummy'),
(149876, 6752, 48, 'dummy'),
(149877, 6753, 48, 'dummy'),
(149878, 6754, 48, 'dummy'),
(149879, 6755, 48, 'dummy'),
(149880, 6756, 48, 'dummy'),
(149881, 6757, 48, 'dummy'),
(149882, 6758, 48, 'dummy'),
(149883, 6759, 48, 'dummy'),
(149884, 6760, 48, 'dummy'),
(149885, 6761, 48, 'dummy'),
(149886, 6762, 48, 'dummy'),
(149887, 6763, 48, 'dummy'),
(149888, 6764, 48, 'dummy'),
(149889, 6765, 48, 'dummy'),
(149890, 6766, 48, 'dummy'),
(149891, 6767, 48, 'dummy'),
(149892, 6768, 48, 'dummy'),
(149893, 6769, 48, 'dummy'),
(149894, 6770, 48, 'dummy'),
(149895, 6771, 48, 'dummy'),
(149896, 6772, 48, 'dummy'),
(149897, 6773, 48, 'dummy'),
(149898, 6774, 48, 'dummy'),
(149899, 6775, 48, 'dummy'),
(149900, 6776, 48, 'dummy'),
(149901, 6777, 48, 'dummy'),
(149902, 6778, 48, 'dummy'),
(149903, 6779, 48, 'dummy'),
(149904, 6780, 48, 'dummy'),
(149905, 6781, 48, 'dummy'),
(149906, 6782, 48, 'dummy'),
(149907, 6783, 48, 'dummy'),
(149908, 6784, 48, 'dummy'),
(149909, 6785, 48, 'dummy'),
(149910, 6786, 48, 'dummy'),
(149911, 6787, 48, 'dummy'),
(149912, 6788, 48, 'dummy'),
(149913, 6789, 48, 'dummy'),
(149914, 6790, 48, 'dummy'),
(149915, 6791, 48, 'dummy'),
(149916, 6792, 48, 'dummy'),
(149917, 6793, 48, 'dummy'),
(149918, 6794, 48, 'dummy'),
(149919, 6795, 48, 'dummy'),
(149920, 6796, 48, 'dummy'),
(149921, 6797, 48, 'dummy'),
(149922, 6798, 48, 'dummy'),
(149923, 6799, 48, 'dummy'),
(149924, 6800, 48, 'dummy'),
(149925, 6801, 48, 'dummy'),
(149926, 6802, 48, 'dummy'),
(149927, 6803, 48, 'dummy'),
(149928, 6804, 48, 'dummy'),
(149929, 6805, 48, 'dummy'),
(149930, 6806, 48, 'dummy'),
(149931, 6807, 48, 'dummy'),
(149932, 6808, 48, 'dummy'),
(149933, 6809, 48, 'dummy'),
(149934, 6810, 48, 'dummy'),
(149935, 6811, 48, 'dummy'),
(149936, 6812, 48, 'dummy'),
(149937, 6813, 48, 'dummy'),
(149938, 6814, 48, 'dummy'),
(149939, 6815, 48, 'dummy'),
(149940, 6816, 48, 'dummy'),
(149941, 6817, 48, 'dummy'),
(149942, 6818, 48, 'dummy'),
(149943, 6819, 48, 'dummy'),
(149944, 6820, 48, 'dummy'),
(149945, 6821, 48, 'dummy'),
(149946, 6822, 48, 'dummy'),
(149947, 6823, 48, 'dummy'),
(149948, 6824, 48, 'dummy'),
(149949, 6825, 48, 'dummy'),
(149950, 6826, 48, 'dummy'),
(149951, 6827, 48, 'dummy'),
(149952, 6828, 48, 'dummy'),
(149953, 6829, 48, 'dummy'),
(149954, 6830, 48, 'dummy'),
(149955, 6831, 48, 'dummy'),
(149956, 6832, 48, 'dummy'),
(149957, 6833, 48, 'dummy'),
(149958, 6834, 48, 'dummy'),
(149959, 6835, 48, 'dummy'),
(149960, 6836, 48, 'dummy'),
(149961, 6837, 48, 'dummy'),
(149962, 6838, 48, 'dummy'),
(149963, 6839, 48, 'dummy'),
(149964, 6840, 48, 'dummy'),
(149965, 6841, 48, 'dummy'),
(149966, 6842, 48, 'dummy'),
(149967, 6843, 48, 'dummy'),
(149968, 6844, 48, 'dummy'),
(149969, 6845, 48, 'dummy'),
(149970, 6846, 48, 'dummy'),
(149971, 6847, 48, 'dummy'),
(149972, 6848, 48, 'dummy'),
(149973, 6849, 48, 'dummy'),
(149974, 6850, 48, 'dummy'),
(149975, 6851, 48, 'dummy'),
(149976, 6852, 48, 'dummy'),
(149977, 6853, 48, 'dummy'),
(149978, 6854, 48, 'dummy'),
(149979, 6855, 48, 'dummy'),
(149980, 6856, 48, 'dummy'),
(149981, 6857, 48, 'dummy'),
(149982, 6858, 48, 'dummy'),
(149983, 6859, 48, 'dummy'),
(149984, 6860, 48, 'dummy'),
(149985, 6861, 48, 'dummy'),
(149986, 6862, 48, 'dummy'),
(149987, 6863, 48, 'dummy'),
(149988, 6864, 48, 'dummy'),
(149989, 6865, 48, 'dummy'),
(149990, 6866, 48, 'dummy'),
(149991, 6867, 48, 'dummy'),
(149992, 6868, 48, 'dummy'),
(149993, 6869, 48, 'dummy'),
(149994, 6870, 48, 'dummy'),
(149995, 6871, 48, 'dummy'),
(149996, 6872, 48, 'dummy'),
(149997, 6873, 48, 'dummy'),
(149998, 6874, 48, 'dummy'),
(149999, 6875, 48, 'dummy'),
(150000, 6876, 48, 'dummy'),
(150001, 6877, 48, 'dummy'),
(150002, 6878, 48, 'dummy'),
(150003, 6879, 48, 'dummy'),
(150004, 6880, 48, 'dummy'),
(150005, 6881, 48, 'dummy'),
(150006, 6882, 48, 'dummy'),
(150007, 6883, 48, 'dummy'),
(150008, 6884, 48, 'dummy'),
(150009, 6885, 48, 'dummy'),
(150010, 6886, 48, 'dummy'),
(150011, 6887, 48, 'dummy'),
(150012, 6888, 48, 'dummy'),
(150013, 6889, 48, 'dummy'),
(150014, 6890, 48, 'dummy'),
(150015, 6891, 48, 'dummy'),
(150016, 6892, 48, 'dummy'),
(150017, 6893, 48, 'dummy'),
(150018, 6894, 48, 'dummy'),
(150019, 6895, 48, 'dummy'),
(150020, 6896, 48, 'dummy'),
(150021, 6897, 48, 'dummy'),
(150022, 6898, 48, 'dummy'),
(150023, 6899, 48, 'dummy'),
(150024, 6900, 48, 'dummy'),
(150025, 6901, 48, 'dummy'),
(150026, 6902, 48, 'dummy'),
(150027, 6903, 48, 'dummy'),
(150028, 6904, 48, 'dummy'),
(150029, 6905, 48, 'dummy'),
(150030, 6906, 48, 'dummy'),
(150031, 6907, 48, 'dummy'),
(150032, 6908, 48, 'dummy'),
(150033, 6909, 48, 'dummy'),
(150034, 6910, 48, 'dummy'),
(150035, 6911, 48, 'dummy'),
(150036, 6912, 48, 'dummy'),
(150037, 6913, 48, 'dummy'),
(150038, 6914, 48, 'dummy'),
(150039, 6915, 48, 'dummy'),
(150040, 6916, 48, 'dummy'),
(150041, 6917, 48, 'dummy'),
(150042, 6918, 48, 'dummy'),
(150043, 6919, 48, 'dummy'),
(150044, 6920, 48, 'dummy'),
(150045, 6921, 48, 'dummy'),
(150046, 6922, 48, 'dummy'),
(150047, 6923, 48, 'dummy'),
(150048, 6924, 48, 'dummy'),
(150049, 6925, 48, 'dummy'),
(150050, 6926, 48, 'dummy'),
(150051, 6927, 48, 'dummy'),
(150052, 6928, 48, 'dummy'),
(150053, 6929, 48, 'dummy'),
(150054, 6930, 48, 'dummy'),
(150055, 6931, 48, 'dummy'),
(150056, 6932, 48, 'dummy'),
(150057, 6933, 48, 'dummy'),
(150058, 6934, 48, 'dummy'),
(150059, 6935, 48, 'dummy'),
(150060, 6936, 48, 'dummy'),
(150061, 6937, 48, 'dummy'),
(150062, 6938, 48, 'dummy'),
(150063, 6939, 48, 'dummy'),
(150064, 6940, 48, 'dummy'),
(150065, 6941, 48, 'dummy'),
(150066, 6942, 48, 'dummy'),
(150067, 6943, 48, 'dummy'),
(150068, 6944, 48, 'dummy'),
(150069, 6945, 48, 'dummy'),
(150070, 6946, 48, 'dummy'),
(150071, 6947, 48, 'dummy'),
(150072, 6948, 48, 'dummy'),
(150073, 6949, 48, 'dummy'),
(150074, 6950, 48, 'dummy'),
(150075, 6951, 48, 'dummy'),
(150076, 6952, 48, 'dummy'),
(150077, 6953, 48, 'dummy'),
(150078, 6954, 48, 'dummy'),
(150079, 6955, 48, 'dummy'),
(150080, 6956, 48, 'dummy'),
(150081, 6957, 48, 'dummy'),
(150082, 6958, 48, 'dummy'),
(150083, 6959, 48, 'dummy'),
(150084, 6960, 48, 'dummy'),
(150085, 6961, 48, 'dummy'),
(150086, 6962, 48, 'dummy'),
(150087, 6963, 48, 'dummy'),
(150088, 6964, 48, 'dummy'),
(150089, 6965, 48, 'dummy'),
(150090, 6966, 48, 'dummy'),
(150091, 6967, 48, 'dummy'),
(150092, 6968, 48, 'dummy'),
(150093, 6969, 48, 'dummy'),
(150094, 6970, 48, 'dummy'),
(150095, 6971, 48, 'dummy'),
(150096, 6972, 48, 'dummy'),
(150097, 6973, 48, 'dummy'),
(150098, 6974, 48, 'dummy'),
(150099, 6975, 48, 'dummy'),
(150100, 6976, 48, 'dummy'),
(150101, 6977, 48, 'dummy'),
(150102, 6978, 48, 'dummy'),
(150103, 6979, 48, 'dummy'),
(150104, 6980, 48, 'dummy'),
(150105, 6981, 48, 'dummy'),
(150106, 6982, 48, 'dummy'),
(150107, 6983, 48, 'dummy'),
(150108, 6984, 48, 'dummy'),
(150109, 6985, 48, 'dummy'),
(150110, 6986, 48, 'dummy'),
(150111, 6987, 48, 'dummy'),
(150112, 6988, 48, 'dummy'),
(150113, 6989, 48, 'dummy'),
(150114, 6990, 48, 'dummy'),
(150115, 6991, 48, 'dummy'),
(150116, 6992, 48, 'dummy'),
(150117, 6993, 48, 'dummy'),
(150118, 6994, 48, 'dummy'),
(150119, 6995, 48, 'dummy'),
(150120, 6996, 48, 'dummy'),
(150121, 6997, 48, 'dummy'),
(150122, 6998, 48, 'dummy'),
(150123, 6999, 48, 'dummy'),
(150124, 7000, 48, 'dummy'),
(150125, 7001, 48, 'dummy'),
(150126, 7002, 48, 'dummy'),
(150127, 7003, 48, 'dummy'),
(150128, 7004, 48, 'dummy'),
(150129, 7005, 48, 'dummy'),
(150130, 7006, 48, 'dummy'),
(150131, 7007, 48, 'dummy'),
(150132, 7008, 48, 'dummy'),
(150133, 7009, 48, 'dummy'),
(150134, 7010, 48, 'dummy'),
(150135, 7011, 48, 'dummy'),
(150136, 7012, 48, 'dummy'),
(150137, 7013, 48, 'dummy'),
(150138, 7014, 48, 'dummy'),
(150139, 7015, 48, 'dummy'),
(150140, 7016, 48, 'dummy'),
(150141, 7017, 48, 'dummy'),
(150142, 7018, 48, 'dummy'),
(150143, 7019, 48, 'dummy'),
(150144, 7020, 48, 'dummy'),
(150145, 7021, 48, 'dummy'),
(150146, 7022, 48, 'dummy'),
(150147, 7023, 48, 'dummy'),
(150148, 7024, 48, 'dummy'),
(150149, 7025, 48, 'dummy'),
(150150, 7026, 48, 'dummy'),
(150151, 7027, 48, 'dummy'),
(150152, 7028, 48, 'dummy'),
(150153, 7029, 48, 'dummy'),
(150154, 7030, 48, 'dummy'),
(150155, 7031, 48, 'dummy'),
(150156, 7032, 48, 'dummy'),
(150157, 7033, 48, 'dummy'),
(150158, 7034, 48, 'dummy'),
(150159, 7035, 48, 'dummy'),
(150160, 7036, 48, 'dummy'),
(150161, 7037, 48, 'dummy'),
(150162, 7038, 48, 'dummy'),
(150163, 7039, 48, 'dummy'),
(150164, 7040, 48, 'dummy'),
(150165, 7041, 48, 'dummy'),
(150166, 7042, 48, 'dummy'),
(150167, 7043, 48, 'dummy'),
(150168, 7044, 48, 'dummy'),
(150169, 7045, 48, 'dummy'),
(150170, 7046, 48, 'dummy'),
(150171, 7047, 48, 'dummy'),
(150172, 7048, 48, 'dummy'),
(150173, 7049, 48, 'dummy'),
(150174, 7050, 48, 'dummy'),
(150175, 7051, 48, 'dummy'),
(150176, 7052, 48, 'dummy'),
(150177, 7053, 48, 'dummy'),
(150178, 7054, 48, 'dummy'),
(150179, 7055, 48, 'dummy'),
(150180, 7056, 48, 'dummy'),
(150181, 7057, 48, 'dummy'),
(150182, 7058, 48, 'dummy'),
(150183, 7059, 48, 'dummy'),
(150184, 7060, 48, 'dummy'),
(150185, 7061, 48, 'dummy'),
(150186, 7062, 48, 'dummy'),
(150187, 7063, 48, 'dummy'),
(150188, 7064, 48, 'dummy'),
(150189, 7065, 48, 'dummy'),
(150190, 7066, 48, 'dummy'),
(150191, 7067, 48, 'dummy'),
(150192, 7068, 48, 'dummy'),
(150193, 7069, 48, 'dummy'),
(150194, 7070, 48, 'dummy'),
(150195, 7071, 48, 'dummy'),
(150196, 7072, 48, 'dummy'),
(150197, 7073, 48, 'dummy'),
(150198, 7074, 48, 'dummy'),
(150199, 7075, 48, 'dummy'),
(150200, 7076, 48, 'dummy'),
(150201, 7077, 48, 'dummy'),
(150202, 7078, 48, 'dummy'),
(150203, 7079, 48, 'dummy'),
(150204, 7080, 48, 'dummy'),
(150205, 7081, 48, 'dummy'),
(150206, 7082, 48, 'dummy'),
(150207, 7083, 48, 'dummy'),
(150208, 7084, 48, 'dummy'),
(150209, 7085, 48, 'dummy'),
(150210, 7086, 48, 'dummy'),
(150211, 7087, 48, 'dummy'),
(150212, 7088, 48, 'dummy'),
(150213, 7089, 48, 'dummy'),
(150214, 7090, 48, 'dummy'),
(150215, 7091, 48, 'dummy'),
(150216, 7092, 48, 'dummy'),
(150217, 7093, 48, 'dummy'),
(150218, 7094, 48, 'dummy'),
(150219, 7095, 48, 'dummy'),
(150220, 7096, 48, 'dummy'),
(150221, 7097, 48, 'dummy'),
(150222, 7098, 48, 'dummy'),
(150223, 7099, 48, 'dummy'),
(150224, 7100, 48, 'dummy'),
(150225, 7101, 48, 'dummy'),
(150226, 7102, 48, 'dummy'),
(150227, 7103, 48, 'dummy'),
(150228, 7104, 48, 'dummy'),
(150229, 7105, 48, 'dummy'),
(150230, 7106, 48, 'dummy'),
(150231, 7107, 48, 'dummy'),
(150232, 7108, 48, 'dummy'),
(150233, 7109, 48, 'dummy'),
(150234, 7110, 48, 'dummy'),
(150235, 7111, 48, 'dummy'),
(150236, 7112, 48, 'dummy'),
(150237, 7113, 48, 'dummy'),
(150238, 7114, 48, 'dummy'),
(150239, 7115, 48, 'dummy'),
(150240, 7116, 48, 'dummy'),
(150241, 7117, 48, 'dummy'),
(150242, 7118, 48, 'dummy'),
(150243, 7119, 48, 'dummy'),
(150244, 7120, 48, 'dummy'),
(150245, 7121, 48, 'dummy'),
(150246, 7122, 48, 'dummy'),
(150247, 7123, 48, 'dummy'),
(150248, 7124, 48, 'dummy'),
(150249, 7125, 48, 'dummy'),
(150250, 7126, 48, 'dummy'),
(150251, 7127, 48, 'dummy'),
(150252, 7128, 48, 'dummy'),
(150253, 7129, 48, 'dummy'),
(150254, 7130, 48, 'dummy'),
(150255, 7131, 48, 'dummy'),
(150256, 7132, 48, 'dummy'),
(150257, 7133, 48, 'dummy'),
(150258, 7134, 48, 'dummy'),
(150259, 7135, 48, 'dummy'),
(150260, 7136, 48, 'dummy'),
(150261, 7137, 48, 'dummy'),
(150262, 7138, 48, 'dummy'),
(150263, 7139, 48, 'dummy'),
(150264, 7140, 48, 'dummy'),
(150265, 7141, 48, 'dummy'),
(150266, 7142, 48, 'dummy'),
(150267, 7143, 48, 'dummy'),
(150268, 7144, 48, 'dummy'),
(150269, 7145, 48, 'dummy'),
(150270, 7146, 48, 'dummy'),
(150271, 7147, 48, 'dummy'),
(150272, 7148, 48, 'dummy'),
(150273, 7149, 48, 'dummy'),
(150274, 7150, 48, 'dummy'),
(150275, 7151, 48, 'dummy'),
(150276, 7152, 48, 'dummy'),
(150277, 7153, 48, 'dummy'),
(150278, 7154, 48, 'dummy'),
(150279, 7155, 48, 'dummy'),
(150280, 7156, 48, 'dummy'),
(150281, 7157, 48, 'dummy'),
(150282, 7158, 48, 'dummy'),
(150283, 7159, 48, 'dummy'),
(150284, 7160, 48, 'dummy'),
(150285, 7161, 48, 'dummy'),
(150286, 7162, 48, 'dummy'),
(150287, 7163, 48, 'dummy'),
(150288, 7164, 48, 'dummy'),
(150289, 7165, 48, 'dummy'),
(150290, 7166, 48, 'dummy'),
(150291, 7167, 48, 'dummy'),
(150292, 7168, 48, 'dummy'),
(150293, 7169, 48, 'dummy'),
(150294, 7170, 48, 'dummy'),
(150295, 7171, 48, 'dummy'),
(150296, 7172, 48, 'dummy'),
(150297, 7173, 48, 'dummy'),
(150298, 7174, 48, 'dummy'),
(150299, 7175, 48, 'dummy'),
(150300, 7176, 48, 'dummy'),
(150301, 7177, 48, 'dummy'),
(150302, 7178, 48, 'dummy'),
(150303, 7179, 48, 'dummy'),
(150304, 7180, 48, 'dummy'),
(150305, 7181, 48, 'dummy'),
(150306, 7182, 48, 'dummy'),
(150307, 7183, 48, 'dummy'),
(150308, 7184, 48, 'dummy'),
(150309, 7185, 48, 'dummy'),
(150310, 7186, 48, 'dummy'),
(150311, 7187, 48, 'dummy'),
(150312, 7188, 48, 'dummy'),
(150313, 7189, 48, 'dummy'),
(150314, 7190, 48, 'dummy'),
(150315, 7191, 48, 'dummy'),
(150316, 7192, 48, 'dummy'),
(150317, 7193, 48, 'dummy'),
(150318, 7194, 48, 'dummy'),
(150319, 7195, 48, 'dummy'),
(150320, 7196, 48, 'dummy'),
(150321, 7197, 48, 'dummy'),
(150322, 7198, 48, 'dummy'),
(150323, 7199, 48, 'dummy'),
(150324, 7200, 48, 'dummy'),
(150325, 7201, 48, 'dummy'),
(150326, 7202, 48, 'dummy'),
(150327, 7203, 48, 'dummy'),
(150328, 7204, 48, 'dummy'),
(150329, 7205, 48, 'dummy'),
(150330, 7206, 48, 'dummy'),
(150331, 7207, 48, 'dummy'),
(150332, 7208, 48, 'dummy'),
(150333, 7209, 48, 'dummy'),
(150334, 7210, 48, 'dummy'),
(150335, 7211, 48, 'dummy'),
(150336, 7212, 48, 'dummy'),
(150337, 7213, 48, 'dummy'),
(150338, 7214, 48, 'dummy'),
(150339, 7215, 48, 'dummy'),
(150340, 7216, 48, 'dummy'),
(150341, 7217, 48, 'dummy'),
(150342, 7218, 48, 'dummy'),
(150343, 7219, 48, 'dummy'),
(150344, 7220, 48, 'dummy'),
(150345, 7221, 48, 'dummy'),
(150346, 7222, 48, 'dummy'),
(150347, 7223, 48, 'dummy'),
(150348, 7224, 48, 'dummy'),
(150349, 7225, 48, 'dummy'),
(150350, 7226, 48, 'dummy'),
(150351, 7227, 48, 'dummy'),
(150352, 7228, 48, 'dummy'),
(150353, 7229, 48, 'dummy'),
(150354, 7230, 48, 'dummy'),
(150355, 7231, 48, 'dummy'),
(150356, 7232, 48, 'dummy'),
(150357, 7233, 48, 'dummy'),
(150358, 7234, 48, 'dummy'),
(150359, 7235, 48, 'dummy'),
(150360, 7236, 48, 'dummy'),
(150361, 7237, 48, 'dummy'),
(150362, 7238, 48, 'dummy'),
(150363, 7239, 48, 'dummy'),
(150364, 7240, 48, 'dummy'),
(150365, 7241, 48, 'dummy'),
(150366, 7242, 48, 'dummy'),
(150367, 7243, 48, 'dummy'),
(150368, 7244, 48, 'dummy'),
(150369, 7245, 48, 'dummy'),
(150370, 7246, 48, 'dummy'),
(150371, 7247, 48, 'dummy'),
(150372, 7248, 48, 'dummy'),
(150373, 7249, 48, 'dummy'),
(150374, 7250, 48, 'dummy'),
(150375, 7251, 48, 'dummy'),
(150376, 7252, 48, 'dummy'),
(150377, 7253, 48, 'dummy'),
(150378, 7254, 48, 'dummy'),
(150379, 7255, 48, 'dummy'),
(150380, 7256, 48, 'dummy'),
(150381, 7257, 48, 'dummy'),
(150382, 7258, 48, 'dummy'),
(150383, 7259, 48, 'dummy'),
(150384, 7260, 48, 'dummy'),
(150385, 7261, 48, 'dummy'),
(150386, 7262, 48, 'dummy'),
(150387, 7263, 48, 'dummy'),
(150388, 7264, 48, 'dummy'),
(150389, 7265, 48, 'dummy'),
(150390, 7266, 48, 'dummy'),
(150391, 7267, 48, 'dummy'),
(150392, 7268, 48, 'dummy'),
(150393, 7269, 48, 'dummy'),
(150394, 7270, 48, 'dummy'),
(150395, 7271, 48, 'dummy'),
(150396, 7272, 48, 'dummy'),
(150397, 7273, 48, 'dummy'),
(150398, 7274, 48, 'dummy'),
(150399, 7275, 48, 'dummy'),
(150400, 7276, 48, 'dummy'),
(150401, 7277, 48, 'dummy'),
(150402, 7278, 48, 'dummy'),
(150403, 7279, 48, 'dummy'),
(150404, 7280, 48, 'dummy'),
(150405, 7281, 48, 'dummy'),
(150406, 7282, 48, 'dummy'),
(150407, 7283, 48, 'dummy'),
(150408, 7284, 48, 'dummy'),
(150409, 7285, 48, 'dummy'),
(150410, 7286, 48, 'dummy'),
(150411, 7287, 48, 'dummy'),
(150412, 7288, 48, 'dummy'),
(150413, 7289, 48, 'dummy'),
(150414, 7290, 48, 'dummy'),
(150415, 7291, 48, 'dummy'),
(150416, 7292, 48, 'dummy'),
(150417, 7293, 48, 'dummy'),
(150418, 7294, 48, 'dummy'),
(150419, 7295, 48, 'dummy'),
(150420, 7296, 48, 'dummy'),
(150421, 7297, 48, 'dummy'),
(150422, 7298, 48, 'dummy'),
(150423, 7299, 48, 'dummy'),
(150424, 7300, 48, 'dummy'),
(150425, 7301, 48, 'dummy'),
(150426, 7302, 48, 'dummy'),
(150427, 7303, 48, 'dummy'),
(150428, 7304, 48, 'dummy'),
(150429, 7305, 48, 'dummy'),
(150430, 7306, 48, 'dummy'),
(150431, 7307, 48, 'dummy'),
(150432, 7308, 48, 'dummy'),
(150433, 7309, 48, 'dummy'),
(150434, 7310, 48, 'dummy'),
(150435, 7311, 48, 'dummy'),
(150436, 7312, 48, 'dummy'),
(150437, 7313, 48, 'dummy'),
(150438, 7314, 48, 'dummy'),
(150439, 7315, 48, 'dummy'),
(150440, 7316, 48, 'dummy'),
(150441, 7317, 48, 'dummy'),
(150442, 7318, 48, 'dummy'),
(150443, 7319, 48, 'dummy'),
(150444, 7320, 48, 'dummy'),
(150445, 7321, 48, 'dummy'),
(150446, 7322, 48, 'dummy'),
(150447, 7323, 48, 'dummy'),
(150448, 7324, 48, 'dummy'),
(150449, 7325, 48, 'dummy'),
(150450, 7326, 48, 'dummy'),
(150451, 7327, 48, 'dummy'),
(150452, 7328, 48, 'dummy'),
(150453, 7329, 48, 'dummy'),
(150454, 7330, 48, 'dummy'),
(150455, 7331, 48, 'dummy'),
(150456, 7332, 48, 'dummy'),
(150457, 7333, 48, 'dummy'),
(150458, 7334, 48, 'dummy'),
(150459, 7335, 48, 'dummy'),
(150460, 7336, 48, 'dummy'),
(150461, 7337, 48, 'dummy'),
(150462, 7338, 48, 'dummy'),
(150463, 7339, 48, 'dummy'),
(150464, 7340, 48, 'dummy'),
(150465, 7341, 48, 'dummy'),
(150466, 7342, 48, 'dummy'),
(150467, 7343, 48, 'dummy'),
(150468, 7344, 48, 'dummy'),
(150469, 7345, 48, 'dummy'),
(150470, 7346, 48, 'dummy'),
(150471, 7347, 48, 'dummy'),
(150472, 7348, 48, 'dummy'),
(150473, 7349, 48, 'dummy'),
(150474, 7350, 48, 'dummy'),
(150475, 7351, 48, 'dummy'),
(150476, 7352, 48, 'dummy'),
(150477, 7353, 48, 'dummy'),
(150478, 7354, 48, 'dummy'),
(150479, 7355, 48, 'dummy'),
(150480, 7356, 48, 'dummy'),
(150481, 7357, 48, 'dummy'),
(150482, 7358, 48, 'dummy'),
(150483, 7359, 48, 'dummy'),
(150484, 7360, 48, 'dummy'),
(150485, 7361, 48, 'dummy'),
(150486, 7362, 48, 'dummy'),
(150487, 7363, 48, 'dummy'),
(150488, 7364, 48, 'dummy'),
(150489, 7365, 48, 'dummy'),
(150490, 7366, 48, 'dummy'),
(150491, 7367, 48, 'dummy'),
(150492, 7368, 48, 'dummy'),
(150493, 7369, 48, 'dummy'),
(150494, 7370, 48, 'dummy'),
(150495, 7371, 48, 'dummy'),
(150496, 7372, 48, 'dummy'),
(150497, 7373, 48, 'dummy'),
(150498, 7374, 48, 'dummy'),
(150499, 7375, 48, 'dummy'),
(150500, 7376, 48, 'dummy'),
(150501, 7377, 48, 'dummy'),
(150502, 7378, 48, 'dummy'),
(150503, 7379, 48, 'dummy'),
(150504, 7380, 48, 'dummy'),
(150505, 7381, 48, 'dummy'),
(150506, 7382, 48, 'dummy'),
(150507, 7383, 48, 'dummy'),
(150508, 7384, 48, 'dummy'),
(150509, 7385, 48, 'dummy'),
(150510, 7386, 48, 'dummy'),
(150511, 7387, 48, 'dummy'),
(150512, 7388, 48, 'dummy'),
(150513, 7389, 48, 'dummy'),
(150514, 7390, 48, 'dummy'),
(150515, 7391, 48, 'dummy'),
(150516, 7392, 48, 'dummy'),
(150517, 7393, 48, 'dummy'),
(150518, 7394, 48, 'dummy'),
(150519, 7395, 48, 'dummy'),
(150520, 7396, 48, 'dummy'),
(150521, 7397, 48, 'dummy'),
(150522, 7398, 48, 'dummy'),
(150523, 7399, 48, 'dummy'),
(150524, 7400, 48, 'dummy'),
(150525, 7401, 48, 'dummy'),
(150526, 7402, 48, 'dummy'),
(150527, 7403, 48, 'dummy'),
(150528, 7404, 48, 'dummy'),
(150529, 7405, 48, 'dummy'),
(150530, 7406, 48, 'dummy'),
(150531, 7407, 48, 'dummy'),
(150532, 7408, 48, 'dummy'),
(150533, 7409, 48, 'dummy'),
(150534, 7410, 48, 'dummy'),
(150535, 7411, 48, 'dummy'),
(150536, 7412, 48, 'dummy'),
(150537, 7413, 48, 'dummy'),
(150538, 7414, 48, 'dummy'),
(150539, 7415, 48, 'dummy'),
(150540, 7416, 48, 'dummy'),
(150541, 7417, 48, 'dummy'),
(150542, 7418, 48, 'dummy'),
(150543, 7419, 48, 'dummy'),
(150544, 7420, 48, 'dummy'),
(150545, 7421, 48, 'dummy'),
(150546, 7422, 48, 'dummy'),
(150547, 7423, 48, 'dummy'),
(150548, 7424, 48, 'dummy'),
(150549, 7425, 48, 'dummy'),
(150550, 7426, 48, 'dummy'),
(150551, 7427, 48, 'dummy'),
(150552, 7428, 48, 'dummy'),
(150553, 7429, 48, 'dummy'),
(150554, 7430, 48, 'dummy'),
(150555, 7431, 48, 'dummy'),
(150556, 7432, 48, 'dummy'),
(150557, 7433, 48, 'dummy'),
(150558, 7434, 48, 'dummy'),
(150559, 7435, 48, 'dummy'),
(150560, 7436, 48, 'dummy'),
(150561, 7437, 48, 'dummy'),
(150562, 7438, 48, 'dummy'),
(150563, 7439, 48, 'dummy'),
(150564, 7440, 48, 'dummy'),
(150565, 7441, 48, 'dummy'),
(150566, 7442, 48, 'dummy'),
(150567, 7443, 48, 'dummy'),
(150568, 7444, 48, 'dummy'),
(150569, 7445, 48, 'dummy'),
(150570, 7446, 48, 'dummy'),
(150571, 7447, 48, 'dummy'),
(150572, 7448, 48, 'dummy'),
(150573, 7449, 48, 'dummy'),
(150574, 7450, 48, 'dummy'),
(150575, 7451, 48, 'dummy'),
(150576, 7452, 48, 'dummy'),
(150577, 7453, 48, 'dummy'),
(150578, 7454, 48, 'dummy'),
(150579, 7455, 48, 'dummy'),
(150580, 7456, 48, 'dummy'),
(150581, 7457, 48, 'dummy'),
(150582, 7458, 48, 'dummy'),
(150583, 7459, 48, 'dummy'),
(150584, 7460, 48, 'dummy'),
(150585, 7461, 48, 'dummy'),
(150586, 7462, 48, 'dummy'),
(150587, 7463, 48, 'dummy'),
(150588, 7464, 48, 'dummy'),
(150589, 7465, 48, 'dummy'),
(150590, 7466, 48, 'dummy'),
(150591, 7467, 48, 'dummy'),
(150592, 7468, 48, 'dummy'),
(150593, 7469, 48, 'dummy'),
(150594, 7470, 48, 'dummy'),
(150595, 7471, 48, 'dummy'),
(150596, 7472, 48, 'dummy'),
(150597, 7473, 48, 'dummy'),
(150598, 7474, 48, 'dummy'),
(150599, 7475, 48, 'dummy'),
(150600, 7476, 48, 'dummy'),
(150601, 7477, 48, 'dummy'),
(150602, 7478, 48, 'dummy'),
(150603, 7479, 48, 'dummy'),
(150604, 7480, 48, 'dummy'),
(150605, 7481, 48, 'dummy'),
(150606, 7482, 48, 'dummy'),
(150607, 7483, 48, 'dummy'),
(150608, 7484, 48, 'dummy'),
(150609, 7485, 48, 'dummy'),
(150610, 7486, 48, 'dummy'),
(150611, 7487, 48, 'dummy'),
(150612, 7488, 48, 'dummy'),
(150613, 7489, 48, 'dummy'),
(150614, 7490, 48, 'dummy'),
(150615, 7491, 48, 'dummy'),
(150616, 7492, 48, 'dummy'),
(150617, 7493, 48, 'dummy'),
(150618, 7494, 48, 'dummy'),
(150619, 7495, 48, 'dummy'),
(150620, 7496, 48, 'dummy'),
(150621, 7497, 48, 'dummy'),
(150622, 7498, 48, 'dummy'),
(150623, 7499, 48, 'dummy'),
(150624, 7500, 48, 'dummy'),
(150625, 7501, 48, 'dummy'),
(150626, 7502, 48, 'dummy'),
(150627, 7503, 48, 'dummy'),
(150628, 7504, 48, 'dummy'),
(150629, 7505, 48, 'dummy'),
(150630, 7506, 48, 'dummy'),
(150631, 7507, 48, 'dummy'),
(150632, 7508, 48, 'dummy'),
(150633, 7509, 48, 'dummy'),
(150634, 7510, 48, 'dummy'),
(150635, 7511, 48, 'dummy'),
(150636, 7512, 48, 'dummy'),
(150637, 7513, 48, 'dummy'),
(150638, 7514, 48, 'dummy'),
(150639, 7515, 48, 'dummy'),
(150640, 7516, 48, 'dummy'),
(150641, 7517, 48, 'dummy'),
(150642, 7518, 48, 'dummy'),
(150643, 7519, 48, 'dummy'),
(150644, 7520, 48, 'dummy'),
(150645, 7521, 48, 'dummy'),
(150646, 7522, 48, 'dummy'),
(150647, 7523, 48, 'dummy'),
(150648, 7524, 48, 'dummy'),
(150649, 7525, 48, 'dummy'),
(150650, 7526, 48, 'dummy'),
(150651, 7527, 48, 'dummy'),
(150652, 7528, 48, 'dummy'),
(150653, 7529, 48, 'dummy'),
(150654, 7530, 48, 'dummy'),
(150655, 7531, 48, 'dummy'),
(150656, 7532, 48, 'dummy'),
(150657, 7533, 48, 'dummy'),
(150658, 7534, 48, 'dummy'),
(150659, 7535, 48, 'dummy'),
(150660, 7536, 48, 'dummy'),
(150661, 7537, 48, 'dummy'),
(150662, 7538, 48, 'dummy'),
(150663, 7539, 48, 'dummy'),
(150664, 7540, 48, 'dummy'),
(150665, 7541, 48, 'dummy'),
(150666, 7542, 48, 'dummy'),
(150667, 7543, 48, 'dummy'),
(150668, 7544, 48, 'dummy'),
(150669, 7545, 48, 'dummy'),
(150670, 7546, 48, 'dummy'),
(150671, 7547, 48, 'dummy'),
(150672, 7548, 48, 'dummy'),
(150673, 7549, 48, 'dummy');

-- --------------------------------------------------------

--
-- Table structure for table `lang_languages`
--

CREATE TABLE `lang_languages` (
  `lang_id` int(11) NOT NULL AUTO_INCREMENT,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `lang_description` varchar(100) DEFAULT NULL,
  `lang_is_rtl` tinyint(4) DEFAULT '0',
  UNIQUE KEY `lang_id` (`lang_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=49 ;

--
-- Dumping data for table `lang_languages`
--

INSERT INTO `lang_languages` VALUES
(1, 'en', 'English (Standard)', 0),
(2, 'se', 'Swedish', 0),
(3, 'es', 'Spanish (Spain)', 0),
(4, 'el', 'Spanish (Latin American)', 0),
(5, 'de', 'German', 0),
(6, 'du', 'Dutch', 0),
(7, 'he', 'Hebrew', 1),
(8, 'fr', 'French (Standard)', 0),
(9, 'fq', 'French (Canadian)', 0),
(10, 'no', 'Norwegian', 0),
(11, 'zh', 'Chinese (Simplified)', 0),
(12, 'zt', 'Chinese (Traditional)', 0),
(13, 'ru', 'Russian', 0),
(14, 'hy', 'Armenian', 0),
(15, 'sk', 'Slovak', 0),
(16, 'id', 'Bahasa Indonesia', 0),
(17, 'gr', 'Greek', 0),
(18, 'ei', 'English (Indian)', 0),
(19, 'pe', 'Portuguese (European)', 0),
(20, 'pt', 'Portuguese (Brazilian)', 0),
(21, 'ar', 'Arabic', 1),
(22, 'da', 'Danish', 0),
(23, 'tr', 'Turkish', 0),
(24, 'po', 'Polish', 0),
(25, 'am', 'Amharic', 0),
(26, 'it', 'Italian', 0),
(27, 'hi', 'Hindi', 0),
(28, 'ro', 'Romanian', 0),
(29, 'vi', 'Vietnamese', 0),
(30, 'hu', 'Hungarian', 0),
(31, 'sq', 'Albanian', 0),
(32, 'cs', 'Czech', 0),
(33, 'uk', 'Ukrainian', 0),
(34, 'bn', 'Bengali', 0),
(35, 'et', 'Estonian', 0),
(36, 'fa', 'Persian', 0),
(37, 'li', 'Lithuanian', 0),
(38, 'si', 'Sinhala', 0),
(39, 'ja', 'Japanese', 0),
(40, 'fi', 'Finnish', 0),
(41, 'ko', 'Korean', 0),
(42, 'ka', 'Georgian', 0),
(43, 'bs', 'Bosnian', 0),
(44, 'hr', 'Croatian', 0),
(45, 'sr', 'Serbian', 0),
(46, 'mr', 'Marathi', 0),
(47, 'so', 'Somali', 0),
(48, 'dd', 'dummy', 0);

-- --------------------------------------------------------

--
-- Table structure for table `layout_options`
--

CREATE TABLE `layout_options` (
  `form_id` varchar(31) NOT NULL DEFAULT '',
  `field_id` varchar(31) NOT NULL DEFAULT '',
  `group_name` varchar(31) NOT NULL DEFAULT '',
  `title` varchar(63) NOT NULL DEFAULT '',
  `seq` int(11) NOT NULL DEFAULT '0',
  `data_type` tinyint(3) NOT NULL DEFAULT '0',
  `uor` tinyint(1) NOT NULL DEFAULT '1',
  `fld_length` int(11) NOT NULL DEFAULT '15',
  `max_length` int(11) NOT NULL DEFAULT '0',
  `list_id` varchar(31) NOT NULL DEFAULT '',
  `titlecols` tinyint(3) NOT NULL DEFAULT '1',
  `datacols` tinyint(3) NOT NULL DEFAULT '1',
  `default_value` varchar(255) NOT NULL DEFAULT '',
  `edit_options` varchar(36) NOT NULL DEFAULT '',
  `description` text,
  `fld_rows` int(11) NOT NULL DEFAULT '0',
  `list_backup_id` varchar(31) NOT NULL DEFAULT '',
  `source` char(1) NOT NULL DEFAULT 'F' COMMENT 'F=Form, D=Demographics, H=History, E=Encounter',
  `conditions` text COMMENT 'serialized array of skip conditions',
  PRIMARY KEY (`form_id`,`field_id`,`seq`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `layout_options`
--

INSERT INTO `layout_options` VALUES
('DEM', 'allow_health_info_ex', '2Privacy', 'Allow Health Information Exchange', 45, 1, 1, 0, 0, 'yesno', 1, 1, '', '', '', 0, '', 'F', ''),
('DEM', 'allow_imm_info_share', '2Privacy', 'Allow Immunization Info Sharing', 40, 1, 1, 0, 0, 'yesno', 1, 1, '', '', '', 0, '', 'F', ''),
('DEM', 'allow_imm_reg_use', '2Privacy', 'Allow Immunization Registry Use', 35, 1, 1, 0, 0, 'yesno', 1, 1, '', '', '', 0, '', 'F', ''),
('DEM', 'allow_patient_portal', '2Privacy', 'Allow Patient Portal', 1, 1, 1, 0, 0, 'yesno', 1, 1, '', '', '', 0, '', 'F', ''),
('DEM', 'billing_note', '1Face Sheet', 'Billing Note', 80, 2, 1, 60, 0, '', 1, 3, '', '', 'Patient Level Billing Note (Collections)', 0, '', 'F', ''),
('DEM', 'city', '1Face Sheet', 'City', 40, 2, 1, 15, 63, '', 1, 1, '', 'C', 'City Name', 0, '', 'F', ''),
('DEM', 'contact_relationship', '2Contacts', 'Emergency Contact', 30, 2, 1, 10, 63, '', 1, 1, '', 'C', 'Emergency Contact Person', 0, '', 'F', ''),
('DEM', 'contrastart', '2Privacy', 'Contraceptives Start', 50, 4, 0, 0, 10, '', 1, 1, '', '', 'Date contraceptive services initially provided', 0, '', 'F', ''),
('DEM', 'country_code', '2Contacts', 'Country', 55, 26, 1, 0, 0, 'country', 1, 1, '', '', 'Country', 0, '', 'F', ''),
('DEM', 'county', '2Contacts', 'County', 50, 26, 1, 0, 0, 'county', 1, 1, '', '', 'County', 0, '', 'F', ''),
('DEM', 'deceased_date', '2Privacy', 'Date Deceased', 60, 4, 1, 0, 20, '', 1, 1, '', 'D', 'If person is deceased then enter date of death.', 0, '', 'F', ''),
('DEM', 'deceased_reason', '2Privacy', 'Reason Deceased', 65, 2, 1, 30, 255, '', 1, 1, '', '', 'Reason for Death', 0, '', 'F', ''),
('DEM', 'DOB', '1Face Sheet', 'DOB', 25, 4, 2, 0, 10, '', 1, 1, '', 'D', 'Date of Birth', 0, '', 'F', ''),
('DEM', 'drivers_license', '1Face Sheet', 'License/ID', 60, 2, 1, 15, 63, '', 1, 1, '', '', 'Drivers License or State ID', 0, '', 'F', ''),
('DEM', 'email', '1Face Sheet', 'Contact Email', 70, 2, 1, 30, 95, '', 1, 1, '', '', 'Contact Email Address', 0, '', 'F', ''),
('DEM', 'email_direct', '2Privacy', 'Trusted Email', 3, 2, 1, 30, 95, '', 1, 1, '', '', 'Trusted Direct Email Address', 0, '', 'F', ''),
('DEM', 'em_city', '4Employer', 'City', 25, 2, 1, 15, 63, '', 1, 1, '', 'C', 'City Name', 0, '', 'F', ''),
('DEM', 'em_country', '4Employer', 'Country', 40, 26, 1, 0, 0, 'country', 1, 1, '', '', 'Country', 0, '', 'F', ''),
('DEM', 'em_name', '4Employer', 'Employer Name', 15, 2, 1, 20, 63, '', 1, 1, '', 'C', 'Employer Name', 0, '', 'F', ''),
('DEM', 'em_postal_code', '4Employer', 'Postal Code', 35, 2, 1, 6, 63, '', 1, 1, '', '', 'Postal Code', 0, '', 'F', ''),
('DEM', 'em_state', '4Employer', 'State', 30, 26, 1, 0, 0, 'state', 1, 1, '', '', 'State/Locality', 0, '', 'F', ''),
('DEM', 'em_street', '4Employer', 'Employer Address', 20, 2, 1, 25, 63, '', 1, 1, '', 'C', 'Street and Number', 0, '', 'F', ''),
('DEM', 'ethnicity', '5Social Statistics', 'Ethnicity', 10, 33, 1, 0, 0, 'ethnicity', 1, 1, '', '', 'Ethnicity', 0, 'ethrace', 'F', ''),
('DEM', 'family_size', '5Social Statistics', 'Family Size', 15, 2, 1, 20, 63, '', 1, 1, '', '', 'Family Size', 0, '', 'F', ''),
('DEM', 'financial_review', '5Social Statistics', 'Financial Review Date', 20, 2, 1, 10, 20, '', 1, 1, '', 'D', 'Financial Review Date', 0, '', 'F', ''),
('DEM', 'fname', '1Face Sheet', 'NAME', 5, 2, 2, 10, 63, '', 1, 1, '', 'CD', 'First Name', 0, '', 'F', ''),
('DEM', 'guardiansname', '2Contacts', 'Name of Guardian', 45, 2, 1, 20, 63, '', 1, 1, '', '', '', 0, '', 'F', ''),
('DEM', 'hipaa_allowemail', '2Privacy', 'Allow Email', 30, 1, 1, 0, 0, 'yesno', 1, 1, '', '', 'Allow Email?', 0, '', 'F', ''),
('DEM', 'hipaa_allowsms', '2Privacy', 'Allow SMS', 25, 1, 1, 0, 0, 'yesno', 1, 1, '', '', 'Allow SMS (text messages)?', 0, '', 'F', ''),
('DEM', 'hipaa_mail', '2Privacy', 'Allow Mail Message', 20, 1, 1, 0, 0, 'yesno', 1, 1, '', '', 'Allow email messages?', 0, '', 'F', ''),
('DEM', 'hipaa_message', '2Privacy', 'Leave Message With', 15, 2, 1, 20, 63, '', 1, 1, '', '', 'With whom may we leave a message?', 0, '', 'F', ''),
('DEM', 'hipaa_notice', '2Privacy', 'Privacy Notice Received', 5, 1, 1, 0, 0, 'yesno', 1, 1, '', '', 'Did you receive a copy of the HIPAA Notice?', 0, '', 'F', ''),
('DEM', 'hipaa_voice', '2Privacy', 'Allow Voice Message', 10, 1, 1, 0, 0, 'yesno', 1, 1, '', '', 'Allow telephone messages?', 0, '', 'F', ''),
('DEM', 'homeless', '5Social Statistics', 'Homeless', 30, 2, 1, 20, 63, '', 1, 1, '', '', 'Homeless or similar?', 0, '', 'F', ''),
('DEM', 'industry', '4Employer', 'Industry', 5, 26, 1, 0, 0, 'Industry', 1, 1, '', '', 'Industry', 0, '', 'F', ''),
('DEM', 'interpretter', '5Social Statistics', 'Interpreter', 7, 2, 1, 20, 63, '', 1, 1, '', '', 'Interpreter needed?', 0, '', 'F', ''),
('DEM', 'language', '5Social Statistics', 'Language', 5, 1, 1, 0, 0, 'language', 1, 3, '', '', 'Preferred Language', 0, '', 'F', ''),
('DEM', 'lname', '1Face Sheet', '', 15, 2, 2, 10, 63, '', 0, 0, '', 'CD', 'Last Name', 0, '', 'F', ''),
('DEM', 'migrantseasonal', '5Social Statistics', 'Migrant/Seasonal', 35, 2, 1, 20, 63, '', 1, 1, '', '', 'Migrant or seasonal worker?', 0, '', 'F', ''),
('DEM', 'mname', '1Face Sheet', '', 10, 2, 1, 2, 63, '', 0, 0, '', 'C', 'Middle Name', 0, '', 'F', ''),
('DEM', 'monthly_income', '5Social Statistics', 'Monthly Income', 25, 2, 1, 20, 63, '', 1, 1, '', '', 'Monthly Income', 0, '', 'F', ''),
('DEM', 'mothersname', '2Contacts', 'Name of Mother', 40, 2, 1, 20, 63, '', 1, 1, '', '', '', 0, '', 'F', ''),
('DEM', 'occupation', '4Employer', 'Occupation', 10, 26, 1, 0, 0, 'Occupation', 1, 1, '', '', 'Occupation', 0, '', 'F', ''),
('DEM', 'pharmacy_id', '2Contacts', 'Pharmacy', 15, 12, 1, 0, 0, '', 1, 3, '', '', 'Preferred Pharmacy', 0, '', 'F', ''),
('DEM', 'phone_biz', '2Contacts', 'Work Phone', 25, 2, 1, 20, 63, '', 1, 1, '', 'P', 'Work Phone Number', 0, '', 'F', ''),
('DEM', 'phone_cell', '1Face Sheet', 'Mobile Phone', 65, 2, 1, 20, 63, '', 1, 1, '', 'P', 'Cell Phone Number', 0, '', 'F', ''),
('DEM', 'phone_contact', '2Contacts', 'Emergency Phone', 35, 2, 1, 20, 63, '', 1, 1, '', 'P', 'Emergency Contact Phone Number', 0, '', 'F', ''),
('DEM', 'phone_home', '2Contacts', 'Home Phone', 20, 2, 1, 20, 63, '', 1, 1, '', 'P', 'Home Phone Number', 0, '', 'F', ''),
('DEM', 'postal_code', '1Face Sheet', 'Postal Code', 50, 2, 1, 6, 63, '', 1, 1, '', '', 'Postal Code', 0, '', 'F', ''),
('DEM', 'pricelevel', '1Face Sheet', 'Price Level', 75, 1, 0, 0, 0, 'pricelevel', 1, 1, '', '', 'Discount Level', 0, '', 'F', ''),
('DEM', 'providerID', '2Contacts', 'Provider', 5, 11, 1, 0, 0, '', 1, 3, '', '', 'Provider', 0, '', 'F', ''),
('DEM', 'referral_source', '2Contacts', 'Referral Source', 60, 26, 1, 0, 0, 'refsource', 1, 1, '', '', 'How did they hear about us', 0, '', 'F', NULL),
('DEM', 'ref_providerID', '2Contacts', 'Referring Provider', 10, 11, 1, 0, 0, '', 1, 3, '', '', 'Referring Provider', 0, '', 'F', ''),
('DEM', 'religion', '5Social Statistics', 'Religion', 45, 1, 1, 0, 0, 'religious_affiliation', 1, 3, '', '', 'Patient Religion', 0, '', 'F', NULL),
('DEM', 'sex', '1Face Sheet', 'Sex', 20, 1, 2, 0, 0, 'sex', 1, 1, '', 'N', 'Sex', 0, '', 'F', ''),
('DEM', 'ss', '1Face Sheet', 'S.S.N.', 55, 2, 1, 11, 11, '', 1, 1, '', '', 'Social Security Number (No dashes for best searching!)', 0, '', 'F', ''),
('DEM', 'state', '1Face Sheet', 'State', 45, 26, 1, 0, 0, 'state', 1, 1, '', '', 'State/Locality', 0, '', 'F', ''),
('DEM', 'status', '1Face Sheet', 'Marital Status', 30, 1, 1, 0, 0, 'marital', 1, 3, '', '', 'Marital Status', 0, '', 'F', ''),
('DEM', 'street', '1Face Sheet', 'Address', 35, 2, 1, 25, 63, '', 1, 1, '', 'C', 'Street and Number', 0, '', 'F', ''),
('DEM', 'vfc', '2Privacy', 'VFC', 55, 1, 1, 20, 0, 'eligibility', 1, 1, '', '', 'Eligibility status for Vaccine for Children supplied vaccine', 0, '', 'F', NULL),
('FACUSR', 'provider_id', '1General', 'Provider ID', 1, 2, 1, 15, 63, '', 1, 1, '', '', 'Provider ID at Specified Facility', 0, '', 'F', NULL),
('HIS', 'additional_history', '5Other', 'Additional History', 5, 3, 1, 30, 0, '', 1, 3, '', '', 'Additional history notes', 3, '', 'F', NULL),
('HIS', 'alcohol', '4Lifestyle', 'Alcohol', 3, 28, 1, 20, 0, '', 1, 3, '', '', 'Alcohol consumption', 0, '', 'F', NULL),
('HIS', 'coffee', '4Lifestyle', 'Coffee', 2, 28, 1, 20, 0, '', 1, 3, '', '', 'Caffeine consumption', 0, '', 'F', NULL),
('HIS', 'counseling', '4Lifestyle', 'Counseling', 5, 28, 1, 20, 0, '', 1, 3, '', '', 'Counseling activities', 0, '', 'F', NULL),
('HIS', 'dc_father', '2Family History', 'Diagnosis Code', 2, 15, 1, 0, 255, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'dc_mother', '2Family History', 'Diagnosis Code', 4, 15, 1, 0, 255, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'dc_offspring', '2Family History', 'Diagnosis Code', 10, 15, 1, 0, 255, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'dc_siblings', '2Family History', 'Diagnosis Code', 6, 15, 1, 0, 255, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'dc_spouse', '2Family History', 'Diagnosis Code', 8, 15, 1, 0, 255, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'exams', '1General', 'Exams/Tests', 2, 23, 1, 0, 0, 'exams', 1, 1, '', '', 'Exam and test results', 0, '', 'F', NULL),
('HIS', 'exercise_patterns', '4Lifestyle', 'Exercise Patterns', 6, 28, 1, 20, 0, '', 1, 3, '', '', 'Exercise patterns', 0, '', 'F', NULL),
('HIS', 'hazardous_activities', '4Lifestyle', 'Hazardous Activities', 7, 28, 1, 20, 0, '', 1, 3, '', '', 'Hazardous activities', 0, '', 'F', NULL),
('HIS', 'history_father', '2Family History', 'Father', 1, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'history_mother', '2Family History', 'Mother', 3, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'history_offspring', '2Family History', 'Offspring', 9, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'history_siblings', '2Family History', 'Siblings', 5, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'history_spouse', '2Family History', 'Spouse', 7, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'name_1', '5Other', 'Name/Value', 1, 2, 1, 10, 255, '', 1, 1, '', '', 'Name 1', 0, '', 'F', NULL),
('HIS', 'name_2', '5Other', 'Name/Value', 3, 2, 1, 10, 255, '', 1, 1, '', '', 'Name 2', 0, '', 'F', NULL),
('HIS', 'recreational_drugs', '4Lifestyle', 'Recreational Drugs', 4, 28, 1, 20, 0, '', 1, 3, '', '', 'Recreational drug use', 0, '', 'F', NULL),
('HIS', 'relatives_cancer', '3Relatives', 'Cancer', 1, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_diabetes', '3Relatives', 'Diabetes', 3, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_epilepsy', '3Relatives', 'Epilepsy', 7, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_heart_problems', '3Relatives', 'Heart Problems', 5, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_high_blood_pressure', '3Relatives', 'High Blood Pressure', 4, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_mental_illness', '3Relatives', 'Mental Illness', 8, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_stroke', '3Relatives', 'Stroke', 6, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_suicide', '3Relatives', 'Suicide', 9, 2, 1, 20, 0, '', 1, 3, '', '', '', 0, '', 'F', NULL),
('HIS', 'relatives_tuberculosis', '3Relatives', 'Tuberculosis', 2, 2, 1, 20, 0, '', 1, 1, '', '', '', 0, '', 'F', NULL),
('HIS', 'seatbelt_use', '4Lifestyle', 'Seatbelt Use', 9, 2, 1, 20, 0, '', 1, 3, '', '', 'Seatbelt use', 0, '', 'F', NULL),
('HIS', 'sleep_patterns', '4Lifestyle', 'Sleep Patterns', 8, 2, 1, 20, 0, '', 1, 3, '', '', 'Sleep patterns', 0, '', 'F', NULL),
('HIS', 'tobacco', '4Lifestyle', 'Tobacco', 1, 32, 1, 0, 0, 'smoking_status', 1, 3, '', '', 'Tobacco use', 0, '', 'F', NULL),
('HIS', 'userarea11', '5Other', 'User Defined Area 11', 6, 3, 0, 30, 0, '', 1, 3, '', '', 'User Defined', 3, '', 'F', NULL),
('HIS', 'userarea12', '5Other', 'User Defined Area 12', 7, 3, 0, 30, 0, '', 1, 3, '', '', 'User Defined', 3, '', 'F', NULL),
('HIS', 'usertext11', '1General', 'Risk Factors', 1, 21, 1, 0, 0, 'riskfactors', 1, 1, '', '', 'Risk Factors', 0, '', 'F', NULL),
('HIS', 'value_1', '5Other', '', 2, 2, 1, 10, 255, '', 0, 0, '', '', 'Value 1', 0, '', 'F', NULL),
('HIS', 'value_2', '5Other', '', 4, 2, 1, 10, 255, '', 0, 0, '', '', 'Value 2', 0, '', 'F', NULL),
('LBTbill', 'body', '1', 'Details', 10, 3, 2, 30, 0, '', 1, 3, '', '', 'Content', 5, '', 'F', NULL),
('LBTlegal', 'body', '1', 'Details', 10, 3, 2, 30, 0, '', 1, 3, '', '', 'Content', 5, '', 'F', NULL),
('LBTphreq', 'body', '1', 'Details', 10, 3, 2, 30, 0, '', 1, 3, '', '', 'Content', 5, '', 'F', NULL),
('LBTptreq', 'body', '1', 'Details', 10, 3, 2, 30, 0, '', 1, 3, '', '', 'Content', 5, '', 'F', NULL),
('LBTref', 'body', '1Referral', 'Reason', 5, 3, 2, 30, 0, '', 1, 1, '', '', 'Reason for referral', 3, '', 'F', NULL),
('LBTref', 'refer_date', '1Referral', 'Referral Date', 1, 4, 2, 0, 0, '', 1, 1, 'C', 'D', 'Date of referral', 0, '', 'F', NULL),
('LBTref', 'refer_diag', '1Referral', 'Referrer Diagnosis', 6, 2, 1, 30, 255, '', 1, 1, '', 'X', 'Referrer diagnosis', 0, '', 'F', NULL),
('LBTref', 'refer_external', '1Referral', 'External Referral', 3, 1, 1, 0, 0, 'boolean', 1, 1, '', '', 'External referral?', 0, '', 'F', NULL),
('LBTref', 'refer_from', '1Referral', 'Refer By', 2, 10, 2, 0, 0, '', 1, 1, '', '', 'Referral By', 0, '', 'F', NULL),
('LBTref', 'refer_related_code', '1Referral', 'Requested Service', 9, 15, 1, 30, 255, '', 1, 1, '', '', 'Billing Code for Requested Service', 0, '', 'F', NULL),
('LBTref', 'refer_risk_level', '1Referral', 'Risk Level', 7, 1, 1, 0, 0, 'risklevel', 1, 1, '', '', 'Level of urgency', 0, '', 'F', NULL),
('LBTref', 'refer_to', '1Referral', 'Refer To', 4, 14, 2, 0, 0, '', 1, 1, '', '', 'Referral To', 0, '', 'F', NULL),
('LBTref', 'refer_vitals', '1Referral', 'Include Vitals', 8, 1, 1, 0, 0, 'boolean', 1, 1, '', '', 'Include vitals data?', 0, '', 'F', NULL),
('LBTref', 'reply_date', '2Counter-Referral', 'Reply Date', 10, 4, 1, 0, 0, '', 1, 1, '', 'D', 'Date of reply', 0, '', 'F', NULL),
('LBTref', 'reply_documents', '2Counter-Referral', 'Documents', 14, 2, 1, 30, 255, '', 1, 1, '', '', 'Where may related scanned or paper documents be found?', 0, '', 'F', NULL),
('LBTref', 'reply_final_diag', '2Counter-Referral', 'Final Diagnosis', 13, 2, 1, 30, 255, '', 1, 1, '', '', 'Final diagnosis by specialist', 0, '', 'F', NULL),
('LBTref', 'reply_findings', '2Counter-Referral', 'Findings', 15, 3, 1, 30, 0, '', 1, 1, '', '', 'Findings by specialist', 3, '', 'F', NULL),
('LBTref', 'reply_from', '2Counter-Referral', 'Reply From', 11, 2, 1, 30, 255, '', 1, 1, '', '', 'Who replied?', 0, '', 'F', NULL),
('LBTref', 'reply_init_diag', '2Counter-Referral', 'Presumed Diagnosis', 12, 2, 1, 30, 255, '', 1, 1, '', '', 'Presumed diagnosis by specialist', 0, '', 'F', NULL),
('LBTref', 'reply_recommend', '2Counter-Referral', 'Recommendations', 17, 3, 1, 30, 0, '', 1, 1, '', '', 'Recommendations by specialist', 3, '', 'F', NULL),
('LBTref', 'reply_rx_refer', '2Counter-Referral', 'Prescriptions/Referrals', 18, 3, 1, 30, 0, '', 1, 1, '', '', 'Prescriptions and/or referrals by specialist', 3, '', 'F', NULL),
('LBTref', 'reply_services', '2Counter-Referral', 'Services Provided', 16, 3, 1, 30, 0, '', 1, 1, '', '', 'Service provided by specialist', 3, '', 'F', NULL);

-- --------------------------------------------------------

--
-- Table structure for table `lbf_data`
--

CREATE TABLE `lbf_data` (
  `form_id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'references forms.form_id',
  `field_id` varchar(31) NOT NULL COMMENT 'references layout_options.field_id',
  `field_value` text,
  PRIMARY KEY (`form_id`,`field_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='contains all data from layout-based forms' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `lbt_data`
--

CREATE TABLE `lbt_data` (
  `form_id` bigint(20) NOT NULL COMMENT 'references transactions.id',
  `field_id` varchar(31) NOT NULL COMMENT 'references layout_options.field_id',
  `field_value` text,
  PRIMARY KEY (`form_id`,`field_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='contains all data from layout-based transactions';

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_modules`
--

CREATE TABLE `libreehr_modules` (
  `pn_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `pn_name` varchar(64) DEFAULT NULL,
  `pn_type` int(6) NOT NULL DEFAULT '0',
  `pn_displayname` varchar(64) DEFAULT NULL,
  `pn_description` varchar(255) DEFAULT NULL,
  `pn_regid` int(11) unsigned NOT NULL DEFAULT '0',
  `pn_directory` varchar(64) DEFAULT NULL,
  `pn_version` varchar(10) DEFAULT NULL,
  `pn_admin_capable` tinyint(1) NOT NULL DEFAULT '0',
  `pn_user_capable` tinyint(1) NOT NULL DEFAULT '0',
  `pn_state` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`pn_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=47 ;

--
-- Dumping data for table `libreehr_modules`
--

INSERT INTO `libreehr_modules` VALUES
(46, 'PostCalendar', 2, 'PostCalendar', 'PostNuke Calendar Module', 0, 'PostCalendar', '4.0.0', 1, 1, 3);

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_module_vars`
--

CREATE TABLE `libreehr_module_vars` (
  `pn_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `pn_modname` varchar(64) DEFAULT NULL,
  `pn_name` varchar(64) DEFAULT NULL,
  `pn_value` longtext,
  PRIMARY KEY (`pn_id`),
  KEY `pn_modname` (`pn_modname`),
  KEY `pn_name` (`pn_name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=235 ;

--
-- Dumping data for table `libreehr_module_vars`
--

INSERT INTO `libreehr_module_vars` VALUES
(216, 'PostCalendar', 'pcTime24Hours', '0'),
(217, 'PostCalendar', 'pcEventsOpenInNewWindow', '0'),
(218, 'PostCalendar', 'pcUseInternationalDates', '0'),
(219, 'PostCalendar', 'pcFirstDayOfWeek', '1'),
(220, 'PostCalendar', 'pcDayHighlightColor', '#EEEEEE'),
(221, 'PostCalendar', 'pcUsePopups', '0'),
(222, 'PostCalendar', 'pcAllowDirectSubmit', '1'),
(223, 'PostCalendar', 'pcListHowManyEvents', '15'),
(224, 'PostCalendar', 'pcDisplayTopics', '0'),
(225, 'PostCalendar', 'pcEventDateFormat', '%Y-%m-%d'),
(226, 'PostCalendar', 'pcTemplate', 'default'),
(227, 'PostCalendar', 'pcAllowSiteWide', '1'),
(228, 'PostCalendar', 'pcAllowUserCalendar', '1'),
(229, 'PostCalendar', 'pcTimeIncrement', '5'),
(230, 'PostCalendar', 'pcDefaultView', 'day'),
(231, 'PostCalendar', 'pcUseCache', '0'),
(232, 'PostCalendar', 'pcCacheLifetime', '3600'),
(233, 'PostCalendar', 'pcNotifyAdmin', '0'),
(234, 'PostCalendar', 'pcNotifyEmail', '');

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_postcalendar_categories`
--

CREATE TABLE `libreehr_postcalendar_categories` (
  `pc_catid` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `pc_catname` varchar(100) DEFAULT NULL,
  `pc_catcolor` varchar(50) DEFAULT NULL,
  `pc_catdesc` text,
  `pc_recurrtype` int(1) NOT NULL DEFAULT '0',
  `pc_enddate` date DEFAULT NULL,
  `pc_recurrspec` text,
  `pc_recurrfreq` int(3) NOT NULL DEFAULT '0',
  `pc_duration` bigint(20) NOT NULL DEFAULT '0',
  `pc_end_date_flag` tinyint(1) NOT NULL DEFAULT '0',
  `pc_end_date_type` int(2) DEFAULT NULL,
  `pc_end_date_freq` int(11) NOT NULL DEFAULT '0',
  `pc_end_all_day` tinyint(1) NOT NULL DEFAULT '0',
  `pc_dailylimit` int(2) NOT NULL DEFAULT '0',
  `pc_cattype` int(11) NOT NULL COMMENT 'Used in grouping categories',
  `pc_active` tinyint(1) NOT NULL DEFAULT '1',
  `pc_seq` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`pc_catid`),
  KEY `basic_cat` (`pc_catname`,`pc_catcolor`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=15 ;

--
-- Dumping data for table `libreehr_postcalendar_categories`
--

INSERT INTO `libreehr_postcalendar_categories` VALUES
(1, 'No Show', '#DDDDDD', 'Reserved to define when an event did not occur as specified.', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 0, 0, 0, 0, 0, 0, 0, 1, 1),
(2, 'In Office', '#99CCFF', 'Reserved todefine when a provider may haveavailable appointments after.', 1, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"1";s:22:"event_repeat_freq_type";s:1:"4";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 0, 1, 3, 2, 0, 0, 1, 1, 2),
(3, 'Out Of Office', '#99FFFF', 'Reserved to define when a provider may not have available appointments after.', 1, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"1";s:22:"event_repeat_freq_type";s:1:"4";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 0, 1, 3, 2, 0, 0, 1, 1, 3),
(4, 'Vacation', '#EFEFEF', 'Reserved for use to define Scheduled Vacation Time', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 0, 0, 0, 0, 1, 0, 1, 1, 4),
(5, 'Office Visit', '#FFFFCC', 'Normal Office Visit', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 900, 0, 0, 0, 0, 0, 0, 1, 5),
(6, 'Holidays', '#9676DB', 'Clinic holiday', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"1";s:22:"event_repeat_freq_type";s:1:"4";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 86400, 1, 3, 2, 0, 0, 2, 1, 6),
(7, 'Closed', '#2374AB', 'Clinic closed', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"1";s:22:"event_repeat_freq_type";s:1:"4";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 86400, 1, 3, 2, 0, 0, 2, 1, 7),
(8, 'Lunch', '#FFFF33', 'Lunch', 1, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"1";s:22:"event_repeat_freq_type";s:1:"4";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 3600, 0, 3, 2, 0, 0, 1, 1, 8),
(9, 'Established Patient', '#CCFF33', '', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 900, 0, 0, 0, 0, 0, 0, 1, 9),
(10, 'New Patient', '#CCFFFF', '', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 1800, 0, 0, 0, 0, 0, 0, 1, 10),
(11, 'Reserved', '#FF7777', 'Reserved', 1, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"1";s:22:"event_repeat_freq_type";s:1:"4";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 900, 0, 3, 2, 0, 0, 1, 1, 11),
(12, 'Health and Behavioral Assessment', '#C7C7C7', 'Health and Behavioral Assessment', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 900, 0, 0, 0, 0, 0, 0, 1, 12),
(13, 'Preventive Care Services', '#CCCCFF', 'Preventive Care Services', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 900, 0, 0, 0, 0, 0, 0, 1, 13),
(14, 'Ophthalmological Services', '#F89219', 'Ophthalmological Services', 0, NULL, 'a:5:{s:17:"event_repeat_freq";s:1:"0";s:22:"event_repeat_freq_type";s:1:"0";s:19:"event_repeat_on_num";s:1:"1";s:19:"event_repeat_on_day";s:1:"0";s:20:"event_repeat_on_freq";s:1:"0";}', 0, 900, 0, 0, 0, 0, 0, 0, 1, 14);

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_postcalendar_events`
--

CREATE TABLE `libreehr_postcalendar_events` (
  `pc_eid` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `pc_catid` int(11) NOT NULL DEFAULT '0',
  `pc_multiple` int(10) unsigned NOT NULL,
  `pc_aid` varchar(30) DEFAULT NULL,
  `pc_pid` varchar(11) DEFAULT NULL,
  `pc_title` varchar(150) DEFAULT NULL,
  `pc_time` datetime DEFAULT NULL,
  `pc_hometext` text,
  `pc_comments` int(11) DEFAULT '0',
  `pc_counter` mediumint(8) unsigned DEFAULT '0',
  `pc_topic` int(3) NOT NULL DEFAULT '1',
  `pc_informant` varchar(20) DEFAULT NULL,
  `pc_eventDate` date NOT NULL DEFAULT '0000-00-00',
  `pc_endDate` date NOT NULL DEFAULT '0000-00-00',
  `pc_duration` bigint(20) NOT NULL DEFAULT '0',
  `pc_recurrtype` int(1) NOT NULL DEFAULT '0',
  `pc_recurrspec` text,
  `pc_recurrfreq` int(3) NOT NULL DEFAULT '0',
  `pc_startTime` time DEFAULT NULL,
  `pc_endTime` time DEFAULT NULL,
  `pc_alldayevent` int(1) NOT NULL DEFAULT '0',
  `pc_location` text,
  `pc_conttel` varchar(50) DEFAULT NULL,
  `pc_contname` varchar(50) DEFAULT NULL,
  `pc_contemail` varchar(255) DEFAULT NULL,
  `pc_website` varchar(255) DEFAULT NULL,
  `pc_fee` varchar(50) DEFAULT NULL,
  `pc_eventstatus` int(11) NOT NULL DEFAULT '0',
  `pc_sharing` int(11) NOT NULL DEFAULT '0',
  `pc_language` varchar(30) DEFAULT NULL,
  `pc_apptstatus` varchar(15) NOT NULL DEFAULT '-',
  `pc_prefcatid` int(11) NOT NULL DEFAULT '0',
  `pc_facility` smallint(6) NOT NULL DEFAULT '0' COMMENT 'facility id for this event',
  `pc_sendalertsms` varchar(3) NOT NULL DEFAULT 'NO',
  `pc_sendalertemail` varchar(3) NOT NULL DEFAULT 'NO',
  `pc_billing_location` smallint(6) NOT NULL DEFAULT '0',
  `pc_room` varchar(20) NOT NULL DEFAULT '',
  PRIMARY KEY (`pc_eid`),
  KEY `basic_event` (`pc_catid`,`pc_aid`,`pc_eventDate`,`pc_endDate`,`pc_eventstatus`,`pc_sharing`,`pc_topic`),
  KEY `pc_eventDate` (`pc_eventDate`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=7 ;

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_postcalendar_limits`
--

CREATE TABLE `libreehr_postcalendar_limits` (
  `pc_limitid` int(11) NOT NULL AUTO_INCREMENT,
  `pc_catid` int(11) NOT NULL DEFAULT '0',
  `pc_starttime` time NOT NULL DEFAULT '00:00:00',
  `pc_endtime` time NOT NULL DEFAULT '00:00:00',
  `pc_limit` int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (`pc_limitid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_postcalendar_topics`
--

CREATE TABLE `libreehr_postcalendar_topics` (
  `pc_catid` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `pc_catname` varchar(100) DEFAULT NULL,
  `pc_catcolor` varchar(50) DEFAULT NULL,
  `pc_catdesc` text,
  PRIMARY KEY (`pc_catid`),
  KEY `basic_cat` (`pc_catname`,`pc_catcolor`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `libreehr_session_info`
--

CREATE TABLE `libreehr_session_info` (
  `pn_sessid` varchar(32) NOT NULL DEFAULT '',
  `pn_ipaddr` varchar(20) DEFAULT NULL,
  `pn_firstused` int(11) NOT NULL DEFAULT '0',
  `pn_lastused` int(11) NOT NULL DEFAULT '0',
  `pn_uid` int(11) NOT NULL DEFAULT '0',
  `pn_vars` blob,
  PRIMARY KEY (`pn_sessid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `lists`
--

CREATE TABLE `lists` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `type` varchar(255) DEFAULT NULL,
  `subtype` varchar(31) NOT NULL DEFAULT '',
  `title` varchar(255) DEFAULT NULL,
  `begdate` date DEFAULT NULL,
  `enddate` date DEFAULT NULL,
  `returndate` date DEFAULT NULL,
  `occurrence` int(11) DEFAULT '0',
  `classification` int(11) DEFAULT '0',
  `referredby` varchar(255) DEFAULT NULL,
  `extrainfo` varchar(255) DEFAULT NULL,
  `diagnosis` varchar(255) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `comments` longtext,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `outcome` int(11) NOT NULL DEFAULT '0',
  `destination` varchar(255) DEFAULT NULL,
  `reinjury_id` bigint(20) NOT NULL DEFAULT '0',
  `injury_part` varchar(31) NOT NULL DEFAULT '',
  `injury_type` varchar(31) NOT NULL DEFAULT '',
  `injury_grade` varchar(31) NOT NULL DEFAULT '',
  `reaction` varchar(255) NOT NULL DEFAULT '',
  `external_allergyid` int(11) DEFAULT NULL,
  `erx_source` enum('0','1') NOT NULL DEFAULT '0' COMMENT '0-LibreEHR 1-External',
  `erx_uploaded` enum('0','1') NOT NULL DEFAULT '0' COMMENT '0-Pending NewCrop upload 1-Uploaded TO NewCrop',
  `modifydate` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `severity_al` varchar(50) DEFAULT NULL,
  `external_id` varchar(20) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`),
  KEY `type` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `lists_touch`
--

CREATE TABLE `lists_touch` (
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `type` varchar(255) NOT NULL DEFAULT '',
  `date` datetime DEFAULT NULL,
  PRIMARY KEY (`pid`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `list_options`
--

CREATE TABLE `list_options` (
  `list_id` varchar(31) NOT NULL DEFAULT '',
  `option_id` varchar(31) NOT NULL DEFAULT '',
  `title` varchar(255) NOT NULL DEFAULT '',
  `seq` int(11) NOT NULL DEFAULT '0',
  `is_default` tinyint(1) NOT NULL DEFAULT '0',
  `option_value` float NOT NULL DEFAULT '0',
  `mapping` varchar(31) NOT NULL DEFAULT '',
  `notes` varchar(255) NOT NULL DEFAULT '',
  `codes` varchar(255) NOT NULL DEFAULT '',
  `toggle_setting_1` tinyint(1) NOT NULL DEFAULT '0',
  `toggle_setting_2` tinyint(1) NOT NULL DEFAULT '0',
  `activity` tinyint(4) NOT NULL DEFAULT '1',
  `subtype` varchar(31) NOT NULL DEFAULT '',
  PRIMARY KEY (`list_id`,`option_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `list_options`
--

INSERT INTO `list_options` VALUES
('abook_type', 'ccda', 'Care Coordination', 35, 0, 2, '', '', '', 0, 0, 1, ''),
('abook_type', 'dist', 'Distributor', 30, 0, 3, '', '', '', 0, 0, 1, ''),
('abook_type', 'emr_direct', 'EMR Direct', 105, 0, 4, '', '', '', 0, 0, 1, ''),
('abook_type', 'external_org', 'External Organization', 120, 0, 1, '', '', '', 0, 0, 1, ''),
('abook_type', 'external_provider', 'External Provider', 110, 0, 1, '', '', '', 0, 0, 1, ''),
('abook_type', 'ord_img', 'Imaging Service', 5, 0, 3, '', '', '', 0, 0, 1, ''),
('abook_type', 'ord_imm', 'Immunization Service', 10, 0, 3, '', '', '', 0, 0, 1, ''),
('abook_type', 'ord_lab', 'Lab Service', 15, 0, 3, '', '', '', 0, 0, 1, ''),
('abook_type', 'oth', 'Other', 95, 0, 1, '', '', '', 0, 0, 1, ''),
('abook_type', 'spe', 'Specialist', 20, 0, 2, '', '', '', 0, 0, 1, ''),
('abook_type', 'vendor', 'Vendor', 25, 0, 3, '', '', '', 0, 0, 1, ''),
('ACLT_Tag_Colors', 'blue', 'Blue', 0, 1, 0, '', '#90caf9', '', 0, 0, 0, ''),
('ACLT_Tag_Colors', 'green', 'Green', 0, 0, 0, '', '#a5d6a7', '', 0, 0, 0, ''),
('ACLT_Tag_Colors', 'orange', 'Orange', 0, 0, 0, '', '#ffb74d', '', 0, 0, 0, ''),
('ACLT_Tag_Colors', 'purple', 'Purple', 0, 0, 0, '', '#b39ddb', '', 0, 0, 0, ''),
('ACLT_Tag_Colors', 'red', 'Red', 0, 0, 0, '', '#e57373', '', 0, 0, 0, ''),
('ACLT_Tag_Colors', 'yellow', 'Yellow', 0, 0, 0, '', '#fff59d', '', 0, 0, 0, ''),
('ACLT_Tag_Status', 'active', 'Active', 0, 1, 0, '', '', '', 0, 0, 0, ''),
('ACLT_Tag_Status', 'deleted', 'Deleted', 0, 0, 0, '', '', '', 0, 0, 0, ''),
('ACLT_Tag_Status', 'suspended', 'Suspended', 0, 0, 0, '', '', '', 0, 0, 0, ''),
('adjreason', 'Adm adjust', 'Adm adjust', 5, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'After hrs calls', 'After hrs calls', 10, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Bad check', 'Bad check', 15, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Bad debt', 'Bad debt', 20, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Coll w/o', 'Coll w/o', 25, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Discount', 'Discount', 30, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Hardship w/o', 'Hardship w/o', 35, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Ins adjust', 'Ins adjust', 40, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Ins bundling', 'Ins bundling', 45, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Ins overpaid', 'Ins overpaid', 50, 0, 5, '', '', '', 0, 0, 1, ''),
('adjreason', 'Ins refund', 'Ins refund', 55, 0, 5, '', '', '', 0, 0, 1, ''),
('adjreason', 'Pt overpaid', 'Pt overpaid', 60, 0, 5, '', '', '', 0, 0, 1, ''),
('adjreason', 'Pt refund', 'Pt refund', 65, 0, 5, '', '', '', 0, 0, 1, ''),
('adjreason', 'Pt released', 'Pt released', 70, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'Sm debt w/o', 'Sm debt w/o', 75, 0, 1, '', '', '', 0, 0, 1, ''),
('adjreason', 'To copay', 'To copay', 80, 0, 2, '', '', '', 0, 0, 1, ''),
('adjreason', 'To ded''ble', 'To ded''ble', 85, 0, 3, '', '', '', 0, 0, 1, ''),
('adjreason', 'Untimely filing', 'Untimely filing', 90, 0, 1, '', '', '', 0, 0, 1, ''),
('allergy_issue_list', 'codeine', 'codeine', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('allergy_issue_list', 'iodine', 'iodine', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('allergy_issue_list', 'penicillin', 'penicillin', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('allergy_issue_list', 'sulfa', 'sulfa', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('amendment_from', 'insurance', 'Insurance', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('amendment_from', 'patient', 'Patient', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('amendment_status', 'approved', 'Approved', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('amendment_status', 'rejected', 'Rejected', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('apptstat', '!', '! Left w/o visit', 40, 0, 0, '', '0BBA34|0', '', 0, 1, 1, ''),
('apptstat', '#', '# Ins/fin issue', 45, 0, 0, '', 'FFFF2B|0', '', 0, 0, 1, ''),
('apptstat', '$', '$ Coding done', 60, 0, 0, '', 'C0FF96|0', '', 0, 0, 1, ''),
('apptstat', '%', '% Canceled < 24h', 65, 0, 0, '', 'BFBFBF|0', '', 0, 0, 1, ''),
('apptstat', '&', '& Rescheduled < 24h', 80, 0, 0, '', 'BFBFBF|0', '', 0, 0, 1, ''),
('apptstat', '*', '* Reminder done', 10, 0, 0, '', 'FFC9F8|0', '', 0, 0, 1, ''),
('apptstat', '+', '+ Chart pulled', 15, 0, 0, '', '87FF1F|0', '', 0, 0, 1, ''),
('apptstat', '-', '- None', 5, 0, 0, '', 'FEFDCF|0', '', 0, 0, 1, ''),
('apptstat', '<', '< In exam room', 50, 0, 0, '', '52D9DE|10', '', 0, 0, 1, ''),
('apptstat', '=', '= Rescheduled', 75, 0, 0, '', 'BFBFBF|0', '', 0, 0, 1, ''),
('apptstat', '>', '> Checked out', 55, 0, 0, '', 'FEFDCF|0', '', 0, 1, 1, ''),
('apptstat', '?', '? No show', 25, 0, 0, '', 'BFBFBF|0', '', 0, 0, 1, ''),
('apptstat', '@', '@ Arrived', 30, 0, 0, '', 'FF2414|10', '', 1, 0, 1, ''),
('apptstat', 'x', 'x Canceled', 20, 0, 0, '', 'BFBFBF|0', '', 0, 0, 1, ''),
('apptstat', '^', '^ Pending from Portal', 70, 0, 0, '', 'ADBBFF|0', '', 0, 0, 1, ''),
('apptstat', '~', '~ Arrived late', 35, 0, 0, '', 'FF6619|10', '', 1, 0, 1, ''),
('boolean', '0', 'No', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('boolean', '1', 'Yes', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('chartloc', 'fileroom', 'File Room', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'back_pain_plan_cqm', 'Back Pain', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'cabg_plan_cqm', 'Coronary Artery Bypass Graft (CABG)', 35, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'ckd_plan_cqm', 'Chronic Kidney Disease (CKD)', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'dm_plan', 'Diabetes Mellitus', 500, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'dm_plan_cqm', 'Diabetes Mellitus', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'periop_plan_cqm', 'Perioperative Care', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'prevent_plan', 'Preventative Care', 510, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'prevent_plan_cqm', 'Preventative Care', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_plans', 'rheum_arth_plan_cqm', 'Rheumatoid Arthritis', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'cpoe_med_amc', 'Use CPOE for medication orders directly entered by any licensed healthcare professional who can enter orders into the medical record per state, local and professional guidelines.', 45, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'cpoe_med_stage2_amc', 'Use CPOE for medication orders.(Alternative)', 47, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'cpoe_proc_orders_amc', 'Use CPOE for procedure orders.', 47, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'cpoe_radiology_amc', 'Use CPOE for radiology orders.', 46, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'electronic_notes_amc', 'Electronic Notes', 3200, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'e_prescribe_1_stage2_amc', 'Generate and transmit permissible prescriptions electronically (All Prescriptions).', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'e_prescribe_2_stage2_amc', 'Generate and transmit permissible prescriptions electronically (Not including controlled substances).', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'e_prescribe_amc', 'Generate and transmit permissible prescriptions electronically.', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'e_prescribe_stage1_amc', 'Generate and transmit permissible prescriptions electronically (Not including controlled substances).', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'family_health_history_amc', 'Family Health History', 3100, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'image_results_amc', 'Image Results', 3000, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'lab_result_amc', 'Incorporate clinical lab-test results into certified EHR technology as structured data.', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'med_allergy_list_amc', 'Maintain active medication allergy list.', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'med_list_amc', 'Maintain active medication list.', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'med_reconc_amc', 'The EP, eligible hospital or CAH who receives a patient from another setting of care or provider of care or believes an encounter is relevant should perform medication reconciliation.', 35, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'patient_edu_amc', 'Use certified EHR technology to identify patient-specific education resources and provide those resources to the patient if appropriate.', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'patient_edu_stage2_amc', 'Use certified EHR technology to identify patient-specific education resources and provide those resources to the patient if appropriate(New).', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'problem_list_amc', 'Maintain an up-to-date problem list of current and active diagnoses.', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'provide_rec_pat_amc', 'Provide patients with an electronic copy of their health information (including diagnostic test results, problem list, medication lists, medication allergies), upon request.', 65, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'provide_sum_pat_amc', 'Provide clinical summaries for patients for each office visit.', 75, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'provide_sum_pat_stage2_amc', 'Provide clinical summaries for patients for each office visit (New).', 75, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_dem_amc', 'Record demographics.', 55, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_smoke_amc', 'Record smoking status for patients 13 years old or older.', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_vitals_1_stage1_amc', 'Record and chart changes in vital signs (SET 1).', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_vitals_2_stage1_amc', 'Record and chart changes in vital signs (BP out of scope).', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_vitals_3_stage1_amc', 'Record and chart changes in vital signs (Height / Weight out of scope).', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_vitals_4_stage1_amc', 'Record and chart changes in vital signs ( Height / Weight / BP with in scope ).', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_vitals_amc', 'Record and chart changes in vital signs.', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'record_vitals_stage2_amc', 'Record and chart changes in vital signs (New).', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_adult_wt_screen_fu', 'Adult Weight Screening and Follow-Up', 530, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_adult_wt_screen_fu_cqm', 'Adult Weight Screening and Follow-Up (CQM)', 220, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_appt_reminder', 'Appointment Reminder Rule', 2000, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_blood_pressure', 'Measure Blood Pressure', 1610, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_children_pharyngitis_cqm', 'Appropriate Testing for Children with Pharyngitis (CQM)', 502, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_child_immun_stat_2014_cqm', 'Childhood immunization Status (CQM)', 250, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_child_immun_stat_cqm', 'Childhood immunization Status (CQM)', 250, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_cs_colon', 'Cancer Screening: Colon Cancer Screening', 640, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_cs_mammo', 'Cancer Screening: Mammogram', 620, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_cs_pap', 'Cancer Screening: Pap Smear', 630, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_cs_prostate', 'Cancer Screening: Prostate Cancer Screening', 650, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_a1c_cqm', 'Diabetes: HbA1c Poor Control (CQM)', 285, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_bp_control_cqm', 'Diabetes: Blood Pressure Management (CQM)', 290, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_eye', 'Diabetes: Eye Exam', 600, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_eye_cqm', 'Diabetes: Eye Exam (CQM)', 270, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_foot', 'Diabetes: Foot Exam', 610, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_foot_cqm', 'Diabetes: Foot Exam (CQM)', 280, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_hemo_a1c', 'Diabetes: Hemoglobin A1C', 570, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_ldl_cqm', 'Diabetes: LDL Management & Control (CQM)', 300, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_dm_urine_alb', 'Diabetes: Urine Microalbumin', 590, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_fall_screening_cqm', 'Falls: Screening, Risk-Assessment, and Plan of Care to Prevent Future Falls (CQM)', 504, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_htn_bp_measure', 'Hypertension: Blood Pressure Measurement', 500, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_htn_bp_measure_cqm', 'Hypertension: Blood Pressure Measurement (CQM)', 200, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_influenza_ge_50', 'Influenza Immunization for Patients >= 50 Years Old', 550, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_influenza_ge_50_cqm', 'Influenza Immunization for Patients >= 50 Years Old (CQM)', 240, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_inr_measure', 'Measure INR', 1620, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_inr_monitor', 'Coumadin Management - INR Monitoring', 1000, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_pain_intensity_cqm', 'Oncology: Medical and Radiation â€“ Pain Intensity Quantified (CQM)', 506, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_penicillin_allergy', 'Assess Penicillin Allergy', 1600, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_pneumovacc_ge_65', 'Pneumonia Vaccination Status for Older Adults', 570, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_pneumovacc_ge_65_cqm', 'Pneumonia Vaccination Status for Older Adults (CQM)', 260, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_socsec_entry', 'Data Entry - Social Security Number', 1500, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_tob_cess_inter', 'Tobacco Cessation Intervention', 520, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_tob_cess_inter_cqm', 'Tobacco Cessation Intervention (CQM)', 210, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_tob_use_2014_cqm', 'Preventive Care and Screening: Tobacco Use: Screening and Cessation Intervention (CQM)', 210, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_tob_use_assess', 'Tobacco Use Assessment', 510, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_tob_use_assess_cqm', 'Tobacco Use Assessment (CQM)', 205, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_wt_assess_couns_child', 'Weight Assessment and Counseling for Children and Adolescents', 540, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'rule_wt_assess_couns_child_cqm', 'Weight Assessment and Counseling for Children and Adolescents (CQM)', 230, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'secure_messaging_amc', 'Secure Electronic Messaging', 3400, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'send_reminder_amc', 'Send reminders to patients per patient preference for preventive/follow up care.', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'send_reminder_stage2_amc', 'Send reminders to patients per patient preference for preventive/follow up care.', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'send_sum_1_stage2_amc', 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral (Measure A).', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'send_sum_amc', 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral.', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'send_sum_stage1_amc', 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral.', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'send_sum_stage2_amc', 'The EP, eligible hospital or CAH who transitions their patient to another setting of care or provider of care or refers their patient to another provider of care should provide summary of care record for each transition of care or referral (Measure B).', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'timely_access_amc', 'Provide patients with timely electronic access to their health information (including lab results, problem list, medication lists, medication allergies) within four business days of the information being available to the EP.', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'vdt_stage2_amc', 'View, Download, Transmit (VDT) (Measure A)', 3500, 0, 0, '', '', '', 0, 0, 1, ''),
('clinical_rules', 'view_download_transmit_amc', 'View, Download, Transmit (VDT)  (Measure B)', 3500, 0, 0, '', '', '', 0, 0, 1, ''),
('country', 'USA', 'USA', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('county', 'adair', 'ADAIR', 10, 0, 0, '', '001', '', 0, 0, 1, ''),
('county', 'andrew', 'ANDREW', 20, 0, 0, '', '003', '', 0, 0, 1, ''),
('county', 'atchison', 'ATCHISON', 30, 0, 0, '', '005', '', 0, 0, 1, ''),
('county', 'audrain', 'AUDRAIN', 40, 0, 0, '', '007', '', 0, 0, 1, ''),
('county', 'barry', 'BARRY', 50, 0, 0, '', '009', '', 0, 0, 1, ''),
('date_master_criteria', 'all', 'All', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'custom', 'Custom', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'last_calendar_year', 'Last Calendar Year', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'last_month', 'Last Month', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'this_calendar_year', 'This Calendar Year', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'this_month_to_date', 'This Month to Date', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'this_week_to_date', 'This Week to Date', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('date_master_criteria', 'today', 'Today', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('disclosure_type', 'disclosure-healthcareoperations', 'Health Care Operations', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('disclosure_type', 'disclosure-payment', 'Payment', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('disclosure_type', 'disclosure-treatment', 'Treatment', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_form', '0', '', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_form', '1', 'suspension', 1, 0, 0, '', '', 'NCI-CONCEPT-ID:C60928', 0, 0, 1, ''),
('drug_form', '10', 'cream', 10, 0, 0, '', '', 'NCI-CONCEPT-ID:C28944', 0, 0, 1, ''),
('drug_form', '11', 'ointment', 11, 0, 0, '', '', 'NCI-CONCEPT-ID:C42966', 0, 0, 1, ''),
('drug_form', '12', 'puff', 12, 0, 0, '', '', 'NCI-CONCEPT-ID:C42944', 0, 0, 1, ''),
('drug_form', '2', 'tablet', 2, 0, 0, '', '', 'NCI-CONCEPT-ID:C42998', 0, 0, 1, ''),
('drug_form', '3', 'capsule', 3, 0, 0, '', '', 'NCI-CONCEPT-ID:C25158', 0, 0, 1, ''),
('drug_form', '4', 'solution', 4, 0, 0, '', '', 'NCI-CONCEPT-ID:C42986', 0, 0, 1, ''),
('drug_form', '5', 'tsp', 5, 0, 0, '', '', 'NCI-CONCEPT-ID:C48544', 0, 0, 1, ''),
('drug_form', '6', 'ml', 6, 0, 0, '', '', 'NCI-CONCEPT-ID:C28254', 0, 0, 1, ''),
('drug_form', '7', 'units', 7, 0, 0, '', '', 'NCI-CONCEPT-ID:C44278', 0, 0, 1, ''),
('drug_form', '8', 'inhalations', 8, 0, 0, '', '', 'NCI-CONCEPT-ID:C42944', 0, 0, 1, ''),
('drug_form', '9', 'gtts(drops)', 9, 0, 0, '', '', 'NCI-CONCEPT-ID:C48491', 0, 0, 1, ''),
('drug_interval', '0', '', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '1', 'b.i.d.', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '10', 'a.c.', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '11', 'p.c.', 11, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '12', 'a.m.', 12, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '13', 'p.m.', 13, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '14', 'ante', 14, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '15', 'h', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '16', 'h.s.', 16, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '17', 'p.r.n.', 17, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '18', 'stat', 18, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '2', 't.i.d.', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '3', 'q.i.d.', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '4', 'q.3h', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '5', 'q.4h', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '6', 'q.5h', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '7', 'q.6h', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '8', 'q.8h', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_interval', '9', 'q.d.', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_route', '0', '', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_route', '1', 'Per Oris', 1, 0, 0, '', 'PO', 'NCI-CONCEPT-ID:C38288', 0, 0, 1, ''),
('drug_route', '10', 'IM', 10, 0, 0, '', 'IM', '', 0, 0, 1, ''),
('drug_route', '11', 'IV', 11, 0, 0, '', 'IV', '', 0, 0, 1, ''),
('drug_route', '12', 'Per Nostril', 12, 0, 0, '', 'NS', '', 0, 0, 1, ''),
('drug_route', '13', 'Both Ears', 13, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '14', 'Left Ear', 14, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '15', 'Right Ear', 15, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '2', 'Per Rectum', 2, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '3', 'To Skin', 3, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '4', 'To Affected Area', 4, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '5', 'Sublingual', 5, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '6', 'OS', 6, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '7', 'OD', 7, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '8', 'OU', 8, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', '9', 'SQ', 9, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', 'inhale', 'Inhale', 16, 0, 0, '', 'RESPIR', 'NCI-CONCEPT-ID:C38216', 0, 0, 1, ''),
('drug_route', 'intradermal', 'Intradermal', 16, 0, 0, '', 'ID', '', 0, 0, 1, ''),
('drug_route', 'intramuscular', 'Intramuscular', 20, 0, 0, '', 'IM', 'NCI-CONCEPT-ID:C28161', 0, 0, 1, ''),
('drug_route', 'other', 'Other/Miscellaneous', 18, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('drug_route', 'transdermal', 'Transdermal', 19, 0, 0, '', 'TD', '', 0, 0, 1, ''),
('drug_units', '0', '', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '1', 'mg', 1, 0, 0, '', '', 'NCI-CONCEPT-ID:C28253', 0, 0, 1, ''),
('drug_units', '2', 'mg/1cc', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '3', 'mg/2cc', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '4', 'mg/3cc', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '5', 'mg/4cc', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '6', 'mg/5cc', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '7', 'mcg', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '8', 'grams', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('drug_units', '9', 'mL', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('eligibility', 'eligible', 'Eligible', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('eligibility', 'ineligible', 'Ineligible', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('ethnicity', 'declne_to_specfy', 'Declined To Specify', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('ethnicity', 'hisp_or_latin', 'Hispanic or Latino', 10, 0, 0, '', '2135-2', '', 0, 0, 1, ''),
('ethnicity', 'not_hisp_or_latin', 'Not Hispanic or Latino', 10, 0, 0, '', '2186-5', '', 0, 0, 1, ''),
('ethrace', 'aleut', 'ALEUT', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'amer_indian', 'American Indian', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'Asian', 'Asian', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'Black', 'Black', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'cambodian', 'Cambodian', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'Caucasian', 'Caucasian', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'chinese', 'Chinese', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'cs_american', 'Central/South American', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'cuban', 'Cuban', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'declne_to_specfy', 'Declined To Specify', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'eskimo', 'Eskimo', 100, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'filipino', 'Filipino', 110, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'guamanian', 'Guamanian', 120, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'hawaiian', 'Hawaiian', 130, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'Hispanic', 'Hispanic', 140, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'hmong', 'Hmong', 170, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'indian', 'Indian', 180, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'japanese', 'Japanese', 190, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'korean', 'Korean', 200, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'laotian', 'Laotian', 210, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'mexican', 'Mexican/MexAmer/Chicano', 220, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'mlt-race', 'Multiracial', 230, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'othr', 'Other', 240, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'othr_non_us', 'Hispanic - Other (Born outside US)', 160, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'othr_spec', 'Other - Specified', 250, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'othr_us', 'Hispanic - Other (Born in US)', 150, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'pac_island', 'Pacific Islander', 260, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'puerto_rican', 'Puerto Rican', 270, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'refused', 'Refused To State', 280, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'samoan', 'Samoan', 290, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'spec', 'Specified', 300, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'thai', 'Thai', 310, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'unknown', 'Unknown', 320, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'unspec', 'Unspecified', 330, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'vietnamese', 'Vietnamese', 340, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'white', 'White', 350, 0, 0, '', '', '', 0, 0, 1, ''),
('ethrace', 'withheld', 'Withheld', 360, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'brs', 'Breast Exam', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'cec', 'Cardiac Echo', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'ecg', 'ECG', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'flu', 'Flu Vaccination', 11, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'gyn', 'Gynecological Exam', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'hem', 'Hemoglobin', 14, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'ldl', 'LDL', 13, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'mam', 'Mammogram', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'phy', 'Physical Exam', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'pne', 'Pneumonia Vaccination', 12, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'pro', 'Prostate Exam', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'psa', 'PSA', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'rec', 'Rectal Exam', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'ret', 'Retinal Exam', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('exams', 'sic', 'Sigmoid/Colonoscopy', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Chiropractic', 'Chiropractic', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Fitness Testing', 'Fitness Testing', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Nutritional', 'Nutritional', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Osteopathy', 'Osteopathy', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Podiatry', 'Podiatry', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Pre Participation Assessment', 'Pre Participation Assessment', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Prevention Rehab', 'Prevention Rehab', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Screening / Testing', 'Screening / Testing', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('general_issue_list', 'Strength and Conditioning', 'Strength and Conditioning', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '1', 'DTaP 1', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '10', 'DT 5', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '11', 'IPV 1', 110, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '12', 'IPV 2', 115, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '13', 'IPV 3', 120, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '14', 'IPV 4', 125, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '15', 'Hib 1', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '16', 'Hib 2', 85, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '17', 'Hib 3', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '18', 'Hib 4', 95, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '19', 'Pneumococcal Conjugate 1', 140, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '2', 'DTaP 2', 35, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '20', 'Pneumococcal Conjugate 2', 145, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '21', 'Pneumococcal Conjugate 3', 150, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '22', 'Pneumococcal Conjugate 4', 155, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '23', 'MMR 1', 130, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '24', 'MMR 2', 135, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '25', 'Varicella 1', 165, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '26', 'Varicella 2', 170, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '27', 'Hepatitis B 1', 65, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '28', 'Hepatitis B 2', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '29', 'Hepatitis B 3', 75, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '3', 'DTaP 3', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '30', 'Influenza 1', 100, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '31', 'Influenza 2', 105, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '32', 'Td', 160, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '33', 'Hepatitis A 1', 55, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '34', 'Hepatitis A 2', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '35', 'Other', 175, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '4', 'DTaP 4', 45, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '5', 'DTaP 5', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '6', 'DT 1', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '7', 'DT 2', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '8', 'DT 3', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('immunizations', '9', 'DT 4', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('Immunization_Completion_Status', 'Completed', 'completed', 10, 0, 0, '', 'CP', '', 0, 0, 1, ''),
('Immunization_Completion_Status', 'Not_Administered', 'Not Administered', 30, 0, 0, '', 'NA', '', 0, 0, 1, ''),
('Immunization_Completion_Status', 'Partially_Administered', 'Partially Administered', 40, 0, 0, '', 'PA', '', 0, 0, 1, ''),
('Immunization_Completion_Status', 'Refused', 'Refused', 20, 0, 0, '', 'RE', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'AB', 'Abbott Laboratories', 10, 0, 0, '', 'AB', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'ACA', 'Acambis, Inc', 20, 0, 0, '', 'ACA', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'AD', 'Adams Laboratories, Inc.', 30, 0, 0, '', 'AD', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'AKR', 'Akorn, Inc', 40, 0, 0, '', 'AKR', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'ALP', 'Alpha Therapeutic Corporation', 50, 0, 0, '', 'ALP', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'AR', 'Armour', 60, 0, 0, '', 'AR', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'AVB', 'Aventis Behring L.L.C.', 70, 0, 0, '', 'AVB', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'AVI', 'Aviron', 80, 0, 0, '', 'AVI', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BA', 'Baxter Healthcare Corporation-inactive', 110, 0, 0, '', 'BA', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BAH', 'Baxter Healthcare Corporation', 100, 0, 0, '', 'BAH', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BAY', 'Bayer Corporation', 120, 0, 0, '', 'BAY', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BP', 'Berna Products', 130, 0, 0, '', 'BP', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BPC', 'Berna Products Corporation', 140, 0, 0, '', 'BPC', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BRR', 'Barr Laboratories', 90, 0, 0, '', 'BRR', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'BTP', 'Biotest Pharmaceuticals Corporation', 150, 0, 0, '', 'BTP', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CEN', 'Centeon L.L.C.', 180, 0, 0, '', 'CEN', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CHI', 'Chiron Corporation', 190, 0, 0, '', 'CHI', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CMP', 'Celltech Medeva Pharmaceuticals', 170, 0, 0, '', 'CMP', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CNJ', 'Cangene Corporation', 160, 0, 0, '', 'CNJ', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CON', 'Connaught', 200, 0, 0, '', 'CON', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CRU', 'Crucell', 210, 0, 0, '', 'CRU', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'CSL', 'CSL Behring, Inc', 220, 0, 0, '', 'CSL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'DVC', 'DynPort Vaccine Company, LLC', 230, 0, 0, '', 'DVC', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'EVN', 'Evans Medical Limited', 250, 0, 0, '', 'EVN', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'GEO', 'GeoVax Labs, Inc.', 260, 0, 0, '', 'GEO', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'GRE', 'Greer Laboratories, Inc.', 280, 0, 0, '', 'GRE', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'GRF', 'Grifols', 290, 0, 0, '', 'GRF', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'IAG', 'Immuno International AG', 310, 0, 0, '', 'IAG', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'IDB', 'ID Biomedical', 300, 0, 0, '', 'IDB', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'IM', 'Merieux', 410, 0, 0, '', 'IM', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'INT', 'Intercell Biomedical', 330, 0, 0, '', 'INT', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'IUS', 'Immuno-U.S., Inc.', 320, 0, 0, '', 'IUS', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'JNJ', 'Johnson and Johnson', 340, 0, 0, '', 'JNJ', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'JPN', 'The Research Foundation for Microbial Diseases of Osaka University (BIKEN)', 610, 0, 0, '', 'JPN', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'KGC', 'Korea Green Cross Corporation', 350, 0, 0, '', 'KGC', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'LED', 'Lederle', 360, 0, 0, '', 'LED', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'MA', 'Massachusetts Public Health Biologic Laboratories', 380, 0, 0, '', 'MA', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'MBL', 'Massachusetts Biologic Laboratories', 370, 0, 0, '', 'MBL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'MED', 'MedImmune, Inc.', 390, 0, 0, '', 'MED', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'MIL', 'Miles', 420, 0, 0, '', 'MIL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'MIP', 'Emergent BioDefense Operations Lansing', 240, 0, 0, '', 'MIP', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'MSD', 'Merck and Co., Inc.', 400, 0, 0, '', 'MSD', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'NAB', 'NABI', 430, 0, 0, '', 'NAB', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'NAV', 'North American Vaccine, Inc.', 450, 0, 0, '', 'NAV', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'NOV', 'Novartis Pharmaceutical Corporation', 460, 0, 0, '', 'NOV', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'NVX', 'Novavax, Inc.', 470, 0, 0, '', 'NVX', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'NYB', 'New York Blood Center', 440, 0, 0, '', 'NYB', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'ORT', 'Ortho-clinical Diagnostics', 490, 0, 0, '', 'ORT', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'OTC', 'Organon Teknika Corporation', 480, 0, 0, '', 'OTC', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'OTH', 'Other manufacturer', 500, 0, 0, '', 'OTH', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'PD', 'Parkedale Pharmaceuticals', 510, 0, 0, '', 'PD', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'PFR', 'Pfizer, Inc', 520, 0, 0, '', 'PFR', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'PMC', 'sanofi pasteur', 560, 0, 0, '', 'PMC', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'PRX', 'Praxis Biologics', 540, 0, 0, '', 'PRX', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'PSC', 'Protein Sciences', 550, 0, 0, '', 'PSC', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'PWJ', 'PowderJect Pharmaceuticals', 530, 0, 0, '', 'PWJ', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'SCL', 'Sclavo, Inc.', 570, 0, 0, '', 'SCL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'SI', 'Swiss Serum and Vaccine Inst.', 590, 0, 0, '', 'SI', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'SKB', 'GlaxoSmithKline', 270, 0, 0, '', 'SKB', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'SOL', 'Solvay Pharmaceuticals', 580, 0, 0, '', 'SOL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'TAL', 'Talecris Biotherapeutics', 600, 0, 0, '', 'TAL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'UNK', 'Unknown manufacturer', 630, 0, 0, '', 'UNK', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'USA', 'United States Army Medical Research and Material Command', 620, 0, 0, '', 'USA', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'VXG', 'VaxGen', 640, 0, 0, '', 'VXG', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'WA', 'Wyeth-Ayerst', 660, 0, 0, '', 'WA', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'WAL', 'Wyeth', 650, 0, 0, '', 'WAL', '', 0, 0, 1, ''),
('Immunization_Manufacturer', 'ZLB', 'ZLB Behring', 670, 0, 0, '', 'ZLB', '', 0, 0, 1, ''),
('Industry', 'construction_firm', 'Construction Firm', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('Industry', 'engineering_firm', 'Engineering Firm', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('Industry', 'law_firm', 'Law Firm', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('insurance_types', 'primary', 'Primary', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('insurance_types', 'secondary', 'Secondary', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('insurance_types', 'tertiary', 'Tertiary', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('irnpool', 'main', 'Main', 1, 1, 0, '', '000001', '', 0, 0, 1, ''),
('issue_subtypes', 'eye', 'Eye', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('language', 'abkhazian', 'Abkhazian', 10, 0, 0, '', 'abk', '', 0, 0, 1, ''),
('language', 'afar', 'Afar', 20, 0, 0, '', 'aar', '', 0, 0, 1, ''),
('language', 'afrikaans', 'Afrikaans', 30, 0, 0, '', 'afr', '', 0, 0, 1, ''),
('language', 'akan', 'Akan', 40, 0, 0, '', 'aka', '', 0, 0, 1, ''),
('language', 'albanian', 'Albanian', 50, 0, 0, '', 'alb(B)|sqi(T)', '', 0, 0, 1, ''),
('language', 'amharic', 'Amharic', 60, 0, 0, '', 'amh', '', 0, 0, 1, ''),
('language', 'arabic', 'Arabic', 70, 0, 0, '', 'ara', '', 0, 0, 1, ''),
('language', 'aragonese', 'Aragonese', 80, 0, 0, '', 'arg', '', 0, 0, 1, ''),
('language', 'armenian', 'Armenian', 90, 0, 0, '', 'arm(B)|hye(T)', '', 0, 0, 1, ''),
('language', 'assamese', 'Assamese', 100, 0, 0, '', 'asm', '', 0, 0, 1, ''),
('language', 'avaric', 'Avaric', 110, 0, 0, '', 'ava', '', 0, 0, 1, ''),
('language', 'avestan', 'Avestan', 120, 0, 0, '', 'ave', '', 0, 0, 1, ''),
('language', 'aymara', 'Aymara', 130, 0, 0, '', 'aym', '', 0, 0, 1, ''),
('language', 'azerbaijani', 'Azerbaijani', 140, 0, 0, '', 'aze', '', 0, 0, 1, ''),
('language', 'bambara', 'Bambara', 150, 0, 0, '', 'bam', '', 0, 0, 1, ''),
('language', 'bashkir', 'Bashkir', 160, 0, 0, '', 'bak', '', 0, 0, 1, ''),
('language', 'basque', 'Basque', 170, 0, 0, '', 'baq(B)|eus(T)', '', 0, 0, 1, ''),
('language', 'belarusian', 'Belarusian', 180, 0, 0, '', 'bel', '', 0, 0, 1, ''),
('language', 'bengali', 'Bengali', 190, 0, 0, '', 'ben', '', 0, 0, 1, ''),
('language', 'bihari_languages', 'Bihari languages', 200, 0, 0, '', 'bih', '', 0, 0, 1, ''),
('language', 'bislama', 'Bislama', 210, 0, 0, '', 'bis', '', 0, 0, 1, ''),
('language', 'bokmal_norwegian_norwegian_bok', 'BokmÃ¥l, Norwegian; Norwegian BokmÃ¥l', 220, 0, 0, '', 'nob', '', 0, 0, 1, ''),
('language', 'bosnian', 'Bosnian', 230, 0, 0, '', 'bos', '', 0, 0, 1, ''),
('language', 'breton', 'Breton', 240, 0, 0, '', 'bre', '', 0, 0, 1, ''),
('language', 'bulgarian', 'Bulgarian', 250, 0, 0, '', 'bul', '', 0, 0, 1, ''),
('language', 'burmese', 'Burmese', 260, 0, 0, '', 'bur(B)|mya(T)', '', 0, 0, 1, ''),
('language', 'catalan_valencian', 'Catalan; Valencian', 270, 0, 0, '', 'cat', '', 0, 0, 1, ''),
('language', 'central_khmer', 'Central Khmer', 280, 0, 0, '', 'khm', '', 0, 0, 1, ''),
('language', 'chamorro', 'Chamorro', 290, 0, 0, '', 'cha', '', 0, 0, 1, ''),
('language', 'chechen', 'Chechen', 300, 0, 0, '', 'che', '', 0, 0, 1, ''),
('language', 'chichewa_chewa_nyanja', 'Chichewa; Chewa; Nyanja', 310, 0, 0, '', 'nya', '', 0, 0, 1, ''),
('language', 'chinese', 'Chinese', 320, 0, 0, '', 'chi(B)|zho(T)', '', 0, 0, 1, ''),
('language', 'church_slavic_old_slavonic_chu', 'Church Slavic; Old Slavonic; Church Slavonic; Old Bulgarian; Old Church Slavonic', 330, 0, 0, '', 'chu', '', 0, 0, 1, ''),
('language', 'chuvash', 'Chuvash', 340, 0, 0, '', 'chv', '', 0, 0, 1, ''),
('language', 'cornish', 'Cornish', 350, 0, 0, '', 'cor', '', 0, 0, 1, ''),
('language', 'corsican', 'Corsican', 360, 0, 0, '', 'cos', '', 0, 0, 1, ''),
('language', 'cree', 'Cree', 370, 0, 0, '', 'cre', '', 0, 0, 1, ''),
('language', 'croatian', 'Croatian', 380, 0, 0, '', 'hrv', '', 0, 0, 1, ''),
('language', 'czech', 'Czech', 390, 0, 0, '', 'cze(B)|ces(T)', '', 0, 0, 1, ''),
('language', 'danish', 'Danish', 400, 0, 0, '', 'dan', '', 0, 0, 1, ''),
('language', 'declne_to_specfy', 'Declined To Specify', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('language', 'divehi_dhivehi_maldivian', 'Divehi; Dhivehi; Maldivian', 410, 0, 0, '', 'div', '', 0, 0, 1, ''),
('language', 'dutch_flemish', 'Dutch; Flemish', 420, 0, 0, '', 'dut(B)|nld(T)', '', 0, 0, 1, ''),
('language', 'dzongkha', 'Dzongkha', 430, 0, 0, '', 'dzo', '', 0, 0, 1, ''),
('language', 'English', 'English', 440, 0, 0, '', 'eng', '', 0, 0, 1, ''),
('language', 'esperanto', 'Esperanto', 450, 0, 0, '', 'epo', '', 0, 0, 1, ''),
('language', 'estonian', 'Estonian', 460, 0, 0, '', 'est', '', 0, 0, 1, ''),
('language', 'ewe', 'Ewe', 470, 0, 0, '', 'ewe', '', 0, 0, 1, ''),
('language', 'faroese', 'Faroese', 480, 0, 0, '', 'fao', '', 0, 0, 1, ''),
('language', 'fijian', 'Fijian', 490, 0, 0, '', 'fij', '', 0, 0, 1, ''),
('language', 'finnish', 'Finnish', 500, 0, 0, '', 'fin', '', 0, 0, 1, ''),
('language', 'french', 'French', 510, 0, 0, '', 'fre(B)|fra(T)', '', 0, 0, 1, ''),
('language', 'fulah', 'Fulah', 520, 0, 0, '', 'ful', '', 0, 0, 1, ''),
('language', 'gaelic_scottish_gaelic', 'Gaelic; Scottish Gaelic', 530, 0, 0, '', 'gla', '', 0, 0, 1, ''),
('language', 'galician', 'Galician', 540, 0, 0, '', 'glg', '', 0, 0, 1, ''),
('language', 'ganda', 'Ganda', 550, 0, 0, '', 'lug', '', 0, 0, 1, ''),
('language', 'georgian', 'Georgian', 560, 0, 0, '', 'geo(B)|kat(T)', '', 0, 0, 1, ''),
('language', 'german', 'German', 570, 0, 0, '', 'ger(B)|deu(T)', '', 0, 0, 1, ''),
('language', 'greek', 'Greek, Modern (1453-)', 580, 0, 0, '', 'gre(B)|ell(T)', '', 0, 0, 1, ''),
('language', 'guarani', 'Guarani', 590, 0, 0, '', 'grn', '', 0, 0, 1, ''),
('language', 'gujarati', 'Gujarati', 600, 0, 0, '', 'guj', '', 0, 0, 1, ''),
('language', 'haitian_haitian_creole', 'Haitian; Haitian Creole', 610, 0, 0, '', 'hat', '', 0, 0, 1, ''),
('language', 'hausa', 'Hausa', 620, 0, 0, '', 'hau', '', 0, 0, 1, ''),
('language', 'hebrew', 'Hebrew', 630, 0, 0, '', 'heb', '', 0, 0, 1, ''),
('language', 'herero', 'Herero', 640, 0, 0, '', 'her', '', 0, 0, 1, ''),
('language', 'hindi', 'Hindi', 650, 0, 0, '', 'hin', '', 0, 0, 1, ''),
('language', 'hiri_motu', 'Hiri Motu', 660, 0, 0, '', 'hmo', '', 0, 0, 1, ''),
('language', 'hungarian', 'Hungarian', 670, 0, 0, '', 'hun', '', 0, 0, 1, ''),
('language', 'icelandic', 'Icelandic', 680, 0, 0, '', 'ice(B)|isl(T)', '', 0, 0, 1, ''),
('language', 'ido', 'Ido', 690, 0, 0, '', 'ido', '', 0, 0, 1, ''),
('language', 'igbo', 'Igbo', 700, 0, 0, '', 'ibo', '', 0, 0, 1, ''),
('language', 'indonesian', 'Indonesian', 710, 0, 0, '', 'ind', '', 0, 0, 1, ''),
('language', 'interlingua_international_auxi', 'Interlingua (International Auxiliary Language Association)', 720, 0, 0, '', 'ina', '', 0, 0, 1, ''),
('language', 'interlingue_occidental', 'Interlingue; Occidental', 730, 0, 0, '', 'ile', '', 0, 0, 1, ''),
('language', 'inuktitut', 'Inuktitut', 740, 0, 0, '', 'iku', '', 0, 0, 1, ''),
('language', 'inupiaq', 'Inupiaq', 750, 0, 0, '', 'ipk', '', 0, 0, 1, ''),
('language', 'irish', 'Irish', 760, 0, 0, '', 'gle', '', 0, 0, 1, ''),
('language', 'italian', 'Italian', 770, 0, 0, '', 'ita', '', 0, 0, 1, ''),
('language', 'japanese', 'Japanese', 780, 0, 0, '', 'jpn', '', 0, 0, 1, ''),
('language', 'javanese', 'Javanese', 790, 0, 0, '', 'jav', '', 0, 0, 1, ''),
('language', 'kalaallisut_greenlandic', 'Kalaallisut; Greenlandic', 800, 0, 0, '', 'kal', '', 0, 0, 1, ''),
('language', 'kannada', 'Kannada', 810, 0, 0, '', 'kan', '', 0, 0, 1, ''),
('language', 'kanuri', 'Kanuri', 820, 0, 0, '', 'kau', '', 0, 0, 1, ''),
('language', 'kashmiri', 'Kashmiri', 830, 0, 0, '', 'kas', '', 0, 0, 1, ''),
('language', 'kazakh', 'Kazakh', 840, 0, 0, '', 'kaz', '', 0, 0, 1, ''),
('language', 'kikuyu_gikuyu', 'Kikuyu; Gikuyu', 850, 0, 0, '', 'kik', '', 0, 0, 1, ''),
('language', 'kinyarwanda', 'Kinyarwanda', 860, 0, 0, '', 'kin', '', 0, 0, 1, ''),
('language', 'kirghiz_kyrgyz', 'Kirghiz; Kyrgyz', 870, 0, 0, '', 'kir', '', 0, 0, 1, ''),
('language', 'komi', 'Komi', 880, 0, 0, '', 'kom', '', 0, 0, 1, ''),
('language', 'kongo', 'Kongo', 890, 0, 0, '', 'kon', '', 0, 0, 1, ''),
('language', 'korean', 'Korean', 900, 0, 0, '', 'kor', '', 0, 0, 1, ''),
('language', 'kuanyama_kwanyama', 'Kuanyama; Kwanyama', 910, 0, 0, '', 'kua', '', 0, 0, 1, ''),
('language', 'kurdish', 'Kurdish', 920, 0, 0, '', 'kur', '', 0, 0, 1, ''),
('language', 'laotian', 'Lao', 930, 0, 0, '', 'lao', '', 0, 0, 1, ''),
('language', 'latin', 'Latin', 940, 0, 0, '', 'lat', '', 0, 0, 1, ''),
('language', 'latvian', 'Latvian', 950, 0, 0, '', 'lav', '', 0, 0, 1, ''),
('language', 'limburgan_limburger_limburgish', 'Limburgan; Limburger; Limburgish', 960, 0, 0, '', 'lim', '', 0, 0, 1, ''),
('language', 'lingala', 'Lingala', 970, 0, 0, '', 'lin', '', 0, 0, 1, ''),
('language', 'lithuanian', 'Lithuanian', 980, 0, 0, '', 'lit', '', 0, 0, 1, ''),
('language', 'luba-katanga', 'Luba-Katanga', 990, 0, 0, '', 'lub', '', 0, 0, 1, ''),
('language', 'luxembourgish_letzeburgesch', 'Luxembourgish; Letzeburgesch', 1000, 0, 0, '', 'ltz', '', 0, 0, 1, ''),
('language', 'macedonian', 'Macedonian', 1010, 0, 0, '', 'mac(B)|mkd(T)', '', 0, 0, 1, ''),
('language', 'malagasy', 'Malagasy', 1020, 0, 0, '', 'mlg', '', 0, 0, 1, ''),
('language', 'malay', 'Malay', 1030, 0, 0, '', 'may(B)|msa(T)', '', 0, 0, 1, ''),
('language', 'malayalam', 'Malayalam', 1040, 0, 0, '', 'mal', '', 0, 0, 1, ''),
('language', 'maltese', 'Maltese', 1050, 0, 0, '', 'mlt', '', 0, 0, 1, ''),
('language', 'manx', 'Manx', 1060, 0, 0, '', 'glv', '', 0, 0, 1, ''),
('language', 'maori', 'Maori', 1070, 0, 0, '', 'mao(B)|mri(T)', '', 0, 0, 1, ''),
('language', 'marathi', 'Marathi', 1080, 0, 0, '', 'mar', '', 0, 0, 1, ''),
('language', 'marshallese', 'Marshallese', 1090, 0, 0, '', 'mah', '', 0, 0, 1, ''),
('language', 'mongolian', 'Mongolian', 1100, 0, 0, '', 'mon', '', 0, 0, 1, ''),
('language', 'nauru', 'Nauru', 1110, 0, 0, '', 'nau', '', 0, 0, 1, ''),
('language', 'navajo_navaho', 'Navajo; Navaho', 1120, 0, 0, '', 'nav', '', 0, 0, 1, ''),
('language', 'ndebele_north_north_ndebele', 'Ndebele, North; North Ndebele', 1130, 0, 0, '', 'nde', '', 0, 0, 1, ''),
('language', 'ndebele_south_south_ndebele', 'Ndebele, South; South Ndebele', 1140, 0, 0, '', 'nbl', '', 0, 0, 1, ''),
('language', 'ndonga', 'Ndonga', 1150, 0, 0, '', 'ndo', '', 0, 0, 1, ''),
('language', 'nepali', 'Nepali', 1160, 0, 0, '', 'nep', '', 0, 0, 1, ''),
('language', 'northern_sami', 'Northern Sami', 1170, 0, 0, '', 'sme', '', 0, 0, 1, ''),
('language', 'norwegian', 'Norwegian', 1180, 0, 0, '', 'nor', '', 0, 0, 1, ''),
('language', 'norwegian_nynorsk_nynorsk_norw', 'Norwegian Nynorsk; Nynorsk, Norwegian', 1190, 0, 0, '', 'nno', '', 0, 0, 1, ''),
('language', 'occitan_post_1500', 'Occitan (post 1500)', 1200, 0, 0, '', 'oci', '', 0, 0, 1, ''),
('language', 'ojibwa', 'Ojibwa', 1210, 0, 0, '', 'oji', '', 0, 0, 1, ''),
('language', 'oriya', 'Oriya', 1220, 0, 0, '', 'ori', '', 0, 0, 1, ''),
('language', 'oromo', 'Oromo', 1230, 0, 0, '', 'orm', '', 0, 0, 1, ''),
('language', 'ossetian_ossetic', 'Ossetian; Ossetic', 1240, 0, 0, '', 'oss', '', 0, 0, 1, ''),
('language', 'pali', 'Pali', 1250, 0, 0, '', 'pli', '', 0, 0, 1, ''),
('language', 'persian', 'Persian', 1260, 0, 0, '', 'per(B)|fas(T)', '', 0, 0, 1, ''),
('language', 'polish', 'Polish', 1270, 0, 0, '', 'pol', '', 0, 0, 1, ''),
('language', 'portuguese', 'Portuguese', 1280, 0, 0, '', 'por', '', 0, 0, 1, ''),
('language', 'punjabi', 'Punjabi', 1290, 0, 0, '', 'pan', '', 0, 0, 1, ''),
('language', 'pushto_pashto', 'Pushto; Pashto', 1300, 0, 0, '', 'pus', '', 0, 0, 1, ''),
('language', 'quechua', 'Quechua', 1310, 0, 0, '', 'que', '', 0, 0, 1, ''),
('language', 'romanian_moldavian_moldovan', 'Romanian; Moldavian; Moldovan', 1320, 0, 0, '', 'rum(B)|ron(T)', '', 0, 0, 1, ''),
('language', 'romansh', 'Romansh', 1330, 0, 0, '', 'roh', '', 0, 0, 1, ''),
('language', 'rundi', 'Rundi', 1340, 0, 0, '', 'run', '', 0, 0, 1, ''),
('language', 'russian', 'Russian', 1350, 0, 0, '', 'rus', '', 0, 0, 1, ''),
('language', 'samoan', 'Samoan', 1360, 0, 0, '', 'smo', '', 0, 0, 1, ''),
('language', 'sango', 'Sango', 1370, 0, 0, '', 'sag', '', 0, 0, 1, ''),
('language', 'sanskrit', 'Sanskrit', 1380, 0, 0, '', 'san', '', 0, 0, 1, ''),
('language', 'sardinian', 'Sardinian', 1390, 0, 0, '', 'srd', '', 0, 0, 1, ''),
('language', 'serbian', 'Serbian', 1400, 0, 0, '', 'srp', '', 0, 0, 1, ''),
('language', 'shona', 'Shona', 1410, 0, 0, '', 'sna', '', 0, 0, 1, ''),
('language', 'sichuan_yi_nuosu', 'Sichuan Yi; Nuosu', 1420, 0, 0, '', 'iii', '', 0, 0, 1, ''),
('language', 'sindhi', 'Sindhi', 1430, 0, 0, '', 'snd', '', 0, 0, 1, '');
INSERT INTO `list_options` VALUES
('language', 'sinhala_sinhalese', 'Sinhala; Sinhalese', 1440, 0, 0, '', 'sin', '', 0, 0, 1, ''),
('language', 'slovak', 'Slovak', 1450, 0, 0, '', 'slo(B)|slk(T)', '', 0, 0, 1, ''),
('language', 'slovenian', 'Slovenian', 1460, 0, 0, '', 'slv', '', 0, 0, 1, ''),
('language', 'somali', 'Somali', 1470, 0, 0, '', 'som', '', 0, 0, 1, ''),
('language', 'sotho_southern', 'Sotho, Southern', 1480, 0, 0, '', 'sot', '', 0, 0, 1, ''),
('language', 'Spanish', 'Spanish', 1490, 0, 0, '', 'spa', '', 0, 0, 1, ''),
('language', 'sundanese', 'Sundanese', 1500, 0, 0, '', 'sun', '', 0, 0, 1, ''),
('language', 'swahili', 'Swahili', 1510, 0, 0, '', 'swa', '', 0, 0, 1, ''),
('language', 'swati', 'Swati', 1520, 0, 0, '', 'ssw', '', 0, 0, 1, ''),
('language', 'swedish', 'Swedish', 1530, 0, 0, '', 'swe', '', 0, 0, 1, ''),
('language', 'tagalog', 'Tagalog', 1540, 0, 0, '', 'tgl', '', 0, 0, 1, ''),
('language', 'tahitian', 'Tahitian', 1550, 0, 0, '', 'tah', '', 0, 0, 1, ''),
('language', 'tajik', 'Tajik', 1560, 0, 0, '', 'tgk', '', 0, 0, 1, ''),
('language', 'tamil', 'Tamil', 1570, 0, 0, '', 'tam', '', 0, 0, 1, ''),
('language', 'tatar', 'Tatar', 1580, 0, 0, '', 'tat', '', 0, 0, 1, ''),
('language', 'telugu', 'Telugu', 1590, 0, 0, '', 'tel', '', 0, 0, 1, ''),
('language', 'thai', 'Thai', 1600, 0, 0, '', 'tha', '', 0, 0, 1, ''),
('language', 'tibetan', 'Tibetan', 1610, 0, 0, '', 'tib(B)|bod(T)', '', 0, 0, 1, ''),
('language', 'tigrinya', 'Tigrinya', 1620, 0, 0, '', 'tir', '', 0, 0, 1, ''),
('language', 'tonga_tonga_islands', 'Tonga (Tonga Islands)', 1630, 0, 0, '', 'ton', '', 0, 0, 1, ''),
('language', 'tsonga', 'Tsonga', 1640, 0, 0, '', 'tso', '', 0, 0, 1, ''),
('language', 'tswana', 'Tswana', 1650, 0, 0, '', 'tsn', '', 0, 0, 1, ''),
('language', 'turkish', 'Turkish', 1660, 0, 0, '', 'tur', '', 0, 0, 1, ''),
('language', 'turkmen', 'Turkmen', 1670, 0, 0, '', 'tuk', '', 0, 0, 1, ''),
('language', 'twi', 'Twi', 1680, 0, 0, '', 'twi', '', 0, 0, 1, ''),
('language', 'uighur_uyghur', 'Uighur; Uyghur', 1690, 0, 0, '', 'uig', '', 0, 0, 1, ''),
('language', 'ukrainian', 'Ukrainian', 1700, 0, 0, '', 'ukr', '', 0, 0, 1, ''),
('language', 'urdu', 'Urdu', 1710, 0, 0, '', 'urd', '', 0, 0, 1, ''),
('language', 'uzbek', 'Uzbek', 1720, 0, 0, '', 'uzb', '', 0, 0, 1, ''),
('language', 'venda', 'Venda', 1730, 0, 0, '', 'ven', '', 0, 0, 1, ''),
('language', 'vietnamese', 'Vietnamese', 1740, 0, 0, '', 'vie', '', 0, 0, 1, ''),
('language', 'volapuk', 'VolapÃ¼k', 1750, 0, 0, '', 'vol', '', 0, 0, 1, ''),
('language', 'walloon', 'Walloon', 1760, 0, 0, '', 'wln', '', 0, 0, 1, ''),
('language', 'welsh', 'Welsh', 1770, 0, 0, '', 'wel(B)|cym(T)', '', 0, 0, 1, ''),
('language', 'western_frisian', 'Western Frisian', 1780, 0, 0, '', 'fry', '', 0, 0, 1, ''),
('language', 'wolof', 'Wolof', 1790, 0, 0, '', 'wol', '', 0, 0, 1, ''),
('language', 'xhosa', 'Xhosa', 1800, 0, 0, '', 'xho', '', 0, 0, 1, ''),
('language', 'yiddish', 'Yiddish', 1810, 0, 0, '', 'yid', '', 0, 0, 1, ''),
('language', 'yoruba', 'Yoruba', 1820, 0, 0, '', 'yor', '', 0, 0, 1, ''),
('language', 'zhuang_chuang', 'Zhuang; Chuang', 1830, 0, 0, '', 'zha', '', 0, 0, 1, ''),
('language', 'zulu', 'Zulu', 1840, 0, 0, '', 'zul', '', 0, 0, 1, ''),
('lists', 'abook_type', 'Address Book Types', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ACLT_Tag_Colors', 'ACLT Tag Colors', 299, 1, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ACLT_Tag_Status', 'ACLT Tag Status', 298, 1, 0, '', '', '', 0, 0, 1, ''),
('lists', 'adjreason', 'Adjustment Reasons', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'allergy_issue_list', 'Allergy Issue List', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'amendment_from', 'Amendment From', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'amendment_status', 'Amendment Status', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'apptstat', 'Appointment Statuses', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'boolean', 'Boolean', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'chartloc', 'Chart Storage Locations', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'clinical_plans', 'Clinical Plans', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'clinical_rules', 'Clinical Rules', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'code_types', 'Code Types', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'country', 'Country', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'county', 'County', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'date_master_criteria', 'Date Master Criteria', 33, 1, 0, '', '', '', 0, 0, 1, ''),
('lists', 'dental_issue_list', 'Dental Issue List', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'disclosure_type', 'Disclosure Type', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'drug_form', 'Drug Forms', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'drug_interval', 'Drug Intervals', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'drug_route', 'Drug Routes', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'drug_units', 'Drug Units', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'eligibility', 'Eligibility', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ethnicity', 'Ethnicity', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ethrace', 'Race/Ethnicity', 12, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'exams', 'Exams/Tests', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'feesheet', 'Fee Sheet', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'general_issue_list', 'General Issue List', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'immunizations', 'Immunizations', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'Immunization_Completion_Status', 'Immunization Completion Status', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'Immunization_Manufacturer', 'Immunization Manufacturer', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'Industry', 'Industry', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'insurance_types', 'Insurance Types', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'irnpool', 'Invoice Reference Number Pools', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'issue_subtypes', 'Issue Subtypes', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'issue_types', 'Issue Types', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'language', 'Language', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'lbfnames', 'Layout-Based Visit Forms', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'marital', 'Marital Status', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'medical_problem_issue_list', 'Medical Problem Issue List', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'medication_issue_list', 'Medication Issue List', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'message_status', 'Message Status', 45, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'msp_remit_codes', 'MSP Remit Codes', 221, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'nation_notes_replace_buttons', 'Nation Notes Replace Buttons', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'newcrop_erx_role', 'NewCrop eRx Role', 221, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'note_type', 'Patient Note Types', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'Occupation', 'Occupation', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'occurrence', 'Occurrence', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'order_type', 'Order Types', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ord_priority', 'Order Priorities', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ord_status', 'Order Statuses', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'outcome', 'Outcome', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'patient_flow_board_rooms', 'Patient Flow Board Rooms', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_adjustment_code', 'Payment Adjustment Code', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_date', 'Payment Date', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_gateways', 'Payment Gateways', 297, 1, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_ins', 'Payment Ins', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_method', 'Payment Method', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_sort_by', 'Payment Sort By', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_status', 'Payment Status', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'payment_type', 'Payment Type', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'personal_relationship', 'Relationship', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'physician_type', 'Physician Type', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'pricelevel', 'Price Level', 11, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_body_site', 'Procedure Body Sites', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_lat', 'Procedure Lateralities', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_rep_status', 'Procedure Report Statuses', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_res_abnormal', 'Procedure Result Abnormal', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_res_bool', 'Procedure Boolean Results', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_res_status', 'Procedure Result Statuses', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_route', 'Procedure Routes', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_specimen', 'Procedure Specimen Types', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_type', 'Procedure Types', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'proc_unit', 'Procedure Units', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'provider_qualifier_code', 'Provider Qualifier Code', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ptlistcols', 'Patient List Columns', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'race', 'Race', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'reaction', 'Reaction', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'refsource', 'Referral Source', 13, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'religious_affiliation', 'Religious Affiliation', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'riskfactors', 'Risk Factors', 14, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'risklevel', 'Risk Level', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_action', 'Clinical Rule Action Item', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_action_category', 'Clinical Rule Action Category', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_age_intervals', 'Clinical Rules Age Intervals', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_comparisons', 'Clinical Rules Comparisons', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_enc_types', 'Clinical Rules Encounter Types', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_filters', 'Clinical Rule Filter Methods', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_reminder_due_opt', 'Clinical Rules Reminder Due Options', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_reminder_inactive_opt', 'Clinical Rules Reminder Inactivation Options', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_reminder_intervals', 'Clinical Rules Reminder Intervals', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_reminder_methods', 'Clinical Rules Reminder Methods', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_targets', 'Clinical Rule Target Methods', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'rule_target_intervals', 'Clinical Rules Target Intervals', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'severity_ccda', 'Severity', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'sex', 'Sex', 17, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'smoking_status', 'Smoking Status', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'state', 'State', 18, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'sub_relation', 'Subscriber Relationship', 18, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'superbill', 'Service Category', 16, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'surgery_issue_list', 'Surgery Issue List', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'taxrate', 'Tax Rate', 19, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'titles', 'Titles', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'transactions', 'Layout-Based Transaction Forms', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ub_admit_source', 'UB Admit Source', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'ub_admit_type', 'UB Admit Type', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'warehouse', 'Warehouses', 21, 0, 0, '', '', '', 0, 0, 1, ''),
('lists', 'yesno', 'Yes/No', 21, 0, 0, '', '', '', 0, 0, 1, ''),
('marital', 'divorced', 'Divorced', 3, 0, 0, '', 'D', '', 0, 0, 1, ''),
('marital', 'domestic partner', 'Domestic Partner', 6, 0, 0, '', 'T', '', 0, 0, 1, ''),
('marital', 'married', 'Married', 1, 0, 0, '', 'M', '', 0, 0, 1, ''),
('marital', 'separated', 'Separated', 5, 0, 0, '', 'L', '', 0, 0, 1, ''),
('marital', 'single', 'Single', 2, 0, 0, '', 'S', '', 0, 0, 1, ''),
('marital', 'widowed', 'Widowed', 4, 0, 0, '', 'W', '', 0, 0, 1, ''),
('medical_problem_issue_list', 'asthma', 'asthma', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('medical_problem_issue_list', 'diabetes', 'diabetes', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('medical_problem_issue_list', 'HTN', 'HTN', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('medical_problem_issue_list', 'hyperlipidemia', 'hyperlipidemia', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('medication_issue_list', 'Lipitor', 'Lipitor', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('medication_issue_list', 'Metformin', 'Metformin', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('medication_issue_list', 'Norvasc', 'Norvasc', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('message_status', 'Done', 'Done', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('message_status', 'Forwarded', 'Forwarded', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('message_status', 'New', 'New', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('message_status', 'Read', 'Read', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('msp_remit_codes', '1', '1', 1, 0, 0, '', 'Deductible Amount', '', 0, 0, 1, ''),
('msp_remit_codes', '10', '10', 10, 0, 0, '', 'The diagnosis is inconsistent with the patient''s gender. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '100', '100', 64, 0, 0, '', 'Payment made to patient/insured/responsible party/employer.', '', 0, 0, 1, ''),
('msp_remit_codes', '101', '101', 65, 0, 0, '', 'Predetermination: anticipated payment upon completion of services or claim adjudication.', '', 0, 0, 1, ''),
('msp_remit_codes', '102', '102', 66, 0, 0, '', 'Major Medical Adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '103', '103', 67, 0, 0, '', 'Provider promotional discount (e.g., Senior citizen discount).', '', 0, 0, 1, ''),
('msp_remit_codes', '104', '104', 68, 0, 0, '', 'Managed care withholding.', '', 0, 0, 1, ''),
('msp_remit_codes', '105', '105', 69, 0, 0, '', 'Tax withholding.', '', 0, 0, 1, ''),
('msp_remit_codes', '106', '106', 70, 0, 0, '', 'Patient payment option/election not in effect.', '', 0, 0, 1, ''),
('msp_remit_codes', '107', '107', 71, 0, 0, '', 'The related or qualifying claim/service was not identified on this claim. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '108', '108', 72, 0, 0, '', 'Rent/purchase guidelines were not met. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '109', '109', 73, 0, 0, '', 'Claim not covered by this payer/contractor. You must send the claim to the correct payer/contractor.', '', 0, 0, 1, ''),
('msp_remit_codes', '11', '11', 11, 0, 0, '', 'The diagnosis is inconsistent with the procedure. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '110', '110', 74, 0, 0, '', 'Billing date predates service date.', '', 0, 0, 1, ''),
('msp_remit_codes', '111', '111', 75, 0, 0, '', 'Not covered unless the provider accepts assignment.', '', 0, 0, 1, ''),
('msp_remit_codes', '112', '112', 76, 0, 0, '', 'Service not furnished directly to the patient and/or not documented.', '', 0, 0, 1, ''),
('msp_remit_codes', '114', '114', 77, 0, 0, '', 'Procedure/product not approved by the Food and Drug Administration.', '', 0, 0, 1, ''),
('msp_remit_codes', '115', '115', 78, 0, 0, '', 'Procedure postponed, canceled, or delayed.', '', 0, 0, 1, ''),
('msp_remit_codes', '116', '116', 79, 0, 0, '', 'The advance indemnification notice signed by the patient did not comply with requirements.', '', 0, 0, 1, ''),
('msp_remit_codes', '117', '117', 80, 0, 0, '', 'Transportation is only covered to the closest facility that can provide the necessary care.', '', 0, 0, 1, ''),
('msp_remit_codes', '118', '118', 81, 0, 0, '', 'ESRD network support adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '119', '119', 82, 0, 0, '', 'Benefit maximum for this time period or occurrence has been reached.', '', 0, 0, 1, ''),
('msp_remit_codes', '12', '12', 12, 0, 0, '', 'The diagnosis is inconsistent with the provider type. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '121', '121', 83, 0, 0, '', 'Indemnification adjustment - compensation for outstanding member responsibility.', '', 0, 0, 1, ''),
('msp_remit_codes', '122', '122', 84, 0, 0, '', 'Psychiatric reduction.', '', 0, 0, 1, ''),
('msp_remit_codes', '125', '125', 85, 0, 0, '', 'Submission/billing error(s). At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', '128', '128', 86, 0, 0, '', 'Newborn''s services are covered in the mother''s Allowance.', '', 0, 0, 1, ''),
('msp_remit_codes', '129', '129', 87, 0, 0, '', 'Prior processing information appears incorrect. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', '13', '13', 13, 0, 0, '', 'The date of death precedes the date of service.', '', 0, 0, 1, ''),
('msp_remit_codes', '130', '130', 88, 0, 0, '', 'Claim submission fee.', '', 0, 0, 1, ''),
('msp_remit_codes', '131', '131', 89, 0, 0, '', 'Claim specific negotiated discount.', '', 0, 0, 1, ''),
('msp_remit_codes', '132', '132', 90, 0, 0, '', 'Prearranged demonstration project adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '133', '133', 91, 0, 0, '', 'The disposition of this claim/service is pending further review.', '', 0, 0, 1, ''),
('msp_remit_codes', '134', '134', 92, 0, 0, '', 'Technical fees removed from charges.', '', 0, 0, 1, ''),
('msp_remit_codes', '135', '135', 93, 0, 0, '', 'Interim bills cannot be processed.', '', 0, 0, 1, ''),
('msp_remit_codes', '136', '136', 94, 0, 0, '', 'Failure to follow prior payer''s coverage rules. (Use Group Code OA).', '', 0, 0, 1, ''),
('msp_remit_codes', '137', '137', 95, 0, 0, '', 'Regulatory Surcharges, Assessments, Allowances or Health Related Taxes.', '', 0, 0, 1, ''),
('msp_remit_codes', '138', '138', 96, 0, 0, '', 'Appeal procedures not followed or time limits not met.', '', 0, 0, 1, ''),
('msp_remit_codes', '139', '139', 97, 0, 0, '', 'Contracted funding agreement - Subscriber is employed by the provider of services.', '', 0, 0, 1, ''),
('msp_remit_codes', '14', '14', 14, 0, 0, '', 'The date of birth follows the date of service.', '', 0, 0, 1, ''),
('msp_remit_codes', '140', '140', 98, 0, 0, '', 'Patient/Insured health identification number and name do not match.', '', 0, 0, 1, ''),
('msp_remit_codes', '141', '141', 99, 0, 0, '', 'Claim spans eligible and ineligible periods of coverage.', '', 0, 0, 1, ''),
('msp_remit_codes', '142', '142', 100, 0, 0, '', 'Monthly Medicaid patient liability amount.', '', 0, 0, 1, ''),
('msp_remit_codes', '143', '143', 101, 0, 0, '', 'Portion of payment deferred.', '', 0, 0, 1, ''),
('msp_remit_codes', '144', '144', 102, 0, 0, '', 'Incentive adjustment, e.g. preferred product/service.', '', 0, 0, 1, ''),
('msp_remit_codes', '146', '146', 103, 0, 0, '', 'Diagnosis was invalid for the date(s) of service reported.', '', 0, 0, 1, ''),
('msp_remit_codes', '147', '147', 104, 0, 0, '', 'Provider contracted/negotiated rate expired or not on file.', '', 0, 0, 1, ''),
('msp_remit_codes', '148', '148', 105, 0, 0, '', 'Information from another provider was not provided or was insufficient/incomplete. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', '149', '149', 106, 0, 0, '', 'Lifetime benefit maximum has been reached for this service/benefit category.', '', 0, 0, 1, ''),
('msp_remit_codes', '15', '15', 15, 0, 0, '', 'The authorization number is missing, invalid, or does not apply to the billed services or provider.', '', 0, 0, 1, ''),
('msp_remit_codes', '150', '150', 107, 0, 0, '', 'Payer deems the information submitted does not support this level of service.', '', 0, 0, 1, ''),
('msp_remit_codes', '151', '151', 108, 0, 0, '', 'Payment adjusted because the payer deems the information submitted does not support this many/frequency of services.', '', 0, 0, 1, ''),
('msp_remit_codes', '152', '152', 109, 0, 0, '', 'Payer deems the information submitted does not support this length of service. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '153', '153', 110, 0, 0, '', 'Payer deems the information submitted does not support this dosage.', '', 0, 0, 1, ''),
('msp_remit_codes', '154', '154', 111, 0, 0, '', 'Payer deems the information submitted does not support this day''s supply.', '', 0, 0, 1, ''),
('msp_remit_codes', '155', '155', 112, 0, 0, '', 'Patient refused the service/procedure.', '', 0, 0, 1, ''),
('msp_remit_codes', '157', '157', 113, 0, 0, '', 'Service/procedure was provided as a result of an act of war.', '', 0, 0, 1, ''),
('msp_remit_codes', '158', '158', 114, 0, 0, '', 'Service/procedure was provided outside of the United States.', '', 0, 0, 1, ''),
('msp_remit_codes', '159', '159', 115, 0, 0, '', 'Service/procedure was provided as a result of terrorism.', '', 0, 0, 1, ''),
('msp_remit_codes', '16', '16', 16, 0, 0, '', 'Claim/service lacks information which is needed for adjudication. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', '160', '160', 116, 0, 0, '', 'Injury/illness was the result of an activity that is a benefit exclusion.', '', 0, 0, 1, ''),
('msp_remit_codes', '161', '161', 117, 0, 0, '', 'Provider performance bonus', '', 0, 0, 1, ''),
('msp_remit_codes', '162', '162', 118, 0, 0, '', 'State-mandated Requirement for Property and Casualty, see Claim Payment Remarks Code for specific explanation.', '', 0, 0, 1, ''),
('msp_remit_codes', '163', '163', 119, 0, 0, '', 'Attachment referenced on the claim was not received.', '', 0, 0, 1, ''),
('msp_remit_codes', '164', '164', 120, 0, 0, '', 'Attachment referenced on the claim was not received in a timely fashion.', '', 0, 0, 1, ''),
('msp_remit_codes', '165', '165', 121, 0, 0, '', 'Referral absent or exceeded.', '', 0, 0, 1, ''),
('msp_remit_codes', '166', '166', 122, 0, 0, '', 'These services were submitted after this payers responsibility for processing claims under this plan ended.', '', 0, 0, 1, ''),
('msp_remit_codes', '167', '167', 123, 0, 0, '', 'This (these) diagnosis(es) is (are) not covered. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '168', '168', 124, 0, 0, '', 'Service(s) have been considered under the patient''s medical plan. Benefits are not available under this dental plan.', '', 0, 0, 1, ''),
('msp_remit_codes', '169', '169', 125, 0, 0, '', 'Alternate benefit has been provided.', '', 0, 0, 1, ''),
('msp_remit_codes', '170', '170', 126, 0, 0, '', 'Payment is denied when performed/billed by this type of provider. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '171', '171', 127, 0, 0, '', 'Payment is denied when performed/billed by this type of provider in this type of facility. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '172', '172', 128, 0, 0, '', 'Payment is adjusted when performed/billed by a provider of this specialty. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '173', '173', 129, 0, 0, '', 'Service was not prescribed by a physician.', '', 0, 0, 1, ''),
('msp_remit_codes', '174', '174', 130, 0, 0, '', 'Service was not prescribed prior to delivery.', '', 0, 0, 1, ''),
('msp_remit_codes', '175', '175', 131, 0, 0, '', 'Prescription is incomplete.', '', 0, 0, 1, ''),
('msp_remit_codes', '176', '176', 132, 0, 0, '', 'Prescription is not current.', '', 0, 0, 1, ''),
('msp_remit_codes', '177', '177', 133, 0, 0, '', 'Patient has not met the required eligibility requirements.', '', 0, 0, 1, ''),
('msp_remit_codes', '178', '178', 134, 0, 0, '', 'Patient has not met the required spend down requirements.', '', 0, 0, 1, ''),
('msp_remit_codes', '179', '179', 135, 0, 0, '', 'Patient has not met the required waiting requirements. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '18', '18', 17, 0, 0, '', 'Duplicate claim/service.', '', 0, 0, 1, ''),
('msp_remit_codes', '180', '180', 136, 0, 0, '', 'Patient has not met the required residency requirements.', '', 0, 0, 1, ''),
('msp_remit_codes', '181', '181', 137, 0, 0, '', 'Procedure code was invalid on the date of service.', '', 0, 0, 1, ''),
('msp_remit_codes', '182', '182', 138, 0, 0, '', 'Procedure modifier was invalid on the date of service.', '', 0, 0, 1, ''),
('msp_remit_codes', '183', '183', 139, 0, 0, '', 'The referring provider is not eligible to refer the service billed. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '184', '184', 140, 0, 0, '', 'The prescribing/ordering provider is not eligible to prescribe/order the service billed. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '185', '185', 141, 0, 0, '', 'The rendering provider is not eligible to perform the service billed. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '186', '186', 142, 0, 0, '', 'Level of care change adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '187', '187', 143, 0, 0, '', 'Consumer Spending Account payments (includes but is not limited to Flexible Spending Account, Health Savings Account, Health Reimbursement Account, etc.)', '', 0, 0, 1, ''),
('msp_remit_codes', '188', '188', 144, 0, 0, '', 'This product/procedure is only covered when used according to FDA recommendations.', '', 0, 0, 1, ''),
('msp_remit_codes', '189', '189', 145, 0, 0, '', '''''Not otherwise classified'' or ''unlisted'' procedure code (CPT/HCPCS) was billed when there is a specific procedure code for this procedure/service''', '', 0, 0, 1, ''),
('msp_remit_codes', '19', '19', 18, 0, 0, '', 'This is a work-related injury/illness and thus the liability of the Worker''s Compensation Carrier.', '', 0, 0, 1, ''),
('msp_remit_codes', '190', '190', 146, 0, 0, '', 'Payment is included in the allowance for a Skilled Nursing Facility (SNF) qualified stay.', '', 0, 0, 1, ''),
('msp_remit_codes', '191', '191', 147, 0, 0, '', 'Not a work related injury/illness and thus not the liability of the workers'' compensation carrier Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Insurance Policy Number Segment (Loop 2100 Other Clai', '', 0, 0, 1, ''),
('msp_remit_codes', '192', '192', 148, 0, 0, '', 'Non standard adjustment code from paper remittance. Note: This code is to be used by providers/payers providing Coordination of Benefits information to another payer in the 837 transaction only. This code is only used when the non-standard code cannot be ', '', 0, 0, 1, ''),
('msp_remit_codes', '193', '193', 149, 0, 0, '', 'Original payment decision is being maintained. Upon review, it was determined that this claim was processed properly.', '', 0, 0, 1, ''),
('msp_remit_codes', '194', '194', 150, 0, 0, '', 'Anesthesia performed by the operating physician, the assistant surgeon or the attending physician.', '', 0, 0, 1, ''),
('msp_remit_codes', '195', '195', 151, 0, 0, '', 'Refund issued to an erroneous priority payer for this claim/service.', '', 0, 0, 1, ''),
('msp_remit_codes', '197', '197', 152, 0, 0, '', 'Precertification/authorization/notification absent.', '', 0, 0, 1, ''),
('msp_remit_codes', '198', '198', 153, 0, 0, '', 'Precertification/authorization exceeded.', '', 0, 0, 1, ''),
('msp_remit_codes', '199', '199', 154, 0, 0, '', 'Revenue code and Procedure code do not match.', '', 0, 0, 1, ''),
('msp_remit_codes', '2', '2', 2, 0, 0, '', 'Coinsurance Amount', '', 0, 0, 1, ''),
('msp_remit_codes', '20', '20', 19, 0, 0, '', 'This injury/illness is covered by the liability carrier.', '', 0, 0, 1, ''),
('msp_remit_codes', '200', '200', 155, 0, 0, '', 'Expenses incurred during lapse in coverage', '', 0, 0, 1, ''),
('msp_remit_codes', '201', '201', 156, 0, 0, '', 'Workers Compensation case settled. Patient is responsible for amount of this claim/service through WC ''Medicare set aside arrangement'' or other agreement. (Use group code PR).', '', 0, 0, 1, ''),
('msp_remit_codes', '202', '202', 157, 0, 0, '', 'Non-covered personal comfort or convenience services.', '', 0, 0, 1, ''),
('msp_remit_codes', '203', '203', 158, 0, 0, '', 'Discontinued or reduced service.', '', 0, 0, 1, ''),
('msp_remit_codes', '204', '204', 159, 0, 0, '', 'This service/equipment/drug is not covered under the patient?s current benefit plan', '', 0, 0, 1, ''),
('msp_remit_codes', '205', '205', 160, 0, 0, '', 'Pharmacy discount card processing fee', '', 0, 0, 1, ''),
('msp_remit_codes', '206', '206', 161, 0, 0, '', 'National Provider Identifier - missing.', '', 0, 0, 1, ''),
('msp_remit_codes', '207', '207', 162, 0, 0, '', 'National Provider identifier - Invalid format', '', 0, 0, 1, ''),
('msp_remit_codes', '208', '208', 163, 0, 0, '', 'National Provider Identifier - Not matched.', '', 0, 0, 1, ''),
('msp_remit_codes', '209', '209', 164, 0, 0, '', 'Per regulatory or other agreement. The provider cannot collect this amount from the patient. However, this amount may be billed to subsequent payer. Refund to patient if collected. (Use Group code OA)', '', 0, 0, 1, ''),
('msp_remit_codes', '21', '21', 20, 0, 0, '', 'This injury/illness is the liability of the no-fault carrier.', '', 0, 0, 1, ''),
('msp_remit_codes', '210', '210', 165, 0, 0, '', 'Payment adjusted because pre-certification/authorization not received in a timely fashion', '', 0, 0, 1, ''),
('msp_remit_codes', '211', '211', 166, 0, 0, '', 'National Drug Codes (NDC) not eligible for rebate, are not covered.', '', 0, 0, 1, ''),
('msp_remit_codes', '212', '212', 167, 0, 0, '', 'Administrative surcharges are not covered', '', 0, 0, 1, ''),
('msp_remit_codes', '213', '213', 168, 0, 0, '', 'Non-compliance with the physician self referral prohibition legislation or payer policy.', '', 0, 0, 1, ''),
('msp_remit_codes', '214', '214', 169, 0, 0, '', 'Workers'' Compensation claim adjudicated as non-compensable. This Payer not liable for claim or service/treatment. Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Insurance Policy Number Segment (Loop', '', 0, 0, 1, ''),
('msp_remit_codes', '215', '215', 170, 0, 0, '', 'Based on subrogation of a third party settlement', '', 0, 0, 1, ''),
('msp_remit_codes', '216', '216', 171, 0, 0, '', 'Based on the findings of a review organization', '', 0, 0, 1, ''),
('msp_remit_codes', '217', '217', 172, 0, 0, '', 'Based on payer reasonable and customary fees. No maximum allowable defined by legislated fee arrangement. (Note: To be used for Workers'' Compensation only)', '', 0, 0, 1, ''),
('msp_remit_codes', '218', '218', 173, 0, 0, '', 'Based on entitlement to benefits. Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Insurance Policy Number Segment (Loop 2100 Other Claim Related Information REF qualifier ''IG'') for the jurisdictional', '', 0, 0, 1, ''),
('msp_remit_codes', '219', '219', 174, 0, 0, '', 'Based on extent of injury. Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Insurance Policy Number Segment (Loop 2100 Other Claim Related Information REF qualifier ''IG'') for the jurisdictional regula', '', 0, 0, 1, ''),
('msp_remit_codes', '22', '22', 21, 0, 0, '', 'This care may be covered by another payer per coordination of benefits.', '', 0, 0, 1, ''),
('msp_remit_codes', '220', '220', 175, 0, 0, '', 'The applicable fee schedule does not contain the billed code. Please resubmit a bill with the appropriate fee schedule code(s) that best describe the service(s) provided and supporting documentation if required. (Note: To be used for Workers'' Compensation', '', 0, 0, 1, ''),
('msp_remit_codes', '221', '221', 176, 0, 0, '', 'Workers'' Compensation claim is under investigation. Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Insurance Policy Number Segment (Loop 2100 Other Claim Related Information REF qualifier ''IG'') for ', '', 0, 0, 1, ''),
('msp_remit_codes', '222', '222', 177, 0, 0, '', 'Exceeds the contracted maximum number of hours/days/units by this provider for this period. This is not patient specific. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '223', '223', 178, 0, 0, '', 'Adjustment code for mandated federal, state or local law/regulation that is not already covered by another code and is mandated before a new code can be created.', '', 0, 0, 1, ''),
('msp_remit_codes', '224', '224', 179, 0, 0, '', 'Patient identification compromised by identity theft. Identity verification required for processing this and future claims.', '', 0, 0, 1, ''),
('msp_remit_codes', '225', '225', 180, 0, 0, '', 'Penalty or Interest Payment by Payer (Only used for plan to plan encounter reporting within the 837)', '', 0, 0, 1, ''),
('msp_remit_codes', '226', '226', 181, 0, 0, '', 'Information requested from the Billing/Rendering Provider was not provided or was insufficient/incomplete. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ', '', 0, 0, 1, ''),
('msp_remit_codes', '227', '227', 182, 0, 0, '', 'Information requested from the patient/insured/responsible party was not provided or was insufficient/incomplete. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is ', '', 0, 0, 1, ''),
('msp_remit_codes', '228', '228', 183, 0, 0, '', 'Denied for failure of this provider, another provider or the subscriber to supply requested information to a previous payer for their adjudication', '', 0, 0, 1, ''),
('msp_remit_codes', '229', '229', 184, 0, 0, '', 'Partial charge amount not considered by Medicare due to the initial claim Type of Bill being 12X. Note: This code can only be used in the 837 transaction to convey Coordination of Benefits information when the secondary payer?s cost avoidance policy allow', '', 0, 0, 1, ''),
('msp_remit_codes', '23', '23', 22, 0, 0, '', 'The impact of prior payer(s) adjudication including payments and/or adjustments.', '', 0, 0, 1, ''),
('msp_remit_codes', '230', '230', 185, 0, 0, '', 'No available or correlating CPT/HCPCS code to describe this service. Note: Used only by Property and Casualty.', '', 0, 0, 1, ''),
('msp_remit_codes', '231', '231', 186, 0, 0, '', 'Mutually exclusive procedures cannot be done in the same day/setting. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '232', '232', 187, 0, 0, '', 'Institutional Transfer Amount. Note - Applies to institutional claims only and explains the DRG amount difference when the patient care crosses multiple institutions.', '', 0, 0, 1, ''),
('msp_remit_codes', '233', '233', 188, 0, 0, '', 'Services/charges related to the treatment of a hospital-acquired condition or preventable medical error.', '', 0, 0, 1, ''),
('msp_remit_codes', '234', '234', 189, 0, 0, '', 'This procedure is not paid separately. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', '235', '235', 190, 0, 0, '', 'Sales Tax', '', 0, 0, 1, ''),
('msp_remit_codes', '236', '236', 191, 0, 0, '', 'This procedure or procedure/modifier combination is not compatible with another procedure or procedure/modifier combination provided on the same day according to the National Correct Coding Initiative.', '', 0, 0, 1, ''),
('msp_remit_codes', '237', '237', 192, 0, 0, '', 'Legislated/Regulatory Penalty. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', '24', '24', 23, 0, 0, '', 'Charges are covered under a capitation agreement/managed care plan.', '', 0, 0, 1, ''),
('msp_remit_codes', '26', '26', 24, 0, 0, '', 'Expenses incurred prior to coverage.', '', 0, 0, 1, ''),
('msp_remit_codes', '27', '27', 25, 0, 0, '', 'Expenses incurred after coverage terminated.', '', 0, 0, 1, ''),
('msp_remit_codes', '29', '29', 26, 0, 0, '', 'The time limit for filing has expired.', '', 0, 0, 1, ''),
('msp_remit_codes', '3', '3', 3, 0, 0, '', 'Co-payment Amount', '', 0, 0, 1, ''),
('msp_remit_codes', '31', '31', 27, 0, 0, '', 'Patient cannot be identified as our insured.', '', 0, 0, 1, ''),
('msp_remit_codes', '32', '32', 28, 0, 0, '', 'Our records indicate that this dependent is not an eligible dependent as defined.', '', 0, 0, 1, ''),
('msp_remit_codes', '33', '33', 29, 0, 0, '', 'Insured has no dependent coverage.', '', 0, 0, 1, ''),
('msp_remit_codes', '34', '34', 30, 0, 0, '', 'Insured has no coverage for newborns.', '', 0, 0, 1, ''),
('msp_remit_codes', '35', '35', 31, 0, 0, '', 'Lifetime benefit maximum has been reached.', '', 0, 0, 1, ''),
('msp_remit_codes', '38', '38', 32, 0, 0, '', 'Services not provided or authorized by designated (network/primary care) providers.', '', 0, 0, 1, ''),
('msp_remit_codes', '39', '39', 33, 0, 0, '', 'Services denied at the time authorization/pre-certification was requested.', '', 0, 0, 1, ''),
('msp_remit_codes', '4', '4', 4, 0, 0, '', 'The procedure code is inconsistent with the modifier used or a required modifier is missing. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '40', '40', 34, 0, 0, '', 'Charges do not meet qualifications for emergent/urgent care. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '44', '44', 35, 0, 0, '', 'Prompt-pay discount.', '', 0, 0, 1, ''),
('msp_remit_codes', '45', '45', 36, 0, 0, '', 'Charge exceeds fee schedule/maximum allowable or contracted/legislated fee arrangement. (Use Group Codes PR or CO depending upon liability).', '', 0, 0, 1, ''),
('msp_remit_codes', '49', '49', 37, 0, 0, '', 'These are non-covered services because this is a routine exam or screening procedure done in conjunction with a routine exam. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '50', '50', 38, 0, 0, '', 'These are non-covered services because this is not deemed a ''medical necessity'' by the payer. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '51', '51', 39, 0, 0, '', 'These are non-covered services because this is a pre-existing condition. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '53', '53', 40, 0, 0, '', 'Services by an immediate relative or a member of the same household are not covered.', '', 0, 0, 1, ''),
('msp_remit_codes', '54', '54', 41, 0, 0, '', 'Multiple physicians/assistants are not covered in this case. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '55', '55', 42, 0, 0, '', 'Procedure/treatment is deemed experimental/investigational by the payer. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '56', '56', 43, 0, 0, '', 'Procedure/treatment has not been deemed ''proven to be effective'' by the payer. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '58', '58', 44, 0, 0, '', 'Treatment was deemed by the payer to have been rendered in an inappropriate or invalid place of service. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '59', '59', 45, 0, 0, '', 'Processed based on multiple or concurrent procedure rules. (For example multiple surgery or diagnostic imaging, concurrent anesthesia.) Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present', '', 0, 0, 1, ''),
('msp_remit_codes', '60', '60', 46, 0, 0, '', 'Charges for outpatient services are not covered when performed within a period of time prior to or after inpatient services.', '', 0, 0, 1, ''),
('msp_remit_codes', '61', '61', 47, 0, 0, '', 'Penalty for failure to obtain second surgical opinion. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '66', '66', 48, 0, 0, '', 'Blood Deductible.', '', 0, 0, 1, ''),
('msp_remit_codes', '69', '69', 49, 0, 0, '', 'Day outlier amount.', '', 0, 0, 1, ''),
('msp_remit_codes', '70', '70', 50, 0, 0, '', 'Cost outlier - Adjustment to compensate for additional costs.', '', 0, 0, 1, ''),
('msp_remit_codes', '74', '74', 51, 0, 0, '', 'Indirect Medical Education Adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '75', '75', 52, 0, 0, '', 'Direct Medical Education Adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '76', '76', 53, 0, 0, '', 'Disproportionate Share Adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '78', '78', 54, 0, 0, '', 'Non-Covered days/Room charge adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '85', '85', 55, 0, 0, '', 'Patient Interest Adjustment (Use Only Group code PR)', '', 0, 0, 1, ''),
('msp_remit_codes', '87', '87', 56, 0, 0, '', 'Transfer amount.', '', 0, 0, 1, ''),
('msp_remit_codes', '89', '89', 57, 0, 0, '', 'Professional fees removed from charges.', '', 0, 0, 1, ''),
('msp_remit_codes', '9', '9', 9, 0, 0, '', 'The diagnosis is inconsistent with the patient''s age. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', '90', '90', 58, 0, 0, '', 'Ingredient cost adjustment. Note: To be used for pharmaceuticals only.', '', 0, 0, 1, ''),
('msp_remit_codes', '91', '91', 59, 0, 0, '', 'Dispensing fee adjustment.', '', 0, 0, 1, ''),
('msp_remit_codes', '94', '94', 60, 0, 0, '', 'Processed in Excess of charges.', '', 0, 0, 1, ''),
('msp_remit_codes', '95', '95', 61, 0, 0, '', 'Plan procedures not followed.', '', 0, 0, 1, ''),
('msp_remit_codes', '96', '96', 62, 0, 0, '', 'Non-covered charge(s). At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.) Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 S', '', 0, 0, 1, ''),
('msp_remit_codes', '97', '97', 63, 0, 0, '', 'The benefit for this service is included in the payment/allowance for another service/procedure that has already been adjudicated. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', 'A0', 'A0', 193, 0, 0, '', 'Patient refund amount.', '', 0, 0, 1, ''),
('msp_remit_codes', 'A1', 'A1', 194, 0, 0, '', 'Claim/Service denied. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', 'A5', 'A5', 195, 0, 0, '', 'Medicare Claim PPS Capital Cost Outlier Amount.', '', 0, 0, 1, ''),
('msp_remit_codes', 'A6', 'A6', 196, 0, 0, '', 'Prior hospitalization or 30 day transfer requirement not met.', '', 0, 0, 1, ''),
('msp_remit_codes', 'A7', 'A7', 197, 0, 0, '', 'Presumptive Payment Adjustment', '', 0, 0, 1, ''),
('msp_remit_codes', 'A8', 'A8', 198, 0, 0, '', 'Ungroupable DRG.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B1', 'B1', 199, 0, 0, '', 'Non-covered visits.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B10', 'B10', 200, 0, 0, '', 'Allowed amount has been reduced because a component of the basic procedure/test was paid. The beneficiary is not liable for more than the charge limit for the basic procedure/test.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B11', 'B11', 201, 0, 0, '', 'The claim/service has been transferred to the proper payer/processor for processing. Claim/service not covered by this payer/processor.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B12', 'B12', 202, 0, 0, '', 'Services not documented in patients'' medical records.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B13', 'B13', 203, 0, 0, '', 'Previously paid. Payment for this claim/service may have been provided in a previous payment.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B14', 'B14', 204, 0, 0, '', 'Only one visit or consultation per physician per day is covered.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B15', 'B15', 205, 0, 0, '', 'This service/procedure requires that a qualifying service/procedure be received and covered. The qualifying other service/procedure has not been received/adjudicated. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payme', '', 0, 0, 1, ''),
('msp_remit_codes', 'B16', 'B16', 206, 0, 0, '', '''''New Patient'' qualifications were not met.''', '', 0, 0, 1, ''),
('msp_remit_codes', 'B20', 'B20', 207, 0, 0, '', 'Procedure/service was partially or fully furnished by another provider.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B22', 'B22', 208, 0, 0, '', 'This payment is adjusted based on the diagnosis.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B23', 'B23', 209, 0, 0, '', 'Procedure billed is not authorized per your Clinical Laboratory Improvement Amendment (CLIA) proficiency test.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B4', 'B4', 210, 0, 0, '', 'Late filing penalty.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B5', 'B5', 211, 0, 0, '', 'Coverage/program guidelines were not met or were exceeded.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B7', 'B7', 212, 0, 0, '', 'This provider was not certified/eligible to be paid for this procedure/service on this date of service. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B8', 'B8', 213, 0, 0, '', 'Alternative services were available, and should have been utilized. Note: Refer to the 835 Healthcare Policy Identification Segment (loop 2110 Service Payment Information REF), if present.', '', 0, 0, 1, ''),
('msp_remit_codes', 'B9', 'B9', 214, 0, 0, '', 'Patient is enrolled in a Hospice.', '', 0, 0, 1, ''),
('msp_remit_codes', 'D23', 'D23', 215, 0, 0, '', 'This dual eligible patient is covered by Medicare Part D per Medicare Retro-Eligibility. At least one Remark Code must be provided (may be comprised of either the NCPDP Reject Reason Code, or Remittance Advice Remark Code that is not an ALERT.)', '', 0, 0, 1, ''),
('msp_remit_codes', 'W1', 'W1', 216, 0, 0, '', 'Workers'' compensation jurisdictional fee schedule adjustment. Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Class of Contract Code Identification Segment (Loop 2100 Other Claim Related Information ', '', 0, 0, 1, ''),
('msp_remit_codes', 'W2', 'W2', 217, 0, 0, '', 'Payment reduced or denied based on workers'' compensation jurisdictional regulations or payment policies, use only if no other code is applicable. Note: If adjustment is at the Claim Level, the payer must send and the provider should refer to the 835 Insur', '', 0, 0, 1, ''),
('nation_notes_replace_buttons', 'Abnormal', 'Abnormal', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('nation_notes_replace_buttons', 'No', 'No', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('nation_notes_replace_buttons', 'Normal', 'Normal', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('nation_notes_replace_buttons', 'Yes', 'Yes', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('newcrop_erx_role', 'erxadmin', 'NewCrop Admin', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('newcrop_erx_role', 'erxdoctor', 'NewCrop Doctor', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('newcrop_erx_role', 'erxmanager', 'NewCrop Manager', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('newcrop_erx_role', 'erxmidlevelPrescriber', 'NewCrop Midlevel Prescriber', 25, 0, 0, '', '', '', 0, 0, 1, '');
INSERT INTO `list_options` VALUES
('newcrop_erx_role', 'erxnurse', 'NewCrop Nurse', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('newcrop_erx_role', 'erxsupervisingDoctor', 'NewCrop Supervising Doctor', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Bill/Collect', 'Bill/Collect', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Chart Note', 'Chart Note', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Insurance', 'Insurance', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Lab Results', 'Lab Results', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'New Document', 'New Document', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'New Orders', 'New Orders', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Other', 'Other', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Patient Reminders', 'Patient Reminders', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Pharmacy', 'Pharmacy', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Prior Auth', 'Prior Auth', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Referral', 'Referral', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Test Scheduling', 'Test Scheduling', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('note_type', 'Unassigned', 'Unassigned', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('Occupation', 'engineer', 'Engineer', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('Occupation', 'lawyer', 'Lawyer', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('Occupation', 'site_worker', 'Site Worker', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '0', 'Unknown or N/A', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '1', 'First', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '4', 'Chronic/Recurrent', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '5', 'Acute on Chronic', 35, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '6', 'Early Recurrence (<2 Mo)', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '7', 'Late Recurrence (2-12 Mo)', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('occurrence', '8', 'Delayed Recurrence (> 12 Mo)', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'enc_checkup_procedure', 'Encounter Checkup Procedure', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'imaging', 'Imaging', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'intervention', 'Intervention', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'laboratory_test', 'Laboratory Test', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'patient_characteristics', 'Patient Characteristics', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'physical_exam', 'Physical Exam', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'procedure', 'Procedure', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('order_type', 'risk_category', 'Risk Category Assessment', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('ord_priority', 'high', 'High', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('ord_priority', 'normal', 'Normal', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('ord_status', 'canceled', 'Canceled', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('ord_status', 'complete', 'Complete', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('ord_status', 'pending', 'Pending', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('ord_status', 'routed', 'Routed', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('outcome', '0', 'Unassigned', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('outcome', '1', 'Resolved', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('outcome', '2', 'Improved', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('outcome', '3', 'Status quo', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('outcome', '4', 'Worse', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('outcome', '5', 'Pending followup', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('patient_flow_board_rooms', '1', 'Room 1', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('patient_flow_board_rooms', '2', 'Room 2', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('patient_flow_board_rooms', '3', 'Room 3', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_adjustment_code', 'family_payment', 'Family Payment', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_adjustment_code', 'group_payment', 'Group Payment', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_adjustment_code', 'insurance_payment', 'Insurance Payment', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_adjustment_code', 'patient_payment', 'Patient Payment', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_adjustment_code', 'pre_payment', 'Pre Payment', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_date', 'date_val', 'Date', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_date', 'deposit_date', 'Deposit Date', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_date', 'post_to_date', 'Post To Date', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_gateways', 'authorize_net', 'Authorize.net', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_ins', '0', 'Pat', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_ins', '1', 'Ins1', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_ins', '2', 'Ins2', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_ins', '3', 'Ins3', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_method', 'authorize_net', 'Authorize.net', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_method', 'bank_draft', 'Bank Draft', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_method', 'cash', 'Cash', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_method', 'check_payment', 'Check Payment', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_method', 'credit_card', 'Credit Card', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_method', 'electronic', 'Electronic', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'check_date', 'Check Date', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'payer_id', 'Ins Code', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'payment_method', 'Payment Method', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'payment_type', 'Paying Entity', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'pay_total', 'Amount', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'reference', 'Check Number', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_sort_by', 'session_id', 'Id', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_status', 'fully_paid', 'Fully Paid', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_status', 'unapplied', 'Unapplied', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_type', 'insurance', 'Insurance', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('payment_type', 'patient', 'Patient', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('personal_relationship', 'ADOPT', 'Adopted Child', 10, 0, 0, '', 'ADOPT', '', 0, 0, 1, ''),
('personal_relationship', 'AUNT', 'Aunt', 20, 0, 0, '', 'AUNT', '', 0, 0, 1, ''),
('personal_relationship', 'CHILD', 'Child', 30, 0, 0, '', 'CHILD', '', 0, 0, 1, ''),
('personal_relationship', 'CHLDFOST', 'Foster Child', 80, 0, 0, '', 'CHLDFOST', '', 0, 0, 1, ''),
('personal_relationship', 'CHLDINLAW', 'Child in-law', 40, 0, 0, '', 'CHLDINLAW', '', 0, 0, 1, ''),
('personal_relationship', 'COUSN', 'Cousin', 50, 0, 0, '', 'COUSN', '', 0, 0, 1, ''),
('personal_relationship', 'DOMPART', 'Domestic Partner', 60, 0, 0, '', 'DOMPART', '', 0, 0, 1, ''),
('personal_relationship', 'FAMMEMB', 'Family Member', 70, 0, 0, '', 'FAMMEMB', '', 0, 0, 1, ''),
('personal_relationship', 'FRND', 'Unrelated Friend', 400, 0, 0, '', 'FRND', '', 0, 0, 1, ''),
('personal_relationship', 'GGRPRN', 'Great Grandparent', 120, 0, 0, '', 'GGRPRN', '', 0, 0, 1, ''),
('personal_relationship', 'GPARNT', 'Grandparent', 100, 0, 0, '', 'GPARNT', '', 0, 0, 1, ''),
('personal_relationship', 'GRNDCHILD', 'Grandchild', 90, 0, 0, '', 'GRNDCHILD', '', 0, 0, 1, ''),
('personal_relationship', 'GRPRN', 'Grandparent', 110, 0, 0, '', 'GRPRN', '', 0, 0, 1, ''),
('personal_relationship', 'HSIB', 'Half-Sibling', 130, 0, 0, '', 'HSIB', '', 0, 0, 1, ''),
('personal_relationship', 'MAUNT', 'MaternalAunt', 140, 0, 0, '', 'MAUNT', '', 0, 0, 1, ''),
('personal_relationship', 'MCOUSN', 'MaternalCousin', 150, 0, 0, '', 'MCOUSN', '', 0, 0, 1, ''),
('personal_relationship', 'MGGRPRN', 'MaternalGreatgrandparent', 170, 0, 0, '', 'MGGRPRN', '', 0, 0, 1, ''),
('personal_relationship', 'MGRPRN', 'MaternalGrandparent', 160, 0, 0, '', 'MGRPRN', '', 0, 0, 1, ''),
('personal_relationship', 'MUNCLE', 'MaternalUncle', 180, 0, 0, '', 'MUNCLE', '', 0, 0, 1, ''),
('personal_relationship', 'NBOR', 'Neighbor', 220, 0, 0, '', 'NBOR', '', 0, 0, 1, ''),
('personal_relationship', 'NCHILD', 'Natural Child', 190, 0, 0, '', 'NCHILD', '', 0, 0, 1, ''),
('personal_relationship', 'NIENEPH', 'Niece/Nephew', 230, 0, 0, '', 'NIENEPH', '', 0, 0, 1, ''),
('personal_relationship', 'NPRN', 'Natural Parent', 200, 0, 0, '', 'NPRN', '', 0, 0, 1, ''),
('personal_relationship', 'NSIB', 'Natural Sibling', 210, 0, 0, '', 'NSIB', '', 0, 0, 1, ''),
('personal_relationship', 'PAUNT', 'PaternalAunt', 260, 0, 0, '', 'PAUNT', '', 0, 0, 1, ''),
('personal_relationship', 'PCOUSN', 'PaternalCousin', 270, 0, 0, '', 'PCOUSN', '', 0, 0, 1, ''),
('personal_relationship', 'PGGRPRN', 'PaternalGreatgrandparent', 290, 0, 0, '', 'PGGRPRN', '', 0, 0, 1, ''),
('personal_relationship', 'PGRPRN', 'PaternalGrandparent', 280, 0, 0, '', 'PGRPRN', '', 0, 0, 1, ''),
('personal_relationship', 'PRN', 'Parent', 240, 0, 0, '', 'PRN', '', 0, 0, 1, ''),
('personal_relationship', 'PRNINLAW', 'parent in-law', 250, 0, 0, '', 'PRNINLAW', '', 0, 0, 1, ''),
('personal_relationship', 'PUNCLE', 'PaternalUncle', 300, 0, 0, '', 'PUNCLE', '', 0, 0, 1, ''),
('personal_relationship', 'ROOM', 'Roommate', 310, 0, 0, '', 'ROOM', '', 0, 0, 1, ''),
('personal_relationship', 'SIB', 'Sibling', 320, 0, 0, '', 'SIB', '', 0, 0, 1, ''),
('personal_relationship', 'SIBINLAW', 'Sibling in-law', 330, 0, 0, '', 'SIBINLAW', '', 0, 0, 1, ''),
('personal_relationship', 'SIGOTHR', 'Significant Other', 340, 0, 0, '', 'SIGOTHR', '', 0, 0, 1, ''),
('personal_relationship', 'SPS', 'Spouse', 350, 0, 0, '', 'SPS', '', 0, 0, 1, ''),
('personal_relationship', 'STEP', 'Step Child', 360, 0, 0, '', 'STEP', '', 0, 0, 1, ''),
('personal_relationship', 'STPPRN', 'Step Parent', 370, 0, 0, '', 'STPPRN', '', 0, 0, 1, ''),
('personal_relationship', 'STPSIB', 'Step Sibling', 380, 0, 0, '', 'STPSIB', '', 0, 0, 1, ''),
('personal_relationship', 'UNCLE', 'Uncle', 390, 0, 0, '', 'UNCLE', '', 0, 0, 1, ''),
('physician_type', 'attending_physician', 'Attending physician', 10, 0, 0, '', '', 'SNOMED-CT:405279007', 0, 0, 1, ''),
('physician_type', 'audiological_physician', 'Audiological physician', 20, 0, 0, '', '', 'SNOMED-CT:310172001', 0, 0, 1, ''),
('physician_type', 'chest_physician', 'Chest physician', 30, 0, 0, '', '', 'SNOMED-CT:309345004', 0, 0, 1, ''),
('physician_type', 'community_health_physician', 'Community health physician', 40, 0, 0, '', '', 'SNOMED-CT:23278007', 0, 0, 1, ''),
('physician_type', 'consultant_physician', 'Consultant physician', 50, 0, 0, '', '', 'SNOMED-CT:158967008', 0, 0, 1, ''),
('physician_type', 'general_physician', 'General physician', 60, 0, 0, '', '', 'SNOMED-CT:59058001', 0, 0, 1, ''),
('physician_type', 'genitourinarymedicinephysician', 'Genitourinary medicine physician', 70, 0, 0, '', '', 'SNOMED-CT:309358003', 0, 0, 1, ''),
('physician_type', 'occupational_physician', 'Occupational physician', 80, 0, 0, '', '', 'SNOMED-CT:158973009', 0, 0, 1, ''),
('physician_type', 'palliative_care_physician', 'Palliative care physician', 90, 0, 0, '', '', 'SNOMED-CT:309359006', 0, 0, 1, ''),
('physician_type', 'physician', 'Physician', 100, 0, 0, '', '', 'SNOMED-CT:309343006', 0, 0, 1, ''),
('physician_type', 'public_health_physician', 'Public health physician', 110, 0, 0, '', '', 'SNOMED-CT:56466003', 0, 0, 1, ''),
('physician_type', 'rehabilitation_physician', 'Rehabilitation physician', 120, 0, 0, '', '', 'SNOMED-CT:309360001', 0, 0, 1, ''),
('physician_type', 'resident_physician', 'Resident physician', 130, 0, 0, '', '', 'SNOMED-CT:405277009', 0, 0, 1, ''),
('physician_type', 'specialized_physician', 'Specialized physician', 140, 0, 0, '', '', 'SNOMED-CT:69280009', 0, 0, 1, ''),
('physician_type', 'thoracic_physician', 'Thoracic physician', 150, 0, 0, '', '', 'SNOMED-CT:309346003', 0, 0, 1, ''),
('pricelevel', 'standard', 'Standard', 1, 1, 0, '', '', '', 0, 0, 1, ''),
('proc_body_site', 'arm', 'Arm', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_body_site', 'buttock', 'Buttock', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_body_site', 'oth', 'Other', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_lat', 'bilat', 'Bilateral', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_lat', 'left', 'Left', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_lat', 'right', 'Right', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_rep_status', 'cancel', 'Canceled', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_rep_status', 'correct', 'Corrected', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_rep_status', 'error', 'Error', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_rep_status', 'final', 'Final', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_rep_status', 'prelim', 'Preliminary', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_rep_status', 'review', 'Reviewed', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_abnormal', 'high', 'High', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_abnormal', 'low', 'Low', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_abnormal', 'no', 'No', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_abnormal', 'vhigh', 'Above upper panic limits', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_abnormal', 'vlow', 'Below lower panic limits', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_abnormal', 'yes', 'Yes', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_bool', 'neg', 'Negative', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_bool', 'pos', 'Positive', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_status', 'cancel', 'Canceled', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_status', 'correct', 'Corrected', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_status', 'error', 'Error', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_status', 'final', 'Final', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_status', 'incomplete', 'Incomplete', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_res_status', 'prelim', 'Preliminary', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_route', 'inj', 'Injection', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_route', 'oral', 'Oral', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_route', 'oth', 'Other', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_specimen', 'blood', 'Blood', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_specimen', 'oth', 'Other', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_specimen', 'saliva', 'Saliva', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_specimen', 'urine', 'Urine', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_type', 'grp', 'Group', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_type', 'ord', 'Procedure Order', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_type', 'rec', 'Recommendation', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_type', 'res', 'Discrete Result', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'bool', 'Boolean', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'cu_mm', 'CU.MM', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'days', 'Days', 600, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'fl', 'FL', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'gm_dl', 'GM/DL', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'g_dl', 'G/DL', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'hmol_l', 'HMOL/L', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'iu_l', 'IU/L', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'mg_dl', 'MG/DL', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'mil_cu_mm', 'Mil/CU.MM', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'months', 'Months', 620, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'oth', 'Other', 990, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'percent', 'Percent', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'percentile', 'Percentile', 100, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'pg', 'PG', 110, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'ratio', 'Ratio', 120, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'thous_cu_mm', 'Thous/CU.MM', 130, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'units', 'Units', 140, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'units_l', 'Units/L', 150, 0, 0, '', '', '', 0, 0, 1, ''),
('proc_unit', 'weeks', 'Weeks', 610, 0, 0, '', '', '', 0, 0, 1, ''),
('provider_qualifier_code', 'dk', 'DK', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('provider_qualifier_code', 'dn', 'DN', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('provider_qualifier_code', 'dq', 'DQ', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('ptlistcols', 'DOB', 'Date of Birth', 50, 0, 3, '', '', '', 0, 0, 1, ''),
('ptlistcols', 'fname', 'First Name', 20, 0, 3, '', '', '', 0, 0, 1, ''),
('ptlistcols', 'lname', 'Last Name', 10, 0, 3, '', '', '', 0, 0, 1, ''),
('ptlistcols', 'phone_home', 'Home Phone', 30, 0, 3, '', '', '', 0, 0, 1, ''),
('ptlistcols', 'pid', 'Patient ID', 70, 0, 3, '', '', '', 0, 0, 1, ''),
('race', 'abenaki', 'Abenaki', 60, 0, 0, '', '1006-6', '', 0, 0, 0, ''),
('race', 'absentee_shawnee', 'Absentee Shawnee', 70, 0, 0, '', '1579-2', '', 0, 0, 0, ''),
('race', 'acoma', 'Acoma', 80, 0, 0, '', '1490-2', '', 0, 0, 0, ''),
('race', 'afghanistani', 'Afghanistani', 90, 0, 0, '', '2126-1', '', 0, 0, 0, ''),
('race', 'african', 'African', 100, 0, 0, '', '2060-2', '', 0, 0, 0, ''),
('race', 'african_american', 'African American', 110, 0, 0, '', '2058-6', '', 0, 0, 0, ''),
('race', 'agdaagux', 'Agdaagux', 120, 0, 0, '', '1994-3', '', 0, 0, 0, ''),
('race', 'agua_caliente', 'Agua Caliente', 130, 0, 0, '', '1212-0', '', 0, 0, 0, ''),
('race', 'agua_caliente_cahuilla', 'Agua Caliente Cahuilla', 140, 0, 0, '', '1045-4', '', 0, 0, 0, ''),
('race', 'ahtna', 'Ahtna', 150, 0, 0, '', '1740-0', '', 0, 0, 0, ''),
('race', 'ak-chin', 'Ak-Chin', 160, 0, 0, '', '1654-3', '', 0, 0, 0, ''),
('race', 'akhiok', 'Akhiok', 170, 0, 0, '', '1993-5', '', 0, 0, 0, ''),
('race', 'akiachak', 'Akiachak', 180, 0, 0, '', '1897-8', '', 0, 0, 0, ''),
('race', 'akiak', 'Akiak', 190, 0, 0, '', '1898-6', '', 0, 0, 0, ''),
('race', 'akutan', 'Akutan', 200, 0, 0, '', '2007-3', '', 0, 0, 0, ''),
('race', 'alabama_coushatta', 'Alabama Coushatta', 210, 0, 0, '', '1187-4', '', 0, 0, 0, ''),
('race', 'alabama_creek', 'Alabama Creek', 220, 0, 0, '', '1194-0', '', 0, 0, 0, ''),
('race', 'alabama_quassarte', 'Alabama Quassarte', 230, 0, 0, '', '1195-7', '', 0, 0, 0, ''),
('race', 'alakanuk', 'Alakanuk', 240, 0, 0, '', '1899-4', '', 0, 0, 0, ''),
('race', 'alamo_navajo', 'Alamo Navajo', 250, 0, 0, '', '1383-9', '', 0, 0, 0, ''),
('race', 'alanvik', 'Alanvik', 260, 0, 0, '', '1744-2', '', 0, 0, 0, ''),
('race', 'alaskan_athabascan', 'Alaskan Athabascan', 290, 0, 0, '', '1739-2', '', 0, 0, 0, ''),
('race', 'alaska_indian', 'Alaska Indian', 270, 0, 0, '', '1737-6', '', 0, 0, 0, ''),
('race', 'alaska_native', 'Alaska Native', 280, 0, 0, '', '1735-0', '', 0, 0, 0, ''),
('race', 'alatna', 'Alatna', 300, 0, 0, '', '1741-8', '', 0, 0, 0, ''),
('race', 'aleknagik', 'Aleknagik', 310, 0, 0, '', '1900-0', '', 0, 0, 0, ''),
('race', 'aleut', 'Aleut', 320, 0, 0, '', '1966-1', '', 0, 0, 0, ''),
('race', 'aleutian', 'Aleutian', 340, 0, 0, '', '2009-9', '', 0, 0, 0, ''),
('race', 'aleutian_islander', 'Aleutian Islander', 350, 0, 0, '', '2010-7', '', 0, 0, 0, ''),
('race', 'aleut_corporation', 'Aleut Corporation', 330, 0, 0, '', '2008-1', '', 0, 0, 0, ''),
('race', 'alexander', 'Alexander', 360, 0, 0, '', '1742-6', '', 0, 0, 0, ''),
('race', 'algonquian', 'Algonquian', 370, 0, 0, '', '1008-2', '', 0, 0, 0, ''),
('race', 'allakaket', 'Allakaket', 380, 0, 0, '', '1743-4', '', 0, 0, 0, ''),
('race', 'allen_canyon', 'Allen Canyon', 390, 0, 0, '', '1671-7', '', 0, 0, 0, ''),
('race', 'alpine', 'Alpine', 400, 0, 0, '', '1688-1', '', 0, 0, 0, ''),
('race', 'alsea', 'Alsea', 410, 0, 0, '', '1392-0', '', 0, 0, 0, ''),
('race', 'alutiiq_aleut', 'Alutiiq Aleut', 420, 0, 0, '', '1968-7', '', 0, 0, 0, ''),
('race', 'ambler', 'Ambler', 430, 0, 0, '', '1845-7', '', 0, 0, 0, ''),
('race', 'american_indian', 'American Indian', 440, 0, 0, '', '1004-1', '', 0, 0, 0, ''),
('race', 'amer_ind_or_alaska_native', 'American Indian or Alaska Native', 10, 0, 0, '', '1002-5', '', 0, 0, 1, ''),
('race', 'anaktuvuk', 'Anaktuvuk', 460, 0, 0, '', '1846-5', '', 0, 0, 0, ''),
('race', 'anaktuvuk_pass', 'Anaktuvuk Pass', 470, 0, 0, '', '1847-3', '', 0, 0, 0, ''),
('race', 'andreafsky', 'Andreafsky', 480, 0, 0, '', '1901-8', '', 0, 0, 0, ''),
('race', 'angoon', 'Angoon', 490, 0, 0, '', '1814-3', '', 0, 0, 0, ''),
('race', 'aniak', 'Aniak', 500, 0, 0, '', '1902-6', '', 0, 0, 0, ''),
('race', 'anvik', 'Anvik', 510, 0, 0, '', '1745-9', '', 0, 0, 0, ''),
('race', 'apache', 'Apache', 520, 0, 0, '', '1010-8', '', 0, 0, 0, ''),
('race', 'arab', 'Arab', 530, 0, 0, '', '2129-5', '', 0, 0, 0, ''),
('race', 'arapaho', 'Arapaho', 540, 0, 0, '', '1021-5', '', 0, 0, 0, ''),
('race', 'arctic', 'Arctic', 550, 0, 0, '', '1746-7', '', 0, 0, 0, ''),
('race', 'arctic_slope_corporation', 'Arctic Slope Corporation', 560, 0, 0, '', '1849-9', '', 0, 0, 0, ''),
('race', 'arctic_slope_inupiat', 'Arctic Slope Inupiat', 570, 0, 0, '', '1848-1', '', 0, 0, 0, ''),
('race', 'arikara', 'Arikara', 580, 0, 0, '', '1026-4', '', 0, 0, 0, ''),
('race', 'arizona_tewa', 'Arizona Tewa', 590, 0, 0, '', '1491-0', '', 0, 0, 0, ''),
('race', 'armenian', 'Armenian', 600, 0, 0, '', '2109-7', '', 0, 0, 0, ''),
('race', 'aroostook', 'Aroostook', 610, 0, 0, '', '1366-4', '', 0, 0, 0, ''),
('race', 'Asian', 'Asian', 20, 0, 0, '', '2028-9', '', 0, 0, 1, ''),
('race', 'asian_indian', 'Asian Indian', 630, 0, 0, '', '2029-7', '', 0, 0, 0, ''),
('race', 'assiniboine', 'Assiniboine', 640, 0, 0, '', '1028-0', '', 0, 0, 0, ''),
('race', 'assiniboine_sioux', 'Assiniboine Sioux', 650, 0, 0, '', '1030-6', '', 0, 0, 0, ''),
('race', 'assyrian', 'Assyrian', 660, 0, 0, '', '2119-6', '', 0, 0, 0, ''),
('race', 'atka', 'Atka', 670, 0, 0, '', '2011-5', '', 0, 0, 0, ''),
('race', 'atmautluak', 'Atmautluak', 680, 0, 0, '', '1903-4', '', 0, 0, 0, ''),
('race', 'atqasuk', 'Atqasuk', 690, 0, 0, '', '1850-7', '', 0, 0, 0, ''),
('race', 'atsina', 'Atsina', 700, 0, 0, '', '1265-8', '', 0, 0, 0, ''),
('race', 'attacapa', 'Attacapa', 710, 0, 0, '', '1234-4', '', 0, 0, 0, ''),
('race', 'augustine', 'Augustine', 720, 0, 0, '', '1046-2', '', 0, 0, 0, ''),
('race', 'bad_river', 'Bad River', 730, 0, 0, '', '1124-7', '', 0, 0, 0, ''),
('race', 'bahamian', 'Bahamian', 740, 0, 0, '', '2067-7', '', 0, 0, 0, ''),
('race', 'bangladeshi', 'Bangladeshi', 750, 0, 0, '', '2030-5', '', 0, 0, 0, ''),
('race', 'bannock', 'Bannock', 760, 0, 0, '', '1033-0', '', 0, 0, 0, ''),
('race', 'barbadian', 'Barbadian', 770, 0, 0, '', '2068-5', '', 0, 0, 0, ''),
('race', 'barrio_libre', 'Barrio Libre', 780, 0, 0, '', '1712-9', '', 0, 0, 0, ''),
('race', 'barrow', 'Barrow', 790, 0, 0, '', '1851-5', '', 0, 0, 0, ''),
('race', 'battle_mountain', 'Battle Mountain', 800, 0, 0, '', '1587-5', '', 0, 0, 0, ''),
('race', 'bay_mills_chippewa', 'Bay Mills Chippewa', 810, 0, 0, '', '1125-4', '', 0, 0, 0, ''),
('race', 'beaver', 'Beaver', 820, 0, 0, '', '1747-5', '', 0, 0, 0, ''),
('race', 'belkofski', 'Belkofski', 830, 0, 0, '', '2012-3', '', 0, 0, 0, ''),
('race', 'bering_straits_inupiat', 'Bering Straits Inupiat', 840, 0, 0, '', '1852-3', '', 0, 0, 0, ''),
('race', 'bethel', 'Bethel', 850, 0, 0, '', '1904-2', '', 0, 0, 0, ''),
('race', 'bhutanese', 'Bhutanese', 860, 0, 0, '', '2031-3', '', 0, 0, 0, ''),
('race', 'big_cypress', 'Big Cypress', 870, 0, 0, '', '1567-7', '', 0, 0, 0, ''),
('race', 'bill_moores_slough', 'Bill Moore''s Slough', 880, 0, 0, '', '1905-9', '', 0, 0, 0, ''),
('race', 'biloxi', 'Biloxi', 890, 0, 0, '', '1235-1', '', 0, 0, 0, ''),
('race', 'birch_creek', 'Birch Creek', 900, 0, 0, '', '1748-3', '', 0, 0, 0, ''),
('race', 'bishop', 'Bishop', 910, 0, 0, '', '1417-5', '', 0, 0, 0, ''),
('race', 'black', 'Black', 920, 0, 0, '', '2056-0', '', 0, 0, 0, ''),
('race', 'blackfeet', 'Blackfeet', 940, 0, 0, '', '1035-5', '', 0, 0, 0, ''),
('race', 'blackfoot_sioux', 'Blackfoot Sioux', 950, 0, 0, '', '1610-5', '', 0, 0, 0, ''),
('race', 'black_or_afri_amer', 'Black or African American', 30, 0, 0, '', '2054-5', '', 0, 0, 1, ''),
('race', 'bois_forte', 'Bois Forte', 960, 0, 0, '', '1126-2', '', 0, 0, 0, ''),
('race', 'botswanan', 'Botswanan', 970, 0, 0, '', '2061-0', '', 0, 0, 0, ''),
('race', 'brevig_mission', 'Brevig Mission', 980, 0, 0, '', '1853-1', '', 0, 0, 0, ''),
('race', 'bridgeport', 'Bridgeport', 990, 0, 0, '', '1418-3', '', 0, 0, 0, ''),
('race', 'brighton', 'Brighton', 1000, 0, 0, '', '1568-5', '', 0, 0, 0, ''),
('race', 'bristol_bay_aleut', 'Bristol Bay Aleut', 1010, 0, 0, '', '1972-9', '', 0, 0, 0, ''),
('race', 'bristol_bay_yupik', 'Bristol Bay Yupik', 1020, 0, 0, '', '1906-7', '', 0, 0, 0, ''),
('race', 'brotherton', 'Brotherton', 1030, 0, 0, '', '1037-1', '', 0, 0, 0, ''),
('race', 'brule_sioux', 'Brule Sioux', 1040, 0, 0, '', '1611-3', '', 0, 0, 0, ''),
('race', 'buckland', 'Buckland', 1050, 0, 0, '', '1854-9', '', 0, 0, 0, ''),
('race', 'burmese', 'Burmese', 1060, 0, 0, '', '2032-1', '', 0, 0, 0, ''),
('race', 'burns_paiute', 'Burns Paiute', 1070, 0, 0, '', '1419-1', '', 0, 0, 0, ''),
('race', 'burt_lake_band', 'Burt Lake Band', 1080, 0, 0, '', '1039-7', '', 0, 0, 0, ''),
('race', 'burt_lake_chippewa', 'Burt Lake Chippewa', 1090, 0, 0, '', '1127-0', '', 0, 0, 0, ''),
('race', 'burt_lake_ottawa', 'Burt Lake Ottawa', 1100, 0, 0, '', '1412-6', '', 0, 0, 0, ''),
('race', 'cabazon', 'Cabazon', 1110, 0, 0, '', '1047-0', '', 0, 0, 0, ''),
('race', 'caddo', 'Caddo', 1120, 0, 0, '', '1041-3', '', 0, 0, 0, ''),
('race', 'cahto', 'Cahto', 1130, 0, 0, '', '1054-6', '', 0, 0, 0, ''),
('race', 'cahuilla', 'Cahuilla', 1140, 0, 0, '', '1044-7', '', 0, 0, 0, ''),
('race', 'california_tribes', 'California Tribes', 1150, 0, 0, '', '1053-8', '', 0, 0, 0, ''),
('race', 'calista_yupik', 'Calista Yupik', 1160, 0, 0, '', '1907-5', '', 0, 0, 0, ''),
('race', 'cambodian', 'Cambodian', 1170, 0, 0, '', '2033-9', '', 0, 0, 0, ''),
('race', 'campo', 'Campo', 1180, 0, 0, '', '1223-7', '', 0, 0, 0, ''),
('race', 'canadian_indian', 'Canadian Indian', 1200, 0, 0, '', '1069-4', '', 0, 0, 0, ''),
('race', 'canadian_latinamerican_indian', 'Canadian and Latin American Indian', 1190, 0, 0, '', '1068-6', '', 0, 0, 0, ''),
('race', 'canoncito_navajo', 'Canoncito Navajo', 1210, 0, 0, '', '1384-7', '', 0, 0, 0, ''),
('race', 'cantwell', 'Cantwell', 1220, 0, 0, '', '1749-1', '', 0, 0, 0, ''),
('race', 'capitan_grande', 'Capitan Grande', 1230, 0, 0, '', '1224-5', '', 0, 0, 0, ''),
('race', 'carolinian', 'Carolinian', 1240, 0, 0, '', '2092-5', '', 0, 0, 0, ''),
('race', 'carson', 'Carson', 1250, 0, 0, '', '1689-9', '', 0, 0, 0, ''),
('race', 'catawba', 'Catawba', 1260, 0, 0, '', '1076-9', '', 0, 0, 0, ''),
('race', 'cayuga', 'Cayuga', 1270, 0, 0, '', '1286-4', '', 0, 0, 0, ''),
('race', 'cayuse', 'Cayuse', 1280, 0, 0, '', '1078-5', '', 0, 0, 0, ''),
('race', 'cedarville', 'Cedarville', 1290, 0, 0, '', '1420-9', '', 0, 0, 0, ''),
('race', 'celilo', 'Celilo', 1300, 0, 0, '', '1393-8', '', 0, 0, 0, ''),
('race', 'central_american_indian', 'Central American Indian', 1310, 0, 0, '', '1070-2', '', 0, 0, 0, ''),
('race', 'central_pomo', 'Central Pomo', 1330, 0, 0, '', '1465-4', '', 0, 0, 0, ''),
('race', 'chalkyitsik', 'Chalkyitsik', 1340, 0, 0, '', '1750-9', '', 0, 0, 0, ''),
('race', 'chamorro', 'Chamorro', 1350, 0, 0, '', '2088-3', '', 0, 0, 0, ''),
('race', 'chefornak', 'Chefornak', 1360, 0, 0, '', '1908-3', '', 0, 0, 0, ''),
('race', 'chehalis', 'Chehalis', 1370, 0, 0, '', '1080-1', '', 0, 0, 0, ''),
('race', 'chemakuan', 'Chemakuan', 1380, 0, 0, '', '1082-7', '', 0, 0, 0, ''),
('race', 'chemehuevi', 'Chemehuevi', 1390, 0, 0, '', '1086-8', '', 0, 0, 0, ''),
('race', 'chenega', 'Chenega', 1400, 0, 0, '', '1985-1', '', 0, 0, 0, ''),
('race', 'cherokee', 'Cherokee', 1410, 0, 0, '', '1088-4', '', 0, 0, 0, ''),
('race', 'cherokees_of_northeast_alabama', 'Cherokees of Northeast Alabama', 1440, 0, 0, '', '1090-0', '', 0, 0, 0, ''),
('race', 'cherokees_of_southeast_alabama', 'Cherokees of Southeast Alabama', 1450, 0, 0, '', '1091-8', '', 0, 0, 0, ''),
('race', 'cherokee_alabama', 'Cherokee Alabama', 1420, 0, 0, '', '1089-2', '', 0, 0, 0, ''),
('race', 'cherokee_shawnee', 'Cherokee Shawnee', 1430, 0, 0, '', '1100-7', '', 0, 0, 0, ''),
('race', 'chevak', 'Chevak', 1460, 0, 0, '', '1909-1', '', 0, 0, 0, ''),
('race', 'cheyenne', 'Cheyenne', 1470, 0, 0, '', '1102-3', '', 0, 0, 0, ''),
('race', 'cheyenne-arapaho', 'Cheyenne-Arapaho', 1490, 0, 0, '', '1106-4', '', 0, 0, 0, ''),
('race', 'cheyenne_river_sioux', 'Cheyenne River Sioux', 1480, 0, 0, '', '1612-1', '', 0, 0, 0, ''),
('race', 'chickahominy', 'Chickahominy', 1500, 0, 0, '', '1108-0', '', 0, 0, 0, ''),
('race', 'chickaloon', 'Chickaloon', 1510, 0, 0, '', '1751-7', '', 0, 0, 0, ''),
('race', 'chickasaw', 'Chickasaw', 1520, 0, 0, '', '1112-2', '', 0, 0, 0, ''),
('race', 'chignik', 'Chignik', 1530, 0, 0, '', '1973-7', '', 0, 0, 0, ''),
('race', 'chignik_lagoon', 'Chignik Lagoon', 1540, 0, 0, '', '2013-1', '', 0, 0, 0, ''),
('race', 'chignik_lake', 'Chignik Lake', 1550, 0, 0, '', '1974-5', '', 0, 0, 0, ''),
('race', 'chilkat', 'Chilkat', 1560, 0, 0, '', '1816-8', '', 0, 0, 0, ''),
('race', 'chilkoot', 'Chilkoot', 1570, 0, 0, '', '1817-6', '', 0, 0, 0, ''),
('race', 'chimariko', 'Chimariko', 1580, 0, 0, '', '1055-3', '', 0, 0, 0, ''),
('race', 'chinese', 'Chinese', 1590, 0, 0, '', '2034-7', '', 0, 0, 0, ''),
('race', 'chinik', 'Chinik', 1600, 0, 0, '', '1855-6', '', 0, 0, 0, ''),
('race', 'chinook', 'Chinook', 1610, 0, 0, '', '1114-8', '', 0, 0, 0, ''),
('race', 'chippewa', 'Chippewa', 1620, 0, 0, '', '1123-9', '', 0, 0, 0, ''),
('race', 'chippewa_cree', 'Chippewa Cree', 1630, 0, 0, '', '1150-2', '', 0, 0, 0, ''),
('race', 'chiricahua', 'Chiricahua', 1640, 0, 0, '', '1011-6', '', 0, 0, 0, ''),
('race', 'chistochina', 'Chistochina', 1650, 0, 0, '', '1752-5', '', 0, 0, 0, ''),
('race', 'chitimacha', 'Chitimacha', 1660, 0, 0, '', '1153-6', '', 0, 0, 0, ''),
('race', 'chitina', 'Chitina', 1670, 0, 0, '', '1753-3', '', 0, 0, 0, ''),
('race', 'choctaw', 'Choctaw', 1680, 0, 0, '', '1155-1', '', 0, 0, 0, ''),
('race', 'chuathbaluk', 'Chuathbaluk', 1690, 0, 0, '', '1910-9', '', 0, 0, 0, ''),
('race', 'chugach_aleut', 'Chugach Aleut', 1700, 0, 0, '', '1984-4', '', 0, 0, 0, ''),
('race', 'chugach_corporation', 'Chugach Corporation', 1710, 0, 0, '', '1986-9', '', 0, 0, 0, ''),
('race', 'chukchansi', 'Chukchansi', 1720, 0, 0, '', '1718-6', '', 0, 0, 0, ''),
('race', 'chumash', 'Chumash', 1730, 0, 0, '', '1162-7', '', 0, 0, 0, ''),
('race', 'chuukese', 'Chuukese', 1740, 0, 0, '', '2097-4', '', 0, 0, 0, ''),
('race', 'circle', 'Circle', 1750, 0, 0, '', '1754-1', '', 0, 0, 0, ''),
('race', 'citizen_band_potawatomi', 'Citizen Band Potawatomi', 1760, 0, 0, '', '1479-5', '', 0, 0, 0, ''),
('race', 'clarks_point', 'Clark''s Point', 1770, 0, 0, '', '1911-7', '', 0, 0, 0, ''),
('race', 'clatsop', 'Clatsop', 1780, 0, 0, '', '1115-5', '', 0, 0, 0, ''),
('race', 'clear_lake', 'Clear Lake', 1790, 0, 0, '', '1165-0', '', 0, 0, 0, ''),
('race', 'clifton_choctaw', 'Clifton Choctaw', 1800, 0, 0, '', '1156-9', '', 0, 0, 0, ''),
('race', 'coast_miwok', 'Coast Miwok', 1810, 0, 0, '', '1056-1', '', 0, 0, 0, ''),
('race', 'coast_yurok', 'Coast Yurok', 1820, 0, 0, '', '1733-5', '', 0, 0, 0, ''),
('race', 'cochiti', 'Cochiti', 1830, 0, 0, '', '1492-8', '', 0, 0, 0, ''),
('race', 'cocopah', 'Cocopah', 1840, 0, 0, '', '1725-1', '', 0, 0, 0, ''),
('race', 'coeur_dalene', 'Coeur D''Alene', 1850, 0, 0, '', '1167-6', '', 0, 0, 0, ''),
('race', 'coharie', 'Coharie', 1860, 0, 0, '', '1169-2', '', 0, 0, 0, ''),
('race', 'colorado_river', 'Colorado River', 1870, 0, 0, '', '1171-8', '', 0, 0, 0, ''),
('race', 'columbia', 'Columbia', 1880, 0, 0, '', '1394-6', '', 0, 0, 0, ''),
('race', 'columbia_river_chinook', 'Columbia River Chinook', 1890, 0, 0, '', '1116-3', '', 0, 0, 0, ''),
('race', 'colville', 'Colville', 1900, 0, 0, '', '1173-4', '', 0, 0, 0, ''),
('race', 'comanche', 'Comanche', 1910, 0, 0, '', '1175-9', '', 0, 0, 0, ''),
('race', 'cook_inlet', 'Cook Inlet', 1920, 0, 0, '', '1755-8', '', 0, 0, 0, ''),
('race', 'coos', 'Coos', 1930, 0, 0, '', '1180-9', '', 0, 0, 0, ''),
('race', 'coos_lower_umpqua_siuslaw', 'Coos, Lower Umpqua, Siuslaw', 1940, 0, 0, '', '1178-3', '', 0, 0, 0, ''),
('race', 'copper_center', 'Copper Center', 1950, 0, 0, '', '1756-6', '', 0, 0, 0, ''),
('race', 'copper_river', 'Copper River', 1960, 0, 0, '', '1757-4', '', 0, 0, 0, ''),
('race', 'coquilles', 'Coquilles', 1970, 0, 0, '', '1182-5', '', 0, 0, 0, ''),
('race', 'costanoan', 'Costanoan', 1980, 0, 0, '', '1184-1', '', 0, 0, 0, ''),
('race', 'council', 'Council', 1990, 0, 0, '', '1856-4', '', 0, 0, 0, ''),
('race', 'coushatta', 'Coushatta', 2000, 0, 0, '', '1186-6', '', 0, 0, 0, ''),
('race', 'cowlitz', 'Cowlitz', 2020, 0, 0, '', '1189-0', '', 0, 0, 0, ''),
('race', 'cow_creek_umpqua', 'Cow Creek Umpqua', 2010, 0, 0, '', '1668-3', '', 0, 0, 0, ''),
('race', 'craig', 'Craig', 2030, 0, 0, '', '1818-4', '', 0, 0, 0, ''),
('race', 'cree', 'Cree', 2040, 0, 0, '', '1191-6', '', 0, 0, 0, ''),
('race', 'creek', 'Creek', 2050, 0, 0, '', '1193-2', '', 0, 0, 0, ''),
('race', 'croatan', 'Croatan', 2060, 0, 0, '', '1207-0', '', 0, 0, 0, ''),
('race', 'crooked_creek', 'Crooked Creek', 2070, 0, 0, '', '1912-5', '', 0, 0, 0, ''),
('race', 'crow', 'Crow', 2080, 0, 0, '', '1209-6', '', 0, 0, 0, ''),
('race', 'crow_creek_sioux', 'Crow Creek Sioux', 2090, 0, 0, '', '1613-9', '', 0, 0, 0, ''),
('race', 'cupeno', 'Cupeno', 2100, 0, 0, '', '1211-2', '', 0, 0, 0, ''),
('race', 'cuyapaipe', 'Cuyapaipe', 2110, 0, 0, '', '1225-2', '', 0, 0, 0, ''),
('race', 'dakota_sioux', 'Dakota Sioux', 2120, 0, 0, '', '1614-7', '', 0, 0, 0, ''),
('race', 'declne_to_specfy', 'Declined To Specify', 0, 0, 0, '', '', '', 0, 0, 1, ''),
('race', 'deering', 'Deering', 2130, 0, 0, '', '1857-2', '', 0, 0, 0, ''),
('race', 'delaware', 'Delaware', 2140, 0, 0, '', '1214-6', '', 0, 0, 0, ''),
('race', 'diegueno', 'Diegueno', 2150, 0, 0, '', '1222-9', '', 0, 0, 0, ''),
('race', 'digger', 'Digger', 2160, 0, 0, '', '1057-9', '', 0, 0, 0, ''),
('race', 'dillingham', 'Dillingham', 2170, 0, 0, '', '1913-3', '', 0, 0, 0, ''),
('race', 'dominican', 'Dominican', 2190, 0, 0, '', '2069-3', '', 0, 0, 0, ''),
('race', 'dominica_islander', 'Dominica Islander', 2180, 0, 0, '', '2070-1', '', 0, 0, 0, ''),
('race', 'dot_lake', 'Dot Lake', 2200, 0, 0, '', '1758-2', '', 0, 0, 0, ''),
('race', 'douglas', 'Douglas', 2210, 0, 0, '', '1819-2', '', 0, 0, 0, ''),
('race', 'doyon', 'Doyon', 2220, 0, 0, '', '1759-0', '', 0, 0, 0, ''),
('race', 'dresslerville', 'Dresslerville', 2230, 0, 0, '', '1690-7', '', 0, 0, 0, ''),
('race', 'dry_creek', 'Dry Creek', 2240, 0, 0, '', '1466-2', '', 0, 0, 0, ''),
('race', 'duckwater', 'Duckwater', 2260, 0, 0, '', '1588-3', '', 0, 0, 0, ''),
('race', 'duck_valley', 'Duck Valley', 2250, 0, 0, '', '1603-0', '', 0, 0, 0, ''),
('race', 'duwamish', 'Duwamish', 2270, 0, 0, '', '1519-8', '', 0, 0, 0, ''),
('race', 'eagle', 'Eagle', 2280, 0, 0, '', '1760-8', '', 0, 0, 0, ''),
('race', 'eastern_cherokee', 'Eastern Cherokee', 2290, 0, 0, '', '1092-6', '', 0, 0, 0, ''),
('race', 'eastern_chickahominy', 'Eastern Chickahominy', 2300, 0, 0, '', '1109-8', '', 0, 0, 0, ''),
('race', 'eastern_creek', 'Eastern Creek', 2310, 0, 0, '', '1196-5', '', 0, 0, 0, ''),
('race', 'eastern_delaware', 'Eastern Delaware', 2320, 0, 0, '', '1215-3', '', 0, 0, 0, ''),
('race', 'eastern_muscogee', 'Eastern Muscogee', 2330, 0, 0, '', '1197-3', '', 0, 0, 0, ''),
('race', 'eastern_pomo', 'Eastern Pomo', 2340, 0, 0, '', '1467-0', '', 0, 0, 0, ''),
('race', 'eastern_shawnee', 'Eastern Shawnee', 2350, 0, 0, '', '1580-0', '', 0, 0, 0, ''),
('race', 'eastern_tribes', 'Eastern Tribes', 2360, 0, 0, '', '1233-6', '', 0, 0, 0, ''),
('race', 'echota_cherokee', 'Echota Cherokee', 2370, 0, 0, '', '1093-4', '', 0, 0, 0, ''),
('race', 'eek', 'Eek', 2380, 0, 0, '', '1914-1', '', 0, 0, 0, ''),
('race', 'egegik', 'Egegik', 2390, 0, 0, '', '1975-2', '', 0, 0, 0, ''),
('race', 'egyptian', 'Egyptian', 2400, 0, 0, '', '2120-4', '', 0, 0, 0, ''),
('race', 'eklutna', 'Eklutna', 2410, 0, 0, '', '1761-6', '', 0, 0, 0, ''),
('race', 'ekuk', 'Ekuk', 2420, 0, 0, '', '1915-8', '', 0, 0, 0, ''),
('race', 'ekwok', 'Ekwok', 2430, 0, 0, '', '1916-6', '', 0, 0, 0, ''),
('race', 'elim', 'Elim', 2440, 0, 0, '', '1858-0', '', 0, 0, 0, ''),
('race', 'elko', 'Elko', 2450, 0, 0, '', '1589-1', '', 0, 0, 0, ''),
('race', 'ely', 'Ely', 2460, 0, 0, '', '1590-9', '', 0, 0, 0, ''),
('race', 'emmonak', 'Emmonak', 2470, 0, 0, '', '1917-4', '', 0, 0, 0, ''),
('race', 'english', 'English', 2480, 0, 0, '', '2110-5', '', 0, 0, 0, ''),
('race', 'english_bay', 'English Bay', 2490, 0, 0, '', '1987-7', '', 0, 0, 0, ''),
('race', 'eskimo', 'Eskimo', 2500, 0, 0, '', '1840-8', '', 0, 0, 0, ''),
('race', 'esselen', 'Esselen', 2510, 0, 0, '', '1250-0', '', 0, 0, 0, ''),
('race', 'ethiopian', 'Ethiopian', 2520, 0, 0, '', '2062-8', '', 0, 0, 0, ''),
('race', 'etowah_cherokee', 'Etowah Cherokee', 2530, 0, 0, '', '1094-2', '', 0, 0, 0, ''),
('race', 'european', 'European', 2540, 0, 0, '', '2108-9', '', 0, 0, 0, ''),
('race', 'evansville', 'Evansville', 2550, 0, 0, '', '1762-4', '', 0, 0, 0, ''),
('race', 'eyak', 'Eyak', 2560, 0, 0, '', '1990-1', '', 0, 0, 0, ''),
('race', 'fallon', 'Fallon', 2570, 0, 0, '', '1604-8', '', 0, 0, 0, ''),
('race', 'false_pass', 'False Pass', 2580, 0, 0, '', '2015-6', '', 0, 0, 0, ''),
('race', 'fijian', 'Fijian', 2590, 0, 0, '', '2101-4', '', 0, 0, 0, ''),
('race', 'filipino', 'Filipino', 2600, 0, 0, '', '2036-2', '', 0, 0, 0, ''),
('race', 'flandreau_santee', 'Flandreau Santee', 2610, 0, 0, '', '1615-4', '', 0, 0, 0, ''),
('race', 'florida_seminole', 'Florida Seminole', 2620, 0, 0, '', '1569-3', '', 0, 0, 0, ''),
('race', 'fond_du_lac', 'Fond du Lac', 2630, 0, 0, '', '1128-8', '', 0, 0, 0, ''),
('race', 'forest_county', 'Forest County', 2640, 0, 0, '', '1480-3', '', 0, 0, 0, ''),
('race', 'fort_belknap', 'Fort Belknap', 2650, 0, 0, '', '1252-6', '', 0, 0, 0, ''),
('race', 'fort_berthold', 'Fort Berthold', 2660, 0, 0, '', '1254-2', '', 0, 0, 0, ''),
('race', 'fort_bidwell', 'Fort Bidwell', 2670, 0, 0, '', '1421-7', '', 0, 0, 0, ''),
('race', 'fort_hall', 'Fort Hall', 2680, 0, 0, '', '1258-3', '', 0, 0, 0, ''),
('race', 'fort_independence', 'Fort Independence', 2690, 0, 0, '', '1422-5', '', 0, 0, 0, ''),
('race', 'fort_mcdermitt', 'Fort McDermitt', 2700, 0, 0, '', '1605-5', '', 0, 0, 0, ''),
('race', 'fort_mcdowell', 'Fort Mcdowell', 2710, 0, 0, '', '1256-7', '', 0, 0, 0, ''),
('race', 'fort_peck', 'Fort Peck', 2720, 0, 0, '', '1616-2', '', 0, 0, 0, ''),
('race', 'fort_peck_assiniboine_sioux', 'Fort Peck Assiniboine Sioux', 2730, 0, 0, '', '1031-4', '', 0, 0, 0, ''),
('race', 'fort_sill_apache', 'Fort Sill Apache', 2740, 0, 0, '', '1012-4', '', 0, 0, 0, ''),
('race', 'fort_yukon', 'Fort Yukon', 2750, 0, 0, '', '1763-2', '', 0, 0, 0, ''),
('race', 'french', 'French', 2760, 0, 0, '', '2111-3', '', 0, 0, 0, ''),
('race', 'french_american_indian', 'French American Indian', 2770, 0, 0, '', '1071-0', '', 0, 0, 0, ''),
('race', 'gabrieleno', 'Gabrieleno', 2780, 0, 0, '', '1260-9', '', 0, 0, 0, ''),
('race', 'gakona', 'Gakona', 2790, 0, 0, '', '1764-0', '', 0, 0, 0, ''),
('race', 'galena', 'Galena', 2800, 0, 0, '', '1765-7', '', 0, 0, 0, ''),
('race', 'gambell', 'Gambell', 2810, 0, 0, '', '1892-9', '', 0, 0, 0, ''),
('race', 'gay_head_wampanoag', 'Gay Head Wampanoag', 2820, 0, 0, '', '1680-8', '', 0, 0, 0, ''),
('race', 'georgetown_eastern_tribes', 'Georgetown (Eastern Tribes)', 2830, 0, 0, '', '1236-9', '', 0, 0, 0, ''),
('race', 'georgetown_yupik-eskimo', 'Georgetown (Yupik-Eskimo)', 2840, 0, 0, '', '1962-0', '', 0, 0, 0, ''),
('race', 'german', 'German', 2850, 0, 0, '', '2112-1', '', 0, 0, 0, ''),
('race', 'gila_bend', 'Gila Bend', 2860, 0, 0, '', '1655-0', '', 0, 0, 0, ''),
('race', 'gila_river_pima-maricopa', 'Gila River Pima-Maricopa', 2870, 0, 0, '', '1457-1', '', 0, 0, 0, ''),
('race', 'golovin', 'Golovin', 2880, 0, 0, '', '1859-8', '', 0, 0, 0, ''),
('race', 'goodnews_bay', 'Goodnews Bay', 2890, 0, 0, '', '1918-2', '', 0, 0, 0, ''),
('race', 'goshute', 'Goshute', 2900, 0, 0, '', '1591-7', '', 0, 0, 0, ''),
('race', 'grand_portage', 'Grand Portage', 2910, 0, 0, '', '1129-6', '', 0, 0, 0, ''),
('race', 'grand_ronde', 'Grand Ronde', 2920, 0, 0, '', '1262-5', '', 0, 0, 0, ''),
('race', 'grand_traverse_band', 'Grand Traverse Band of Ottawa/Chippewa', 2930, 0, 0, '', '1130-4', '', 0, 0, 0, ''),
('race', 'grayling', 'Grayling', 2940, 0, 0, '', '1766-5', '', 0, 0, 0, ''),
('race', 'greenland_eskimo', 'Greenland Eskimo', 2950, 0, 0, '', '1842-4', '', 0, 0, 0, ''),
('race', 'gros_ventres', 'Gros Ventres', 2960, 0, 0, '', '1264-1', '', 0, 0, 0, ''),
('race', 'guamanian', 'Guamanian', 2970, 0, 0, '', '2087-5', '', 0, 0, 0, ''),
('race', 'guamanian_or_chamorro', 'Guamanian or Chamorro', 2980, 0, 0, '', '2086-7', '', 0, 0, 0, ''),
('race', 'gulkana', 'Gulkana', 2990, 0, 0, '', '1767-3', '', 0, 0, 0, ''),
('race', 'haida', 'Haida', 3000, 0, 0, '', '1820-0', '', 0, 0, 0, ''),
('race', 'haitian', 'Haitian', 3010, 0, 0, '', '2071-9', '', 0, 0, 0, ''),
('race', 'haliwa', 'Haliwa', 3020, 0, 0, '', '1267-4', '', 0, 0, 0, ''),
('race', 'hannahville', 'Hannahville', 3030, 0, 0, '', '1481-1', '', 0, 0, 0, ''),
('race', 'havasupai', 'Havasupai', 3040, 0, 0, '', '1726-9', '', 0, 0, 0, ''),
('race', 'healy_lake', 'Healy Lake', 3050, 0, 0, '', '1768-1', '', 0, 0, 0, ''),
('race', 'hidatsa', 'Hidatsa', 3060, 0, 0, '', '1269-0', '', 0, 0, 0, ''),
('race', 'hmong', 'Hmong', 3070, 0, 0, '', '2037-0', '', 0, 0, 0, ''),
('race', 'ho-chunk', 'Ho-chunk', 3080, 0, 0, '', '1697-2', '', 0, 0, 0, ''),
('race', 'hoh', 'Hoh', 3090, 0, 0, '', '1083-5', '', 0, 0, 0, ''),
('race', 'hollywood_seminole', 'Hollywood Seminole', 3100, 0, 0, '', '1570-1', '', 0, 0, 0, ''),
('race', 'holy_cross', 'Holy Cross', 3110, 0, 0, '', '1769-9', '', 0, 0, 0, ''),
('race', 'hoonah', 'Hoonah', 3120, 0, 0, '', '1821-8', '', 0, 0, 0, ''),
('race', 'hoopa', 'Hoopa', 3130, 0, 0, '', '1271-6', '', 0, 0, 0, ''),
('race', 'hoopa_extension', 'Hoopa Extension', 3140, 0, 0, '', '1275-7', '', 0, 0, 0, ''),
('race', 'hooper_bay', 'Hooper Bay', 3150, 0, 0, '', '1919-0', '', 0, 0, 0, ''),
('race', 'hopi', 'Hopi', 3160, 0, 0, '', '1493-6', '', 0, 0, 0, ''),
('race', 'houma', 'Houma', 3170, 0, 0, '', '1277-3', '', 0, 0, 0, ''),
('race', 'hualapai', 'Hualapai', 3180, 0, 0, '', '1727-7', '', 0, 0, 0, ''),
('race', 'hughes', 'Hughes', 3190, 0, 0, '', '1770-7', '', 0, 0, 0, ''),
('race', 'huron_potawatomi', 'Huron Potawatomi', 3200, 0, 0, '', '1482-9', '', 0, 0, 0, ''),
('race', 'huslia', 'Huslia', 3210, 0, 0, '', '1771-5', '', 0, 0, 0, ''),
('race', 'hydaburg', 'Hydaburg', 3220, 0, 0, '', '1822-6', '', 0, 0, 0, ''),
('race', 'igiugig', 'Igiugig', 3230, 0, 0, '', '1976-0', '', 0, 0, 0, ''),
('race', 'iliamna', 'Iliamna', 3240, 0, 0, '', '1772-3', '', 0, 0, 0, ''),
('race', 'illinois_miami', 'Illinois Miami', 3250, 0, 0, '', '1359-9', '', 0, 0, 0, ''),
('race', 'inaja-cosmit', 'Inaja-Cosmit', 3260, 0, 0, '', '1279-9', '', 0, 0, 0, ''),
('race', 'inalik_diomede', 'Inalik Diomede', 3270, 0, 0, '', '1860-6', '', 0, 0, 0, ''),
('race', 'indiana_miami', 'Indiana Miami', 3290, 0, 0, '', '1360-7', '', 0, 0, 0, ''),
('race', 'indian_township', 'Indian Township', 3280, 0, 0, '', '1442-3', '', 0, 0, 0, ''),
('race', 'indonesian', 'Indonesian', 3300, 0, 0, '', '2038-8', '', 0, 0, 0, ''),
('race', 'inupiaq', 'Inupiaq', 3310, 0, 0, '', '1861-4', '', 0, 0, 0, ''),
('race', 'inupiat_eskimo', 'Inupiat Eskimo', 3320, 0, 0, '', '1844-0', '', 0, 0, 0, ''),
('race', 'iowa', 'Iowa', 3330, 0, 0, '', '1281-5', '', 0, 0, 0, ''),
('race', 'iowa_of_kansas-nebraska', 'Iowa of Kansas-Nebraska', 3340, 0, 0, '', '1282-3', '', 0, 0, 0, ''),
('race', 'iowa_of_oklahoma', 'Iowa of Oklahoma', 3350, 0, 0, '', '1283-1', '', 0, 0, 0, ''),
('race', 'iowa_sac_and_fox', 'Iowa Sac and Fox', 3360, 0, 0, '', '1552-9', '', 0, 0, 0, ''),
('race', 'iqurmuit_russian_mission', 'Iqurmuit (Russian Mission)', 3370, 0, 0, '', '1920-8', '', 0, 0, 0, ''),
('race', 'iranian', 'Iranian', 3380, 0, 0, '', '2121-2', '', 0, 0, 0, ''),
('race', 'iraqi', 'Iraqi', 3390, 0, 0, '', '2122-0', '', 0, 0, 0, ''),
('race', 'irish', 'Irish', 3400, 0, 0, '', '2113-9', '', 0, 0, 0, ''),
('race', 'iroquois', 'Iroquois', 3410, 0, 0, '', '1285-6', '', 0, 0, 0, ''),
('race', 'isleta', 'Isleta', 3420, 0, 0, '', '1494-4', '', 0, 0, 0, ''),
('race', 'israeili', 'Israeili', 3430, 0, 0, '', '2127-9', '', 0, 0, 0, ''),
('race', 'italian', 'Italian', 3440, 0, 0, '', '2114-7', '', 0, 0, 0, ''),
('race', 'ivanof_bay', 'Ivanof Bay', 3450, 0, 0, '', '1977-8', '', 0, 0, 0, ''),
('race', 'iwo_jiman', 'Iwo Jiman', 3460, 0, 0, '', '2048-7', '', 0, 0, 0, ''),
('race', 'jamaican', 'Jamaican', 3470, 0, 0, '', '2072-7', '', 0, 0, 0, ''),
('race', 'jamestown', 'Jamestown', 3480, 0, 0, '', '1313-6', '', 0, 0, 0, ''),
('race', 'japanese', 'Japanese', 3490, 0, 0, '', '2039-6', '', 0, 0, 0, ''),
('race', 'jemez', 'Jemez', 3500, 0, 0, '', '1495-1', '', 0, 0, 0, ''),
('race', 'jena_choctaw', 'Jena Choctaw', 3510, 0, 0, '', '1157-7', '', 0, 0, 0, ''),
('race', 'jicarilla_apache', 'Jicarilla Apache', 3520, 0, 0, '', '1013-2', '', 0, 0, 0, ''),
('race', 'juaneno', 'Juaneno', 3530, 0, 0, '', '1297-1', '', 0, 0, 0, ''),
('race', 'kaibab', 'Kaibab', 3540, 0, 0, '', '1423-3', '', 0, 0, 0, ''),
('race', 'kake', 'Kake', 3550, 0, 0, '', '1823-4', '', 0, 0, 0, ''),
('race', 'kaktovik', 'Kaktovik', 3560, 0, 0, '', '1862-2', '', 0, 0, 0, ''),
('race', 'kalapuya', 'Kalapuya', 3570, 0, 0, '', '1395-3', '', 0, 0, 0, ''),
('race', 'kalispel', 'Kalispel', 3580, 0, 0, '', '1299-7', '', 0, 0, 0, ''),
('race', 'kalskag', 'Kalskag', 3590, 0, 0, '', '1921-6', '', 0, 0, 0, ''),
('race', 'kaltag', 'Kaltag', 3600, 0, 0, '', '1773-1', '', 0, 0, 0, ''),
('race', 'karluk', 'Karluk', 3610, 0, 0, '', '1995-0', '', 0, 0, 0, ''),
('race', 'karuk', 'Karuk', 3620, 0, 0, '', '1301-1', '', 0, 0, 0, ''),
('race', 'kasaan', 'Kasaan', 3630, 0, 0, '', '1824-2', '', 0, 0, 0, ''),
('race', 'kashia', 'Kashia', 3640, 0, 0, '', '1468-8', '', 0, 0, 0, ''),
('race', 'kasigluk', 'Kasigluk', 3650, 0, 0, '', '1922-4', '', 0, 0, 0, ''),
('race', 'kathlamet', 'Kathlamet', 3660, 0, 0, '', '1117-1', '', 0, 0, 0, ''),
('race', 'kaw', 'Kaw', 3670, 0, 0, '', '1303-7', '', 0, 0, 0, ''),
('race', 'kawaiisu', 'Kawaiisu', 3680, 0, 0, '', '1058-7', '', 0, 0, 0, ''),
('race', 'kawerak', 'Kawerak', 3690, 0, 0, '', '1863-0', '', 0, 0, 0, ''),
('race', 'kenaitze', 'Kenaitze', 3700, 0, 0, '', '1825-9', '', 0, 0, 0, ''),
('race', 'keres', 'Keres', 3710, 0, 0, '', '1496-9', '', 0, 0, 0, ''),
('race', 'kern_river', 'Kern River', 3720, 0, 0, '', '1059-5', '', 0, 0, 0, ''),
('race', 'ketchikan', 'Ketchikan', 3730, 0, 0, '', '1826-7', '', 0, 0, 0, ''),
('race', 'keweenaw', 'Keweenaw', 3740, 0, 0, '', '1131-2', '', 0, 0, 0, ''),
('race', 'kialegee', 'Kialegee', 3750, 0, 0, '', '1198-1', '', 0, 0, 0, ''),
('race', 'kiana', 'Kiana', 3760, 0, 0, '', '1864-8', '', 0, 0, 0, ''),
('race', 'kickapoo', 'Kickapoo', 3770, 0, 0, '', '1305-2', '', 0, 0, 0, ''),
('race', 'kikiallus', 'Kikiallus', 3780, 0, 0, '', '1520-6', '', 0, 0, 0, ''),
('race', 'king_cove', 'King Cove', 3790, 0, 0, '', '2014-9', '', 0, 0, 0, ''),
('race', 'king_salmon', 'King Salmon', 3800, 0, 0, '', '1978-6', '', 0, 0, 0, ''),
('race', 'kiowa', 'Kiowa', 3810, 0, 0, '', '1309-4', '', 0, 0, 0, ''),
('race', 'kipnuk', 'Kipnuk', 3820, 0, 0, '', '1923-2', '', 0, 0, 0, ''),
('race', 'kiribati', 'Kiribati', 3830, 0, 0, '', '2096-6', '', 0, 0, 0, ''),
('race', 'kivalina', 'Kivalina', 3840, 0, 0, '', '1865-5', '', 0, 0, 0, ''),
('race', 'klallam', 'Klallam', 3850, 0, 0, '', '1312-8', '', 0, 0, 0, ''),
('race', 'klamath', 'Klamath', 3860, 0, 0, '', '1317-7', '', 0, 0, 0, ''),
('race', 'klawock', 'Klawock', 3870, 0, 0, '', '1827-5', '', 0, 0, 0, ''),
('race', 'kluti_kaah', 'Kluti Kaah', 3880, 0, 0, '', '1774-9', '', 0, 0, 0, ''),
('race', 'knik', 'Knik', 3890, 0, 0, '', '1775-6', '', 0, 0, 0, ''),
('race', 'kobuk', 'Kobuk', 3900, 0, 0, '', '1866-3', '', 0, 0, 0, ''),
('race', 'kodiak', 'Kodiak', 3910, 0, 0, '', '1996-8', '', 0, 0, 0, ''),
('race', 'kokhanok', 'Kokhanok', 3920, 0, 0, '', '1979-4', '', 0, 0, 0, ''),
('race', 'koliganek', 'Koliganek', 3930, 0, 0, '', '1924-0', '', 0, 0, 0, ''),
('race', 'kongiganak', 'Kongiganak', 3940, 0, 0, '', '1925-7', '', 0, 0, 0, ''),
('race', 'koniag_aleut', 'Koniag Aleut', 3950, 0, 0, '', '1992-7', '', 0, 0, 0, ''),
('race', 'konkow', 'Konkow', 3960, 0, 0, '', '1319-3', '', 0, 0, 0, ''),
('race', 'kootenai', 'Kootenai', 3970, 0, 0, '', '1321-9', '', 0, 0, 0, ''),
('race', 'korean', 'Korean', 3980, 0, 0, '', '2040-4', '', 0, 0, 0, ''),
('race', 'kosraean', 'Kosraean', 3990, 0, 0, '', '2093-3', '', 0, 0, 0, ''),
('race', 'kotlik', 'Kotlik', 4000, 0, 0, '', '1926-5', '', 0, 0, 0, ''),
('race', 'kotzebue', 'Kotzebue', 4010, 0, 0, '', '1867-1', '', 0, 0, 0, ''),
('race', 'koyuk', 'Koyuk', 4020, 0, 0, '', '1868-9', '', 0, 0, 0, ''),
('race', 'koyukuk', 'Koyukuk', 4030, 0, 0, '', '1776-4', '', 0, 0, 0, ''),
('race', 'kwethluk', 'Kwethluk', 4040, 0, 0, '', '1927-3', '', 0, 0, 0, ''),
('race', 'kwigillingok', 'Kwigillingok', 4050, 0, 0, '', '1928-1', '', 0, 0, 0, ''),
('race', 'kwiguk', 'Kwiguk', 4060, 0, 0, '', '1869-7', '', 0, 0, 0, ''),
('race', 'lac_courte_oreilles', 'Lac Courte Oreilles', 4090, 0, 0, '', '1132-0', '', 0, 0, 0, ''),
('race', 'lac_du_flambeau', 'Lac du Flambeau', 4100, 0, 0, '', '1133-8', '', 0, 0, 0, ''),
('race', 'lac_vieux_desert_chippewa', 'Lac Vieux Desert Chippewa', 4110, 0, 0, '', '1134-6', '', 0, 0, 0, ''),
('race', 'laguna', 'Laguna', 4120, 0, 0, '', '1497-7', '', 0, 0, 0, ''),
('race', 'lake_minchumina', 'Lake Minchumina', 4130, 0, 0, '', '1777-2', '', 0, 0, 0, ''),
('race', 'lake_superior', 'Lake Superior', 4140, 0, 0, '', '1135-3', '', 0, 0, 0, ''),
('race', 'lake_traverse_sioux', 'Lake Traverse Sioux', 4150, 0, 0, '', '1617-0', '', 0, 0, 0, ''),
('race', 'laotian', 'Laotian', 4160, 0, 0, '', '2041-2', '', 0, 0, 0, ''),
('race', 'larsen_bay', 'Larsen Bay', 4170, 0, 0, '', '1997-6', '', 0, 0, 0, ''),
('race', 'lassik', 'Lassik', 4190, 0, 0, '', '1323-5', '', 0, 0, 0, ''),
('race', 'las_vegas', 'Las Vegas', 4180, 0, 0, '', '1424-1', '', 0, 0, 0, ''),
('race', 'la_jolla', 'La Jolla', 4070, 0, 0, '', '1332-6', '', 0, 0, 0, ''),
('race', 'la_posta', 'La Posta', 4080, 0, 0, '', '1226-0', '', 0, 0, 0, ''),
('race', 'lebanese', 'Lebanese', 4200, 0, 0, '', '2123-8', '', 0, 0, 0, ''),
('race', 'leech_lake', 'Leech Lake', 4210, 0, 0, '', '1136-1', '', 0, 0, 0, ''),
('race', 'lenni-lenape', 'Lenni-Lenape', 4220, 0, 0, '', '1216-1', '', 0, 0, 0, ''),
('race', 'levelock', 'Levelock', 4230, 0, 0, '', '1929-9', '', 0, 0, 0, ''),
('race', 'liberian', 'Liberian', 4240, 0, 0, '', '2063-6', '', 0, 0, 0, ''),
('race', 'lime', 'Lime', 4250, 0, 0, '', '1778-0', '', 0, 0, 0, ''),
('race', 'lipan_apache', 'Lipan Apache', 4260, 0, 0, '', '1014-0', '', 0, 0, 0, ''),
('race', 'little_shell_chippewa', 'Little Shell Chippewa', 4270, 0, 0, '', '1137-9', '', 0, 0, 0, ''),
('race', 'lone_pine', 'Lone Pine', 4280, 0, 0, '', '1425-8', '', 0, 0, 0, ''),
('race', 'long_island', 'Long Island', 4290, 0, 0, '', '1325-0', '', 0, 0, 0, '');
INSERT INTO `list_options` VALUES
('race', 'los_coyotes', 'Los Coyotes', 4300, 0, 0, '', '1048-8', '', 0, 0, 0, ''),
('race', 'lovelock', 'Lovelock', 4310, 0, 0, '', '1426-6', '', 0, 0, 0, ''),
('race', 'lower_brule_sioux', 'Lower Brule Sioux', 4320, 0, 0, '', '1618-8', '', 0, 0, 0, ''),
('race', 'lower_elwha', 'Lower Elwha', 4330, 0, 0, '', '1314-4', '', 0, 0, 0, ''),
('race', 'lower_kalskag', 'Lower Kalskag', 4340, 0, 0, '', '1930-7', '', 0, 0, 0, ''),
('race', 'lower_muscogee', 'Lower Muscogee', 4350, 0, 0, '', '1199-9', '', 0, 0, 0, ''),
('race', 'lower_sioux', 'Lower Sioux', 4360, 0, 0, '', '1619-6', '', 0, 0, 0, ''),
('race', 'lower_skagit', 'Lower Skagit', 4370, 0, 0, '', '1521-4', '', 0, 0, 0, ''),
('race', 'luiseno', 'Luiseno', 4380, 0, 0, '', '1331-8', '', 0, 0, 0, ''),
('race', 'lumbee', 'Lumbee', 4390, 0, 0, '', '1340-9', '', 0, 0, 0, ''),
('race', 'lummi', 'Lummi', 4400, 0, 0, '', '1342-5', '', 0, 0, 0, ''),
('race', 'machis_lower_creek_indian', 'Machis Lower Creek Indian', 4410, 0, 0, '', '1200-5', '', 0, 0, 0, ''),
('race', 'madagascar', 'Madagascar', 4420, 0, 0, '', '2052-9', '', 0, 0, 0, ''),
('race', 'maidu', 'Maidu', 4430, 0, 0, '', '1344-1', '', 0, 0, 0, ''),
('race', 'makah', 'Makah', 4440, 0, 0, '', '1348-2', '', 0, 0, 0, ''),
('race', 'malaysian', 'Malaysian', 4450, 0, 0, '', '2042-0', '', 0, 0, 0, ''),
('race', 'maldivian', 'Maldivian', 4460, 0, 0, '', '2049-5', '', 0, 0, 0, ''),
('race', 'malheur_paiute', 'Malheur Paiute', 4470, 0, 0, '', '1427-4', '', 0, 0, 0, ''),
('race', 'maliseet', 'Maliseet', 4480, 0, 0, '', '1350-8', '', 0, 0, 0, ''),
('race', 'mandan', 'Mandan', 4490, 0, 0, '', '1352-4', '', 0, 0, 0, ''),
('race', 'manley_hot_springs', 'Manley Hot Springs', 4500, 0, 0, '', '1780-6', '', 0, 0, 0, ''),
('race', 'manokotak', 'Manokotak', 4510, 0, 0, '', '1931-5', '', 0, 0, 0, ''),
('race', 'manzanita', 'Manzanita', 4520, 0, 0, '', '1227-8', '', 0, 0, 0, ''),
('race', 'mariana_islander', 'Mariana Islander', 4530, 0, 0, '', '2089-1', '', 0, 0, 0, ''),
('race', 'maricopa', 'Maricopa', 4540, 0, 0, '', '1728-5', '', 0, 0, 0, ''),
('race', 'marshall', 'Marshall', 4550, 0, 0, '', '1932-3', '', 0, 0, 0, ''),
('race', 'marshallese', 'Marshallese', 4560, 0, 0, '', '2090-9', '', 0, 0, 0, ''),
('race', 'marshantucket_pequot', 'Marshantucket Pequot', 4570, 0, 0, '', '1454-8', '', 0, 0, 0, ''),
('race', 'marys_igloo', 'Mary''s Igloo', 4580, 0, 0, '', '1889-5', '', 0, 0, 0, ''),
('race', 'mashpee_wampanoag', 'Mashpee Wampanoag', 4590, 0, 0, '', '1681-6', '', 0, 0, 0, ''),
('race', 'matinecock', 'Matinecock', 4600, 0, 0, '', '1326-8', '', 0, 0, 0, ''),
('race', 'mattaponi', 'Mattaponi', 4610, 0, 0, '', '1354-0', '', 0, 0, 0, ''),
('race', 'mattole', 'Mattole', 4620, 0, 0, '', '1060-3', '', 0, 0, 0, ''),
('race', 'mauneluk_inupiat', 'Mauneluk Inupiat', 4630, 0, 0, '', '1870-5', '', 0, 0, 0, ''),
('race', 'mcgrath', 'Mcgrath', 4640, 0, 0, '', '1779-8', '', 0, 0, 0, ''),
('race', 'mdewakanton_sioux', 'Mdewakanton Sioux', 4650, 0, 0, '', '1620-4', '', 0, 0, 0, ''),
('race', 'mekoryuk', 'Mekoryuk', 4660, 0, 0, '', '1933-1', '', 0, 0, 0, ''),
('race', 'melanesian', 'Melanesian', 4670, 0, 0, '', '2100-6', '', 0, 0, 0, ''),
('race', 'menominee', 'Menominee', 4680, 0, 0, '', '1356-5', '', 0, 0, 0, ''),
('race', 'mentasta_lake', 'Mentasta Lake', 4690, 0, 0, '', '1781-4', '', 0, 0, 0, ''),
('race', 'mesa_grande', 'Mesa Grande', 4700, 0, 0, '', '1228-6', '', 0, 0, 0, ''),
('race', 'mescalero_apache', 'Mescalero Apache', 4710, 0, 0, '', '1015-7', '', 0, 0, 0, ''),
('race', 'metlakatla', 'Metlakatla', 4720, 0, 0, '', '1838-2', '', 0, 0, 0, ''),
('race', 'mexican_american_indian', 'Mexican American Indian', 4730, 0, 0, '', '1072-8', '', 0, 0, 0, ''),
('race', 'miami', 'Miami', 4740, 0, 0, '', '1358-1', '', 0, 0, 0, ''),
('race', 'miccosukee', 'Miccosukee', 4750, 0, 0, '', '1363-1', '', 0, 0, 0, ''),
('race', 'michigan_ottawa', 'Michigan Ottawa', 4760, 0, 0, '', '1413-4', '', 0, 0, 0, ''),
('race', 'micmac', 'Micmac', 4770, 0, 0, '', '1365-6', '', 0, 0, 0, ''),
('race', 'micronesian', 'Micronesian', 4780, 0, 0, '', '2085-9', '', 0, 0, 0, ''),
('race', 'middle_eastern_north_african', 'Middle Eastern or North African', 4790, 0, 0, '', '2118-8', '', 0, 0, 0, ''),
('race', 'mille_lacs', 'Mille Lacs', 4800, 0, 0, '', '1138-7', '', 0, 0, 0, ''),
('race', 'miniconjou', 'Miniconjou', 4810, 0, 0, '', '1621-2', '', 0, 0, 0, ''),
('race', 'minnesota_chippewa', 'Minnesota Chippewa', 4820, 0, 0, '', '1139-5', '', 0, 0, 0, ''),
('race', 'minto', 'Minto', 4830, 0, 0, '', '1782-2', '', 0, 0, 0, ''),
('race', 'mission_indians', 'Mission Indians', 4840, 0, 0, '', '1368-0', '', 0, 0, 0, ''),
('race', 'mississippi_choctaw', 'Mississippi Choctaw', 4850, 0, 0, '', '1158-5', '', 0, 0, 0, ''),
('race', 'missouri_sac_and_fox', 'Missouri Sac and Fox', 4860, 0, 0, '', '1553-7', '', 0, 0, 0, ''),
('race', 'miwok', 'Miwok', 4870, 0, 0, '', '1370-6', '', 0, 0, 0, ''),
('race', 'moapa', 'Moapa', 4880, 0, 0, '', '1428-2', '', 0, 0, 0, ''),
('race', 'modoc', 'Modoc', 4890, 0, 0, '', '1372-2', '', 0, 0, 0, ''),
('race', 'mohave', 'Mohave', 4900, 0, 0, '', '1729-3', '', 0, 0, 0, ''),
('race', 'mohawk', 'Mohawk', 4910, 0, 0, '', '1287-2', '', 0, 0, 0, ''),
('race', 'mohegan', 'Mohegan', 4920, 0, 0, '', '1374-8', '', 0, 0, 0, ''),
('race', 'molala', 'Molala', 4930, 0, 0, '', '1396-1', '', 0, 0, 0, ''),
('race', 'mono', 'Mono', 4940, 0, 0, '', '1376-3', '', 0, 0, 0, ''),
('race', 'montauk', 'Montauk', 4950, 0, 0, '', '1327-6', '', 0, 0, 0, ''),
('race', 'moor', 'Moor', 4960, 0, 0, '', '1237-7', '', 0, 0, 0, ''),
('race', 'morongo', 'Morongo', 4970, 0, 0, '', '1049-6', '', 0, 0, 0, ''),
('race', 'mountain_maidu', 'Mountain Maidu', 4980, 0, 0, '', '1345-8', '', 0, 0, 0, ''),
('race', 'mountain_village', 'Mountain Village', 4990, 0, 0, '', '1934-9', '', 0, 0, 0, ''),
('race', 'mowa_band_of_choctaw', 'Mowa Band of Choctaw', 5000, 0, 0, '', '1159-3', '', 0, 0, 0, ''),
('race', 'muckleshoot', 'Muckleshoot', 5010, 0, 0, '', '1522-2', '', 0, 0, 0, ''),
('race', 'munsee', 'Munsee', 5020, 0, 0, '', '1217-9', '', 0, 0, 0, ''),
('race', 'naknek', 'Naknek', 5030, 0, 0, '', '1935-6', '', 0, 0, 0, ''),
('race', 'nambe', 'Nambe', 5040, 0, 0, '', '1498-5', '', 0, 0, 0, ''),
('race', 'namibian', 'Namibian', 5050, 0, 0, '', '2064-4', '', 0, 0, 0, ''),
('race', 'nana_inupiat', 'Nana Inupiat', 5060, 0, 0, '', '1871-3', '', 0, 0, 0, ''),
('race', 'nansemond', 'Nansemond', 5070, 0, 0, '', '1238-5', '', 0, 0, 0, ''),
('race', 'nanticoke', 'Nanticoke', 5080, 0, 0, '', '1378-9', '', 0, 0, 0, ''),
('race', 'napakiak', 'Napakiak', 5090, 0, 0, '', '1937-2', '', 0, 0, 0, ''),
('race', 'napaskiak', 'Napaskiak', 5100, 0, 0, '', '1938-0', '', 0, 0, 0, ''),
('race', 'napaumute', 'Napaumute', 5110, 0, 0, '', '1936-4', '', 0, 0, 0, ''),
('race', 'narragansett', 'Narragansett', 5120, 0, 0, '', '1380-5', '', 0, 0, 0, ''),
('race', 'natchez', 'Natchez', 5130, 0, 0, '', '1239-3', '', 0, 0, 0, ''),
('race', 'native_hawaiian', 'Native Hawaiian', 5140, 0, 0, '', '2079-2', '', 0, 0, 0, ''),
('race', 'native_hawai_or_pac_island', 'Native Hawaiian or Other Pacific Islander', 40, 0, 0, '', '2076-8', '', 0, 0, 1, ''),
('race', 'nausu_waiwash', 'Nausu Waiwash', 5160, 0, 0, '', '1240-1', '', 0, 0, 0, ''),
('race', 'navajo', 'Navajo', 5170, 0, 0, '', '1382-1', '', 0, 0, 0, ''),
('race', 'nebraska_ponca', 'Nebraska Ponca', 5180, 0, 0, '', '1475-3', '', 0, 0, 0, ''),
('race', 'nebraska_winnebago', 'Nebraska Winnebago', 5190, 0, 0, '', '1698-0', '', 0, 0, 0, ''),
('race', 'nelson_lagoon', 'Nelson Lagoon', 5200, 0, 0, '', '2016-4', '', 0, 0, 0, ''),
('race', 'nenana', 'Nenana', 5210, 0, 0, '', '1783-0', '', 0, 0, 0, ''),
('race', 'nepalese', 'Nepalese', 5220, 0, 0, '', '2050-3', '', 0, 0, 0, ''),
('race', 'newhalen', 'Newhalen', 5250, 0, 0, '', '1939-8', '', 0, 0, 0, ''),
('race', 'newtok', 'Newtok', 5260, 0, 0, '', '1941-4', '', 0, 0, 0, ''),
('race', 'new_hebrides', 'New Hebrides', 5230, 0, 0, '', '2104-8', '', 0, 0, 0, ''),
('race', 'new_stuyahok', 'New Stuyahok', 5240, 0, 0, '', '1940-6', '', 0, 0, 0, ''),
('race', 'nez_perce', 'Nez Perce', 5270, 0, 0, '', '1387-0', '', 0, 0, 0, ''),
('race', 'nigerian', 'Nigerian', 5280, 0, 0, '', '2065-1', '', 0, 0, 0, ''),
('race', 'nightmute', 'Nightmute', 5290, 0, 0, '', '1942-2', '', 0, 0, 0, ''),
('race', 'nikolai', 'Nikolai', 5300, 0, 0, '', '1784-8', '', 0, 0, 0, ''),
('race', 'nikolski', 'Nikolski', 5310, 0, 0, '', '2017-2', '', 0, 0, 0, ''),
('race', 'ninilchik', 'Ninilchik', 5320, 0, 0, '', '1785-5', '', 0, 0, 0, ''),
('race', 'nipmuc', 'Nipmuc', 5330, 0, 0, '', '1241-9', '', 0, 0, 0, ''),
('race', 'nishinam', 'Nishinam', 5340, 0, 0, '', '1346-6', '', 0, 0, 0, ''),
('race', 'nisqually', 'Nisqually', 5350, 0, 0, '', '1523-0', '', 0, 0, 0, ''),
('race', 'noatak', 'Noatak', 5360, 0, 0, '', '1872-1', '', 0, 0, 0, ''),
('race', 'nomalaki', 'Nomalaki', 5370, 0, 0, '', '1389-6', '', 0, 0, 0, ''),
('race', 'nome', 'Nome', 5380, 0, 0, '', '1873-9', '', 0, 0, 0, ''),
('race', 'nondalton', 'Nondalton', 5390, 0, 0, '', '1786-3', '', 0, 0, 0, ''),
('race', 'nooksack', 'Nooksack', 5400, 0, 0, '', '1524-8', '', 0, 0, 0, ''),
('race', 'noorvik', 'Noorvik', 5410, 0, 0, '', '1874-7', '', 0, 0, 0, ''),
('race', 'northern_arapaho', 'Northern Arapaho', 5420, 0, 0, '', '1022-3', '', 0, 0, 0, ''),
('race', 'northern_cherokee', 'Northern Cherokee', 5430, 0, 0, '', '1095-9', '', 0, 0, 0, ''),
('race', 'northern_cheyenne', 'Northern Cheyenne', 5440, 0, 0, '', '1103-1', '', 0, 0, 0, ''),
('race', 'northern_paiute', 'Northern Paiute', 5450, 0, 0, '', '1429-0', '', 0, 0, 0, ''),
('race', 'northern_pomo', 'Northern Pomo', 5460, 0, 0, '', '1469-6', '', 0, 0, 0, ''),
('race', 'northway', 'Northway', 5470, 0, 0, '', '1787-1', '', 0, 0, 0, ''),
('race', 'northwest_tribes', 'Northwest Tribes', 5480, 0, 0, '', '1391-2', '', 0, 0, 0, ''),
('race', 'nuiqsut', 'Nuiqsut', 5490, 0, 0, '', '1875-4', '', 0, 0, 0, ''),
('race', 'nulato', 'Nulato', 5500, 0, 0, '', '1788-9', '', 0, 0, 0, ''),
('race', 'nunapitchukv', 'Nunapitchukv', 5510, 0, 0, '', '1943-0', '', 0, 0, 0, ''),
('race', 'oglala_sioux', 'Oglala Sioux', 5520, 0, 0, '', '1622-0', '', 0, 0, 0, ''),
('race', 'okinawan', 'Okinawan', 5530, 0, 0, '', '2043-8', '', 0, 0, 0, ''),
('race', 'oklahoma_apache', 'Oklahoma Apache', 5540, 0, 0, '', '1016-5', '', 0, 0, 0, ''),
('race', 'oklahoma_cado', 'Oklahoma Cado', 5550, 0, 0, '', '1042-1', '', 0, 0, 0, ''),
('race', 'oklahoma_choctaw', 'Oklahoma Choctaw', 5560, 0, 0, '', '1160-1', '', 0, 0, 0, ''),
('race', 'oklahoma_comanche', 'Oklahoma Comanche', 5570, 0, 0, '', '1176-7', '', 0, 0, 0, ''),
('race', 'oklahoma_delaware', 'Oklahoma Delaware', 5580, 0, 0, '', '1218-7', '', 0, 0, 0, ''),
('race', 'oklahoma_kickapoo', 'Oklahoma Kickapoo', 5590, 0, 0, '', '1306-0', '', 0, 0, 0, ''),
('race', 'oklahoma_kiowa', 'Oklahoma Kiowa', 5600, 0, 0, '', '1310-2', '', 0, 0, 0, ''),
('race', 'oklahoma_miami', 'Oklahoma Miami', 5610, 0, 0, '', '1361-5', '', 0, 0, 0, ''),
('race', 'oklahoma_ottawa', 'Oklahoma Ottawa', 5620, 0, 0, '', '1414-2', '', 0, 0, 0, ''),
('race', 'oklahoma_pawnee', 'Oklahoma Pawnee', 5630, 0, 0, '', '1446-4', '', 0, 0, 0, ''),
('race', 'oklahoma_peoria', 'Oklahoma Peoria', 5640, 0, 0, '', '1451-4', '', 0, 0, 0, ''),
('race', 'oklahoma_ponca', 'Oklahoma Ponca', 5650, 0, 0, '', '1476-1', '', 0, 0, 0, ''),
('race', 'oklahoma_sac_and_fox', 'Oklahoma Sac and Fox', 5660, 0, 0, '', '1554-5', '', 0, 0, 0, ''),
('race', 'oklahoma_seminole', 'Oklahoma Seminole', 5670, 0, 0, '', '1571-9', '', 0, 0, 0, ''),
('race', 'old_harbor', 'Old Harbor', 5680, 0, 0, '', '1998-4', '', 0, 0, 0, ''),
('race', 'omaha', 'Omaha', 5690, 0, 0, '', '1403-5', '', 0, 0, 0, ''),
('race', 'oneida', 'Oneida', 5700, 0, 0, '', '1288-0', '', 0, 0, 0, ''),
('race', 'onondaga', 'Onondaga', 5710, 0, 0, '', '1289-8', '', 0, 0, 0, ''),
('race', 'ontonagon', 'Ontonagon', 5720, 0, 0, '', '1140-3', '', 0, 0, 0, ''),
('race', 'oregon_athabaskan', 'Oregon Athabaskan', 5730, 0, 0, '', '1405-0', '', 0, 0, 0, ''),
('race', 'osage', 'Osage', 5740, 0, 0, '', '1407-6', '', 0, 0, 0, ''),
('race', 'oscarville', 'Oscarville', 5750, 0, 0, '', '1944-8', '', 0, 0, 0, ''),
('race', 'other_pacific_islander', 'Other Pacific Islander', 5760, 0, 0, '', '2500-7', '', 0, 0, 0, ''),
('race', 'other_race', 'Other Race', 5770, 0, 0, '', '2131-1', '', 0, 0, 0, ''),
('race', 'otoe-missouria', 'Otoe-Missouria', 5780, 0, 0, '', '1409-2', '', 0, 0, 0, ''),
('race', 'ottawa', 'Ottawa', 5790, 0, 0, '', '1411-8', '', 0, 0, 0, ''),
('race', 'ouzinkie', 'Ouzinkie', 5800, 0, 0, '', '1999-2', '', 0, 0, 0, ''),
('race', 'owens_valley', 'Owens Valley', 5810, 0, 0, '', '1430-8', '', 0, 0, 0, ''),
('race', 'paiute', 'Paiute', 5820, 0, 0, '', '1416-7', '', 0, 0, 0, ''),
('race', 'pakistani', 'Pakistani', 5830, 0, 0, '', '2044-6', '', 0, 0, 0, ''),
('race', 'pala', 'Pala', 5840, 0, 0, '', '1333-4', '', 0, 0, 0, ''),
('race', 'palauan', 'Palauan', 5850, 0, 0, '', '2091-7', '', 0, 0, 0, ''),
('race', 'palestinian', 'Palestinian', 5860, 0, 0, '', '2124-6', '', 0, 0, 0, ''),
('race', 'pamunkey', 'Pamunkey', 5870, 0, 0, '', '1439-9', '', 0, 0, 0, ''),
('race', 'panamint', 'Panamint', 5880, 0, 0, '', '1592-5', '', 0, 0, 0, ''),
('race', 'papua_new_guinean', 'Papua New Guinean', 5890, 0, 0, '', '2102-2', '', 0, 0, 0, ''),
('race', 'pascua_yaqui', 'Pascua Yaqui', 5900, 0, 0, '', '1713-7', '', 0, 0, 0, ''),
('race', 'passamaquoddy', 'Passamaquoddy', 5910, 0, 0, '', '1441-5', '', 0, 0, 0, ''),
('race', 'paugussett', 'Paugussett', 5920, 0, 0, '', '1242-7', '', 0, 0, 0, ''),
('race', 'pauloff_harbor', 'Pauloff Harbor', 5930, 0, 0, '', '2018-0', '', 0, 0, 0, ''),
('race', 'pauma', 'Pauma', 5940, 0, 0, '', '1334-2', '', 0, 0, 0, ''),
('race', 'pawnee', 'Pawnee', 5950, 0, 0, '', '1445-6', '', 0, 0, 0, ''),
('race', 'payson_apache', 'Payson Apache', 5960, 0, 0, '', '1017-3', '', 0, 0, 0, ''),
('race', 'pechanga', 'Pechanga', 5970, 0, 0, '', '1335-9', '', 0, 0, 0, ''),
('race', 'pedro_bay', 'Pedro Bay', 5980, 0, 0, '', '1789-7', '', 0, 0, 0, ''),
('race', 'pelican', 'Pelican', 5990, 0, 0, '', '1828-3', '', 0, 0, 0, ''),
('race', 'penobscot', 'Penobscot', 6000, 0, 0, '', '1448-0', '', 0, 0, 0, ''),
('race', 'peoria', 'Peoria', 6010, 0, 0, '', '1450-6', '', 0, 0, 0, ''),
('race', 'pequot', 'Pequot', 6020, 0, 0, '', '1453-0', '', 0, 0, 0, ''),
('race', 'perryville', 'Perryville', 6030, 0, 0, '', '1980-2', '', 0, 0, 0, ''),
('race', 'petersburg', 'Petersburg', 6040, 0, 0, '', '1829-1', '', 0, 0, 0, ''),
('race', 'picuris', 'Picuris', 6050, 0, 0, '', '1499-3', '', 0, 0, 0, ''),
('race', 'pilot_point', 'Pilot Point', 6060, 0, 0, '', '1981-0', '', 0, 0, 0, ''),
('race', 'pilot_station', 'Pilot Station', 6070, 0, 0, '', '1945-5', '', 0, 0, 0, ''),
('race', 'pima', 'Pima', 6080, 0, 0, '', '1456-3', '', 0, 0, 0, ''),
('race', 'pine_ridge_sioux', 'Pine Ridge Sioux', 6090, 0, 0, '', '1623-8', '', 0, 0, 0, ''),
('race', 'pipestone_sioux', 'Pipestone Sioux', 6100, 0, 0, '', '1624-6', '', 0, 0, 0, ''),
('race', 'piro', 'Piro', 6110, 0, 0, '', '1500-8', '', 0, 0, 0, ''),
('race', 'piscataway', 'Piscataway', 6120, 0, 0, '', '1460-5', '', 0, 0, 0, ''),
('race', 'pitkas_point', 'Pitkas Point', 6140, 0, 0, '', '1946-3', '', 0, 0, 0, ''),
('race', 'pit_river', 'Pit River', 6130, 0, 0, '', '1462-1', '', 0, 0, 0, ''),
('race', 'platinum', 'Platinum', 6150, 0, 0, '', '1947-1', '', 0, 0, 0, ''),
('race', 'pleasant_point_passamaquoddy', 'Pleasant Point Passamaquoddy', 6160, 0, 0, '', '1443-1', '', 0, 0, 0, ''),
('race', 'poarch_band', 'Poarch Band', 6170, 0, 0, '', '1201-3', '', 0, 0, 0, ''),
('race', 'pocomoke_acohonock', 'Pocomoke Acohonock', 6180, 0, 0, '', '1243-5', '', 0, 0, 0, ''),
('race', 'pohnpeian', 'Pohnpeian', 6190, 0, 0, '', '2094-1', '', 0, 0, 0, ''),
('race', 'point_hope', 'Point Hope', 6200, 0, 0, '', '1876-2', '', 0, 0, 0, ''),
('race', 'point_lay', 'Point Lay', 6210, 0, 0, '', '1877-0', '', 0, 0, 0, ''),
('race', 'pojoaque', 'Pojoaque', 6220, 0, 0, '', '1501-6', '', 0, 0, 0, ''),
('race', 'pokagon_potawatomi', 'Pokagon Potawatomi', 6230, 0, 0, '', '1483-7', '', 0, 0, 0, ''),
('race', 'polish', 'Polish', 6240, 0, 0, '', '2115-4', '', 0, 0, 0, ''),
('race', 'polynesian', 'Polynesian', 6250, 0, 0, '', '2078-4', '', 0, 0, 0, ''),
('race', 'pomo', 'Pomo', 6260, 0, 0, '', '1464-7', '', 0, 0, 0, ''),
('race', 'ponca', 'Ponca', 6270, 0, 0, '', '1474-6', '', 0, 0, 0, ''),
('race', 'poospatuck', 'Poospatuck', 6280, 0, 0, '', '1328-4', '', 0, 0, 0, ''),
('race', 'portage_creek', 'Portage Creek', 6340, 0, 0, '', '1948-9', '', 0, 0, 0, ''),
('race', 'port_gamble_klallam', 'Port Gamble Klallam', 6290, 0, 0, '', '1315-1', '', 0, 0, 0, ''),
('race', 'port_graham', 'Port Graham', 6300, 0, 0, '', '1988-5', '', 0, 0, 0, ''),
('race', 'port_heiden', 'Port Heiden', 6310, 0, 0, '', '1982-8', '', 0, 0, 0, ''),
('race', 'port_lions', 'Port Lions', 6320, 0, 0, '', '2000-8', '', 0, 0, 0, ''),
('race', 'port_madison', 'Port Madison', 6330, 0, 0, '', '1525-5', '', 0, 0, 0, ''),
('race', 'potawatomi', 'Potawatomi', 6350, 0, 0, '', '1478-7', '', 0, 0, 0, ''),
('race', 'powhatan', 'Powhatan', 6360, 0, 0, '', '1487-8', '', 0, 0, 0, ''),
('race', 'prairie_band', 'Prairie Band', 6370, 0, 0, '', '1484-5', '', 0, 0, 0, ''),
('race', 'prairie_island_sioux', 'Prairie Island Sioux', 6380, 0, 0, '', '1625-3', '', 0, 0, 0, ''),
('race', 'principal_creek_indian_nation', 'Principal Creek Indian Nation', 6390, 0, 0, '', '1202-1', '', 0, 0, 0, ''),
('race', 'prior_lake_sioux', 'Prior Lake Sioux', 6400, 0, 0, '', '1626-1', '', 0, 0, 0, ''),
('race', 'pueblo', 'Pueblo', 6410, 0, 0, '', '1489-4', '', 0, 0, 0, ''),
('race', 'puget_sound_salish', 'Puget Sound Salish', 6420, 0, 0, '', '1518-0', '', 0, 0, 0, ''),
('race', 'puyallup', 'Puyallup', 6430, 0, 0, '', '1526-3', '', 0, 0, 0, ''),
('race', 'pyramid_lake', 'Pyramid Lake', 6440, 0, 0, '', '1431-6', '', 0, 0, 0, ''),
('race', 'qagan_toyagungin', 'Qagan Toyagungin', 6450, 0, 0, '', '2019-8', '', 0, 0, 0, ''),
('race', 'qawalangin', 'Qawalangin', 6460, 0, 0, '', '2020-6', '', 0, 0, 0, ''),
('race', 'quapaw', 'Quapaw', 6470, 0, 0, '', '1541-2', '', 0, 0, 0, ''),
('race', 'quechan', 'Quechan', 6480, 0, 0, '', '1730-1', '', 0, 0, 0, ''),
('race', 'quileute', 'Quileute', 6490, 0, 0, '', '1084-3', '', 0, 0, 0, ''),
('race', 'quinault', 'Quinault', 6500, 0, 0, '', '1543-8', '', 0, 0, 0, ''),
('race', 'quinhagak', 'Quinhagak', 6510, 0, 0, '', '1949-7', '', 0, 0, 0, ''),
('race', 'ramah_navajo', 'Ramah Navajo', 6520, 0, 0, '', '1385-4', '', 0, 0, 0, ''),
('race', 'rampart', 'Rampart', 6530, 0, 0, '', '1790-5', '', 0, 0, 0, ''),
('race', 'rampough_mountain', 'Rampough Mountain', 6540, 0, 0, '', '1219-5', '', 0, 0, 0, ''),
('race', 'rappahannock', 'Rappahannock', 6550, 0, 0, '', '1545-3', '', 0, 0, 0, ''),
('race', 'red_cliff_chippewa', 'Red Cliff Chippewa', 6560, 0, 0, '', '1141-1', '', 0, 0, 0, ''),
('race', 'red_devil', 'Red Devil', 6570, 0, 0, '', '1950-5', '', 0, 0, 0, ''),
('race', 'red_lake_chippewa', 'Red Lake Chippewa', 6580, 0, 0, '', '1142-9', '', 0, 0, 0, ''),
('race', 'red_wood', 'Red Wood', 6590, 0, 0, '', '1061-1', '', 0, 0, 0, ''),
('race', 'reno-sparks', 'Reno-Sparks', 6600, 0, 0, '', '1547-9', '', 0, 0, 0, ''),
('race', 'rocky_boys_chippewa_cree', 'Rocky Boy''s Chippewa Cree', 6610, 0, 0, '', '1151-0', '', 0, 0, 0, ''),
('race', 'rosebud_sioux', 'Rosebud Sioux', 6620, 0, 0, '', '1627-9', '', 0, 0, 0, ''),
('race', 'round_valley', 'Round Valley', 6630, 0, 0, '', '1549-5', '', 0, 0, 0, ''),
('race', 'ruby', 'Ruby', 6640, 0, 0, '', '1791-3', '', 0, 0, 0, ''),
('race', 'ruby_valley', 'Ruby Valley', 6650, 0, 0, '', '1593-3', '', 0, 0, 0, ''),
('race', 'sac_and_fox', 'Sac and Fox', 6660, 0, 0, '', '1551-1', '', 0, 0, 0, ''),
('race', 'saginaw_chippewa', 'Saginaw Chippewa', 6670, 0, 0, '', '1143-7', '', 0, 0, 0, ''),
('race', 'saipanese', 'Saipanese', 6680, 0, 0, '', '2095-8', '', 0, 0, 0, ''),
('race', 'salamatof', 'Salamatof', 6690, 0, 0, '', '1792-1', '', 0, 0, 0, ''),
('race', 'salinan', 'Salinan', 6700, 0, 0, '', '1556-0', '', 0, 0, 0, ''),
('race', 'salish', 'Salish', 6710, 0, 0, '', '1558-6', '', 0, 0, 0, ''),
('race', 'salish_and_kootenai', 'Salish and Kootenai', 6720, 0, 0, '', '1560-2', '', 0, 0, 0, ''),
('race', 'salt_river_pima-maricopa', 'Salt River Pima-Maricopa', 6730, 0, 0, '', '1458-9', '', 0, 0, 0, ''),
('race', 'samish', 'Samish', 6740, 0, 0, '', '1527-1', '', 0, 0, 0, ''),
('race', 'samoan', 'Samoan', 6750, 0, 0, '', '2080-0', '', 0, 0, 0, ''),
('race', 'sandia', 'Sandia', 6880, 0, 0, '', '1507-3', '', 0, 0, 0, ''),
('race', 'sand_hill', 'Sand Hill', 6860, 0, 0, '', '1220-3', '', 0, 0, 0, ''),
('race', 'sand_point', 'Sand Point', 6870, 0, 0, '', '2023-0', '', 0, 0, 0, ''),
('race', 'sans_arc_sioux', 'Sans Arc Sioux', 6890, 0, 0, '', '1628-7', '', 0, 0, 0, ''),
('race', 'santa_ana', 'Santa Ana', 6900, 0, 0, '', '1508-1', '', 0, 0, 0, ''),
('race', 'santa_clara', 'Santa Clara', 6910, 0, 0, '', '1509-9', '', 0, 0, 0, ''),
('race', 'santa_rosa', 'Santa Rosa', 6920, 0, 0, '', '1062-9', '', 0, 0, 0, ''),
('race', 'santa_rosa_cahuilla', 'Santa Rosa Cahuilla', 6930, 0, 0, '', '1050-4', '', 0, 0, 0, ''),
('race', 'santa_ynez', 'Santa Ynez', 6940, 0, 0, '', '1163-5', '', 0, 0, 0, ''),
('race', 'santa_ysabel', 'Santa Ysabel', 6950, 0, 0, '', '1230-2', '', 0, 0, 0, ''),
('race', 'santee_sioux', 'Santee Sioux', 6960, 0, 0, '', '1629-5', '', 0, 0, 0, ''),
('race', 'santo_domingo', 'Santo Domingo', 6970, 0, 0, '', '1510-7', '', 0, 0, 0, ''),
('race', 'san_carlos_apache', 'San Carlos Apache', 6760, 0, 0, '', '1018-1', '', 0, 0, 0, ''),
('race', 'san_felipe', 'San Felipe', 6770, 0, 0, '', '1502-4', '', 0, 0, 0, ''),
('race', 'san_ildefonso', 'San Ildefonso', 6780, 0, 0, '', '1503-2', '', 0, 0, 0, ''),
('race', 'san_juan', 'San Juan', 6790, 0, 0, '', '1506-5', '', 0, 0, 0, ''),
('race', 'san_juan_de', 'San Juan De', 6800, 0, 0, '', '1505-7', '', 0, 0, 0, ''),
('race', 'san_juan_pueblo', 'San Juan Pueblo', 6810, 0, 0, '', '1504-0', '', 0, 0, 0, ''),
('race', 'san_juan_southern_paiute', 'San Juan Southern Paiute', 6820, 0, 0, '', '1432-4', '', 0, 0, 0, ''),
('race', 'san_manual', 'San Manual', 6830, 0, 0, '', '1574-3', '', 0, 0, 0, ''),
('race', 'san_pasqual', 'San Pasqual', 6840, 0, 0, '', '1229-4', '', 0, 0, 0, ''),
('race', 'san_xavier', 'San Xavier', 6850, 0, 0, '', '1656-8', '', 0, 0, 0, ''),
('race', 'sauk-suiattle', 'Sauk-Suiattle', 6980, 0, 0, '', '1528-9', '', 0, 0, 0, ''),
('race', 'sault_ste_marie_chippewa', 'Sault Ste. Marie Chippewa', 6990, 0, 0, '', '1145-2', '', 0, 0, 0, ''),
('race', 'savoonga', 'Savoonga', 7000, 0, 0, '', '1893-7', '', 0, 0, 0, ''),
('race', 'saxman', 'Saxman', 7010, 0, 0, '', '1830-9', '', 0, 0, 0, ''),
('race', 'scammon_bay', 'Scammon Bay', 7020, 0, 0, '', '1952-1', '', 0, 0, 0, ''),
('race', 'schaghticoke', 'Schaghticoke', 7030, 0, 0, '', '1562-8', '', 0, 0, 0, ''),
('race', 'scottish', 'Scottish', 7050, 0, 0, '', '2116-2', '', 0, 0, 0, ''),
('race', 'scotts_valley', 'Scotts Valley', 7060, 0, 0, '', '1470-4', '', 0, 0, 0, ''),
('race', 'scott_valley', 'Scott Valley', 7040, 0, 0, '', '1564-4', '', 0, 0, 0, ''),
('race', 'selawik', 'Selawik', 7070, 0, 0, '', '1878-8', '', 0, 0, 0, ''),
('race', 'seldovia', 'Seldovia', 7080, 0, 0, '', '1793-9', '', 0, 0, 0, ''),
('race', 'sells', 'Sells', 7090, 0, 0, '', '1657-6', '', 0, 0, 0, ''),
('race', 'seminole', 'Seminole', 7100, 0, 0, '', '1566-9', '', 0, 0, 0, ''),
('race', 'seneca', 'Seneca', 7110, 0, 0, '', '1290-6', '', 0, 0, 0, ''),
('race', 'seneca-cayuga', 'Seneca-Cayuga', 7130, 0, 0, '', '1292-2', '', 0, 0, 0, ''),
('race', 'seneca_nation', 'Seneca Nation', 7120, 0, 0, '', '1291-4', '', 0, 0, 0, ''),
('race', 'serrano', 'Serrano', 7140, 0, 0, '', '1573-5', '', 0, 0, 0, ''),
('race', 'setauket', 'Setauket', 7150, 0, 0, '', '1329-2', '', 0, 0, 0, ''),
('race', 'shageluk', 'Shageluk', 7160, 0, 0, '', '1795-4', '', 0, 0, 0, ''),
('race', 'shaktoolik', 'Shaktoolik', 7170, 0, 0, '', '1879-6', '', 0, 0, 0, ''),
('race', 'shasta', 'Shasta', 7180, 0, 0, '', '1576-8', '', 0, 0, 0, ''),
('race', 'shawnee', 'Shawnee', 7190, 0, 0, '', '1578-4', '', 0, 0, 0, ''),
('race', 'sheldons_point', 'Sheldon''s Point', 7200, 0, 0, '', '1953-9', '', 0, 0, 0, ''),
('race', 'shinnecock', 'Shinnecock', 7210, 0, 0, '', '1582-6', '', 0, 0, 0, ''),
('race', 'shishmaref', 'Shishmaref', 7220, 0, 0, '', '1880-4', '', 0, 0, 0, ''),
('race', 'shoalwater_bay', 'Shoalwater Bay', 7230, 0, 0, '', '1584-2', '', 0, 0, 0, ''),
('race', 'shoshone', 'Shoshone', 7240, 0, 0, '', '1586-7', '', 0, 0, 0, ''),
('race', 'shoshone_paiute', 'Shoshone Paiute', 7250, 0, 0, '', '1602-2', '', 0, 0, 0, ''),
('race', 'shungnak', 'Shungnak', 7260, 0, 0, '', '1881-2', '', 0, 0, 0, ''),
('race', 'siberian_eskimo', 'Siberian Eskimo', 7270, 0, 0, '', '1891-1', '', 0, 0, 0, ''),
('race', 'siberian_yupik', 'Siberian Yupik', 7280, 0, 0, '', '1894-5', '', 0, 0, 0, ''),
('race', 'siletz', 'Siletz', 7290, 0, 0, '', '1607-1', '', 0, 0, 0, ''),
('race', 'singaporean', 'Singaporean', 7300, 0, 0, '', '2051-1', '', 0, 0, 0, ''),
('race', 'sioux', 'Sioux', 7310, 0, 0, '', '1609-7', '', 0, 0, 0, ''),
('race', 'sisseton-wahpeton', 'Sisseton-Wahpeton', 7330, 0, 0, '', '1630-3', '', 0, 0, 0, ''),
('race', 'sisseton_sioux', 'Sisseton Sioux', 7320, 0, 0, '', '1631-1', '', 0, 0, 0, ''),
('race', 'sitka', 'Sitka', 7340, 0, 0, '', '1831-7', '', 0, 0, 0, ''),
('race', 'siuslaw', 'Siuslaw', 7350, 0, 0, '', '1643-6', '', 0, 0, 0, ''),
('race', 'skokomish', 'Skokomish', 7360, 0, 0, '', '1529-7', '', 0, 0, 0, ''),
('race', 'skull_valley', 'Skull Valley', 7370, 0, 0, '', '1594-1', '', 0, 0, 0, ''),
('race', 'skykomish', 'Skykomish', 7380, 0, 0, '', '1530-5', '', 0, 0, 0, ''),
('race', 'slana', 'Slana', 7390, 0, 0, '', '1794-7', '', 0, 0, 0, ''),
('race', 'sleetmute', 'Sleetmute', 7400, 0, 0, '', '1954-7', '', 0, 0, 0, ''),
('race', 'snohomish', 'Snohomish', 7410, 0, 0, '', '1531-3', '', 0, 0, 0, ''),
('race', 'snoqualmie', 'Snoqualmie', 7420, 0, 0, '', '1532-1', '', 0, 0, 0, ''),
('race', 'soboba', 'Soboba', 7430, 0, 0, '', '1336-7', '', 0, 0, 0, ''),
('race', 'sokoagon_chippewa', 'Sokoagon Chippewa', 7440, 0, 0, '', '1146-0', '', 0, 0, 0, ''),
('race', 'solomon', 'Solomon', 7450, 0, 0, '', '1882-0', '', 0, 0, 0, ''),
('race', 'solomon_islander', 'Solomon Islander', 7460, 0, 0, '', '2103-0', '', 0, 0, 0, ''),
('race', 'southeastern_indians', 'Southeastern Indians', 7510, 0, 0, '', '1244-3', '', 0, 0, 0, ''),
('race', 'southeast_alaska', 'Southeast Alaska', 7500, 0, 0, '', '1811-9', '', 0, 0, 0, ''),
('race', 'southern_arapaho', 'Southern Arapaho', 7520, 0, 0, '', '1023-1', '', 0, 0, 0, ''),
('race', 'southern_cheyenne', 'Southern Cheyenne', 7530, 0, 0, '', '1104-9', '', 0, 0, 0, ''),
('race', 'southern_paiute', 'Southern Paiute', 7540, 0, 0, '', '1433-2', '', 0, 0, 0, ''),
('race', 'south_american_indian', 'South American Indian', 7470, 0, 0, '', '1073-6', '', 0, 0, 0, ''),
('race', 'south_fork_shoshone', 'South Fork Shoshone', 7480, 0, 0, '', '1595-8', '', 0, 0, 0, ''),
('race', 'south_naknek', 'South Naknek', 7490, 0, 0, '', '2024-8', '', 0, 0, 0, ''),
('race', 'spanish_american_indian', 'Spanish American Indian', 7550, 0, 0, '', '1074-4', '', 0, 0, 0, ''),
('race', 'spirit_lake_sioux', 'Spirit Lake Sioux', 7560, 0, 0, '', '1632-9', '', 0, 0, 0, ''),
('race', 'spokane', 'Spokane', 7570, 0, 0, '', '1645-1', '', 0, 0, 0, ''),
('race', 'squaxin_island', 'Squaxin Island', 7580, 0, 0, '', '1533-9', '', 0, 0, 0, ''),
('race', 'sri_lankan', 'Sri Lankan', 7590, 0, 0, '', '2045-3', '', 0, 0, 0, ''),
('race', 'standing_rock_sioux', 'Standing Rock Sioux', 7650, 0, 0, '', '1633-7', '', 0, 0, 0, ''),
('race', 'star_clan_of_muscogee_creeks', 'Star Clan of Muscogee Creeks', 7660, 0, 0, '', '1203-9', '', 0, 0, 0, ''),
('race', 'stebbins', 'Stebbins', 7670, 0, 0, '', '1955-4', '', 0, 0, 0, ''),
('race', 'steilacoom', 'Steilacoom', 7680, 0, 0, '', '1534-7', '', 0, 0, 0, ''),
('race', 'stevens', 'Stevens', 7690, 0, 0, '', '1796-2', '', 0, 0, 0, ''),
('race', 'stewart', 'Stewart', 7700, 0, 0, '', '1647-7', '', 0, 0, 0, ''),
('race', 'stillaguamish', 'Stillaguamish', 7710, 0, 0, '', '1535-4', '', 0, 0, 0, ''),
('race', 'stockbridge', 'Stockbridge', 7720, 0, 0, '', '1649-3', '', 0, 0, 0, ''),
('race', 'stonyford', 'Stonyford', 7740, 0, 0, '', '1471-2', '', 0, 0, 0, ''),
('race', 'stony_river', 'Stony River', 7730, 0, 0, '', '1797-0', '', 0, 0, 0, ''),
('race', 'st_croix_chippewa', 'St. Croix Chippewa', 7600, 0, 0, '', '1144-5', '', 0, 0, 0, ''),
('race', 'st_george', 'St. George', 7610, 0, 0, '', '2021-4', '', 0, 0, 0, ''),
('race', 'st_marys', 'St. Mary''s', 7620, 0, 0, '', '1963-8', '', 0, 0, 0, ''),
('race', 'st_michael', 'St. Michael', 7630, 0, 0, '', '1951-3', '', 0, 0, 0, ''),
('race', 'st_paul', 'St. Paul', 7640, 0, 0, '', '2022-2', '', 0, 0, 0, ''),
('race', 'sugpiaq', 'Sugpiaq', 7750, 0, 0, '', '2002-4', '', 0, 0, 0, ''),
('race', 'sulphur_bank', 'Sulphur Bank', 7760, 0, 0, '', '1472-0', '', 0, 0, 0, ''),
('race', 'summit_lake', 'Summit Lake', 7770, 0, 0, '', '1434-0', '', 0, 0, 0, ''),
('race', 'suqpigaq', 'Suqpigaq', 7780, 0, 0, '', '2004-0', '', 0, 0, 0, ''),
('race', 'suquamish', 'Suquamish', 7790, 0, 0, '', '1536-2', '', 0, 0, 0, ''),
('race', 'susanville', 'Susanville', 7800, 0, 0, '', '1651-9', '', 0, 0, 0, ''),
('race', 'susquehanock', 'Susquehanock', 7810, 0, 0, '', '1245-0', '', 0, 0, 0, ''),
('race', 'swinomish', 'Swinomish', 7820, 0, 0, '', '1537-0', '', 0, 0, 0, ''),
('race', 'sycuan', 'Sycuan', 7830, 0, 0, '', '1231-0', '', 0, 0, 0, ''),
('race', 'syrian', 'Syrian', 7840, 0, 0, '', '2125-3', '', 0, 0, 0, ''),
('race', 'table_bluff', 'Table Bluff', 7850, 0, 0, '', '1705-3', '', 0, 0, 0, ''),
('race', 'tachi', 'Tachi', 7860, 0, 0, '', '1719-4', '', 0, 0, 0, ''),
('race', 'tahitian', 'Tahitian', 7870, 0, 0, '', '2081-8', '', 0, 0, 0, ''),
('race', 'taiwanese', 'Taiwanese', 7880, 0, 0, '', '2035-4', '', 0, 0, 0, ''),
('race', 'takelma', 'Takelma', 7890, 0, 0, '', '1063-7', '', 0, 0, 0, ''),
('race', 'takotna', 'Takotna', 7900, 0, 0, '', '1798-8', '', 0, 0, 0, ''),
('race', 'talakamish', 'Talakamish', 7910, 0, 0, '', '1397-9', '', 0, 0, 0, ''),
('race', 'tanacross', 'Tanacross', 7920, 0, 0, '', '1799-6', '', 0, 0, 0, ''),
('race', 'tanaina', 'Tanaina', 7930, 0, 0, '', '1800-2', '', 0, 0, 0, ''),
('race', 'tanana', 'Tanana', 7940, 0, 0, '', '1801-0', '', 0, 0, 0, ''),
('race', 'tanana_chiefs', 'Tanana Chiefs', 7950, 0, 0, '', '1802-8', '', 0, 0, 0, ''),
('race', 'taos', 'Taos', 7960, 0, 0, '', '1511-5', '', 0, 0, 0, ''),
('race', 'tatitlek', 'Tatitlek', 7970, 0, 0, '', '1969-5', '', 0, 0, 0, ''),
('race', 'tazlina', 'Tazlina', 7980, 0, 0, '', '1803-6', '', 0, 0, 0, ''),
('race', 'te-moak_western_shoshone', 'Te-Moak Western Shoshone', 8020, 0, 0, '', '1596-6', '', 0, 0, 0, ''),
('race', 'telida', 'Telida', 7990, 0, 0, '', '1804-4', '', 0, 0, 0, ''),
('race', 'teller', 'Teller', 8000, 0, 0, '', '1883-8', '', 0, 0, 0, ''),
('race', 'temecula', 'Temecula', 8010, 0, 0, '', '1338-3', '', 0, 0, 0, ''),
('race', 'tenakee_springs', 'Tenakee Springs', 8030, 0, 0, '', '1832-5', '', 0, 0, 0, ''),
('race', 'tenino', 'Tenino', 8040, 0, 0, '', '1398-7', '', 0, 0, 0, ''),
('race', 'tesuque', 'Tesuque', 8050, 0, 0, '', '1512-3', '', 0, 0, 0, ''),
('race', 'tetlin', 'Tetlin', 8060, 0, 0, '', '1805-1', '', 0, 0, 0, ''),
('race', 'teton_sioux', 'Teton Sioux', 8070, 0, 0, '', '1634-5', '', 0, 0, 0, ''),
('race', 'tewa', 'Tewa', 8080, 0, 0, '', '1513-1', '', 0, 0, 0, ''),
('race', 'texas_kickapoo', 'Texas Kickapoo', 8090, 0, 0, '', '1307-8', '', 0, 0, 0, ''),
('race', 'thai', 'Thai', 8100, 0, 0, '', '2046-1', '', 0, 0, 0, ''),
('race', 'thlopthlocco', 'Thlopthlocco', 8110, 0, 0, '', '1204-7', '', 0, 0, 0, ''),
('race', 'tigua', 'Tigua', 8120, 0, 0, '', '1514-9', '', 0, 0, 0, ''),
('race', 'tillamook', 'Tillamook', 8130, 0, 0, '', '1399-5', '', 0, 0, 0, ''),
('race', 'timbi-sha_shoshone', 'Timbi-Sha Shoshone', 8140, 0, 0, '', '1597-4', '', 0, 0, 0, ''),
('race', 'tlingit', 'Tlingit', 8150, 0, 0, '', '1833-3', '', 0, 0, 0, ''),
('race', 'tlingit-haida', 'Tlingit-Haida', 8160, 0, 0, '', '1813-5', '', 0, 0, 0, ''),
('race', 'tlingit_and_haida_tribes', 'Central Council of Tlingit and Haida Tribes', 1320, 0, 0, '', '1815-0', '', 0, 0, 0, ''),
('race', 'tobagoan', 'Tobagoan', 8170, 0, 0, '', '2073-5', '', 0, 0, 0, ''),
('race', 'togiak', 'Togiak', 8180, 0, 0, '', '1956-2', '', 0, 0, 0, ''),
('race', 'tohono_oodham', 'Tohono O''Odham', 8190, 0, 0, '', '1653-5', '', 0, 0, 0, ''),
('race', 'tok', 'Tok', 8200, 0, 0, '', '1806-9', '', 0, 0, 0, ''),
('race', 'tokelauan', 'Tokelauan', 8210, 0, 0, '', '2083-4', '', 0, 0, 0, ''),
('race', 'toksook', 'Toksook', 8220, 0, 0, '', '1957-0', '', 0, 0, 0, ''),
('race', 'tolowa', 'Tolowa', 8230, 0, 0, '', '1659-2', '', 0, 0, 0, ''),
('race', 'tonawanda_seneca', 'Tonawanda Seneca', 8240, 0, 0, '', '1293-0', '', 0, 0, 0, ''),
('race', 'tongan', 'Tongan', 8250, 0, 0, '', '2082-6', '', 0, 0, 0, ''),
('race', 'tonkawa', 'Tonkawa', 8260, 0, 0, '', '1661-8', '', 0, 0, 0, ''),
('race', 'torres-martinez', 'Torres-Martinez', 8270, 0, 0, '', '1051-2', '', 0, 0, 0, ''),
('race', 'trinidadian', 'Trinidadian', 8280, 0, 0, '', '2074-3', '', 0, 0, 0, ''),
('race', 'trinity', 'Trinity', 8290, 0, 0, '', '1272-4', '', 0, 0, 0, ''),
('race', 'tsimshian', 'Tsimshian', 8300, 0, 0, '', '1837-4', '', 0, 0, 0, ''),
('race', 'tuckabachee', 'Tuckabachee', 8310, 0, 0, '', '1205-4', '', 0, 0, 0, ''),
('race', 'tulalip', 'Tulalip', 8320, 0, 0, '', '1538-8', '', 0, 0, 0, ''),
('race', 'tule_river', 'Tule River', 8330, 0, 0, '', '1720-2', '', 0, 0, 0, ''),
('race', 'tulukskak', 'Tulukskak', 8340, 0, 0, '', '1958-8', '', 0, 0, 0, ''),
('race', 'tunica_biloxi', 'Tunica Biloxi', 8350, 0, 0, '', '1246-8', '', 0, 0, 0, ''),
('race', 'tuntutuliak', 'Tuntutuliak', 8360, 0, 0, '', '1959-6', '', 0, 0, 0, ''),
('race', 'tununak', 'Tununak', 8370, 0, 0, '', '1960-4', '', 0, 0, 0, ''),
('race', 'turtle_mountain', 'Turtle Mountain', 8380, 0, 0, '', '1147-8', '', 0, 0, 0, ''),
('race', 'tuscarora', 'Tuscarora', 8390, 0, 0, '', '1294-8', '', 0, 0, 0, ''),
('race', 'tuscola', 'Tuscola', 8400, 0, 0, '', '1096-7', '', 0, 0, 0, ''),
('race', 'twenty-nine_palms', 'Twenty-Nine Palms', 8410, 0, 0, '', '1337-5', '', 0, 0, 0, ''),
('race', 'twin_hills', 'Twin Hills', 8420, 0, 0, '', '1961-2', '', 0, 0, 0, ''),
('race', 'two_kettle_sioux', 'Two Kettle Sioux', 8430, 0, 0, '', '1635-2', '', 0, 0, 0, ''),
('race', 'tygh', 'Tygh', 8440, 0, 0, '', '1663-4', '', 0, 0, 0, ''),
('race', 'tyonek', 'Tyonek', 8450, 0, 0, '', '1807-7', '', 0, 0, 0, ''),
('race', 'ugashik', 'Ugashik', 8460, 0, 0, '', '1970-3', '', 0, 0, 0, ''),
('race', 'uintah_ute', 'Uintah Ute', 8470, 0, 0, '', '1672-5', '', 0, 0, 0, ''),
('race', 'umatilla', 'Umatilla', 8480, 0, 0, '', '1665-9', '', 0, 0, 0, ''),
('race', 'umkumiate', 'Umkumiate', 8490, 0, 0, '', '1964-6', '', 0, 0, 0, ''),
('race', 'umpqua', 'Umpqua', 8500, 0, 0, '', '1667-5', '', 0, 0, 0, ''),
('race', 'unalakleet', 'Unalakleet', 8510, 0, 0, '', '1884-6', '', 0, 0, 0, ''),
('race', 'unalaska', 'Unalaska', 8520, 0, 0, '', '2025-5', '', 0, 0, 0, ''),
('race', 'unangan_aleut', 'Unangan Aleut', 8530, 0, 0, '', '2006-5', '', 0, 0, 0, ''),
('race', 'unga', 'Unga', 8540, 0, 0, '', '2026-3', '', 0, 0, 0, ''),
('race', 'united_ketowah_band_of_cheroke', 'United Keetowah Band of Cherokee', 8550, 0, 0, '', '1097-5', '', 0, 0, 0, ''),
('race', 'upper_chinook', 'Upper Chinook', 8560, 0, 0, '', '1118-9', '', 0, 0, 0, ''),
('race', 'upper_sioux', 'Upper Sioux', 8570, 0, 0, '', '1636-0', '', 0, 0, 0, ''),
('race', 'upper_skagit', 'Upper Skagit', 8580, 0, 0, '', '1539-6', '', 0, 0, 0, ''),
('race', 'ute', 'Ute', 8590, 0, 0, '', '1670-9', '', 0, 0, 0, ''),
('race', 'ute_mountain_ute', 'Ute Mountain Ute', 8600, 0, 0, '', '1673-3', '', 0, 0, 0, ''),
('race', 'utu_utu_gwaitu_paiute', 'Utu Utu Gwaitu Paiute', 8610, 0, 0, '', '1435-7', '', 0, 0, 0, ''),
('race', 'venetie', 'Venetie', 8620, 0, 0, '', '1808-5', '', 0, 0, 0, ''),
('race', 'vietnamese', 'Vietnamese', 8630, 0, 0, '', '2047-9', '', 0, 0, 0, ''),
('race', 'waccamaw-siousan', 'Waccamaw-Siousan', 8640, 0, 0, '', '1247-6', '', 0, 0, 0, ''),
('race', 'wahpekute_sioux', 'Wahpekute Sioux', 8650, 0, 0, '', '1637-8', '', 0, 0, 0, ''),
('race', 'wahpeton_sioux', 'Wahpeton Sioux', 8660, 0, 0, '', '1638-6', '', 0, 0, 0, ''),
('race', 'wailaki', 'Wailaki', 8670, 0, 0, '', '1675-8', '', 0, 0, 0, ''),
('race', 'wainwright', 'Wainwright', 8680, 0, 0, '', '1885-3', '', 0, 0, 0, ''),
('race', 'wakiakum_chinook', 'Wakiakum Chinook', 8690, 0, 0, '', '1119-7', '', 0, 0, 0, ''),
('race', 'wales', 'Wales', 8700, 0, 0, '', '1886-1', '', 0, 0, 0, ''),
('race', 'walker_river', 'Walker River', 8710, 0, 0, '', '1436-5', '', 0, 0, 0, ''),
('race', 'walla-walla', 'Walla-Walla', 8720, 0, 0, '', '1677-4', '', 0, 0, 0, ''),
('race', 'wampanoag', 'Wampanoag', 8730, 0, 0, '', '1679-0', '', 0, 0, 0, ''),
('race', 'wappo', 'Wappo', 8740, 0, 0, '', '1064-5', '', 0, 0, 0, ''),
('race', 'warm_springs', 'Warm Springs', 8750, 0, 0, '', '1683-2', '', 0, 0, 0, ''),
('race', 'wascopum', 'Wascopum', 8760, 0, 0, '', '1685-7', '', 0, 0, 0, ''),
('race', 'washakie', 'Washakie', 8770, 0, 0, '', '1598-2', '', 0, 0, 0, ''),
('race', 'washoe', 'Washoe', 8780, 0, 0, '', '1687-3', '', 0, 0, 0, ''),
('race', 'wazhaza_sioux', 'Wazhaza Sioux', 8790, 0, 0, '', '1639-4', '', 0, 0, 0, ''),
('race', 'wenatchee', 'Wenatchee', 8800, 0, 0, '', '1400-1', '', 0, 0, 0, ''),
('race', 'western_cherokee', 'Western Cherokee', 8820, 0, 0, '', '1098-3', '', 0, 0, 0, ''),
('race', 'western_chickahominy', 'Western Chickahominy', 8830, 0, 0, '', '1110-6', '', 0, 0, 0, ''),
('race', 'west_indian', 'West Indian', 8810, 0, 0, '', '2075-0', '', 0, 0, 0, ''),
('race', 'whilkut', 'Whilkut', 8840, 0, 0, '', '1273-2', '', 0, 0, 0, ''),
('race', 'white', 'White', 50, 0, 0, '', '2106-3', '', 0, 0, 1, ''),
('race', 'white_earth', 'White Earth', 8860, 0, 0, '', '1148-6', '', 0, 0, 0, ''),
('race', 'white_mountain', 'White Mountain', 8870, 0, 0, '', '1887-9', '', 0, 0, 0, ''),
('race', 'white_mountain_apache', 'White Mountain Apache', 8880, 0, 0, '', '1019-9', '', 0, 0, 0, ''),
('race', 'white_mountain_inupiat', 'White Mountain Inupiat', 8890, 0, 0, '', '1888-7', '', 0, 0, 0, ''),
('race', 'wichita', 'Wichita', 8900, 0, 0, '', '1692-3', '', 0, 0, 0, ''),
('race', 'wicomico', 'Wicomico', 8910, 0, 0, '', '1248-4', '', 0, 0, 0, ''),
('race', 'willapa_chinook', 'Willapa Chinook', 8920, 0, 0, '', '1120-5', '', 0, 0, 0, ''),
('race', 'wind_river', 'Wind River', 8930, 0, 0, '', '1694-9', '', 0, 0, 0, ''),
('race', 'wind_river_arapaho', 'Wind River Arapaho', 8940, 0, 0, '', '1024-9', '', 0, 0, 0, ''),
('race', 'wind_river_shoshone', 'Wind River Shoshone', 8950, 0, 0, '', '1599-0', '', 0, 0, 0, ''),
('race', 'winnebago', 'Winnebago', 8960, 0, 0, '', '1696-4', '', 0, 0, 0, ''),
('race', 'winnemucca', 'Winnemucca', 8970, 0, 0, '', '1700-4', '', 0, 0, 0, ''),
('race', 'wintun', 'Wintun', 8980, 0, 0, '', '1702-0', '', 0, 0, 0, ''),
('race', 'wisconsin_potawatomi', 'Wisconsin Potawatomi', 8990, 0, 0, '', '1485-2', '', 0, 0, 0, ''),
('race', 'wiseman', 'Wiseman', 9000, 0, 0, '', '1809-3', '', 0, 0, 0, ''),
('race', 'wishram', 'Wishram', 9010, 0, 0, '', '1121-3', '', 0, 0, 0, ''),
('race', 'wiyot', 'Wiyot', 9020, 0, 0, '', '1704-6', '', 0, 0, 0, ''),
('race', 'wrangell', 'Wrangell', 9030, 0, 0, '', '1834-1', '', 0, 0, 0, ''),
('race', 'wyandotte', 'Wyandotte', 9040, 0, 0, '', '1295-5', '', 0, 0, 0, ''),
('race', 'yahooskin', 'Yahooskin', 9050, 0, 0, '', '1401-9', '', 0, 0, 0, ''),
('race', 'yakama', 'Yakama', 9060, 0, 0, '', '1707-9', '', 0, 0, 0, ''),
('race', 'yakama_cowlitz', 'Yakama Cowlitz', 9070, 0, 0, '', '1709-5', '', 0, 0, 0, ''),
('race', 'yakutat', 'Yakutat', 9080, 0, 0, '', '1835-8', '', 0, 0, 0, ''),
('race', 'yana', 'Yana', 9090, 0, 0, '', '1065-2', '', 0, 0, 0, ''),
('race', 'yanktonai_sioux', 'Yanktonai Sioux', 9110, 0, 0, '', '1641-0', '', 0, 0, 0, ''),
('race', 'yankton_sioux', 'Yankton Sioux', 9100, 0, 0, '', '1640-2', '', 0, 0, 0, ''),
('race', 'yapese', 'Yapese', 9120, 0, 0, '', '2098-2', '', 0, 0, 0, ''),
('race', 'yaqui', 'Yaqui', 9130, 0, 0, '', '1711-1', '', 0, 0, 0, ''),
('race', 'yavapai', 'Yavapai', 9140, 0, 0, '', '1731-9', '', 0, 0, 0, ''),
('race', 'yavapai_apache', 'Yavapai Apache', 9150, 0, 0, '', '1715-2', '', 0, 0, 0, ''),
('race', 'yerington_paiute', 'Yerington Paiute', 9160, 0, 0, '', '1437-3', '', 0, 0, 0, ''),
('race', 'yokuts', 'Yokuts', 9170, 0, 0, '', '1717-8', '', 0, 0, 0, ''),
('race', 'yomba', 'Yomba', 9180, 0, 0, '', '1600-6', '', 0, 0, 0, ''),
('race', 'yuchi', 'Yuchi', 9190, 0, 0, '', '1722-8', '', 0, 0, 0, ''),
('race', 'yuki', 'Yuki', 9200, 0, 0, '', '1066-0', '', 0, 0, 0, ''),
('race', 'yuman', 'Yuman', 9210, 0, 0, '', '1724-4', '', 0, 0, 0, ''),
('race', 'yupik_eskimo', 'Yupik Eskimo', 9220, 0, 0, '', '1896-0', '', 0, 0, 0, ''),
('race', 'yurok', 'Yurok', 9230, 0, 0, '', '1732-7', '', 0, 0, 0, ''),
('race', 'zairean', 'Zairean', 9240, 0, 0, '', '2066-9', '', 0, 0, 0, ''),
('race', 'zia', 'Zia', 9250, 0, 0, '', '1515-6', '', 0, 0, 0, ''),
('race', 'zuni', 'Zuni', 9260, 0, 0, '', '1516-4', '', 0, 0, 0, ''),
('reaction', 'hives', 'Hives', 20, 0, 0, '', '', 'SNOMED-CT:247472004', 0, 0, 1, ''),
('reaction', 'nausea', 'Nausea', 30, 0, 0, '', '', 'SNOMED-CT:422587007', 0, 0, 1, ''),
('reaction', 'shortness_of_breath', 'Shortness of Breath', 40, 0, 0, '', '', 'SNOMED-CT:267036007', 0, 0, 1, ''),
('reaction', 'unassigned', 'Unassigned', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Coupon', 'Coupon', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Direct Mail', 'Direct Mail', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Employee', 'Employee', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Newspaper', 'Newspaper', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Other', 'Other', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Patient', 'Patient', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Radio', 'Radio', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Referral Card', 'Referral Card', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'T.V.', 'T.V.', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('refsource', 'Walk-In', 'Walk-In', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('religious_affiliation', 'adventist', 'Adventist', 5, 0, 0, '', '1001', '', 0, 0, 1, ''),
('religious_affiliation', 'african_religions', 'African Religions', 15, 0, 0, '', '1002', '', 0, 0, 1, ''),
('religious_affiliation', 'afro-caribbean_religions', 'Afro-Caribbean Religions', 25, 0, 0, '', '1003', '', 0, 0, 1, ''),
('religious_affiliation', 'agnosticism', 'Agnosticism', 35, 0, 0, '', '1004', '', 0, 0, 1, ''),
('religious_affiliation', 'anglican', 'Anglican', 45, 0, 0, '', '1005', '', 0, 0, 1, ''),
('religious_affiliation', 'animism', 'Animism', 55, 0, 0, '', '1006', '', 0, 0, 1, ''),
('religious_affiliation', 'assembly_of_god', 'Assembly of God', 65, 0, 0, '', '1061', '', 0, 0, 1, ''),
('religious_affiliation', 'atheist', 'NONE (non-theist, atheist)', 75, 0, 0, '', '1007', '', 0, 0, 1, ''),
('religious_affiliation', 'babi_bahai_faiths', 'Babi & Baha''I faiths', 85, 0, 0, '', '1008', '', 0, 0, 1, ''),
('religious_affiliation', 'baptist', 'Baptist', 95, 0, 0, '', '1009', '', 0, 0, 1, ''),
('religious_affiliation', 'bon', 'Bon', 105, 0, 0, '', '1010', '', 0, 0, 1, ''),
('religious_affiliation', 'brethren', 'Brethren', 115, 0, 0, '', '1062', '', 0, 0, 1, ''),
('religious_affiliation', 'cao_dai', 'Cao Dai', 125, 0, 0, '', '1011', '', 0, 0, 1, ''),
('religious_affiliation', 'celticism', 'Celticism', 135, 0, 0, '', '1012', '', 0, 0, 1, ''),
('religious_affiliation', 'christiannoncatholicnonspecifc', 'Christian (non-Catholic, non-specific)', 145, 0, 0, '', '1013', '', 0, 0, 1, ''),
('religious_affiliation', 'christian_scientist', 'Christian Scientist', 155, 0, 0, '', '1063', '', 0, 0, 1, ''),
('religious_affiliation', 'church_of_christ', 'Church of Christ', 165, 0, 0, '', '1064', '', 0, 0, 1, ''),
('religious_affiliation', 'church_of_god', 'Church of God', 175, 0, 0, '', '1065', '', 0, 0, 1, ''),
('religious_affiliation', 'confucianism', 'Confucianism', 185, 0, 0, '', '1014', '', 0, 0, 1, ''),
('religious_affiliation', 'congregational', 'Congregational', 195, 0, 0, '', '1066', '', 0, 0, 1, ''),
('religious_affiliation', 'cyberculture_religions', 'Cyberculture Religions', 205, 0, 0, '', '1015', '', 0, 0, 1, ''),
('religious_affiliation', 'disciples_of_christ', 'Disciples of Christ', 215, 0, 0, '', '1067', '', 0, 0, 1, ''),
('religious_affiliation', 'divination', 'Divination', 225, 0, 0, '', '1016', '', 0, 0, 1, ''),
('religious_affiliation', 'eastern_orthodox', 'Eastern Orthodox', 235, 0, 0, '', '1068', '', 0, 0, 1, ''),
('religious_affiliation', 'episcopalian', 'Episcopalian', 245, 0, 0, '', '1069', '', 0, 0, 1, ''),
('religious_affiliation', 'evangelical_covenant', 'Evangelical Covenant', 255, 0, 0, '', '1070', '', 0, 0, 1, ''),
('religious_affiliation', 'fourth_way', 'Fourth Way', 265, 0, 0, '', '1017', '', 0, 0, 1, ''),
('religious_affiliation', 'free_daism', 'Free Daism', 275, 0, 0, '', '1018', '', 0, 0, 1, ''),
('religious_affiliation', 'friends', 'Friends', 285, 0, 0, '', '1071', '', 0, 0, 1, ''),
('religious_affiliation', 'full_gospel', 'Full Gospel', 295, 0, 0, '', '1072', '', 0, 0, 1, ''),
('religious_affiliation', 'gnosis', 'Gnosis', 305, 0, 0, '', '1019', '', 0, 0, 1, ''),
('religious_affiliation', 'hinduism', 'Hinduism', 315, 0, 0, '', '1020', '', 0, 0, 1, ''),
('religious_affiliation', 'humanism', 'Humanism', 325, 0, 0, '', '1021', '', 0, 0, 1, ''),
('religious_affiliation', 'independent', 'Independent', 335, 0, 0, '', '1022', '', 0, 0, 1, ''),
('religious_affiliation', 'islam', 'Islam', 345, 0, 0, '', '1023', '', 0, 0, 1, ''),
('religious_affiliation', 'jainism', 'Jainism', 355, 0, 0, '', '1024', '', 0, 0, 1, ''),
('religious_affiliation', 'jehovahs_witnesses', 'Jehovah''s Witnesses', 365, 0, 0, '', '1025', '', 0, 0, 1, ''),
('religious_affiliation', 'judaism', 'Judaism', 375, 0, 0, '', '1026', '', 0, 0, 1, ''),
('religious_affiliation', 'latter_day_saints', 'Latter Day Saints', 385, 0, 0, '', '1027', '', 0, 0, 1, ''),
('religious_affiliation', 'lutheran', 'Lutheran', 395, 0, 0, '', '1028', '', 0, 0, 1, ''),
('religious_affiliation', 'mahayana', 'Mahayana', 405, 0, 0, '', '1029', '', 0, 0, 1, ''),
('religious_affiliation', 'meditation', 'Meditation', 415, 0, 0, '', '1030', '', 0, 0, 1, ''),
('religious_affiliation', 'messianic_judaism', 'Messianic Judaism', 425, 0, 0, '', '1031', '', 0, 0, 1, ''),
('religious_affiliation', 'methodist', 'Methodist', 435, 0, 0, '', '1073', '', 0, 0, 1, ''),
('religious_affiliation', 'mitraism', 'Mitraism', 445, 0, 0, '', '1032', '', 0, 0, 1, ''),
('religious_affiliation', 'native_american', 'Native American', 455, 0, 0, '', '1074', '', 0, 0, 1, ''),
('religious_affiliation', 'nazarene', 'Nazarene', 465, 0, 0, '', '1075', '', 0, 0, 1, ''),
('religious_affiliation', 'new_age', 'New Age', 475, 0, 0, '', '1033', '', 0, 0, 1, ''),
('religious_affiliation', 'non-roman_catholic', 'non-Roman Catholic', 485, 0, 0, '', '1034', '', 0, 0, 1, ''),
('religious_affiliation', 'occult', 'Occult', 495, 0, 0, '', '1035', '', 0, 0, 1, ''),
('religious_affiliation', 'orthodox', 'Orthodox', 505, 0, 0, '', '1036', '', 0, 0, 1, ''),
('religious_affiliation', 'paganism', 'Paganism', 515, 0, 0, '', '1037', '', 0, 0, 1, ''),
('religious_affiliation', 'pentecostal', 'Pentecostal', 525, 0, 0, '', '1038', '', 0, 0, 1, ''),
('religious_affiliation', 'presbyterian', 'Presbyterian', 535, 0, 0, '', '1076', '', 0, 0, 1, ''),
('religious_affiliation', 'process_the', 'Process, The', 545, 0, 0, '', '1039', '', 0, 0, 1, ''),
('religious_affiliation', 'protestant', 'Protestant', 555, 0, 0, '', '1077', '', 0, 0, 1, ''),
('religious_affiliation', 'protestant_no_denomination', 'Protestant, No Denomination', 565, 0, 0, '', '1078', '', 0, 0, 1, ''),
('religious_affiliation', 'reformed', 'Reformed', 575, 0, 0, '', '1079', '', 0, 0, 1, ''),
('religious_affiliation', 'reformed_presbyterian', 'Reformed/Presbyterian', 585, 0, 0, '', '1040', '', 0, 0, 1, ''),
('religious_affiliation', 'roman_catholic_church', 'Roman Catholic Church', 595, 0, 0, '', '1041', '', 0, 0, 1, ''),
('religious_affiliation', 'salvation_army', 'Salvation Army', 605, 0, 0, '', '1080', '', 0, 0, 1, ''),
('religious_affiliation', 'satanism', 'Satanism', 615, 0, 0, '', '1042', '', 0, 0, 1, ''),
('religious_affiliation', 'scientology', 'Scientology', 625, 0, 0, '', '1043', '', 0, 0, 1, ''),
('religious_affiliation', 'shamanism', 'Shamanism', 635, 0, 0, '', '1044', '', 0, 0, 1, ''),
('religious_affiliation', 'shiite_islam', 'Shiite (Islam)', 645, 0, 0, '', '1045', '', 0, 0, 1, ''),
('religious_affiliation', 'shinto', 'Shinto', 655, 0, 0, '', '1046', '', 0, 0, 1, ''),
('religious_affiliation', 'sikism', 'Sikism', 665, 0, 0, '', '1047', '', 0, 0, 1, ''),
('religious_affiliation', 'spiritualism', 'Spiritualism', 675, 0, 0, '', '1048', '', 0, 0, 1, ''),
('religious_affiliation', 'sunni_islam', 'Sunni (Islam)', 685, 0, 0, '', '1049', '', 0, 0, 1, ''),
('religious_affiliation', 'taoism', 'Taoism', 695, 0, 0, '', '1050', '', 0, 0, 1, ''),
('religious_affiliation', 'theravada', 'Theravada', 705, 0, 0, '', '1051', '', 0, 0, 1, ''),
('religious_affiliation', 'unitarian-universalism', 'Unitarian-Universalism', 725, 0, 0, '', '1052', '', 0, 0, 1, ''),
('religious_affiliation', 'unitarian_universalist', 'Unitarian Universalist', 715, 0, 0, '', '1081', '', 0, 0, 1, ''),
('religious_affiliation', 'united_church_of_christ', 'United Church of Christ', 735, 0, 0, '', '1082', '', 0, 0, 1, ''),
('religious_affiliation', 'universal_life_church', 'Universal Life Church', 745, 0, 0, '', '1053', '', 0, 0, 1, ''),
('religious_affiliation', 'vajrayana_tibetan', 'Vajrayana (Tibetan)', 755, 0, 0, '', '1054', '', 0, 0, 1, ''),
('religious_affiliation', 'veda', 'Veda', 765, 0, 0, '', '1055', '', 0, 0, 1, ''),
('religious_affiliation', 'voodoo', 'Voodoo', 775, 0, 0, '', '1056', '', 0, 0, 1, ''),
('religious_affiliation', 'wicca', 'Wicca', 785, 0, 0, '', '1057', '', 0, 0, 1, ''),
('religious_affiliation', 'yaohushua', 'Yaohushua', 795, 0, 0, '', '1058', '', 0, 0, 1, ''),
('religious_affiliation', 'zen_buddhism', 'Zen Buddhism', 805, 0, 0, '', '1059', '', 0, 0, 1, ''),
('religious_affiliation', 'zoroastrianism', 'Zoroastrianism', 815, 0, 0, '', '1060', '', 0, 0, 1, ''),
('riskfactors', 'all', 'Allergies', 14, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'ast', 'Asthma', 16, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'br', 'Breast Disease', 12, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'cl', 'Contact Lenses', 18, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'coc', 'Contraceptive Complication (specify)', 19, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'db', 'Diabetes', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'dpr', 'Depression', 13, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'ep', 'Epilepsy', 17, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'fib', 'Fibroids', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'gb', 'Gall Bladder Condition', 11, 0, 0, '', '', '', 0, 0, 1, '');
INSERT INTO `list_options` VALUES
('riskfactors', 'hd', 'Heart Disease', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'hep', 'Hepatitis', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'ht', 'Hypertension', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'inf', 'Infertility', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'mig', 'Severe Migraine', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'oth', 'Other (specify)', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'pid', 'PID (Pelvic Inflammatory Disease)', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'sc', 'Sickle Cell', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'str', 'Thrombosis/Stroke', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('riskfactors', 'vv', 'Varicose Veins', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('risklevel', 'high', 'High', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('risklevel', 'low', 'Low', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('risklevel', 'medium', 'Medium', 2, 1, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_appointment', 'Appointment', 160, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_bmi', 'BMI', 43, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_bp', 'Blood Pressure', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_colon_cancer_screen', 'Colon Cancer Screening', 130, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_exercise', 'Exercise', 47, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_eye', 'Opthalmic', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_foot', 'Podiatric', 100, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_hemo_a1c', 'Hemoglobin A1C', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_influvacc', 'Influenza Vaccine', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_lab_inr', 'INR', 150, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_mammo', 'Mammogram', 110, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_nutrition', 'Nutrition', 45, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_pap', 'Pap Smear', 120, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_penicillin_allergy', 'Penicillin Allergy', 157, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_pneumovacc', 'Pneumococcal Vaccine', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_prostate_cancer_screen', 'Prostate Cancer Screening', 140, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_soc_sec', 'Social Security Number', 155, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_tobacco', 'Tobacco', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_urine_alb', 'Urine Microalbumin', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action', 'act_wt', 'Weight', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_assess', 'Assessment', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_edu', 'Education', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_exam', 'Examination', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_inter', 'Intervention', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_measure', 'Measurement', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_remind', 'Reminder', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_action_category', 'act_cat_treat', 'Treatment', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_age_intervals', 'month', 'Month', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_age_intervals', 'year', 'Year', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_comparisons', 'EXIST', 'Exist', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_comparisons', 'ge', 'Greater Than or Equal To', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_comparisons', 'gt', 'Greater Than', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_comparisons', 'le', 'Less Than or Equal To', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_comparisons', 'lt', 'Less Than', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_acute_inp_or_ed', 'encounter acute inpatient or ED', 130, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_hea_and_beh', 'encounter health and behavior assessment', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_influenza', 'encounter influenza', 150, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_nonac_inp_out_or_opth', 'Encounter: encounter non-acute inpt, outpatient, or ophthalmology', 140, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_nurs_discharge', 'encounter nursing discharge', 130, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_nurs_fac', 'encounter nursing facility', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_occ_ther', 'encounter occupational therapy', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_off_vis', 'encounter office visit', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_outpatient', 'encounter outpatient', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_out_pcp_obgyn', 'encounter outpatient w/PCP & obgyn', 110, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_pregnancy', 'encounter pregnancy', 120, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_pre_ind_counsel', 'encounter preventive medicine - individual counseling', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_pre_med_group_counsel', 'encounter preventive medicine group counseling', 90, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_pre_med_other_serv', 'encounter preventive medicine other services', 100, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_pre_med_ser_18_older', 'encounter preventive medicine services 18 and older', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_pre_med_ser_40_older', 'encounter preventive medicine 40 and older', 75, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_enc_types', 'enc_psych_and_psych', 'encounter psychiatric & psychologic', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_age_max', 'Maximum Age', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_age_min', 'Minimum Age', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_database', 'Database', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_diagnosis', 'Diagnosis', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_lists', 'Lists', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_proc', 'Procedure', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_filters', 'filt_sex', 'Gender', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_due_opt', 'due', 'Due', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_due_opt', 'not_due', 'Not Due', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_due_opt', 'past_due', 'Past Due', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_due_opt', 'soon_due', 'Due Soon', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_inactive_opt', 'auto', 'Automatic', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_inactive_opt', 'due_status_update', 'Due Status Update', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_inactive_opt', 'manual', 'Manual', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_intervals', 'month', 'Month', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_intervals', 'week', 'Week', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_methods', 'clinical_reminder_post', 'Soon Due Interval (Clinical Reminders)', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_methods', 'clinical_reminder_pre', 'Past Due Interval (Clinical Reminders)', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_methods', 'patient_reminder_post', 'Soon Due Interval (Patient Reminders)', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_reminder_methods', 'patient_reminder_pre', 'Past Due Interval (Patient Reminders)', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_targets', 'target_appt', 'Appointment', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_targets', 'target_database', 'Database', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_targets', 'target_interval', 'Interval', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_targets', 'target_proc', 'Procedure', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'day', 'Day', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'flu_season', 'Flu Season', 80, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'hour', 'Hour', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'minute', 'Minute', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'month', 'Month', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'second', 'Second', 70, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'week', 'Week', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('rule_target_intervals', 'year', 'Year', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('severity_ccda', 'fatal', 'Fatal', 80, 0, 0, '', '', 'SNOMED-CT:399166001', 0, 0, 1, ''),
('severity_ccda', 'life_threatening_severity', 'Life threatening severity', 70, 0, 0, '', '', 'SNOMED-CT:442452003', 0, 0, 1, ''),
('severity_ccda', 'mild', 'Mild', 20, 0, 0, '', '', 'SNOMED-CT:255604002', 0, 0, 1, ''),
('severity_ccda', 'mild_to_moderate', 'Mild to moderate', 30, 0, 0, '', '', 'SNOMED-CT:371923003', 0, 0, 1, ''),
('severity_ccda', 'moderate', 'Moderate', 40, 0, 0, '', '', 'SNOMED-CT:6736007', 0, 0, 1, ''),
('severity_ccda', 'moderate_to_severe', 'Moderate to severe', 50, 0, 0, '', '', 'SNOMED-CT:371924009', 0, 0, 1, ''),
('severity_ccda', 'severe', 'Severe', 60, 0, 0, '', '', 'SNOMED-CT:24484000', 0, 0, 1, ''),
('severity_ccda', 'unassigned', 'Unassigned', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('sex', 'Female', 'Female', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('sex', 'Male', 'Male', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('smoking_status', '1', 'Current every day smoker', 10, 0, 0, '', '', 'SNOMED-CT:449868002', 0, 0, 1, ''),
('smoking_status', '15', 'Heavy tobacco smoker', 70, 0, 0, '', '', 'SNOMED-CT:428071000124103', 0, 0, 1, ''),
('smoking_status', '16', 'Light tobacco smoker', 80, 0, 0, '', '', 'SNOMED-CT:428061000124105', 0, 0, 1, ''),
('smoking_status', '2', 'Current some day smoker', 20, 0, 0, '', '', 'SNOMED-CT:428041000124106', 0, 0, 1, ''),
('smoking_status', '3', 'Former smoker', 30, 0, 0, '', '', 'SNOMED-CT:8517006', 0, 0, 1, ''),
('smoking_status', '4', 'Never smoker', 40, 0, 0, '', '', 'SNOMED-CT:266919005', 0, 0, 1, ''),
('smoking_status', '5', 'Smoker, current status unknown', 50, 0, 0, '', '', 'SNOMED-CT:77176002', 0, 0, 1, ''),
('smoking_status', '9', 'Unknown if ever smoked', 60, 0, 0, '', '', 'SNOMED-CT:266927001', 0, 0, 1, ''),
('state', 'AK', 'Alaska', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'AL', 'Alabama', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'AR', 'Arkansas', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'AZ', 'Arizona', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'CA', 'California', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'CO', 'Colorado', 6, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'CT', 'Connecticut', 7, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'DC', 'District of Columbia', 9, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'DE', 'Delaware', 8, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'FL', 'Florida', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'GA', 'Georgia', 11, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'HI', 'Hawaii', 12, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'IA', 'Iowa', 16, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'ID', 'Idaho', 13, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'IL', 'Illinois', 14, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'IN', 'Indiana', 15, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'KS', 'Kansas', 17, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'KY', 'Kentucky', 18, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'LA', 'Louisiana', 19, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MA', 'Massachusetts', 22, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MD', 'Maryland', 21, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'ME', 'Maine', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MI', 'Michigan', 23, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MN', 'Minnesota', 24, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MO', 'Missouri', 26, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MS', 'Mississippi', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'MT', 'Montana', 27, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NC', 'North Carolina', 34, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'ND', 'North Dakota', 35, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NE', 'Nebraska', 28, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NH', 'New Hampshire', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NJ', 'New Jersey', 31, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NM', 'New Mexico', 32, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NV', 'Nevada', 29, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'NY', 'New York', 33, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'OH', 'Ohio', 36, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'OK', 'Oklahoma', 37, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'OR', 'Oregon', 38, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'PA', 'Pennsylvania', 39, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'RI', 'Rhode Island', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'SC', 'South Carolina', 41, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'SD', 'South Dakota', 42, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'TN', 'Tennessee', 43, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'TX', 'Texas', 44, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'UT', 'Utah', 45, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'VA', 'Virginia', 47, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'VT', 'Vermont', 46, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'WA', 'Washington', 48, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'WI', 'Wisconsin', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'WV', 'West Virginia', 49, 0, 0, '', '', '', 0, 0, 1, ''),
('state', 'WY', 'Wyoming', 51, 0, 0, '', '', '', 0, 0, 1, ''),
('sub_relation', 'child', 'Child', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('sub_relation', 'other', 'Other', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('sub_relation', 'self', 'Self', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('sub_relation', 'spouse', 'Spouse', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('surgery_issue_list', 'appendectomy', 'appendectomy', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('surgery_issue_list', 'cholecystectomy', 'cholecystectomy', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('surgery_issue_list', 'tonsillectomy', 'tonsillectomy', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('titles', 'Dr.', 'Dr.', 4, 0, 0, '', '', '', 0, 0, 1, ''),
('titles', 'Mr.', 'Mr.', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('titles', 'Mrs.', 'Mrs.', 2, 0, 0, '', '', '', 0, 0, 1, ''),
('titles', 'Ms.', 'Ms.', 3, 0, 0, '', '', '', 0, 0, 1, ''),
('transactions', 'LBTbill', 'Billing', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('transactions', 'LBTlegal', 'Legal', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('transactions', 'LBTphreq', 'Physician Request', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('transactions', 'LBTptreq', 'Patient Request', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('transactions', 'LBTref', 'Referral', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '1', 'Physician Referral', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '2', 'Clinic Referral', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '3', 'HMO Referral', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '4', 'Transfer from Hospital', 25, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '5', 'Transfer from SNF', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '6', 'Transfer From Another Health Care Facility', 35, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '7', 'Emergency Room', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '8', 'Court/Law Enforcement', 45, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_source', '9', 'Information Not Available', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_type', '1', 'Emergency', 10, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_type', '2', 'Urgent', 20, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_type', '3', 'Elective', 30, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_type', '4', 'Newborn', 40, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_type', '5', 'Trauma', 50, 0, 0, '', '', '', 0, 0, 1, ''),
('ub_admit_type', '9', 'Information Not Available', 60, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist1', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist2', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist3', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist4', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist5', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist6', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('userlist7', 'sample', 'Sample', 1, 0, 0, '', '', '', 0, 0, 1, ''),
('warehouse', 'onsite', 'On Site', 5, 0, 0, '', '', '', 0, 0, 1, ''),
('yesno', 'NO', 'NO', 1, 0, 0, '', 'N', '', 0, 0, 1, ''),
('yesno', 'YES', 'YES', 2, 0, 0, '', 'Y', '', 0, 0, 1, '');

-- --------------------------------------------------------

--
-- Table structure for table `log`
--

CREATE TABLE `log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `event` varchar(255) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `comments` longtext,
  `user_notes` longtext,
  `patient_id` bigint(20) DEFAULT NULL,
  `success` tinyint(1) DEFAULT '1',
  `checksum` longtext,
  `crt_user` varchar(255) DEFAULT NULL,
  `log_from` varchar(20) DEFAULT 'LibreEHR',
  `menu_item_id` int(11) DEFAULT NULL,
  `ccda_doc_id` int(11) DEFAULT NULL COMMENT 'CCDA document id from ccda',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

--
-- Dumping data for table `log`
--

INSERT INTO `log` VALUES
(1, '[[regtime]]', 'other-insert', '', '', 'INSERT INTO `migrations` ( `migration`, `batch` ) VALUES ( ?, ? ) (''Migration_2016_05_19_10_52_06.php'',''1'')', NULL, 0, 1, '', '', 'LibreEHR', NULL, NULL),
(2, '[[regtime]]', 'other-insert', '', '', 'INSERT INTO `list_options` (`list_id`, `option_id`, `title`, `seq`, `is_default`, `option_value`, `mapping`, `notes`, `codes`, `toggle_setting_1`, `toggle_setting_2`, `activity`) VALUES (''ACLT_Tag_Colors'', ''blue'', ''Blue'', 0, 1, 0, '''', ''#90caf9'', '''', 0, 0, 0), (''ACLT_Tag_Colors'', ''green'', ''Green'', 0, 0, 0, '''', ''#a5d6a7'', '''', 0, 0, 0), (''ACLT_Tag_Colors'', ''orange'', ''Orange'', 0, 0, 0, '''', ''#ffb74d'', '''', 0, 0, 0), (''ACLT_Tag_Colors'', ''purple'', ''Purple'', 0, 0, 0, '''', ''#b39ddb'', '''', 0, 0, 0), (''ACLT_Tag_Colors'', ''red'', ''Red'', 0, 0, 0, '''', ''#e57373'', '''', 0, 0, 0), (''ACLT_Tag_Colors'', ''yellow'', ''Yellow'', 0, 0, 0, '''', ''#fff59d'', '''', 0, 0, 0), (''lists'', ''ACLT_Tag_Colors'', ''ACLT Tag Colors'', 299, 1, 0, '''', '''', '''', 0, 0, 1)', NULL, 0, 1, '', '', 'LibreEHR', NULL, NULL),
(3, '[[regtime]]', 'other-insert', '', '', 'INSERT INTO `list_options` (`list_id`, `option_id`, `title`, `seq`, `is_default`, `option_value`, `mapping`, `notes`, `codes`, `toggle_setting_1`, `toggle_setting_2`, `activity`) VALUES (''ACLT_Tag_Status'', ''active'', ''Active'', 0, 1, 0, '''', '''', '''', 0, 0, 0), (''ACLT_Tag_Status'', ''deleted'', ''Deleted'', 0, 0, 0, '''', '''', '''', 0, 0, 0), (''ACLT_Tag_Status'', ''suspended'', ''Suspended'', 0, 0, 0, '''', '''', '''', 0, 0, 0), (''lists'', ''ACLT_Tag_Status'', ''ACLT Tag Status'', 298, 1, 0, '''', '''', '''', 0, 0, 1)', NULL, 0, 1, '', '', 'LibreEHR', NULL, NULL),
(4, '[[regtime]]', 'other-insert', '', '', 'INSERT INTO `migrations` ( `migration`, `batch` ) VALUES ( ?, ? ) (''Migration_2016_12_05_14_48_11.php'',''1'')', NULL, 0, 1, '', '', 'LibreEHR', NULL, NULL);

-- --------------------------------------------------------

--
-- Table structure for table `log_comment_encrypt`
--

CREATE TABLE `log_comment_encrypt` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `log_id` int(11) NOT NULL,
  `encrypt` enum('Yes','No') NOT NULL DEFAULT 'No',
  `checksum` longtext,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

--
-- Dumping data for table `log_comment_encrypt`
--

INSERT INTO `log_comment_encrypt` VALUES
(1, 1, 'No', ''),
(2, 2, 'No', ''),
(3, 3, 'No', ''),
(4, 4, 'No', '');

-- --------------------------------------------------------

--
-- Table structure for table `migrations`
--

CREATE TABLE `migrations` (
  `migration` varchar(255) DEFAULT NULL,
  `batch` int(11) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `migrations`
--

INSERT INTO `migrations` VALUES
('Migration_2016_05_19_10_52_06.php', 1),
('Migration_2016_12_05_14_48_11.php', 1);

-- --------------------------------------------------------

--
-- Table structure for table `misc_address_book`
--

CREATE TABLE `misc_address_book` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `fname` varchar(255) DEFAULT NULL,
  `mname` varchar(255) DEFAULT NULL,
  `lname` varchar(255) DEFAULT NULL,
  `street` varchar(60) DEFAULT NULL,
  `city` varchar(30) DEFAULT NULL,
  `state` varchar(30) DEFAULT NULL,
  `zip` varchar(20) DEFAULT NULL,
  `phone` varchar(30) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `modules`
--

CREATE TABLE `modules` (
  `mod_id` int(11) NOT NULL AUTO_INCREMENT,
  `mod_name` varchar(64) NOT NULL DEFAULT '0',
  `mod_directory` varchar(64) NOT NULL DEFAULT '',
  `mod_parent` varchar(64) NOT NULL DEFAULT '',
  `mod_type` varchar(64) NOT NULL DEFAULT '',
  `mod_active` int(1) unsigned NOT NULL DEFAULT '0',
  `mod_ui_name` varchar(20) NOT NULL DEFAULT '''',
  `mod_relative_link` varchar(64) NOT NULL DEFAULT '',
  `mod_ui_order` tinyint(3) NOT NULL DEFAULT '0',
  `mod_ui_active` int(1) unsigned NOT NULL DEFAULT '0',
  `mod_description` varchar(255) NOT NULL DEFAULT '',
  `mod_nick_name` varchar(25) NOT NULL DEFAULT '',
  `mod_enc_menu` varchar(10) NOT NULL DEFAULT 'no',
  `permissions_item_table` char(100) DEFAULT NULL,
  `directory` varchar(255) NOT NULL,
  `date` datetime NOT NULL,
  `sql_run` tinyint(4) DEFAULT '0',
  `type` tinyint(4) DEFAULT '0',
  PRIMARY KEY (`mod_id`,`mod_directory`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `modules_hooks_settings`
--

CREATE TABLE `modules_hooks_settings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `mod_id` int(11) DEFAULT NULL,
  `enabled_hooks` varchar(255) DEFAULT NULL,
  `attached_to` varchar(45) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `modules_settings`
--

CREATE TABLE `modules_settings` (
  `mod_id` int(11) DEFAULT NULL,
  `fld_type` smallint(6) DEFAULT NULL COMMENT '1=>ACL,2=>preferences,3=>hooks',
  `obj_name` varchar(255) DEFAULT NULL,
  `menu_name` varchar(255) DEFAULT NULL,
  `path` varchar(255) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `module_acl_group_settings`
--

CREATE TABLE `module_acl_group_settings` (
  `module_id` int(11) NOT NULL,
  `group_id` int(11) NOT NULL,
  `section_id` int(11) NOT NULL,
  `allowed` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`module_id`,`group_id`,`section_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `module_acl_sections`
--

CREATE TABLE `module_acl_sections` (
  `section_id` int(11) DEFAULT NULL,
  `section_name` varchar(255) DEFAULT NULL,
  `parent_section` int(11) DEFAULT NULL,
  `section_identifier` varchar(50) DEFAULT NULL,
  `module_id` int(11) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `module_acl_user_settings`
--

CREATE TABLE `module_acl_user_settings` (
  `module_id` int(11) NOT NULL,
  `user_id` int(11) NOT NULL,
  `section_id` int(11) NOT NULL,
  `allowed` int(1) DEFAULT NULL,
  PRIMARY KEY (`module_id`,`user_id`,`section_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `module_configuration`
--

CREATE TABLE `module_configuration` (
  `module_config_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `module_id` int(10) unsigned NOT NULL,
  `field_name` varchar(45) NOT NULL,
  `field_value` varchar(255) NOT NULL,
  PRIMARY KEY (`module_config_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `notes`
--

CREATE TABLE `notes` (
  `id` int(11) NOT NULL DEFAULT '0',
  `foreign_id` int(11) NOT NULL DEFAULT '0',
  `note` varchar(255) DEFAULT NULL,
  `owner` int(11) DEFAULT NULL,
  `date` datetime DEFAULT NULL,
  `revision` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `foreign_id` (`owner`),
  KEY `foreign_id_2` (`foreign_id`),
  KEY `date` (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `notification_log`
--

CREATE TABLE `notification_log` (
  `iLogId` int(11) NOT NULL AUTO_INCREMENT,
  `pid` int(7) NOT NULL,
  `pc_eid` int(11) unsigned DEFAULT NULL,
  `sms_gateway_type` varchar(50) NOT NULL,
  `smsgateway_info` varchar(255) NOT NULL,
  `message` text,
  `email_sender` varchar(255) NOT NULL,
  `email_subject` varchar(255) NOT NULL,
  `type` enum('SMS','Email') NOT NULL,
  `patient_info` text,
  `pc_eventDate` date NOT NULL,
  `pc_endDate` date NOT NULL,
  `pc_startTime` time NOT NULL,
  `pc_endTime` time NOT NULL,
  `dSentDateTime` datetime NOT NULL,
  PRIMARY KEY (`iLogId`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

-- --------------------------------------------------------

--
-- Table structure for table `notification_settings`
--

CREATE TABLE `notification_settings` (
  `SettingsId` int(3) NOT NULL AUTO_INCREMENT,
  `Send_SMS_Before_Hours` int(3) NOT NULL,
  `Send_Email_Before_Hours` int(3) NOT NULL,
  `SMS_gateway_username` varchar(100) NOT NULL,
  `SMS_gateway_password` varchar(100) NOT NULL,
  `SMS_gateway_apikey` varchar(100) NOT NULL,
  `type` varchar(50) NOT NULL,
  PRIMARY KEY (`SettingsId`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `notification_settings`
--

INSERT INTO `notification_settings` VALUES
(1, 150, 150, 'sms username', 'sms password', 'sms api key', 'SMS/Email Settings');

-- --------------------------------------------------------

--
-- Table structure for table `onotes`
--

CREATE TABLE `onotes` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `body` longtext,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `onsite_documents`
--

CREATE TABLE `onsite_documents` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `pid` int(10) unsigned DEFAULT NULL,
  `facility` int(10) unsigned DEFAULT NULL,
  `provider` int(10) unsigned DEFAULT NULL,
  `encounter` int(10) unsigned DEFAULT NULL,
  `create_date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `doc_type` varchar(255) NOT NULL,
  `patient_signed_status` smallint(5) unsigned NOT NULL,
  `patient_signed_time` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `authorize_signed_time` datetime DEFAULT NULL,
  `accept_signed_status` smallint(5) NOT NULL,
  `authorizing_signator` varchar(50) NOT NULL,
  `review_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `denial_reason` varchar(255) NOT NULL,
  `authorized_signature` text,
  `patient_signature` text,
  `full_document` blob,
  `file_name` varchar(255) NOT NULL,
  `file_path` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `onsite_mail`
--

CREATE TABLE `onsite_mail` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `owner` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `header` varchar(255) DEFAULT NULL,
  `title` varchar(255) DEFAULT NULL,
  `body` longtext,
  `recipient_id` varchar(128) DEFAULT NULL,
  `recipient_name` varchar(255) DEFAULT NULL,
  `sender_id` varchar(128) DEFAULT NULL,
  `sender_name` varchar(255) DEFAULT NULL,
  `assigned_to` varchar(255) DEFAULT NULL,
  `deleted` tinyint(4) DEFAULT '0' COMMENT 'flag indicates note is deleted',
  `delete_date` datetime DEFAULT NULL,
  `mtype` varchar(128) DEFAULT NULL,
  `message_status` varchar(20) NOT NULL DEFAULT 'New',
  `mail_chain` int(11) DEFAULT NULL,
  `reply_mail_chain` int(11) DEFAULT NULL,
  `is_msg_encrypted` tinyint(2) DEFAULT '0' COMMENT 'Whether messsage encrypted 0-Not encrypted, 1-Encrypted',
  PRIMARY KEY (`id`),
  KEY `pid` (`owner`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `onsite_messages`
--

CREATE TABLE `onsite_messages` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `username` varchar(64) NOT NULL,
  `message` longtext,
  `ip` varchar(15) NOT NULL,
  `date` datetime NOT NULL,
  `sender_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT 'who sent id',
  `recip_id` varchar(255) NOT NULL COMMENT 'who to id array',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Portal messages' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `onsite_online`
--

CREATE TABLE `onsite_online` (
  `hash` varchar(32) NOT NULL,
  `ip` varchar(15) NOT NULL,
  `last_update` datetime NOT NULL,
  `username` varchar(64) NOT NULL,
  `userid` int(11) unsigned DEFAULT NULL,
  PRIMARY KEY (`hash`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `onsite_portal_activity`
--

CREATE TABLE `onsite_portal_activity` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `patient_id` bigint(20) DEFAULT NULL,
  `activity` varchar(255) DEFAULT NULL,
  `require_audit` tinyint(1) DEFAULT '1',
  `pending_action` varchar(255) DEFAULT NULL,
  `action_taken` varchar(255) DEFAULT NULL,
  `status` varchar(255) DEFAULT NULL,
  `narrative` longtext,
  `table_action` longtext,
  `table_args` longtext,
  `action_user` int(11) DEFAULT NULL,
  `action_taken_time` datetime DEFAULT NULL,
  `checksum` longtext,
  PRIMARY KEY (`id`),
  KEY `date` (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `onsite_signatures`
--

CREATE TABLE `onsite_signatures` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `status` varchar(128) NOT NULL DEFAULT 'waiting',
  `type` varchar(128) NOT NULL,
  `created` int(11) NOT NULL,
  `lastmod` datetime NOT NULL,
  `pid` bigint(20) DEFAULT NULL,
  `encounter` int(11) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `activity` tinyint(4) NOT NULL DEFAULT '0',
  `authorized` tinyint(4) DEFAULT NULL,
  `signator` varchar(255) NOT NULL,
  `sig_image` text,
  `signature` text,
  `sig_hash` varchar(128) NOT NULL,
  `ip` varchar(46) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `pid` (`pid`,`user`),
  KEY `encounter` (`encounter`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `patient_access_onsite`
--

CREATE TABLE `patient_access_onsite` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `pid` int(11) DEFAULT NULL,
  `portal_username` varchar(100) DEFAULT NULL,
  `portal_pwd` varchar(100) DEFAULT NULL,
  `portal_pwd_status` tinyint(4) DEFAULT '1' COMMENT '0=>Password Created Through Demographics by The provider or staff. Patient Should Change it at first time it.1=>Pwd updated or created by patient itself',
  `portal_salt` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `patient_data`
--

CREATE TABLE `patient_data` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `title` varchar(255) NOT NULL DEFAULT '',
  `language` varchar(255) NOT NULL DEFAULT '',
  `financial` varchar(255) NOT NULL DEFAULT '',
  `fname` varchar(255) NOT NULL DEFAULT '',
  `lname` varchar(255) NOT NULL DEFAULT '',
  `mname` varchar(255) NOT NULL DEFAULT '',
  `DOB` date DEFAULT NULL,
  `street` varchar(255) NOT NULL DEFAULT '',
  `postal_code` varchar(255) NOT NULL DEFAULT '',
  `city` varchar(255) NOT NULL DEFAULT '',
  `state` varchar(255) NOT NULL DEFAULT '',
  `country_code` varchar(255) NOT NULL DEFAULT '',
  `drivers_license` varchar(255) NOT NULL DEFAULT '',
  `ss` varchar(255) NOT NULL DEFAULT '',
  `occupation` longtext,
  `phone_home` varchar(255) NOT NULL DEFAULT '',
  `phone_biz` varchar(255) NOT NULL DEFAULT '',
  `phone_contact` varchar(255) NOT NULL DEFAULT '',
  `phone_cell` varchar(255) NOT NULL DEFAULT '',
  `pharmacy_id` int(11) NOT NULL DEFAULT '0',
  `status` varchar(255) NOT NULL DEFAULT '',
  `contact_relationship` varchar(255) NOT NULL DEFAULT '',
  `date` datetime DEFAULT NULL,
  `sex` varchar(255) NOT NULL DEFAULT '',
  `referrer` varchar(255) NOT NULL DEFAULT '',
  `referrerID` varchar(255) NOT NULL DEFAULT '',
  `providerID` int(11) DEFAULT NULL,
  `ref_providerID` int(11) DEFAULT NULL,
  `email` varchar(255) NOT NULL DEFAULT '',
  `email_direct` varchar(255) NOT NULL DEFAULT '',
  `ethnoracial` varchar(255) NOT NULL DEFAULT '',
  `race` varchar(255) NOT NULL DEFAULT '',
  `ethnicity` varchar(255) NOT NULL DEFAULT '',
  `religion` varchar(40) NOT NULL DEFAULT '',
  `interpretter` varchar(255) NOT NULL DEFAULT '',
  `migrantseasonal` varchar(255) NOT NULL DEFAULT '',
  `family_size` varchar(255) NOT NULL DEFAULT '',
  `monthly_income` varchar(255) NOT NULL DEFAULT '',
  `billing_note` text,
  `homeless` varchar(255) NOT NULL DEFAULT '',
  `financial_review` datetime DEFAULT NULL,
  `pubpid` varchar(255) NOT NULL DEFAULT '',
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `genericname1` varchar(255) NOT NULL DEFAULT '',
  `genericval1` varchar(255) NOT NULL DEFAULT '',
  `genericname2` varchar(255) NOT NULL DEFAULT '',
  `genericval2` varchar(255) NOT NULL DEFAULT '',
  `hipaa_mail` varchar(3) NOT NULL DEFAULT '',
  `hipaa_voice` varchar(3) NOT NULL DEFAULT '',
  `hipaa_notice` varchar(3) NOT NULL DEFAULT '',
  `hipaa_message` varchar(20) NOT NULL DEFAULT '',
  `hipaa_allowsms` varchar(3) NOT NULL DEFAULT 'NO',
  `hipaa_allowemail` varchar(3) NOT NULL DEFAULT 'NO',
  `squad` varchar(32) NOT NULL DEFAULT '',
  `fitness` int(11) NOT NULL DEFAULT '0',
  `referral_source` varchar(30) NOT NULL DEFAULT '',
  `pricelevel` varchar(255) NOT NULL DEFAULT 'standard',
  `regdate` date DEFAULT NULL COMMENT 'Registration Date',
  `contrastart` date DEFAULT NULL COMMENT 'Date contraceptives initially used',
  `completed_ad` varchar(3) NOT NULL DEFAULT 'NO',
  `ad_reviewed` date DEFAULT NULL,
  `vfc` varchar(255) NOT NULL DEFAULT '',
  `mothersname` varchar(255) NOT NULL DEFAULT '',
  `guardiansname` text,
  `allow_imm_reg_use` varchar(255) NOT NULL DEFAULT '',
  `allow_imm_info_share` varchar(255) NOT NULL DEFAULT '',
  `allow_health_info_ex` varchar(255) NOT NULL DEFAULT '',
  `allow_patient_portal` varchar(31) NOT NULL DEFAULT '',
  `deceased_date` datetime DEFAULT NULL,
  `deceased_reason` varchar(255) NOT NULL DEFAULT '',
  `soap_import_status` tinyint(4) DEFAULT NULL COMMENT '1-Prescription Press 2-Prescription Import 3-Allergy Press 4-Allergy Import',
  `care_team` int(11) DEFAULT NULL,
  `county` varchar(40) NOT NULL DEFAULT '',
  `industry` text,
  UNIQUE KEY `pid` (`pid`),
  KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `patient_reminders`
--

CREATE TABLE `patient_reminders` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `active` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1 if active and 0 if not active',
  `date_inactivated` datetime DEFAULT NULL,
  `reason_inactivated` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_reminder_inactive_opt',
  `due_status` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_reminder_due_opt',
  `pid` bigint(20) NOT NULL COMMENT 'id from patient_data table',
  `category` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the category item in the rule_action_item table',
  `item` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the item column in the rule_action_item table',
  `date_created` datetime DEFAULT NULL,
  `date_sent` datetime DEFAULT NULL,
  `voice_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 if not sent and 1 if sent',
  `sms_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 if not sent and 1 if sent',
  `email_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 if not sent and 1 if sent',
  `mail_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 if not sent and 1 if sent',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`),
  KEY `category` (`category`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `patient_tracker`
--

CREATE TABLE `patient_tracker` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `apptdate` date DEFAULT NULL,
  `appttime` time DEFAULT NULL,
  `eid` bigint(20) NOT NULL DEFAULT '0',
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `original_user` varchar(255) NOT NULL DEFAULT '' COMMENT 'This is the user that created the original record',
  `encounter` bigint(20) NOT NULL DEFAULT '0',
  `lastseq` varchar(4) NOT NULL DEFAULT '' COMMENT 'The element file should contain this number of elements',
  `random_drug_test` tinyint(1) DEFAULT NULL COMMENT 'NULL if not randomized. If randomized, 0 is no, 1 is yes',
  `drug_screen_completed` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `eid` (`eid`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `patient_tracker_element`
--

CREATE TABLE `patient_tracker_element` (
  `pt_tracker_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'maps to id column in patient_tracker table',
  `start_datetime` datetime DEFAULT NULL,
  `room` varchar(20) NOT NULL DEFAULT '',
  `status` varchar(31) NOT NULL DEFAULT '',
  `seq` varchar(4) NOT NULL DEFAULT '' COMMENT 'This is a numerical sequence for this pt_tracker_id events',
  `user` varchar(255) NOT NULL DEFAULT '' COMMENT 'This is the user that created this element',
  KEY `pt_tracker_id` (`pt_tracker_id`,`seq`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `payments`
--

CREATE TABLE `payments` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `pid` bigint(20) NOT NULL DEFAULT '0',
  `dtime` datetime NOT NULL,
  `encounter` bigint(20) NOT NULL DEFAULT '0',
  `user` varchar(255) DEFAULT NULL,
  `method` varchar(255) DEFAULT NULL,
  `source` varchar(255) DEFAULT NULL,
  `amount1` decimal(12,2) NOT NULL DEFAULT '0.00',
  `amount2` decimal(12,2) NOT NULL DEFAULT '0.00',
  `posted1` decimal(12,2) NOT NULL DEFAULT '0.00',
  `posted2` decimal(12,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `payment_gateway_details`
--

CREATE TABLE `payment_gateway_details` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `service_name` varchar(100) DEFAULT NULL,
  `login_id` varchar(255) DEFAULT NULL,
  `transaction_key` varchar(255) DEFAULT NULL,
  `md5` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `pharmacies`
--

CREATE TABLE `pharmacies` (
  `id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `transmit_method` int(11) NOT NULL DEFAULT '1',
  `email` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `phone_numbers`
--

CREATE TABLE `phone_numbers` (
  `id` int(11) NOT NULL DEFAULT '0',
  `country_code` varchar(5) DEFAULT NULL,
  `area_code` char(3) DEFAULT NULL,
  `prefix` char(3) DEFAULT NULL,
  `number` varchar(4) DEFAULT NULL,
  `type` int(11) DEFAULT NULL,
  `foreign_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `foreign_id` (`foreign_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `pnotes`
--

CREATE TABLE `pnotes` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `body` longtext,
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) DEFAULT NULL,
  `groupname` varchar(255) DEFAULT NULL,
  `activity` tinyint(4) DEFAULT NULL,
  `authorized` tinyint(4) DEFAULT NULL,
  `title` varchar(255) DEFAULT NULL,
  `assigned_to` varchar(255) DEFAULT NULL,
  `deleted` tinyint(4) DEFAULT '0' COMMENT 'flag indicates note is deleted',
  `message_status` varchar(20) NOT NULL DEFAULT 'New',
  `portal_relation` varchar(100) DEFAULT NULL,
  `is_msg_encrypted` tinyint(2) DEFAULT '0' COMMENT 'Whether messsage encrypted 0-Not encrypted, 1-Encrypted',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `prescriptions`
--

CREATE TABLE `prescriptions` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `patient_id` int(11) DEFAULT NULL,
  `filled_by_id` int(11) DEFAULT NULL,
  `pharmacy_id` int(11) DEFAULT NULL,
  `date_added` date DEFAULT NULL,
  `date_modified` date DEFAULT NULL,
  `provider_id` int(11) DEFAULT NULL,
  `encounter` int(11) DEFAULT NULL,
  `start_date` date DEFAULT NULL,
  `drug` varchar(150) DEFAULT NULL,
  `drug_id` int(11) NOT NULL DEFAULT '0',
  `rxnorm_drugcode` int(11) DEFAULT NULL,
  `form` int(3) DEFAULT NULL,
  `dosage` varchar(100) DEFAULT NULL,
  `quantity` varchar(31) DEFAULT NULL,
  `size` varchar(16) DEFAULT NULL,
  `unit` int(11) DEFAULT NULL,
  `route` int(11) DEFAULT NULL,
  `interval` int(11) DEFAULT NULL,
  `substitute` int(11) DEFAULT NULL,
  `refills` int(11) DEFAULT NULL,
  `per_refill` int(11) DEFAULT NULL,
  `filled_date` date DEFAULT NULL,
  `medication` int(11) DEFAULT NULL,
  `note` text,
  `active` int(11) NOT NULL DEFAULT '1',
  `datetime` datetime DEFAULT NULL,
  `user` varchar(50) DEFAULT NULL,
  `site` varchar(50) DEFAULT NULL,
  `prescriptionguid` varchar(50) DEFAULT NULL,
  `erx_source` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0-LibreEHR 1-External',
  `erx_uploaded` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0-Pending NewCrop upload 1-Uploaded to NewCrop',
  `drug_info_erx` text,
  `external_id` varchar(20) DEFAULT NULL,
  `end_date` date DEFAULT NULL,
  `indication` text,
  `prn` varchar(30) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `patient_id` (`patient_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `prices`
--

CREATE TABLE `prices` (
  `pr_id` varchar(11) NOT NULL DEFAULT '',
  `pr_selector` varchar(255) NOT NULL DEFAULT '' COMMENT 'template selector for drugs, empty for codes',
  `pr_level` varchar(31) NOT NULL DEFAULT '',
  `pr_price` decimal(12,2) NOT NULL DEFAULT '0.00' COMMENT 'price in local currency',
  PRIMARY KEY (`pr_id`,`pr_selector`,`pr_level`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_answers`
--

CREATE TABLE `procedure_answers` (
  `procedure_order_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references procedure_order.procedure_order_id',
  `procedure_order_seq` int(11) NOT NULL DEFAULT '0' COMMENT 'references procedure_order_code.procedure_order_seq',
  `question_code` varchar(31) NOT NULL DEFAULT '' COMMENT 'references procedure_questions.question_code',
  `answer_seq` int(11) NOT NULL AUTO_INCREMENT COMMENT 'supports multiple-choice questions',
  `answer` varchar(255) NOT NULL DEFAULT '' COMMENT 'answer data',
  PRIMARY KEY (`answer_seq`,`procedure_order_id`,`procedure_order_seq`,`question_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_order`
--

CREATE TABLE `procedure_order` (
  `procedure_order_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `provider_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references users.id, the ordering provider',
  `patient_id` bigint(20) NOT NULL COMMENT 'references patient_data.pid',
  `encounter_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references form_encounter.encounter',
  `date_collected` datetime DEFAULT NULL COMMENT 'time specimen collected',
  `date_ordered` date DEFAULT NULL,
  `order_priority` varchar(31) NOT NULL DEFAULT '',
  `order_status` varchar(31) NOT NULL DEFAULT '' COMMENT 'pending,routed,complete,canceled',
  `patient_instructions` text,
  `activity` tinyint(1) NOT NULL DEFAULT '1' COMMENT '0 if deleted',
  `control_id` varchar(255) NOT NULL DEFAULT '' COMMENT 'This is the CONTROL ID that is sent back from lab',
  `lab_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references procedure_providers.ppid',
  `specimen_type` varchar(31) NOT NULL DEFAULT '' COMMENT 'from the Specimen_Type list',
  `specimen_location` varchar(31) NOT NULL DEFAULT '' COMMENT 'from the Specimen_Location list',
  `specimen_volume` varchar(30) NOT NULL DEFAULT '' COMMENT 'from a text input field',
  `date_transmitted` datetime DEFAULT NULL COMMENT 'time of order transmission, null if unsent',
  `clinical_hx` varchar(255) NOT NULL DEFAULT '' COMMENT 'clinical history text that may be relevant to the order',
  `external_id` varchar(20) DEFAULT NULL,
  PRIMARY KEY (`procedure_order_id`),
  KEY `datepid` (`date_ordered`,`patient_id`),
  KEY `patient_id` (`patient_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_order_code`
--

CREATE TABLE `procedure_order_code` (
  `procedure_order_id` bigint(20) NOT NULL COMMENT 'references procedure_order.procedure_order_id',
  `procedure_order_seq` int(11) NOT NULL AUTO_INCREMENT COMMENT 'supports multiple tests per order',
  `procedure_code` varchar(31) NOT NULL DEFAULT '' COMMENT 'like procedure_type.procedure_code',
  `procedure_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'descriptive name of the procedure code',
  `procedure_source` char(1) NOT NULL DEFAULT '1' COMMENT '1=original order, 2=added after order sent',
  `diagnoses` text COMMENT 'diagnoses and maybe other coding (e.g. ICD9:111.11)',
  `do_not_send` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 = normal, 1 = do not transmit to lab',
  `procedure_order_title` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`procedure_order_seq`,`procedure_order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_providers`
--

CREATE TABLE `procedure_providers` (
  `ppid` bigint(20) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL DEFAULT '',
  `npi` varchar(15) NOT NULL DEFAULT '',
  `send_app_id` varchar(255) NOT NULL DEFAULT '' COMMENT 'Sending application ID (MSH-3.1)',
  `send_fac_id` varchar(255) NOT NULL DEFAULT '' COMMENT 'Sending facility ID (MSH-4.1)',
  `recv_app_id` varchar(255) NOT NULL DEFAULT '' COMMENT 'Receiving application ID (MSH-5.1)',
  `recv_fac_id` varchar(255) NOT NULL DEFAULT '' COMMENT 'Receiving facility ID (MSH-6.1)',
  `DorP` char(1) NOT NULL DEFAULT 'D' COMMENT 'Debugging or Production (MSH-11)',
  `direction` char(1) NOT NULL DEFAULT 'B' COMMENT 'Bidirectional or Results-only',
  `protocol` varchar(15) NOT NULL DEFAULT 'DL',
  `remote_host` varchar(255) NOT NULL DEFAULT '',
  `login` varchar(255) NOT NULL DEFAULT '',
  `password` varchar(255) NOT NULL DEFAULT '',
  `orders_path` varchar(255) NOT NULL DEFAULT '',
  `results_path` varchar(255) NOT NULL DEFAULT '',
  `notes` text,
  `lab_director` bigint(20) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ppid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_questions`
--

CREATE TABLE `procedure_questions` (
  `lab_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references procedure_providers.ppid to identify the lab',
  `procedure_code` varchar(31) NOT NULL DEFAULT '' COMMENT 'references procedure_type.procedure_code to identify this order type',
  `question_code` varchar(31) NOT NULL DEFAULT '' COMMENT 'code identifying this question',
  `seq` int(11) NOT NULL DEFAULT '0' COMMENT 'sequence number for ordering',
  `question_text` varchar(255) NOT NULL DEFAULT '' COMMENT 'descriptive text for question_code',
  `required` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 = required, 0 = not',
  `maxsize` int(11) NOT NULL DEFAULT '0' COMMENT 'maximum length if text input field',
  `fldtype` char(1) NOT NULL DEFAULT 'T' COMMENT 'Text, Number, Select, Multiselect, Date, Gestational-age',
  `options` text COMMENT 'choices for fldtype S and T',
  `tips` varchar(255) NOT NULL DEFAULT '' COMMENT 'Additional instructions for answering the question',
  `activity` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1 = active, 0 = inactive',
  PRIMARY KEY (`lab_id`,`procedure_code`,`question_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_report`
--

CREATE TABLE `procedure_report` (
  `procedure_report_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `procedure_order_id` bigint(20) DEFAULT NULL COMMENT 'references procedure_order.procedure_order_id',
  `procedure_order_seq` int(11) NOT NULL DEFAULT '1' COMMENT 'references procedure_order_code.procedure_order_seq',
  `date_collected` datetime DEFAULT NULL,
  `date_collected_tz` varchar(5) DEFAULT '' COMMENT '+-hhmm offset from UTC',
  `date_report` datetime DEFAULT NULL,
  `date_report_tz` varchar(5) DEFAULT '' COMMENT '+-hhmm offset from UTC',
  `source` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references users.id, who entered this data',
  `specimen_num` varchar(63) NOT NULL DEFAULT '',
  `report_status` varchar(31) NOT NULL DEFAULT '' COMMENT 'received,complete,error',
  `review_status` varchar(31) NOT NULL DEFAULT 'received' COMMENT 'pending review status: received,reviewed',
  `report_notes` text COMMENT 'notes from the lab',
  PRIMARY KEY (`procedure_report_id`),
  KEY `procedure_order_id` (`procedure_order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_result`
--

CREATE TABLE `procedure_result` (
  `procedure_result_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `procedure_report_id` bigint(20) NOT NULL COMMENT 'references procedure_report.procedure_report_id',
  `result_data_type` char(1) NOT NULL DEFAULT 'S' COMMENT 'N=Numeric, S=String, F=Formatted, E=External, L=Long text as first line of comments',
  `result_code` varchar(31) NOT NULL DEFAULT '' COMMENT 'LOINC code, might match a procedure_type.procedure_code',
  `result_text` varchar(255) NOT NULL DEFAULT '' COMMENT 'Description of result_code',
  `date` datetime DEFAULT NULL COMMENT 'lab-provided date specific to this result',
  `facility` varchar(255) NOT NULL DEFAULT '' COMMENT 'lab-provided testing facility ID',
  `units` varchar(31) NOT NULL DEFAULT '',
  `result` varchar(255) NOT NULL DEFAULT '',
  `range` varchar(255) NOT NULL DEFAULT '',
  `abnormal` varchar(31) NOT NULL DEFAULT '' COMMENT 'no,yes,high,low',
  `comments` text COMMENT 'comments from the lab',
  `document_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references documents.id if this result is a document',
  `result_status` varchar(31) NOT NULL DEFAULT '' COMMENT 'preliminary, cannot be done, final, corrected, incompete...etc.',
  PRIMARY KEY (`procedure_result_id`),
  KEY `procedure_report_id` (`procedure_report_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `procedure_type`
--

CREATE TABLE `procedure_type` (
  `procedure_type_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `parent` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references procedure_type.procedure_type_id',
  `name` varchar(63) NOT NULL DEFAULT '' COMMENT 'name for this category, procedure or result type',
  `lab_id` bigint(20) NOT NULL DEFAULT '0' COMMENT 'references procedure_providers.ppid, 0 means default to parent',
  `procedure_code` varchar(31) NOT NULL DEFAULT '' COMMENT 'code identifying this procedure',
  `procedure_type` varchar(31) NOT NULL DEFAULT '' COMMENT 'see list proc_type',
  `body_site` varchar(31) NOT NULL DEFAULT '' COMMENT 'where to do injection, e.g. arm, buttok',
  `specimen` varchar(31) NOT NULL DEFAULT '' COMMENT 'blood, urine, saliva, etc.',
  `route_admin` varchar(31) NOT NULL DEFAULT '' COMMENT 'oral, injection',
  `laterality` varchar(31) NOT NULL DEFAULT '' COMMENT 'left, right, ...',
  `description` varchar(255) NOT NULL DEFAULT '' COMMENT 'descriptive text for procedure_code',
  `standard_code` varchar(255) NOT NULL DEFAULT '' COMMENT 'industry standard code type and code (e.g. CPT4:12345)',
  `related_code` varchar(255) NOT NULL DEFAULT '' COMMENT 'suggested code(s) for followup services if result is abnormal',
  `units` varchar(31) NOT NULL DEFAULT '' COMMENT 'default for procedure_result.units',
  `range` varchar(255) NOT NULL DEFAULT '' COMMENT 'default for procedure_result.range',
  `seq` int(11) NOT NULL DEFAULT '0' COMMENT 'sequence number for ordering',
  `activity` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1=active, 0=inactive',
  `notes` varchar(255) NOT NULL DEFAULT '' COMMENT 'additional notes to enhance description',
  PRIMARY KEY (`procedure_type_id`),
  KEY `parent` (`parent`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `product_warehouse`
--

CREATE TABLE `product_warehouse` (
  `pw_drug_id` int(11) NOT NULL,
  `pw_warehouse` varchar(31) NOT NULL,
  `pw_min_level` float DEFAULT '0',
  `pw_max_level` float DEFAULT '0',
  PRIMARY KEY (`pw_drug_id`,`pw_warehouse`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `registry`
--

CREATE TABLE `registry` (
  `name` varchar(255) DEFAULT NULL,
  `state` tinyint(4) DEFAULT NULL,
  `directory` varchar(255) DEFAULT NULL,
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `sql_run` tinyint(4) DEFAULT NULL,
  `unpackaged` tinyint(4) DEFAULT NULL,
  `date` datetime DEFAULT NULL,
  `priority` int(11) DEFAULT '0',
  `category` varchar(255) DEFAULT NULL,
  `nickname` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=21 ;

--
-- Dumping data for table `registry`
--

INSERT INTO `registry` VALUES
('New Encounter Form', 1, 'patient_encounter', 1, 1, 1, '2003-09-14 15:16:45', 0, 'Administrative', ''),
('Review of Systems Checks', 1, 'reviewofs', 9, 1, 1, '2003-09-14 15:16:45', 0, 'Clinical', ''),
('Speech Dictation', 1, 'dictation', 10, 1, 1, '2003-09-14 15:16:45', 0, 'Clinical', ''),
('SOAP', 1, 'soap', 11, 1, 1, '2005-03-03 00:16:35', 0, 'Clinical', ''),
('Vitals', 1, 'vitals', 12, 1, 1, '2005-03-03 00:16:34', 0, 'Clinical', ''),
('Review Of Systems', 1, 'ros', 13, 1, 1, '2005-03-03 00:16:30', 0, 'Clinical', ''),
('Fee Sheet', 1, 'fee_sheet', 14, 1, 1, '2007-07-28 00:00:00', 0, 'Administrative', ''),
('Misc Billing Options HCFA', 1, 'misc_billing_options', 15, 1, 1, '2007-07-28 00:00:00', 0, 'Administrative', ''),
('Procedure Order', 1, 'procedure_order', 16, 1, 1, '2010-02-25 00:00:00', 0, 'Administrative', ''),
('Annotatable Diagrams', 1, 'annotate_diagram', 17, 1, 1, '2017-02-02 00:00:00', 0, 'Clinical', ''),
('Clinical Instructions', 1, 'clinical_instructions', 20, 1, 1, '2015-09-09 00:00:00', 0, 'Clinical', '');

-- --------------------------------------------------------

--
-- Table structure for table `report_itemized`
--

CREATE TABLE `report_itemized` (
  `report_id` bigint(20) NOT NULL,
  `itemized_test_id` smallint(6) NOT NULL,
  `numerator_label` varchar(25) NOT NULL DEFAULT '' COMMENT 'Only used in special cases',
  `pass` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 is fail, 1 is pass, 2 is excluded,9 is off',
  `pid` bigint(20) NOT NULL,
  KEY `report_id` (`report_id`,`itemized_test_id`,`numerator_label`,`pass`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `report_results`
--

CREATE TABLE `report_results` (
  `report_id` bigint(20) NOT NULL,
  `field_id` varchar(31) NOT NULL DEFAULT '',
  `field_value` longtext,
  PRIMARY KEY (`report_id`,`field_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `rule_action`
--

CREATE TABLE `rule_action` (
  `id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the id column in the clinical_rules table',
  `group_id` bigint(20) NOT NULL DEFAULT '1' COMMENT 'Contains group id to identify collection of targets in a rule',
  `category` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the category item in the rule_action_item table',
  `item` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the item column in the rule_action_item table',
  KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `rule_action`
--

INSERT INTO `rule_action` VALUES
('rule_htn_bp_measure', 1, 'act_cat_measure', 'act_bp'),
('rule_tob_use_assess', 1, 'act_cat_assess', 'act_tobacco'),
('rule_tob_cess_inter', 1, 'act_cat_inter', 'act_tobacco'),
('rule_adult_wt_screen_fu', 1, 'act_cat_measure', 'act_wt'),
('rule_wt_assess_couns_child', 1, 'act_cat_measure', 'act_wt'),
('rule_wt_assess_couns_child', 2, 'act_cat_edu', 'act_wt'),
('rule_wt_assess_couns_child', 3, 'act_cat_edu', 'act_nutrition'),
('rule_wt_assess_couns_child', 4, 'act_cat_edu', 'act_exercise'),
('rule_wt_assess_couns_child', 5, 'act_cat_measure', 'act_bmi'),
('rule_influenza_ge_50', 1, 'act_cat_treat', 'act_influvacc'),
('rule_pneumovacc_ge_65', 1, 'act_cat_treat', 'act_pneumovacc'),
('rule_dm_hemo_a1c', 1, 'act_cat_measure', 'act_hemo_a1c'),
('rule_dm_urine_alb', 1, 'act_cat_measure', 'act_urine_alb'),
('rule_dm_eye', 1, 'act_cat_exam', 'act_eye'),
('rule_dm_foot', 1, 'act_cat_exam', 'act_foot'),
('rule_cs_mammo', 1, 'act_cat_measure', 'act_mammo'),
('rule_cs_pap', 1, 'act_cat_exam', 'act_pap'),
('rule_cs_colon', 1, 'act_cat_assess', 'act_colon_cancer_screen'),
('rule_cs_prostate', 1, 'act_cat_assess', 'act_prostate_cancer_screen'),
('rule_inr_monitor', 1, 'act_cat_measure', 'act_lab_inr'),
('rule_socsec_entry', 1, 'act_cat_assess', 'act_soc_sec'),
('rule_penicillin_allergy', 1, 'act_cat_assess', 'act_penicillin_allergy'),
('rule_blood_pressure', 1, 'act_cat_measure', 'act_bp'),
('rule_inr_measure', 1, 'act_cat_measure', 'act_lab_inr');

-- --------------------------------------------------------

--
-- Table structure for table `rule_action_item`
--

CREATE TABLE `rule_action_item` (
  `category` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_action_category',
  `item` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_action',
  `clin_rem_link` varchar(255) NOT NULL DEFAULT '' COMMENT 'Custom html link in clinical reminder widget',
  `reminder_message` text COMMENT 'Custom message in patient reminder',
  `custom_flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 indexed to rule_patient_data, 0 indexed within main schema',
  PRIMARY KEY (`category`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `rule_action_item`
--

INSERT INTO `rule_action_item` VALUES
('act_cat_assess', 'act_colon_cancer_screen', '', '', 1),
('act_cat_assess', 'act_penicillin_allergy', '', '', 1),
('act_cat_assess', 'act_prostate_cancer_screen', '', '', 1),
('act_cat_assess', 'act_soc_sec', '', '', 0),
('act_cat_assess', 'act_tobacco', '', '', 0),
('act_cat_edu', 'act_exercise', '', '', 1),
('act_cat_edu', 'act_nutrition', '', '', 1),
('act_cat_edu', 'act_wt', '', '', 1),
('act_cat_exam', 'act_eye', '', '', 1),
('act_cat_exam', 'act_foot', '', '', 1),
('act_cat_exam', 'act_pap', '', '', 1),
('act_cat_inter', 'act_tobacco', '', '', 1),
('act_cat_measure', 'act_bmi', '', '', 0),
('act_cat_measure', 'act_bp', '', '', 0),
('act_cat_measure', 'act_hemo_a1c', '', '', 1),
('act_cat_measure', 'act_lab_inr', '', '', 0),
('act_cat_measure', 'act_mammo', '', '', 1),
('act_cat_measure', 'act_urine_alb', '', '', 1),
('act_cat_measure', 'act_wt', '', '', 0),
('act_cat_treat', 'act_influvacc', '', '', 0),
('act_cat_treat', 'act_pneumovacc', '', '', 0);

-- --------------------------------------------------------

--
-- Table structure for table `rule_filter`
--

CREATE TABLE `rule_filter` (
  `id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the id column in the clinical_rules table',
  `include_flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 is exclude and 1 is include',
  `required_flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 is required and 1 is optional',
  `method` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_filters',
  `method_detail` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options lists rule__intervals',
  `value` varchar(255) NOT NULL DEFAULT '',
  KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `rule_filter`
--

INSERT INTO `rule_filter` VALUES
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'CUSTOM::HTN'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::401.0'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::401.1'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::401.9'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::402.00'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::402.01'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::402.10'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::402.11'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::402.90'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::402.91'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::403.00'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::403.01'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::403.10'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::403.11'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::403.90'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::403.91'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.00'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.01'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.02'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.03'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.10'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.11'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.12'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.13'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.90'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.91'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.92'),
('rule_htn_bp_measure', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::404.93'),
('rule_tob_cess_inter', 1, 1, 'filt_database', '', 'LIFESTYLE::tobacco::current'),
('rule_adult_wt_screen_fu', 1, 1, 'filt_age_min', 'year', '18'),
('rule_wt_assess_couns_child', 1, 1, 'filt_age_max', 'year', '18'),
('rule_wt_assess_couns_child', 1, 1, 'filt_age_min', 'year', '2'),
('rule_influenza_ge_50', 1, 1, 'filt_age_min', 'year', '50'),
('rule_pneumovacc_ge_65', 1, 1, 'filt_age_min', 'year', '65'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'CUSTOM::diabetes'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.0'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.00'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.01'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.02'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.03'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.10'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.11'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.12'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.13'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.20'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.21'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.22'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.23'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.30'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.31'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.32'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.33'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.4'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.40'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.41'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.42'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.43'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.50'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.51'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.52'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.53'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.60'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.61'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.62'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.63'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.7'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.70'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.71'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.72'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.73'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.80'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.81'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.82'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.83'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.9'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.90'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.91'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.92'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.93'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::357.2'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.0'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.01'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.02'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.03'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.04'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.05'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.06'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::366.41'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.0'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.00'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.01'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.02'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.03'),
('rule_dm_hemo_a1c', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.04'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'CUSTOM::diabetes'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.0'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.00'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.01'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.02'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.03'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.10'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.11'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.12'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.13'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.20'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.21'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.22'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.23'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.30'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.31'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.32'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.33'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.4'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.40'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.41'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.42'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.43'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.50'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.51'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.52'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.53'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.60'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.61'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.62'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.63'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.7'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.70'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.71'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.72'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.73'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.80'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.81'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.82'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.83'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.9'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.90'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.91'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.92'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.93'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::357.2'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.0'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.01'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.02'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.03'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.04'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.05'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.06'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::366.41'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.0'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.00'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.01'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.02'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.03'),
('rule_dm_urine_alb', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.04'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'CUSTOM::diabetes'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.0'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.00'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.01'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.02'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.03'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.10'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.11'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.12'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.13'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.20'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.21'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.22'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.23'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.30'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.31'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.32'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.33'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.4'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.40'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.41'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.42'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.43'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.50'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.51'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.52'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.53'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.60'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.61'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.62'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.63'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.7'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.70'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.71'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.72'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.73'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.80'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.81'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.82'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.83'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.9'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.90'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.91'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.92'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.93'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::357.2'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.0'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.01'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.02'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.03'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.04'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.05'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.06'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::366.41'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.0'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.00'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.01'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.02'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.03'),
('rule_dm_eye', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.04'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'CUSTOM::diabetes'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.0'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.00'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.01'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.02'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.03'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.10'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.11'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.12'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.13'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.20'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.21'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.22'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.23'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.30'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.31'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.32'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.33'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.4'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.40'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.41'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.42'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.43'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.50'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.51'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.52'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.53'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.60'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.61'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.62'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.63'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.7'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.70'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.71'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.72'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.73'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.80'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.81'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.82'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.83'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.9'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.90'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.91'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.92'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::250.93'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::357.2'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.0'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.01'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.02'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.03'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.04'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.05'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::362.06'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::366.41'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.0'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.00'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.01'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.02'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.03'),
('rule_dm_foot', 1, 0, 'filt_lists', 'medical_problem', 'ICD9::648.04'),
('rule_cs_mammo', 1, 1, 'filt_age_min', 'year', '40'),
('rule_cs_mammo', 1, 1, 'filt_sex', '', 'Female'),
('rule_cs_pap', 1, 1, 'filt_age_min', 'year', '18'),
('rule_cs_pap', 1, 1, 'filt_sex', '', 'Female'),
('rule_cs_colon', 1, 1, 'filt_age_min', 'year', '50'),
('rule_cs_prostate', 1, 1, 'filt_age_min', 'year', '50'),
('rule_cs_prostate', 1, 1, 'filt_sex', '', 'Male'),
('rule_inr_monitor', 1, 0, 'filt_lists', 'medication', 'coumadin'),
('rule_inr_monitor', 1, 0, 'filt_lists', 'medication', 'warfarin'),
('rule_penicillin_allergy', 1, 0, 'filt_lists', 'allergy', 'penicillin');

-- --------------------------------------------------------

--
-- Table structure for table `rule_patient_data`
--

CREATE TABLE `rule_patient_data` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `pid` bigint(20) NOT NULL,
  `category` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the category item in the rule_action_item table',
  `item` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the item column in the rule_action_item table',
  `complete` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list yesno',
  `result` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`),
  KEY `category` (`category`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `rule_reminder`
--

CREATE TABLE `rule_reminder` (
  `id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the id column in the clinical_rules table',
  `method` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_reminder_methods',
  `method_detail` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_reminder_intervals',
  `value` varchar(255) NOT NULL DEFAULT '',
  KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `rule_reminder`
--

INSERT INTO `rule_reminder` VALUES
('rule_htn_bp_measure', 'clinical_reminder_pre', 'week', '2'),
('rule_htn_bp_measure', 'clinical_reminder_post', 'month', '1'),
('rule_htn_bp_measure', 'patient_reminder_pre', 'week', '2'),
('rule_htn_bp_measure', 'patient_reminder_post', 'month', '1'),
('rule_tob_use_assess', 'clinical_reminder_pre', 'week', '2'),
('rule_tob_use_assess', 'clinical_reminder_post', 'month', '1'),
('rule_tob_use_assess', 'patient_reminder_pre', 'week', '2'),
('rule_tob_use_assess', 'patient_reminder_post', 'month', '1'),
('rule_tob_cess_inter', 'clinical_reminder_pre', 'week', '2'),
('rule_tob_cess_inter', 'clinical_reminder_post', 'month', '1'),
('rule_tob_cess_inter', 'patient_reminder_pre', 'week', '2'),
('rule_tob_cess_inter', 'patient_reminder_post', 'month', '1'),
('rule_adult_wt_screen_fu', 'clinical_reminder_pre', 'week', '2'),
('rule_adult_wt_screen_fu', 'clinical_reminder_post', 'month', '1'),
('rule_adult_wt_screen_fu', 'patient_reminder_pre', 'week', '2'),
('rule_adult_wt_screen_fu', 'patient_reminder_post', 'month', '1'),
('rule_wt_assess_couns_child', 'clinical_reminder_pre', 'week', '2'),
('rule_wt_assess_couns_child', 'clinical_reminder_post', 'month', '1'),
('rule_wt_assess_couns_child', 'patient_reminder_pre', 'week', '2'),
('rule_wt_assess_couns_child', 'patient_reminder_post', 'month', '1'),
('rule_influenza_ge_50', 'clinical_reminder_pre', 'week', '2'),
('rule_influenza_ge_50', 'clinical_reminder_post', 'month', '1'),
('rule_influenza_ge_50', 'patient_reminder_pre', 'week', '2'),
('rule_influenza_ge_50', 'patient_reminder_post', 'month', '1'),
('rule_pneumovacc_ge_65', 'clinical_reminder_pre', 'week', '2'),
('rule_pneumovacc_ge_65', 'clinical_reminder_post', 'month', '1'),
('rule_pneumovacc_ge_65', 'patient_reminder_pre', 'week', '2'),
('rule_pneumovacc_ge_65', 'patient_reminder_post', 'month', '1'),
('rule_dm_hemo_a1c', 'clinical_reminder_pre', 'week', '2'),
('rule_dm_hemo_a1c', 'clinical_reminder_post', 'month', '1'),
('rule_dm_hemo_a1c', 'patient_reminder_pre', 'week', '2'),
('rule_dm_hemo_a1c', 'patient_reminder_post', 'month', '1'),
('rule_dm_urine_alb', 'clinical_reminder_pre', 'week', '2'),
('rule_dm_urine_alb', 'clinical_reminder_post', 'month', '1'),
('rule_dm_urine_alb', 'patient_reminder_pre', 'week', '2'),
('rule_dm_urine_alb', 'patient_reminder_post', 'month', '1'),
('rule_dm_eye', 'clinical_reminder_pre', 'week', '2'),
('rule_dm_eye', 'clinical_reminder_post', 'month', '1'),
('rule_dm_eye', 'patient_reminder_pre', 'week', '2'),
('rule_dm_eye', 'patient_reminder_post', 'month', '1'),
('rule_dm_foot', 'clinical_reminder_pre', 'week', '2'),
('rule_dm_foot', 'clinical_reminder_post', 'month', '1'),
('rule_dm_foot', 'patient_reminder_pre', 'week', '2'),
('rule_dm_foot', 'patient_reminder_post', 'month', '1'),
('rule_cs_mammo', 'clinical_reminder_pre', 'week', '2'),
('rule_cs_mammo', 'clinical_reminder_post', 'month', '1'),
('rule_cs_mammo', 'patient_reminder_pre', 'week', '2'),
('rule_cs_mammo', 'patient_reminder_post', 'month', '1'),
('rule_cs_pap', 'clinical_reminder_pre', 'week', '2'),
('rule_cs_pap', 'clinical_reminder_post', 'month', '1'),
('rule_cs_pap', 'patient_reminder_pre', 'week', '2'),
('rule_cs_pap', 'patient_reminder_post', 'month', '1'),
('rule_cs_colon', 'clinical_reminder_pre', 'week', '2'),
('rule_cs_colon', 'clinical_reminder_post', 'month', '1'),
('rule_cs_colon', 'patient_reminder_pre', 'week', '2'),
('rule_cs_colon', 'patient_reminder_post', 'month', '1'),
('rule_cs_prostate', 'clinical_reminder_pre', 'week', '2'),
('rule_cs_prostate', 'clinical_reminder_post', 'month', '1'),
('rule_cs_prostate', 'patient_reminder_pre', 'week', '2'),
('rule_cs_prostate', 'patient_reminder_post', 'month', '1'),
('rule_inr_monitor', 'clinical_reminder_pre', 'week', '2'),
('rule_inr_monitor', 'clinical_reminder_post', 'month', '1'),
('rule_inr_monitor', 'patient_reminder_pre', 'week', '2'),
('rule_inr_monitor', 'patient_reminder_post', 'month', '1'),
('rule_socsec_entry', 'clinical_reminder_pre', 'week', '2'),
('rule_socsec_entry', 'clinical_reminder_post', 'month', '1'),
('rule_socsec_entry', 'patient_reminder_pre', 'week', '2'),
('rule_socsec_entry', 'patient_reminder_post', 'month', '1'),
('rule_penicillin_allergy', 'clinical_reminder_pre', 'week', '2'),
('rule_penicillin_allergy', 'clinical_reminder_post', 'month', '1'),
('rule_penicillin_allergy', 'patient_reminder_pre', 'week', '2'),
('rule_penicillin_allergy', 'patient_reminder_post', 'month', '1'),
('rule_blood_pressure', 'clinical_reminder_pre', 'week', '2'),
('rule_blood_pressure', 'clinical_reminder_post', 'month', '1'),
('rule_blood_pressure', 'patient_reminder_pre', 'week', '2'),
('rule_blood_pressure', 'patient_reminder_post', 'month', '1'),
('rule_inr_measure', 'clinical_reminder_pre', 'week', '2'),
('rule_inr_measure', 'clinical_reminder_post', 'month', '1'),
('rule_inr_measure', 'patient_reminder_pre', 'week', '2'),
('rule_inr_measure', 'patient_reminder_post', 'month', '1');

-- --------------------------------------------------------

--
-- Table structure for table `rule_target`
--

CREATE TABLE `rule_target` (
  `id` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to the id column in the clinical_rules table',
  `group_id` bigint(20) NOT NULL DEFAULT '1' COMMENT 'Contains group id to identify collection of targets in a rule',
  `include_flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 is exclude and 1 is include',
  `required_flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 is required and 1 is optional',
  `method` varchar(31) NOT NULL DEFAULT '' COMMENT 'Maps to list_options list rule_targets',
  `value` varchar(255) NOT NULL DEFAULT '' COMMENT 'Data is dependent on the method',
  `interval` bigint(20) NOT NULL DEFAULT '0' COMMENT 'Only used in interval entries',
  KEY `id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `rule_target`
--

INSERT INTO `rule_target` VALUES
('rule_htn_bp_measure', 1, 1, 1, 'target_interval', 'year', 1),
('rule_htn_bp_measure', 1, 1, 1, 'target_database', '::form_vitals::bps::::::ge::1', 0),
('rule_htn_bp_measure', 1, 1, 1, 'target_database', '::form_vitals::bpd::::::ge::1', 0),
('rule_tob_use_assess', 1, 1, 1, 'target_database', 'LIFESTYLE::tobacco::', 0),
('rule_tob_cess_inter', 1, 1, 1, 'target_interval', 'year', 1),
('rule_tob_cess_inter', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_inter::act_tobacco::YES::ge::1', 0),
('rule_adult_wt_screen_fu', 1, 1, 1, 'target_database', '::form_vitals::weight::::::ge::1', 0),
('rule_wt_assess_couns_child', 1, 1, 1, 'target_database', '::form_vitals::weight::::::ge::1', 0),
('rule_wt_assess_couns_child', 1, 1, 1, 'target_interval', 'year', 3),
('rule_wt_assess_couns_child', 2, 1, 1, 'target_database', 'CUSTOM::act_cat_edu::act_wt::YES::ge::1', 0),
('rule_wt_assess_couns_child', 2, 1, 1, 'target_interval', 'year', 3),
('rule_wt_assess_couns_child', 3, 1, 1, 'target_database', 'CUSTOM::act_cat_edu::act_nutrition::YES::ge::1', 0),
('rule_wt_assess_couns_child', 3, 1, 1, 'target_interval', 'year', 3),
('rule_wt_assess_couns_child', 4, 1, 1, 'target_database', 'CUSTOM::act_cat_edu::act_exercise::YES::ge::1', 0),
('rule_wt_assess_couns_child', 4, 1, 1, 'target_interval', 'year', 3),
('rule_wt_assess_couns_child', 5, 1, 1, 'target_database', '::form_vitals::BMI::::::ge::1', 0),
('rule_wt_assess_couns_child', 5, 1, 1, 'target_interval', 'year', 3),
('rule_influenza_ge_50', 1, 1, 1, 'target_interval', 'flu_season', 1),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::15::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::16::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::88::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::111::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::125::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::126::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::127::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::128::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::135::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::140::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::141::ge::1', 0),
('rule_influenza_ge_50', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::144::ge::1', 0),
('rule_pneumovacc_ge_65', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::33::ge::1', 0),
('rule_pneumovacc_ge_65', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::100::ge::1', 0),
('rule_pneumovacc_ge_65', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::109::ge::1', 0),
('rule_pneumovacc_ge_65', 1, 1, 0, 'target_database', '::immunizations::cvx_code::eq::133::ge::1', 0),
('rule_dm_hemo_a1c', 1, 1, 1, 'target_interval', 'month', 3),
('rule_dm_hemo_a1c', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_measure::act_hemo_a1c::YES::ge::1', 0),
('rule_dm_urine_alb', 1, 1, 1, 'target_interval', 'year', 1),
('rule_dm_urine_alb', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_measure::act_urine_alb::YES::ge::1', 0),
('rule_dm_eye', 1, 1, 1, 'target_interval', 'year', 1),
('rule_dm_eye', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_exam::act_eye::YES::ge::1', 0),
('rule_dm_foot', 1, 1, 1, 'target_interval', 'year', 1),
('rule_dm_foot', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_exam::act_foot::YES::ge::1', 0),
('rule_cs_mammo', 1, 1, 1, 'target_interval', 'year', 1),
('rule_cs_mammo', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_measure::act_mammo::YES::ge::1', 0),
('rule_cs_pap', 1, 1, 1, 'target_interval', 'year', 1),
('rule_cs_pap', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_exam::act_pap::YES::ge::1', 0),
('rule_cs_colon', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_assess::act_colon_cancer_screen::YES::ge::1', 0),
('rule_cs_prostate', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_assess::act_prostate_cancer_screen::YES::ge::1', 0),
('rule_inr_monitor', 1, 1, 1, 'target_interval', 'week', 3),
('rule_inr_monitor', 1, 1, 1, 'target_proc', 'INR::CPT4:85610::::::ge::1', 0),
('rule_socsec_entry', 1, 1, 1, 'target_database', '::patient_data::ss::::::ge::1', 0),
('rule_penicillin_allergy', 1, 1, 1, 'target_interval', 'year', 1),
('rule_penicillin_allergy', 1, 1, 1, 'target_database', 'CUSTOM::act_cat_assess::act_penicillin_allergy::YES::ge::1', 0),
('rule_blood_pressure', 1, 1, 1, 'target_database', '::form_vitals::bps::::::ge::1', 0),
('rule_blood_pressure', 1, 1, 1, 'target_database', '::form_vitals::bpd::::::ge::1', 0),
('rule_inr_measure', 1, 1, 1, 'target_proc', 'INR::CPT4:85610::::::ge::1', 0);

-- --------------------------------------------------------

--
-- Table structure for table `sequences`
--

CREATE TABLE `sequences` (
  `id` int(11) unsigned NOT NULL DEFAULT '0'
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `sequences`
--

INSERT INTO `sequences` VALUES
(1);

-- --------------------------------------------------------

--
-- Table structure for table `shared_attributes`
--

CREATE TABLE `shared_attributes` (
  `pid` bigint(20) NOT NULL,
  `encounter` bigint(20) NOT NULL COMMENT '0 if patient attribute, else encounter attribute',
  `field_id` varchar(31) NOT NULL COMMENT 'references layout_options.field_id',
  `last_update` datetime NOT NULL COMMENT 'time of last update',
  `user_id` bigint(20) NOT NULL COMMENT 'user who last updated',
  `field_value` text,
  PRIMARY KEY (`pid`,`encounter`,`field_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `standardized_tables_track`
--

CREATE TABLE `standardized_tables_track` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `imported_date` datetime DEFAULT NULL,
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'name of standardized tables such as RXNORM',
  `revision_version` varchar(255) NOT NULL DEFAULT '' COMMENT 'revision of standardized tables that were imported',
  `revision_date` datetime DEFAULT NULL COMMENT 'revision of standardized tables that were imported',
  `file_checksum` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `supported_external_dataloads`
--

CREATE TABLE `supported_external_dataloads` (
  `load_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `load_type` varchar(24) NOT NULL DEFAULT '',
  `load_source` varchar(24) NOT NULL DEFAULT 'CMS',
  `load_release_date` date NOT NULL,
  `load_filename` varchar(256) NOT NULL DEFAULT '',
  `load_checksum` varchar(32) NOT NULL DEFAULT '',
  UNIQUE KEY `load_id` (`load_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=42 ;

--
-- Dumping data for table `supported_external_dataloads`
--

INSERT INTO `supported_external_dataloads` VALUES
(1, 'ICD9', 'CMS', '2011-10-01', 'cmsv29_master_descriptions.zip', 'c360c2b5a29974d6c58617c7378dd7c4'),
(2, 'ICD9', 'CMS', '2012-10-01', 'cmsv30_master_descriptions.zip', 'eb26446536435f5f5e677090a7976b15'),
(3, 'ICD9', 'CMS', '2013-10-01', 'cmsv31-master-descriptions.zip', 'fe0d7f9a5338f5ff187683b4737ad2b7'),
(4, 'ICD10', 'CMS', '2011-10-01', '2012_PCS_long_and_abbreviated_titles.zip', '201a732b649d8c7fba807cc4c083a71a'),
(5, 'ICD10', 'CMS', '2011-10-01', 'DiagnosisGEMs_2012.zip', '6758c4a3384c47161ce24f13a2464b53'),
(6, 'ICD10', 'CMS', '2011-10-01', 'ICD10OrderFiles_2012.zip', 'a76601df7a9f5270d8229828a833f6a1'),
(7, 'ICD10', 'CMS', '2011-10-01', 'ProcedureGEMs_2012.zip', 'f37416d8fab6cd2700b634ca5025295d'),
(8, 'ICD10', 'CMS', '2011-10-01', 'ReimbursementMapping_2012.zip', '8b438d1fd1f34a9bb0e423c15e89744b'),
(9, 'ICD10', 'CMS', '2012-10-01', '2013_PCS_long_and_abbreviated_titles.zip', '04458ed0631c2c122624ee0a4ca1c475'),
(10, 'ICD10', 'CMS', '2012-10-01', '2013-DiagnosisGEMs.zip', '773aac2a675d6aefd1d7dd149883be51'),
(11, 'ICD10', 'CMS', '2012-10-01', 'ICD10CMOrderFiles_2013.zip', '1c175a858f833485ef8f9d3e66b4d8bd'),
(12, 'ICD10', 'CMS', '2012-10-01', 'ProcedureGEMs_2013.zip', '92aa7640e5ce29b9629728f7d4fc81db'),
(13, 'ICD10', 'CMS', '2012-10-01', '2013-ReimbursementMapping_dx.zip', '0d5d36e3f4519bbba08a9508576787fb'),
(14, 'ICD10', 'CMS', '2012-10-01', 'ReimbursementMapping_pr_2013.zip', '4c3920fedbcd9f6af54a1dc9069a11ca'),
(15, 'ICD10', 'CMS', '2013-10-01', '2014-Reimbursement-Mappings-PR.zip', 'f306a0e8c9edb34d28fd6ce8af82b646'),
(16, 'ICD10', 'CMS', '2013-10-01', '2014-Reimbursement-Mappings-DX.zip', '614b3957304208e3ef7d3ba8b3618888'),
(17, 'ICD10', 'CMS', '2013-10-01', 'ProcedureGEMs-2014.zip', 'be46de29f4f40f97315d04821273acf9'),
(18, 'ICD10', 'CMS', '2013-10-01', '2014-ICD10-Code-Descriptions.zip', '5458b95f6f37228b5cdfa03aefc6c8bb'),
(19, 'ICD10', 'CMS', '2013-10-01', 'DiagnosisGEMs-2014.zip', '3ed7b7c5a11c766102b12d97d777a11b'),
(20, 'ICD10', 'CMS', '2013-10-01', '2014-PCS-long-and-abbreviated-titles.zip', '2d03514a0c66d92cf022a0bc28c83d38'),
(21, 'ICD9', 'CMS', '2014-10-01', 'ICD-9-CM-v32-master-descriptions.zip', 'b852b85f770c83433201dc8ae2c59074'),
(22, 'ICD10', 'CMS', '2014-10-01', '2015-PCS-long-and-abbreviated-titles.zip', 'd1504d6cbc40e008e52dbc50600a4b66'),
(23, 'ICD10', 'CMS', '2014-10-01', 'DiagnosisGEMs_2015.zip', 'a4505805edf25ba4eacda07f23934e63'),
(24, 'ICD10', 'CMS', '2014-10-01', '2015-code-descriptions.zip', '6a8c0ab630d5afa7482daa417950846a'),
(25, 'ICD10', 'CMS', '2014-10-01', 'ProcedureGEMs_2015.zip', 'fcba4e4c96851f4c900345bc557483e2'),
(26, 'ICD10', 'CMS', '2014-10-01', 'Reimbursement_Mapping_dx_2015.zip', '0990d5bcac13ccf5e288249be5261fd7'),
(27, 'ICD10', 'CMS', '2014-10-01', 'Reimbursement_Mapping_pr_2015.zip', '493c022db17a70fcdcbb41bf0ad61a47'),
(28, 'ICD10', 'CMS', '2015-10-01', '2016-PCS-Long-Abbrev-Titles.zip', 'd5ea519d0257db0ed7deb0406a4d0503'),
(29, 'ICD10', 'CMS', '2015-10-01', '2016-General-Equivalence-Mappings.zip', '3324a45b6040be7e48ab770a0d3ca695'),
(30, 'ICD10', 'CMS', '2015-10-01', '2016-Code-Descriptions-in-Tabular-Order.zip', '518a47fe9e268e4fb72fecf633d15f17'),
(31, 'ICD10', 'CMS', '2015-10-01', '2016-ProcedureGEMs.zip', '45a8d9da18d8aed57f0c6ea91e3e8fe4'),
(32, 'ICD10', 'CMS', '2015-10-01', 'Reimbursement_Mapping_dx_2016.zip', '1b53b512e10c1fdf7ae4cfd1baa8dfbb'),
(33, 'ICD10', 'CMS', '2015-10-01', 'Reimbursement_Mapping_pr_2016.zip', '3c780dd103d116aa57980decfddd4f19'),
(34, 'ICD10', 'CMS', '2016-10-01', '2017-PCS-Long-Abbrev-Titles.zip', '4669c47f6a9ca34bf4c14d7f93b37993'),
(35, 'ICD10', 'CMS', '2016-10-01', '2017-GEM-DC.zip', '5a0affdc77a152e6971781233ee969c1'),
(36, 'ICD10', 'CMS', '2016-10-01', '2017-ICD10-Code-Descriptions.zip', 'ed9c159cb4ac4ae4f145062e15f83291'),
(37, 'ICD10', 'CMS', '2016-10-01', '2017-GEM-PCS.zip', 'a4e08b08fb9a53c81385867c82aa8a9e'),
(38, 'ICD10', 'CMS', '2017-10-01', '2018-ICD-10-PCS-Order-File.zip', '264b342310236f2b3927062d2c72cfe3'),
(39, 'ICD10', 'CMS', '2017-10-01', '2018-ICD-10-CM-General-Equivalence-Mappings.zip', '787a025fdcf6e1da1a85be779004f670'),
(40, 'ICD10', 'CMS', '2017-10-01', '2018-ICD-10-Code-Descriptions.zip', '6f9c77440132e30f565222ca9bb6599c'),
(41, 'ICD10', 'CMS', '2017-10-01', '2018-ICD-10-PCS-General-Equivalence-Mappings.zip', 'bb73c80e272da28712887d7979b1cebf');

-- --------------------------------------------------------

--
-- Table structure for table `syndromic_surveillance`
--

CREATE TABLE `syndromic_surveillance` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `lists_id` bigint(20) NOT NULL,
  `submission_date` datetime NOT NULL,
  `filename` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `lists_id` (`lists_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `tf_filters`
--

CREATE TABLE `tf_filters` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `created_at` datetime NOT NULL,
  `created_by` varchar(255) NOT NULL,
  `updated_at` datetime NOT NULL,
  `updated_by` varchar(255) NOT NULL,
  `requesting_action` varchar(255) NOT NULL COMMENT 'allow or deny',
  `requesting_type` varchar(255) NOT NULL COMMENT 'user or group',
  `requesting_entity` varchar(255) NOT NULL COMMENT 'the group name or username of the source',
  `object_type` varchar(255) NOT NULL COMMENT 'patient or tag',
  `object_entity` bigint(20) NOT NULL COMMENT 'tag id of tag',
  `note` text NOT NULL,
  `gacl_aro` int(11) NOT NULL COMMENT 'placeholder',
  `gacl_acl` int(11) NOT NULL COMMENT 'placeholder',
  `effective_datetime` datetime NOT NULL,
  `expiration_datetime` datetime NOT NULL,
  `priority` int(11) NOT NULL,
  `deleted` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `tf_patients_tags`
--

CREATE TABLE `tf_patients_tags` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `tag_id` bigint(20) NOT NULL,
  `pid` bigint(20) NOT NULL,
  `created_at` datetime NOT NULL,
  `created_by` datetime NOT NULL,
  `updated_at` datetime NOT NULL,
  `updated_by` datetime NOT NULL,
  `status` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `tf_tags`
--

CREATE TABLE `tf_tags` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `created_at` datetime NOT NULL,
  `created_by` varchar(255) NOT NULL,
  `updated_at` datetime NOT NULL,
  `updated_by` varchar(255) NOT NULL,
  `tag_name` varchar(255) NOT NULL,
  `tag_color` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

-- --------------------------------------------------------

--
-- Table structure for table `transactions`
--

CREATE TABLE `transactions` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `date` datetime DEFAULT NULL,
  `title` varchar(255) NOT NULL DEFAULT '',
  `pid` bigint(20) DEFAULT NULL,
  `user` varchar(255) NOT NULL DEFAULT '',
  `groupname` varchar(255) NOT NULL DEFAULT '',
  `authorized` tinyint(4) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `pid` (`pid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `users`
--

CREATE TABLE `users` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `username` varchar(255) DEFAULT NULL,
  `password` longtext,
  `authorized` tinyint(4) DEFAULT NULL,
  `info` longtext,
  `source` tinyint(4) DEFAULT NULL,
  `fname` varchar(255) DEFAULT NULL,
  `mname` varchar(255) DEFAULT NULL,
  `lname` varchar(255) DEFAULT NULL,
  `federaltaxid` varchar(255) DEFAULT NULL,
  `federaldrugid` varchar(255) DEFAULT NULL,
  `upin` varchar(255) DEFAULT NULL,
  `facility` varchar(255) DEFAULT NULL,
  `facility_id` int(11) NOT NULL DEFAULT '0',
  `see_auth` int(11) NOT NULL DEFAULT '1',
  `active` tinyint(1) NOT NULL DEFAULT '1',
  `npi` varchar(15) DEFAULT NULL,
  `title` varchar(30) DEFAULT NULL,
  `specialty` varchar(255) DEFAULT NULL,
  `billname` varchar(255) DEFAULT NULL,
  `email` varchar(255) DEFAULT NULL,
  `email_direct` varchar(255) NOT NULL DEFAULT '',
  `url` varchar(255) DEFAULT NULL,
  `assistant` varchar(255) DEFAULT NULL,
  `organization` varchar(255) DEFAULT NULL,
  `valedictory` varchar(255) DEFAULT NULL,
  `street` varchar(60) DEFAULT NULL,
  `streetb` varchar(60) DEFAULT NULL,
  `city` varchar(30) DEFAULT NULL,
  `state` varchar(30) DEFAULT NULL,
  `zip` varchar(20) DEFAULT NULL,
  `street2` varchar(60) DEFAULT NULL,
  `streetb2` varchar(60) DEFAULT NULL,
  `city2` varchar(30) DEFAULT NULL,
  `state2` varchar(30) DEFAULT NULL,
  `zip2` varchar(20) DEFAULT NULL,
  `phone` varchar(30) DEFAULT NULL,
  `fax` varchar(30) DEFAULT NULL,
  `phonew1` varchar(30) DEFAULT NULL,
  `phonew2` varchar(30) DEFAULT NULL,
  `phonecell` varchar(30) DEFAULT NULL,
  `notes` text,
  `cal_ui` tinyint(4) NOT NULL DEFAULT '1',
  `taxonomy` varchar(30) NOT NULL DEFAULT '207Q00000X',
  `calendar` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 = appears in calendar',
  `abook_type` varchar(31) NOT NULL DEFAULT '',
  `pwd_expiration_date` date DEFAULT NULL,
  `pwd_history1` longtext,
  `pwd_history2` longtext,
  `default_warehouse` varchar(31) NOT NULL DEFAULT '',
  `irnpool` varchar(31) NOT NULL DEFAULT '',
  `state_license_number` varchar(25) DEFAULT NULL,
  `newcrop_user_role` varchar(30) DEFAULT NULL,
  `cpoe` tinyint(1) DEFAULT NULL,
  `physician_type` varchar(50) DEFAULT NULL,
  `suffix` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `users`
--

INSERT INTO `users` VALUES
(1, '[[admin_username]]', 'NoLongerUsed', 1, NULL, NULL, '[[admin_fname]]', NULL, '[[admin_lname]]', NULL, NULL, NULL, NULL, 3, 1, 1, NULL, NULL, NULL, NULL, NULL, '', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 3, '207Q00000X', 1, '', NULL, NULL, NULL, '', '', NULL, NULL, NULL, NULL, NULL),
(2, 'phimail-service', 'NoLogin', 0, NULL, NULL, NULL, NULL, 'phiMail Gateway', NULL, NULL, NULL, NULL, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, '', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, '207Q00000X', 0, '', NULL, NULL, NULL, '', '', NULL, NULL, NULL, NULL, NULL),
(3, 'portal-user', 'NoLogin', 0, NULL, NULL, NULL, NULL, 'Patient Portal User', NULL, NULL, NULL, NULL, 0, 1, 0, NULL, NULL, NULL, NULL, NULL, '', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, '207Q00000X', 0, '', NULL, NULL, NULL, '', '', NULL, NULL, NULL, NULL, NULL);

-- --------------------------------------------------------

--
-- Table structure for table `users_facility`
--

CREATE TABLE `users_facility` (
  `tablename` varchar(64) NOT NULL,
  `table_id` int(11) NOT NULL,
  `facility_id` int(11) NOT NULL,
  PRIMARY KEY (`tablename`,`table_id`,`facility_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='joins users or patient_data to facility table';

-- --------------------------------------------------------

--
-- Table structure for table `users_secure`
--

CREATE TABLE `users_secure` (
  `id` bigint(20) NOT NULL,
  `username` varchar(255) DEFAULT NULL,
  `password` varchar(255) DEFAULT NULL,
  `salt` varchar(255) DEFAULT NULL,
  `last_update` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `password_history1` varchar(255) DEFAULT NULL,
  `salt_history1` varchar(255) DEFAULT NULL,
  `password_history2` varchar(255) DEFAULT NULL,
  `salt_history2` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `USERNAME_ID` (`id`,`username`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `users_secure`
--

INSERT INTO `users_secure` VALUES
(1, '[[admin_username]]', '[[admin_pass]]', '[[salt]]', '[[regtime]]', NULL, NULL, NULL, NULL);

-- --------------------------------------------------------

--
-- Table structure for table `user_settings`
--

CREATE TABLE `user_settings` (
  `setting_user` bigint(20) NOT NULL DEFAULT '0',
  `setting_label` varchar(63) NOT NULL,
  `setting_value` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`setting_user`,`setting_label`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `user_settings`
--

INSERT INTO `user_settings` VALUES
(0, 'allergy_ps_expand', '1'),
(0, 'appointments_ps_expand', '1'),
(0, 'billing_ps_expand', '0'),
(0, 'clinical_reminders_ps_expand', '1'),
(0, 'demographics_ps_expand', '0'),
(0, 'dental_ps_expand', '1'),
(0, 'directives_ps_expand', '1'),
(0, 'disclosures_ps_expand', '0'),
(0, 'gacl_protect', '0'),
(0, 'immunizations_ps_expand', '1'),
(0, 'insurance_ps_expand', '0'),
(0, 'medical_problem_ps_expand', '1'),
(0, 'medication_ps_expand', '1'),
(0, 'patient_reminders_ps_expand', '0'),
(0, 'pnotes_ps_expand', '0'),
(0, 'prescriptions_ps_expand', '1'),
(0, 'surgery_ps_expand', '1'),
(0, 'vitals_ps_expand', '1'),
(1, 'gacl_protect', '1');

-- --------------------------------------------------------

--
-- Table structure for table `version`
--

CREATE TABLE `version` (
  `v_major` int(11) NOT NULL DEFAULT '0',
  `v_minor` int(11) NOT NULL DEFAULT '0',
  `v_patch` int(11) NOT NULL DEFAULT '0',
  `v_realpatch` int(11) NOT NULL DEFAULT '0',
  `v_tag` varchar(31) NOT NULL DEFAULT '',
  `v_database` int(11) NOT NULL DEFAULT '0',
  `v_acl` int(11) NOT NULL DEFAULT '0'
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Dumping data for table `version`
--

INSERT INTO `version` VALUES
(2, 0, 0, 0, '', 2, 0);

-- --------------------------------------------------------

--
-- Table structure for table `x12_partners`
--

CREATE TABLE `x12_partners` (
  `id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `id_number` varchar(255) DEFAULT NULL,
  `x12_sender_id` varchar(255) DEFAULT NULL,
  `x12_receiver_id` varchar(255) DEFAULT NULL,
  `x12_version` varchar(255) DEFAULT NULL,
  `processing_format` enum('standard','medi-cal','cms','proxymed') DEFAULT NULL,
  `x12_isa01` varchar(2) NOT NULL DEFAULT '00' COMMENT 'User logon Required Indicator',
  `x12_isa02` varchar(10) NOT NULL DEFAULT '          ' COMMENT 'User Logon',
  `x12_isa03` varchar(2) NOT NULL DEFAULT '00' COMMENT 'User password required Indicator',
  `x12_isa04` varchar(10) NOT NULL DEFAULT '          ' COMMENT 'User Password',
  `x12_isa05` char(2) NOT NULL DEFAULT 'ZZ',
  `x12_isa07` char(2) NOT NULL DEFAULT 'ZZ',
  `x12_isa14` char(1) NOT NULL DEFAULT '0',
  `x12_isa15` char(1) NOT NULL DEFAULT 'P',
  `x12_gs02` varchar(15) NOT NULL DEFAULT '',
  `x12_per06` varchar(80) NOT NULL DEFAULT '',
  `x12_gs03` varchar(15) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
